﻿#pragma once
#include <string_view>

namespace data {
    using std::string_view;

    // From the "Corncob" online dictionary,
    // <url: http://www.mieliestronk.com/wordlist.html>.
    
    // Originally expressed as a single long string literal for the MinGW g++ compiler.
    // But now using an array of `char` to work around Visual C++ 2019 errors
    // “string too big, trailing characters truncated” and “string exceeds 65535 bytes
    // in length”. These limits seem to be unadjusted since the 1980’s.

    inline extern constexpr char english_words_literal[] =
    {
        '\n',
        'a', 'a', 'r', 'd', 'v', 'a', 'r', 'k', '\n',
        'a', 'a', 'r', 'd', 'w', 'o', 'l', 'f', '\n',
        'a', 'a', 'r', 'o', 'n', '\n',
        'a', 'b', 'a', 'c', 'k', '\n',
        'a', 'b', 'a', 'c', 'u', 's', '\n',
        'a', 'b', 'a', 'f', 't', '\n',
        'a', 'b', 'a', 'l', 'o', 'n', 'e', '\n',
        'a', 'b', 'a', 'n', 'd', 'o', 'n', '\n',
        'a', 'b', 'a', 'n', 'd', 'o', 'n', 'e', 'd', '\n',
        'a', 'b', 'a', 'n', 'd', 'o', 'n', 'm', 'e', 'n', 't', '\n',
        'a', 'b', 'a', 'n', 'd', 'o', 'n', 's', '\n',
        'a', 'b', 'a', 's', 'e', '\n',
        'a', 'b', 'a', 's', 'e', 'd', '\n',
        'a', 'b', 'a', 's', 'e', 'm', 'e', 'n', 't', '\n',
        'a', 'b', 'a', 's', 'h', '\n',
        'a', 'b', 'a', 's', 'h', 'e', 'd', '\n',
        'a', 'b', 'a', 't', 'e', '\n',
        'a', 'b', 'a', 't', 'e', 'd', '\n',
        'a', 'b', 'a', 't', 'e', 'm', 'e', 'n', 't', '\n',
        'a', 'b', 'a', 't', 'e', 's', '\n',
        'a', 'b', 'a', 't', 't', 'o', 'i', 'r', '\n',
        'a', 'b', 'a', 't', 't', 'o', 'i', 'r', 's', '\n',
        'a', 'b', 'b', 'e', '\n',
        'a', 'b', 'b', 'e', 's', 's', '\n',
        'a', 'b', 'b', 'e', 'y', '\n',
        'a', 'b', 'b', 'e', 'y', 's', '\n',
        'a', 'b', 'b', 'o', 't', '\n',
        'a', 'b', 'b', 'o', 't', 's', '\n',
        'a', 'b', 'b', 'r', 'e', 'v', 'i', 'a', 't', 'e', '\n',
        'a', 'b', 'b', 'r', 'e', 'v', 'i', 'a', 't', 'e', 'd', '\n',
        'a', 'b', 'b', 'r', 'e', 'v', 'i', 'a', 't', 'e', 's', '\n',
        'a', 'b', 'b', 'r', 'e', 'v', 'i', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'b', 'b', 'r', 'e', 'v', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'b', 'b', 'r', 'e', 'v', 'i', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'b', 'd', 'i', 'c', 'a', 't', 'e', '\n',
        'a', 'b', 'd', 'i', 'c', 'a', 't', 'e', 'd', '\n',
        'a', 'b', 'd', 'i', 'c', 'a', 't', 'e', 's', '\n',
        'a', 'b', 'd', 'i', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'b', 'd', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'b', 'd', 'o', 'm', 'e', 'n', '\n',
        'a', 'b', 'd', 'o', 'm', 'e', 'n', 's', '\n',
        'a', 'b', 'd', 'o', 'm', 'i', 'n', 'a', 'l', '\n',
        'a', 'b', 'd', 'u', 'c', 't', '\n',
        'a', 'b', 'd', 'u', 'c', 't', 'e', 'd', '\n',
        'a', 'b', 'd', 'u', 'c', 't', 'i', 'n', 'g', '\n',
        'a', 'b', 'd', 'u', 'c', 't', 'i', 'o', 'n', '\n',
        'a', 'b', 'd', 'u', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'b', 'd', 'u', 'c', 't', 'o', 'r', '\n',
        'a', 'b', 'd', 'u', 'c', 't', 'o', 'r', 's', '\n',
        'a', 'b', 'd', 'u', 'c', 't', 's', '\n',
        'a', 'b', 'e', '\n',
        'a', 'b', 'e', 'a', 'm', '\n',
        'a', 'b', 'e', 'l', '\n',
        'a', 'b', 'e', 'l', 'e', '\n',
        'a', 'b', 'e', 'r', 'd', 'e', 'e', 'n', '\n',
        'a', 'b', 'e', 'r', 'r', 'a', 'n', 't', '\n',
        'a', 'b', 'e', 'r', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'b', 'e', 'r', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'b', 'e', 't', '\n',
        'a', 'b', 'e', 't', 's', '\n',
        'a', 'b', 'e', 't', 't', 'e', 'd', '\n',
        'a', 'b', 'e', 't', 't', 'i', 'n', 'g', '\n',
        'a', 'b', 'e', 'y', 'a', 'n', 'c', 'e', '\n',
        'a', 'b', 'h', 'o', 'r', '\n',
        'a', 'b', 'h', 'o', 'r', 'r', 'e', 'd', '\n',
        'a', 'b', 'h', 'o', 'r', 'r', 'e', 'n', 'c', 'e', '\n',
        'a', 'b', 'h', 'o', 'r', 'r', 'e', 'n', 't', '\n',
        'a', 'b', 'h', 'o', 'r', 's', '\n',
        'a', 'b', 'i', 'd', 'e', '\n',
        'a', 'b', 'i', 'd', 'e', 'd', '\n',
        'a', 'b', 'i', 'd', 'e', 's', '\n',
        'a', 'b', 'i', 'd', 'i', 'n', 'g', '\n',
        'a', 'b', 'i', 'd', 'j', 'a', 'n', '\n',
        'a', 'b', 'i', 'e', 's', '\n',
        'a', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'a', 'b', 'j', 'e', 'c', 't', '\n',
        'a', 'b', 'j', 'e', 'c', 't', 'l', 'y', '\n',
        'a', 'b', 'j', 'u', 'r', 'e', '\n',
        'a', 'b', 'j', 'u', 'r', 'e', 'd', '\n',
        'a', 'b', 'l', 'a', 't', 'e', '\n',
        'a', 'b', 'l', 'a', 't', 'e', 's', '\n',
        'a', 'b', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'b', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'b', 'l', 'a', 't', 'i', 'v', 'e', '\n',
        'a', 'b', 'l', 'a', 'z', 'e', '\n',
        'a', 'b', 'l', 'e', '\n',
        'a', 'b', 'l', 'e', 'b', 'o', 'd', 'i', 'e', 'd', '\n',
        'a', 'b', 'l', 'e', 'r', '\n',
        'a', 'b', 'l', 'e', 's', 't', '\n',
        'a', 'b', 'l', 'o', 'o', 'm', '\n',
        'a', 'b', 'l', 'u', 't', 'i', 'o', 'n', '\n',
        'a', 'b', 'l', 'u', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'b', 'l', 'y', '\n',
        'a', 'b', 'n', 'e', 'g', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'b', 'n', 'o', 'r', 'm', 'a', 'l', '\n',
        'a', 'b', 'n', 'o', 'r', 'm', 'a', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'a', 'b', 'n', 'o', 'r', 'm', 'a', 'l', 'i', 't', 'y', '\n',
        'a', 'b', 'n', 'o', 'r', 'm', 'a', 'l', 'l', 'y', '\n',
        'a', 'b', 'o', 'a', 'r', 'd', '\n',
        'a', 'b', 'o', 'd', 'e', '\n',
        'a', 'b', 'o', 'd', 'e', 's', '\n',
        'a', 'b', 'o', 'l', 'i', 's', 'h', '\n',
        'a', 'b', 'o', 'l', 'i', 's', 'h', 'e', 'd', '\n',
        'a', 'b', 'o', 'l', 'i', 's', 'h', 'e', 's', '\n',
        'a', 'b', 'o', 'l', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'a', 'b', 'o', 'l', 'i', 't', 'i', 'o', 'n', '\n',
        'a', 'b', 'o', 'l', 'i', 't', 'i', 'o', 'n', 'i', 's', 't', '\n',
        'a', 'b', 'o', 'l', 'i', 't', 'i', 'o', 'n', 'i', 's', 't', 's', '\n',
        'a', 'b', 'o', 'm', 'b', '\n',
        'a', 'b', 'o', 'm', 'i', 'n', 'a', 'b', 'l', 'e', '\n',
        'a', 'b', 'o', 'm', 'i', 'n', 'a', 'b', 'l', 'y', '\n',
        'a', 'b', 'o', 'm', 'i', 'n', 'a', 't', 'e', '\n',
        'a', 'b', 'o', 'm', 'i', 'n', 'a', 't', 'e', 'd', '\n',
        'a', 'b', 'o', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'b', 'o', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'b', 'o', 'r', 'i', 'g', 'i', 'n', 'a', 'l', '\n',
        'a', 'b', 'o', 'r', 'i', 'g', 'i', 'n', 'e', 's', '\n',
        'a', 'b', 'o', 'r', 't', '\n',
        'a', 'b', 'o', 'r', 't', 'e', 'd', '\n',
        'a', 'b', 'o', 'r', 't', 'i', 'n', 'g', '\n',
        'a', 'b', 'o', 'r', 't', 'i', 'o', 'n', '\n',
        'a', 'b', 'o', 'r', 't', 'i', 'o', 'n', 'i', 's', 't', '\n',
        'a', 'b', 'o', 'r', 't', 'i', 'o', 'n', 'i', 's', 't', 's', '\n',
        'a', 'b', 'o', 'r', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'b', 'o', 'r', 't', 'i', 'v', 'e', '\n',
        'a', 'b', 'o', 'r', 't', 's', '\n',
        'a', 'b', 'o', 'u', 'n', 'd', '\n',
        'a', 'b', 'o', 'u', 'n', 'd', 'e', 'd', '\n',
        'a', 'b', 'o', 'u', 'n', 'd', 'i', 'n', 'g', '\n',
        'a', 'b', 'o', 'u', 'n', 'd', 's', '\n',
        'a', 'b', 'o', 'u', 't', '\n',
        'a', 'b', 'o', 'v', 'e', '\n',
        'a', 'b', 'r', 'a', 'd', 'e', 'd', '\n',
        'a', 'b', 'r', 'a', 'h', 'a', 'm', '\n',
        'a', 'b', 'r', 'a', 's', 'i', 'o', 'n', '\n',
        'a', 'b', 'r', 'a', 's', 'i', 'o', 'n', 's', '\n',
        'a', 'b', 'r', 'a', 's', 'i', 'v', 'e', '\n',
        'a', 'b', 'r', 'a', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'a', 'b', 'r', 'a', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'a', 'b', 'r', 'a', 's', 'i', 'v', 'e', 's', '\n',
        'a', 'b', 'r', 'e', 'a', 's', 't', '\n',
        'a', 'b', 'r', 'i', 'd', 'g', 'e', '\n',
        'a', 'b', 'r', 'i', 'd', 'g', 'e', 'd', '\n',
        'a', 'b', 'r', 'i', 'd', 'g', 'e', 'm', 'e', 'n', 't', '\n',
        'a', 'b', 'r', 'i', 'd', 'g', 'i', 'n', 'g', '\n',
        'a', 'b', 'r', 'o', 'a', 'd', '\n',
        'a', 'b', 'r', 'o', 'g', 'a', 't', 'e', '\n',
        'a', 'b', 'r', 'o', 'g', 'a', 't', 'e', 'd', '\n',
        'a', 'b', 'r', 'o', 'g', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'b', 'r', 'o', 'g', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'b', 'r', 'o', 'g', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'b', 'r', 'u', 'p', 't', '\n',
        'a', 'b', 'r', 'u', 'p', 't', 'l', 'y', '\n',
        'a', 'b', 'r', 'u', 'p', 't', 'n', 'e', 's', 's', '\n',
        'a', 'b', 's', 'c', 'e', 's', 's', '\n',
        'a', 'b', 's', 'c', 'e', 's', 's', 'e', 's', '\n',
        'a', 'b', 's', 'c', 'i', 's', 's', 'a', '\n',
        'a', 'b', 's', 'c', 'i', 's', 's', 'a', 'e', '\n',
        'a', 'b', 's', 'c', 'i', 's', 's', 'a', 's', '\n',
        'a', 'b', 's', 'c', 'o', 'n', 'd', '\n',
        'a', 'b', 's', 'c', 'o', 'n', 'd', 'e', 'd', '\n',
        'a', 'b', 's', 'c', 'o', 'n', 'd', 'e', 'r', '\n',
        'a', 'b', 's', 'c', 'o', 'n', 'd', 'i', 'n', 'g', '\n',
        'a', 'b', 's', 'c', 'o', 'n', 'd', 's', '\n',
        'a', 'b', 's', 'e', 'i', 'l', '\n',
        'a', 'b', 's', 'e', 'i', 'l', 'e', 'd', '\n',
        'a', 'b', 's', 'e', 'i', 'l', 'e', 'r', '\n',
        'a', 'b', 's', 'e', 'i', 'l', 'i', 'n', 'g', '\n',
        'a', 'b', 's', 'e', 'i', 'l', 's', '\n',
        'a', 'b', 's', 'e', 'n', 'c', 'e', '\n',
        'a', 'b', 's', 'e', 'n', 'c', 'e', 's', '\n',
        'a', 'b', 's', 'e', 'n', 't', '\n',
        'a', 'b', 's', 'e', 'n', 't', 'e', 'd', '\n',
        'a', 'b', 's', 'e', 'n', 't', 'e', 'e', '\n',
        'a', 'b', 's', 'e', 'n', 't', 'e', 'e', 'i', 's', 'm', '\n',
        'a', 'b', 's', 'e', 'n', 't', 'e', 'e', 's', '\n',
        'a', 'b', 's', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'a', 'b', 's', 'e', 'n', 't', 'l', 'y', '\n',
        'a', 'b', 's', 'e', 'n', 't', 'm', 'i', 'n', 'd', 'e', 'd', '\n',
        'a', 'b', 's', 'e', 'n', 't', 'm', 'i', 'n', 'd', 'e', 'd', 'l', 'y', '\n',
        'a', 'b', 's', 'e', 'n', 't', 'm', 'i', 'n', 'd', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'a', 'b', 's', 'o', 'l', 'u', 't', 'e', '\n',
        'a', 'b', 's', 'o', 'l', 'u', 't', 'e', 'l', 'y', '\n',
        'a', 'b', 's', 'o', 'l', 'u', 't', 'e', 'n', 'e', 's', 's', '\n',
        'a', 'b', 's', 'o', 'l', 'u', 't', 'e', 's', '\n',
        'a', 'b', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', '\n',
        'a', 'b', 's', 'o', 'l', 'u', 't', 'i', 's', 'm', '\n',
        'a', 'b', 's', 'o', 'l', 'u', 't', 'i', 's', 't', '\n',
        'a', 'b', 's', 'o', 'l', 'u', 't', 'i', 's', 't', 's', '\n',
        'a', 'b', 's', 'o', 'l', 'v', 'e', '\n',
        'a', 'b', 's', 'o', 'l', 'v', 'e', 'd', '\n',
        'a', 'b', 's', 'o', 'l', 'v', 'e', 's', '\n',
        'a', 'b', 's', 'o', 'l', 'v', 'i', 'n', 'g', '\n',
        'a', 'b', 's', 'o', 'r', 'b', '\n',
        'a', 'b', 's', 'o', 'r', 'b', 'e', 'd', '\n',
        'a', 'b', 's', 'o', 'r', 'b', 'e', 'n', 'c', 'y', '\n',
        'a', 'b', 's', 'o', 'r', 'b', 'e', 'n', 't', '\n',
        'a', 'b', 's', 'o', 'r', 'b', 'e', 'r', '\n',
        'a', 'b', 's', 'o', 'r', 'b', 'e', 'r', 's', '\n',
        'a', 'b', 's', 'o', 'r', 'b', 'i', 'n', 'g', '\n',
        'a', 'b', 's', 'o', 'r', 'b', 'i', 'n', 'g', 'l', 'y', '\n',
        'a', 'b', 's', 'o', 'r', 'b', 's', '\n',
        'a', 'b', 's', 'o', 'r', 'p', 't', 'i', 'o', 'n', '\n',
        'a', 'b', 's', 'o', 'r', 'p', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'b', 's', 'o', 'r', 'p', 't', 'i', 'v', 'e', '\n',
        'a', 'b', 's', 'o', 'r', 'p', 't', 'i', 'v', 'i', 't', 'y', '\n',
        'a', 'b', 's', 't', 'a', 'i', 'n', '\n',
        'a', 'b', 's', 't', 'a', 'i', 'n', 'e', 'd', '\n',
        'a', 'b', 's', 't', 'a', 'i', 'n', 'e', 'r', '\n',
        'a', 'b', 's', 't', 'a', 'i', 'n', 'e', 'r', 's', '\n',
        'a', 'b', 's', 't', 'a', 'i', 'n', 'i', 'n', 'g', '\n',
        'a', 'b', 's', 't', 'a', 'i', 'n', 's', '\n',
        'a', 'b', 's', 't', 'e', 'm', 'i', 'o', 'u', 's', '\n',
        'a', 'b', 's', 't', 'e', 'm', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'a', 'b', 's', 't', 'e', 'm', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'a', 'b', 's', 't', 'e', 'n', 't', 'i', 'o', 'n', '\n',
        'a', 'b', 's', 't', 'e', 'n', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'b', 's', 't', 'i', 'n', 'e', 'n', 'c', 'e', '\n',
        'a', 'b', 's', 't', 'i', 'n', 'e', 'n', 't', '\n',
        'a', 'b', 's', 't', 'r', 'a', 'c', 't', '\n',
        'a', 'b', 's', 't', 'r', 'a', 'c', 't', 'e', 'd', '\n',
        'a', 'b', 's', 't', 'r', 'a', 'c', 't', 'e', 'd', 'l', 'y', '\n',
        'a', 'b', 's', 't', 'r', 'a', 'c', 't', 'i', 'n', 'g', '\n',
        'a', 'b', 's', 't', 'r', 'a', 'c', 't', 'i', 'o', 'n', '\n',
        'a', 'b', 's', 't', 'r', 'a', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'b', 's', 't', 'r', 'a', 'c', 't', 'l', 'y', '\n',
        'a', 'b', 's', 't', 'r', 'a', 'c', 't', 's', '\n',
        'a', 'b', 's', 't', 'r', 'u', 's', 'e', '\n',
        'a', 'b', 's', 't', 'r', 'u', 's', 'e', 'l', 'y', '\n',
        'a', 'b', 's', 'u', 'r', 'd', '\n',
        'a', 'b', 's', 'u', 'r', 'd', 'e', 'r', '\n',
        'a', 'b', 's', 'u', 'r', 'd', 'e', 's', 't', '\n',
        'a', 'b', 's', 'u', 'r', 'd', 'i', 's', 't', '\n',
        'a', 'b', 's', 'u', 'r', 'd', 'i', 't', 'i', 'e', 's', '\n',
        'a', 'b', 's', 'u', 'r', 'd', 'i', 't', 'y', '\n',
        'a', 'b', 's', 'u', 'r', 'd', 'l', 'y', '\n',
        'a', 'b', 'u', 'n', 'd', 'a', 'n', 'c', 'e', '\n',
        'a', 'b', 'u', 'n', 'd', 'a', 'n', 'c', 'e', 's', '\n',
        'a', 'b', 'u', 'n', 'd', 'a', 'n', 't', '\n',
        'a', 'b', 'u', 'n', 'd', 'a', 'n', 't', 'l', 'y', '\n',
        'a', 'b', 'u', 's', 'e', '\n',
        'a', 'b', 'u', 's', 'e', 'd', '\n',
        'a', 'b', 'u', 's', 'e', 'r', '\n',
        'a', 'b', 'u', 's', 'e', 'r', 's', '\n',
        'a', 'b', 'u', 's', 'e', 's', '\n',
        'a', 'b', 'u', 's', 'i', 'n', 'g', '\n',
        'a', 'b', 'u', 's', 'i', 'v', 'e', '\n',
        'a', 'b', 'u', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'a', 'b', 'u', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'a', 'b', 'u', 't', '\n',
        'a', 'b', 'u', 't', 'm', 'e', 'n', 't', '\n',
        'a', 'b', 'u', 't', 'm', 'e', 'n', 't', 's', '\n',
        'a', 'b', 'u', 't', 't', 'e', 'd', '\n',
        'a', 'b', 'u', 't', 't', 'i', 'n', 'g', '\n',
        'a', 'b', 'u', 'z', 'z', '\n',
        'a', 'b', 'y', '\n',
        'a', 'b', 'y', 's', 'm', 'a', 'l', '\n',
        'a', 'b', 'y', 's', 'm', 'a', 'l', 'l', 'y', '\n',
        'a', 'b', 'y', 's', 's', '\n',
        'a', 'b', 'y', 's', 's', 'a', 'l', '\n',
        'a', 'b', 'y', 's', 's', 'e', 's', '\n',
        'a', 'c', 'a', 'c', 'i', 'a', '\n',
        'a', 'c', 'a', 'd', 'e', 'm', 'e', '\n',
        'a', 'c', 'a', 'd', 'e', 'm', 'i', 'a', '\n',
        'a', 'c', 'a', 'd', 'e', 'm', 'i', 'c', '\n',
        'a', 'c', 'a', 'd', 'e', 'm', 'i', 'c', 'a', 'l', '\n',
        'a', 'c', 'a', 'd', 'e', 'm', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 'c', 'a', 'd', 'e', 'm', 'i', 'c', 'i', 'a', 'n', '\n',
        'a', 'c', 'a', 'd', 'e', 'm', 'i', 'c', 'i', 'a', 'n', 's', '\n',
        'a', 'c', 'a', 'd', 'e', 'm', 'i', 'c', 's', '\n',
        'a', 'c', 'a', 'd', 'e', 'm', 'i', 'e', 's', '\n',
        'a', 'c', 'a', 'd', 'e', 'm', 'y', '\n',
        'a', 'c', 'a', 'n', 't', 'h', 'u', 's', '\n',
        'a', 'c', 'a', 'p', 'u', 'l', 'c', 'o', '\n',
        'a', 'c', 'c', 'e', 'd', 'e', '\n',
        'a', 'c', 'c', 'e', 'd', 'e', 'd', '\n',
        'a', 'c', 'c', 'e', 'd', 'i', 'n', 'g', '\n',
        'a', 'c', 'c', 'e', 'l', 'e', 'r', 'a', 't', 'e', '\n',
        'a', 'c', 'c', 'e', 'l', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'a', 'c', 'c', 'e', 'l', 'e', 'r', 'a', 't', 'e', 's', '\n',
        'a', 'c', 'c', 'e', 'l', 'e', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'c', 'c', 'e', 'l', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'c', 'c', 'e', 'l', 'e', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'c', 'c', 'e', 'l', 'e', 'r', 'a', 't', 'o', 'r', '\n',
        'a', 'c', 'c', 'e', 'l', 'e', 'r', 'a', 't', 'o', 'r', 's', '\n',
        'a', 'c', 'c', 'e', 'l', 'e', 'r', 'o', 'm', 'e', 't', 'e', 'r', '\n',
        'a', 'c', 'c', 'e', 'l', 'e', 'r', 'o', 'm', 'e', 't', 'e', 'r', 's', '\n',
        'a', 'c', 'c', 'e', 'n', 't', '\n',
        'a', 'c', 'c', 'e', 'n', 't', 'e', 'd', '\n',
        'a', 'c', 'c', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'a', 'c', 'c', 'e', 'n', 't', 's', '\n',
        'a', 'c', 'c', 'e', 'n', 't', 'u', 'a', 't', 'e', '\n',
        'a', 'c', 'c', 'e', 'n', 't', 'u', 'a', 't', 'e', 'd', '\n',
        'a', 'c', 'c', 'e', 'n', 't', 'u', 'a', 't', 'e', 's', '\n',
        'a', 'c', 'c', 'e', 'n', 't', 'u', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'c', 'c', 'e', 'n', 't', 'u', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'c', 'c', 'e', 'p', 't', '\n',
        'a', 'c', 'c', 'e', 'p', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'a', 'c', 'c', 'e', 'p', 't', 'a', 'b', 'l', 'e', '\n',
        'a', 'c', 'c', 'e', 'p', 't', 'a', 'b', 'l', 'y', '\n',
        'a', 'c', 'c', 'e', 'p', 't', 'a', 'n', 'c', 'e', '\n',
        'a', 'c', 'c', 'e', 'p', 't', 'a', 'n', 'c', 'e', 's', '\n',
        'a', 'c', 'c', 'e', 'p', 't', 'e', 'd', '\n',
        'a', 'c', 'c', 'e', 'p', 't', 'i', 'n', 'g', '\n',
        'a', 'c', 'c', 'e', 'p', 't', 'o', 'r', '\n',
        'a', 'c', 'c', 'e', 'p', 't', 'o', 'r', 's', '\n',
        'a', 'c', 'c', 'e', 'p', 't', 's', '\n',
        'a', 'c', 'c', 'e', 's', 's', '\n',
        'a', 'c', 'c', 'e', 's', 's', 'e', 'd', '\n',
        'a', 'c', 'c', 'e', 's', 's', 'e', 's', '\n',
        'a', 'c', 'c', 'e', 's', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'a', 'c', 'c', 'e', 's', 's', 'i', 'b', 'l', 'e', '\n',
        'a', 'c', 'c', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'a', 'c', 'c', 'e', 's', 's', 'i', 'o', 'n', '\n',
        'a', 'c', 'c', 'e', 's', 's', 'i', 'o', 'n', 's', '\n',
        'a', 'c', 'c', 'e', 's', 's', 'o', 'r', 'i', 'e', 's', '\n',
        'a', 'c', 'c', 'e', 's', 's', 'o', 'r', 'y', '\n',
        'a', 'c', 'c', 'i', 'd', 'e', 'n', 'c', 'e', '\n',
        'a', 'c', 'c', 'i', 'd', 'e', 'n', 't', '\n',
        'a', 'c', 'c', 'i', 'd', 'e', 'n', 't', 'a', 'l', '\n',
        'a', 'c', 'c', 'i', 'd', 'e', 'n', 't', 'a', 'l', 'l', 'y', '\n',
        'a', 'c', 'c', 'i', 'd', 'e', 'n', 't', 'p', 'r', 'o', 'n', 'e', '\n',
        'a', 'c', 'c', 'i', 'd', 'e', 'n', 't', 's', '\n',
        'a', 'c', 'c', 'l', 'a', 'i', 'm', '\n',
        'a', 'c', 'c', 'l', 'a', 'i', 'm', 'e', 'd', '\n',
        'a', 'c', 'c', 'l', 'a', 'i', 'm', 's', '\n',
        'a', 'c', 'c', 'l', 'a', 'm', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'c', 'c', 'l', 'a', 'm', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'c', 'c', 'l', 'i', 'm', 'a', 't', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'c', 'c', 'l', 'i', 'm', 'a', 't', 'i', 's', 'e', '\n',
        'a', 'c', 'c', 'l', 'i', 'm', 'a', 't', 'i', 's', 'e', 'd', '\n',
        'a', 'c', 'c', 'l', 'i', 'm', 'a', 't', 'i', 's', 'i', 'n', 'g', '\n',
        'a', 'c', 'c', 'o', 'l', 'a', 'd', 'e', '\n',
        'a', 'c', 'c', 'o', 'l', 'a', 'd', 'e', 's', '\n',
        'a', 'c', 'c', 'o', 'm', 'm', 'o', 'd', 'a', 't', 'e', '\n',
        'a', 'c', 'c', 'o', 'm', 'm', 'o', 'd', 'a', 't', 'e', 'd', '\n',
        'a', 'c', 'c', 'o', 'm', 'm', 'o', 'd', 'a', 't', 'e', 's', '\n',
        'a', 'c', 'c', 'o', 'm', 'm', 'o', 'd', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'c', 'c', 'o', 'm', 'm', 'o', 'd', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'c', 'c', 'o', 'm', 'm', 'o', 'd', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'c', 'c', 'o', 'm', 'p', 'a', 'n', 'i', 'e', 'd', '\n',
        'a', 'c', 'c', 'o', 'm', 'p', 'a', 'n', 'i', 'e', 's', '\n',
        'a', 'c', 'c', 'o', 'm', 'p', 'a', 'n', 'i', 'm', 'e', 'n', 't', '\n',
        'a', 'c', 'c', 'o', 'm', 'p', 'a', 'n', 'i', 'm', 'e', 'n', 't', 's', '\n',
        'a', 'c', 'c', 'o', 'm', 'p', 'a', 'n', 'i', 's', 't', '\n',
        'a', 'c', 'c', 'o', 'm', 'p', 'a', 'n', 'y', '\n',
        'a', 'c', 'c', 'o', 'm', 'p', 'a', 'n', 'y', 'i', 'n', 'g', '\n',
        'a', 'c', 'c', 'o', 'm', 'p', 'l', 'i', 'c', 'e', '\n',
        'a', 'c', 'c', 'o', 'm', 'p', 'l', 'i', 'c', 'e', 's', '\n',
        'a', 'c', 'c', 'o', 'm', 'p', 'l', 'i', 's', 'h', '\n',
        'a', 'c', 'c', 'o', 'm', 'p', 'l', 'i', 's', 'h', 'e', 'd', '\n',
        'a', 'c', 'c', 'o', 'm', 'p', 'l', 'i', 's', 'h', 'e', 's', '\n',
        'a', 'c', 'c', 'o', 'm', 'p', 'l', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'a', 'c', 'c', 'o', 'm', 'p', 'l', 'i', 's', 'h', 'm', 'e', 'n', 't', '\n',
        'a', 'c', 'c', 'o', 'm', 'p', 'l', 'i', 's', 'h', 'm', 'e', 'n', 't', 's', '\n',
        'a', 'c', 'c', 'o', 'r', 'd', '\n',
        'a', 'c', 'c', 'o', 'r', 'd', 'a', 'n', 'c', 'e', '\n',
        'a', 'c', 'c', 'o', 'r', 'd', 'e', 'd', '\n',
        'a', 'c', 'c', 'o', 'r', 'd', 'i', 'n', 'g', '\n',
        'a', 'c', 'c', 'o', 'r', 'd', 'i', 'n', 'g', 'l', 'y', '\n',
        'a', 'c', 'c', 'o', 'r', 'd', 'i', 'o', 'n', '\n',
        'a', 'c', 'c', 'o', 'r', 'd', 'i', 'o', 'n', 'i', 's', 't', '\n',
        'a', 'c', 'c', 'o', 'r', 'd', 'i', 'o', 'n', 's', '\n',
        'a', 'c', 'c', 'o', 'r', 'd', 's', '\n',
        'a', 'c', 'c', 'o', 's', 't', '\n',
        'a', 'c', 'c', 'o', 's', 't', 'e', 'd', '\n',
        'a', 'c', 'c', 'o', 's', 't', 'i', 'n', 'g', '\n',
        'a', 'c', 'c', 'o', 's', 't', 's', '\n',
        'a', 'c', 'c', 'o', 'u', 'n', 't', '\n',
        'a', 'c', 'c', 'o', 'u', 'n', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'a', 'c', 'c', 'o', 'u', 'n', 't', 'a', 'b', 'l', 'e', '\n',
        'a', 'c', 'c', 'o', 'u', 'n', 't', 'a', 'n', 'c', 'y', '\n',
        'a', 'c', 'c', 'o', 'u', 'n', 't', 'a', 'n', 't', '\n',
        'a', 'c', 'c', 'o', 'u', 'n', 't', 'a', 'n', 't', 's', '\n',
        'a', 'c', 'c', 'o', 'u', 'n', 't', 'e', 'd', '\n',
        'a', 'c', 'c', 'o', 'u', 'n', 't', 'i', 'n', 'g', '\n',
        'a', 'c', 'c', 'o', 'u', 'n', 't', 's', '\n',
        'a', 'c', 'c', 'r', 'a', '\n',
        'a', 'c', 'c', 'r', 'e', 'd', 'i', 't', '\n',
        'a', 'c', 'c', 'r', 'e', 'd', 'i', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'c', 'c', 'r', 'e', 'd', 'i', 't', 'e', 'd', '\n',
        'a', 'c', 'c', 'r', 'e', 'd', 'i', 't', 'i', 'n', 'g', '\n',
        'a', 'c', 'c', 'r', 'e', 'd', 'i', 't', 's', '\n',
        'a', 'c', 'c', 'r', 'e', 't', 'e', 'd', '\n',
        'a', 'c', 'c', 'r', 'e', 't', 'i', 'o', 'n', '\n',
        'a', 'c', 'c', 'r', 'e', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'c', 'c', 'r', 'u', 'a', 'l', '\n',
        'a', 'c', 'c', 'r', 'u', 'a', 'l', 's', '\n',
        'a', 'c', 'c', 'r', 'u', 'e', '\n',
        'a', 'c', 'c', 'r', 'u', 'e', 'd', '\n',
        'a', 'c', 'c', 'r', 'u', 'e', 's', '\n',
        'a', 'c', 'c', 'r', 'u', 'i', 'n', 'g', '\n',
        'a', 'c', 'c', 'u', 'm', 'u', 'l', 'a', 't', 'e', '\n',
        'a', 'c', 'c', 'u', 'm', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'a', 'c', 'c', 'u', 'm', 'u', 'l', 'a', 't', 'e', 's', '\n',
        'a', 'c', 'c', 'u', 'm', 'u', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'c', 'c', 'u', 'm', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'c', 'c', 'u', 'm', 'u', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'c', 'c', 'u', 'm', 'u', 'l', 'a', 't', 'i', 'v', 'e', '\n',
        'a', 'c', 'c', 'u', 'm', 'u', 'l', 'a', 't', 'o', 'r', '\n',
        'a', 'c', 'c', 'u', 'm', 'u', 'l', 'a', 't', 'o', 'r', 's', '\n',
        'a', 'c', 'c', 'u', 'r', 'a', 'c', 'i', 'e', 's', '\n',
        'a', 'c', 'c', 'u', 'r', 'a', 'c', 'y', '\n',
        'a', 'c', 'c', 'u', 'r', 'a', 't', 'e', '\n',
        'a', 'c', 'c', 'u', 'r', 'a', 't', 'e', 'l', 'y', '\n',
        'a', 'c', 'c', 'u', 'r', 's', 'e', 'd', '\n',
        'a', 'c', 'c', 'u', 's', 'a', 'l', '\n',
        'a', 'c', 'c', 'u', 's', 'a', 'l', 's', '\n',
        'a', 'c', 'c', 'u', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'c', 'c', 'u', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'c', 'c', 'u', 's', 'a', 't', 'i', 'v', 'e', '\n',
        'a', 'c', 'c', 'u', 's', 'a', 't', 'o', 'r', 'y', '\n',
        'a', 'c', 'c', 'u', 's', 'e', '\n',
        'a', 'c', 'c', 'u', 's', 'e', 'd', '\n',
        'a', 'c', 'c', 'u', 's', 'e', 'r', '\n',
        'a', 'c', 'c', 'u', 's', 'e', 'r', 's', '\n',
        'a', 'c', 'c', 'u', 's', 'e', 's', '\n',
        'a', 'c', 'c', 'u', 's', 'i', 'n', 'g', '\n',
        'a', 'c', 'c', 'u', 's', 'i', 'n', 'g', 'l', 'y', '\n',
        'a', 'c', 'c', 'u', 's', 't', 'o', 'm', '\n',
        'a', 'c', 'c', 'u', 's', 't', 'o', 'm', 'e', 'd', '\n',
        'a', 'c', 'c', 'u', 's', 't', 'o', 'm', 'i', 'n', 'g', '\n',
        'a', 'c', 'e', '\n',
        'a', 'c', 'e', 'd', '\n',
        'a', 'c', 'e', 'n', 't', 'r', 'i', 'c', '\n',
        'a', 'c', 'e', 'r', 'b', 'i', 'c', '\n',
        'a', 'c', 'e', 'r', 'b', 'i', 't', 'y', '\n',
        'a', 'c', 'e', 'r', 's', '\n',
        'a', 'c', 'e', 's', '\n',
        'a', 'c', 'e', 't', 'a', 'l', '\n',
        'a', 'c', 'e', 't', 'a', 't', 'e', '\n',
        'a', 'c', 'e', 't', 'a', 't', 'e', 's', '\n',
        'a', 'c', 'e', 't', 'i', 'c', '\n',
        'a', 'c', 'e', 't', 'o', 'n', 'e', '\n',
        'a', 'c', 'e', 't', 'y', 'l', 'e', 'n', 'e', '\n',
        'a', 'c', 'h', 'e', '\n',
        'a', 'c', 'h', 'e', 'd', '\n',
        'a', 'c', 'h', 'e', 's', '\n',
        'a', 'c', 'h', 'i', 'e', 'v', 'a', 'b', 'l', 'e', '\n',
        'a', 'c', 'h', 'i', 'e', 'v', 'e', '\n',
        'a', 'c', 'h', 'i', 'e', 'v', 'e', 'd', '\n',
        'a', 'c', 'h', 'i', 'e', 'v', 'e', 'm', 'e', 'n', 't', '\n',
        'a', 'c', 'h', 'i', 'e', 'v', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'a', 'c', 'h', 'i', 'e', 'v', 'e', 'r', '\n',
        'a', 'c', 'h', 'i', 'e', 'v', 'e', 'r', 's', '\n',
        'a', 'c', 'h', 'i', 'e', 'v', 'e', 's', '\n',
        'a', 'c', 'h', 'i', 'e', 'v', 'i', 'n', 'g', '\n',
        'a', 'c', 'h', 'i', 'n', 'g', '\n',
        'a', 'c', 'h', 'i', 'n', 'g', 'l', 'y', '\n',
        'a', 'c', 'h', 'i', 'n', 'g', 's', '\n',
        'a', 'c', 'h', 'r', 'o', 'm', 'a', 't', 'i', 'c', '\n',
        'a', 'c', 'h', 'y', '\n',
        'a', 'c', 'i', 'd', '\n',
        'a', 'c', 'i', 'd', 'i', 'c', '\n',
        'a', 'c', 'i', 'd', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'c', 'i', 'd', 'i', 'f', 'i', 'e', 'd', '\n',
        'a', 'c', 'i', 'd', 'i', 'f', 'y', '\n',
        'a', 'c', 'i', 'd', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'a', 'c', 'i', 'd', 'i', 't', 'y', '\n',
        'a', 'c', 'i', 'd', 'l', 'y', '\n',
        'a', 'c', 'i', 'd', 'o', 'p', 'h', 'i', 'l', 'e', 's', '\n',
        'a', 'c', 'i', 'd', 'r', 'a', 'i', 'n', '\n',
        'a', 'c', 'i', 'd', 's', '\n',
        'a', 'c', 'k', 'n', 'o', 'w', 'l', 'e', 'd', 'g', 'e', '\n',
        'a', 'c', 'k', 'n', 'o', 'w', 'l', 'e', 'd', 'g', 'e', 'd', '\n',
        'a', 'c', 'k', 'n', 'o', 'w', 'l', 'e', 'd', 'g', 'e', 'm', 'e', 'n', 't', '\n',
        'a', 'c', 'k', 'n', 'o', 'w', 'l', 'e', 'd', 'g', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'a', 'c', 'k', 'n', 'o', 'w', 'l', 'e', 'd', 'g', 'e', 's', '\n',
        'a', 'c', 'k', 'n', 'o', 'w', 'l', 'e', 'd', 'g', 'i', 'n', 'g', '\n',
        'a', 'c', 'k', 'n', 'o', 'w', 'l', 'e', 'd', 'g', 'm', 'e', 'n', 't', '\n',
        'a', 'c', 'k', 'n', 'o', 'w', 'l', 'e', 'd', 'g', 'm', 'e', 'n', 't', 's', '\n',
        'a', 'c', 'm', 'e', '\n',
        'a', 'c', 'n', 'e', '\n',
        'a', 'c', 'o', 'l', 'y', 't', 'e', '\n',
        'a', 'c', 'o', 'l', 'y', 't', 'e', 's', '\n',
        'a', 'c', 'o', 'n', 'i', 't', 'e', '\n',
        'a', 'c', 'o', 'r', 'n', '\n',
        'a', 'c', 'o', 'r', 'n', 's', '\n',
        'a', 'c', 'o', 'u', 's', 't', 'i', 'c', '\n',
        'a', 'c', 'o', 'u', 's', 't', 'i', 'c', 'a', 'l', '\n',
        'a', 'c', 'o', 'u', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 'c', 'o', 'u', 's', 't', 'i', 'c', 's', '\n',
        'a', 'c', 'q', 'u', 'a', 'i', 'n', 't', '\n',
        'a', 'c', 'q', 'u', 'a', 'i', 'n', 't', 'a', 'n', 'c', 'e', '\n',
        'a', 'c', 'q', 'u', 'a', 'i', 'n', 't', 'a', 'n', 'c', 'e', 's', '\n',
        'a', 'c', 'q', 'u', 'a', 'i', 'n', 't', 'e', 'd', '\n',
        'a', 'c', 'q', 'u', 'a', 'i', 'n', 't', 'i', 'n', 'g', '\n',
        'a', 'c', 'q', 'u', 'a', 'i', 'n', 't', 's', '\n',
        'a', 'c', 'q', 'u', 'i', 'e', 's', 'c', 'e', '\n',
        'a', 'c', 'q', 'u', 'i', 'e', 's', 'c', 'e', 'd', '\n',
        'a', 'c', 'q', 'u', 'i', 'e', 's', 'c', 'e', 'n', 'c', 'e', '\n',
        'a', 'c', 'q', 'u', 'i', 'e', 's', 'c', 'e', 'n', 't', '\n',
        'a', 'c', 'q', 'u', 'i', 'e', 's', 'c', 'i', 'n', 'g', '\n',
        'a', 'c', 'q', 'u', 'i', 'r', 'e', '\n',
        'a', 'c', 'q', 'u', 'i', 'r', 'e', 'd', '\n',
        'a', 'c', 'q', 'u', 'i', 'r', 'e', 'r', '\n',
        'a', 'c', 'q', 'u', 'i', 'r', 'e', 'r', 's', '\n',
        'a', 'c', 'q', 'u', 'i', 'r', 'e', 's', '\n',
        'a', 'c', 'q', 'u', 'i', 'r', 'i', 'n', 'g', '\n',
        'a', 'c', 'q', 'u', 'i', 's', 'i', 't', 'i', 'o', 'n', '\n',
        'a', 'c', 'q', 'u', 'i', 's', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'c', 'q', 'u', 'i', 's', 'i', 't', 'i', 'v', 'e', '\n',
        'a', 'c', 'q', 'u', 'i', 's', 'i', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'a', 'c', 'q', 'u', 'i', 't', '\n',
        'a', 'c', 'q', 'u', 'i', 't', 'e', 'd', '\n',
        'a', 'c', 'q', 'u', 'i', 't', 'e', 's', '\n',
        'a', 'c', 'q', 'u', 'i', 't', 's', '\n',
        'a', 'c', 'q', 'u', 'i', 't', 't', 'a', 'l', '\n',
        'a', 'c', 'q', 'u', 'i', 't', 't', 'a', 'l', 's', '\n',
        'a', 'c', 'q', 'u', 'i', 't', 't', 'a', 'n', 'c', 'e', '\n',
        'a', 'c', 'q', 'u', 'i', 't', 't', 'e', 'd', '\n',
        'a', 'c', 'q', 'u', 'i', 't', 't', 'i', 'n', 'g', '\n',
        'a', 'c', 'r', 'e', '\n',
        'a', 'c', 'r', 'e', 'a', 'g', 'e', '\n',
        'a', 'c', 'r', 'e', 's', '\n',
        'a', 'c', 'r', 'i', 'd', '\n',
        'a', 'c', 'r', 'i', 'm', 'o', 'n', 'i', 'o', 'u', 's', '\n',
        'a', 'c', 'r', 'i', 'm', 'o', 'n', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'a', 'c', 'r', 'i', 'm', 'o', 'n', 'y', '\n',
        'a', 'c', 'r', 'o', 'b', 'a', 't', '\n',
        'a', 'c', 'r', 'o', 'b', 'a', 't', 'i', 'c', '\n',
        'a', 'c', 'r', 'o', 'b', 'a', 't', 'i', 'c', 's', '\n',
        'a', 'c', 'r', 'o', 'b', 'a', 't', 's', '\n',
        'a', 'c', 'r', 'o', 'n', 'y', 'm', '\n',
        'a', 'c', 'r', 'o', 'n', 'y', 'm', 's', '\n',
        'a', 'c', 'r', 'o', 's', 's', '\n',
        'a', 'c', 'r', 'o', 's', 't', 'i', 'c', '\n',
        'a', 'c', 'r', 'o', 's', 't', 'i', 'c', 's', '\n',
        'a', 'c', 'r', 'y', 'l', 'i', 'c', '\n',
        'a', 'c', 'r', 'y', 'l', 'i', 'c', 's', '\n',
        'a', 'c', 't', '\n',
        'a', 'c', 't', 'e', 'd', '\n',
        'a', 'c', 't', 'i', 'n', 'g', '\n',
        'a', 'c', 't', 'i', 'n', 'g', 's', '\n',
        'a', 'c', 't', 'i', 'n', 'i', 'd', 'e', 's', '\n',
        'a', 'c', 't', 'i', 'o', 'n', '\n',
        'a', 'c', 't', 'i', 'o', 'n', 'a', 'b', 'l', 'e', '\n',
        'a', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'c', 't', 'i', 'v', 'a', 't', 'e', '\n',
        'a', 'c', 't', 'i', 'v', 'a', 't', 'e', 'd', '\n',
        'a', 'c', 't', 'i', 'v', 'a', 't', 'e', 's', '\n',
        'a', 'c', 't', 'i', 'v', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'c', 't', 'i', 'v', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'c', 't', 'i', 'v', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'c', 't', 'i', 'v', 'a', 't', 'o', 'r', '\n',
        'a', 'c', 't', 'i', 'v', 'a', 't', 'o', 'r', 's', '\n',
        'a', 'c', 't', 'i', 'v', 'e', '\n',
        'a', 'c', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'a', 'c', 't', 'i', 'v', 'e', 's', '\n',
        'a', 'c', 't', 'i', 'v', 'i', 's', 'm', '\n',
        'a', 'c', 't', 'i', 'v', 'i', 's', 't', '\n',
        'a', 'c', 't', 'i', 'v', 'i', 's', 't', 's', '\n',
        'a', 'c', 't', 'i', 'v', 'i', 't', 'i', 'e', 's', '\n',
        'a', 'c', 't', 'i', 'v', 'i', 't', 'y', '\n',
        'a', 'c', 't', 'o', 'r', '\n',
        'a', 'c', 't', 'o', 'r', 's', '\n',
        'a', 'c', 't', 'r', 'e', 's', 's', '\n',
        'a', 'c', 't', 'r', 'e', 's', 's', 'e', 's', '\n',
        'a', 'c', 't', 's', '\n',
        'a', 'c', 't', 'u', 'a', 'l', '\n',
        'a', 'c', 't', 'u', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'c', 't', 'u', 'a', 'l', 'i', 's', 'e', '\n',
        'a', 'c', 't', 'u', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'a', 'c', 't', 'u', 'a', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'a', 'c', 't', 'u', 'a', 'l', 'i', 't', 'y', '\n',
        'a', 'c', 't', 'u', 'a', 'l', 'l', 'y', '\n',
        'a', 'c', 't', 'u', 'a', 'r', 'i', 'a', 'l', '\n',
        'a', 'c', 't', 'u', 'a', 'r', 'i', 'e', 's', '\n',
        'a', 'c', 't', 'u', 'a', 'r', 'y', '\n',
        'a', 'c', 't', 'u', 'a', 't', 'e', '\n',
        'a', 'c', 't', 'u', 'a', 't', 'e', 'd', '\n',
        'a', 'c', 't', 'u', 'a', 't', 'e', 's', '\n',
        'a', 'c', 't', 'u', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'c', 't', 'u', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'c', 't', 'u', 'a', 't', 'o', 'r', '\n',
        'a', 'c', 't', 'u', 'a', 't', 'o', 'r', 's', '\n',
        'a', 'c', 'u', 'i', 't', 'y', '\n',
        'a', 'c', 'u', 'm', 'e', 'n', '\n',
        'a', 'c', 'u', 'p', 'u', 'n', 'c', 't', 'u', 'r', 'e', '\n',
        'a', 'c', 'u', 'p', 'u', 'n', 'c', 't', 'u', 'r', 'i', 's', 't', '\n',
        'a', 'c', 'u', 'p', 'u', 'n', 'c', 't', 'u', 'r', 'i', 's', 't', 's', '\n',
        'a', 'c', 'u', 't', 'e', '\n',
        'a', 'c', 'u', 't', 'e', 'l', 'y', '\n',
        'a', 'c', 'u', 't', 'e', 'n', 'e', 's', 's', '\n',
        'a', 'c', 'u', 't', 'e', 'r', '\n',
        'a', 'c', 'u', 't', 'e', 's', 't', '\n',
        'a', 'c', 'y', 'c', 'l', 'i', 'c', '\n',
        'a', 'd', 'a', 'g', 'e', '\n',
        'a', 'd', 'a', 'g', 'e', 's', '\n',
        'a', 'd', 'a', 'g', 'i', 'o', '\n',
        'a', 'd', 'a', 'm', '\n',
        'a', 'd', 'a', 'm', 'a', 'n', 't', '\n',
        'a', 'd', 'a', 'm', 'a', 'n', 't', 'l', 'y', '\n',
        'a', 'd', 'a', 'p', 't', '\n',
        'a', 'd', 'a', 'p', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'a', 'd', 'a', 'p', 't', 'a', 'b', 'l', 'e', '\n',
        'a', 'd', 'a', 'p', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'd', 'a', 'p', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'd', 'a', 'p', 't', 'e', 'd', '\n',
        'a', 'd', 'a', 'p', 't', 'e', 'r', '\n',
        'a', 'd', 'a', 'p', 't', 'e', 'r', 's', '\n',
        'a', 'd', 'a', 'p', 't', 'i', 'n', 'g', '\n',
        'a', 'd', 'a', 'p', 't', 'i', 'v', 'e', '\n',
        'a', 'd', 'a', 'p', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'a', 'd', 'a', 'p', 't', 'i', 'v', 'i', 't', 'y', '\n',
        'a', 'd', 'a', 'p', 't', 'o', 'r', '\n',
        'a', 'd', 'a', 'p', 't', 'o', 'r', 's', '\n',
        'a', 'd', 'a', 'p', 't', 's', '\n',
        'a', 'd', 'd', '\n',
        'a', 'd', 'd', 'e', 'd', '\n',
        'a', 'd', 'd', 'e', 'n', 'd', 'a', '\n',
        'a', 'd', 'd', 'e', 'n', 'd', 'u', 'm', '\n',
        'a', 'd', 'd', 'e', 'r', '\n',
        'a', 'd', 'd', 'e', 'r', 's', '\n',
        'a', 'd', 'd', 'i', 'c', 't', '\n',
        'a', 'd', 'd', 'i', 'c', 't', 'e', 'd', '\n',
        'a', 'd', 'd', 'i', 'c', 't', 'i', 'o', 'n', '\n',
        'a', 'd', 'd', 'i', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'd', 'd', 'i', 'c', 't', 'i', 'v', 'e', '\n',
        'a', 'd', 'd', 'i', 'c', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'a', 'd', 'd', 'i', 'c', 't', 's', '\n',
        'a', 'd', 'd', 'i', 'n', 'g', '\n',
        'a', 'd', 'd', 'i', 't', 'i', 'o', 'n', '\n',
        'a', 'd', 'd', 'i', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'a', 'd', 'd', 'i', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'a', 'd', 'd', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'd', 'd', 'i', 't', 'i', 'v', 'e', '\n',
        'a', 'd', 'd', 'i', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'a', 'd', 'd', 'i', 't', 'i', 'v', 'e', 's', '\n',
        'a', 'd', 'd', 'l', 'e', '\n',
        'a', 'd', 'd', 'l', 'e', 'd', '\n',
        'a', 'd', 'd', 'l', 'e', 's', '\n',
        'a', 'd', 'd', 'l', 'i', 'n', 'g', '\n',
        'a', 'd', 'd', 'r', 'e', 's', 's', '\n',
        'a', 'd', 'd', 'r', 'e', 's', 's', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'a', 'd', 'd', 'r', 'e', 's', 's', 'a', 'b', 'l', 'e', '\n',
        'a', 'd', 'd', 'r', 'e', 's', 's', 'e', 'd', '\n',
        'a', 'd', 'd', 'r', 'e', 's', 's', 'e', 'e', '\n',
        'a', 'd', 'd', 'r', 'e', 's', 's', 'e', 'e', 's', '\n',
        'a', 'd', 'd', 'r', 'e', 's', 's', 'e', 's', '\n',
        'a', 'd', 'd', 'r', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'a', 'd', 'd', 's', '\n',
        'a', 'd', 'd', 'u', 'c', 'e', '\n',
        'a', 'd', 'd', 'u', 'c', 'e', 'd', '\n',
        'a', 'd', 'd', 'u', 'c', 'e', 's', '\n',
        'a', 'd', 'd', 'u', 'c', 'i', 'n', 'g', '\n',
        'a', 'd', 'e', 'l', 'a', 'i', 'd', 'e', '\n',
        'a', 'd', 'e', 'n', '\n',
        'a', 'd', 'e', 'n', 'i', 'n', 'e', '\n',
        'a', 'd', 'e', 'n', 'o', 'i', 'd', '\n',
        'a', 'd', 'e', 'n', 'o', 'i', 'd', 's', '\n',
        'a', 'd', 'e', 'n', 'o', 'm', 'a', '\n',
        'a', 'd', 'e', 'n', 'o', 'm', 'a', 's', '\n',
        'a', 'd', 'e', 'p', 't', '\n',
        'a', 'd', 'e', 'p', 't', 's', '\n',
        'a', 'd', 'e', 'q', 'u', 'a', 'c', 'y', '\n',
        'a', 'd', 'e', 'q', 'u', 'a', 't', 'e', '\n',
        'a', 'd', 'e', 'q', 'u', 'a', 't', 'e', 'l', 'y', '\n',
        'a', 'd', 'h', 'e', 'r', 'e', '\n',
        'a', 'd', 'h', 'e', 'r', 'e', 'd', '\n',
        'a', 'd', 'h', 'e', 'r', 'e', 'n', 'c', 'e', '\n',
        'a', 'd', 'h', 'e', 'r', 'e', 'n', 't', '\n',
        'a', 'd', 'h', 'e', 'r', 'e', 'n', 't', 's', '\n',
        'a', 'd', 'h', 'e', 'r', 'e', 'r', '\n',
        'a', 'd', 'h', 'e', 'r', 'e', 'r', 's', '\n',
        'a', 'd', 'h', 'e', 'r', 'e', 's', '\n',
        'a', 'd', 'h', 'e', 'r', 'i', 'n', 'g', '\n',
        'a', 'd', 'h', 'e', 's', 'i', 'o', 'n', '\n',
        'a', 'd', 'h', 'e', 's', 'i', 'o', 'n', 's', '\n',
        'a', 'd', 'h', 'e', 's', 'i', 'v', 'e', '\n',
        'a', 'd', 'h', 'e', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'a', 'd', 'h', 'e', 's', 'i', 'v', 'e', 's', '\n',
        'a', 'd', 'h', 'o', 'c', '\n',
        'a', 'd', 'i', 'a', 'b', 'a', 't', 'i', 'c', '\n',
        'a', 'd', 'i', 'a', 'b', 'a', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 'd', 'i', 'e', 'u', '\n',
        'a', 'd', 'i', 'e', 'u', 's', '\n',
        'a', 'd', 'i', 'e', 'u', 'x', '\n',
        'a', 'd', 'i', 'o', 's', '\n',
        'a', 'd', 'i', 'p', 'o', 's', 'e', '\n',
        'a', 'd', 'i', 't', '\n',
        'a', 'd', 'j', 'a', 'c', 'e', 'n', 'c', 'y', '\n',
        'a', 'd', 'j', 'a', 'c', 'e', 'n', 't', '\n',
        'a', 'd', 'j', 'a', 'c', 'e', 'n', 't', 'l', 'y', '\n',
        'a', 'd', 'j', 'e', 'c', 't', 'i', 'v', 'a', 'l', '\n',
        'a', 'd', 'j', 'e', 'c', 't', 'i', 'v', 'e', '\n',
        'a', 'd', 'j', 'e', 'c', 't', 'i', 'v', 'e', 's', '\n',
        'a', 'd', 'j', 'o', 'i', 'n', '\n',
        'a', 'd', 'j', 'o', 'i', 'n', 'e', 'd', '\n',
        'a', 'd', 'j', 'o', 'i', 'n', 'i', 'n', 'g', '\n',
        'a', 'd', 'j', 'o', 'i', 'n', 's', '\n',
        'a', 'd', 'j', 'o', 'u', 'r', 'n', '\n',
        'a', 'd', 'j', 'o', 'u', 'r', 'n', 'e', 'd', '\n',
        'a', 'd', 'j', 'o', 'u', 'r', 'n', 'i', 'n', 'g', '\n',
        'a', 'd', 'j', 'o', 'u', 'r', 'n', 'm', 'e', 'n', 't', '\n',
        'a', 'd', 'j', 'o', 'u', 'r', 'n', 's', '\n',
        'a', 'd', 'j', 'u', 'd', 'g', 'e', '\n',
        'a', 'd', 'j', 'u', 'd', 'g', 'e', 'd', '\n',
        'a', 'd', 'j', 'u', 'd', 'g', 'e', 's', '\n',
        'a', 'd', 'j', 'u', 'd', 'i', 'c', 'a', 't', 'e', '\n',
        'a', 'd', 'j', 'u', 'd', 'i', 'c', 'a', 't', 'e', 'd', '\n',
        'a', 'd', 'j', 'u', 'd', 'i', 'c', 'a', 't', 'e', 's', '\n',
        'a', 'd', 'j', 'u', 'd', 'i', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'd', 'j', 'u', 'd', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'd', 'j', 'u', 'd', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'd', 'j', 'u', 'd', 'i', 'c', 'a', 't', 'o', 'r', '\n',
        'a', 'd', 'j', 'u', 'd', 'i', 'c', 'a', 't', 'o', 'r', 's', '\n',
        'a', 'd', 'j', 'u', 'n', 'c', 't', '\n',
        'a', 'd', 'j', 'u', 'n', 'c', 't', 's', '\n',
        'a', 'd', 'j', 'u', 'r', 'e', '\n',
        'a', 'd', 'j', 'u', 's', 't', '\n',
        'a', 'd', 'j', 'u', 's', 't', 'a', 'b', 'l', 'e', '\n',
        'a', 'd', 'j', 'u', 's', 't', 'e', 'd', '\n',
        'a', 'd', 'j', 'u', 's', 't', 'e', 'r', '\n',
        'a', 'd', 'j', 'u', 's', 't', 'i', 'n', 'g', '\n',
        'a', 'd', 'j', 'u', 's', 't', 'm', 'e', 'n', 't', '\n',
        'a', 'd', 'j', 'u', 's', 't', 'm', 'e', 'n', 't', 's', '\n',
        'a', 'd', 'j', 'u', 's', 't', 's', '\n',
        'a', 'd', 'j', 'u', 't', 'a', 'n', 't', '\n',
        'a', 'd', 'l', 'i', 'b', '\n',
        'a', 'd', 'l', 'i', 'b', 's', '\n',
        'a', 'd', 'm', 'a', 'n', '\n',
        'a', 'd', 'm', 'e', 'n', '\n',
        'a', 'd', 'm', 'i', 'n', '\n',
        'a', 'd', 'm', 'i', 'n', 'i', 's', 't', 'e', 'r', '\n',
        'a', 'd', 'm', 'i', 'n', 'i', 's', 't', 'e', 'r', 'e', 'd', '\n',
        'a', 'd', 'm', 'i', 'n', 'i', 's', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'a', 'd', 'm', 'i', 'n', 'i', 's', 't', 'e', 'r', 's', '\n',
        'a', 'd', 'm', 'i', 'n', 'i', 's', 't', 'r', 'a', 't', 'e', '\n',
        'a', 'd', 'm', 'i', 'n', 'i', 's', 't', 'r', 'a', 't', 'e', 'd', '\n',
        'a', 'd', 'm', 'i', 'n', 'i', 's', 't', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'd', 'm', 'i', 'n', 'i', 's', 't', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'd', 'm', 'i', 'n', 'i', 's', 't', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'd', 'm', 'i', 'n', 'i', 's', 't', 'r', 'a', 't', 'i', 'v', 'e', '\n',
        'a', 'd', 'm', 'i', 'n', 'i', 's', 't', 'r', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'a', 'd', 'm', 'i', 'n', 'i', 's', 't', 'r', 'a', 't', 'o', 'r', '\n',
        'a', 'd', 'm', 'i', 'n', 'i', 's', 't', 'r', 'a', 't', 'o', 'r', 's', '\n',
        'a', 'd', 'm', 'i', 'r', 'a', 'b', 'l', 'e', '\n',
        'a', 'd', 'm', 'i', 'r', 'a', 'b', 'l', 'y', '\n',
        'a', 'd', 'm', 'i', 'r', 'a', 'l', '\n',
        'a', 'd', 'm', 'i', 'r', 'a', 'l', 's', '\n',
        'a', 'd', 'm', 'i', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'd', 'm', 'i', 'r', 'e', '\n',
        'a', 'd', 'm', 'i', 'r', 'e', 'd', '\n',
        'a', 'd', 'm', 'i', 'r', 'e', 'r', '\n',
        'a', 'd', 'm', 'i', 'r', 'e', 'r', 's', '\n',
        'a', 'd', 'm', 'i', 'r', 'e', 's', '\n',
        'a', 'd', 'm', 'i', 'r', 'i', 'n', 'g', '\n',
        'a', 'd', 'm', 'i', 'r', 'i', 'n', 'g', 'l', 'y', '\n',
        'a', 'd', 'm', 'i', 's', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'a', 'd', 'm', 'i', 's', 's', 'i', 'b', 'l', 'e', '\n',
        'a', 'd', 'm', 'i', 's', 's', 'i', 'o', 'n', '\n',
        'a', 'd', 'm', 'i', 's', 's', 'i', 'o', 'n', 's', '\n',
        'a', 'd', 'm', 'i', 't', '\n',
        'a', 'd', 'm', 'i', 't', 's', '\n',
        'a', 'd', 'm', 'i', 't', 't', 'a', 'n', 'c', 'e', '\n',
        'a', 'd', 'm', 'i', 't', 't', 'a', 'n', 'c', 'e', 's', '\n',
        'a', 'd', 'm', 'i', 't', 't', 'e', 'd', '\n',
        'a', 'd', 'm', 'i', 't', 't', 'e', 'd', 'l', 'y', '\n',
        'a', 'd', 'm', 'i', 't', 't', 'i', 'n', 'g', '\n',
        'a', 'd', 'm', 'i', 'x', '\n',
        'a', 'd', 'm', 'i', 'x', 't', 'u', 'r', 'e', '\n',
        'a', 'd', 'm', 'o', 'n', 'i', 's', 'h', '\n',
        'a', 'd', 'm', 'o', 'n', 'i', 's', 'h', 'e', 'd', '\n',
        'a', 'd', 'm', 'o', 'n', 'i', 's', 'h', 'e', 's', '\n',
        'a', 'd', 'm', 'o', 'n', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'a', 'd', 'm', 'o', 'n', 'i', 's', 'h', 'm', 'e', 'n', 't', '\n',
        'a', 'd', 'm', 'o', 'n', 'i', 't', 'i', 'o', 'n', '\n',
        'a', 'd', 'm', 'o', 'n', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'd', 'm', 'o', 'n', 'i', 't', 'o', 'r', 'y', '\n',
        'a', 'd', 'o', '\n',
        'a', 'd', 'o', 'b', 'e', '\n',
        'a', 'd', 'o', 'l', 'e', 's', 'c', 'e', 'n', 'c', 'e', '\n',
        'a', 'd', 'o', 'l', 'e', 's', 'c', 'e', 'n', 't', '\n',
        'a', 'd', 'o', 'l', 'e', 's', 'c', 'e', 'n', 't', 's', '\n',
        'a', 'd', 'o', 'n', 'i', 's', '\n',
        'a', 'd', 'o', 'p', 't', '\n',
        'a', 'd', 'o', 'p', 't', 'e', 'd', '\n',
        'a', 'd', 'o', 'p', 't', 'e', 'r', '\n',
        'a', 'd', 'o', 'p', 't', 'i', 'n', 'g', '\n',
        'a', 'd', 'o', 'p', 't', 'i', 'o', 'n', '\n',
        'a', 'd', 'o', 'p', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'd', 'o', 'p', 't', 'i', 'v', 'e', '\n',
        'a', 'd', 'o', 'p', 't', 's', '\n',
        'a', 'd', 'o', 'r', 'a', 'b', 'l', 'e', '\n',
        'a', 'd', 'o', 'r', 'a', 'b', 'l', 'y', '\n',
        'a', 'd', 'o', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'd', 'o', 'r', 'e', '\n',
        'a', 'd', 'o', 'r', 'e', 'd', '\n',
        'a', 'd', 'o', 'r', 'e', 'r', '\n',
        'a', 'd', 'o', 'r', 'e', 'r', 's', '\n',
        'a', 'd', 'o', 'r', 'e', 's', '\n',
        'a', 'd', 'o', 'r', 'i', 'n', 'g', '\n',
        'a', 'd', 'o', 'r', 'i', 'n', 'g', 'l', 'y', '\n',
        'a', 'd', 'o', 'r', 'n', '\n',
        'a', 'd', 'o', 'r', 'n', 'e', 'd', '\n',
        'a', 'd', 'o', 'r', 'n', 'i', 'n', 'g', '\n',
        'a', 'd', 'o', 'r', 'n', 'm', 'e', 'n', 't', '\n',
        'a', 'd', 'o', 'r', 'n', 'm', 'e', 'n', 't', 's', '\n',
        'a', 'd', 'o', 'r', 'n', 's', '\n',
        'a', 'd', 'r', 'e', 'n', 'a', 'l', '\n',
        'a', 'd', 'r', 'e', 'n', 'a', 'l', 'i', 'n', '\n',
        'a', 'd', 'r', 'e', 'n', 'a', 'l', 'i', 'n', 'e', '\n',
        'a', 'd', 'r', 'i', 'f', 't', '\n',
        'a', 'd', 'r', 'o', 'i', 't', '\n',
        'a', 'd', 'r', 'o', 'i', 't', 'l', 'y', '\n',
        'a', 'd', 'r', 'o', 'i', 't', 'n', 'e', 's', 's', '\n',
        'a', 'd', 's', 'o', 'r', 'b', '\n',
        'a', 'd', 's', 'o', 'r', 'b', 'e', 'd', '\n',
        'a', 'd', 's', 'o', 'r', 'p', 't', 'i', 'o', 'n', '\n',
        'a', 'd', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'd', 'u', 'l', 'a', 't', 'o', 'r', 'y', '\n',
        'a', 'd', 'u', 'l', 't', '\n',
        'a', 'd', 'u', 'l', 't', 'e', 'r', 'a', 't', 'e', '\n',
        'a', 'd', 'u', 'l', 't', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'a', 'd', 'u', 'l', 't', 'e', 'r', 'a', 't', 'e', 's', '\n',
        'a', 'd', 'u', 'l', 't', 'e', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'd', 'u', 'l', 't', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'd', 'u', 'l', 't', 'e', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'd', 'u', 'l', 't', 'e', 'r', 'e', 'r', '\n',
        'a', 'd', 'u', 'l', 't', 'e', 'r', 'e', 'r', 's', '\n',
        'a', 'd', 'u', 'l', 't', 'e', 'r', 'e', 's', 's', '\n',
        'a', 'd', 'u', 'l', 't', 'e', 'r', 'e', 's', 's', 'e', 's', '\n',
        'a', 'd', 'u', 'l', 't', 'e', 'r', 'o', 'u', 's', '\n',
        'a', 'd', 'u', 'l', 't', 'e', 'r', 'y', '\n',
        'a', 'd', 'u', 'l', 't', 'h', 'o', 'o', 'd', '\n',
        'a', 'd', 'u', 'l', 't', 's', '\n',
        'a', 'd', 'u', 'm', 'b', 'r', 'a', 't', 'e', '\n',
        'a', 'd', 'u', 'm', 'b', 'r', 'a', 't', 'e', 'd', '\n',
        'a', 'd', 'u', 'm', 'b', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'd', 'v', 'a', 'n', 'c', 'e', '\n',
        'a', 'd', 'v', 'a', 'n', 'c', 'e', 'd', '\n',
        'a', 'd', 'v', 'a', 'n', 'c', 'e', 'm', 'e', 'n', 't', '\n',
        'a', 'd', 'v', 'a', 'n', 'c', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'a', 'd', 'v', 'a', 'n', 'c', 'e', 'r', '\n',
        'a', 'd', 'v', 'a', 'n', 'c', 'e', 's', '\n',
        'a', 'd', 'v', 'a', 'n', 'c', 'i', 'n', 'g', '\n',
        'a', 'd', 'v', 'a', 'n', 't', 'a', 'g', 'e', '\n',
        'a', 'd', 'v', 'a', 'n', 't', 'a', 'g', 'e', 'd', '\n',
        'a', 'd', 'v', 'a', 'n', 't', 'a', 'g', 'e', 'o', 'u', 's', '\n',
        'a', 'd', 'v', 'a', 'n', 't', 'a', 'g', 'e', 'o', 'u', 's', 'l', 'y', '\n',
        'a', 'd', 'v', 'a', 'n', 't', 'a', 'g', 'e', 's', '\n',
        'a', 'd', 'v', 'e', 'n', 't', '\n',
        'a', 'd', 'v', 'e', 'n', 't', 's', '\n',
        'a', 'd', 'v', 'e', 'n', 't', 'u', 'r', 'e', '\n',
        'a', 'd', 'v', 'e', 'n', 't', 'u', 'r', 'e', 'd', '\n',
        'a', 'd', 'v', 'e', 'n', 't', 'u', 'r', 'e', 'r', '\n',
        'a', 'd', 'v', 'e', 'n', 't', 'u', 'r', 'e', 'r', 's', '\n',
        'a', 'd', 'v', 'e', 'n', 't', 'u', 'r', 'e', 's', '\n',
        'a', 'd', 'v', 'e', 'n', 't', 'u', 'r', 'i', 'n', 'g', '\n',
        'a', 'd', 'v', 'e', 'n', 't', 'u', 'r', 'i', 's', 'm', '\n',
        'a', 'd', 'v', 'e', 'n', 't', 'u', 'r', 'o', 'u', 's', '\n',
        'a', 'd', 'v', 'e', 'n', 't', 'u', 'r', 'o', 'u', 's', 'l', 'y', '\n',
        'a', 'd', 'v', 'e', 'r', 'b', '\n',
        'a', 'd', 'v', 'e', 'r', 'b', 'i', 'a', 'l', '\n',
        'a', 'd', 'v', 'e', 'r', 'b', 's', '\n',
        'a', 'd', 'v', 'e', 'r', 's', 'a', 'r', 'i', 'a', 'l', '\n',
        'a', 'd', 'v', 'e', 'r', 's', 'a', 'r', 'i', 'e', 's', '\n',
        'a', 'd', 'v', 'e', 'r', 's', 'a', 'r', 'y', '\n',
        'a', 'd', 'v', 'e', 'r', 's', 'e', '\n',
        'a', 'd', 'v', 'e', 'r', 's', 'e', 'l', 'y', '\n',
        'a', 'd', 'v', 'e', 'r', 's', 'i', 't', 'i', 'e', 's', '\n',
        'a', 'd', 'v', 'e', 'r', 's', 'i', 't', 'y', '\n',
        'a', 'd', 'v', 'e', 'r', 't', '\n',
        'a', 'd', 'v', 'e', 'r', 't', 'e', 'd', '\n',
        'a', 'd', 'v', 'e', 'r', 't', 'i', 's', 'e', '\n',
        'a', 'd', 'v', 'e', 'r', 't', 'i', 's', 'e', 'd', '\n',
        'a', 'd', 'v', 'e', 'r', 't', 'i', 's', 'e', 'm', 'e', 'n', 't', '\n',
        'a', 'd', 'v', 'e', 'r', 't', 'i', 's', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'a', 'd', 'v', 'e', 'r', 't', 'i', 's', 'e', 'r', '\n',
        'a', 'd', 'v', 'e', 'r', 't', 'i', 's', 'e', 'r', 's', '\n',
        'a', 'd', 'v', 'e', 'r', 't', 'i', 's', 'e', 's', '\n',
        'a', 'd', 'v', 'e', 'r', 't', 'i', 's', 'i', 'n', 'g', '\n',
        'a', 'd', 'v', 'e', 'r', 't', 's', '\n',
        'a', 'd', 'v', 'i', 'c', 'e', '\n',
        'a', 'd', 'v', 'i', 'c', 'e', 's', '\n',
        'a', 'd', 'v', 'i', 's', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'a', 'd', 'v', 'i', 's', 'a', 'b', 'l', 'e', '\n',
        'a', 'd', 'v', 'i', 's', 'e', '\n',
        'a', 'd', 'v', 'i', 's', 'e', 'd', '\n',
        'a', 'd', 'v', 'i', 's', 'e', 'd', 'l', 'y', '\n',
        'a', 'd', 'v', 'i', 's', 'e', 'r', '\n',
        'a', 'd', 'v', 'i', 's', 'e', 'r', 's', '\n',
        'a', 'd', 'v', 'i', 's', 'e', 's', '\n',
        'a', 'd', 'v', 'i', 's', 'i', 'n', 'g', '\n',
        'a', 'd', 'v', 'i', 's', 'o', 'r', 'y', '\n',
        'a', 'd', 'v', 'o', 'c', 'a', 'c', 'y', '\n',
        'a', 'd', 'v', 'o', 'c', 'a', 't', 'e', '\n',
        'a', 'd', 'v', 'o', 'c', 'a', 't', 'e', 'd', '\n',
        'a', 'd', 'v', 'o', 'c', 'a', 't', 'e', 's', '\n',
        'a', 'd', 'v', 'o', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'd', 'z', 'e', '\n',
        'a', 'e', 'g', 'e', 'a', 'n', '\n',
        'a', 'e', 'g', 'i', 'n', 'a', '\n',
        'a', 'e', 'g', 'i', 's', '\n',
        'a', 'e', 'o', 'l', 'i', 'a', 'n', '\n',
        'a', 'e', 'o', 'n', '\n',
        'a', 'e', 'o', 'n', 's', '\n',
        'a', 'e', 'r', 'a', 't', 'e', '\n',
        'a', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'a', 'e', 'r', 'a', 't', 'e', 's', '\n',
        'a', 'e', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'e', 'r', 'a', 't', 'o', 'r', '\n',
        'a', 'e', 'r', 'i', 'a', 'l', '\n',
        'a', 'e', 'r', 'i', 'a', 'l', 'l', 'y', '\n',
        'a', 'e', 'r', 'i', 'a', 'l', 's', '\n',
        'a', 'e', 'r', 'i', 'f', 'y', '\n',
        'a', 'e', 'r', 'o', 'b', 'a', 't', 'i', 'c', '\n',
        'a', 'e', 'r', 'o', 'b', 'a', 't', 'i', 'c', 's', '\n',
        'a', 'e', 'r', 'o', 'b', 'e', '\n',
        'a', 'e', 'r', 'o', 'b', 'e', 's', '\n',
        'a', 'e', 'r', 'o', 'b', 'i', 'c', '\n',
        'a', 'e', 'r', 'o', 'b', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 'e', 'r', 'o', 'b', 'i', 'c', 's', '\n',
        'a', 'e', 'r', 'o', 'b', 'r', 'a', 'k', 'i', 'n', 'g', '\n',
        'a', 'e', 'r', 'o', 'd', 'r', 'o', 'm', 'e', '\n',
        'a', 'e', 'r', 'o', 'd', 'r', 'o', 'm', 'e', 's', '\n',
        'a', 'e', 'r', 'o', 'd', 'y', 'n', 'a', 'm', 'i', 'c', '\n',
        'a', 'e', 'r', 'o', 'd', 'y', 'n', 'a', 'm', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 'e', 'r', 'o', 'd', 'y', 'n', 'a', 'm', 'i', 'c', 's', '\n',
        'a', 'e', 'r', 'o', 'f', 'o', 'i', 'l', '\n',
        'a', 'e', 'r', 'o', 'f', 'o', 'i', 'l', 's', '\n',
        'a', 'e', 'r', 'o', 'n', 'a', 'u', 't', '\n',
        'a', 'e', 'r', 'o', 'n', 'a', 'u', 't', 'i', 'c', '\n',
        'a', 'e', 'r', 'o', 'n', 'a', 'u', 't', 'i', 'c', 'a', 'l', '\n',
        'a', 'e', 'r', 'o', 'n', 'a', 'u', 't', 'i', 'c', 's', '\n',
        'a', 'e', 'r', 'o', 'p', 'l', 'a', 'n', 'e', '\n',
        'a', 'e', 'r', 'o', 'p', 'l', 'a', 'n', 'e', 's', '\n',
        'a', 'e', 'r', 'o', 's', 'o', 'l', '\n',
        'a', 'e', 'r', 'o', 's', 'o', 'l', 's', '\n',
        'a', 'e', 'r', 'o', 's', 'p', 'a', 'c', 'e', '\n',
        'a', 'e', 's', 'o', 'p', '\n',
        'a', 'e', 's', 't', 'h', 'e', 't', 'e', '\n',
        'a', 'e', 's', 't', 'h', 'e', 't', 'e', 's', '\n',
        'a', 'e', 's', 't', 'h', 'e', 't', 'i', 'c', '\n',
        'a', 'e', 's', 't', 'h', 'e', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 'e', 's', 't', 'h', 'e', 't', 'i', 'c', 'i', 's', 'm', '\n',
        'a', 'e', 's', 't', 'h', 'e', 't', 'i', 'c', 's', 'y', '\n',
        'a', 'f', 'a', 'r', '\n',
        'a', 'f', 'f', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'a', 'f', 'f', 'a', 'b', 'l', 'e', '\n',
        'a', 'f', 'f', 'a', 'b', 'l', 'y', '\n',
        'a', 'f', 'f', 'a', 'i', 'r', '\n',
        'a', 'f', 'f', 'a', 'i', 'r', 's', '\n',
        'a', 'f', 'f', 'e', 'c', 't', '\n',
        'a', 'f', 'f', 'e', 'c', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'f', 'f', 'e', 'c', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'f', 'f', 'e', 'c', 't', 'e', 'd', '\n',
        'a', 'f', 'f', 'e', 'c', 't', 'e', 'd', 'l', 'y', '\n',
        'a', 'f', 'f', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'a', 'f', 'f', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'a', 'f', 'f', 'e', 'c', 't', 'i', 'o', 'n', 'a', 't', 'e', '\n',
        'a', 'f', 'f', 'e', 'c', 't', 'i', 'o', 'n', 'a', 't', 'e', 'l', 'y', '\n',
        'a', 'f', 'f', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'f', 'f', 'e', 'c', 't', 'i', 'v', 'e', '\n',
        'a', 'f', 'f', 'e', 'c', 't', 's', '\n',
        'a', 'f', 'f', 'e', 'r', 'e', 'n', 't', '\n',
        'a', 'f', 'f', 'i', 'd', 'a', 'v', 'i', 't', '\n',
        'a', 'f', 'f', 'i', 'd', 'a', 'v', 'i', 't', 's', '\n',
        'a', 'f', 'f', 'i', 'l', 'i', 'a', 't', 'e', '\n',
        'a', 'f', 'f', 'i', 'l', 'i', 'a', 't', 'e', 'd', '\n',
        'a', 'f', 'f', 'i', 'l', 'i', 'a', 't', 'e', 's', '\n',
        'a', 'f', 'f', 'i', 'l', 'i', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'f', 'f', 'i', 'l', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'f', 'f', 'i', 'l', 'i', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'f', 'f', 'i', 'n', 'e', '\n',
        'a', 'f', 'f', 'i', 'n', 'i', 't', 'i', 'e', 's', '\n',
        'a', 'f', 'f', 'i', 'n', 'i', 't', 'y', '\n',
        'a', 'f', 'f', 'i', 'r', 'm', '\n',
        'a', 'f', 'f', 'i', 'r', 'm', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'f', 'f', 'i', 'r', 'm', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'f', 'f', 'i', 'r', 'm', 'a', 't', 'i', 'v', 'e', '\n',
        'a', 'f', 'f', 'i', 'r', 'm', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'a', 'f', 'f', 'i', 'r', 'm', 'e', 'd', '\n',
        'a', 'f', 'f', 'i', 'r', 'm', 'i', 'n', 'g', '\n',
        'a', 'f', 'f', 'i', 'r', 'm', 's', '\n',
        'a', 'f', 'f', 'i', 'x', '\n',
        'a', 'f', 'f', 'i', 'x', 'e', 'd', '\n',
        'a', 'f', 'f', 'i', 'x', 'e', 's', '\n',
        'a', 'f', 'f', 'i', 'x', 'i', 'n', 'g', '\n',
        'a', 'f', 'f', 'l', 'i', 'c', 't', '\n',
        'a', 'f', 'f', 'l', 'i', 'c', 't', 'e', 'd', '\n',
        'a', 'f', 'f', 'l', 'i', 'c', 't', 'i', 'n', 'g', '\n',
        'a', 'f', 'f', 'l', 'i', 'c', 't', 'i', 'o', 'n', '\n',
        'a', 'f', 'f', 'l', 'i', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'f', 'f', 'l', 'i', 'c', 't', 's', '\n',
        'a', 'f', 'f', 'l', 'u', 'e', 'n', 'c', 'e', '\n',
        'a', 'f', 'f', 'l', 'u', 'e', 'n', 't', '\n',
        'a', 'f', 'f', 'l', 'u', 'x', '\n',
        'a', 'f', 'f', 'o', 'r', 'd', '\n',
        'a', 'f', 'f', 'o', 'r', 'd', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'a', 'f', 'f', 'o', 'r', 'd', 'a', 'b', 'l', 'e', '\n',
        'a', 'f', 'f', 'o', 'r', 'd', 'e', 'd', '\n',
        'a', 'f', 'f', 'o', 'r', 'd', 'i', 'n', 'g', '\n',
        'a', 'f', 'f', 'o', 'r', 'd', 's', '\n',
        'a', 'f', 'f', 'o', 'r', 'e', 's', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'f', 'f', 'o', 'r', 'e', 's', 't', 'e', 'd', '\n',
        'a', 'f', 'f', 'r', 'a', 'y', '\n',
        'a', 'f', 'f', 'r', 'o', 'n', 't', '\n',
        'a', 'f', 'f', 'r', 'o', 'n', 't', 'e', 'd', '\n',
        'a', 'f', 'f', 'r', 'o', 'n', 't', 's', '\n',
        'a', 'f', 'g', 'h', 'a', 'n', '\n',
        'a', 'f', 'g', 'h', 'a', 'n', 'i', '\n',
        'a', 'f', 'g', 'h', 'a', 'n', 's', '\n',
        'a', 'f', 'i', 'e', 'l', 'd', '\n',
        'a', 'f', 'i', 'r', 'e', '\n',
        'a', 'f', 'l', 'a', 'm', 'e', '\n',
        'a', 'f', 'l', 'o', 'a', 't', '\n',
        'a', 'f', 'o', 'o', 't', '\n',
        'a', 'f', 'o', 'r', 'e', 'm', 'e', 'n', 't', 'i', 'o', 'n', 'e', 'd', '\n',
        'a', 'f', 'o', 'r', 'e', 's', 'a', 'i', 'd', '\n',
        'a', 'f', 'o', 'r', 'e', 't', 'h', 'o', 'u', 'g', 'h', 't', '\n',
        'a', 'f', 'r', 'a', 'i', 'd', '\n',
        'a', 'f', 'r', 'e', 's', 'h', '\n',
        'a', 'f', 'r', 'i', 'c', 'a', '\n',
        'a', 'f', 'r', 'i', 'c', 'a', 'n', '\n',
        'a', 'f', 'r', 'i', 'c', 'a', 'n', 's', '\n',
        'a', 'f', 'r', 'o', '\n',
        'a', 'f', 'r', 'o', 's', '\n',
        'a', 'f', 't', '\n',
        'a', 'f', 't', 'e', 'r', '\n',
        'a', 'f', 't', 'e', 'r', 'b', 'i', 'r', 't', 'h', '\n',
        'a', 'f', 't', 'e', 'r', 'c', 'a', 'r', 'e', '\n',
        'a', 'f', 't', 'e', 'r', 'e', 'f', 'f', 'e', 'c', 't', '\n',
        'a', 'f', 't', 'e', 'r', 'e', 'f', 'f', 'e', 'c', 't', 's', '\n',
        'a', 'f', 't', 'e', 'r', 'g', 'l', 'o', 'w', '\n',
        'a', 'f', 't', 'e', 'r', 'l', 'i', 'f', 'e', '\n',
        'a', 'f', 't', 'e', 'r', 'l', 'i', 'v', 'e', 's', '\n',
        'a', 'f', 't', 'e', 'r', 'm', 'a', 't', 'h', '\n',
        'a', 'f', 't', 'e', 'r', 'n', 'o', 'o', 'n', '\n',
        'a', 'f', 't', 'e', 'r', 'n', 'o', 'o', 'n', 's', '\n',
        'a', 'f', 't', 'e', 'r', 's', 'h', 'a', 'v', 'e', '\n',
        'a', 'f', 't', 'e', 'r', 's', 'h', 'o', 'c', 'k', 's', '\n',
        'a', 'f', 't', 'e', 'r', 't', 'a', 's', 't', 'e', '\n',
        'a', 'f', 't', 'e', 'r', 't', 'h', 'o', 'u', 'g', 'h', 't', '\n',
        'a', 'f', 't', 'e', 'r', 't', 'h', 'o', 'u', 'g', 'h', 't', 's', '\n',
        'a', 'f', 't', 'e', 'r', 'w', 'a', 'r', 'd', '\n',
        'a', 'f', 't', 'e', 'r', 'w', 'a', 'r', 'd', 's', '\n',
        'a', 'g', 'a', '\n',
        'a', 'g', 'a', 'i', 'n', '\n',
        'a', 'g', 'a', 'i', 'n', 's', 't', '\n',
        'a', 'g', 'a', 'k', 'h', 'a', 'n', '\n',
        'a', 'g', 'a', 'p', 'e', '\n',
        'a', 'g', 'a', 'r', '\n',
        'a', 'g', 'a', 'r', 'a', 'g', 'a', 'r', '\n',
        'a', 'g', 'a', 'v', 'e', '\n',
        'a', 'g', 'a', 'v', 'e', 's', '\n',
        'a', 'g', 'e', '\n',
        'a', 'g', 'e', 'd', '\n',
        'a', 'g', 'e', 'i', 'n', 'g', '\n',
        'a', 'g', 'e', 'i', 'n', 'g', 's', '\n',
        'a', 'g', 'e', 'i', 's', 'm', '\n',
        'a', 'g', 'e', 'l', 'e', 's', 's', '\n',
        'a', 'g', 'e', 'n', 'c', 'i', 'e', 's', '\n',
        'a', 'g', 'e', 'n', 'c', 'y', '\n',
        'a', 'g', 'e', 'n', 'd', 'a', '\n',
        'a', 'g', 'e', 'n', 'd', 'a', 's', '\n',
        'a', 'g', 'e', 'n', 'd', 'u', 'm', 's', '\n',
        'a', 'g', 'e', 'n', 't', '\n',
        'a', 'g', 'e', 'n', 't', 's', '\n',
        'a', 'g', 'e', 'o', 'l', 'd', '\n',
        'a', 'g', 'e', 's', '\n',
        'a', 'g', 'g', 'l', 'o', 'm', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'a', 'g', 'g', 'l', 'o', 'm', 'e', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'g', 'g', 'l', 'o', 'm', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'g', 'g', 'l', 'o', 'm', 'e', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'g', 'g', 'l', 'u', 't', 'i', 'n', 'a', 't', 'i', 'v', 'e', '\n',
        'a', 'g', 'g', 'r', 'a', 'v', 'a', 't', 'e', '\n',
        'a', 'g', 'g', 'r', 'a', 'v', 'a', 't', 'e', 'd', '\n',
        'a', 'g', 'g', 'r', 'a', 'v', 'a', 't', 'e', 's', '\n',
        'a', 'g', 'g', 'r', 'a', 'v', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'g', 'g', 'r', 'a', 'v', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'g', 'g', 'r', 'a', 'v', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'g', 'g', 'r', 'e', 'g', 'a', 't', 'e', '\n',
        'a', 'g', 'g', 'r', 'e', 'g', 'a', 't', 'e', 'd', '\n',
        'a', 'g', 'g', 'r', 'e', 'g', 'a', 't', 'e', 's', '\n',
        'a', 'g', 'g', 'r', 'e', 'g', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'g', 'g', 'r', 'e', 'g', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'g', 'g', 'r', 'e', 'g', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'g', 'g', 'r', 'e', 's', 's', 'i', 'o', 'n', '\n',
        'a', 'g', 'g', 'r', 'e', 's', 's', 'i', 'o', 'n', 's', '\n',
        'a', 'g', 'g', 'r', 'e', 's', 's', 'i', 'v', 'e', '\n',
        'a', 'g', 'g', 'r', 'e', 's', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'a', 'g', 'g', 'r', 'e', 's', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'a', 'g', 'g', 'r', 'e', 's', 's', 'o', 'r', '\n',
        'a', 'g', 'g', 'r', 'e', 's', 's', 'o', 'r', 's', '\n',
        'a', 'g', 'g', 'r', 'i', 'e', 'v', 'e', 'd', '\n',
        'a', 'g', 'g', 'r', 'i', 'e', 'v', 'e', 'd', 'l', 'y', '\n',
        'a', 'g', 'h', 'a', 's', 't', '\n',
        'a', 'g', 'i', 'l', 'e', '\n',
        'a', 'g', 'i', 'l', 'e', 'r', '\n',
        'a', 'g', 'i', 'l', 'i', 't', 'y', '\n',
        'a', 'g', 'i', 'n', 'g', '\n',
        'a', 'g', 'i', 'n', 'g', 's', '\n',
        'a', 'g', 'i', 'o', '\n',
        'a', 'g', 'i', 't', 'a', 't', 'e', '\n',
        'a', 'g', 'i', 't', 'a', 't', 'e', 'd', '\n',
        'a', 'g', 'i', 't', 'a', 't', 'e', 'd', 'l', 'y', '\n',
        'a', 'g', 'i', 't', 'a', 't', 'e', 's', '\n',
        'a', 'g', 'i', 't', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'g', 'i', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'g', 'i', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'g', 'i', 't', 'a', 't', 'o', 'r', '\n',
        'a', 'g', 'i', 't', 'a', 't', 'o', 'r', 's', '\n',
        'a', 'g', 'i', 't', 'p', 'r', 'o', 'p', '\n',
        'a', 'g', 'l', 'e', 'a', 'm', '\n',
        'a', 'g', 'l', 'o', 'w', '\n',
        'a', 'g', 'n', 'o', 's', 't', 'i', 'c', '\n',
        'a', 'g', 'n', 'o', 's', 't', 'i', 'c', 'i', 's', 'm', '\n',
        'a', 'g', 'n', 'o', 's', 't', 'i', 'c', 's', '\n',
        'a', 'g', 'o', '\n',
        'a', 'g', 'o', 'g', '\n',
        'a', 'g', 'o', 'n', 'i', 'e', 's', '\n',
        'a', 'g', 'o', 'n', 'i', 's', 'e', '\n',
        'a', 'g', 'o', 'n', 'i', 's', 'e', 'd', '\n',
        'a', 'g', 'o', 'n', 'i', 's', 'e', 's', '\n',
        'a', 'g', 'o', 'n', 'i', 's', 'i', 'n', 'g', '\n',
        'a', 'g', 'o', 'n', 'i', 's', 'i', 'n', 'g', 'l', 'y', '\n',
        'a', 'g', 'o', 'n', 'i', 's', 't', '\n',
        'a', 'g', 'o', 'n', 'i', 's', 't', 's', '\n',
        'a', 'g', 'o', 'n', 'y', '\n',
        'a', 'g', 'o', 'r', 'a', '\n',
        'a', 'g', 'o', 'r', 'a', 'p', 'h', 'o', 'b', 'i', 'a', '\n',
        'a', 'g', 'o', 'r', 'a', 'p', 'h', 'o', 'b', 'i', 'c', '\n',
        'a', 'g', 'o', 'u', 't', 'i', '\n',
        'a', 'g', 'r', 'a', 'r', 'i', 'a', 'n', '\n',
        'a', 'g', 'r', 'e', 'e', '\n',
        'a', 'g', 'r', 'e', 'e', 'a', 'b', 'l', 'e', '\n',
        'a', 'g', 'r', 'e', 'e', 'a', 'b', 'l', 'e', 'n', 'e', 's', 's', '\n',
        'a', 'g', 'r', 'e', 'e', 'a', 'b', 'l', 'y', '\n',
        'a', 'g', 'r', 'e', 'e', 'd', '\n',
        'a', 'g', 'r', 'e', 'e', 'i', 'n', 'g', '\n',
        'a', 'g', 'r', 'e', 'e', 'm', 'e', 'n', 't', '\n',
        'a', 'g', 'r', 'e', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'a', 'g', 'r', 'e', 'e', 's', '\n',
        'a', 'g', 'r', 'i', 'b', 'u', 's', 'i', 'n', 'e', 's', 's', '\n',
        'a', 'g', 'r', 'i', 'c', 'u', 'l', 't', 'u', 'r', 'a', 'l', '\n',
        'a', 'g', 'r', 'i', 'c', 'u', 'l', 't', 'u', 'r', 'a', 'l', 'i', 's', 't', '\n',
        'a', 'g', 'r', 'i', 'c', 'u', 'l', 't', 'u', 'r', 'a', 'l', 'i', 's', 't', 's', '\n',
        'a', 'g', 'r', 'i', 'c', 'u', 'l', 't', 'u', 'r', 'a', 'l', 'l', 'y', '\n',
        'a', 'g', 'r', 'i', 'c', 'u', 'l', 't', 'u', 'r', 'e', '\n',
        'a', 'g', 'r', 'i', 'm', 'o', 'n', 'y', '\n',
        'a', 'g', 'r', 'o', 'c', 'h', 'e', 'm', 'i', 'c', 'a', 'l', '\n',
        'a', 'g', 'r', 'o', 'c', 'h', 'e', 'm', 'i', 'c', 'a', 'l', 's', '\n',
        'a', 'g', 'r', 'o', 'n', 'o', 'm', 'i', 's', 't', '\n',
        'a', 'g', 'r', 'o', 'n', 'o', 'm', 'i', 's', 't', 's', '\n',
        'a', 'g', 'r', 'o', 'n', 'o', 'm', 'y', '\n',
        'a', 'g', 'r', 'o', 'u', 'n', 'd', '\n',
        'a', 'g', 'u', 'e', '\n',
        'a', 'h', '\n',
        'a', 'h', 'a', '\n',
        'a', 'h', 'e', 'a', 'd', '\n',
        'a', 'h', 'e', 'm', '\n',
        'a', 'h', 'o', 'y', '\n',
        'a', 'i', 'd', '\n',
        'a', 'i', 'd', 'e', '\n',
        'a', 'i', 'd', 'e', 'd', '\n',
        'a', 'i', 'd', 'e', 'd', 'e', 'c', 'a', 'm', 'p', '\n',
        'a', 'i', 'd', 'e', 'r', '\n',
        'a', 'i', 'd', 'e', 'r', 's', '\n',
        'a', 'i', 'd', 'e', 's', '\n',
        'a', 'i', 'd', 'e', 's', 'd', 'e', 'c', 'a', 'm', 'p', '\n',
        'a', 'i', 'd', 'i', 'n', 'g', '\n',
        'a', 'i', 'd', 's', '\n',
        'a', 'i', 'l', '\n',
        'a', 'i', 'l', 'e', 'r', 'o', 'n', '\n',
        'a', 'i', 'l', 'e', 'r', 'o', 'n', 's', '\n',
        'a', 'i', 'l', 'i', 'n', 'g', '\n',
        'a', 'i', 'l', 'm', 'e', 'n', 't', '\n',
        'a', 'i', 'l', 'm', 'e', 'n', 't', 's', '\n',
        'a', 'i', 'l', 's', '\n',
        'a', 'i', 'm', '\n',
        'a', 'i', 'm', 'e', 'd', '\n',
        'a', 'i', 'm', 'e', 'r', '\n',
        'a', 'i', 'm', 'i', 'n', 'g', '\n',
        'a', 'i', 'm', 'l', 'e', 's', 's', '\n',
        'a', 'i', 'm', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'a', 'i', 'm', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'a', 'i', 'm', 's', '\n',
        'a', 'i', 'n', 't', '\n',
        'a', 'i', 'r', '\n',
        'a', 'i', 'r', 'b', 'a', 's', 'e', '\n',
        'a', 'i', 'r', 'b', 'o', 'r', 'n', 'e', '\n',
        'a', 'i', 'r', 'b', 'r', 'u', 's', 'h', '\n',
        'a', 'i', 'r', 'b', 'u', 's', '\n',
        'a', 'i', 'r', 'c', 'o', 'n', 'd', 'i', 't', 'i', 'o', 'n', 'e', 'd', '\n',
        'a', 'i', 'r', 'c', 'o', 'n', 'd', 'i', 't', 'i', 'o', 'n', 'e', 'r', '\n',
        'a', 'i', 'r', 'c', 'o', 'n', 'd', 'i', 't', 'i', 'o', 'n', 'i', 'n', 'g', '\n',
        'a', 'i', 'r', 'c', 'r', 'a', 'f', 't', '\n',
        'a', 'i', 'r', 'c', 'r', 'e', 'w', '\n',
        'a', 'i', 'r', 'c', 'r', 'e', 'w', 's', '\n',
        'a', 'i', 'r', 'e', '\n',
        'a', 'i', 'r', 'e', 'd', '\n',
        'a', 'i', 'r', 'f', 'i', 'e', 'l', 'd', '\n',
        'a', 'i', 'r', 'f', 'i', 'e', 'l', 'd', 's', '\n',
        'a', 'i', 'r', 'f', 'l', 'o', 'w', '\n',
        'a', 'i', 'r', 'f', 'o', 'r', 'c', 'e', '\n',
        'a', 'i', 'r', 'f', 'r', 'a', 'm', 'e', '\n',
        'a', 'i', 'r', 'f', 'r', 'a', 'm', 'e', 's', '\n',
        'a', 'i', 'r', 'g', 'u', 'n', '\n',
        'a', 'i', 'r', 'i', 'e', 'r', '\n',
        'a', 'i', 'r', 'i', 'e', 's', 't', '\n',
        'a', 'i', 'r', 'i', 'l', 'y', '\n',
        'a', 'i', 'r', 'i', 'n', 'e', 's', 's', '\n',
        'a', 'i', 'r', 'i', 'n', 'g', '\n',
        'a', 'i', 'r', 'i', 'n', 'g', 's', '\n',
        'a', 'i', 'r', 'l', 'e', 's', 's', '\n',
        'a', 'i', 'r', 'l', 'i', 'f', 't', '\n',
        'a', 'i', 'r', 'l', 'i', 'f', 't', 'e', 'd', '\n',
        'a', 'i', 'r', 'l', 'i', 'f', 't', 'i', 'n', 'g', '\n',
        'a', 'i', 'r', 'l', 'i', 'f', 't', 's', '\n',
        'a', 'i', 'r', 'l', 'i', 'n', 'e', '\n',
        'a', 'i', 'r', 'l', 'i', 'n', 'e', 'r', '\n',
        'a', 'i', 'r', 'l', 'i', 'n', 'e', 'r', 's', '\n',
        'a', 'i', 'r', 'l', 'i', 'n', 'e', 's', '\n',
        'a', 'i', 'r', 'l', 'o', 'c', 'k', '\n',
        'a', 'i', 'r', 'l', 'o', 'c', 'k', 's', '\n',
        'a', 'i', 'r', 'm', 'a', 'i', 'l', '\n',
        'a', 'i', 'r', 'm', 'a', 'n', '\n',
        'a', 'i', 'r', 'm', 'e', 'n', '\n',
        'a', 'i', 'r', 'p', 'l', 'a', 'n', 'e', '\n',
        'a', 'i', 'r', 'p', 'l', 'a', 'y', '\n',
        'a', 'i', 'r', 'p', 'o', 'r', 't', '\n',
        'a', 'i', 'r', 'p', 'o', 'r', 't', 's', '\n',
        'a', 'i', 'r', 'r', 'a', 'i', 'd', '\n',
        'a', 'i', 'r', 's', '\n',
        'a', 'i', 'r', 's', 'h', 'i', 'p', '\n',
        'a', 'i', 'r', 's', 'h', 'i', 'p', 's', '\n',
        'a', 'i', 'r', 's', 'i', 'c', 'k', '\n',
        'a', 'i', 'r', 's', 'i', 'c', 'k', 'n', 'e', 's', 's', '\n',
        'a', 'i', 'r', 's', 'p', 'a', 'c', 'e', '\n',
        'a', 'i', 'r', 's', 't', 'r', 'e', 'a', 'm', '\n',
        'a', 'i', 'r', 's', 't', 'r', 'i', 'p', '\n',
        'a', 'i', 'r', 's', 't', 'r', 'i', 'p', 's', '\n',
        'a', 'i', 'r', 't', 'i', 'g', 'h', 't', '\n',
        'a', 'i', 'r', 't', 'i', 'm', 'e', '\n',
        'a', 'i', 'r', 'w', 'a', 'v', 'e', '\n',
        'a', 'i', 'r', 'w', 'a', 'v', 'e', 's', '\n',
        'a', 'i', 'r', 'w', 'a', 'y', '\n',
        'a', 'i', 'r', 'w', 'a', 'y', 's', '\n',
        'a', 'i', 'r', 'w', 'o', 'r', 't', 'h', 'i', 'n', 'e', 's', 's', '\n',
        'a', 'i', 'r', 'w', 'o', 'r', 't', 'h', 'y', '\n',
        'a', 'i', 'r', 'y', '\n',
        'a', 'i', 's', 'l', 'e', '\n',
        'a', 'i', 's', 'l', 'e', 's', '\n',
        'a', 'i', 't', 'c', 'h', 'e', 's', '\n',
        'a', 'j', 'a', 'r', '\n',
        'a', 'k', 'i', 'm', 'b', 'o', '\n',
        'a', 'k', 'i', 'n', '\n',
        'a', 'l', 'a', '\n',
        'a', 'l', 'a', 'b', 'a', 'm', 'a', '\n',
        'a', 'l', 'a', 'b', 'a', 's', 't', 'e', 'r', '\n',
        'a', 'l', 'a', 'c', 'a', 'r', 't', 'e', '\n',
        'a', 'l', 'a', 'c', 'k', '\n',
        'a', 'l', 'a', 'c', 'r', 'i', 't', 'y', '\n',
        'a', 'l', 'a', 'd', 'd', 'i', 'n', '\n',
        'a', 'l', 'a', 'n', 'i', 'n', 'e', '\n',
        'a', 'l', 'a', 'r', 'm', '\n',
        'a', 'l', 'a', 'r', 'm', 'e', 'd', '\n',
        'a', 'l', 'a', 'r', 'm', 'i', 'n', 'g', '\n',
        'a', 'l', 'a', 'r', 'm', 'i', 'n', 'g', 'l', 'y', '\n',
        'a', 'l', 'a', 'r', 'm', 'i', 's', 'm', '\n',
        'a', 'l', 'a', 'r', 'm', 'i', 's', 't', '\n',
        'a', 'l', 'a', 'r', 'm', 's', '\n',
        'a', 'l', 'a', 's', '\n',
        'a', 'l', 'a', 's', 'k', 'a', '\n',
        'a', 'l', 'a', 's', 'k', 'a', 'n', '\n',
        'a', 'l', 'b', '\n',
        'a', 'l', 'b', 'a', 'n', 'i', 'a', '\n',
        'a', 'l', 'b', 'a', 'n', 'y', '\n',
        'a', 'l', 'b', 'a', 't', 'r', 'o', 's', 's', '\n',
        'a', 'l', 'b', 'a', 't', 'r', 'o', 's', 's', 'e', 's', '\n',
        'a', 'l', 'b', 'e', 'i', 't', '\n',
        'a', 'l', 'b', 'i', 'n', 'i', 's', 'm', '\n',
        'a', 'l', 'b', 'i', 'n', 'o', '\n',
        'a', 'l', 'b', 'u', 'm', '\n',
        'a', 'l', 'b', 'u', 'm', 'e', 'n', '\n',
        'a', 'l', 'b', 'u', 'm', 'i', 'n', '\n',
        'a', 'l', 'b', 'u', 'm', 's', '\n',
        'a', 'l', 'c', 'h', 'e', 'm', 'i', 'c', 'a', 'l', '\n',
        'a', 'l', 'c', 'h', 'e', 'm', 'i', 's', 't', '\n',
        'a', 'l', 'c', 'h', 'e', 'm', 'i', 's', 't', 's', '\n',
        'a', 'l', 'c', 'h', 'e', 'm', 'y', '\n',
        'a', 'l', 'c', 'o', 'h', 'o', 'l', '\n',
        'a', 'l', 'c', 'o', 'h', 'o', 'l', 'i', 'c', '\n',
        'a', 'l', 'c', 'o', 'h', 'o', 'l', 'i', 'c', 's', '\n',
        'a', 'l', 'c', 'o', 'h', 'o', 'l', 'i', 's', 'm', '\n',
        'a', 'l', 'c', 'o', 'h', 'o', 'l', 's', '\n',
        'a', 'l', 'c', 'o', 'v', 'e', '\n',
        'a', 'l', 'c', 'o', 'v', 'e', 's', '\n',
        'a', 'l', 'd', 'e', 'h', 'y', 'd', 'e', '\n',
        'a', 'l', 'd', 'e', 'h', 'y', 'd', 'e', 's', '\n',
        'a', 'l', 'd', 'e', 'r', '\n',
        'a', 'l', 'd', 'e', 'r', 'm', 'a', 'n', '\n',
        'a', 'l', 'd', 'e', 'r', 'm', 'e', 'n', '\n',
        'a', 'l', 'd', 'r', 'i', 'n', '\n',
        'a', 'l', 'e', '\n',
        'a', 'l', 'e', 'h', 'o', 'u', 's', 'e', '\n',
        'a', 'l', 'e', 'm', 'b', 'i', 'c', '\n',
        'a', 'l', 'e', 'r', 't', '\n',
        'a', 'l', 'e', 'r', 't', 'e', 'd', '\n',
        'a', 'l', 'e', 'r', 't', 'i', 'n', 'g', '\n',
        'a', 'l', 'e', 'r', 't', 'l', 'y', '\n',
        'a', 'l', 'e', 'r', 't', 'n', 'e', 's', 's', '\n',
        'a', 'l', 'e', 'r', 't', 's', '\n',
        'a', 'l', 'e', 's', '\n',
        'a', 'l', 'f', 'a', 'l', 'f', 'a', '\n',
        'a', 'l', 'f', 'a', 't', 'a', 'h', '\n',
        'a', 'l', 'g', 'a', '\n',
        'a', 'l', 'g', 'a', 'e', '\n',
        'a', 'l', 'g', 'a', 'l', '\n',
        'a', 'l', 'g', 'e', 'b', 'r', 'a', '\n',
        'a', 'l', 'g', 'e', 'b', 'r', 'a', 'i', 'c', '\n',
        'a', 'l', 'g', 'e', 'b', 'r', 'a', 'i', 'c', 'a', 'l', '\n',
        'a', 'l', 'g', 'e', 'b', 'r', 'a', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 'l', 'g', 'e', 'b', 'r', 'a', 'i', 's', 't', '\n',
        'a', 'l', 'g', 'e', 'b', 'r', 'a', 's', '\n',
        'a', 'l', 'g', 'e', 'r', 'i', 'a', '\n',
        'a', 'l', 'g', 'e', 'r', 'i', 'a', 'n', '\n',
        'a', 'l', 'g', 'i', 'e', 'r', 's', '\n',
        'a', 'l', 'g', 'o', 'r', 'i', 't', 'h', 'm', '\n',
        'a', 'l', 'g', 'o', 'r', 'i', 't', 'h', 'm', 'i', 'c', '\n',
        'a', 'l', 'g', 'o', 'r', 'i', 't', 'h', 'm', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 'l', 'g', 'o', 'r', 'i', 't', 'h', 'm', 's', '\n',
        'a', 'l', 'i', 'a', 's', '\n',
        'a', 'l', 'i', 'a', 's', 'e', 's', '\n',
        'a', 'l', 'i', 'b', 'a', 'b', 'a', '\n',
        'a', 'l', 'i', 'b', 'i', '\n',
        'a', 'l', 'i', 'b', 'i', 's', '\n',
        'a', 'l', 'i', 'e', 'n', '\n',
        'a', 'l', 'i', 'e', 'n', 'a', 't', 'e', '\n',
        'a', 'l', 'i', 'e', 'n', 'a', 't', 'e', 'd', '\n',
        'a', 'l', 'i', 'e', 'n', 'a', 't', 'e', 's', '\n',
        'a', 'l', 'i', 'e', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'l', 'i', 'e', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'l', 'i', 'e', 'n', 'e', 'd', '\n',
        'a', 'l', 'i', 'e', 'n', 'i', 'n', 'g', '\n',
        'a', 'l', 'i', 'e', 'n', 's', '\n',
        'a', 'l', 'i', 'g', 'h', 't', '\n',
        'a', 'l', 'i', 'g', 'h', 't', 'e', 'd', '\n',
        'a', 'l', 'i', 'g', 'h', 't', 'i', 'n', 'g', '\n',
        'a', 'l', 'i', 'g', 'h', 't', 's', '\n',
        'a', 'l', 'i', 'g', 'n', '\n',
        'a', 'l', 'i', 'g', 'n', 'e', 'd', '\n',
        'a', 'l', 'i', 'g', 'n', 'i', 'n', 'g', '\n',
        'a', 'l', 'i', 'g', 'n', 'm', 'e', 'n', 't', '\n',
        'a', 'l', 'i', 'g', 'n', 'm', 'e', 'n', 't', 's', '\n',
        'a', 'l', 'i', 'g', 'n', 's', '\n',
        'a', 'l', 'i', 'k', 'e', '\n',
        'a', 'l', 'i', 'm', 'e', 'n', 't', 'a', 'r', 'y', '\n',
        'a', 'l', 'i', 'm', 'o', 'n', 'y', '\n',
        'a', 'l', 'i', 'n', 'e', '\n',
        'a', 'l', 'i', 'n', 'e', 'd', '\n',
        'a', 'l', 'i', 'n', 'e', 's', '\n',
        'a', 'l', 'i', 'n', 'i', 'n', 'g', '\n',
        'a', 'l', 'i', 'p', 'h', 'a', 't', 'i', 'c', '\n',
        'a', 'l', 'i', 'q', 'u', 'o', 't', '\n',
        'a', 'l', 'i', 'q', 'u', 'o', 't', 's', '\n',
        'a', 'l', 'i', 'v', 'e', '\n',
        'a', 'l', 'k', 'a', 'l', 'i', '\n',
        'a', 'l', 'k', 'a', 'l', 'i', 'c', '\n',
        'a', 'l', 'k', 'a', 'l', 'i', 'n', 'e', '\n',
        'a', 'l', 'k', 'a', 'l', 'i', 'n', 'i', 't', 'y', '\n',
        'a', 'l', 'k', 'a', 'l', 'i', 's', '\n',
        'a', 'l', 'k', 'a', 'l', 'i', 's', 'e', '\n',
        'a', 'l', 'k', 'a', 'l', 'o', 'i', 'd', '\n',
        'a', 'l', 'k', 'a', 'l', 'o', 'i', 'd', 's', '\n',
        'a', 'l', 'k', 'a', 'n', 'e', 's', '\n',
        'a', 'l', 'k', 'y', 'l', '\n',
        'a', 'l', 'l', '\n',
        'a', 'l', 'l', 'a', 'y', '\n',
        'a', 'l', 'l', 'a', 'y', 'e', 'd', '\n',
        'a', 'l', 'l', 'a', 'y', 'i', 'n', 'g', '\n',
        'a', 'l', 'l', 'a', 'y', 's', '\n',
        'a', 'l', 'l', 'e', 'g', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'l', 'l', 'e', 'g', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'l', 'l', 'e', 'g', 'e', '\n',
        'a', 'l', 'l', 'e', 'g', 'e', 'd', '\n',
        'a', 'l', 'l', 'e', 'g', 'e', 'd', 'l', 'y', '\n',
        'a', 'l', 'l', 'e', 'g', 'e', 's', '\n',
        'a', 'l', 'l', 'e', 'g', 'i', 'a', 'n', 'c', 'e', '\n',
        'a', 'l', 'l', 'e', 'g', 'i', 'a', 'n', 'c', 'e', 's', '\n',
        'a', 'l', 'l', 'e', 'g', 'i', 'n', 'g', '\n',
        'a', 'l', 'l', 'e', 'g', 'o', 'r', 'i', 'c', 'a', 'l', '\n',
        'a', 'l', 'l', 'e', 'g', 'o', 'r', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 'l', 'l', 'e', 'g', 'o', 'r', 'i', 'e', 's', '\n',
        'a', 'l', 'l', 'e', 'g', 'o', 'r', 'y', '\n',
        'a', 'l', 'l', 'e', 'g', 'r', 'i', '\n',
        'a', 'l', 'l', 'e', 'g', 'r', 'o', '\n',
        'a', 'l', 'l', 'e', 'l', 'e', '\n',
        'a', 'l', 'l', 'e', 'l', 'e', 's', '\n',
        'a', 'l', 'l', 'e', 'l', 'i', 'c', '\n',
        'a', 'l', 'l', 'e', 'r', 'g', 'e', 'n', '\n',
        'a', 'l', 'l', 'e', 'r', 'g', 'e', 'n', 's', '\n',
        'a', 'l', 'l', 'e', 'r', 'g', 'i', 'c', '\n',
        'a', 'l', 'l', 'e', 'r', 'g', 'i', 'e', 's', '\n',
        'a', 'l', 'l', 'e', 'r', 'g', 'y', '\n',
        'a', 'l', 'l', 'e', 'v', 'i', 'a', 't', 'e', '\n',
        'a', 'l', 'l', 'e', 'v', 'i', 'a', 't', 'e', 'd', '\n',
        'a', 'l', 'l', 'e', 'v', 'i', 'a', 't', 'e', 's', '\n',
        'a', 'l', 'l', 'e', 'v', 'i', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'l', 'l', 'e', 'v', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'l', 'l', 'e', 'v', 'i', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'l', 'l', 'e', 'y', '\n',
        'a', 'l', 'l', 'e', 'y', 's', '\n',
        'a', 'l', 'l', 'e', 'y', 'w', 'a', 'y', '\n',
        'a', 'l', 'l', 'e', 'y', 'w', 'a', 'y', 's', '\n',
        'a', 'l', 'l', 'i', 'a', 'n', 'c', 'e', '\n',
        'a', 'l', 'l', 'i', 'a', 'n', 'c', 'e', 's', '\n',
        'a', 'l', 'l', 'i', 'e', 'd', '\n',
        'a', 'l', 'l', 'i', 'e', 's', '\n',
        'a', 'l', 'l', 'i', 'g', 'a', 't', 'o', 'r', '\n',
        'a', 'l', 'l', 'i', 'g', 'a', 't', 'o', 'r', 's', '\n',
        'a', 'l', 'l', 'i', 't', 'e', 'r', 'a', 't', 'e', '\n',
        'a', 'l', 'l', 'i', 't', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'a', 'l', 'l', 'i', 't', 'e', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'l', 'l', 'i', 't', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'l', 'l', 'i', 't', 'e', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'l', 'l', 'i', 't', 'e', 'r', 'a', 't', 'i', 'v', 'e', '\n',
        'a', 'l', 'l', 'o', 'c', 'a', 't', 'a', 'b', 'l', 'e', '\n',
        'a', 'l', 'l', 'o', 'c', 'a', 't', 'e', '\n',
        'a', 'l', 'l', 'o', 'c', 'a', 't', 'e', 'd', '\n',
        'a', 'l', 'l', 'o', 'c', 'a', 't', 'e', 's', '\n',
        'a', 'l', 'l', 'o', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'l', 'l', 'o', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'l', 'l', 'o', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'l', 'l', 'o', 'c', 'a', 't', 'o', 'r', '\n',
        'a', 'l', 'l', 'o', 'c', 'a', 't', 'o', 'r', 's', '\n',
        'a', 'l', 'l', 'o', 'p', 'h', 'o', 'n', 'e', 's', '\n',
        'a', 'l', 'l', 'o', 't', '\n',
        'a', 'l', 'l', 'o', 't', 'm', 'e', 'n', 't', '\n',
        'a', 'l', 'l', 'o', 't', 'm', 'e', 'n', 't', 's', '\n',
        'a', 'l', 'l', 'o', 't', 'r', 'o', 'p', 'e', '\n',
        'a', 'l', 'l', 'o', 't', 'r', 'o', 'p', 'i', 'c', '\n',
        'a', 'l', 'l', 'o', 't', 's', '\n',
        'a', 'l', 'l', 'o', 't', 't', 'e', 'd', '\n',
        'a', 'l', 'l', 'o', 't', 't', 'i', 'n', 'g', '\n',
        'a', 'l', 'l', 'o', 'w', '\n',
        'a', 'l', 'l', 'o', 'w', 'a', 'b', 'l', 'e', '\n',
        'a', 'l', 'l', 'o', 'w', 'a', 'n', 'c', 'e', '\n',
        'a', 'l', 'l', 'o', 'w', 'a', 'n', 'c', 'e', 's', '\n',
        'a', 'l', 'l', 'o', 'w', 'e', 'd', '\n',
        'a', 'l', 'l', 'o', 'w', 'i', 'n', 'g', '\n',
        'a', 'l', 'l', 'o', 'w', 's', '\n',
        'a', 'l', 'l', 'o', 'y', '\n',
        'a', 'l', 'l', 'o', 'y', 'e', 'd', '\n',
        'a', 'l', 'l', 'o', 'y', 'i', 'n', 'g', '\n',
        'a', 'l', 'l', 'o', 'y', 's', '\n',
        'a', 'l', 'l', 'u', 'd', 'e', '\n',
        'a', 'l', 'l', 'u', 'd', 'e', 'd', '\n',
        'a', 'l', 'l', 'u', 'd', 'e', 's', '\n',
        'a', 'l', 'l', 'u', 'd', 'i', 'n', 'g', '\n',
        'a', 'l', 'l', 'u', 'r', 'e', '\n',
        'a', 'l', 'l', 'u', 'r', 'e', 'd', '\n',
        'a', 'l', 'l', 'u', 'r', 'e', 'm', 'e', 'n', 't', '\n',
        'a', 'l', 'l', 'u', 'r', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'a', 'l', 'l', 'u', 'r', 'e', 's', '\n',
        'a', 'l', 'l', 'u', 'r', 'i', 'n', 'g', '\n',
        'a', 'l', 'l', 'u', 'r', 'i', 'n', 'g', 'l', 'y', '\n',
        'a', 'l', 'l', 'u', 's', 'i', 'o', 'n', '\n',
        'a', 'l', 'l', 'u', 's', 'i', 'o', 'n', 's', '\n',
        'a', 'l', 'l', 'u', 's', 'i', 'v', 'e', '\n',
        'a', 'l', 'l', 'u', 'v', 'i', 'a', '\n',
        'a', 'l', 'l', 'u', 'v', 'i', 'a', 'l', '\n',
        'a', 'l', 'l', 'u', 'v', 'i', 'u', 'm', '\n',
        'a', 'l', 'l', 'y', '\n',
        'a', 'l', 'l', 'y', 'i', 'n', 'g', '\n',
        'a', 'l', 'm', 'a', 'n', 'a', 'c', '\n',
        'a', 'l', 'm', 'a', 'n', 'a', 'c', 's', '\n',
        'a', 'l', 'm', 'i', 'g', 'h', 't', 'y', '\n',
        'a', 'l', 'm', 'o', 'n', 'd', '\n',
        'a', 'l', 'm', 'o', 'n', 'd', 's', '\n',
        'a', 'l', 'm', 'o', 's', 't', '\n',
        'a', 'l', 'm', 's', '\n',
        'a', 'l', 'm', 's', 'h', 'o', 'u', 's', 'e', '\n',
        'a', 'l', 'm', 's', 'h', 'o', 'u', 's', 'e', 's', '\n',
        'a', 'l', 'o', 'e', '\n',
        'a', 'l', 'o', 'e', 's', '\n',
        'a', 'l', 'o', 'f', 't', '\n',
        'a', 'l', 'o', 'h', 'a', '\n',
        'a', 'l', 'o', 'n', 'e', '\n',
        'a', 'l', 'o', 'n', 'e', 'n', 'e', 's', 's', '\n',
        'a', 'l', 'o', 'n', 'g', '\n',
        'a', 'l', 'o', 'n', 'g', 's', 'i', 'd', 'e', '\n',
        'a', 'l', 'o', 'o', 'f', '\n',
        'a', 'l', 'o', 'o', 'f', 'n', 'e', 's', 's', '\n',
        'a', 'l', 'o', 'u', 'd', '\n',
        'a', 'l', 'p', '\n',
        'a', 'l', 'p', 'a', 'c', 'a', '\n',
        'a', 'l', 'p', 'a', 'c', 'a', 's', '\n',
        'a', 'l', 'p', 'h', 'a', '\n',
        'a', 'l', 'p', 'h', 'a', 'b', 'e', 't', '\n',
        'a', 'l', 'p', 'h', 'a', 'b', 'e', 't', 'i', 'c', '\n',
        'a', 'l', 'p', 'h', 'a', 'b', 'e', 't', 'i', 'c', 'a', 'l', '\n',
        'a', 'l', 'p', 'h', 'a', 'b', 'e', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 'l', 'p', 'h', 'a', 'b', 'e', 't', 's', '\n',
        'a', 'l', 'p', 'h', 'a', 'n', 'u', 'm', 'e', 'r', 'i', 'c', '\n',
        'a', 'l', 'p', 'h', 'a', 's', '\n',
        'a', 'l', 'p', 'i', 'n', 'e', '\n',
        'a', 'l', 'p', 's', '\n',
        'a', 'l', 'r', 'e', 'a', 'd', 'y', '\n',
        'a', 'l', 'r', 'i', 'g', 'h', 't', '\n',
        'a', 'l', 's', 'o', '\n',
        'a', 'l', 't', '\n',
        'a', 'l', 't', 'a', 'r', '\n',
        'a', 'l', 't', 'a', 'r', 'p', 'i', 'e', 'c', 'e', '\n',
        'a', 'l', 't', 'a', 'r', 'p', 'i', 'e', 'c', 'e', 's', '\n',
        'a', 'l', 't', 'a', 'r', 's', '\n',
        'a', 'l', 't', 'e', 'r', '\n',
        'a', 'l', 't', 'e', 'r', 'a', 'b', 'l', 'e', '\n',
        'a', 'l', 't', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'l', 't', 'e', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'l', 't', 'e', 'r', 'c', 'a', 't', 'e', '\n',
        'a', 'l', 't', 'e', 'r', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'l', 't', 'e', 'r', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'l', 't', 'e', 'r', 'e', 'd', '\n',
        'a', 'l', 't', 'e', 'r', 'e', 'g', 'o', '\n',
        'a', 'l', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'a', 'l', 't', 'e', 'r', 'n', 'a', 't', 'e', '\n',
        'a', 'l', 't', 'e', 'r', 'n', 'a', 't', 'e', 'd', '\n',
        'a', 'l', 't', 'e', 'r', 'n', 'a', 't', 'e', 'l', 'y', '\n',
        'a', 'l', 't', 'e', 'r', 'n', 'a', 't', 'e', 's', '\n',
        'a', 'l', 't', 'e', 'r', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'l', 't', 'e', 'r', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'l', 't', 'e', 'r', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'l', 't', 'e', 'r', 'n', 'a', 't', 'i', 'v', 'e', '\n',
        'a', 'l', 't', 'e', 'r', 'n', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'a', 'l', 't', 'e', 'r', 'n', 'a', 't', 'i', 'v', 'e', 's', '\n',
        'a', 'l', 't', 'e', 'r', 'n', 'a', 't', 'o', 'r', '\n',
        'a', 'l', 't', 'e', 'r', 'n', 'a', 't', 'o', 'r', 's', '\n',
        'a', 'l', 't', 'e', 'r', 's', '\n',
        'a', 'l', 't', 'h', 'o', 'u', 'g', 'h', '\n',
        'a', 'l', 't', 'i', 'm', 'e', 't', 'e', 'r', '\n',
        'a', 'l', 't', 'i', 'm', 'e', 't', 'e', 'r', 's', '\n',
        'a', 'l', 't', 'i', 't', 'u', 'd', 'e', '\n',
        'a', 'l', 't', 'i', 't', 'u', 'd', 'e', 's', '\n',
        'a', 'l', 't', 'o', '\n',
        'a', 'l', 't', 'o', 'g', 'e', 't', 'h', 'e', 'r', '\n',
        'a', 'l', 't', 'r', 'u', 'i', 's', 'm', '\n',
        'a', 'l', 't', 'r', 'u', 'i', 's', 't', '\n',
        'a', 'l', 't', 'r', 'u', 'i', 's', 't', 'i', 'c', '\n',
        'a', 'l', 't', 'r', 'u', 'i', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 'l', 't', 's', '\n',
        'a', 'l', 'u', 'm', '\n',
        'a', 'l', 'u', 'm', 'i', 'n', 'i', 'u', 'm', '\n',
        'a', 'l', 'u', 'm', 'i', 'n', 'u', 'm', '\n',
        'a', 'l', 'u', 'm', 'n', 'i', '\n',
        'a', 'l', 'u', 'm', 'n', 'u', 's', '\n',
        'a', 'l', 'v', 'e', 'o', 'l', 'a', 'r', '\n',
        'a', 'l', 'v', 'e', 'o', 'l', 'i', '\n',
        'a', 'l', 'w', 'a', 'y', 's', '\n',
        'a', 'm', '\n',
        'a', 'm', 'a', 'l', 'g', 'a', 'm', '\n',
        'a', 'm', 'a', 'l', 'g', 'a', 'm', 'a', 't', 'e', '\n',
        'a', 'm', 'a', 'l', 'g', 'a', 'm', 'a', 't', 'e', 'd', '\n',
        'a', 'm', 'a', 'l', 'g', 'a', 'm', 'a', 't', 'e', 's', '\n',
        'a', 'm', 'a', 'l', 'g', 'a', 'm', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'm', 'a', 'l', 'g', 'a', 'm', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'm', 'a', 'l', 'g', 'a', 'm', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'm', 'a', 'l', 'g', 'a', 'm', 's', '\n',
        'a', 'm', 'a', 'n', 'u', 'e', 'n', 's', 'i', 's', '\n',
        'a', 'm', 'a', 's', 's', '\n',
        'a', 'm', 'a', 's', 's', 'e', 'd', '\n',
        'a', 'm', 'a', 's', 's', 'e', 's', '\n',
        'a', 'm', 'a', 's', 's', 'i', 'n', 'g', '\n',
        'a', 'm', 'a', 't', 'e', 'u', 'r', '\n',
        'a', 'm', 'a', 't', 'e', 'u', 'r', 'i', 's', 'h', '\n',
        'a', 'm', 'a', 't', 'e', 'u', 'r', 'i', 's', 'h', 'l', 'y', '\n',
        'a', 'm', 'a', 't', 'e', 'u', 'r', 'i', 's', 'h', 'n', 'e', 's', 's', '\n',
        'a', 'm', 'a', 't', 'e', 'u', 'r', 'i', 's', 'm', '\n',
        'a', 'm', 'a', 't', 'e', 'u', 'r', 's', '\n',
        'a', 'm', 'a', 't', 'o', 'r', 'y', '\n',
        'a', 'm', 'a', 'z', 'e', '\n',
        'a', 'm', 'a', 'z', 'e', 'd', '\n',
        'a', 'm', 'a', 'z', 'e', 'm', 'e', 'n', 't', '\n',
        'a', 'm', 'a', 'z', 'e', 's', '\n',
        'a', 'm', 'a', 'z', 'i', 'n', 'g', '\n',
        'a', 'm', 'a', 'z', 'i', 'n', 'g', 'l', 'y', '\n',
        'a', 'm', 'a', 'z', 'o', 'n', '\n',
        'a', 'm', 'a', 'z', 'o', 'n', 's', '\n',
        'a', 'm', 'b', 'a', 's', 's', 'a', 'd', 'o', 'r', '\n',
        'a', 'm', 'b', 'a', 's', 's', 'a', 'd', 'o', 'r', 'i', 'a', 'l', '\n',
        'a', 'm', 'b', 'a', 's', 's', 'a', 'd', 'o', 'r', 's', '\n',
        'a', 'm', 'b', 'e', 'r', '\n',
        'a', 'm', 'b', 'e', 'r', 'g', 'r', 'i', 's', '\n',
        'a', 'm', 'b', 'i', 'a', 'n', 'c', 'e', '\n',
        'a', 'm', 'b', 'i', 'd', 'e', 'x', 't', 'r', 'o', 'u', 's', '\n',
        'a', 'm', 'b', 'i', 'e', 'n', 'c', 'e', '\n',
        'a', 'm', 'b', 'i', 'e', 'n', 't', '\n',
        'a', 'm', 'b', 'i', 'g', 'u', 'i', 't', 'i', 'e', 's', '\n',
        'a', 'm', 'b', 'i', 'g', 'u', 'i', 't', 'y', '\n',
        'a', 'm', 'b', 'i', 'g', 'u', 'o', 'u', 's', '\n',
        'a', 'm', 'b', 'i', 'g', 'u', 'o', 'u', 's', 'l', 'y', '\n',
        'a', 'm', 'b', 'i', 't', '\n',
        'a', 'm', 'b', 'i', 't', 'i', 'o', 'n', '\n',
        'a', 'm', 'b', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'm', 'b', 'i', 't', 'i', 'o', 'u', 's', '\n',
        'a', 'm', 'b', 'i', 't', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'a', 'm', 'b', 'i', 'v', 'a', 'l', 'e', 'n', 'c', 'e', '\n',
        'a', 'm', 'b', 'i', 'v', 'a', 'l', 'e', 'n', 't', '\n',
        'a', 'm', 'b', 'i', 'v', 'a', 'l', 'e', 'n', 't', 'l', 'y', '\n',
        'a', 'm', 'b', 'l', 'e', '\n',
        'a', 'm', 'b', 'l', 'e', 'd', '\n',
        'a', 'm', 'b', 'l', 'e', 'r', '\n',
        'a', 'm', 'b', 'l', 'e', 's', '\n',
        'a', 'm', 'b', 'l', 'i', 'n', 'g', '\n',
        'a', 'm', 'b', 'r', 'o', 's', 'i', 'a', '\n',
        'a', 'm', 'b', 'u', 'l', 'a', 'n', 'c', 'e', '\n',
        'a', 'm', 'b', 'u', 'l', 'a', 'n', 'c', 'e', 's', '\n',
        'a', 'm', 'b', 'u', 'l', 'a', 'n', 't', '\n',
        'a', 'm', 'b', 'u', 'l', 'a', 't', 'e', '\n',
        'a', 'm', 'b', 'u', 'l', 'a', 't', 'o', 'r', 'y', '\n',
        'a', 'm', 'b', 'u', 's', 'c', 'a', 'd', 'e', '\n',
        'a', 'm', 'b', 'u', 's', 'c', 'a', 'd', 'e', 's', '\n',
        'a', 'm', 'b', 'u', 's', 'h', '\n',
        'a', 'm', 'b', 'u', 's', 'h', 'e', 'd', '\n',
        'a', 'm', 'b', 'u', 's', 'h', 'e', 'r', 's', '\n',
        'a', 'm', 'b', 'u', 's', 'h', 'e', 's', '\n',
        'a', 'm', 'b', 'u', 's', 'h', 'i', 'n', 'g', '\n',
        'a', 'm', 'e', 'l', 'i', 'o', 'r', 'a', 't', 'e', '\n',
        'a', 'm', 'e', 'l', 'i', 'o', 'r', 'a', 't', 'e', 'd', '\n',
        'a', 'm', 'e', 'l', 'i', 'o', 'r', 'a', 't', 'e', 's', '\n',
        'a', 'm', 'e', 'l', 'i', 'o', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'm', 'e', 'l', 'i', 'o', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'm', 'e', 'n', '\n',
        'a', 'm', 'e', 'n', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'a', 'm', 'e', 'n', 'a', 'b', 'l', 'e', '\n',
        'a', 'm', 'e', 'n', 'd', '\n',
        'a', 'm', 'e', 'n', 'd', 'a', 'b', 'l', 'e', '\n',
        'a', 'm', 'e', 'n', 'd', 'e', 'd', '\n',
        'a', 'm', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'a', 'm', 'e', 'n', 'd', 'm', 'e', 'n', 't', '\n',
        'a', 'm', 'e', 'n', 'd', 'm', 'e', 'n', 't', 's', '\n',
        'a', 'm', 'e', 'n', 'd', 's', '\n',
        'a', 'm', 'e', 'n', 'i', 't', 'i', 'e', 's', '\n',
        'a', 'm', 'e', 'n', 'i', 't', 'y', '\n',
        'a', 'm', 'e', 'n', 'o', 'r', 'r', 'h', 'o', 'e', 'a', '\n',
        'a', 'm', 'e', 'n', 's', '\n',
        'a', 'm', 'e', 'r', 'i', 'c', 'a', '\n',
        'a', 'm', 'e', 'r', 'i', 'c', 'a', 'n', '\n',
        'a', 'm', 'e', 'r', 'i', 'c', 'a', 'n', 's', '\n',
        'a', 'm', 'e', 'r', 'i', 'c', 'i', 'u', 'm', '\n',
        'a', 'm', 'e', 't', 'h', 'y', 's', 't', '\n',
        'a', 'm', 'e', 't', 'h', 'y', 's', 't', 'i', 'n', 'e', '\n',
        'a', 'm', 'e', 't', 'h', 'y', 's', 't', 's', '\n',
        'a', 'm', 'i', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'a', 'm', 'i', 'a', 'b', 'l', 'e', '\n',
        'a', 'm', 'i', 'a', 'b', 'l', 'e', 'n', 'e', 's', 's', '\n',
        'a', 'm', 'i', 'a', 'b', 'l', 'y', '\n',
        'a', 'm', 'i', 'c', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'a', 'm', 'i', 'c', 'a', 'b', 'l', 'e', '\n',
        'a', 'm', 'i', 'c', 'a', 'b', 'l', 'y', '\n',
        'a', 'm', 'i', 'd', '\n',
        'a', 'm', 'i', 'd', 'e', '\n',
        'a', 'm', 'i', 'd', 's', 'h', 'i', 'p', 's', '\n',
        'a', 'm', 'i', 'd', 's', 't', '\n',
        'a', 'm', 'i', 'g', 'o', '\n',
        'a', 'm', 'i', 'n', 'e', '\n',
        'a', 'm', 'i', 'n', 'e', 's', '\n',
        'a', 'm', 'i', 'n', 'o', '\n',
        'a', 'm', 'i', 'r', '\n',
        'a', 'm', 'i', 's', 's', '\n',
        'a', 'm', 'i', 't', 'y', '\n',
        'a', 'm', 'm', 'a', 'n', '\n',
        'a', 'm', 'm', 'e', 't', 'e', 'r', '\n',
        'a', 'm', 'm', 'e', 't', 'e', 'r', 's', '\n',
        'a', 'm', 'm', 'o', '\n',
        'a', 'm', 'm', 'o', 'n', 'i', 'a', '\n',
        'a', 'm', 'm', 'o', 'n', 'i', 't', 'e', 's', '\n',
        'a', 'm', 'm', 'o', 'n', 'i', 'u', 'm', '\n',
        'a', 'm', 'm', 'u', 'n', 'i', 't', 'i', 'o', 'n', '\n',
        'a', 'm', 'n', 'e', 's', 'i', 'a', '\n',
        'a', 'm', 'n', 'e', 's', 'i', 'a', 'c', '\n',
        'a', 'm', 'n', 'e', 's', 'i', 'c', '\n',
        'a', 'm', 'n', 'e', 's', 't', 'i', 'e', 's', '\n',
        'a', 'm', 'n', 'e', 's', 't', 'y', '\n',
        'a', 'm', 'n', 'i', 'o', 't', 'i', 'c', '\n',
        'a', 'm', 'o', 'e', 'b', 'a', '\n',
        'a', 'm', 'o', 'e', 'b', 'a', 'e', '\n',
        'a', 'm', 'o', 'e', 'b', 'i', 'c', '\n',
        'a', 'm', 'o', 'k', '\n',
        'a', 'm', 'o', 'n', 'g', '\n',
        'a', 'm', 'o', 'n', 'g', 's', 't', '\n',
        'a', 'm', 'o', 'r', 'a', 'l', '\n',
        'a', 'm', 'o', 'r', 'a', 'l', 'i', 't', 'y', '\n',
        'a', 'm', 'o', 'r', 'i', 's', 't', '\n',
        'a', 'm', 'o', 'r', 'o', 'u', 's', '\n',
        'a', 'm', 'o', 'r', 'o', 'u', 's', 'l', 'y', '\n',
        'a', 'm', 'o', 'r', 'p', 'h', 'o', 'u', 's', '\n',
        'a', 'm', 'o', 'r', 't', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'm', 'o', 'r', 't', 'i', 's', 'e', '\n',
        'a', 'm', 'o', 'r', 't', 'i', 's', 'e', 'd', '\n',
        'a', 'm', 'o', 'u', 'n', 't', '\n',
        'a', 'm', 'o', 'u', 'n', 't', 'e', 'd', '\n',
        'a', 'm', 'o', 'u', 'n', 't', 'i', 'n', 'g', '\n',
        'a', 'm', 'o', 'u', 'n', 't', 's', '\n',
        'a', 'm', 'o', 'u', 'r', '\n',
        'a', 'm', 'o', 'u', 'r', 's', '\n',
        'a', 'm', 'p', '\n',
        'a', 'm', 'p', 'e', 'r', 'e', '\n',
        'a', 'm', 'p', 'e', 'r', 'e', 's', '\n',
        'a', 'm', 'p', 'e', 'r', 's', 'a', 'n', 'd', '\n',
        'a', 'm', 'p', 'e', 'r', 's', 'a', 'n', 'd', 's', '\n',
        'a', 'm', 'p', 'h', 'e', 't', 'a', 'm', 'i', 'n', 'e', '\n',
        'a', 'm', 'p', 'h', 'e', 't', 'a', 'm', 'i', 'n', 'e', 's', '\n',
        'a', 'm', 'p', 'h', 'i', 'b', 'i', 'a', '\n',
        'a', 'm', 'p', 'h', 'i', 'b', 'i', 'a', 'n', '\n',
        'a', 'm', 'p', 'h', 'i', 'b', 'i', 'a', 'n', 's', '\n',
        'a', 'm', 'p', 'h', 'i', 'b', 'i', 'o', 'u', 's', '\n',
        'a', 'm', 'p', 'h', 'i', 't', 'h', 'e', 'a', 't', 'r', 'e', '\n',
        'a', 'm', 'p', 'h', 'i', 't', 'h', 'e', 'a', 't', 'r', 'e', 's', '\n',
        'a', 'm', 'p', 'h', 'o', 'r', 'a', '\n',
        'a', 'm', 'p', 'l', 'e', '\n',
        'a', 'm', 'p', 'l', 'e', 'r', '\n',
        'a', 'm', 'p', 'l', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'm', 'p', 'l', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'm', 'p', 'l', 'i', 'f', 'i', 'e', 'd', '\n',
        'a', 'm', 'p', 'l', 'i', 'f', 'i', 'e', 'r', '\n',
        'a', 'm', 'p', 'l', 'i', 'f', 'i', 'e', 'r', 's', '\n',
        'a', 'm', 'p', 'l', 'i', 'f', 'i', 'e', 's', '\n',
        'a', 'm', 'p', 'l', 'i', 'f', 'y', '\n',
        'a', 'm', 'p', 'l', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'a', 'm', 'p', 'l', 'i', 't', 'u', 'd', 'e', '\n',
        'a', 'm', 'p', 'l', 'i', 't', 'u', 'd', 'e', 's', '\n',
        'a', 'm', 'p', 'l', 'y', '\n',
        'a', 'm', 'p', 'o', 'u', 'l', 'e', 's', '\n',
        'a', 'm', 'p', 's', '\n',
        'a', 'm', 'p', 'u', 'l', 'e', '\n',
        'a', 'm', 'p', 'u', 'l', 'e', 's', '\n',
        'a', 'm', 'p', 'u', 'l', 's', '\n',
        'a', 'm', 'p', 'u', 't', 'a', 't', 'e', '\n',
        'a', 'm', 'p', 'u', 't', 'a', 't', 'e', 'd', '\n',
        'a', 'm', 'p', 'u', 't', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'm', 'p', 'u', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'm', 'p', 'u', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'm', 'p', 'u', 't', 'e', 'e', '\n',
        'a', 'm', 'p', 'u', 't', 'e', 'e', 's', '\n',
        'a', 'm', 'u', 'c', 'k', '\n',
        'a', 'm', 'u', 'l', 'e', 't', '\n',
        'a', 'm', 'u', 'l', 'e', 't', 's', '\n',
        'a', 'm', 'u', 's', 'e', '\n',
        'a', 'm', 'u', 's', 'e', 'd', '\n',
        'a', 'm', 'u', 's', 'e', 'm', 'e', 'n', 't', '\n',
        'a', 'm', 'u', 's', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'a', 'm', 'u', 's', 'e', 's', '\n',
        'a', 'm', 'u', 's', 'i', 'n', 'g', '\n',
        'a', 'm', 'u', 's', 'i', 'n', 'g', 'l', 'y', '\n',
        'a', 'n', '\n',
        'a', 'n', 'a', '\n',
        'a', 'n', 'a', 'b', 'o', 'l', 'i', 'c', '\n',
        'a', 'n', 'a', 'c', 'h', 'r', 'o', 'n', 'i', 's', 'm', '\n',
        'a', 'n', 'a', 'c', 'h', 'r', 'o', 'n', 'i', 's', 'm', 's', '\n',
        'a', 'n', 'a', 'c', 'h', 'r', 'o', 'n', 'i', 's', 't', 'i', 'c', '\n',
        'a', 'n', 'a', 'c', 'h', 'r', 'o', 'n', 'i', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 'n', 'a', 'c', 'o', 'n', 'd', 'a', '\n',
        'a', 'n', 'a', 'c', 'o', 'n', 'd', 'a', 's', '\n',
        'a', 'n', 'a', 'e', 'm', 'i', 'a', '\n',
        'a', 'n', 'a', 'e', 'm', 'i', 'c', '\n',
        'a', 'n', 'a', 'e', 'r', 'o', 'b', 'i', 'c', '\n',
        'a', 'n', 'a', 'e', 'r', 'o', 'b', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 'n', 'a', 'e', 's', 't', 'h', 'e', 's', 'i', 'a', '\n',
        'a', 'n', 'a', 'e', 's', 't', 'h', 'e', 't', 'i', 'c', '\n',
        'a', 'n', 'a', 'e', 's', 't', 'h', 'e', 't', 'i', 'c', 's', '\n',
        'a', 'n', 'a', 'e', 's', 't', 'h', 'e', 't', 'i', 's', 'e', '\n',
        'a', 'n', 'a', 'e', 's', 't', 'h', 'e', 't', 'i', 's', 'e', 'd', '\n',
        'a', 'n', 'a', 'e', 's', 't', 'h', 'e', 't', 'i', 's', 'i', 'n', 'g', '\n',
        'a', 'n', 'a', 'e', 's', 't', 'h', 'e', 't', 'i', 's', 't', '\n',
        'a', 'n', 'a', 'e', 's', 't', 'h', 'e', 't', 'i', 's', 't', 's', '\n',
        'a', 'n', 'a', 'g', 'r', 'a', 'm', '\n',
        'a', 'n', 'a', 'g', 'r', 'a', 'm', 'm', 'a', 't', 'i', 'c', '\n',
        'a', 'n', 'a', 'g', 'r', 'a', 'm', 'm', 'a', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 'n', 'a', 'g', 'r', 'a', 'm', 's', '\n',
        'a', 'n', 'a', 'l', '\n',
        'a', 'n', 'a', 'l', 'g', 'e', 's', 'i', 'a', '\n',
        'a', 'n', 'a', 'l', 'g', 'e', 's', 'i', 'c', '\n',
        'a', 'n', 'a', 'l', 'g', 'e', 's', 'i', 'c', 's', '\n',
        'a', 'n', 'a', 'l', 'l', 'y', '\n',
        'a', 'n', 'a', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'a', 'n', 'a', 'l', 'o', 'g', 'i', 'e', 's', '\n',
        'a', 'n', 'a', 'l', 'o', 'g', 'i', 's', 'e', '\n',
        'a', 'n', 'a', 'l', 'o', 'g', 'o', 'u', 's', '\n',
        'a', 'n', 'a', 'l', 'o', 'g', 'o', 'u', 's', 'l', 'y', '\n',
        'a', 'n', 'a', 'l', 'o', 'g', 'u', 'e', '\n',
        'a', 'n', 'a', 'l', 'o', 'g', 'u', 'e', 's', '\n',
        'a', 'n', 'a', 'l', 'o', 'g', 'y', '\n',
        'a', 'n', 'a', 'l', 'y', 's', 'a', 'b', 'l', 'e', '\n',
        'a', 'n', 'a', 'l', 'y', 's', 'e', '\n',
        'a', 'n', 'a', 'l', 'y', 's', 'e', 'd', '\n',
        'a', 'n', 'a', 'l', 'y', 's', 'e', 'r', '\n',
        'a', 'n', 'a', 'l', 'y', 's', 'e', 'r', 's', '\n',
        'a', 'n', 'a', 'l', 'y', 's', 'e', 's', '\n',
        'a', 'n', 'a', 'l', 'y', 's', 'i', 'n', 'g', '\n',
        'a', 'n', 'a', 'l', 'y', 's', 'i', 's', '\n',
        'a', 'n', 'a', 'l', 'y', 's', 't', '\n',
        'a', 'n', 'a', 'l', 'y', 's', 't', 's', '\n',
        'a', 'n', 'a', 'l', 'y', 't', 'i', 'c', '\n',
        'a', 'n', 'a', 'l', 'y', 't', 'i', 'c', 'a', 'l', '\n',
        'a', 'n', 'a', 'l', 'y', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 'n', 'a', 'm', 'o', 'r', 'p', 'h', 'i', 'c', '\n',
        'a', 'n', 'a', 'n', 'a', 's', '\n',
        'a', 'n', 'a', 'p', 'h', 'o', 'r', 'a', '\n',
        'a', 'n', 'a', 'p', 'h', 'o', 'r', 'i', 'c', '\n',
        'a', 'n', 'a', 'r', 'c', 'h', 'i', 'c', '\n',
        'a', 'n', 'a', 'r', 'c', 'h', 'i', 'c', 'a', 'l', '\n',
        'a', 'n', 'a', 'r', 'c', 'h', 'i', 's', 'm', '\n',
        'a', 'n', 'a', 'r', 'c', 'h', 'i', 's', 't', '\n',
        'a', 'n', 'a', 'r', 'c', 'h', 'i', 's', 't', 'i', 'c', '\n',
        'a', 'n', 'a', 'r', 'c', 'h', 'i', 's', 't', 's', '\n',
        'a', 'n', 'a', 'r', 'c', 'h', 'y', '\n',
        'a', 'n', 'a', 't', 'h', 'e', 'm', 'a', '\n',
        'a', 'n', 'a', 't', 'o', 'm', 'i', 'c', '\n',
        'a', 'n', 'a', 't', 'o', 'm', 'i', 'c', 'a', 'l', '\n',
        'a', 'n', 'a', 't', 'o', 'm', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 'n', 'a', 't', 'o', 'm', 'i', 'e', 's', '\n',
        'a', 'n', 'a', 't', 'o', 'm', 'i', 's', 't', '\n',
        'a', 'n', 'a', 't', 'o', 'm', 'i', 's', 't', 's', '\n',
        'a', 'n', 'a', 't', 'o', 'm', 'y', '\n',
        'a', 'n', 'c', 'e', 's', 't', 'o', 'r', '\n',
        'a', 'n', 'c', 'e', 's', 't', 'o', 'r', 's', '\n',
        'a', 'n', 'c', 'e', 's', 't', 'r', 'a', 'l', '\n',
        'a', 'n', 'c', 'e', 's', 't', 'r', 'i', 'e', 's', '\n',
        'a', 'n', 'c', 'e', 's', 't', 'r', 'y', '\n',
        'a', 'n', 'c', 'h', 'o', 'r', '\n',
        'a', 'n', 'c', 'h', 'o', 'r', 'a', 'g', 'e', '\n',
        'a', 'n', 'c', 'h', 'o', 'r', 'a', 'g', 'e', 's', '\n',
        'a', 'n', 'c', 'h', 'o', 'r', 'e', 'd', '\n',
        'a', 'n', 'c', 'h', 'o', 'r', 'i', 'n', 'g', '\n',
        'a', 'n', 'c', 'h', 'o', 'r', 'i', 't', 'e', '\n',
        'a', 'n', 'c', 'h', 'o', 'r', 's', '\n',
        'a', 'n', 'c', 'h', 'o', 'v', 'i', 'e', 's', '\n',
        'a', 'n', 'c', 'h', 'o', 'v', 'y', '\n',
        'a', 'n', 'c', 'i', 'e', 'n', 't', '\n',
        'a', 'n', 'c', 'i', 'e', 'n', 't', 'l', 'y', '\n',
        'a', 'n', 'c', 'i', 'e', 'n', 't', 's', '\n',
        'a', 'n', 'c', 'i', 'l', 'l', 'a', 'r', 'y', '\n',
        'a', 'n', 'd', '\n',
        'a', 'n', 'd', 'a', 'n', 't', 'e', '\n',
        'a', 'n', 'd', 'e', 's', '\n',
        'a', 'n', 'd', 'r', 'e', 'w', '\n',
        'a', 'n', 'd', 'r', 'o', 'g', 'y', 'n', 'o', 'u', 's', '\n',
        'a', 'n', 'd', 'r', 'o', 'i', 'd', '\n',
        'a', 'n', 'd', 'r', 'o', 'i', 'd', 's', '\n',
        'a', 'n', 'e', 'c', 'd', 'o', 't', 'a', 'l', '\n',
        'a', 'n', 'e', 'c', 'd', 'o', 't', 'a', 'l', 'l', 'y', '\n',
        'a', 'n', 'e', 'c', 'd', 'o', 't', 'e', '\n',
        'a', 'n', 'e', 'c', 'd', 'o', 't', 'e', 's', '\n',
        'a', 'n', 'e', 'c', 'h', 'o', 'i', 'c', '\n',
        'a', 'n', 'e', 'm', 'i', 'a', '\n',
        'a', 'n', 'e', 'm', 'i', 'c', '\n',
        'a', 'n', 'e', 'm', 'o', 'n', 'e', '\n',
        'a', 'n', 'e', 'm', 'o', 'n', 'e', 's', '\n',
        'a', 'n', 'e', 'r', 'g', 'y', '\n',
        'a', 'n', 'e', 'r', 'o', 'i', 'd', '\n',
        'a', 'n', 'e', 'u', 'r', 'y', 's', 'm', '\n',
        'a', 'n', 'e', 'u', 'r', 'y', 's', 'm', 's', '\n',
        'a', 'n', 'e', 'w', '\n',
        'a', 'n', 'g', 'e', 'l', '\n',
        'a', 'n', 'g', 'e', 'l', 'i', 'c', '\n',
        'a', 'n', 'g', 'e', 'l', 'i', 'c', 'a', '\n',
        'a', 'n', 'g', 'e', 'l', 's', '\n',
        'a', 'n', 'g', 'e', 'l', 'u', 's', '\n',
        'a', 'n', 'g', 'e', 'r', '\n',
        'a', 'n', 'g', 'e', 'r', 'e', 'd', '\n',
        'a', 'n', 'g', 'e', 'r', 'i', 'n', 'g', '\n',
        'a', 'n', 'g', 'e', 'r', 's', '\n',
        'a', 'n', 'g', 'i', 'n', 'a', '\n',
        'a', 'n', 'g', 'i', 'n', 'a', 'l', '\n',
        'a', 'n', 'g', 'i', 'o', 'p', 'l', 'a', 's', 't', 'y', '\n',
        'a', 'n', 'g', 'l', 'e', '\n',
        'a', 'n', 'g', 'l', 'e', 'd', '\n',
        'a', 'n', 'g', 'l', 'e', 'p', 'o', 'i', 's', 'e', '\n',
        'a', 'n', 'g', 'l', 'e', 'r', '\n',
        'a', 'n', 'g', 'l', 'e', 'r', 's', '\n',
        'a', 'n', 'g', 'l', 'e', 's', '\n',
        'a', 'n', 'g', 'l', 'i', 'a', 'n', '\n',
        'a', 'n', 'g', 'l', 'i', 'c', 'a', 'n', '\n',
        'a', 'n', 'g', 'l', 'i', 'n', 'g', '\n',
        'a', 'n', 'g', 'o', 'l', 'a', '\n',
        'a', 'n', 'g', 'o', 'l', 'a', 'n', '\n',
        'a', 'n', 'g', 'o', 'l', 'a', 'n', 's', '\n',
        'a', 'n', 'g', 'o', 'r', 'a', '\n',
        'a', 'n', 'g', 'o', 'r', 'a', 's', '\n',
        'a', 'n', 'g', 'r', 'i', 'e', 'r', '\n',
        'a', 'n', 'g', 'r', 'i', 'e', 's', 't', '\n',
        'a', 'n', 'g', 'r', 'i', 'l', 'y', '\n',
        'a', 'n', 'g', 'r', 'y', '\n',
        'a', 'n', 'g', 's', 't', '\n',
        'a', 'n', 'g', 's', 't', 'r', 'o', 'm', 's', '\n',
        'a', 'n', 'g', 'u', 'i', 's', 'h', '\n',
        'a', 'n', 'g', 'u', 'i', 's', 'h', 'e', 'd', '\n',
        'a', 'n', 'g', 'u', 'i', 's', 'h', 'e', 's', '\n',
        'a', 'n', 'g', 'u', 'l', 'a', 'r', '\n',
        'a', 'n', 'g', 'u', 'l', 'a', 'r', 'i', 't', 'y', '\n',
        'a', 'n', 'h', 'y', 'd', 'r', 'o', 'u', 's', '\n',
        'a', 'n', 'i', 'l', '\n',
        'a', 'n', 'i', 'l', 'i', 'n', 'e', '\n',
        'a', 'n', 'i', 'm', 'a', 'l', '\n',
        'a', 'n', 'i', 'm', 'a', 'l', 's', '\n',
        'a', 'n', 'i', 'm', 'a', 't', 'e', '\n',
        'a', 'n', 'i', 'm', 'a', 't', 'e', 'd', '\n',
        'a', 'n', 'i', 'm', 'a', 't', 'e', 'd', 'l', 'y', '\n',
        'a', 'n', 'i', 'm', 'a', 't', 'e', 's', '\n',
        'a', 'n', 'i', 'm', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'n', 'i', 'm', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'n', 'i', 'm', 'a', 't', 'o', 'r', '\n',
        'a', 'n', 'i', 'm', 'a', 't', 'o', 'r', 's', '\n',
        'a', 'n', 'i', 'm', 'i', 's', 'm', '\n',
        'a', 'n', 'i', 'm', 'i', 's', 't', '\n',
        'a', 'n', 'i', 'm', 'i', 's', 't', 's', '\n',
        'a', 'n', 'i', 'm', 'o', 's', 'i', 't', 'i', 'e', 's', '\n',
        'a', 'n', 'i', 'm', 'o', 's', 'i', 't', 'y', '\n',
        'a', 'n', 'i', 'm', 'u', 's', '\n',
        'a', 'n', 'i', 'o', 'n', '\n',
        'a', 'n', 'i', 'o', 'n', 'i', 'c', '\n',
        'a', 'n', 'i', 'o', 'n', 's', '\n',
        'a', 'n', 'i', 's', 'e', '\n',
        'a', 'n', 'i', 's', 'e', 'e', 'd', '\n',
        'a', 'n', 'i', 's', 'e', 'e', 'd', 's', '\n',
        'a', 'n', 'i', 's', 'o', 't', 'r', 'o', 'p', 'i', 'c', '\n',
        'a', 'n', 'i', 's', 'o', 't', 'r', 'o', 'p', 'i', 'e', 's', '\n',
        'a', 'n', 'i', 's', 'o', 't', 'r', 'o', 'p', 'y', '\n',
        'a', 'n', 'k', 'a', 'r', 'a', '\n',
        'a', 'n', 'k', 'l', 'e', '\n',
        'a', 'n', 'k', 'l', 'e', 's', '\n',
        'a', 'n', 'k', 'l', 'e', 't', '\n',
        'a', 'n', 'k', 'l', 'e', 't', 's', '\n',
        'a', 'n', 'n', 'a', '\n',
        'a', 'n', 'n', 'a', 'l', '\n',
        'a', 'n', 'n', 'a', 'l', 's', '\n',
        'a', 'n', 'n', 'e', 'a', 'l', '\n',
        'a', 'n', 'n', 'e', 'a', 'l', 'e', 'd', '\n',
        'a', 'n', 'n', 'e', 'a', 'l', 'e', 'r', '\n',
        'a', 'n', 'n', 'e', 'a', 'l', 'i', 'n', 'g', '\n',
        'a', 'n', 'n', 'e', 'x', '\n',
        'a', 'n', 'n', 'e', 'x', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'n', 'n', 'e', 'x', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'n', 'n', 'e', 'x', 'e', '\n',
        'a', 'n', 'n', 'e', 'x', 'e', 'd', '\n',
        'a', 'n', 'n', 'e', 'x', 'e', 's', '\n',
        'a', 'n', 'n', 'e', 'x', 'i', 'n', 'g', '\n',
        'a', 'n', 'n', 'i', 'h', 'i', 'l', 'a', 't', 'e', '\n',
        'a', 'n', 'n', 'i', 'h', 'i', 'l', 'a', 't', 'e', 'd', '\n',
        'a', 'n', 'n', 'i', 'h', 'i', 'l', 'a', 't', 'e', 's', '\n',
        'a', 'n', 'n', 'i', 'h', 'i', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'n', 'n', 'i', 'h', 'i', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'n', 'n', 'i', 'v', 'e', 'r', 's', 'a', 'r', 'i', 'e', 's', '\n',
        'a', 'n', 'n', 'i', 'v', 'e', 'r', 's', 'a', 'r', 'y', '\n',
        'a', 'n', 'n', 'o', 't', 'a', 't', 'e', '\n',
        'a', 'n', 'n', 'o', 't', 'a', 't', 'e', 'd', '\n',
        'a', 'n', 'n', 'o', 't', 'a', 't', 'e', 's', '\n',
        'a', 'n', 'n', 'o', 't', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'n', 'n', 'o', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'n', 'n', 'o', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'n', 'n', 'o', 'u', 'n', 'c', 'e', '\n',
        'a', 'n', 'n', 'o', 'u', 'n', 'c', 'e', 'd', '\n',
        'a', 'n', 'n', 'o', 'u', 'n', 'c', 'e', 'm', 'e', 'n', 't', '\n',
        'a', 'n', 'n', 'o', 'u', 'n', 'c', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'a', 'n', 'n', 'o', 'u', 'n', 'c', 'e', 'r', '\n',
        'a', 'n', 'n', 'o', 'u', 'n', 'c', 'e', 'r', 's', '\n',
        'a', 'n', 'n', 'o', 'u', 'n', 'c', 'e', 's', '\n',
        'a', 'n', 'n', 'o', 'u', 'n', 'c', 'i', 'n', 'g', '\n',
        'a', 'n', 'n', 'o', 'y', '\n',
        'a', 'n', 'n', 'o', 'y', 'a', 'n', 'c', 'e', '\n',
        'a', 'n', 'n', 'o', 'y', 'a', 'n', 'c', 'e', 's', '\n',
        'a', 'n', 'n', 'o', 'y', 'e', 'd', '\n',
        'a', 'n', 'n', 'o', 'y', 'e', 'r', '\n',
        'a', 'n', 'n', 'o', 'y', 'e', 'r', 's', '\n',
        'a', 'n', 'n', 'o', 'y', 'i', 'n', 'g', '\n',
        'a', 'n', 'n', 'o', 'y', 'i', 'n', 'g', 'l', 'y', '\n',
        'a', 'n', 'n', 'o', 'y', 's', '\n',
        'a', 'n', 'n', 'u', 'a', 'l', '\n',
        'a', 'n', 'n', 'u', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'a', 'n', 'n', 'u', 'a', 'l', 'l', 'y', '\n',
        'a', 'n', 'n', 'u', 'a', 'l', 's', '\n',
        'a', 'n', 'n', 'u', 'i', 't', 'i', 'e', 's', '\n',
        'a', 'n', 'n', 'u', 'i', 't', 'y', '\n',
        'a', 'n', 'n', 'u', 'l', '\n',
        'a', 'n', 'n', 'u', 'l', 'a', 'r', '\n',
        'a', 'n', 'n', 'u', 'l', 'i', '\n',
        'a', 'n', 'n', 'u', 'l', 'l', 'e', 'd', '\n',
        'a', 'n', 'n', 'u', 'l', 'l', 'i', 'n', 'g', '\n',
        'a', 'n', 'n', 'u', 'l', 'm', 'e', 'n', 't', '\n',
        'a', 'n', 'n', 'u', 'l', 's', '\n',
        'a', 'n', 'n', 'u', 'l', 'u', 's', '\n',
        'a', 'n', 'n', 'u', 'n', 'c', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'n', 'o', 'd', 'e', '\n',
        'a', 'n', 'o', 'd', 'e', 's', '\n',
        'a', 'n', 'o', 'd', 'i', 's', 'e', 'd', '\n',
        'a', 'n', 'o', 'd', 'y', 'n', 'e', '\n',
        'a', 'n', 'o', 'i', 'n', 't', '\n',
        'a', 'n', 'o', 'i', 'n', 't', 'e', 'd', '\n',
        'a', 'n', 'o', 'i', 'n', 't', 'i', 'n', 'g', '\n',
        'a', 'n', 'o', 'i', 'n', 't', 's', '\n',
        'a', 'n', 'o', 'm', 'a', 'l', 'i', 'e', 's', '\n',
        'a', 'n', 'o', 'm', 'a', 'l', 'o', 'u', 's', '\n',
        'a', 'n', 'o', 'm', 'a', 'l', 'o', 'u', 's', 'l', 'y', '\n',
        'a', 'n', 'o', 'm', 'a', 'l', 'y', '\n',
        'a', 'n', 'o', 'm', 'i', 'c', '\n',
        'a', 'n', 'o', 'n', '\n',
        'a', 'n', 'o', 'n', 'y', 'm', '\n',
        'a', 'n', 'o', 'n', 'y', 'm', 'i', 't', 'y', '\n',
        'a', 'n', 'o', 'n', 'y', 'm', 'o', 'u', 's', '\n',
        'a', 'n', 'o', 'n', 'y', 'm', 'o', 'u', 's', 'l', 'y', '\n',
        'a', 'n', 'o', 'n', 'y', 'm', 's', '\n',
        'a', 'n', 'o', 'r', 'a', 'k', '\n',
        'a', 'n', 'o', 'r', 'a', 'k', 's', '\n',
        'a', 'n', 'o', 'r', 'e', 'x', 'i', 'a', '\n',
        'a', 'n', 'o', 'r', 'e', 'x', 'i', 'c', '\n',
        'a', 'n', 'o', 't', 'h', 'e', 'r', '\n',
        'a', 'n', 's', 'w', 'e', 'r', '\n',
        'a', 'n', 's', 'w', 'e', 'r', 'a', 'b', 'l', 'e', '\n',
        'a', 'n', 's', 'w', 'e', 'r', 'e', 'd', '\n',
        'a', 'n', 's', 'w', 'e', 'r', 'e', 'r', '\n',
        'a', 'n', 's', 'w', 'e', 'r', 'i', 'n', 'g', '\n',
        'a', 'n', 's', 'w', 'e', 'r', 's', '\n',
        'a', 'n', 't', '\n',
        'a', 'n', 't', 'a', 'c', 'i', 'd', '\n',
        'a', 'n', 't', 'a', 'c', 'i', 'd', 's', '\n',
        'a', 'n', 't', 'a', 'g', 'o', 'n', 'i', 's', 'e', '\n',
        'a', 'n', 't', 'a', 'g', 'o', 'n', 'i', 's', 'e', 'd', '\n',
        'a', 'n', 't', 'a', 'g', 'o', 'n', 'i', 's', 'e', 's', '\n',
        'a', 'n', 't', 'a', 'g', 'o', 'n', 'i', 's', 'i', 'n', 'g', '\n',
        'a', 'n', 't', 'a', 'g', 'o', 'n', 'i', 's', 'm', '\n',
        'a', 'n', 't', 'a', 'g', 'o', 'n', 'i', 's', 'm', 's', '\n',
        'a', 'n', 't', 'a', 'g', 'o', 'n', 'i', 's', 't', '\n',
        'a', 'n', 't', 'a', 'g', 'o', 'n', 'i', 's', 't', 'i', 'c', '\n',
        'a', 'n', 't', 'a', 'g', 'o', 'n', 'i', 's', 't', 's', '\n',
        'a', 'n', 't', 'e', '\n',
        'a', 'n', 't', 'e', 'a', 't', 'e', 'r', '\n',
        'a', 'n', 't', 'e', 'a', 't', 'e', 'r', 's', '\n',
        'a', 'n', 't', 'e', 'c', 'e', 'd', 'e', 'n', 't', '\n',
        'a', 'n', 't', 'e', 'c', 'e', 'd', 'e', 'n', 't', 's', '\n',
        'a', 'n', 't', 'e', 'c', 'h', 'a', 'm', 'b', 'e', 'r', '\n',
        'a', 'n', 't', 'e', 'd', 'a', 't', 'e', '\n',
        'a', 'n', 't', 'e', 'd', 'a', 't', 'e', 's', '\n',
        'a', 'n', 't', 'e', 'd', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'n', 't', 'e', 'd', 'i', 'l', 'u', 'v', 'i', 'a', 'n', '\n',
        'a', 'n', 't', 'e', 'l', 'o', 'p', 'e', '\n',
        'a', 'n', 't', 'e', 'l', 'o', 'p', 'e', 's', '\n',
        'a', 'n', 't', 'e', 'n', 'a', 't', 'a', 'l', '\n',
        'a', 'n', 't', 'e', 'n', 'n', 'a', '\n',
        'a', 'n', 't', 'e', 'n', 'n', 'a', 'e', '\n',
        'a', 'n', 't', 'e', 'n', 'n', 'a', 's', '\n',
        'a', 'n', 't', 'e', 'r', 'i', 'o', 'r', '\n',
        'a', 'n', 't', 'e', 'r', 'i', 'o', 'r', 'l', 'y', '\n',
        'a', 'n', 't', 'e', 'r', 'o', 'o', 'm', '\n',
        'a', 'n', 't', 'h', 'e', 'm', '\n',
        'a', 'n', 't', 'h', 'e', 'm', 's', '\n',
        'a', 'n', 't', 'h', 'e', 'r', '\n',
        'a', 'n', 't', 'h', 'o', 'l', 'o', 'g', 'i', 'e', 's', '\n',
        'a', 'n', 't', 'h', 'o', 'l', 'o', 'g', 'i', 's', 'e', '\n',
        'a', 'n', 't', 'h', 'o', 'l', 'o', 'g', 'i', 's', 'e', 'd', '\n',
        'a', 'n', 't', 'h', 'o', 'l', 'o', 'g', 'y', '\n',
        'a', 'n', 't', 'h', 'r', 'a', 'c', 'i', 't', 'e', '\n',
        'a', 'n', 't', 'h', 'r', 'a', 'x', '\n',
        'a', 'n', 't', 'h', 'r', 'o', 'p', 'i', 'c', '\n',
        'a', 'n', 't', 'h', 'r', 'o', 'p', 'o', 'c', 'e', 'n', 't', 'r', 'i', 'c', '\n',
        'a', 'n', 't', 'h', 'r', 'o', 'p', 'o', 'g', 'e', 'n', 'i', 'c', '\n',
        'a', 'n', 't', 'h', 'r', 'o', 'p', 'o', 'g', 'e', 'n', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 'n', 't', 'h', 'r', 'o', 'p', 'o', 'i', 'd', '\n',
        'a', 'n', 't', 'h', 'r', 'o', 'p', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'a', 'n', 't', 'h', 'r', 'o', 'p', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'a', 'n', 't', 'h', 'r', 'o', 'p', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'a', 'n', 't', 'h', 'r', 'o', 'p', 'o', 'l', 'o', 'g', 'y', '\n',
        'a', 'n', 't', 'h', 'r', 'o', 'p', 'o', 'm', 'e', 't', 'r', 'i', 'c', '\n',
        'a', 'n', 't', 'h', 'r', 'o', 'p', 'o', 'm', 'o', 'r', 'p', 'h', 'i', 'c', '\n',
        'a', 'n', 't', 'h', 'r', 'o', 'p', 'o', 'm', 'o', 'r', 'p', 'h', 'i', 's', 'i', 'n', 'g', '\n',
        'a', 'n', 't', 'h', 'r', 'o', 'p', 'o', 'm', 'o', 'r', 'p', 'h', 'i', 's', 'm', '\n',
        'a', 'n', 't', 'i', '\n',
        'a', 'n', 't', 'i', 'a', 'b', 'o', 'r', 't', 'i', 'o', 'n', 'i', 's', 't', 's', '\n',
        'a', 'n', 't', 'i', 'a', 'i', 'r', 'c', 'r', 'a', 'f', 't', '\n',
        'a', 'n', 't', 'i', 'b', 'i', 'o', 't', 'i', 'c', '\n',
        'a', 'n', 't', 'i', 'b', 'i', 'o', 't', 'i', 'c', 's', '\n',
        'a', 'n', 't', 'i', 'b', 'o', 'd', 'i', 'e', 's', '\n',
        'a', 'n', 't', 'i', 'b', 'o', 'd', 'y', '\n',
        'a', 'n', 't', 'i', 'c', '\n',
        'a', 'n', 't', 'i', 'c', 'i', 'p', 'a', 't', 'e', '\n',
        'a', 'n', 't', 'i', 'c', 'i', 'p', 'a', 't', 'e', 'd', '\n',
        'a', 'n', 't', 'i', 'c', 'i', 'p', 'a', 't', 'e', 's', '\n',
        'a', 'n', 't', 'i', 'c', 'i', 'p', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'n', 't', 'i', 'c', 'i', 'p', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'n', 't', 'i', 'c', 'i', 'p', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'n', 't', 'i', 'c', 'i', 'p', 'a', 't', 'i', 'v', 'e', '\n',
        'a', 'n', 't', 'i', 'c', 'i', 'p', 'a', 't', 'o', 'r', 'y', '\n',
        'a', 'n', 't', 'i', 'c', 'l', 'i', 'm', 'a', 'x', '\n',
        'a', 'n', 't', 'i', 'c', 'l', 'o', 'c', 'k', 'w', 'i', 's', 'e', '\n',
        'a', 'n', 't', 'i', 'c', 'o', 'a', 'g', 'u', 'l', 'a', 'n', 't', 's', '\n',
        'a', 'n', 't', 'i', 'c', 'o', 'n', 's', 't', 'i', 't', 'u', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'a', 'n', 't', 'i', 'c', 's', '\n',
        'a', 'n', 't', 'i', 'c', 'y', 'c', 'l', 'o', 'n', 'e', '\n',
        'a', 'n', 't', 'i', 'd', 'e', 'p', 'r', 'e', 's', 's', 'a', 'n', 't', '\n',
        'a', 'n', 't', 'i', 'd', 'e', 'p', 'r', 'e', 's', 's', 'a', 'n', 't', 's', '\n',
        'a', 'n', 't', 'i', 'd', 'o', 't', 'e', '\n',
        'a', 'n', 't', 'i', 'd', 'o', 't', 'e', 's', '\n',
        'a', 'n', 't', 'i', 'f', 'r', 'e', 'e', 'z', 'e', '\n',
        'a', 'n', 't', 'i', 'g', 'e', 'n', '\n',
        'a', 'n', 't', 'i', 'g', 'e', 'n', 'i', 'c', '\n',
        'a', 'n', 't', 'i', 'g', 'e', 'n', 's', '\n',
        'a', 'n', 't', 'i', 'h', 'i', 's', 't', 'a', 'm', 'i', 'n', 'e', 's', '\n',
        'a', 'n', 't', 'i', 'l', 'o', 'p', 'e', '\n',
        'a', 'n', 't', 'i', 'm', 'a', 't', 't', 'e', 'r', '\n',
        'a', 'n', 't', 'i', 'm', 'o', 'n', 'y', '\n',
        'a', 'n', 't', 'i', 'o', 'x', 'i', 'd', 'a', 'n', 't', 's', '\n',
        'a', 'n', 't', 'i', 'p', 'a', 'r', 't', 'i', 'c', 'l', 'e', 's', '\n',
        'a', 'n', 't', 'i', 'p', 'a', 't', 'h', 'e', 't', 'i', 'c', '\n',
        'a', 'n', 't', 'i', 'p', 'a', 't', 'h', 'i', 'e', 's', '\n',
        'a', 'n', 't', 'i', 'p', 'a', 't', 'h', 'y', '\n',
        'a', 'n', 't', 'i', 'p', 'o', 'd', 'e', 's', '\n',
        'a', 'n', 't', 'i', 'q', 'u', 'a', 'r', 'i', 'a', 'n', '\n',
        'a', 'n', 't', 'i', 'q', 'u', 'a', 'r', 'i', 'a', 'n', 'i', 's', 'm', '\n',
        'a', 'n', 't', 'i', 'q', 'u', 'a', 'r', 'i', 'a', 'n', 's', '\n',
        'a', 'n', 't', 'i', 'q', 'u', 'a', 'r', 'i', 'e', 's', '\n',
        'a', 'n', 't', 'i', 'q', 'u', 'a', 'r', 'y', '\n',
        'a', 'n', 't', 'i', 'q', 'u', 'a', 't', 'e', 'd', '\n',
        'a', 'n', 't', 'i', 'q', 'u', 'e', '\n',
        'a', 'n', 't', 'i', 'q', 'u', 'e', 's', '\n',
        'a', 'n', 't', 'i', 'q', 'u', 'i', 't', 'i', 'e', 's', '\n',
        'a', 'n', 't', 'i', 'q', 'u', 'i', 't', 'y', '\n',
        'a', 'n', 't', 'i', 's', 'e', 'p', 't', 'i', 'c', '\n',
        'a', 'n', 't', 'i', 's', 'e', 'p', 't', 'i', 'c', 's', '\n',
        'a', 'n', 't', 'i', 's', 'o', 'c', 'i', 'a', 'l', '\n',
        'a', 'n', 't', 'i', 's', 't', 'a', 't', 'i', 'c', '\n',
        'a', 'n', 't', 'i', 's', 'y', 'm', 'm', 'e', 't', 'r', 'i', 'c', '\n',
        'a', 'n', 't', 'i', 's', 'y', 'm', 'm', 'e', 't', 'r', 'y', '\n',
        'a', 'n', 't', 'i', 't', 'h', 'e', 's', 'e', 's', '\n',
        'a', 'n', 't', 'i', 't', 'h', 'e', 's', 'i', 's', '\n',
        'a', 'n', 't', 'i', 't', 'h', 'e', 't', 'i', 'c', '\n',
        'a', 'n', 't', 'i', 't', 'h', 'e', 't', 'i', 'c', 'a', 'l', '\n',
        'a', 'n', 't', 'i', 't', 'h', 'e', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 'n', 't', 'i', 't', 'r', 'u', 's', 't', '\n',
        'a', 'n', 't', 'i', 'v', 'i', 'r', 'a', 'l', '\n',
        'a', 'n', 't', 'l', 'e', 'r', '\n',
        'a', 'n', 't', 'l', 'e', 'r', 's', '\n',
        'a', 'n', 't', 'l', 'i', 'o', 'n', '\n',
        'a', 'n', 't', 'l', 'i', 'o', 'n', 's', '\n',
        'a', 'n', 't', 'o', 'n', 'y', 'm', '\n',
        'a', 'n', 't', 'o', 'n', 'y', 'm', 's', '\n',
        'a', 'n', 't', 'r', 'a', 'l', '\n',
        'a', 'n', 't', 'r', 'u', 'm', '\n',
        'a', 'n', 't', 's', '\n',
        'a', 'n', 't', 'w', 'e', 'r', 'p', '\n',
        'a', 'n', 'u', 's', '\n',
        'a', 'n', 'v', 'i', 'l', '\n',
        'a', 'n', 'v', 'i', 'l', 's', '\n',
        'a', 'n', 'x', 'i', 'e', 't', 'i', 'e', 's', '\n',
        'a', 'n', 'x', 'i', 'e', 't', 'y', '\n',
        'a', 'n', 'x', 'i', 'o', 'u', 's', '\n',
        'a', 'n', 'x', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'a', 'n', 'y', '\n',
        'a', 'n', 'y', 'b', 'o', 'd', 'y', '\n',
        'a', 'n', 'y', 'h', 'o', 'w', '\n',
        'a', 'n', 'y', 'm', 'o', 'r', 'e', '\n',
        'a', 'n', 'y', 'o', 'n', 'e', '\n',
        'a', 'n', 'y', 'p', 'l', 'a', 'c', 'e', '\n',
        'a', 'n', 'y', 't', 'h', 'i', 'n', 'g', '\n',
        'a', 'n', 'y', 'w', 'a', 'y', '\n',
        'a', 'n', 'y', 'w', 'a', 'y', 's', '\n',
        'a', 'n', 'y', 'w', 'h', 'e', 'r', 'e', '\n',
        'a', 'o', 'r', 'i', 's', 't', '\n',
        'a', 'o', 'r', 't', 'a', '\n',
        'a', 'o', 'r', 't', 'a', 's', '\n',
        'a', 'o', 'r', 't', 'i', 'c', '\n',
        'a', 'p', 'a', 'c', 'e', '\n',
        'a', 'p', 'a', 'c', 'h', 'e', '\n',
        'a', 'p', 'a', 'c', 'h', 'e', 's', '\n',
        'a', 'p', 'a', 'r', 't', '\n',
        'a', 'p', 'a', 'r', 't', 'm', 'e', 'n', 't', '\n',
        'a', 'p', 'a', 'r', 't', 'm', 'e', 'n', 't', 's', '\n',
        'a', 'p', 'a', 'r', 't', 'n', 'e', 's', 's', '\n',
        'a', 'p', 'a', 't', 'h', 'e', 't', 'i', 'c', '\n',
        'a', 'p', 'a', 't', 'h', 'e', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 'p', 'a', 't', 'h', 'y', '\n',
        'a', 'p', 'e', '\n',
        'a', 'p', 'e', 'd', '\n',
        'a', 'p', 'e', 'm', 'a', 'n', '\n',
        'a', 'p', 'e', 'r', 'i', 'e', 's', '\n',
        'a', 'p', 'e', 'r', 'i', 'o', 'd', 'i', 'c', '\n',
        'a', 'p', 'e', 'r', 'i', 'o', 'd', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 'p', 'e', 'r', 'i', 't', 'i', 'f', '\n',
        'a', 'p', 'e', 'r', 'i', 't', 'i', 'f', 's', '\n',
        'a', 'p', 'e', 'r', 't', 'u', 'r', 'e', '\n',
        'a', 'p', 'e', 'r', 't', 'u', 'r', 'e', 's', '\n',
        'a', 'p', 'e', 'r', 'y', '\n',
        'a', 'p', 'e', 's', '\n',
        'a', 'p', 'e', 'x', '\n',
        'a', 'p', 'h', 'a', 's', 'i', 'a', '\n',
        'a', 'p', 'h', 'e', 'l', 'i', 'o', 'n', '\n',
        'a', 'p', 'h', 'i', 'd', '\n',
        'a', 'p', 'h', 'i', 'd', 's', '\n',
        'a', 'p', 'h', 'o', 'r', 'i', 's', 'm', '\n',
        'a', 'p', 'h', 'o', 'r', 'i', 's', 'm', 's', '\n',
        'a', 'p', 'h', 'o', 'r', 'i', 's', 't', '\n',
        'a', 'p', 'h', 'o', 'r', 'i', 's', 't', 'i', 'c', '\n',
        'a', 'p', 'h', 'r', 'o', 'd', 'i', 's', 'i', 'a', 'c', '\n',
        'a', 'p', 'h', 'r', 'o', 'd', 'i', 's', 'i', 'a', 'c', 's', '\n',
        'a', 'p', 'i', 'a', 'n', '\n',
        'a', 'p', 'i', 'a', 'r', 'i', 'e', 's', '\n',
        'a', 'p', 'i', 'a', 'r', 'i', 's', 't', '\n',
        'a', 'p', 'i', 'a', 'r', 'y', '\n',
        'a', 'p', 'i', 'e', 'c', 'e', '\n',
        'a', 'p', 'i', 'n', 'g', '\n',
        'a', 'p', 'i', 's', '\n',
        'a', 'p', 'i', 's', 'h', '\n',
        'a', 'p', 'l', 'e', 'n', 't', 'y', '\n',
        'a', 'p', 'l', 'o', 'm', 'b', '\n',
        'a', 'p', 'n', 'e', 'a', '\n',
        'a', 'p', 'n', 'o', 'e', 'a', '\n',
        'a', 'p', 'o', 'c', 'a', 'l', 'y', 'p', 's', 'e', '\n',
        'a', 'p', 'o', 'c', 'a', 'l', 'y', 'p', 't', 'i', 'c', '\n',
        'a', 'p', 'o', 'c', 'r', 'y', 'p', 'h', 'a', 'l', '\n',
        'a', 'p', 'o', 'g', 'e', 'e', '\n',
        'a', 'p', 'o', 'l', 'i', 't', 'i', 'c', 'a', 'l', '\n',
        'a', 'p', 'o', 'l', 'l', 'o', '\n',
        'a', 'p', 'o', 'l', 'o', 'g', 'e', 't', 'i', 'c', '\n',
        'a', 'p', 'o', 'l', 'o', 'g', 'e', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 'p', 'o', 'l', 'o', 'g', 'i', 'a', '\n',
        'a', 'p', 'o', 'l', 'o', 'g', 'i', 'e', 's', '\n',
        'a', 'p', 'o', 'l', 'o', 'g', 'i', 's', 'e', '\n',
        'a', 'p', 'o', 'l', 'o', 'g', 'i', 's', 'e', 'd', '\n',
        'a', 'p', 'o', 'l', 'o', 'g', 'i', 's', 'e', 's', '\n',
        'a', 'p', 'o', 'l', 'o', 'g', 'i', 's', 'i', 'n', 'g', '\n',
        'a', 'p', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'a', 'p', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'a', 'p', 'o', 'l', 'o', 'g', 'y', '\n',
        'a', 'p', 'o', 'p', 'l', 'e', 'c', 't', 'i', 'c', '\n',
        'a', 'p', 'o', 'p', 'l', 'e', 'x', 'y', '\n',
        'a', 'p', 'o', 's', 't', 'a', 's', 'y', '\n',
        'a', 'p', 'o', 's', 't', 'a', 't', 'e', '\n',
        'a', 'p', 'o', 's', 't', 'a', 't', 'e', 's', '\n',
        'a', 'p', 'o', 's', 't', 'l', 'e', '\n',
        'a', 'p', 'o', 's', 't', 'l', 'e', 's', '\n',
        'a', 'p', 'o', 's', 't', 'o', 'l', 'a', 't', 'e', '\n',
        'a', 'p', 'o', 's', 't', 'o', 'l', 'i', 'c', '\n',
        'a', 'p', 'o', 's', 't', 'r', 'o', 'p', 'h', 'e', '\n',
        'a', 'p', 'o', 's', 't', 'r', 'o', 'p', 'h', 'e', 's', '\n',
        'a', 'p', 'o', 's', 't', 'r', 'o', 'p', 'h', 'i', 's', 'e', 'd', '\n',
        'a', 'p', 'o', 't', 'h', 'e', 'c', 'a', 'r', 'i', 'e', 's', '\n',
        'a', 'p', 'o', 't', 'h', 'e', 'c', 'a', 'r', 'y', '\n',
        'a', 'p', 'o', 't', 'h', 'e', 'o', 's', 'i', 's', '\n',
        'a', 'p', 'p', 'a', 'l', '\n',
        'a', 'p', 'p', 'a', 'l', 'l', 'e', 'd', '\n',
        'a', 'p', 'p', 'a', 'l', 'l', 'i', 'n', 'g', '\n',
        'a', 'p', 'p', 'a', 'l', 'l', 'i', 'n', 'g', 'l', 'y', '\n',
        'a', 'p', 'p', 'a', 'l', 's', '\n',
        'a', 'p', 'p', 'a', 'r', 'a', 't', 'c', 'h', 'i', 'k', '\n',
        'a', 'p', 'p', 'a', 'r', 'a', 't', 'c', 'h', 'i', 'k', 's', '\n',
        'a', 'p', 'p', 'a', 'r', 'a', 't', 'u', 's', '\n',
        'a', 'p', 'p', 'a', 'r', 'a', 't', 'u', 's', 'e', 's', '\n',
        'a', 'p', 'p', 'a', 'r', 'e', 'l', '\n',
        'a', 'p', 'p', 'a', 'r', 'e', 'l', 'l', 'e', 'd', '\n',
        'a', 'p', 'p', 'a', 'r', 'e', 'n', 't', '\n',
        'a', 'p', 'p', 'a', 'r', 'e', 'n', 't', 'l', 'y', '\n',
        'a', 'p', 'p', 'a', 'r', 'i', 't', 'i', 'o', 'n', '\n',
        'a', 'p', 'p', 'a', 'r', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'p', 'p', 'e', 'a', 'l', '\n',
        'a', 'p', 'p', 'e', 'a', 'l', 'e', 'd', '\n',
        'a', 'p', 'p', 'e', 'a', 'l', 'i', 'n', 'g', '\n',
        'a', 'p', 'p', 'e', 'a', 'l', 'i', 'n', 'g', 'l', 'y', '\n',
        'a', 'p', 'p', 'e', 'a', 'l', 's', '\n',
        'a', 'p', 'p', 'e', 'a', 'r', '\n',
        'a', 'p', 'p', 'e', 'a', 'r', 'a', 'n', 'c', 'e', '\n',
        'a', 'p', 'p', 'e', 'a', 'r', 'a', 'n', 'c', 'e', 's', '\n',
        'a', 'p', 'p', 'e', 'a', 'r', 'e', 'd', '\n',
        'a', 'p', 'p', 'e', 'a', 'r', 'i', 'n', 'g', '\n',
        'a', 'p', 'p', 'e', 'a', 'r', 's', '\n',
        'a', 'p', 'p', 'e', 'a', 's', 'e', '\n',
        'a', 'p', 'p', 'e', 'a', 's', 'e', 'd', '\n',
        'a', 'p', 'p', 'e', 'a', 's', 'e', 'm', 'e', 'n', 't', '\n',
        'a', 'p', 'p', 'e', 'a', 's', 'e', 'r', '\n',
        'a', 'p', 'p', 'e', 'a', 's', 'e', 'r', 's', '\n',
        'a', 'p', 'p', 'e', 'a', 's', 'e', 's', '\n',
        'a', 'p', 'p', 'e', 'a', 's', 'i', 'n', 'g', '\n',
        'a', 'p', 'p', 'e', 'l', 'l', 'a', 'n', 't', '\n',
        'a', 'p', 'p', 'e', 'l', 'l', 'a', 'n', 't', 's', '\n',
        'a', 'p', 'p', 'e', 'l', 'l', 'a', 't', 'e', '\n',
        'a', 'p', 'p', 'e', 'l', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'p', 'p', 'e', 'l', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'p', 'p', 'e', 'n', 'd', '\n',
        'a', 'p', 'p', 'e', 'n', 'd', 'a', 'g', 'e', '\n',
        'a', 'p', 'p', 'e', 'n', 'd', 'a', 'g', 'e', 's', '\n',
        'a', 'p', 'p', 'e', 'n', 'd', 'e', 'd', '\n',
        'a', 'p', 'p', 'e', 'n', 'd', 'i', 'c', 'e', 's', '\n',
        'a', 'p', 'p', 'e', 'n', 'd', 'i', 'c', 'i', 't', 'i', 's', '\n',
        'a', 'p', 'p', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'a', 'p', 'p', 'e', 'n', 'd', 'i', 'x', '\n',
        'a', 'p', 'p', 'e', 'n', 'd', 's', '\n',
        'a', 'p', 'p', 'e', 'r', 't', 'a', 'i', 'n', '\n',
        'a', 'p', 'p', 'e', 'r', 't', 'a', 'i', 'n', 'e', 'd', '\n',
        'a', 'p', 'p', 'e', 'r', 't', 'a', 'i', 'n', 'i', 'n', 'g', '\n',
        'a', 'p', 'p', 'e', 't', 'i', 's', 'e', 'r', '\n',
        'a', 'p', 'p', 'e', 't', 'i', 's', 'i', 'n', 'g', '\n',
        'a', 'p', 'p', 'e', 't', 'i', 't', 'e', '\n',
        'a', 'p', 'p', 'e', 't', 'i', 't', 'e', 's', '\n',
        'a', 'p', 'p', 'l', 'a', 'u', 'd', '\n',
        'a', 'p', 'p', 'l', 'a', 'u', 'd', 'e', 'd', '\n',
        'a', 'p', 'p', 'l', 'a', 'u', 'd', 'i', 'n', 'g', '\n',
        'a', 'p', 'p', 'l', 'a', 'u', 'd', 's', '\n',
        'a', 'p', 'p', 'l', 'a', 'u', 's', 'e', '\n',
        'a', 'p', 'p', 'l', 'e', '\n',
        'a', 'p', 'p', 'l', 'e', 'c', 'a', 'r', 't', '\n',
        'a', 'p', 'p', 'l', 'e', 'p', 'i', 'e', '\n',
        'a', 'p', 'p', 'l', 'e', 's', '\n',
        'a', 'p', 'p', 'l', 'e', 't', '\n',
        'a', 'p', 'p', 'l', 'i', 'a', 'n', 'c', 'e', '\n',
        'a', 'p', 'p', 'l', 'i', 'a', 'n', 'c', 'e', 's', '\n',
        'a', 'p', 'p', 'l', 'i', 'c', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'a', 'p', 'p', 'l', 'i', 'c', 'a', 'b', 'l', 'e', '\n',
        'a', 'p', 'p', 'l', 'i', 'c', 'a', 'n', 't', '\n',
        'a', 'p', 'p', 'l', 'i', 'c', 'a', 'n', 't', 's', '\n',
        'a', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'v', 'e', '\n',
        'a', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'o', 'r', '\n',
        'a', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'o', 'r', 's', '\n',
        'a', 'p', 'p', 'l', 'i', 'e', 'd', '\n',
        'a', 'p', 'p', 'l', 'i', 'e', 'r', '\n',
        'a', 'p', 'p', 'l', 'i', 'e', 's', '\n',
        'a', 'p', 'p', 'l', 'i', 'q', 'u', 'e', '\n',
        'a', 'p', 'p', 'l', 'y', '\n',
        'a', 'p', 'p', 'l', 'y', 'i', 'n', 'g', '\n',
        'a', 'p', 'p', 'o', 'i', 'n', 't', '\n',
        'a', 'p', 'p', 'o', 'i', 'n', 't', 'e', 'd', '\n',
        'a', 'p', 'p', 'o', 'i', 'n', 't', 'e', 'e', '\n',
        'a', 'p', 'p', 'o', 'i', 'n', 't', 'e', 'e', 's', '\n',
        'a', 'p', 'p', 'o', 'i', 'n', 't', 'i', 'n', 'g', '\n',
        'a', 'p', 'p', 'o', 'i', 'n', 't', 'm', 'e', 'n', 't', '\n',
        'a', 'p', 'p', 'o', 'i', 'n', 't', 'm', 'e', 'n', 't', 's', '\n',
        'a', 'p', 'p', 'o', 'i', 'n', 't', 's', '\n',
        'a', 'p', 'p', 'o', 'r', 't', 'i', 'o', 'n', '\n',
        'a', 'p', 'p', 'o', 'r', 't', 'i', 'o', 'n', 'e', 'd', '\n',
        'a', 'p', 'p', 'o', 'r', 't', 'i', 'o', 'n', 'i', 'n', 'g', '\n',
        'a', 'p', 'p', 'o', 'r', 't', 'i', 'o', 'n', 'm', 'e', 'n', 't', '\n',
        'a', 'p', 'p', 'o', 'r', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'p', 'p', 'o', 's', 'i', 't', 'e', '\n',
        'a', 'p', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', '\n',
        'a', 'p', 'p', 'r', 'a', 'i', 's', 'a', 'l', '\n',
        'a', 'p', 'p', 'r', 'a', 'i', 's', 'a', 'l', 's', '\n',
        'a', 'p', 'p', 'r', 'a', 'i', 's', 'e', '\n',
        'a', 'p', 'p', 'r', 'a', 'i', 's', 'e', 'd', '\n',
        'a', 'p', 'p', 'r', 'a', 'i', 's', 'e', 'e', 's', '\n',
        'a', 'p', 'p', 'r', 'a', 'i', 's', 'e', 'r', '\n',
        'a', 'p', 'p', 'r', 'a', 'i', 's', 'e', 'r', 's', '\n',
        'a', 'p', 'p', 'r', 'a', 'i', 's', 'e', 's', '\n',
        'a', 'p', 'p', 'r', 'a', 'i', 's', 'i', 'n', 'g', '\n',
        'a', 'p', 'p', 'r', 'a', 'i', 's', 'i', 'n', 'g', 'l', 'y', '\n',
        'a', 'p', 'p', 'r', 'e', 'c', 'i', 'a', 'b', 'l', 'e', '\n',
        'a', 'p', 'p', 'r', 'e', 'c', 'i', 'a', 'b', 'l', 'y', '\n',
        'a', 'p', 'p', 'r', 'e', 'c', 'i', 'a', 't', 'e', '\n',
        'a', 'p', 'p', 'r', 'e', 'c', 'i', 'a', 't', 'e', 'd', '\n',
        'a', 'p', 'p', 'r', 'e', 'c', 'i', 'a', 't', 'e', 's', '\n',
        'a', 'p', 'p', 'r', 'e', 'c', 'i', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'p', 'p', 'r', 'e', 'c', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'p', 'p', 'r', 'e', 'c', 'i', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'p', 'p', 'r', 'e', 'c', 'i', 'a', 't', 'i', 'v', 'e', '\n',
        'a', 'p', 'p', 'r', 'e', 'c', 'i', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'a', 'p', 'p', 'r', 'e', 'h', 'e', 'n', 'd', '\n',
        'a', 'p', 'p', 'r', 'e', 'h', 'e', 'n', 'd', 'e', 'd', '\n',
        'a', 'p', 'p', 'r', 'e', 'h', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'a', 'p', 'p', 'r', 'e', 'h', 'e', 'n', 'd', 's', '\n',
        'a', 'p', 'p', 'r', 'e', 'h', 'e', 'n', 's', 'i', 'o', 'n', '\n',
        'a', 'p', 'p', 'r', 'e', 'h', 'e', 'n', 's', 'i', 'o', 'n', 's', '\n',
        'a', 'p', 'p', 'r', 'e', 'h', 'e', 'n', 's', 'i', 'v', 'e', '\n',
        'a', 'p', 'p', 'r', 'e', 'h', 'e', 'n', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'a', 'p', 'p', 'r', 'e', 'n', 't', 'i', 'c', 'e', '\n',
        'a', 'p', 'p', 'r', 'e', 'n', 't', 'i', 'c', 'e', 'd', '\n',
        'a', 'p', 'p', 'r', 'e', 'n', 't', 'i', 'c', 'e', 's', '\n',
        'a', 'p', 'p', 'r', 'e', 'n', 't', 'i', 'c', 'e', 's', 'h', 'i', 'p', '\n',
        'a', 'p', 'p', 'r', 'e', 'n', 't', 'i', 'c', 'e', 's', 'h', 'i', 'p', 's', '\n',
        'a', 'p', 'p', 'r', 'i', 's', 'e', '\n',
        'a', 'p', 'p', 'r', 'i', 's', 'e', 'd', '\n',
        'a', 'p', 'p', 'r', 'i', 's', 'i', 'n', 'g', '\n',
        'a', 'p', 'p', 'r', 'o', '\n',
        'a', 'p', 'p', 'r', 'o', 'a', 'c', 'h', '\n',
        'a', 'p', 'p', 'r', 'o', 'a', 'c', 'h', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'a', 'p', 'p', 'r', 'o', 'a', 'c', 'h', 'a', 'b', 'l', 'e', '\n',
        'a', 'p', 'p', 'r', 'o', 'a', 'c', 'h', 'e', 'd', '\n',
        'a', 'p', 'p', 'r', 'o', 'a', 'c', 'h', 'e', 's', '\n',
        'a', 'p', 'p', 'r', 'o', 'a', 'c', 'h', 'i', 'n', 'g', '\n',
        'a', 'p', 'p', 'r', 'o', 'b', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'p', 'p', 'r', 'o', 'p', 'r', 'i', 'a', 't', 'e', '\n',
        'a', 'p', 'p', 'r', 'o', 'p', 'r', 'i', 'a', 't', 'e', 'd', '\n',
        'a', 'p', 'p', 'r', 'o', 'p', 'r', 'i', 'a', 't', 'e', 'l', 'y', '\n',
        'a', 'p', 'p', 'r', 'o', 'p', 'r', 'i', 'a', 't', 'e', 'n', 'e', 's', 's', '\n',
        'a', 'p', 'p', 'r', 'o', 'p', 'r', 'i', 'a', 't', 'e', 's', '\n',
        'a', 'p', 'p', 'r', 'o', 'p', 'r', 'i', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'p', 'p', 'r', 'o', 'p', 'r', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'p', 'p', 'r', 'o', 'p', 'r', 'i', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'p', 'p', 'r', 'o', 'v', 'a', 'l', '\n',
        'a', 'p', 'p', 'r', 'o', 'v', 'a', 'l', 's', '\n',
        'a', 'p', 'p', 'r', 'o', 'v', 'e', '\n',
        'a', 'p', 'p', 'r', 'o', 'v', 'e', 'd', '\n',
        'a', 'p', 'p', 'r', 'o', 'v', 'e', 's', '\n',
        'a', 'p', 'p', 'r', 'o', 'v', 'i', 'n', 'g', '\n',
        'a', 'p', 'p', 'r', 'o', 'v', 'i', 'n', 'g', 'l', 'y', '\n',
        'a', 'p', 'p', 'r', 'o', 'x', 'i', 'm', 'a', 't', 'e', '\n',
        'a', 'p', 'p', 'r', 'o', 'x', 'i', 'm', 'a', 't', 'e', 'd', '\n',
        'a', 'p', 'p', 'r', 'o', 'x', 'i', 'm', 'a', 't', 'e', 'l', 'y', '\n',
        'a', 'p', 'p', 'r', 'o', 'x', 'i', 'm', 'a', 't', 'e', 's', '\n',
        'a', 'p', 'p', 'r', 'o', 'x', 'i', 'm', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'p', 'p', 'r', 'o', 'x', 'i', 'm', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'p', 'p', 'r', 'o', 'x', 'i', 'm', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'p', 'r', 'i', 'c', 'o', 't', '\n',
        'a', 'p', 'r', 'i', 'c', 'o', 't', 's', '\n',
        'a', 'p', 'r', 'i', 'l', '\n',
        'a', 'p', 'r', 'i', 'o', 'r', 'i', '\n',
        'a', 'p', 'r', 'o', 'n', '\n',
        'a', 'p', 'r', 'o', 'n', 's', '\n',
        'a', 'p', 'r', 'o', 'p', 'o', 's', '\n',
        'a', 'p', 's', 'e', '\n',
        'a', 'p', 's', 'e', 's', '\n',
        'a', 'p', 's', 'i', 's', '\n',
        'a', 'p', 't', '\n',
        'a', 'p', 't', 'e', 's', 't', '\n',
        'a', 'p', 't', 'i', 't', 'u', 'd', 'e', '\n',
        'a', 'p', 't', 'i', 't', 'u', 'd', 'e', 's', '\n',
        'a', 'p', 't', 'l', 'y', '\n',
        'a', 'p', 't', 'n', 'e', 's', 's', '\n',
        'a', 'q', 'u', 'a', '\n',
        'a', 'q', 'u', 'a', 'l', 'u', 'n', 'g', '\n',
        'a', 'q', 'u', 'a', 'm', 'a', 'r', 'i', 'n', 'e', '\n',
        'a', 'q', 'u', 'a', 'n', 'a', 'u', 't', '\n',
        'a', 'q', 'u', 'a', 'r', 'i', 'a', '\n',
        'a', 'q', 'u', 'a', 'r', 'i', 'u', 'm', '\n',
        'a', 'q', 'u', 'a', 'r', 'i', 'u', 'm', 's', '\n',
        'a', 'q', 'u', 'a', 't', 'i', 'c', '\n',
        'a', 'q', 'u', 'a', 't', 'i', 'c', 's', '\n',
        'a', 'q', 'u', 'e', 'd', 'u', 'c', 't', '\n',
        'a', 'q', 'u', 'e', 'd', 'u', 'c', 't', 's', '\n',
        'a', 'q', 'u', 'e', 'o', 'u', 's', '\n',
        'a', 'q', 'u', 'i', 'f', 'e', 'r', '\n',
        'a', 'q', 'u', 'i', 'f', 'e', 'r', 's', '\n',
        'a', 'q', 'u', 'i', 'l', 'i', 'n', 'e', '\n',
        'a', 'r', 'a', 'b', '\n',
        'a', 'r', 'a', 'b', 'e', 's', 'q', 'u', 'e', '\n',
        'a', 'r', 'a', 'b', 'e', 's', 'q', 'u', 'e', 's', '\n',
        'a', 'r', 'a', 'b', 'i', 'a', '\n',
        'a', 'r', 'a', 'b', 'i', 'a', 'n', '\n',
        'a', 'r', 'a', 'b', 'i', 'a', 'n', 's', '\n',
        'a', 'r', 'a', 'b', 'i', 'c', '\n',
        'a', 'r', 'a', 'b', 'l', 'e', '\n',
        'a', 'r', 'a', 'b', 's', '\n',
        'a', 'r', 'a', 'c', 'h', 'n', 'i', 'd', '\n',
        'a', 'r', 'a', 'c', 'h', 'n', 'i', 'd', 's', '\n',
        'a', 'r', 'a', 'c', 'h', 'n', 'o', 'i', 'd', '\n',
        'a', 'r', 'a', 'c', 'h', 'n', 'o', 'p', 'h', 'o', 'b', 'i', 'a', '\n',
        'a', 'r', 'a', 'k', '\n',
        'a', 'r', 'a', 'k', 's', '\n',
        'a', 'r', 'a', 'r', 'a', 't', '\n',
        'a', 'r', 'b', 'i', 't', 'e', 'r', '\n',
        'a', 'r', 'b', 'i', 't', 'e', 'r', 's', '\n',
        'a', 'r', 'b', 'i', 't', 'r', 'a', 'g', 'e', '\n',
        'a', 'r', 'b', 'i', 't', 'r', 'a', 'g', 'e', 'u', 'r', '\n',
        'a', 'r', 'b', 'i', 't', 'r', 'a', 'g', 'e', 'u', 'r', 's', '\n',
        'a', 'r', 'b', 'i', 't', 'r', 'a', 'l', '\n',
        'a', 'r', 'b', 'i', 't', 'r', 'a', 'r', 'i', 'l', 'y', '\n',
        'a', 'r', 'b', 'i', 't', 'r', 'a', 'r', 'i', 'n', 'e', 's', 's', '\n',
        'a', 'r', 'b', 'i', 't', 'r', 'a', 'r', 'y', '\n',
        'a', 'r', 'b', 'i', 't', 'r', 'a', 't', 'e', '\n',
        'a', 'r', 'b', 'i', 't', 'r', 'a', 't', 'e', 'd', '\n',
        'a', 'r', 'b', 'i', 't', 'r', 'a', 't', 'e', 's', '\n',
        'a', 'r', 'b', 'i', 't', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'r', 'b', 'i', 't', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'r', 'b', 'i', 't', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'r', 'b', 'i', 't', 'r', 'a', 't', 'o', 'r', '\n',
        'a', 'r', 'b', 'i', 't', 'r', 'a', 't', 'o', 'r', 's', '\n',
        'a', 'r', 'b', 'o', 'r', '\n',
        'a', 'r', 'b', 'o', 'r', 'e', 'a', 'l', '\n',
        'a', 'r', 'b', 'o', 'r', 'e', 't', 'u', 'm', '\n',
        'a', 'r', 'b', 'o', 'u', 'r', '\n',
        'a', 'r', 'c', '\n',
        'a', 'r', 'c', 'a', 'd', 'e', '\n',
        'a', 'r', 'c', 'a', 'd', 'e', 's', '\n',
        'a', 'r', 'c', 'a', 'd', 'i', 'a', '\n',
        'a', 'r', 'c', 'a', 'd', 'i', 'n', 'g', '\n',
        'a', 'r', 'c', 'a', 'n', 'a', '\n',
        'a', 'r', 'c', 'a', 'n', 'e', '\n',
        'a', 'r', 'c', 'a', 'n', 'e', 'l', 'y', '\n',
        'a', 'r', 'c', 'a', 'n', 'e', 'n', 'e', 's', 's', '\n',
        'a', 'r', 'c', 'e', 'd', '\n',
        'a', 'r', 'c', 'h', '\n',
        'a', 'r', 'c', 'h', 'a', 'e', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'a', 'r', 'c', 'h', 'a', 'e', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 'r', 'c', 'h', 'a', 'e', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'a', 'r', 'c', 'h', 'a', 'e', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'a', 'r', 'c', 'h', 'a', 'e', 'o', 'l', 'o', 'g', 'y', '\n',
        'a', 'r', 'c', 'h', 'a', 'e', 'o', 'p', 't', 'e', 'r', 'y', 'x', '\n',
        'a', 'r', 'c', 'h', 'a', 'i', 'c', '\n',
        'a', 'r', 'c', 'h', 'a', 'i', 's', 'm', '\n',
        'a', 'r', 'c', 'h', 'a', 'i', 's', 'm', 's', '\n',
        'a', 'r', 'c', 'h', 'a', 'n', 'g', 'e', 'l', '\n',
        'a', 'r', 'c', 'h', 'a', 'n', 'g', 'e', 'l', 's', '\n',
        'a', 'r', 'c', 'h', 'b', 'i', 's', 'h', 'o', 'p', '\n',
        'a', 'r', 'c', 'h', 'b', 'i', 's', 'h', 'o', 'p', 's', '\n',
        'a', 'r', 'c', 'h', 'd', 'e', 'a', 'c', 'o', 'n', '\n',
        'a', 'r', 'c', 'h', 'd', 'e', 'a', 'c', 'o', 'n', 'r', 'y', '\n',
        'a', 'r', 'c', 'h', 'd', 'e', 'a', 'c', 'o', 'n', 's', '\n',
        'a', 'r', 'c', 'h', 'd', 'i', 'o', 'c', 'e', 's', 'e', '\n',
        'a', 'r', 'c', 'h', 'd', 'u', 'k', 'e', '\n',
        'a', 'r', 'c', 'h', 'd', 'u', 'k', 'e', 's', '\n',
        'a', 'r', 'c', 'h', 'e', 'd', '\n',
        'a', 'r', 'c', 'h', 'e', 'n', 'e', 'm', 'i', 'e', 's', '\n',
        'a', 'r', 'c', 'h', 'e', 'n', 'e', 'm', 'y', '\n',
        'a', 'r', 'c', 'h', 'e', 'r', '\n',
        'a', 'r', 'c', 'h', 'e', 'r', 's', '\n',
        'a', 'r', 'c', 'h', 'e', 'r', 'y', '\n',
        'a', 'r', 'c', 'h', 'e', 's', '\n',
        'a', 'r', 'c', 'h', 'e', 't', 'y', 'p', 'a', 'l', '\n',
        'a', 'r', 'c', 'h', 'e', 't', 'y', 'p', 'e', '\n',
        'a', 'r', 'c', 'h', 'e', 't', 'y', 'p', 'e', 's', '\n',
        'a', 'r', 'c', 'h', 'e', 't', 'y', 'p', 'i', 'c', 'a', 'l', '\n',
        'a', 'r', 'c', 'h', 'i', 'n', 'g', '\n',
        'a', 'r', 'c', 'h', 'i', 'p', 'e', 'l', 'a', 'g', 'o', '\n',
        'a', 'r', 'c', 'h', 'i', 't', 'e', 'c', 't', '\n',
        'a', 'r', 'c', 'h', 'i', 't', 'e', 'c', 't', 'o', 'n', 'i', 'c', '\n',
        'a', 'r', 'c', 'h', 'i', 't', 'e', 'c', 't', 's', '\n',
        'a', 'r', 'c', 'h', 'i', 't', 'e', 'c', 't', 'u', 'r', 'a', 'l', '\n',
        'a', 'r', 'c', 'h', 'i', 't', 'e', 'c', 't', 'u', 'r', 'a', 'l', 'l', 'y', '\n',
        'a', 'r', 'c', 'h', 'i', 't', 'e', 'c', 't', 'u', 'r', 'e', '\n',
        'a', 'r', 'c', 'h', 'i', 't', 'e', 'c', 't', 'u', 'r', 'e', 's', '\n',
        'a', 'r', 'c', 'h', 'i', 't', 'r', 'a', 'v', 'e', '\n',
        'a', 'r', 'c', 'h', 'i', 't', 'r', 'a', 'v', 'e', 's', '\n',
        'a', 'r', 'c', 'h', 'i', 'v', 'a', 'l', '\n',
        'a', 'r', 'c', 'h', 'i', 'v', 'e', '\n',
        'a', 'r', 'c', 'h', 'i', 'v', 'e', 'd', '\n',
        'a', 'r', 'c', 'h', 'i', 'v', 'e', 's', '\n',
        'a', 'r', 'c', 'h', 'i', 'v', 'i', 'n', 'g', '\n',
        'a', 'r', 'c', 'h', 'i', 'v', 'i', 's', 't', '\n',
        'a', 'r', 'c', 'h', 'i', 'v', 'i', 's', 't', 's', '\n',
        'a', 'r', 'c', 'h', 'l', 'y', '\n',
        'a', 'r', 'c', 'h', 'n', 'e', 's', 's', '\n',
        'a', 'r', 'c', 'h', 'w', 'a', 'y', '\n',
        'a', 'r', 'c', 'h', 'w', 'a', 'y', 's', '\n',
        'a', 'r', 'c', 'i', 'n', 'g', '\n',
        'a', 'r', 'c', 's', '\n',
        'a', 'r', 'c', 't', 'i', 'c', '\n',
        'a', 'r', 'd', 'e', 'n', 'c', 'y', '\n',
        'a', 'r', 'd', 'e', 'n', 't', '\n',
        'a', 'r', 'd', 'e', 'n', 't', 'l', 'y', '\n',
        'a', 'r', 'd', 'o', 'u', 'r', '\n',
        'a', 'r', 'd', 'u', 'o', 'u', 's', '\n',
        'a', 'r', 'e', '\n',
        'a', 'r', 'e', 'a', '\n',
        'a', 'r', 'e', 'a', 'l', '\n',
        'a', 'r', 'e', 'a', 's', '\n',
        'a', 'r', 'e', 'n', 'a', '\n',
        'a', 'r', 'e', 'n', 'a', 's', '\n',
        'a', 'r', 'e', 'n', 't', '\n',
        'a', 'r', 'g', 'e', 'n', 't', '\n',
        'a', 'r', 'g', 'o', 'n', '\n',
        'a', 'r', 'g', 'o', 't', '\n',
        'a', 'r', 'g', 'u', 'a', 'b', 'l', 'e', '\n',
        'a', 'r', 'g', 'u', 'a', 'b', 'l', 'y', '\n',
        'a', 'r', 'g', 'u', 'e', '\n',
        'a', 'r', 'g', 'u', 'e', 'd', '\n',
        'a', 'r', 'g', 'u', 'e', 'r', '\n',
        'a', 'r', 'g', 'u', 'e', 'r', 's', '\n',
        'a', 'r', 'g', 'u', 'e', 's', '\n',
        'a', 'r', 'g', 'u', 'i', 'n', 'g', '\n',
        'a', 'r', 'g', 'u', 'm', 'e', 'n', 't', '\n',
        'a', 'r', 'g', 'u', 'm', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'r', 'g', 'u', 'm', 'e', 'n', 't', 'a', 't', 'i', 'v', 'e', '\n',
        'a', 'r', 'g', 'u', 'm', 'e', 'n', 't', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'a', 'r', 'g', 'u', 'm', 'e', 'n', 't', 's', '\n',
        'a', 'r', 'g', 'u', 's', '\n',
        'a', 'r', 'i', 'a', '\n',
        'a', 'r', 'i', 'a', 's', '\n',
        'a', 'r', 'i', 'd', '\n',
        'a', 'r', 'i', 'd', 'i', 't', 'y', '\n',
        'a', 'r', 'i', 'd', 'n', 'e', 's', 's', '\n',
        'a', 'r', 'i', 'g', 'h', 't', '\n',
        'a', 'r', 'i', 's', 'e', '\n',
        'a', 'r', 'i', 's', 'e', 'n', '\n',
        'a', 'r', 'i', 's', 'e', 's', '\n',
        'a', 'r', 'i', 's', 'i', 'n', 'g', '\n',
        'a', 'r', 'i', 's', 't', 'o', 'c', 'r', 'a', 'c', 'i', 'e', 's', '\n',
        'a', 'r', 'i', 's', 't', 'o', 'c', 'r', 'a', 'c', 'y', '\n',
        'a', 'r', 'i', 's', 't', 'o', 'c', 'r', 'a', 't', '\n',
        'a', 'r', 'i', 's', 't', 'o', 'c', 'r', 'a', 't', 'i', 'c', '\n',
        'a', 'r', 'i', 's', 't', 'o', 'c', 'r', 'a', 't', 's', '\n',
        'a', 'r', 'i', 't', 'h', 'm', 'e', 't', 'i', 'c', '\n',
        'a', 'r', 'i', 't', 'h', 'm', 'e', 't', 'i', 'c', 'a', 'l', '\n',
        'a', 'r', 'i', 't', 'h', 'm', 'e', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 'r', 'i', 'z', 'o', 'n', 'a', '\n',
        'a', 'r', 'k', '\n',
        'a', 'r', 'k', 'a', 'n', 's', 'a', 's', '\n',
        'a', 'r', 'k', 's', '\n',
        'a', 'r', 'm', '\n',
        'a', 'r', 'm', 'a', 'd', 'a', '\n',
        'a', 'r', 'm', 'a', 'd', 'a', 's', '\n',
        'a', 'r', 'm', 'a', 'd', 'i', 'l', 'l', 'o', '\n',
        'a', 'r', 'm', 'a', 'm', 'e', 'n', 't', '\n',
        'a', 'r', 'm', 'a', 'm', 'e', 'n', 't', 's', '\n',
        'a', 'r', 'm', 'a', 't', 'u', 'r', 'e', '\n',
        'a', 'r', 'm', 'a', 't', 'u', 'r', 'e', 's', '\n',
        'a', 'r', 'm', 'b', 'a', 'n', 'd', '\n',
        'a', 'r', 'm', 'b', 'a', 'n', 'd', 's', '\n',
        'a', 'r', 'm', 'c', 'h', 'a', 'i', 'r', '\n',
        'a', 'r', 'm', 'c', 'h', 'a', 'i', 'r', 's', '\n',
        'a', 'r', 'm', 'e', 'd', '\n',
        'a', 'r', 'm', 'e', 'n', 'i', 'a', '\n',
        'a', 'r', 'm', 'f', 'u', 'l', '\n',
        'a', 'r', 'm', 'f', 'u', 'l', 's', '\n',
        'a', 'r', 'm', 'h', 'o', 'l', 'e', '\n',
        'a', 'r', 'm', 'h', 'o', 'l', 'e', 's', '\n',
        'a', 'r', 'm', 'i', 'e', 's', '\n',
        'a', 'r', 'm', 'i', 'n', 'g', '\n',
        'a', 'r', 'm', 'i', 's', 't', 'i', 'c', 'e', '\n',
        'a', 'r', 'm', 'l', 'e', 's', 's', '\n',
        'a', 'r', 'm', 'l', 'e', 't', '\n',
        'a', 'r', 'm', 'l', 'e', 't', 's', '\n',
        'a', 'r', 'm', 'o', 'u', 'r', '\n',
        'a', 'r', 'm', 'o', 'u', 'r', 'e', 'd', '\n',
        'a', 'r', 'm', 'o', 'u', 'r', 'e', 'r', '\n',
        'a', 'r', 'm', 'o', 'u', 'r', 'e', 'r', 's', '\n',
        'a', 'r', 'm', 'o', 'u', 'r', 'i', 'e', 's', '\n',
        'a', 'r', 'm', 'o', 'u', 'r', 'p', 'l', 'a', 't', 'e', 'd', '\n',
        'a', 'r', 'm', 'o', 'u', 'r', 'y', '\n',
        'a', 'r', 'm', 'p', 'i', 't', '\n',
        'a', 'r', 'm', 'p', 'i', 't', 's', '\n',
        'a', 'r', 'm', 'r', 'e', 's', 't', '\n',
        'a', 'r', 'm', 's', '\n',
        'a', 'r', 'm', 'y', '\n',
        'a', 'r', 'o', 'm', 'a', '\n',
        'a', 'r', 'o', 'm', 'a', 's', '\n',
        'a', 'r', 'o', 'm', 'a', 't', 'h', 'e', 'r', 'a', 'p', 'i', 's', 't', '\n',
        'a', 'r', 'o', 'm', 'a', 't', 'h', 'e', 'r', 'a', 'p', 'y', '\n',
        'a', 'r', 'o', 'm', 'a', 't', 'i', 'c', '\n',
        'a', 'r', 'o', 'm', 'a', 't', 'i', 'c', 'i', 't', 'y', '\n',
        'a', 'r', 'o', 'm', 'a', 't', 'i', 'c', 's', '\n',
        'a', 'r', 'o', 's', 'e', '\n',
        'a', 'r', 'o', 'u', 'n', 'd', '\n',
        'a', 'r', 'o', 'u', 's', 'a', 'l', '\n',
        'a', 'r', 'o', 'u', 's', 'a', 'l', 's', '\n',
        'a', 'r', 'o', 'u', 's', 'e', '\n',
        'a', 'r', 'o', 'u', 's', 'e', 'd', '\n',
        'a', 'r', 'o', 'u', 's', 'e', 's', '\n',
        'a', 'r', 'o', 'u', 's', 'i', 'n', 'g', '\n',
        'a', 'r', 'r', 'a', 'n', 'g', 'e', '\n',
        'a', 'r', 'r', 'a', 'n', 'g', 'e', 'a', 'b', 'l', 'e', '\n',
        'a', 'r', 'r', 'a', 'n', 'g', 'e', 'd', '\n',
        'a', 'r', 'r', 'a', 'n', 'g', 'e', 'm', 'e', 'n', 't', '\n',
        'a', 'r', 'r', 'a', 'n', 'g', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'a', 'r', 'r', 'a', 'n', 'g', 'e', 'r', '\n',
        'a', 'r', 'r', 'a', 'n', 'g', 'e', 's', '\n',
        'a', 'r', 'r', 'a', 'n', 'g', 'i', 'n', 'g', '\n',
        'a', 'r', 'r', 'a', 'n', 't', '\n',
        'a', 'r', 'r', 'a', 's', 'e', 's', '\n',
        'a', 'r', 'r', 'a', 'y', '\n',
        'a', 'r', 'r', 'a', 'y', 'e', 'd', '\n',
        'a', 'r', 'r', 'a', 'y', 'i', 'n', 'g', '\n',
        'a', 'r', 'r', 'a', 'y', 's', '\n',
        'a', 'r', 'r', 'e', 'a', 'r', 's', '\n',
        'a', 'r', 'r', 'e', 's', 't', '\n',
        'a', 'r', 'r', 'e', 's', 't', 'a', 'b', 'l', 'e', '\n',
        'a', 'r', 'r', 'e', 's', 't', 'e', 'd', '\n',
        'a', 'r', 'r', 'e', 's', 't', 'e', 'r', '\n',
        'a', 'r', 'r', 'e', 's', 't', 'i', 'n', 'g', '\n',
        'a', 'r', 'r', 'e', 's', 't', 's', '\n',
        'a', 'r', 'r', 'h', 'y', 't', 'h', 'm', 'i', 'a', '\n',
        'a', 'r', 'r', 'i', 'v', 'a', 'l', '\n',
        'a', 'r', 'r', 'i', 'v', 'a', 'l', 's', '\n',
        'a', 'r', 'r', 'i', 'v', 'e', '\n',
        'a', 'r', 'r', 'i', 'v', 'e', 'd', '\n',
        'a', 'r', 'r', 'i', 'v', 'e', 'r', '\n',
        'a', 'r', 'r', 'i', 'v', 'e', 's', '\n',
        'a', 'r', 'r', 'i', 'v', 'i', 'n', 'g', '\n',
        'a', 'r', 'r', 'o', 'g', 'a', 'n', 'c', 'e', '\n',
        'a', 'r', 'r', 'o', 'g', 'a', 'n', 't', '\n',
        'a', 'r', 'r', 'o', 'g', 'a', 'n', 't', 'l', 'y', '\n',
        'a', 'r', 'r', 'o', 'w', '\n',
        'a', 'r', 'r', 'o', 'w', 'e', 'd', '\n',
        'a', 'r', 'r', 'o', 'w', 'h', 'e', 'a', 'd', '\n',
        'a', 'r', 'r', 'o', 'w', 'h', 'e', 'a', 'd', 's', '\n',
        'a', 'r', 'r', 'o', 'w', 'i', 'n', 'g', '\n',
        'a', 'r', 'r', 'o', 'w', 'r', 'o', 'o', 't', '\n',
        'a', 'r', 'r', 'o', 'w', 's', '\n',
        'a', 'r', 's', 'e', 'n', 'a', 'l', '\n',
        'a', 'r', 's', 'e', 'n', 'a', 'l', 's', '\n',
        'a', 'r', 's', 'e', 'n', 'i', 'c', '\n',
        'a', 'r', 's', 'e', 'n', 'i', 'd', 'e', '\n',
        'a', 'r', 's', 'o', 'n', '\n',
        'a', 'r', 's', 'o', 'n', 'i', 's', 't', '\n',
        'a', 'r', 's', 'o', 'n', 'i', 's', 't', 's', '\n',
        'a', 'r', 't', '\n',
        'a', 'r', 't', 'e', 'f', 'a', 'c', 't', '\n',
        'a', 'r', 't', 'e', 'f', 'a', 'c', 't', 's', '\n',
        'a', 'r', 't', 'e', 'f', 'a', 'c', 't', 'u', 'a', 'l', '\n',
        'a', 'r', 't', 'e', 'r', 'i', 'a', 'l', '\n',
        'a', 'r', 't', 'e', 'r', 'i', 'e', 's', '\n',
        'a', 'r', 't', 'e', 'r', 'y', '\n',
        'a', 'r', 't', 'f', 'u', 'l', '\n',
        'a', 'r', 't', 'f', 'u', 'l', 'l', 'y', '\n',
        'a', 'r', 't', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'a', 'r', 't', 'h', 'r', 'i', 't', 'i', 'c', '\n',
        'a', 'r', 't', 'h', 'r', 'i', 't', 'i', 's', '\n',
        'a', 'r', 't', 'h', 'r', 'o', 'p', 'o', 'd', '\n',
        'a', 'r', 't', 'h', 'r', 'o', 'p', 'o', 'd', 's', '\n',
        'a', 'r', 't', 'h', 'u', 'r', '\n',
        'a', 'r', 't', 'i', 'c', 'h', 'o', 'k', 'e', '\n',
        'a', 'r', 't', 'i', 'c', 'h', 'o', 'k', 'e', 's', '\n',
        'a', 'r', 't', 'i', 'c', 'l', 'e', '\n',
        'a', 'r', 't', 'i', 'c', 'l', 'e', 'd', '\n',
        'a', 'r', 't', 'i', 'c', 'l', 'e', 's', '\n',
        'a', 'r', 't', 'i', 'c', 'u', 'l', 'a', 'c', 'y', '\n',
        'a', 'r', 't', 'i', 'c', 'u', 'l', 'a', 'r', '\n',
        'a', 'r', 't', 'i', 'c', 'u', 'l', 'a', 't', 'e', '\n',
        'a', 'r', 't', 'i', 'c', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'a', 'r', 't', 'i', 'c', 'u', 'l', 'a', 't', 'e', 'l', 'y', '\n',
        'a', 'r', 't', 'i', 'c', 'u', 'l', 'a', 't', 'e', 's', '\n',
        'a', 'r', 't', 'i', 'c', 'u', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'r', 't', 'i', 'c', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'r', 't', 'i', 'c', 'u', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'r', 't', 'i', 'c', 'u', 'l', 'a', 't', 'o', 'r', 'y', '\n',
        'a', 'r', 't', 'i', 'e', 'r', '\n',
        'a', 'r', 't', 'i', 'f', 'i', 'c', 'e', '\n',
        'a', 'r', 't', 'i', 'f', 'i', 'c', 'i', 'a', 'l', '\n',
        'a', 'r', 't', 'i', 'f', 'i', 'c', 'i', 'a', 'l', 'i', 't', 'y', '\n',
        'a', 'r', 't', 'i', 'f', 'i', 'c', 'i', 'a', 'l', 'l', 'y', '\n',
        'a', 'r', 't', 'i', 'l', 'l', 'e', 'r', 'y', '\n',
        'a', 'r', 't', 'i', 's', 'a', 'n', '\n',
        'a', 'r', 't', 'i', 's', 'a', 'n', 's', '\n',
        'a', 'r', 't', 'i', 's', 't', '\n',
        'a', 'r', 't', 'i', 's', 't', 'e', '\n',
        'a', 'r', 't', 'i', 's', 't', 'e', 's', '\n',
        'a', 'r', 't', 'i', 's', 't', 'i', 'c', '\n',
        'a', 'r', 't', 'i', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 'r', 't', 'i', 's', 't', 'r', 'y', '\n',
        'a', 'r', 't', 'i', 's', 't', 's', '\n',
        'a', 'r', 't', 'l', 'e', 's', 's', '\n',
        'a', 'r', 't', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'a', 'r', 't', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'a', 'r', 't', 's', '\n',
        'a', 'r', 't', 'w', 'o', 'r', 'k', '\n',
        'a', 'r', 't', 'w', 'o', 'r', 'k', 's', '\n',
        'a', 'r', 't', 'y', '\n',
        'a', 'r', 'u', 'm', '\n',
        'a', 's', '\n',
        'a', 's', 'b', 'e', 's', 't', 'o', 's', '\n',
        'a', 's', 'b', 'e', 's', 't', 'o', 's', 'i', 's', '\n',
        'a', 's', 'c', 'e', 'n', 'd', '\n',
        'a', 's', 'c', 'e', 'n', 'd', 'a', 'n', 'c', 'y', '\n',
        'a', 's', 'c', 'e', 'n', 'd', 'a', 'n', 't', '\n',
        'a', 's', 'c', 'e', 'n', 'd', 'e', 'd', '\n',
        'a', 's', 'c', 'e', 'n', 'd', 'e', 'n', 'c', 'y', '\n',
        'a', 's', 'c', 'e', 'n', 'd', 'e', 'r', '\n',
        'a', 's', 'c', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'a', 's', 'c', 'e', 'n', 'd', 's', '\n',
        'a', 's', 'c', 'e', 'n', 's', 'i', 'o', 'n', '\n',
        'a', 's', 'c', 'e', 'n', 's', 'i', 'o', 'n', 's', '\n',
        'a', 's', 'c', 'e', 'n', 't', '\n',
        'a', 's', 'c', 'e', 'n', 't', 's', '\n',
        'a', 's', 'c', 'e', 'r', 't', 'a', 'i', 'n', '\n',
        'a', 's', 'c', 'e', 'r', 't', 'a', 'i', 'n', 'a', 'b', 'l', 'e', '\n',
        'a', 's', 'c', 'e', 'r', 't', 'a', 'i', 'n', 'e', 'd', '\n',
        'a', 's', 'c', 'e', 'r', 't', 'a', 'i', 'n', 'i', 'n', 'g', '\n',
        'a', 's', 'c', 'e', 'r', 't', 'a', 'i', 'n', 'm', 'e', 'n', 't', '\n',
        'a', 's', 'c', 'e', 'r', 't', 'a', 'i', 'n', 's', '\n',
        'a', 's', 'c', 'e', 't', 'i', 'c', '\n',
        'a', 's', 'c', 'e', 't', 'i', 'c', 'i', 's', 'm', '\n',
        'a', 's', 'c', 'e', 't', 'i', 'c', 's', '\n',
        'a', 's', 'c', 'o', 'r', 'b', 'i', 'c', '\n',
        'a', 's', 'c', 'r', 'i', 'b', 'a', 'b', 'l', 'e', '\n',
        'a', 's', 'c', 'r', 'i', 'b', 'e', '\n',
        'a', 's', 'c', 'r', 'i', 'b', 'e', 'd', '\n',
        'a', 's', 'c', 'r', 'i', 'b', 'e', 's', '\n',
        'a', 's', 'c', 'r', 'i', 'b', 'i', 'n', 'g', '\n',
        'a', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', '\n',
        'a', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', 's', '\n',
        'a', 's', 'e', 'p', 't', 'i', 'c', '\n',
        'a', 's', 'e', 'x', 'u', 'a', 'l', '\n',
        'a', 's', 'h', '\n',
        'a', 's', 'h', 'a', 'm', 'e', 'd', '\n',
        'a', 's', 'h', 'a', 'm', 'e', 'd', 'l', 'y', '\n',
        'a', 's', 'h', 'b', 'i', 'n', '\n',
        'a', 's', 'h', 'b', 'i', 'n', 's', '\n',
        'a', 's', 'h', 'c', 'a', 'n', 's', '\n',
        'a', 's', 'h', 'e', 'n', '\n',
        'a', 's', 'h', 'e', 's', '\n',
        'a', 's', 'h', 'o', 'r', 'e', '\n',
        'a', 's', 'h', 't', 'r', 'a', 'y', '\n',
        'a', 's', 'h', 't', 'r', 'a', 'y', 's', '\n',
        'a', 's', 'h', 'y', '\n',
        'a', 's', 'i', 'a', '\n',
        'a', 's', 'i', 'a', 'n', '\n',
        'a', 's', 'i', 'a', 'n', 's', '\n',
        'a', 's', 'i', 'a', 't', 'i', 'c', '\n',
        'a', 's', 'i', 'd', 'e', '\n',
        'a', 's', 'i', 'd', 'e', 's', '\n',
        'a', 's', 'i', 'n', 'i', 'n', 'e', '\n',
        'a', 's', 'k', '\n',
        'a', 's', 'k', 'a', 'n', 'c', 'e', '\n',
        'a', 's', 'k', 'e', 'd', '\n',
        'a', 's', 'k', 'e', 'r', 's', '\n',
        'a', 's', 'k', 'e', 'w', '\n',
        'a', 's', 'k', 'i', 'n', 'g', '\n',
        'a', 's', 'k', 's', '\n',
        'a', 's', 'l', 'a', 'n', 't', '\n',
        'a', 's', 'l', 'e', 'e', 'p', '\n',
        'a', 's', 'o', 'c', 'i', 'a', 'l', '\n',
        'a', 's', 'p', '\n',
        'a', 's', 'p', 'a', 'r', 'a', 'g', 'u', 's', '\n',
        'a', 's', 'p', 'e', 'c', 't', '\n',
        'a', 's', 'p', 'e', 'c', 't', 's', '\n',
        'a', 's', 'p', 'e', 'r', 'i', 't', 'y', '\n',
        'a', 's', 'p', 'e', 'r', 's', 'i', 'o', 'n', '\n',
        'a', 's', 'p', 'e', 'r', 's', 'i', 'o', 'n', 's', '\n',
        'a', 's', 'p', 'h', 'a', 'l', 't', '\n',
        'a', 's', 'p', 'h', 'y', 'x', 'i', 'a', '\n',
        'a', 's', 'p', 'h', 'y', 'x', 'i', 'a', 't', 'e', '\n',
        'a', 's', 'p', 'h', 'y', 'x', 'i', 'a', 't', 'e', 'd', '\n',
        'a', 's', 'p', 'h', 'y', 'x', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 's', 'p', 'i', 'c', '\n',
        'a', 's', 'p', 'i', 'd', 'i', 's', 't', 'r', 'a', '\n',
        'a', 's', 'p', 'i', 'r', 'a', 'n', 't', '\n',
        'a', 's', 'p', 'i', 'r', 'a', 'n', 't', 's', '\n',
        'a', 's', 'p', 'i', 'r', 'a', 't', 'e', '\n',
        'a', 's', 'p', 'i', 'r', 'a', 't', 'e', 'd', '\n',
        'a', 's', 'p', 'i', 'r', 'a', 't', 'e', 's', '\n',
        'a', 's', 'p', 'i', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 's', 'p', 'i', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 's', 'p', 'i', 'r', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'a', 's', 'p', 'i', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 's', 'p', 'i', 'r', 'a', 't', 'o', 'r', 's', '\n',
        'a', 's', 'p', 'i', 'r', 'e', '\n',
        'a', 's', 'p', 'i', 'r', 'e', 'd', '\n',
        'a', 's', 'p', 'i', 'r', 'e', 's', '\n',
        'a', 's', 'p', 'i', 'r', 'i', 'n', '\n',
        'a', 's', 'p', 'i', 'r', 'i', 'n', 'g', '\n',
        'a', 's', 'p', 'i', 'r', 'i', 'n', 's', '\n',
        'a', 's', 'p', 's', '\n',
        'a', 's', 's', '\n',
        'a', 's', 's', 'a', 'i', 'l', '\n',
        'a', 's', 's', 'a', 'i', 'l', 'a', 'b', 'l', 'e', '\n',
        'a', 's', 's', 'a', 'i', 'l', 'a', 'n', 't', '\n',
        'a', 's', 's', 'a', 'i', 'l', 'a', 'n', 't', 's', '\n',
        'a', 's', 's', 'a', 'i', 'l', 'e', 'd', '\n',
        'a', 's', 's', 'a', 'i', 'l', 'i', 'n', 'g', '\n',
        'a', 's', 's', 'a', 'i', 'l', 's', '\n',
        'a', 's', 's', 'a', 's', 's', 'i', 'n', '\n',
        'a', 's', 's', 'a', 's', 's', 'i', 'n', 'a', 't', 'e', '\n',
        'a', 's', 's', 'a', 's', 's', 'i', 'n', 'a', 't', 'e', 'd', '\n',
        'a', 's', 's', 'a', 's', 's', 'i', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 's', 's', 'a', 's', 's', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 's', 's', 'a', 's', 's', 'i', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 's', 's', 'a', 's', 's', 'i', 'n', 's', '\n',
        'a', 's', 's', 'a', 'u', 'l', 't', '\n',
        'a', 's', 's', 'a', 'u', 'l', 't', 'e', 'd', '\n',
        'a', 's', 's', 'a', 'u', 'l', 't', 'i', 'n', 'g', '\n',
        'a', 's', 's', 'a', 'u', 'l', 't', 's', '\n',
        'a', 's', 's', 'a', 'y', '\n',
        'a', 's', 's', 'a', 'y', 'e', 'd', '\n',
        'a', 's', 's', 'a', 'y', 'e', 'r', '\n',
        'a', 's', 's', 'a', 'y', 's', '\n',
        'a', 's', 's', 'e', 'g', 'a', 'i', '\n',
        'a', 's', 's', 'e', 'g', 'a', 'i', 's', '\n',
        'a', 's', 's', 'e', 'm', 'b', 'l', 'a', 'g', 'e', '\n',
        'a', 's', 's', 'e', 'm', 'b', 'l', 'a', 'g', 'e', 's', '\n',
        'a', 's', 's', 'e', 'm', 'b', 'l', 'e', '\n',
        'a', 's', 's', 'e', 'm', 'b', 'l', 'e', 'd', '\n',
        'a', 's', 's', 'e', 'm', 'b', 'l', 'e', 'r', '\n',
        'a', 's', 's', 'e', 'm', 'b', 'l', 'e', 'r', 's', '\n',
        'a', 's', 's', 'e', 'm', 'b', 'l', 'e', 's', '\n',
        'a', 's', 's', 'e', 'm', 'b', 'l', 'i', 'e', 's', '\n',
        'a', 's', 's', 'e', 'm', 'b', 'l', 'i', 'n', 'g', '\n',
        'a', 's', 's', 'e', 'm', 'b', 'l', 'y', '\n',
        'a', 's', 's', 'e', 'n', 't', '\n',
        'a', 's', 's', 'e', 'n', 't', 'e', 'd', '\n',
        'a', 's', 's', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'a', 's', 's', 'e', 'n', 't', 's', '\n',
        'a', 's', 's', 'e', 'r', 't', '\n',
        'a', 's', 's', 'e', 'r', 't', 'e', 'd', '\n',
        'a', 's', 's', 'e', 'r', 't', 'i', 'n', 'g', '\n',
        'a', 's', 's', 'e', 'r', 't', 'i', 'o', 'n', '\n',
        'a', 's', 's', 'e', 'r', 't', 'i', 'o', 'n', 's', '\n',
        'a', 's', 's', 'e', 'r', 't', 'i', 'v', 'e', '\n',
        'a', 's', 's', 'e', 'r', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'a', 's', 's', 'e', 'r', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'a', 's', 's', 'e', 'r', 't', 's', '\n',
        'a', 's', 's', 'e', 's', '\n',
        'a', 's', 's', 'e', 's', 's', '\n',
        'a', 's', 's', 'e', 's', 's', 'a', 'b', 'l', 'e', '\n',
        'a', 's', 's', 'e', 's', 's', 'e', 'd', '\n',
        'a', 's', 's', 'e', 's', 's', 'e', 's', '\n',
        'a', 's', 's', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'a', 's', 's', 'e', 's', 's', 'm', 'e', 'n', 't', '\n',
        'a', 's', 's', 'e', 's', 's', 'm', 'e', 'n', 't', 's', '\n',
        'a', 's', 's', 'e', 's', 's', 'o', 'r', '\n',
        'a', 's', 's', 'e', 's', 's', 'o', 'r', 's', '\n',
        'a', 's', 's', 'e', 't', '\n',
        'a', 's', 's', 'e', 't', 's', '\n',
        'a', 's', 's', 'i', 'd', 'u', 'i', 't', 'y', '\n',
        'a', 's', 's', 'i', 'd', 'u', 'o', 'u', 's', '\n',
        'a', 's', 's', 'i', 'd', 'u', 'o', 'u', 's', 'l', 'y', '\n',
        'a', 's', 's', 'i', 'g', 'n', '\n',
        'a', 's', 's', 'i', 'g', 'n', 'a', 'b', 'l', 'e', '\n',
        'a', 's', 's', 'i', 'g', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 's', 's', 'i', 'g', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 's', 's', 'i', 'g', 'n', 'e', 'd', '\n',
        'a', 's', 's', 'i', 'g', 'n', 'e', 'e', 's', '\n',
        'a', 's', 's', 'i', 'g', 'n', 'e', 'r', '\n',
        'a', 's', 's', 'i', 'g', 'n', 'i', 'n', 'g', '\n',
        'a', 's', 's', 'i', 'g', 'n', 'm', 'e', 'n', 't', '\n',
        'a', 's', 's', 'i', 'g', 'n', 'm', 'e', 'n', 't', 's', '\n',
        'a', 's', 's', 'i', 'g', 'n', 's', '\n',
        'a', 's', 's', 'i', 'm', 'i', 'l', 'a', 'b', 'l', 'e', '\n',
        'a', 's', 's', 'i', 'm', 'i', 'l', 'a', 't', 'e', '\n',
        'a', 's', 's', 'i', 'm', 'i', 'l', 'a', 't', 'e', 'd', '\n',
        'a', 's', 's', 'i', 'm', 'i', 'l', 'a', 't', 'e', 's', '\n',
        'a', 's', 's', 'i', 'm', 'i', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 's', 's', 'i', 'm', 'i', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 's', 's', 'i', 's', 't', '\n',
        'a', 's', 's', 'i', 's', 't', 'a', 'n', 'c', 'e', '\n',
        'a', 's', 's', 'i', 's', 't', 'a', 'n', 't', '\n',
        'a', 's', 's', 'i', 's', 't', 'a', 'n', 't', 's', '\n',
        'a', 's', 's', 'i', 's', 't', 'e', 'd', '\n',
        'a', 's', 's', 'i', 's', 't', 'i', 'n', 'g', '\n',
        'a', 's', 's', 'i', 's', 't', 's', '\n',
        'a', 's', 's', 'i', 'z', 'e', 's', '\n',
        'a', 's', 's', 'o', 'c', 'i', 'a', 't', 'e', '\n',
        'a', 's', 's', 'o', 'c', 'i', 'a', 't', 'e', 'd', '\n',
        'a', 's', 's', 'o', 'c', 'i', 'a', 't', 'e', 's', '\n',
        'a', 's', 's', 'o', 'c', 'i', 'a', 't', 'e', 's', 'h', 'i', 'p', '\n',
        'a', 's', 's', 'o', 'c', 'i', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 's', 's', 'o', 'c', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 's', 's', 'o', 'c', 'i', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'a', 's', 's', 'o', 'c', 'i', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 's', 's', 'o', 'c', 'i', 'a', 't', 'i', 'v', 'e', '\n',
        'a', 's', 's', 'o', 'c', 'i', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'a', 's', 's', 'o', 'c', 'i', 'a', 't', 'i', 'v', 'i', 't', 'y', '\n',
        'a', 's', 's', 'o', 'n', 'a', 'n', 'c', 'e', '\n',
        'a', 's', 's', 'o', 'r', 't', '\n',
        'a', 's', 's', 'o', 'r', 't', 'e', 'd', '\n',
        'a', 's', 's', 'o', 'r', 't', 'm', 'e', 'n', 't', '\n',
        'a', 's', 's', 'o', 'r', 't', 'm', 'e', 'n', 't', 's', '\n',
        'a', 's', 's', 'u', 'a', 'g', 'e', '\n',
        'a', 's', 's', 'u', 'a', 'g', 'e', 'd', '\n',
        'a', 's', 's', 'u', 'a', 'g', 'e', 's', '\n',
        'a', 's', 's', 'u', 'a', 'g', 'i', 'n', 'g', '\n',
        'a', 's', 's', 'u', 'm', 'e', '\n',
        'a', 's', 's', 'u', 'm', 'e', 'd', '\n',
        'a', 's', 's', 'u', 'm', 'e', 's', '\n',
        'a', 's', 's', 'u', 'm', 'i', 'n', 'g', '\n',
        'a', 's', 's', 'u', 'm', 'p', 't', 'i', 'o', 'n', '\n',
        'a', 's', 's', 'u', 'm', 'p', 't', 'i', 'o', 'n', 's', '\n',
        'a', 's', 's', 'u', 'r', 'a', 'n', 'c', 'e', '\n',
        'a', 's', 's', 'u', 'r', 'a', 'n', 'c', 'e', 's', '\n',
        'a', 's', 's', 'u', 'r', 'e', '\n',
        'a', 's', 's', 'u', 'r', 'e', 'd', '\n',
        'a', 's', 's', 'u', 'r', 'e', 'd', 'l', 'y', '\n',
        'a', 's', 's', 'u', 'r', 'e', 's', '\n',
        'a', 's', 's', 'u', 'r', 'i', 'n', 'g', '\n',
        'a', 's', 's', 'y', 'r', 'i', 'a', '\n',
        'a', 's', 's', 'y', 'r', 'i', 'a', 'n', '\n',
        'a', 's', 't', 'e', 'r', '\n',
        'a', 's', 't', 'e', 'r', 'i', 's', 'k', '\n',
        'a', 's', 't', 'e', 'r', 'i', 's', 'k', 'e', 'd', '\n',
        'a', 's', 't', 'e', 'r', 'i', 's', 'k', 's', '\n',
        'a', 's', 't', 'e', 'r', 'n', '\n',
        'a', 's', 't', 'e', 'r', 'o', 'i', 'd', '\n',
        'a', 's', 't', 'e', 'r', 'o', 'i', 'd', 's', '\n',
        'a', 's', 't', 'e', 'r', 's', '\n',
        'a', 's', 't', 'h', 'm', 'a', '\n',
        'a', 's', 't', 'h', 'm', 'a', 't', 'i', 'c', '\n',
        'a', 's', 't', 'h', 'm', 'a', 't', 'i', 'c', 's', '\n',
        'a', 's', 't', 'i', 'g', 'm', 'a', 't', 'i', 'c', '\n',
        'a', 's', 't', 'i', 'g', 'm', 'a', 't', 'i', 's', 'm', '\n',
        'a', 's', 't', 'i', 'r', '\n',
        'a', 's', 't', 'o', 'n', 'i', 's', 'h', '\n',
        'a', 's', 't', 'o', 'n', 'i', 's', 'h', 'e', 'd', '\n',
        'a', 's', 't', 'o', 'n', 'i', 's', 'h', 'e', 's', '\n',
        'a', 's', 't', 'o', 'n', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'a', 's', 't', 'o', 'n', 'i', 's', 'h', 'i', 'n', 'g', 'l', 'y', '\n',
        'a', 's', 't', 'o', 'n', 'i', 's', 'h', 'm', 'e', 'n', 't', '\n',
        'a', 's', 't', 'o', 'u', 'n', 'd', '\n',
        'a', 's', 't', 'o', 'u', 'n', 'd', 'e', 'd', '\n',
        'a', 's', 't', 'o', 'u', 'n', 'd', 'i', 'n', 'g', '\n',
        'a', 's', 't', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 'l', 'y', '\n',
        'a', 's', 't', 'o', 'u', 'n', 'd', 's', '\n',
        'a', 's', 't', 'r', 'a', 'd', 'd', 'l', 'e', '\n',
        'a', 's', 't', 'r', 'a', 'l', '\n',
        'a', 's', 't', 'r', 'a', 'l', 'l', 'y', '\n',
        'a', 's', 't', 'r', 'a', 'y', '\n',
        'a', 's', 't', 'r', 'i', 'd', 'e', '\n',
        'a', 's', 't', 'r', 'i', 'n', 'g', 'e', 'n', 't', '\n',
        'a', 's', 't', 'r', 'o', 'l', 'a', 'b', 'e', '\n',
        'a', 's', 't', 'r', 'o', 'l', 'a', 'b', 'e', 's', '\n',
        'a', 's', 't', 'r', 'o', 'l', 'o', 'g', 'e', 'r', '\n',
        'a', 's', 't', 'r', 'o', 'l', 'o', 'g', 'e', 'r', 's', '\n',
        'a', 's', 't', 'r', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'a', 's', 't', 'r', 'o', 'l', 'o', 'g', 'y', '\n',
        'a', 's', 't', 'r', 'o', 'n', 'a', 'u', 't', '\n',
        'a', 's', 't', 'r', 'o', 'n', 'a', 'u', 't', 'i', 'c', 'a', 'l', '\n',
        'a', 's', 't', 'r', 'o', 'n', 'a', 'u', 't', 'i', 'c', 's', '\n',
        'a', 's', 't', 'r', 'o', 'n', 'a', 'u', 't', 's', '\n',
        'a', 's', 't', 'r', 'o', 'n', 'o', 'm', 'e', 'r', '\n',
        'a', 's', 't', 'r', 'o', 'n', 'o', 'm', 'e', 'r', 's', '\n',
        'a', 's', 't', 'r', 'o', 'n', 'o', 'm', 'i', 'c', '\n',
        'a', 's', 't', 'r', 'o', 'n', 'o', 'm', 'i', 'c', 'a', 'l', '\n',
        'a', 's', 't', 'r', 'o', 'n', 'o', 'm', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 's', 't', 'r', 'o', 'n', 'o', 'm', 'y', '\n',
        'a', 's', 't', 'r', 'o', 'p', 'h', 'y', 's', 'i', 'c', 'a', 'l', '\n',
        'a', 's', 't', 'r', 'o', 'p', 'h', 'y', 's', 'i', 'c', 'i', 's', 't', '\n',
        'a', 's', 't', 'r', 'o', 'p', 'h', 'y', 's', 'i', 'c', 'i', 's', 't', 's', '\n',
        'a', 's', 't', 'r', 'o', 'p', 'h', 'y', 's', 'i', 'c', 's', '\n',
        'a', 's', 't', 'u', 't', 'e', '\n',
        'a', 's', 't', 'u', 't', 'e', 'l', 'y', '\n',
        'a', 's', 't', 'u', 't', 'e', 'n', 'e', 's', 's', '\n',
        'a', 's', 'u', 'n', 'd', 'e', 'r', '\n',
        'a', 's', 'w', 'a', 'n', '\n',
        'a', 's', 'y', 'l', 'u', 'm', '\n',
        'a', 's', 'y', 'l', 'u', 'm', 's', '\n',
        'a', 's', 'y', 'm', 'm', 'e', 't', 'r', 'i', 'c', '\n',
        'a', 's', 'y', 'm', 'm', 'e', 't', 'r', 'i', 'c', 'a', 'l', '\n',
        'a', 's', 'y', 'm', 'm', 'e', 't', 'r', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 's', 'y', 'm', 'm', 'e', 't', 'r', 'i', 'e', 's', '\n',
        'a', 's', 'y', 'm', 'm', 'e', 't', 'r', 'y', '\n',
        'a', 's', 'y', 'm', 'p', 't', 'o', 'm', 'a', 't', 'i', 'c', '\n',
        'a', 's', 'y', 'm', 'p', 't', 'o', 't', 'e', '\n',
        'a', 's', 'y', 'm', 'p', 't', 'o', 't', 'e', 's', '\n',
        'a', 's', 'y', 'm', 'p', 't', 'o', 't', 'i', 'c', '\n',
        'a', 's', 'y', 'm', 'p', 't', 'o', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 's', 'y', 'n', 'c', 'h', 'r', 'o', 'n', 'o', 'u', 's', '\n',
        'a', 's', 'y', 'n', 'c', 'h', 'r', 'o', 'n', 'o', 'u', 's', 'l', 'y', '\n',
        'a', 't', '\n',
        'a', 't', 'a', 'v', 'i', 's', 'm', '\n',
        'a', 't', 'a', 'v', 'i', 's', 't', 'i', 'c', '\n',
        'a', 't', 'e', '\n',
        'a', 't', 'e', 'l', 'i', 'e', 'r', '\n',
        'a', 't', 'h', 'e', 'i', 's', 'm', '\n',
        'a', 't', 'h', 'e', 'i', 's', 't', '\n',
        'a', 't', 'h', 'e', 'i', 's', 't', 'i', 'c', '\n',
        'a', 't', 'h', 'e', 'i', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 't', 'h', 'e', 'i', 's', 't', 's', '\n',
        'a', 't', 'h', 'e', 'n', 'a', '\n',
        'a', 't', 'h', 'e', 'n', 's', '\n',
        'a', 't', 'h', 'e', 'r', 'o', 's', 'c', 'l', 'e', 'r', 'o', 's', 'i', 's', '\n',
        'a', 't', 'h', 'l', 'e', 't', 'e', '\n',
        'a', 't', 'h', 'l', 'e', 't', 'e', 's', '\n',
        'a', 't', 'h', 'l', 'e', 't', 'i', 'c', '\n',
        'a', 't', 'h', 'l', 'e', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 't', 'h', 'l', 'e', 't', 'i', 'c', 'i', 's', 'm', '\n',
        'a', 't', 'h', 'l', 'e', 't', 'i', 'c', 's', '\n',
        'a', 't', 'l', 'a', 'n', 't', 'a', '\n',
        'a', 't', 'l', 'a', 'n', 't', 'i', 'c', '\n',
        'a', 't', 'l', 'a', 'n', 't', 'i', 's', '\n',
        'a', 't', 'l', 'a', 's', '\n',
        'a', 't', 'l', 'a', 's', 'e', 's', '\n',
        'a', 't', 'm', 'o', 's', 'p', 'h', 'e', 'r', 'e', '\n',
        'a', 't', 'm', 'o', 's', 'p', 'h', 'e', 'r', 'e', 's', '\n',
        'a', 't', 'm', 'o', 's', 'p', 'h', 'e', 'r', 'i', 'c', '\n',
        'a', 't', 'm', 'o', 's', 'p', 'h', 'e', 'r', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 't', 'm', 'o', 's', 'p', 'h', 'e', 'r', 'i', 'c', 's', '\n',
        'a', 't', 'o', 'l', 'l', '\n',
        'a', 't', 'o', 'l', 'l', 's', '\n',
        'a', 't', 'o', 'm', '\n',
        'a', 't', 'o', 'm', 'b', 'o', 'm', 'b', '\n',
        'a', 't', 'o', 'm', 'i', 'c', '\n',
        'a', 't', 'o', 'm', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 't', 'o', 'm', 'i', 'c', 'i', 't', 'y', '\n',
        'a', 't', 'o', 'm', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 't', 'o', 'm', 'i', 's', 'e', 'd', '\n',
        'a', 't', 'o', 'm', 'i', 's', 't', 'i', 'c', '\n',
        'a', 't', 'o', 'm', 's', '\n',
        'a', 't', 'o', 'n', 'a', 'l', '\n',
        'a', 't', 'o', 'n', 'a', 'l', 'i', 't', 'y', '\n',
        'a', 't', 'o', 'n', 'e', '\n',
        'a', 't', 'o', 'n', 'e', 'd', '\n',
        'a', 't', 'o', 'n', 'e', 'm', 'e', 'n', 't', '\n',
        'a', 't', 'o', 'n', 'e', 's', '\n',
        'a', 't', 'o', 'n', 'i', 'c', '\n',
        'a', 't', 'o', 'n', 'i', 'n', 'g', '\n',
        'a', 't', 'o', 'p', '\n',
        'a', 't', 'r', 'i', 'a', 'l', '\n',
        'a', 't', 'r', 'i', 'u', 'm', '\n',
        'a', 't', 'r', 'o', 'c', 'i', 'o', 'u', 's', '\n',
        'a', 't', 'r', 'o', 'c', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'a', 't', 'r', 'o', 'c', 'i', 't', 'i', 'e', 's', '\n',
        'a', 't', 'r', 'o', 'c', 'i', 't', 'y', '\n',
        'a', 't', 'r', 'o', 'p', 'h', 'i', 'e', 'd', '\n',
        'a', 't', 'r', 'o', 'p', 'h', 'i', 'e', 's', '\n',
        'a', 't', 'r', 'o', 'p', 'h', 'y', '\n',
        'a', 't', 'r', 'o', 'p', 'h', 'y', 'i', 'n', 'g', '\n',
        'a', 't', 'r', 'o', 'p', 'i', 'n', 'e', '\n',
        'a', 't', 't', 'a', 'c', 'h', '\n',
        'a', 't', 't', 'a', 'c', 'h', 'a', 'b', 'l', 'e', '\n',
        'a', 't', 't', 'a', 'c', 'h', 'e', '\n',
        'a', 't', 't', 'a', 'c', 'h', 'e', 'd', '\n',
        'a', 't', 't', 'a', 'c', 'h', 'e', 's', '\n',
        'a', 't', 't', 'a', 'c', 'h', 'i', 'n', 'g', '\n',
        'a', 't', 't', 'a', 'c', 'h', 'm', 'e', 'n', 't', '\n',
        'a', 't', 't', 'a', 'c', 'h', 'm', 'e', 'n', 't', 's', '\n',
        'a', 't', 't', 'a', 'c', 'k', '\n',
        'a', 't', 't', 'a', 'c', 'k', 'e', 'd', '\n',
        'a', 't', 't', 'a', 'c', 'k', 'e', 'r', '\n',
        'a', 't', 't', 'a', 'c', 'k', 'e', 'r', 's', '\n',
        'a', 't', 't', 'a', 'c', 'k', 'i', 'n', 'g', '\n',
        'a', 't', 't', 'a', 'c', 'k', 's', '\n',
        'a', 't', 't', 'a', 'i', 'n', '\n',
        'a', 't', 't', 'a', 'i', 'n', 'a', 'b', 'l', 'e', '\n',
        'a', 't', 't', 'a', 'i', 'n', 'e', 'd', '\n',
        'a', 't', 't', 'a', 'i', 'n', 'i', 'n', 'g', '\n',
        'a', 't', 't', 'a', 'i', 'n', 'm', 'e', 'n', 't', '\n',
        'a', 't', 't', 'a', 'i', 'n', 'm', 'e', 'n', 't', 's', '\n',
        'a', 't', 't', 'a', 'i', 'n', 's', '\n',
        'a', 't', 't', 'e', 'm', 'p', 't', '\n',
        'a', 't', 't', 'e', 'm', 'p', 't', 'e', 'd', '\n',
        'a', 't', 't', 'e', 'm', 'p', 't', 'i', 'n', 'g', '\n',
        'a', 't', 't', 'e', 'm', 'p', 't', 's', '\n',
        'a', 't', 't', 'e', 'n', 'd', '\n',
        'a', 't', 't', 'e', 'n', 'd', 'a', 'n', 'c', 'e', '\n',
        'a', 't', 't', 'e', 'n', 'd', 'a', 'n', 'c', 'e', 's', '\n',
        'a', 't', 't', 'e', 'n', 'd', 'a', 'n', 't', '\n',
        'a', 't', 't', 'e', 'n', 'd', 'a', 'n', 't', 's', '\n',
        'a', 't', 't', 'e', 'n', 'd', 'e', 'd', '\n',
        'a', 't', 't', 'e', 'n', 'd', 'e', 'e', 's', '\n',
        'a', 't', 't', 'e', 'n', 'd', 'e', 'r', '\n',
        'a', 't', 't', 'e', 'n', 'd', 'e', 'r', 's', '\n',
        'a', 't', 't', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'a', 't', 't', 'e', 'n', 'd', 's', '\n',
        'a', 't', 't', 'e', 'n', 't', 'i', 'o', 'n', '\n',
        'a', 't', 't', 'e', 'n', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'a', 't', 't', 'e', 'n', 't', 'i', 'o', 'n', 's', '\n',
        'a', 't', 't', 'e', 'n', 't', 'i', 'v', 'e', '\n',
        'a', 't', 't', 'e', 'n', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'a', 't', 't', 'e', 'n', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'a', 't', 't', 'e', 'n', 'u', 'a', 't', 'e', '\n',
        'a', 't', 't', 'e', 'n', 'u', 'a', 't', 'e', 'd', '\n',
        'a', 't', 't', 'e', 'n', 'u', 'a', 't', 'e', 's', '\n',
        'a', 't', 't', 'e', 'n', 'u', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 't', 't', 'e', 'n', 'u', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 't', 't', 'e', 'n', 'u', 'a', 't', 'o', 'r', '\n',
        'a', 't', 't', 'e', 'n', 'u', 'a', 't', 'o', 'r', 's', '\n',
        'a', 't', 't', 'e', 's', 't', '\n',
        'a', 't', 't', 'e', 's', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 't', 't', 'e', 's', 't', 'e', 'd', '\n',
        'a', 't', 't', 'e', 's', 't', 'i', 'n', 'g', '\n',
        'a', 't', 't', 'e', 's', 't', 's', '\n',
        'a', 't', 't', 'i', 'c', '\n',
        'a', 't', 't', 'i', 'c', 's', '\n',
        'a', 't', 't', 'i', 'l', 'a', '\n',
        'a', 't', 't', 'i', 'r', 'e', '\n',
        'a', 't', 't', 'i', 'r', 'e', 'd', '\n',
        'a', 't', 't', 'i', 'r', 'i', 'n', 'g', '\n',
        'a', 't', 't', 'i', 't', 'u', 'd', 'e', '\n',
        'a', 't', 't', 'i', 't', 'u', 'd', 'e', 's', '\n',
        'a', 't', 't', 'i', 't', 'u', 'd', 'i', 'n', 'a', 'l', '\n',
        'a', 't', 't', 'o', 'r', 'n', 'e', 'y', '\n',
        'a', 't', 't', 'o', 'r', 'n', 'e', 'y', 's', '\n',
        'a', 't', 't', 'r', 'a', 'c', 't', '\n',
        'a', 't', 't', 'r', 'a', 'c', 't', 'e', 'd', '\n',
        'a', 't', 't', 'r', 'a', 'c', 't', 'i', 'n', 'g', '\n',
        'a', 't', 't', 'r', 'a', 'c', 't', 'i', 'o', 'n', '\n',
        'a', 't', 't', 'r', 'a', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'a', 't', 't', 'r', 'a', 'c', 't', 'i', 'v', 'e', '\n',
        'a', 't', 't', 'r', 'a', 'c', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'a', 't', 't', 'r', 'a', 'c', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'a', 't', 't', 'r', 'a', 'c', 't', 'o', 'r', '\n',
        'a', 't', 't', 'r', 'a', 'c', 't', 'o', 'r', 's', '\n',
        'a', 't', 't', 'r', 'a', 'c', 't', 's', '\n',
        'a', 't', 't', 'r', 'i', 'b', 'u', 't', 'a', 'b', 'l', 'e', '\n',
        'a', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', '\n',
        'a', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'd', '\n',
        'a', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 's', '\n',
        'a', 't', 't', 'r', 'i', 'b', 'u', 't', 'i', 'n', 'g', '\n',
        'a', 't', 't', 'r', 'i', 'b', 'u', 't', 'i', 'o', 'n', '\n',
        'a', 't', 't', 'r', 'i', 'b', 'u', 't', 'i', 'o', 'n', 's', '\n',
        'a', 't', 't', 'r', 'i', 'b', 'u', 't', 'i', 'v', 'e', '\n',
        'a', 't', 't', 'r', 'i', 't', 'i', 'o', 'n', '\n',
        'a', 't', 't', 'r', 'i', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'a', 't', 't', 'u', 'n', 'e', '\n',
        'a', 't', 't', 'u', 'n', 'e', 'd', '\n',
        'a', 't', 'y', 'p', 'i', 'c', 'a', 'l', '\n',
        'a', 't', 'y', 'p', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 'u', 'b', 'e', 'r', 'g', 'i', 'n', 'e', '\n',
        'a', 'u', 'b', 'e', 'r', 'g', 'i', 'n', 'e', 's', '\n',
        'a', 'u', 'b', 'u', 'r', 'n', '\n',
        'a', 'u', 'c', 't', 'i', 'o', 'n', '\n',
        'a', 'u', 'c', 't', 'i', 'o', 'n', 'e', 'd', '\n',
        'a', 'u', 'c', 't', 'i', 'o', 'n', 'e', 'e', 'r', '\n',
        'a', 'u', 'c', 't', 'i', 'o', 'n', 'e', 'e', 'r', 's', '\n',
        'a', 'u', 'c', 't', 'i', 'o', 'n', 'i', 'n', 'g', '\n',
        'a', 'u', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'u', 'd', 'a', 'c', 'i', 'o', 'u', 's', '\n',
        'a', 'u', 'd', 'a', 'c', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'a', 'u', 'd', 'a', 'c', 'i', 't', 'y', '\n',
        'a', 'u', 'd', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'a', 'u', 'd', 'i', 'b', 'l', 'e', '\n',
        'a', 'u', 'd', 'i', 'b', 'l', 'y', '\n',
        'a', 'u', 'd', 'i', 'e', 'n', 'c', 'e', '\n',
        'a', 'u', 'd', 'i', 'e', 'n', 'c', 'e', 's', '\n',
        'a', 'u', 'd', 'i', 'o', '\n',
        'a', 'u', 'd', 'i', 'o', 'v', 'i', 's', 'u', 'a', 'l', '\n',
        'a', 'u', 'd', 'i', 't', '\n',
        'a', 'u', 'd', 'i', 't', 'e', 'd', '\n',
        'a', 'u', 'd', 'i', 't', 'i', 'n', 'g', '\n',
        'a', 'u', 'd', 'i', 't', 'i', 'o', 'n', '\n',
        'a', 'u', 'd', 'i', 't', 'i', 'o', 'n', 'e', 'd', '\n',
        'a', 'u', 'd', 'i', 't', 'i', 'o', 'n', 'i', 'n', 'g', '\n',
        'a', 'u', 'd', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'u', 'd', 'i', 't', 'i', 'v', 'e', '\n',
        'a', 'u', 'd', 'i', 't', 'o', 'r', '\n',
        'a', 'u', 'd', 'i', 't', 'o', 'r', 'i', 'u', 'm', '\n',
        'a', 'u', 'd', 'i', 't', 'o', 'r', 's', '\n',
        'a', 'u', 'd', 'i', 't', 'o', 'r', 'y', '\n',
        'a', 'u', 'd', 'i', 't', 's', '\n',
        'a', 'u', 'g', 'e', 'r', '\n',
        'a', 'u', 'g', 'e', 'r', 's', '\n',
        'a', 'u', 'g', 'i', 't', 'e', '\n',
        'a', 'u', 'g', 'm', 'e', 'n', 't', '\n',
        'a', 'u', 'g', 'm', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'u', 'g', 'm', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'u', 'g', 'm', 'e', 'n', 't', 'e', 'd', '\n',
        'a', 'u', 'g', 'm', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'a', 'u', 'g', 'm', 'e', 'n', 't', 's', '\n',
        'a', 'u', 'g', 'u', 'r', '\n',
        'a', 'u', 'g', 'u', 'r', 'e', 'd', '\n',
        'a', 'u', 'g', 'u', 'r', 's', '\n',
        'a', 'u', 'g', 'u', 'r', 'y', '\n',
        'a', 'u', 'g', 'u', 's', 't', '\n',
        'a', 'u', 'g', 'u', 's', 't', 'u', 's', '\n',
        'a', 'u', 'k', '\n',
        'a', 'u', 'k', 's', '\n',
        'a', 'u', 'n', 't', '\n',
        'a', 'u', 'n', 't', 'i', 'e', '\n',
        'a', 'u', 'n', 't', 'i', 'e', 's', '\n',
        'a', 'u', 'n', 't', 's', '\n',
        'a', 'u', 'p', 'a', 'i', 'r', '\n',
        'a', 'u', 'p', 'a', 'i', 'r', 's', '\n',
        'a', 'u', 'r', 'a', '\n',
        'a', 'u', 'r', 'a', 'l', '\n',
        'a', 'u', 'r', 'a', 'l', 'l', 'y', '\n',
        'a', 'u', 'r', 'a', 's', '\n',
        'a', 'u', 'r', 'e', 'v', 'o', 'i', 'r', '\n',
        'a', 'u', 'r', 'i', 'c', '\n',
        'a', 'u', 'r', 'i', 'c', 'u', 'l', 'a', 's', '\n',
        'a', 'u', 'r', 'o', 'r', 'a', '\n',
        'a', 'u', 'r', 'o', 'r', 'a', 'e', '\n',
        'a', 'u', 'r', 'o', 'r', 'a', 'l', '\n',
        'a', 'u', 'r', 'o', 'r', 'a', 's', '\n',
        'a', 'u', 's', 'p', 'i', 'c', 'e', '\n',
        'a', 'u', 's', 'p', 'i', 'c', 'e', 's', '\n',
        'a', 'u', 's', 'p', 'i', 'c', 'i', 'o', 'u', 's', '\n',
        'a', 'u', 's', 'p', 'i', 'c', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'a', 'u', 's', 's', 'i', 'e', '\n',
        'a', 'u', 's', 's', 'i', 'e', 's', '\n',
        'a', 'u', 's', 't', 'e', 'r', 'e', '\n',
        'a', 'u', 's', 't', 'e', 'r', 'e', 'l', 'y', '\n',
        'a', 'u', 's', 't', 'e', 'r', 'i', 't', 'y', '\n',
        'a', 'u', 's', 't', 'r', 'a', 'l', '\n',
        'a', 'u', 's', 't', 'r', 'a', 'l', 'i', 'a', 'n', '\n',
        'a', 'u', 's', 't', 'r', 'i', 'a', '\n',
        'a', 'u', 't', 'a', 'r', 'c', 'h', 'y', '\n',
        'a', 'u', 't', 'e', 'u', 'r', '\n',
        'a', 'u', 't', 'h', 'e', 'n', 't', 'i', 'c', '\n',
        'a', 'u', 't', 'h', 'e', 'n', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 'u', 't', 'h', 'e', 'n', 't', 'i', 'c', 'a', 't', 'e', '\n',
        'a', 'u', 't', 'h', 'e', 'n', 't', 'i', 'c', 'a', 't', 'e', 'd', '\n',
        'a', 'u', 't', 'h', 'e', 'n', 't', 'i', 'c', 'a', 't', 'e', 's', '\n',
        'a', 'u', 't', 'h', 'e', 'n', 't', 'i', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'u', 't', 'h', 'e', 'n', 't', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'u', 't', 'h', 'e', 'n', 't', 'i', 'c', 'a', 't', 'o', 'r', '\n',
        'a', 'u', 't', 'h', 'e', 'n', 't', 'i', 'c', 'a', 't', 'o', 'r', 's', '\n',
        'a', 'u', 't', 'h', 'e', 'n', 't', 'i', 'c', 'i', 't', 'y', '\n',
        'a', 'u', 't', 'h', 'o', 'r', '\n',
        'a', 'u', 't', 'h', 'o', 'r', 'e', 'd', '\n',
        'a', 'u', 't', 'h', 'o', 'r', 'e', 's', 's', '\n',
        'a', 'u', 't', 'h', 'o', 'r', 'i', 'a', 'l', '\n',
        'a', 'u', 't', 'h', 'o', 'r', 'i', 'n', 'g', '\n',
        'a', 'u', 't', 'h', 'o', 'r', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'u', 't', 'h', 'o', 'r', 'i', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'a', 'u', 't', 'h', 'o', 'r', 'i', 's', 'e', '\n',
        'a', 'u', 't', 'h', 'o', 'r', 'i', 's', 'e', 'd', '\n',
        'a', 'u', 't', 'h', 'o', 'r', 'i', 's', 'e', 's', '\n',
        'a', 'u', 't', 'h', 'o', 'r', 'i', 's', 'i', 'n', 'g', '\n',
        'a', 'u', 't', 'h', 'o', 'r', 'i', 't', 'a', 'r', 'i', 'a', 'n', '\n',
        'a', 'u', 't', 'h', 'o', 'r', 'i', 't', 'a', 'r', 'i', 'a', 'n', 'i', 's', 'm', '\n',
        'a', 'u', 't', 'h', 'o', 'r', 'i', 't', 'a', 'r', 'i', 'a', 'n', 's', '\n',
        'a', 'u', 't', 'h', 'o', 'r', 'i', 't', 'a', 't', 'i', 'v', 'e', '\n',
        'a', 'u', 't', 'h', 'o', 'r', 'i', 't', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'a', 'u', 't', 'h', 'o', 'r', 'i', 't', 'i', 'e', 's', '\n',
        'a', 'u', 't', 'h', 'o', 'r', 'i', 't', 'y', '\n',
        'a', 'u', 't', 'h', 'o', 'r', 's', '\n',
        'a', 'u', 't', 'h', 'o', 'r', 's', 'h', 'i', 'p', '\n',
        'a', 'u', 't', 'i', 's', 'm', '\n',
        'a', 'u', 't', 'i', 's', 't', 'i', 'c', '\n',
        'a', 'u', 't', 'o', '\n',
        'a', 'u', 't', 'o', 'b', 'a', 'h', 'n', '\n',
        'a', 'u', 't', 'o', 'b', 'a', 'h', 'n', 's', '\n',
        'a', 'u', 't', 'o', 'b', 'i', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', 'a', 'l', '\n',
        'a', 'u', 't', 'o', 'b', 'i', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 'u', 't', 'o', 'b', 'i', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'e', 's', '\n',
        'a', 'u', 't', 'o', 'b', 'i', 'o', 'g', 'r', 'a', 'p', 'h', 'y', '\n',
        'a', 'u', 't', 'o', 'c', 'r', 'a', 'c', 'i', 'e', 's', '\n',
        'a', 'u', 't', 'o', 'c', 'r', 'a', 'c', 'y', '\n',
        'a', 'u', 't', 'o', 'c', 'r', 'a', 't', '\n',
        'a', 'u', 't', 'o', 'c', 'r', 'a', 't', 'i', 'c', '\n',
        'a', 'u', 't', 'o', 'c', 'r', 'a', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 'u', 't', 'o', 'c', 'r', 'a', 't', 's', '\n',
        'a', 'u', 't', 'o', 'c', 'u', 'e', '\n',
        'a', 'u', 't', 'o', 'g', 'r', 'a', 'p', 'h', '\n',
        'a', 'u', 't', 'o', 'g', 'r', 'a', 'p', 'h', 'e', 'd', '\n',
        'a', 'u', 't', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'n', 'g', '\n',
        'a', 'u', 't', 'o', 'g', 'r', 'a', 'p', 'h', 's', '\n',
        'a', 'u', 't', 'o', 'i', 'g', 'n', 'i', 't', 'i', 'o', 'n', '\n',
        'a', 'u', 't', 'o', 'i', 'm', 'm', 'u', 'n', 'e', '\n',
        'a', 'u', 't', 'o', 'm', 'a', 't', '\n',
        'a', 'u', 't', 'o', 'm', 'a', 't', 'a', '\n',
        'a', 'u', 't', 'o', 'm', 'a', 't', 'e', '\n',
        'a', 'u', 't', 'o', 'm', 'a', 't', 'e', 'd', '\n',
        'a', 'u', 't', 'o', 'm', 'a', 't', 'e', 's', '\n',
        'a', 'u', 't', 'o', 'm', 'a', 't', 'i', 'c', '\n',
        'a', 'u', 't', 'o', 'm', 'a', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 'u', 't', 'o', 'm', 'a', 't', 'i', 'c', 's', '\n',
        'a', 'u', 't', 'o', 'm', 'a', 't', 'i', 'n', 'g', '\n',
        'a', 'u', 't', 'o', 'm', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'u', 't', 'o', 'm', 'a', 't', 'o', 'n', '\n',
        'a', 'u', 't', 'o', 'm', 'a', 't', 's', '\n',
        'a', 'u', 't', 'o', 'm', 'o', 'b', 'i', 'l', 'e', '\n',
        'a', 'u', 't', 'o', 'm', 'o', 'r', 'p', 'h', 'i', 's', 'm', '\n',
        'a', 'u', 't', 'o', 'm', 'o', 'r', 'p', 'h', 'i', 's', 'm', 's', '\n',
        'a', 'u', 't', 'o', 'm', 'o', 't', 'i', 'v', 'e', '\n',
        'a', 'u', 't', 'o', 'n', 'o', 'm', 'i', 'c', '\n',
        'a', 'u', 't', 'o', 'n', 'o', 'm', 'o', 'u', 's', '\n',
        'a', 'u', 't', 'o', 'n', 'o', 'm', 'o', 'u', 's', 'l', 'y', '\n',
        'a', 'u', 't', 'o', 'n', 'o', 'm', 'y', '\n',
        'a', 'u', 't', 'o', 'p', 'i', 'l', 'o', 't', '\n',
        'a', 'u', 't', 'o', 'p', 's', 'i', 'e', 's', '\n',
        'a', 'u', 't', 'o', 'p', 's', 'y', '\n',
        'a', 'u', 't', 'o', 's', 'u', 'g', 'g', 'e', 's', 't', 'i', 'o', 'n', '\n',
        'a', 'u', 't', 'u', 'm', 'n', '\n',
        'a', 'u', 't', 'u', 'm', 'n', 'a', 'l', '\n',
        'a', 'u', 't', 'u', 'm', 'n', 's', '\n',
        'a', 'u', 'x', 'i', 'l', 'i', 'a', 'r', 'i', 'e', 's', '\n',
        'a', 'u', 'x', 'i', 'l', 'i', 'a', 'r', 'y', '\n',
        'a', 'v', 'a', 'i', 'l', '\n',
        'a', 'v', 'a', 'i', 'l', 'a', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'a', 'v', 'a', 'i', 'l', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', '\n',
        'a', 'v', 'a', 'i', 'l', 'e', 'd', '\n',
        'a', 'v', 'a', 'i', 'l', 'i', 'n', 'g', '\n',
        'a', 'v', 'a', 'i', 'l', 's', '\n',
        'a', 'v', 'a', 'l', 'a', 'n', 'c', 'h', 'e', '\n',
        'a', 'v', 'a', 'l', 'a', 'n', 'c', 'h', 'e', 's', '\n',
        'a', 'v', 'a', 'l', 'a', 'n', 'c', 'h', 'i', 'n', 'g', '\n',
        'a', 'v', 'a', 'n', 't', 'g', 'a', 'r', 'd', 'e', '\n',
        'a', 'v', 'a', 'r', 'i', 'c', 'e', '\n',
        'a', 'v', 'a', 'r', 'i', 'c', 'i', 'o', 'u', 's', '\n',
        'a', 'v', 'a', 'r', 'i', 'c', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'a', 'v', 'e', '\n',
        'a', 'v', 'e', 'n', 'g', 'e', '\n',
        'a', 'v', 'e', 'n', 'g', 'e', 'd', '\n',
        'a', 'v', 'e', 'n', 'g', 'e', 'r', '\n',
        'a', 'v', 'e', 'n', 'g', 'e', 'r', 's', '\n',
        'a', 'v', 'e', 'n', 'g', 'e', 's', '\n',
        'a', 'v', 'e', 'n', 'g', 'i', 'n', 'g', '\n',
        'a', 'v', 'e', 'n', 's', '\n',
        'a', 'v', 'e', 'n', 'u', 'e', '\n',
        'a', 'v', 'e', 'n', 'u', 'e', 's', '\n',
        'a', 'v', 'e', 'r', '\n',
        'a', 'v', 'e', 'r', 'a', 'g', 'e', '\n',
        'a', 'v', 'e', 'r', 'a', 'g', 'e', 'd', '\n',
        'a', 'v', 'e', 'r', 'a', 'g', 'e', 'l', 'y', '\n',
        'a', 'v', 'e', 'r', 'a', 'g', 'e', 's', '\n',
        'a', 'v', 'e', 'r', 'a', 'g', 'i', 'n', 'g', '\n',
        'a', 'v', 'e', 'r', 'r', 'e', 'd', '\n',
        'a', 'v', 'e', 'r', 'r', 'i', 'n', 'g', '\n',
        'a', 'v', 'e', 'r', 's', '\n',
        'a', 'v', 'e', 'r', 's', 'e', '\n',
        'a', 'v', 'e', 'r', 's', 'i', 'o', 'n', '\n',
        'a', 'v', 'e', 'r', 's', 'i', 'o', 'n', 's', '\n',
        'a', 'v', 'e', 'r', 's', 'i', 'v', 'e', '\n',
        'a', 'v', 'e', 'r', 't', '\n',
        'a', 'v', 'e', 'r', 't', 'e', 'd', '\n',
        'a', 'v', 'e', 'r', 't', 'i', 'n', 'g', '\n',
        'a', 'v', 'e', 'r', 't', 's', '\n',
        'a', 'v', 'i', 'a', 'n', '\n',
        'a', 'v', 'i', 'a', 'r', 'i', 'e', 's', '\n',
        'a', 'v', 'i', 'a', 'r', 'y', '\n',
        'a', 'v', 'i', 'a', 't', 'e', '\n',
        'a', 'v', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'a', 'v', 'i', 'a', 't', 'o', 'r', '\n',
        'a', 'v', 'i', 'a', 't', 'o', 'r', 's', '\n',
        'a', 'v', 'i', 'd', '\n',
        'a', 'v', 'i', 'd', 'i', 't', 'y', '\n',
        'a', 'v', 'i', 'd', 'l', 'y', '\n',
        'a', 'v', 'i', 'o', 'n', 'i', 'c', 's', '\n',
        'a', 'v', 'o', 'c', 'a', 'd', 'o', '\n',
        'a', 'v', 'o', 'i', 'd', '\n',
        'a', 'v', 'o', 'i', 'd', 'a', 'b', 'l', 'e', '\n',
        'a', 'v', 'o', 'i', 'd', 'a', 'n', 'c', 'e', '\n',
        'a', 'v', 'o', 'i', 'd', 'e', 'd', '\n',
        'a', 'v', 'o', 'i', 'd', 'i', 'n', 'g', '\n',
        'a', 'v', 'o', 'i', 'd', 's', '\n',
        'a', 'v', 'o', 'i', 'r', 'd', 'u', 'p', 'o', 'i', 's', '\n',
        'a', 'v', 'o', 'w', '\n',
        'a', 'v', 'o', 'w', 'a', 'l', '\n',
        'a', 'v', 'o', 'w', 'a', 'l', 's', '\n',
        'a', 'v', 'o', 'w', 'e', 'd', '\n',
        'a', 'v', 'o', 'w', 'e', 'd', 'l', 'y', '\n',
        'a', 'v', 'o', 'w', 'i', 'n', 'g', '\n',
        'a', 'v', 'u', 'l', 's', 'i', 'o', 'n', '\n',
        'a', 'v', 'u', 'n', 'c', 'u', 'l', 'a', 'r', '\n',
        'a', 'w', 'a', 'i', 't', '\n',
        'a', 'w', 'a', 'i', 't', 'e', 'd', '\n',
        'a', 'w', 'a', 'i', 't', 'i', 'n', 'g', '\n',
        'a', 'w', 'a', 'i', 't', 's', '\n',
        'a', 'w', 'a', 'k', 'e', '\n',
        'a', 'w', 'a', 'k', 'e', 'n', '\n',
        'a', 'w', 'a', 'k', 'e', 'n', 'e', 'd', '\n',
        'a', 'w', 'a', 'k', 'e', 'n', 'i', 'n', 'g', '\n',
        'a', 'w', 'a', 'k', 'e', 'n', 'i', 'n', 'g', 's', '\n',
        'a', 'w', 'a', 'k', 'e', 'n', 's', '\n',
        'a', 'w', 'a', 'k', 'e', 's', '\n',
        'a', 'w', 'a', 'k', 'i', 'n', 'g', '\n',
        'a', 'w', 'a', 'r', 'd', '\n',
        'a', 'w', 'a', 'r', 'd', 'e', 'd', '\n',
        'a', 'w', 'a', 'r', 'd', 'i', 'n', 'g', '\n',
        'a', 'w', 'a', 'r', 'd', 's', '\n',
        'a', 'w', 'a', 'r', 'e', '\n',
        'a', 'w', 'a', 'r', 'e', 'n', 'e', 's', 's', '\n',
        'a', 'w', 'a', 's', 'h', '\n',
        'a', 'w', 'a', 'y', '\n',
        'a', 'w', 'e', '\n',
        'a', 'w', 'e', 'd', '\n',
        'a', 'w', 'e', 'l', 'e', 's', 's', '\n',
        'a', 'w', 'e', 's', 'o', 'm', 'e', '\n',
        'a', 'w', 'e', 's', 'o', 'm', 'e', 'l', 'y', '\n',
        'a', 'w', 'e', 's', 'o', 'm', 'e', 'n', 'e', 's', 's', '\n',
        'a', 'w', 'e', 's', 't', 'r', 'u', 'c', 'k', '\n',
        'a', 'w', 'f', 'u', 'l', '\n',
        'a', 'w', 'f', 'u', 'l', 'l', 'y', '\n',
        'a', 'w', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'a', 'w', 'h', 'i', 'l', 'e', '\n',
        'a', 'w', 'k', 'w', 'a', 'r', 'd', '\n',
        'a', 'w', 'k', 'w', 'a', 'r', 'd', 'e', 's', 't', '\n',
        'a', 'w', 'k', 'w', 'a', 'r', 'd', 'l', 'y', '\n',
        'a', 'w', 'k', 'w', 'a', 'r', 'd', 'n', 'e', 's', 's', '\n',
        'a', 'w', 'l', 's', '\n',
        'a', 'w', 'n', '\n',
        'a', 'w', 'n', 'i', 'n', 'g', '\n',
        'a', 'w', 'n', 'i', 'n', 'g', 's', '\n',
        'a', 'w', 'o', 'k', 'e', '\n',
        'a', 'w', 'o', 'k', 'e', 'n', '\n',
        'a', 'w', 'o', 'l', '\n',
        'a', 'w', 'r', 'y', '\n',
        'a', 'x', 'e', '\n',
        'a', 'x', 'e', 'd', '\n',
        'a', 'x', 'e', 'h', 'e', 'a', 'd', '\n',
        'a', 'x', 'e', 'h', 'e', 'a', 'd', 's', '\n',
        'a', 'x', 'e', 'm', 'a', 'n', '\n',
        'a', 'x', 'e', 's', '\n',
        'a', 'x', 'i', 'a', 'l', '\n',
        'a', 'x', 'i', 'a', 'l', 'l', 'y', '\n',
        'a', 'x', 'i', 'l', 'l', 'a', 'r', 'y', '\n',
        'a', 'x', 'i', 'n', 'g', '\n',
        'a', 'x', 'i', 'o', 'm', '\n',
        'a', 'x', 'i', 'o', 'm', 'a', 't', 'i', 'c', '\n',
        'a', 'x', 'i', 'o', 'm', 'a', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'a', 'x', 'i', 'o', 'm', 'a', 't', 'i', 's', 'i', 'n', 'g', '\n',
        'a', 'x', 'i', 'o', 'm', 's', '\n',
        'a', 'x', 'i', 's', '\n',
        'a', 'x', 'l', 'e', '\n',
        'a', 'x', 'l', 'e', 's', '\n',
        'a', 'x', 'o', 'l', 'o', 't', 'l', '\n',
        'a', 'x', 'o', 'n', '\n',
        'a', 'x', 'o', 'n', 's', '\n',
        'a', 'y', 'e', '\n',
        'a', 'y', 'u', 'r', 'v', 'e', 'd', 'i', 'c', '\n',
        'a', 'z', 'a', 'l', 'e', 'a', '\n',
        'a', 'z', 'a', 'l', 'e', 'a', 's', '\n',
        'a', 'z', 'i', 'm', 'u', 't', 'h', '\n',
        'a', 'z', 'i', 'm', 'u', 't', 'h', 'a', 'l', '\n',
        'a', 'z', 'o', 'r', 'e', 's', '\n',
        'a', 'z', 't', 'e', 'c', '\n',
        'a', 'z', 't', 'e', 'c', 's', '\n',
        'a', 'z', 'u', 'r', 'e', '\n',
        'b', 'a', 'a', '\n',
        'b', 'a', 'a', 'i', 'n', 'g', '\n',
        'b', 'a', 'a', 'l', '\n',
        'b', 'a', 'b', 'a', 's', '\n',
        'b', 'a', 'b', 'b', 'l', 'e', '\n',
        'b', 'a', 'b', 'b', 'l', 'e', 'd', '\n',
        'b', 'a', 'b', 'b', 'l', 'e', 'r', '\n',
        'b', 'a', 'b', 'b', 'l', 'e', 'r', 's', '\n',
        'b', 'a', 'b', 'b', 'l', 'e', 's', '\n',
        'b', 'a', 'b', 'b', 'l', 'i', 'n', 'g', '\n',
        'b', 'a', 'b', 'e', '\n',
        'b', 'a', 'b', 'e', 'l', '\n',
        'b', 'a', 'b', 'e', 's', '\n',
        'b', 'a', 'b', 'i', 'e', 's', '\n',
        'b', 'a', 'b', 'o', 'o', 'n', '\n',
        'b', 'a', 'b', 'o', 'o', 'n', 's', '\n',
        'b', 'a', 'b', 'y', '\n',
        'b', 'a', 'b', 'y', 'f', 'a', 'c', 'e', '\n',
        'b', 'a', 'b', 'y', 'h', 'o', 'o', 'd', '\n',
        'b', 'a', 'b', 'y', 'i', 'n', 'g', '\n',
        'b', 'a', 'b', 'y', 'i', 's', 'h', '\n',
        'b', 'a', 'b', 'y', 'l', 'o', 'n', '\n',
        'b', 'a', 'b', 'y', 's', 'i', 't', '\n',
        'b', 'a', 'b', 'y', 's', 'i', 't', 't', 'e', 'r', '\n',
        'b', 'a', 'b', 'y', 's', 'i', 't', 't', 'e', 'r', 's', '\n',
        'b', 'a', 'b', 'y', 's', 'i', 't', 't', 'i', 'n', 'g', '\n',
        'b', 'a', 'c', 'c', 'a', 'r', 'a', 't', '\n',
        'b', 'a', 'c', 'c', 'h', 'u', 's', '\n',
        'b', 'a', 'c', 'h', '\n',
        'b', 'a', 'c', 'h', 'e', 'l', 'o', 'r', '\n',
        'b', 'a', 'c', 'h', 'e', 'l', 'o', 'r', 's', '\n',
        'b', 'a', 'c', 'i', 'l', 'l', 'i', '\n',
        'b', 'a', 'c', 'i', 'l', 'l', 'u', 's', '\n',
        'b', 'a', 'c', 'k', '\n',
        'b', 'a', 'c', 'k', 'a', 'c', 'h', 'e', '\n',
        'b', 'a', 'c', 'k', 'b', 'e', 'n', 'c', 'h', '\n',
        'b', 'a', 'c', 'k', 'b', 'e', 'n', 'c', 'h', 'e', 'r', '\n',
        'b', 'a', 'c', 'k', 'b', 'e', 'n', 'c', 'h', 'e', 'r', 's', '\n',
        'b', 'a', 'c', 'k', 'b', 'o', 'n', 'e', '\n',
        'b', 'a', 'c', 'k', 'b', 'o', 'n', 'e', 's', '\n',
        'b', 'a', 'c', 'k', 'c', 'h', 'a', 't', '\n',
        'b', 'a', 'c', 'k', 'd', 'a', 't', 'e', '\n',
        'b', 'a', 'c', 'k', 'd', 'a', 't', 'e', 'd', '\n',
        'b', 'a', 'c', 'k', 'd', 'r', 'o', 'p', '\n',
        'b', 'a', 'c', 'k', 'e', 'd', '\n',
        'b', 'a', 'c', 'k', 'e', 'r', '\n',
        'b', 'a', 'c', 'k', 'e', 'r', 's', '\n',
        'b', 'a', 'c', 'k', 'f', 'i', 'r', 'e', '\n',
        'b', 'a', 'c', 'k', 'f', 'i', 'r', 'e', 'd', '\n',
        'b', 'a', 'c', 'k', 'f', 'i', 'r', 'e', 's', '\n',
        'b', 'a', 'c', 'k', 'f', 'i', 'r', 'i', 'n', 'g', '\n',
        'b', 'a', 'c', 'k', 'g', 'a', 'm', 'm', 'o', 'n', '\n',
        'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', '\n',
        'b', 'a', 'c', 'k', 'g', 'r', 'o', 'u', 'n', 'd', 's', '\n',
        'b', 'a', 'c', 'k', 'h', 'a', 'n', 'd', '\n',
        'b', 'a', 'c', 'k', 'h', 'a', 'n', 'd', 'e', 'd', '\n',
        'b', 'a', 'c', 'k', 'i', 'n', 'g', '\n',
        'b', 'a', 'c', 'k', 'l', 'a', 's', 'h', '\n',
        'b', 'a', 'c', 'k', 'l', 'e', 's', 's', '\n',
        'b', 'a', 'c', 'k', 'l', 'i', 'g', 'h', 't', '\n',
        'b', 'a', 'c', 'k', 'l', 'i', 't', '\n',
        'b', 'a', 'c', 'k', 'l', 'o', 'g', '\n',
        'b', 'a', 'c', 'k', 'l', 'o', 'g', 's', '\n',
        'b', 'a', 'c', 'k', 'p', 'a', 'c', 'k', '\n',
        'b', 'a', 'c', 'k', 'p', 'a', 'c', 'k', 'e', 'r', '\n',
        'b', 'a', 'c', 'k', 'p', 'a', 'c', 'k', 'e', 'r', 's', '\n',
        'b', 'a', 'c', 'k', 'p', 'a', 'c', 'k', 'i', 'n', 'g', '\n',
        'b', 'a', 'c', 'k', 'p', 'a', 'c', 'k', 's', '\n',
        'b', 'a', 'c', 'k', 'p', 'e', 'd', 'a', 'l', '\n',
        'b', 'a', 'c', 'k', 'p', 'e', 'd', 'a', 'l', 'l', 'e', 'd', '\n',
        'b', 'a', 'c', 'k', 'p', 'e', 'd', 'a', 'l', 'l', 'i', 'n', 'g', '\n',
        'b', 'a', 'c', 'k', 'r', 'e', 's', 't', '\n',
        'b', 'a', 'c', 'k', 's', '\n',
        'b', 'a', 'c', 'k', 's', 'e', 'a', 't', '\n',
        'b', 'a', 'c', 'k', 's', 'i', 'd', 'e', '\n',
        'b', 'a', 'c', 'k', 's', 'i', 'd', 'e', 's', '\n',
        'b', 'a', 'c', 'k', 's', 'l', 'a', 'p', 'p', 'i', 'n', 'g', '\n',
        'b', 'a', 'c', 'k', 's', 'l', 'a', 's', 'h', '\n',
        'b', 'a', 'c', 'k', 's', 'l', 'i', 'd', 'i', 'n', 'g', '\n',
        'b', 'a', 'c', 'k', 's', 'p', 'a', 'c', 'e', '\n',
        'b', 'a', 'c', 'k', 's', 'p', 'a', 'c', 'e', 's', '\n',
        'b', 'a', 'c', 'k', 's', 'p', 'a', 'c', 'i', 'n', 'g', '\n',
        'b', 'a', 'c', 'k', 's', 't', 'a', 'b', 'b', 'i', 'n', 'g', '\n',
        'b', 'a', 'c', 'k', 's', 't', 'a', 'g', 'e', '\n',
        'b', 'a', 'c', 'k', 's', 't', 'a', 'i', 'r', 's', '\n',
        'b', 'a', 'c', 'k', 's', 't', 'r', 'e', 'e', 't', '\n',
        'b', 'a', 'c', 'k', 's', 't', 'r', 'e', 'e', 't', 's', '\n',
        'b', 'a', 'c', 'k', 's', 't', 'r', 'o', 'k', 'e', '\n',
        'b', 'a', 'c', 'k', 't', 'r', 'a', 'c', 'k', '\n',
        'b', 'a', 'c', 'k', 't', 'r', 'a', 'c', 'k', 'e', 'd', '\n',
        'b', 'a', 'c', 'k', 't', 'r', 'a', 'c', 'k', 'i', 'n', 'g', '\n',
        'b', 'a', 'c', 'k', 't', 'r', 'a', 'c', 'k', 's', '\n',
        'b', 'a', 'c', 'k', 'u', 'p', '\n',
        'b', 'a', 'c', 'k', 'u', 'p', 's', '\n',
        'b', 'a', 'c', 'k', 'w', 'a', 'r', 'd', '\n',
        'b', 'a', 'c', 'k', 'w', 'a', 'r', 'd', 'n', 'e', 's', 's', '\n',
        'b', 'a', 'c', 'k', 'w', 'a', 'r', 'd', 's', '\n',
        'b', 'a', 'c', 'k', 'w', 'a', 's', 'h', '\n',
        'b', 'a', 'c', 'k', 'w', 'a', 't', 'e', 'r', '\n',
        'b', 'a', 'c', 'k', 'w', 'a', 't', 'e', 'r', 's', '\n',
        'b', 'a', 'c', 'k', 'w', 'o', 'o', 'd', 's', '\n',
        'b', 'a', 'c', 'k', 'w', 'o', 'o', 'd', 's', 'm', 'e', 'n', '\n',
        'b', 'a', 'c', 'k', 'y', 'a', 'r', 'd', '\n',
        'b', 'a', 'c', 'o', 'n', '\n',
        'b', 'a', 'c', 't', 'e', 'r', 'i', 'a', '\n',
        'b', 'a', 'c', 't', 'e', 'r', 'i', 'a', 'l', '\n',
        'b', 'a', 'c', 't', 'e', 'r', 'i', 'c', 'i', 'd', 'a', 'l', '\n',
        'b', 'a', 'c', 't', 'e', 'r', 'i', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'b', 'a', 'c', 't', 'e', 'r', 'i', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'b', 'a', 'c', 't', 'e', 'r', 'i', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'b', 'a', 'c', 't', 'e', 'r', 'i', 'o', 'l', 'o', 'g', 'y', '\n',
        'b', 'a', 'c', 't', 'e', 'r', 'i', 'o', 'p', 'h', 'a', 'g', 'e', '\n',
        'b', 'a', 'c', 't', 'e', 'r', 'i', 'u', 'm', '\n',
        'b', 'a', 'd', '\n',
        'b', 'a', 'd', 'd', 'y', '\n',
        'b', 'a', 'd', 'e', '\n',
        'b', 'a', 'd', 'e', 'r', '\n',
        'b', 'a', 'd', 'g', 'e', '\n',
        'b', 'a', 'd', 'g', 'e', 'd', '\n',
        'b', 'a', 'd', 'g', 'e', 'r', '\n',
        'b', 'a', 'd', 'g', 'e', 'r', 'e', 'd', '\n',
        'b', 'a', 'd', 'g', 'e', 'r', 'i', 'n', 'g', '\n',
        'b', 'a', 'd', 'g', 'e', 'r', 's', '\n',
        'b', 'a', 'd', 'g', 'e', 's', '\n',
        'b', 'a', 'd', 'i', 'n', 'a', 'g', 'e', '\n',
        'b', 'a', 'd', 'l', 'a', 'n', 'd', 's', '\n',
        'b', 'a', 'd', 'l', 'y', '\n',
        'b', 'a', 'd', 'm', 'i', 'n', 't', 'o', 'n', '\n',
        'b', 'a', 'd', 'n', 'e', 's', 's', '\n',
        'b', 'a', 'd', 't', 'e', 'm', 'p', 'e', 'r', 'e', 'd', '\n',
        'b', 'a', 'f', 'f', 'l', 'e', '\n',
        'b', 'a', 'f', 'f', 'l', 'e', 'd', '\n',
        'b', 'a', 'f', 'f', 'l', 'e', 'm', 'e', 'n', 't', '\n',
        'b', 'a', 'f', 'f', 'l', 'e', 'r', '\n',
        'b', 'a', 'f', 'f', 'l', 'e', 's', '\n',
        'b', 'a', 'f', 'f', 'l', 'i', 'n', 'g', '\n',
        'b', 'a', 'f', 'f', 'l', 'i', 'n', 'g', 'l', 'y', '\n',
        'b', 'a', 'g', '\n',
        'b', 'a', 'g', 'a', 't', 'e', 'l', 'l', 'e', '\n',
        'b', 'a', 'g', 'd', 'a', 'd', '\n',
        'b', 'a', 'g', 'e', 'l', 's', '\n',
        'b', 'a', 'g', 'f', 'u', 'l', '\n',
        'b', 'a', 'g', 'f', 'u', 'l', 's', '\n',
        'b', 'a', 'g', 'g', 'a', 'g', 'e', '\n',
        'b', 'a', 'g', 'g', 'a', 'g', 'e', 's', '\n',
        'b', 'a', 'g', 'g', 'e', 'd', '\n',
        'b', 'a', 'g', 'g', 'e', 'r', '\n',
        'b', 'a', 'g', 'g', 'i', 'e', 'r', '\n',
        'b', 'a', 'g', 'g', 'i', 'e', 's', 't', '\n',
        'b', 'a', 'g', 'g', 'i', 'n', 'g', '\n',
        'b', 'a', 'g', 'g', 'y', '\n',
        'b', 'a', 'g', 'h', 'd', 'a', 'd', '\n',
        'b', 'a', 'g', 'm', 'a', 'n', '\n',
        'b', 'a', 'g', 'm', 'e', 'n', '\n',
        'b', 'a', 'g', 'p', 'i', 'p', 'e', '\n',
        'b', 'a', 'g', 'p', 'i', 'p', 'e', 'r', '\n',
        'b', 'a', 'g', 'p', 'i', 'p', 'e', 's', '\n',
        'b', 'a', 'g', 's', '\n',
        'b', 'a', 'g', 'u', 'e', 't', 't', 'e', '\n',
        'b', 'a', 'g', 'u', 'e', 't', 't', 'e', 's', '\n',
        'b', 'a', 'h', '\n',
        'b', 'a', 'h', 'a', 'm', 'a', 's', '\n',
        'b', 'a', 'i', 'l', '\n',
        'b', 'a', 'i', 'l', 'e', 'd', '\n',
        'b', 'a', 'i', 'l', 'i', 'f', 'f', '\n',
        'b', 'a', 'i', 'l', 'i', 'f', 'f', 's', '\n',
        'b', 'a', 'i', 'l', 'i', 'n', 'g', '\n',
        'b', 'a', 'i', 'l', 'i', 'w', 'i', 'c', 'k', '\n',
        'b', 'a', 'i', 'l', 'o', 'u', 't', '\n',
        'b', 'a', 'i', 'l', 's', '\n',
        'b', 'a', 'i', 't', '\n',
        'b', 'a', 'i', 't', 'e', 'd', '\n',
        'b', 'a', 'i', 't', 'e', 'r', 's', '\n',
        'b', 'a', 'i', 't', 'i', 'n', 'g', '\n',
        'b', 'a', 'i', 't', 'i', 'n', 'g', 's', '\n',
        'b', 'a', 'i', 't', 's', '\n',
        'b', 'a', 'k', 'e', '\n',
        'b', 'a', 'k', 'e', 'd', '\n',
        'b', 'a', 'k', 'e', 'h', 'o', 'u', 's', 'e', '\n',
        'b', 'a', 'k', 'e', 'r', '\n',
        'b', 'a', 'k', 'e', 'r', 'i', 'e', 's', '\n',
        'b', 'a', 'k', 'e', 'r', 's', '\n',
        'b', 'a', 'k', 'e', 'r', 'y', '\n',
        'b', 'a', 'k', 'e', 's', '\n',
        'b', 'a', 'k', 'i', 'n', 'g', '\n',
        'b', 'a', 'k', 'i', 'n', 'g', 's', '\n',
        'b', 'a', 'k', 'l', 'a', 'v', 'a', 's', '\n',
        'b', 'a', 'l', 'a', 'c', 'l', 'a', 'v', 'a', '\n',
        'b', 'a', 'l', 'a', 'c', 'l', 'a', 'v', 'a', 's', '\n',
        'b', 'a', 'l', 'a', 'l', 'a', 'i', 'k', 'a', '\n',
        'b', 'a', 'l', 'a', 'n', 'c', 'e', '\n',
        'b', 'a', 'l', 'a', 'n', 'c', 'e', 'd', '\n',
        'b', 'a', 'l', 'a', 'n', 'c', 'e', 'r', '\n',
        'b', 'a', 'l', 'a', 'n', 'c', 'e', 's', '\n',
        'b', 'a', 'l', 'a', 'n', 'c', 'i', 'n', 'g', '\n',
        'b', 'a', 'l', 'c', 'o', 'n', 'i', 'e', 's', '\n',
        'b', 'a', 'l', 'c', 'o', 'n', 'y', '\n',
        'b', 'a', 'l', 'd', '\n',
        'b', 'a', 'l', 'd', 'e', 'r', '\n',
        'b', 'a', 'l', 'd', 'e', 'r', 'd', 'a', 's', 'h', '\n',
        'b', 'a', 'l', 'd', 'e', 's', 't', '\n',
        'b', 'a', 'l', 'd', 'i', 'n', 'g', '\n',
        'b', 'a', 'l', 'd', 'l', 'y', '\n',
        'b', 'a', 'l', 'd', 'n', 'e', 's', 's', '\n',
        'b', 'a', 'l', 'd', 'y', '\n',
        'b', 'a', 'l', 'e', '\n',
        'b', 'a', 'l', 'e', 'd', '\n',
        'b', 'a', 'l', 'e', 'e', 'n', '\n',
        'b', 'a', 'l', 'e', 'f', 'u', 'l', '\n',
        'b', 'a', 'l', 'e', 'f', 'u', 'l', 'l', 'y', '\n',
        'b', 'a', 'l', 'e', 's', '\n',
        'b', 'a', 'l', 'i', '\n',
        'b', 'a', 'l', 'i', 'n', 'g', '\n',
        'b', 'a', 'l', 'l', '\n',
        'b', 'a', 'l', 'l', 'a', 'd', '\n',
        'b', 'a', 'l', 'l', 'a', 'd', 'e', '\n',
        'b', 'a', 'l', 'l', 'a', 'd', 'e', 's', '\n',
        'b', 'a', 'l', 'l', 'a', 'd', 's', '\n',
        'b', 'a', 'l', 'l', 'a', 's', 't', '\n',
        'b', 'a', 'l', 'l', 'a', 's', 't', 's', '\n',
        'b', 'a', 'l', 'l', 'b', 'e', 'a', 'r', 'i', 'n', 'g', '\n',
        'b', 'a', 'l', 'l', 'b', 'e', 'a', 'r', 'i', 'n', 'g', 's', '\n',
        'b', 'a', 'l', 'l', 'e', 'r', 'i', 'n', 'a', '\n',
        'b', 'a', 'l', 'l', 'e', 'r', 'i', 'n', 'a', 's', '\n',
        'b', 'a', 'l', 'l', 'e', 't', '\n',
        'b', 'a', 'l', 'l', 'e', 't', 'i', 'c', '\n',
        'b', 'a', 'l', 'l', 'e', 't', 's', '\n',
        'b', 'a', 'l', 'l', 'i', 's', 't', 'i', 'c', '\n',
        'b', 'a', 'l', 'l', 'i', 's', 't', 'i', 'c', 's', '\n',
        'b', 'a', 'l', 'l', 'o', 'o', 'n', '\n',
        'b', 'a', 'l', 'l', 'o', 'o', 'n', 'e', 'd', '\n',
        'b', 'a', 'l', 'l', 'o', 'o', 'n', 'i', 'n', 'g', '\n',
        'b', 'a', 'l', 'l', 'o', 'o', 'n', 'i', 's', 't', '\n',
        'b', 'a', 'l', 'l', 'o', 'o', 'n', 'i', 's', 't', 's', '\n',
        'b', 'a', 'l', 'l', 'o', 'o', 'n', 's', '\n',
        'b', 'a', 'l', 'l', 'o', 't', '\n',
        'b', 'a', 'l', 'l', 'o', 't', 'e', 'd', '\n',
        'b', 'a', 'l', 'l', 'o', 't', 'i', 'n', 'g', '\n',
        'b', 'a', 'l', 'l', 'o', 't', 's', '\n',
        'b', 'a', 'l', 'l', 'p', 'e', 'n', '\n',
        'b', 'a', 'l', 'l', 'p', 'e', 'n', 's', '\n',
        'b', 'a', 'l', 'l', 'p', 'o', 'i', 'n', 't', '\n',
        'b', 'a', 'l', 'l', 'r', 'o', 'o', 'm', '\n',
        'b', 'a', 'l', 'l', 'r', 'o', 'o', 'm', 's', '\n',
        'b', 'a', 'l', 'l', 's', '\n',
        'b', 'a', 'l', 'l', 'y', 'h', 'o', 'o', '\n',
        'b', 'a', 'l', 'm', '\n',
        'b', 'a', 'l', 'm', 'i', 'e', 'r', '\n',
        'b', 'a', 'l', 'm', 'i', 'e', 's', 't', '\n',
        'b', 'a', 'l', 'm', 'o', 'r', 'a', 'l', '\n',
        'b', 'a', 'l', 'm', 's', '\n',
        'b', 'a', 'l', 'm', 'y', '\n',
        'b', 'a', 'l', 'o', 'n', 'e', 'y', '\n',
        'b', 'a', 'l', 's', 'a', '\n',
        'b', 'a', 'l', 's', 'a', 'm', '\n',
        'b', 'a', 'l', 't', 'i', 'c', '\n',
        'b', 'a', 'l', 'u', 's', 't', 'e', 'r', '\n',
        'b', 'a', 'l', 'u', 's', 't', 'e', 'r', 's', '\n',
        'b', 'a', 'l', 'u', 's', 't', 'r', 'a', 'd', 'e', '\n',
        'b', 'a', 'l', 'u', 's', 't', 'r', 'a', 'd', 'e', 'd', '\n',
        'b', 'a', 'l', 'u', 's', 't', 'r', 'a', 'd', 'e', 's', '\n',
        'b', 'a', 'm', 'b', 'i', 'n', 'o', '\n',
        'b', 'a', 'm', 'b', 'o', 'o', '\n',
        'b', 'a', 'm', 'b', 'o', 'o', 's', '\n',
        'b', 'a', 'm', 'b', 'o', 'o', 'z', 'l', 'e', '\n',
        'b', 'a', 'm', 'b', 'o', 'o', 'z', 'l', 'e', 'd', '\n',
        'b', 'a', 'm', 'b', 'o', 'o', 'z', 'l', 'e', 's', '\n',
        'b', 'a', 'n', '\n',
        'b', 'a', 'n', 'a', 'l', '\n',
        'b', 'a', 'n', 'a', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'b', 'a', 'n', 'a', 'l', 'i', 't', 'y', '\n',
        'b', 'a', 'n', 'a', 'n', 'a', '\n',
        'b', 'a', 'n', 'a', 'n', 'a', 's', '\n',
        'b', 'a', 'n', 'd', '\n',
        'b', 'a', 'n', 'd', 'a', 'g', 'e', '\n',
        'b', 'a', 'n', 'd', 'a', 'g', 'e', 'd', '\n',
        'b', 'a', 'n', 'd', 'a', 'g', 'e', 's', '\n',
        'b', 'a', 'n', 'd', 'a', 'g', 'i', 'n', 'g', '\n',
        'b', 'a', 'n', 'd', 'a', 'n', 'n', 'a', '\n',
        'b', 'a', 'n', 'd', 'e', 'd', '\n',
        'b', 'a', 'n', 'd', 'i', 'e', 'd', '\n',
        'b', 'a', 'n', 'd', 'i', 'e', 'r', '\n',
        'b', 'a', 'n', 'd', 'i', 'e', 's', 't', '\n',
        'b', 'a', 'n', 'd', 'i', 'n', 'g', '\n',
        'b', 'a', 'n', 'd', 'i', 't', '\n',
        'b', 'a', 'n', 'd', 'i', 't', 'r', 'y', '\n',
        'b', 'a', 'n', 'd', 'i', 't', 's', '\n',
        'b', 'a', 'n', 'd', 'p', 'a', 's', 's', '\n',
        'b', 'a', 'n', 'd', 's', '\n',
        'b', 'a', 'n', 'd', 's', 't', 'a', 'n', 'd', '\n',
        'b', 'a', 'n', 'd', 'w', 'a', 'g', 'o', 'n', '\n',
        'b', 'a', 'n', 'd', 'w', 'a', 'g', 'o', 'n', 's', '\n',
        'b', 'a', 'n', 'd', 'w', 'i', 'd', 't', 'h', '\n',
        'b', 'a', 'n', 'd', 'w', 'i', 'd', 't', 'h', 's', '\n',
        'b', 'a', 'n', 'e', '\n',
        'b', 'a', 'n', 'g', '\n',
        'b', 'a', 'n', 'g', 'e', 'd', '\n',
        'b', 'a', 'n', 'g', 'e', 'r', '\n',
        'b', 'a', 'n', 'g', 'e', 'r', 's', '\n',
        'b', 'a', 'n', 'g', 'i', 'n', 'g', '\n',
        'b', 'a', 'n', 'g', 'k', 'o', 'k', '\n',
        'b', 'a', 'n', 'g', 'l', 'e', '\n',
        'b', 'a', 'n', 'g', 'l', 'e', 's', '\n',
        'b', 'a', 'n', 'g', 's', '\n',
        'b', 'a', 'n', 'i', 's', 'h', '\n',
        'b', 'a', 'n', 'i', 's', 'h', 'e', 'd', '\n',
        'b', 'a', 'n', 'i', 's', 'h', 'e', 's', '\n',
        'b', 'a', 'n', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'b', 'a', 'n', 'i', 's', 'h', 'm', 'e', 'n', 't', '\n',
        'b', 'a', 'n', 'i', 's', 't', 'e', 'r', '\n',
        'b', 'a', 'n', 'i', 's', 't', 'e', 'r', 's', '\n',
        'b', 'a', 'n', 'j', 'o', '\n',
        'b', 'a', 'n', 'k', '\n',
        'b', 'a', 'n', 'k', 'a', 'b', 'l', 'e', '\n',
        'b', 'a', 'n', 'k', 'e', 'd', '\n',
        'b', 'a', 'n', 'k', 'e', 'r', '\n',
        'b', 'a', 'n', 'k', 'e', 'r', 's', '\n',
        'b', 'a', 'n', 'k', 'i', 'n', 'g', '\n',
        'b', 'a', 'n', 'k', 'n', 'o', 't', 'e', '\n',
        'b', 'a', 'n', 'k', 'n', 'o', 't', 'e', 's', '\n',
        'b', 'a', 'n', 'k', 'r', 'u', 'p', 't', '\n',
        'b', 'a', 'n', 'k', 'r', 'u', 'p', 't', 'c', 'i', 'e', 's', '\n',
        'b', 'a', 'n', 'k', 'r', 'u', 'p', 't', 'c', 'y', '\n',
        'b', 'a', 'n', 'k', 'r', 'u', 'p', 't', 'e', 'd', '\n',
        'b', 'a', 'n', 'k', 'r', 'u', 'p', 't', 'i', 'n', 'g', '\n',
        'b', 'a', 'n', 'k', 'r', 'u', 'p', 't', 's', '\n',
        'b', 'a', 'n', 'k', 's', '\n',
        'b', 'a', 'n', 'n', 'e', 'd', '\n',
        'b', 'a', 'n', 'n', 'e', 'r', '\n',
        'b', 'a', 'n', 'n', 'e', 'r', 's', '\n',
        'b', 'a', 'n', 'n', 'i', 'n', 'g', '\n',
        'b', 'a', 'n', 'n', 'i', 's', 't', 'e', 'r', '\n',
        'b', 'a', 'n', 'n', 'i', 's', 't', 'e', 'r', 's', '\n',
        'b', 'a', 'n', 'n', 's', '\n',
        'b', 'a', 'n', 'q', 'u', 'e', 't', '\n',
        'b', 'a', 'n', 'q', 'u', 'e', 't', 'i', 'n', 'g', '\n',
        'b', 'a', 'n', 'q', 'u', 'e', 't', 's', '\n',
        'b', 'a', 'n', 's', '\n',
        'b', 'a', 'n', 's', 'h', 'e', 'e', '\n',
        'b', 'a', 'n', 's', 'h', 'e', 'e', 's', '\n',
        'b', 'a', 'n', 't', 'a', 'm', '\n',
        'b', 'a', 'n', 't', 'a', 'm', 's', '\n',
        'b', 'a', 'n', 't', 'a', 'm', 'w', 'e', 'i', 'g', 'h', 't', '\n',
        'b', 'a', 'n', 't', 'e', 'r', '\n',
        'b', 'a', 'n', 't', 'e', 'r', 'e', 'd', '\n',
        'b', 'a', 'n', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'b', 'a', 'o', 'b', 'a', 'b', '\n',
        'b', 'a', 'o', 'b', 'a', 'b', 's', '\n',
        'b', 'a', 'p', '\n',
        'b', 'a', 'p', 't', 'i', 's', 'e', '\n',
        'b', 'a', 'p', 't', 'i', 's', 'e', 'd', '\n',
        'b', 'a', 'p', 't', 'i', 's', 'e', 's', '\n',
        'b', 'a', 'p', 't', 'i', 's', 'i', 'n', 'g', '\n',
        'b', 'a', 'p', 't', 'i', 's', 'm', '\n',
        'b', 'a', 'p', 't', 'i', 's', 'm', 'a', 'l', '\n',
        'b', 'a', 'p', 't', 'i', 's', 'm', 's', '\n',
        'b', 'a', 'p', 't', 'i', 's', 't', '\n',
        'b', 'a', 'p', 't', 'i', 's', 't', 's', '\n',
        'b', 'a', 'r', '\n',
        'b', 'a', 'r', 'b', '\n',
        'b', 'a', 'r', 'b', 'a', 'r', 'i', 'a', 'n', '\n',
        'b', 'a', 'r', 'b', 'a', 'r', 'i', 'a', 'n', 's', '\n',
        'b', 'a', 'r', 'b', 'a', 'r', 'i', 'c', '\n',
        'b', 'a', 'r', 'b', 'a', 'r', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'b', 'a', 'r', 'b', 'a', 'r', 'i', 's', 'm', '\n',
        'b', 'a', 'r', 'b', 'a', 'r', 'i', 't', 'i', 'e', 's', '\n',
        'b', 'a', 'r', 'b', 'a', 'r', 'i', 't', 'y', '\n',
        'b', 'a', 'r', 'b', 'a', 'r', 'o', 'u', 's', '\n',
        'b', 'a', 'r', 'b', 'a', 'r', 'o', 'u', 's', 'l', 'y', '\n',
        'b', 'a', 'r', 'b', 'e', 'c', 'u', 'e', '\n',
        'b', 'a', 'r', 'b', 'e', 'c', 'u', 'e', 'd', '\n',
        'b', 'a', 'r', 'b', 'e', 'c', 'u', 'e', 's', '\n',
        'b', 'a', 'r', 'b', 'e', 'd', '\n',
        'b', 'a', 'r', 'b', 'e', 'l', 'l', '\n',
        'b', 'a', 'r', 'b', 'e', 'l', 's', '\n',
        'b', 'a', 'r', 'b', 'e', 'r', '\n',
        'b', 'a', 'r', 'b', 'e', 'r', 's', '\n',
        'b', 'a', 'r', 'b', 'i', 'e', '\n',
        'b', 'a', 'r', 'b', 'i', 't', 'u', 'r', 'a', 't', 'e', '\n',
        'b', 'a', 'r', 'b', 'i', 't', 'u', 'r', 'a', 't', 'e', 's', '\n',
        'b', 'a', 'r', 'b', 's', '\n',
        'b', 'a', 'r', 'c', 'o', 'd', 'e', '\n',
        'b', 'a', 'r', 'd', '\n',
        'b', 'a', 'r', 'd', 's', '\n',
        'b', 'a', 'r', 'e', '\n',
        'b', 'a', 'r', 'e', 'b', 'a', 'c', 'k', '\n',
        'b', 'a', 'r', 'e', 'd', '\n',
        'b', 'a', 'r', 'e', 'f', 'a', 'c', 'e', 'd', '\n',
        'b', 'a', 'r', 'e', 'f', 'o', 'o', 't', '\n',
        'b', 'a', 'r', 'e', 'f', 'o', 'o', 't', 'e', 'd', '\n',
        'b', 'a', 'r', 'e', 'l', 'y', '\n',
        'b', 'a', 'r', 'e', 'n', 'e', 's', 's', '\n',
        'b', 'a', 'r', 'e', 'r', '\n',
        'b', 'a', 'r', 'e', 's', '\n',
        'b', 'a', 'r', 'e', 's', 't', '\n',
        'b', 'a', 'r', 'g', 'a', 'i', 'n', '\n',
        'b', 'a', 'r', 'g', 'a', 'i', 'n', 'e', 'd', '\n',
        'b', 'a', 'r', 'g', 'a', 'i', 'n', 'e', 'r', 's', '\n',
        'b', 'a', 'r', 'g', 'a', 'i', 'n', 'i', 'n', 'g', '\n',
        'b', 'a', 'r', 'g', 'a', 'i', 'n', 's', '\n',
        'b', 'a', 'r', 'g', 'e', '\n',
        'b', 'a', 'r', 'g', 'e', 'd', '\n',
        'b', 'a', 'r', 'g', 'e', 'p', 'o', 'l', 'e', '\n',
        'b', 'a', 'r', 'g', 'e', 's', '\n',
        'b', 'a', 'r', 'g', 'i', 'n', 'g', '\n',
        'b', 'a', 'r', 'i', 'n', 'g', '\n',
        'b', 'a', 'r', 'i', 't', 'o', 'n', 'e', '\n',
        'b', 'a', 'r', 'i', 't', 'o', 'n', 'e', 's', '\n',
        'b', 'a', 'r', 'i', 'u', 'm', '\n',
        'b', 'a', 'r', 'k', '\n',
        'b', 'a', 'r', 'k', 'e', 'd', '\n',
        'b', 'a', 'r', 'k', 'e', 'r', '\n',
        'b', 'a', 'r', 'k', 'e', 'r', 's', '\n',
        'b', 'a', 'r', 'k', 'i', 'n', 'g', '\n',
        'b', 'a', 'r', 'k', 's', '\n',
        'b', 'a', 'r', 'k', 'y', '\n',
        'b', 'a', 'r', 'l', 'e', 'y', '\n',
        'b', 'a', 'r', 'l', 'e', 'y', 'c', 'o', 'r', 'n', '\n',
        'b', 'a', 'r', 'l', 'e', 'y', 'c', 'o', 'r', 'n', 's', '\n',
        'b', 'a', 'r', 'm', 'a', 'i', 'd', '\n',
        'b', 'a', 'r', 'm', 'a', 'i', 'd', 's', '\n',
        'b', 'a', 'r', 'm', 'a', 'n', '\n',
        'b', 'a', 'r', 'm', 'e', 'n', '\n',
        'b', 'a', 'r', 'n', '\n',
        'b', 'a', 'r', 'n', 'a', 'c', 'l', 'e', '\n',
        'b', 'a', 'r', 'n', 'a', 'c', 'l', 'e', 's', '\n',
        'b', 'a', 'r', 'n', 's', '\n',
        'b', 'a', 'r', 'n', 's', 't', 'o', 'r', 'm', 'i', 'n', 'g', '\n',
        'b', 'a', 'r', 'n', 'y', 'a', 'r', 'd', '\n',
        'b', 'a', 'r', 'o', 'm', 'e', 't', 'e', 'r', '\n',
        'b', 'a', 'r', 'o', 'm', 'e', 't', 'e', 'r', 's', '\n',
        'b', 'a', 'r', 'o', 'm', 'e', 't', 'r', 'i', 'c', '\n',
        'b', 'a', 'r', 'o', 'n', '\n',
        'b', 'a', 'r', 'o', 'n', 'a', 'g', 'e', '\n',
        'b', 'a', 'r', 'o', 'n', 'e', 's', 's', '\n',
        'b', 'a', 'r', 'o', 'n', 'e', 's', 's', 'e', 's', '\n',
        'b', 'a', 'r', 'o', 'n', 'e', 't', '\n',
        'b', 'a', 'r', 'o', 'n', 'e', 't', 's', '\n',
        'b', 'a', 'r', 'o', 'n', 'i', 'a', 'l', '\n',
        'b', 'a', 'r', 'o', 'n', 'i', 'e', 's', '\n',
        'b', 'a', 'r', 'o', 'n', 's', '\n',
        'b', 'a', 'r', 'o', 'n', 'y', '\n',
        'b', 'a', 'r', 'o', 'q', 'u', 'e', '\n',
        'b', 'a', 'r', 'r', 'a', 'c', 'k', '\n',
        'b', 'a', 'r', 'r', 'a', 'c', 'k', 'i', 'n', 'g', '\n',
        'b', 'a', 'r', 'r', 'a', 'c', 'k', 's', '\n',
        'b', 'a', 'r', 'r', 'a', 'c', 'u', 'd', 'a', '\n',
        'b', 'a', 'r', 'r', 'a', 'g', 'e', '\n',
        'b', 'a', 'r', 'r', 'a', 'g', 'e', 's', '\n',
        'b', 'a', 'r', 'r', 'e', '\n',
        'b', 'a', 'r', 'r', 'e', 'd', '\n',
        'b', 'a', 'r', 'r', 'e', 'l', '\n',
        'b', 'a', 'r', 'r', 'e', 'l', 'l', 'e', 'd', '\n',
        'b', 'a', 'r', 'r', 'e', 'l', 's', '\n',
        'b', 'a', 'r', 'r', 'e', 'n', '\n',
        'b', 'a', 'r', 'r', 'e', 'n', 'n', 'e', 's', 's', '\n',
        'b', 'a', 'r', 'r', 'i', 'c', 'a', 'd', 'e', '\n',
        'b', 'a', 'r', 'r', 'i', 'c', 'a', 'd', 'e', 'd', '\n',
        'b', 'a', 'r', 'r', 'i', 'c', 'a', 'd', 'e', 's', '\n',
        'b', 'a', 'r', 'r', 'i', 'e', 'r', '\n',
        'b', 'a', 'r', 'r', 'i', 'e', 'r', 's', '\n',
        'b', 'a', 'r', 'r', 'i', 'n', 'g', '\n',
        'b', 'a', 'r', 'r', 'i', 's', 't', 'e', 'r', '\n',
        'b', 'a', 'r', 'r', 'i', 's', 't', 'e', 'r', 's', '\n',
        'b', 'a', 'r', 'r', 'o', 'w', '\n',
        'b', 'a', 'r', 'r', 'o', 'w', 's', '\n',
        'b', 'a', 'r', 's', '\n',
        'b', 'a', 'r', 't', '\n',
        'b', 'a', 'r', 't', 'e', 'n', 'd', 'e', 'r', '\n',
        'b', 'a', 'r', 't', 'e', 'r', '\n',
        'b', 'a', 'r', 't', 'e', 'r', 'e', 'd', '\n',
        'b', 'a', 'r', 't', 'e', 'r', 'e', 'r', '\n',
        'b', 'a', 'r', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'b', 'a', 's', 'a', 'l', '\n',
        'b', 'a', 's', 'a', 'l', 't', '\n',
        'b', 'a', 's', 'a', 'l', 't', 'i', 'c', '\n',
        'b', 'a', 's', 'a', 'l', 't', 's', '\n',
        'b', 'a', 's', 'e', '\n',
        'b', 'a', 's', 'e', 'b', 'a', 'l', 'l', '\n',
        'b', 'a', 's', 'e', 'b', 'a', 'l', 'l', 's', '\n',
        'b', 'a', 's', 'e', 'd', '\n',
        'b', 'a', 's', 'e', 'l', 'e', 's', 's', '\n',
        'b', 'a', 's', 'e', 'l', 'i', 'n', 'e', '\n',
        'b', 'a', 's', 'e', 'l', 'i', 'n', 'e', 's', '\n',
        'b', 'a', 's', 'e', 'l', 'y', '\n',
        'b', 'a', 's', 'e', 'm', 'e', 'n', 't', '\n',
        'b', 'a', 's', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'b', 'a', 's', 'e', 'n', 'e', 's', 's', '\n',
        'b', 'a', 's', 'e', 'r', '\n',
        'b', 'a', 's', 'e', 's', '\n',
        'b', 'a', 's', 'e', 's', 't', '\n',
        'b', 'a', 's', 'h', '\n',
        'b', 'a', 's', 'h', 'e', 'd', '\n',
        'b', 'a', 's', 'h', 'e', 's', '\n',
        'b', 'a', 's', 'h', 'f', 'u', 'l', '\n',
        'b', 'a', 's', 'h', 'f', 'u', 'l', 'l', 'y', '\n',
        'b', 'a', 's', 'h', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'b', 'a', 's', 'h', 'i', 'n', 'g', '\n',
        'b', 'a', 's', 'i', 'c', '\n',
        'b', 'a', 's', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'b', 'a', 's', 'i', 'c', 's', '\n',
        'b', 'a', 's', 'i', 'f', 'y', '\n',
        'b', 'a', 's', 'i', 'l', '\n',
        'b', 'a', 's', 'i', 'l', 'i', 'c', 'a', '\n',
        'b', 'a', 's', 'i', 'l', 'i', 'c', 'a', 's', '\n',
        'b', 'a', 's', 'i', 'l', 'i', 's', 'k', '\n',
        'b', 'a', 's', 'i', 'l', 'i', 's', 'k', 's', '\n',
        'b', 'a', 's', 'i', 'n', '\n',
        'b', 'a', 's', 'i', 'n', 'f', 'u', 'l', '\n',
        'b', 'a', 's', 'i', 'n', 'g', '\n',
        'b', 'a', 's', 'i', 'n', 's', '\n',
        'b', 'a', 's', 'i', 's', '\n',
        'b', 'a', 's', 'k', '\n',
        'b', 'a', 's', 'k', 'e', 'd', '\n',
        'b', 'a', 's', 'k', 'e', 't', '\n',
        'b', 'a', 's', 'k', 'e', 't', 'b', 'a', 'l', 'l', '\n',
        'b', 'a', 's', 'k', 'e', 't', 'f', 'u', 'l', '\n',
        'b', 'a', 's', 'k', 'e', 't', 'r', 'y', '\n',
        'b', 'a', 's', 'k', 'e', 't', 's', '\n',
        'b', 'a', 's', 'k', 'i', 'n', 'g', '\n',
        'b', 'a', 's', 'k', 's', '\n',
        'b', 'a', 's', 'q', 'u', 'e', '\n',
        'b', 'a', 's', 'r', 'e', 'l', 'i', 'e', 'f', '\n',
        'b', 'a', 's', 'r', 'e', 'l', 'i', 'e', 'f', 's', '\n',
        'b', 'a', 's', 's', '\n',
        'b', 'a', 's', 's', 'e', 's', '\n',
        'b', 'a', 's', 's', 'i', 's', 't', '\n',
        'b', 'a', 's', 's', 'o', 'o', 'n', '\n',
        'b', 'a', 's', 's', 'o', 'o', 'n', 's', '\n',
        'b', 'a', 's', 't', 'a', 'r', 'd', '\n',
        'b', 'a', 's', 't', 'a', 'r', 'd', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'b', 'a', 's', 't', 'a', 'r', 'd', 'i', 's', 'e', '\n',
        'b', 'a', 's', 't', 'a', 'r', 'd', 'i', 's', 'e', 'd', '\n',
        'b', 'a', 's', 't', 'a', 'r', 'd', 's', '\n',
        'b', 'a', 's', 't', 'a', 'r', 'd', 'y', '\n',
        'b', 'a', 's', 't', 'e', '\n',
        'b', 'a', 's', 't', 'e', 'd', '\n',
        'b', 'a', 's', 't', 'i', 'n', 'g', '\n',
        'b', 'a', 's', 't', 'i', 'o', 'n', '\n',
        'b', 'a', 's', 't', 'i', 'o', 'n', 's', '\n',
        'b', 'a', 't', '\n',
        'b', 'a', 't', 'c', 'h', '\n',
        'b', 'a', 't', 'c', 'h', 'e', 'd', '\n',
        'b', 'a', 't', 'c', 'h', 'e', 's', '\n',
        'b', 'a', 't', 'c', 'h', 'i', 'n', 'g', '\n',
        'b', 'a', 't', 'e', '\n',
        'b', 'a', 't', 'e', 'd', '\n',
        'b', 'a', 't', 'e', 's', '\n',
        'b', 'a', 't', 'h', '\n',
        'b', 'a', 't', 'h', 'e', '\n',
        'b', 'a', 't', 'h', 'e', 'd', '\n',
        'b', 'a', 't', 'h', 'e', 'r', '\n',
        'b', 'a', 't', 'h', 'e', 'r', 's', '\n',
        'b', 'a', 't', 'h', 'e', 's', '\n',
        'b', 'a', 't', 'h', 'e', 't', 'i', 'c', '\n',
        'b', 'a', 't', 'h', 'h', 'o', 'u', 's', 'e', '\n',
        'b', 'a', 't', 'h', 'i', 'n', 'g', '\n',
        'b', 'a', 't', 'h', 'o', 's', '\n',
        'b', 'a', 't', 'h', 'r', 'o', 'b', 'e', '\n',
        'b', 'a', 't', 'h', 'r', 'o', 'o', 'm', '\n',
        'b', 'a', 't', 'h', 'r', 'o', 'o', 'm', 's', '\n',
        'b', 'a', 't', 'h', 's', '\n',
        'b', 'a', 't', 'h', 't', 'u', 'b', '\n',
        'b', 'a', 't', 'h', 't', 'u', 'b', 's', '\n',
        'b', 'a', 't', 'h', 'u', 'r', 's', 't', '\n',
        'b', 'a', 't', 'h', 'w', 'a', 't', 'e', 'r', '\n',
        'b', 'a', 't', 'i', 'k', '\n',
        'b', 'a', 't', 'i', 'k', 's', '\n',
        'b', 'a', 't', 'i', 'n', 'g', '\n',
        'b', 'a', 't', 'm', 'a', 'n', '\n',
        'b', 'a', 't', 'm', 'e', 'n', '\n',
        'b', 'a', 't', 'o', 'n', '\n',
        'b', 'a', 't', 'o', 'n', 's', '\n',
        'b', 'a', 't', 's', '\n',
        'b', 'a', 't', 's', 'm', 'a', 'n', '\n',
        'b', 'a', 't', 's', 'm', 'e', 'n', '\n',
        'b', 'a', 't', 't', 'a', 'l', 'i', 'o', 'n', '\n',
        'b', 'a', 't', 't', 'a', 'l', 'i', 'o', 'n', 's', '\n',
        'b', 'a', 't', 't', 'e', 'd', '\n',
        'b', 'a', 't', 't', 'e', 'n', '\n',
        'b', 'a', 't', 't', 'e', 'n', 'e', 'd', '\n',
        'b', 'a', 't', 't', 'e', 'n', 'i', 'n', 'g', '\n',
        'b', 'a', 't', 't', 'e', 'n', 's', '\n',
        'b', 'a', 't', 't', 'e', 'r', '\n',
        'b', 'a', 't', 't', 'e', 'r', 'e', 'd', '\n',
        'b', 'a', 't', 't', 'e', 'r', 'i', 'e', 's', '\n',
        'b', 'a', 't', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'b', 'a', 't', 't', 'e', 'r', 's', '\n',
        'b', 'a', 't', 't', 'e', 'r', 'y', '\n',
        'b', 'a', 't', 't', 'i', 'n', 'g', '\n',
        'b', 'a', 't', 't', 'l', 'e', '\n',
        'b', 'a', 't', 't', 'l', 'e', 'a', 'x', 'e', '\n',
        'b', 'a', 't', 't', 'l', 'e', 'c', 'r', 'y', '\n',
        'b', 'a', 't', 't', 'l', 'e', 'd', '\n',
        'b', 'a', 't', 't', 'l', 'e', 'd', 'r', 'e', 's', 's', '\n',
        'b', 'a', 't', 't', 'l', 'e', 'f', 'i', 'e', 'l', 'd', '\n',
        'b', 'a', 't', 't', 'l', 'e', 'f', 'i', 'e', 'l', 'd', 's', '\n',
        'b', 'a', 't', 't', 'l', 'e', 'g', 'r', 'o', 'u', 'n', 'd', '\n',
        'b', 'a', 't', 't', 'l', 'e', 'g', 'r', 'o', 'u', 'n', 'd', 's', '\n',
        'b', 'a', 't', 't', 'l', 'e', 'm', 'e', 'n', 't', '\n',
        'b', 'a', 't', 't', 'l', 'e', 'm', 'e', 'n', 't', 'e', 'd', '\n',
        'b', 'a', 't', 't', 'l', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'b', 'a', 't', 't', 'l', 'e', 'r', '\n',
        'b', 'a', 't', 't', 'l', 'e', 'r', 's', '\n',
        'b', 'a', 't', 't', 'l', 'e', 's', '\n',
        'b', 'a', 't', 't', 'l', 'e', 's', 'h', 'i', 'p', '\n',
        'b', 'a', 't', 't', 'l', 'e', 's', 'h', 'i', 'p', 's', '\n',
        'b', 'a', 't', 't', 'l', 'i', 'n', 'g', '\n',
        'b', 'a', 't', 't', 'y', '\n',
        'b', 'a', 'u', 'b', 'l', 'e', '\n',
        'b', 'a', 'u', 'b', 'l', 'e', 's', '\n',
        'b', 'a', 'u', 'd', '\n',
        'b', 'a', 'u', 'l', 'k', '\n',
        'b', 'a', 'u', 'l', 'k', 'e', 'd', '\n',
        'b', 'a', 'u', 'l', 'k', 'i', 'n', 'g', '\n',
        'b', 'a', 'u', 'l', 'k', 's', '\n',
        'b', 'a', 'u', 'l', 'k', 'y', '\n',
        'b', 'a', 'u', 'x', 'i', 't', 'e', '\n',
        'b', 'a', 'v', 'a', 'r', 'i', 'a', '\n',
        'b', 'a', 'v', 'a', 'r', 'i', 'a', 'n', '\n',
        'b', 'a', 'w', 'd', 'i', 'e', 'r', '\n',
        'b', 'a', 'w', 'd', 'i', 'e', 's', 't', '\n',
        'b', 'a', 'w', 'd', 'y', '\n',
        'b', 'a', 'w', 'l', '\n',
        'b', 'a', 'w', 'l', 'e', 'd', '\n',
        'b', 'a', 'w', 'l', 'i', 'n', 'g', '\n',
        'b', 'a', 'w', 'l', 's', '\n',
        'b', 'a', 'y', '\n',
        'b', 'a', 'y', 'e', 'd', '\n',
        'b', 'a', 'y', 'i', 'n', 'g', '\n',
        'b', 'a', 'y', 'o', 'n', 'e', 't', '\n',
        'b', 'a', 'y', 'o', 'n', 'e', 't', 's', '\n',
        'b', 'a', 'y', 's', '\n',
        'b', 'a', 'z', 'a', 'a', 'r', '\n',
        'b', 'a', 'z', 'a', 'a', 'r', 's', '\n',
        'b', 'a', 'z', 'o', 'o', 'k', 'a', '\n',
        'b', 'a', 'z', 'o', 'o', 'k', 'a', 's', '\n',
        'b', 'e', '\n',
        'b', 'e', 'a', 'c', 'h', '\n',
        'b', 'e', 'a', 'c', 'h', 'c', 'o', 'm', 'b', 'e', 'r', '\n',
        'b', 'e', 'a', 'c', 'h', 'e', 'd', '\n',
        'b', 'e', 'a', 'c', 'h', 'e', 's', '\n',
        'b', 'e', 'a', 'c', 'h', 'h', 'e', 'a', 'd', '\n',
        'b', 'e', 'a', 'c', 'h', 'i', 'n', 'g', '\n',
        'b', 'e', 'a', 'c', 'h', 's', 'i', 'd', 'e', '\n',
        'b', 'e', 'a', 'c', 'h', 'y', '\n',
        'b', 'e', 'a', 'c', 'o', 'n', '\n',
        'b', 'e', 'a', 'c', 'o', 'n', 'e', 'd', '\n',
        'b', 'e', 'a', 'c', 'o', 'n', 's', '\n',
        'b', 'e', 'a', 'd', '\n',
        'b', 'e', 'a', 'd', 'e', 'd', '\n',
        'b', 'e', 'a', 'd', 'i', 'e', 'r', '\n',
        'b', 'e', 'a', 'd', 'i', 'e', 's', 't', '\n',
        'b', 'e', 'a', 'd', 'i', 'n', 'g', '\n',
        'b', 'e', 'a', 'd', 'i', 'n', 'g', 's', '\n',
        'b', 'e', 'a', 'd', 'l', 'e', '\n',
        'b', 'e', 'a', 'd', 'l', 'e', 's', '\n',
        'b', 'e', 'a', 'd', 's', '\n',
        'b', 'e', 'a', 'd', 'w', 'o', 'r', 'k', '\n',
        'b', 'e', 'a', 'd', 'y', '\n',
        'b', 'e', 'a', 'd', 'y', 'e', 'y', 'e', 'd', '\n',
        'b', 'e', 'a', 'g', 'l', 'e', '\n',
        'b', 'e', 'a', 'g', 'l', 'e', 's', '\n',
        'b', 'e', 'a', 'k', '\n',
        'b', 'e', 'a', 'k', 'e', 'd', '\n',
        'b', 'e', 'a', 'k', 'e', 'r', '\n',
        'b', 'e', 'a', 'k', 'e', 'r', 's', '\n',
        'b', 'e', 'a', 'k', 's', '\n',
        'b', 'e', 'a', 'm', '\n',
        'b', 'e', 'a', 'm', 'e', 'd', '\n',
        'b', 'e', 'a', 'm', 'i', 'n', 'g', '\n',
        'b', 'e', 'a', 'm', 's', '\n',
        'b', 'e', 'a', 'm', 'y', '\n',
        'b', 'e', 'a', 'n', '\n',
        'b', 'e', 'a', 'n', 'b', 'a', 'g', '\n',
        'b', 'e', 'a', 'n', 'e', 'r', 'y', '\n',
        'b', 'e', 'a', 'n', 'i', 'e', '\n',
        'b', 'e', 'a', 'n', 'p', 'o', 'l', 'e', '\n',
        'b', 'e', 'a', 'n', 's', '\n',
        'b', 'e', 'a', 'n', 's', 't', 'a', 'l', 'k', '\n',
        'b', 'e', 'a', 'n', 's', 't', 'a', 'l', 'k', 's', '\n',
        'b', 'e', 'a', 'n', 'y', '\n',
        'b', 'e', 'a', 'r', '\n',
        'b', 'e', 'a', 'r', 'a', 'b', 'l', 'e', '\n',
        'b', 'e', 'a', 'r', 'a', 'b', 'l', 'y', '\n',
        'b', 'e', 'a', 'r', 'd', '\n',
        'b', 'e', 'a', 'r', 'd', 'e', 'd', '\n',
        'b', 'e', 'a', 'r', 'd', 'l', 'e', 's', 's', '\n',
        'b', 'e', 'a', 'r', 'd', 's', '\n',
        'b', 'e', 'a', 'r', 'e', 'r', '\n',
        'b', 'e', 'a', 'r', 'e', 'r', 's', '\n',
        'b', 'e', 'a', 'r', 'i', 'n', 'g', '\n',
        'b', 'e', 'a', 'r', 'i', 'n', 'g', 's', '\n',
        'b', 'e', 'a', 'r', 'i', 's', 'h', '\n',
        'b', 'e', 'a', 'r', 's', '\n',
        'b', 'e', 'a', 'r', 's', 'k', 'i', 'n', '\n',
        'b', 'e', 'a', 'r', 's', 'k', 'i', 'n', 's', '\n',
        'b', 'e', 'a', 's', 't', '\n',
        'b', 'e', 'a', 's', 't', 'l', 'i', 'e', 's', 't', '\n',
        'b', 'e', 'a', 's', 't', 'l', 'i', 'n', 'e', 's', 's', '\n',
        'b', 'e', 'a', 's', 't', 'l', 'y', '\n',
        'b', 'e', 'a', 's', 't', 's', '\n',
        'b', 'e', 'a', 't', '\n',
        'b', 'e', 'a', 't', 'e', 'n', '\n',
        'b', 'e', 'a', 't', 'e', 'r', '\n',
        'b', 'e', 'a', 't', 'e', 'r', 's', '\n',
        'b', 'e', 'a', 't', 'i', 'f', 'i', 'c', '\n',
        'b', 'e', 'a', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'b', 'e', 'a', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'b', 'e', 'a', 't', 'i', 'f', 'i', 'e', 'd', '\n',
        'b', 'e', 'a', 't', 'i', 'f', 'i', 'e', 's', '\n',
        'b', 'e', 'a', 't', 'i', 'f', 'y', '\n',
        'b', 'e', 'a', 't', 'i', 'n', 'g', '\n',
        'b', 'e', 'a', 't', 'i', 'n', 'g', 's', '\n',
        'b', 'e', 'a', 't', 'i', 't', 'u', 'd', 'e', '\n',
        'b', 'e', 'a', 't', 'i', 't', 'u', 'd', 'e', 's', '\n',
        'b', 'e', 'a', 't', 'n', 'i', 'k', '\n',
        'b', 'e', 'a', 't', 'n', 'i', 'k', 's', '\n',
        'b', 'e', 'a', 't', 's', '\n',
        'b', 'e', 'a', 't', 'u', 'p', '\n',
        'b', 'e', 'a', 'u', '\n',
        'b', 'e', 'a', 'u', 's', '\n',
        'b', 'e', 'a', 'u', 't', 'e', 'o', 'u', 's', '\n',
        'b', 'e', 'a', 'u', 't', 'i', 'c', 'i', 'a', 'n', '\n',
        'b', 'e', 'a', 'u', 't', 'i', 'e', 's', '\n',
        'b', 'e', 'a', 'u', 't', 'i', 'f', 'i', 'e', 'd', '\n',
        'b', 'e', 'a', 'u', 't', 'i', 'f', 'i', 'e', 'r', '\n',
        'b', 'e', 'a', 'u', 't', 'i', 'f', 'i', 'e', 'r', 's', '\n',
        'b', 'e', 'a', 'u', 't', 'i', 'f', 'i', 'e', 's', '\n',
        'b', 'e', 'a', 'u', 't', 'i', 'f', 'u', 'l', '\n',
        'b', 'e', 'a', 'u', 't', 'i', 'f', 'u', 'l', 'l', 'y', '\n',
        'b', 'e', 'a', 'u', 't', 'i', 'f', 'y', '\n',
        'b', 'e', 'a', 'u', 't', 's', '\n',
        'b', 'e', 'a', 'u', 't', 'y', '\n',
        'b', 'e', 'a', 'u', 'x', '\n',
        'b', 'e', 'a', 'v', 'e', 'r', '\n',
        'b', 'e', 'a', 'v', 'e', 'r', 'i', 'n', 'g', '\n',
        'b', 'e', 'a', 'v', 'e', 'r', 's', '\n',
        'b', 'e', 'b', 'o', 'p', '\n',
        'b', 'e', 'c', 'a', 'l', 'm', '\n',
        'b', 'e', 'c', 'a', 'l', 'm', 'e', 'd', '\n',
        'b', 'e', 'c', 'a', 'm', 'e', '\n',
        'b', 'e', 'c', 'a', 'u', 's', 'e', '\n',
        'b', 'e', 'c', 'k', '\n',
        'b', 'e', 'c', 'k', 'o', 'n', '\n',
        'b', 'e', 'c', 'k', 'o', 'n', 'e', 'd', '\n',
        'b', 'e', 'c', 'k', 'o', 'n', 'i', 'n', 'g', '\n',
        'b', 'e', 'c', 'k', 'o', 'n', 's', '\n',
        'b', 'e', 'c', 'k', 's', '\n',
        'b', 'e', 'c', 'o', 'm', 'e', '\n',
        'b', 'e', 'c', 'o', 'm', 'e', 's', '\n',
        'b', 'e', 'c', 'o', 'm', 'i', 'n', 'g', '\n',
        'b', 'e', 'd', '\n',
        'b', 'e', 'd', 'a', 'z', 'z', 'l', 'e', '\n',
        'b', 'e', 'd', 'a', 'z', 'z', 'l', 'e', 'd', '\n',
        'b', 'e', 'd', 'b', 'u', 'g', '\n',
        'b', 'e', 'd', 'b', 'u', 'g', 's', '\n',
        'b', 'e', 'd', 'c', 'h', 'a', 'm', 'b', 'e', 'r', '\n',
        'b', 'e', 'd', 'c', 'l', 'o', 't', 'h', 'e', 's', '\n',
        'b', 'e', 'd', 'c', 'o', 'v', 'e', 'r', '\n',
        'b', 'e', 'd', 'd', 'e', 'd', '\n',
        'b', 'e', 'd', 'd', 'e', 'r', '\n',
        'b', 'e', 'd', 'd', 'i', 'n', 'g', '\n',
        'b', 'e', 'd', 'd', 'i', 'n', 'g', 's', '\n',
        'b', 'e', 'd', 'e', 'c', 'k', 'e', 'd', '\n',
        'b', 'e', 'd', 'e', 'c', 'k', 's', '\n',
        'b', 'e', 'd', 'e', 'v', 'i', 'l', '\n',
        'b', 'e', 'd', 'e', 'v', 'i', 'l', 'l', 'e', 'd', '\n',
        'b', 'e', 'd', 'e', 'v', 'i', 'l', 'm', 'e', 'n', 't', '\n',
        'b', 'e', 'd', 'e', 'v', 'i', 'l', 's', '\n',
        'b', 'e', 'd', 'f', 'e', 'l', 'l', 'o', 'w', '\n',
        'b', 'e', 'd', 'f', 'e', 'l', 'l', 'o', 'w', 's', '\n',
        'b', 'e', 'd', 'l', 'a', 'm', '\n',
        'b', 'e', 'd', 'l', 'i', 'n', 'e', 'n', '\n',
        'b', 'e', 'd', 'm', 'a', 'k', 'e', 'r', '\n',
        'b', 'e', 'd', 'm', 'a', 'k', 'e', 'r', 's', '\n',
        'b', 'e', 'd', 'o', 'u', 'i', 'n', '\n',
        'b', 'e', 'd', 'o', 'u', 'i', 'n', 's', '\n',
        'b', 'e', 'd', 'p', 'a', 'n', '\n',
        'b', 'e', 'd', 'p', 'a', 'n', 's', '\n',
        'b', 'e', 'd', 'p', 'o', 's', 't', '\n',
        'b', 'e', 'd', 'r', 'a', 'g', 'g', 'l', 'e', 'd', '\n',
        'b', 'e', 'd', 'r', 'i', 'd', 'd', 'e', 'n', '\n',
        'b', 'e', 'd', 'r', 'o', 'c', 'k', '\n',
        'b', 'e', 'd', 'r', 'o', 'o', 'm', '\n',
        'b', 'e', 'd', 'r', 'o', 'o', 'm', 's', '\n',
        'b', 'e', 'd', 's', '\n',
        'b', 'e', 'd', 's', 'h', 'e', 'e', 't', 's', '\n',
        'b', 'e', 'd', 's', 'i', 'd', 'e', '\n',
        'b', 'e', 'd', 's', 'i', 't', '\n',
        'b', 'e', 'd', 's', 'i', 't', 't', 'e', 'r', '\n',
        'b', 'e', 'd', 's', 'i', 't', 't', 'e', 'r', 's', '\n',
        'b', 'e', 'd', 's', 'o', 'r', 'e', '\n',
        'b', 'e', 'd', 's', 'o', 'r', 'e', 's', '\n',
        'b', 'e', 'd', 's', 'p', 'r', 'e', 'a', 'd', '\n',
        'b', 'e', 'd', 's', 'p', 'r', 'e', 'a', 'd', 's', '\n',
        'b', 'e', 'd', 's', 't', 'e', 'a', 'd', '\n',
        'b', 'e', 'd', 's', 't', 'e', 'a', 'd', 's', '\n',
        'b', 'e', 'd', 't', 'i', 'm', 'e', '\n',
        'b', 'e', 'd', 't', 'i', 'm', 'e', 's', '\n',
        'b', 'e', 'e', '\n',
        'b', 'e', 'e', 'c', 'h', '\n',
        'b', 'e', 'e', 'c', 'h', 'e', 's', '\n',
        'b', 'e', 'e', 'c', 'h', 'n', 'u', 't', '\n',
        'b', 'e', 'e', 'c', 'h', 'w', 'o', 'o', 'd', '\n',
        'b', 'e', 'e', 'f', '\n',
        'b', 'e', 'e', 'f', 'b', 'u', 'r', 'g', 'e', 'r', '\n',
        'b', 'e', 'e', 'f', 'b', 'u', 'r', 'g', 'e', 'r', 's', '\n',
        'b', 'e', 'e', 'f', 'c', 'a', 'k', 'e', '\n',
        'b', 'e', 'e', 'f', 'e', 'a', 't', 'e', 'r', '\n',
        'b', 'e', 'e', 'f', 'i', 'e', 'r', '\n',
        'b', 'e', 'e', 'f', 'i', 'e', 's', 't', '\n',
        'b', 'e', 'e', 'f', 's', '\n',
        'b', 'e', 'e', 'f', 'y', '\n',
        'b', 'e', 'e', 'h', 'i', 'v', 'e', '\n',
        'b', 'e', 'e', 'h', 'i', 'v', 'e', 's', '\n',
        'b', 'e', 'e', 'k', 'e', 'e', 'p', 'e', 'r', 's', '\n',
        'b', 'e', 'e', 'l', 'i', 'n', 'e', '\n',
        'b', 'e', 'e', 'l', 'i', 'n', 'e', 's', '\n',
        'b', 'e', 'e', 'n', '\n',
        'b', 'e', 'e', 'p', '\n',
        'b', 'e', 'e', 'p', 'e', 'r', '\n',
        'b', 'e', 'e', 'p', 'i', 'n', 'g', '\n',
        'b', 'e', 'e', 'p', 's', '\n',
        'b', 'e', 'e', 'r', '\n',
        'b', 'e', 'e', 'r', 'm', 'a', 't', '\n',
        'b', 'e', 'e', 'r', 'm', 'a', 't', 's', '\n',
        'b', 'e', 'e', 'r', 's', '\n',
        'b', 'e', 'e', 'r', 'y', '\n',
        'b', 'e', 'e', 's', '\n',
        'b', 'e', 'e', 's', 'w', 'a', 'x', '\n',
        'b', 'e', 'e', 't', '\n',
        'b', 'e', 'e', 't', 'l', 'e', '\n',
        'b', 'e', 'e', 't', 'l', 'e', 's', '\n',
        'b', 'e', 'e', 't', 'r', 'o', 'o', 't', '\n',
        'b', 'e', 'e', 't', 's', '\n',
        'b', 'e', 'f', 'a', 'l', 'l', '\n',
        'b', 'e', 'f', 'a', 'l', 'l', 'e', 'n', '\n',
        'b', 'e', 'f', 'a', 'l', 'l', 'i', 'n', 'g', '\n',
        'b', 'e', 'f', 'a', 'l', 'l', 's', '\n',
        'b', 'e', 'f', 'e', 'l', 'l', '\n',
        'b', 'e', 'f', 'i', 't', '\n',
        'b', 'e', 'f', 'i', 't', 's', '\n',
        'b', 'e', 'f', 'i', 't', 't', 'e', 'd', '\n',
        'b', 'e', 'f', 'i', 't', 't', 'i', 'n', 'g', '\n',
        'b', 'e', 'f', 'o', 'g', '\n',
        'b', 'e', 'f', 'o', 'r', 'e', '\n',
        'b', 'e', 'f', 'o', 'r', 'e', 'h', 'a', 'n', 'd', '\n',
        'b', 'e', 'f', 'o', 'u', 'l', '\n',
        'b', 'e', 'f', 'r', 'i', 'e', 'n', 'd', '\n',
        'b', 'e', 'f', 'r', 'i', 'e', 'n', 'd', 'e', 'd', '\n',
        'b', 'e', 'f', 'r', 'i', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'b', 'e', 'f', 'r', 'i', 'e', 'n', 'd', 's', '\n',
        'b', 'e', 'f', 'u', 'd', 'd', 'l', 'e', '\n',
        'b', 'e', 'f', 'u', 'd', 'd', 'l', 'e', 'd', '\n',
        'b', 'e', 'f', 'u', 'd', 'd', 'l', 'i', 'n', 'g', '\n',
        'b', 'e', 'g', '\n',
        'b', 'e', 'g', 'a', 'n', '\n',
        'b', 'e', 'g', 'a', 't', '\n',
        'b', 'e', 'g', 'e', 't', '\n',
        'b', 'e', 'g', 'e', 't', 's', '\n',
        'b', 'e', 'g', 'e', 't', 't', 'i', 'n', 'g', '\n',
        'b', 'e', 'g', 'g', 'a', 'r', '\n',
        'b', 'e', 'g', 'g', 'a', 'r', 'e', 'd', '\n',
        'b', 'e', 'g', 'g', 'a', 'r', 'l', 'y', '\n',
        'b', 'e', 'g', 'g', 'a', 'r', 's', '\n',
        'b', 'e', 'g', 'g', 'a', 'r', 'y', '\n',
        'b', 'e', 'g', 'g', 'e', 'd', '\n',
        'b', 'e', 'g', 'g', 'i', 'n', 'g', '\n',
        'b', 'e', 'g', 'g', 'i', 'n', 'g', 's', '\n',
        'b', 'e', 'g', 'i', 'n', '\n',
        'b', 'e', 'g', 'i', 'n', 'n', 'e', 'r', '\n',
        'b', 'e', 'g', 'i', 'n', 'n', 'e', 'r', 's', '\n',
        'b', 'e', 'g', 'i', 'n', 'n', 'i', 'n', 'g', '\n',
        'b', 'e', 'g', 'i', 'n', 'n', 'i', 'n', 'g', 's', '\n',
        'b', 'e', 'g', 'i', 'n', 's', '\n',
        'b', 'e', 'g', 'o', 'n', 'e', '\n',
        'b', 'e', 'g', 'o', 'n', 'i', 'a', 's', '\n',
        'b', 'e', 'g', 'o', 't', '\n',
        'b', 'e', 'g', 'o', 't', 't', 'e', 'n', '\n',
        'b', 'e', 'g', 'r', 'u', 'd', 'g', 'e', '\n',
        'b', 'e', 'g', 'r', 'u', 'd', 'g', 'e', 'd', '\n',
        'b', 'e', 'g', 'r', 'u', 'd', 'g', 'i', 'n', 'g', 'l', 'y', '\n',
        'b', 'e', 'g', 's', '\n',
        'b', 'e', 'g', 'u', 'i', 'l', 'e', '\n',
        'b', 'e', 'g', 'u', 'i', 'l', 'e', 'd', '\n',
        'b', 'e', 'g', 'u', 'i', 'l', 'e', 'm', 'e', 'n', 't', '\n',
        'b', 'e', 'g', 'u', 'i', 'l', 'i', 'n', 'g', '\n',
        'b', 'e', 'g', 'u', 'n', '\n',
        'b', 'e', 'h', 'a', 'l', 'f', '\n',
        'b', 'e', 'h', 'a', 'v', 'e', '\n',
        'b', 'e', 'h', 'a', 'v', 'e', 'd', '\n',
        'b', 'e', 'h', 'a', 'v', 'e', 's', '\n',
        'b', 'e', 'h', 'a', 'v', 'i', 'n', 'g', '\n',
        'b', 'e', 'h', 'a', 'v', 'i', 'o', 'u', 'r', '\n',
        'b', 'e', 'h', 'a', 'v', 'i', 'o', 'u', 'r', 'a', 'l', '\n',
        'b', 'e', 'h', 'a', 'v', 'i', 'o', 'u', 'r', 'a', 'l', 'l', 'y', '\n',
        'b', 'e', 'h', 'a', 'v', 'i', 'o', 'u', 'r', 'i', 's', 'm', '\n',
        'b', 'e', 'h', 'a', 'v', 'i', 'o', 'u', 'r', 'i', 's', 't', '\n',
        'b', 'e', 'h', 'a', 'v', 'i', 'o', 'u', 'r', 'i', 's', 't', 's', '\n',
        'b', 'e', 'h', 'a', 'v', 'i', 'o', 'u', 'r', 's', '\n',
        'b', 'e', 'h', 'e', 'a', 'd', '\n',
        'b', 'e', 'h', 'e', 'a', 'd', 'e', 'd', '\n',
        'b', 'e', 'h', 'e', 'a', 'd', 'i', 'n', 'g', '\n',
        'b', 'e', 'h', 'e', 'l', 'd', '\n',
        'b', 'e', 'h', 'e', 'm', 'o', 't', 'h', '\n',
        'b', 'e', 'h', 'e', 's', 't', '\n',
        'b', 'e', 'h', 'i', 'n', 'd', '\n',
        'b', 'e', 'h', 'i', 'n', 'd', 'h', 'a', 'n', 'd', '\n',
        'b', 'e', 'h', 'i', 'n', 'd', 's', '\n',
        'b', 'e', 'h', 'o', 'l', 'd', '\n',
        'b', 'e', 'h', 'o', 'l', 'd', 'e', 'n', '\n',
        'b', 'e', 'h', 'o', 'l', 'd', 'e', 'r', '\n',
        'b', 'e', 'h', 'o', 'l', 'd', 'e', 'r', 's', '\n',
        'b', 'e', 'h', 'o', 'l', 'd', 'i', 'n', 'g', '\n',
        'b', 'e', 'h', 'o', 'l', 'd', 's', '\n',
        'b', 'e', 'h', 'o', 'v', 'e', 'd', '\n',
        'b', 'e', 'h', 'o', 'v', 'e', 's', '\n',
        'b', 'e', 'i', 'g', 'e', '\n',
        'b', 'e', 'i', 'j', 'i', 'n', 'g', '\n',
        'b', 'e', 'i', 'n', 'g', '\n',
        'b', 'e', 'i', 'n', 'g', 's', '\n',
        'b', 'e', 'i', 'r', 'u', 't', '\n',
        'b', 'e', 'j', 'e', 'w', 'e', 'l', '\n',
        'b', 'e', 'j', 'e', 'w', 'e', 'l', 'l', 'e', 'd', '\n',
        'b', 'e', 'l', '\n',
        'b', 'e', 'l', 'a', 'b', 'o', 'u', 'r', '\n',
        'b', 'e', 'l', 'a', 't', 'e', 'd', '\n',
        'b', 'e', 'l', 'a', 't', 'e', 'd', 'l', 'y', '\n',
        'b', 'e', 'l', 'a', 't', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'b', 'e', 'l', 'a', 'y', '\n',
        'b', 'e', 'l', 'a', 'y', 'e', 'd', '\n',
        'b', 'e', 'l', 'a', 'y', 's', '\n',
        'b', 'e', 'l', 'c', 'h', '\n',
        'b', 'e', 'l', 'c', 'h', 'e', 'd', '\n',
        'b', 'e', 'l', 'c', 'h', 'e', 's', '\n',
        'b', 'e', 'l', 'c', 'h', 'i', 'n', 'g', '\n',
        'b', 'e', 'l', 'e', 'a', 'g', 'u', 'e', 'r', 'e', 'd', '\n',
        'b', 'e', 'l', 'f', 'a', 's', 't', '\n',
        'b', 'e', 'l', 'f', 'r', 'i', 'e', 's', '\n',
        'b', 'e', 'l', 'f', 'r', 'y', '\n',
        'b', 'e', 'l', 'g', 'i', 'a', 'n', '\n',
        'b', 'e', 'l', 'g', 'i', 'a', 'n', 's', '\n',
        'b', 'e', 'l', 'g', 'i', 'u', 'm', '\n',
        'b', 'e', 'l', 'g', 'r', 'a', 'd', 'e', '\n',
        'b', 'e', 'l', 'i', 'e', '\n',
        'b', 'e', 'l', 'i', 'e', 'd', '\n',
        'b', 'e', 'l', 'i', 'e', 'f', '\n',
        'b', 'e', 'l', 'i', 'e', 'f', 's', '\n',
        'b', 'e', 'l', 'i', 'e', 's', '\n',
        'b', 'e', 'l', 'i', 'e', 'v', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'b', 'e', 'l', 'i', 'e', 'v', 'a', 'b', 'l', 'e', '\n',
        'b', 'e', 'l', 'i', 'e', 'v', 'a', 'b', 'l', 'y', '\n',
        'b', 'e', 'l', 'i', 'e', 'v', 'e', '\n',
        'b', 'e', 'l', 'i', 'e', 'v', 'e', 'd', '\n',
        'b', 'e', 'l', 'i', 'e', 'v', 'e', 'r', '\n',
        'b', 'e', 'l', 'i', 'e', 'v', 'e', 'r', 's', '\n',
        'b', 'e', 'l', 'i', 'e', 'v', 'e', 's', '\n',
        'b', 'e', 'l', 'i', 'e', 'v', 'i', 'n', 'g', '\n',
        'b', 'e', 'l', 'i', 'k', 'e', '\n',
        'b', 'e', 'l', 'i', 't', 't', 'l', 'e', '\n',
        'b', 'e', 'l', 'i', 't', 't', 'l', 'e', 'd', '\n',
        'b', 'e', 'l', 'i', 't', 't', 'l', 'e', 's', '\n',
        'b', 'e', 'l', 'i', 't', 't', 'l', 'i', 'n', 'g', '\n',
        'b', 'e', 'l', 'l', '\n',
        'b', 'e', 'l', 'l', 'a', 'd', 'o', 'n', 'n', 'a', '\n',
        'b', 'e', 'l', 'l', 'b', 'o', 't', 't', 'o', 'm', 's', '\n',
        'b', 'e', 'l', 'l', 'e', '\n',
        'b', 'e', 'l', 'l', 'e', 'd', '\n',
        'b', 'e', 'l', 'l', 'e', 's', '\n',
        'b', 'e', 'l', 'l', 'i', 'c', 'o', 's', 'e', '\n',
        'b', 'e', 'l', 'l', 'i', 'c', 'o', 's', 'i', 't', 'y', '\n',
        'b', 'e', 'l', 'l', 'i', 'e', 's', '\n',
        'b', 'e', 'l', 'l', 'i', 'g', 'e', 'r', 'e', 'n', 'c', 'e', '\n',
        'b', 'e', 'l', 'l', 'i', 'g', 'e', 'r', 'e', 'n', 't', '\n',
        'b', 'e', 'l', 'l', 'i', 'g', 'e', 'r', 'e', 'n', 't', 'l', 'y', '\n',
        'b', 'e', 'l', 'l', 'i', 'g', 'e', 'r', 'e', 'n', 't', 's', '\n',
        'b', 'e', 'l', 'l', 'o', 'w', '\n',
        'b', 'e', 'l', 'l', 'o', 'w', 'e', 'd', '\n',
        'b', 'e', 'l', 'l', 'o', 'w', 'i', 'n', 'g', '\n',
        'b', 'e', 'l', 'l', 'o', 'w', 's', '\n',
        'b', 'e', 'l', 'l', 's', '\n',
        'b', 'e', 'l', 'l', 'y', '\n',
        'b', 'e', 'l', 'l', 'y', 'f', 'u', 'l', '\n',
        'b', 'e', 'l', 'o', 'n', 'g', '\n',
        'b', 'e', 'l', 'o', 'n', 'g', 'e', 'd', '\n',
        'b', 'e', 'l', 'o', 'n', 'g', 'i', 'n', 'g', '\n',
        'b', 'e', 'l', 'o', 'n', 'g', 'i', 'n', 'g', 's', '\n',
        'b', 'e', 'l', 'o', 'n', 'g', 's', '\n',
        'b', 'e', 'l', 'o', 'v', 'e', 'd', '\n',
        'b', 'e', 'l', 'o', 'w', '\n',
        'b', 'e', 'l', 't', '\n',
        'b', 'e', 'l', 't', 'e', 'd', '\n',
        'b', 'e', 'l', 't', 'i', 'n', 'g', '\n',
        'b', 'e', 'l', 't', 'i', 'n', 'g', 's', '\n',
        'b', 'e', 'l', 't', 's', '\n',
        'b', 'e', 'l', 'y', 'i', 'n', 'g', '\n',
        'b', 'e', 'm', 'o', 'a', 'n', '\n',
        'b', 'e', 'm', 'o', 'a', 'n', 'e', 'd', '\n',
        'b', 'e', 'm', 'o', 'a', 'n', 'i', 'n', 'g', '\n',
        'b', 'e', 'm', 'o', 'a', 'n', 's', '\n',
        'b', 'e', 'm', 'u', 's', 'e', '\n',
        'b', 'e', 'm', 'u', 's', 'e', 'd', '\n',
        'b', 'e', 'm', 'u', 's', 'e', 'd', 'l', 'y', '\n',
        'b', 'e', 'm', 'u', 's', 'e', 'm', 'e', 'n', 't', '\n',
        'b', 'e', 'n', '\n',
        'b', 'e', 'n', 'c', 'h', '\n',
        'b', 'e', 'n', 'c', 'h', 'e', 's', '\n',
        'b', 'e', 'n', 'c', 'h', 'm', 'a', 'r', 'k', '\n',
        'b', 'e', 'n', 'c', 'h', 'm', 'a', 'r', 'k', 'i', 'n', 'g', '\n',
        'b', 'e', 'n', 'c', 'h', 'm', 'a', 'r', 'k', 's', '\n',
        'b', 'e', 'n', 'd', '\n',
        'b', 'e', 'n', 'd', 'a', 'b', 'l', 'e', '\n',
        'b', 'e', 'n', 'd', 'e', 'd', '\n',
        'b', 'e', 'n', 'd', 'e', 'r', '\n',
        'b', 'e', 'n', 'd', 'e', 'r', 's', '\n',
        'b', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'b', 'e', 'n', 'd', 'i', 'n', 'g', 's', '\n',
        'b', 'e', 'n', 'd', 's', '\n',
        'b', 'e', 'n', 'e', 'a', 't', 'h', '\n',
        'b', 'e', 'n', 'e', 'd', 'i', 'c', 't', 'i', 'o', 'n', '\n',
        'b', 'e', 'n', 'e', 'd', 'i', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'b', 'e', 'n', 'e', 'f', 'a', 'c', 't', 'i', 'o', 'n', '\n',
        'b', 'e', 'n', 'e', 'f', 'a', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'b', 'e', 'n', 'e', 'f', 'a', 'c', 't', 'o', 'r', '\n',
        'b', 'e', 'n', 'e', 'f', 'a', 'c', 't', 'o', 'r', 's', '\n',
        'b', 'e', 'n', 'e', 'f', 'a', 'c', 't', 'r', 'e', 's', 's', '\n',
        'b', 'e', 'n', 'e', 'f', 'i', 'c', 'e', '\n',
        'b', 'e', 'n', 'e', 'f', 'i', 'c', 'e', 'n', 'c', 'e', '\n',
        'b', 'e', 'n', 'e', 'f', 'i', 'c', 'e', 'n', 't', '\n',
        'b', 'e', 'n', 'e', 'f', 'i', 'c', 'i', 'a', 'l', '\n',
        'b', 'e', 'n', 'e', 'f', 'i', 'c', 'i', 'a', 'l', 'l', 'y', '\n',
        'b', 'e', 'n', 'e', 'f', 'i', 'c', 'i', 'a', 'r', 'i', 'e', 's', '\n',
        'b', 'e', 'n', 'e', 'f', 'i', 'c', 'i', 'a', 'r', 'y', '\n',
        'b', 'e', 'n', 'e', 'f', 'i', 't', '\n',
        'b', 'e', 'n', 'e', 'f', 'i', 't', 'e', 'd', '\n',
        'b', 'e', 'n', 'e', 'f', 'i', 't', 'i', 'n', 'g', '\n',
        'b', 'e', 'n', 'e', 'f', 'i', 't', 's', '\n',
        'b', 'e', 'n', 'e', 'l', 'u', 'x', '\n',
        'b', 'e', 'n', 'e', 'v', 'o', 'l', 'e', 'n', 'c', 'e', '\n',
        'b', 'e', 'n', 'e', 'v', 'o', 'l', 'e', 'n', 't', '\n',
        'b', 'e', 'n', 'e', 'v', 'o', 'l', 'e', 'n', 't', 'l', 'y', '\n',
        'b', 'e', 'n', 'g', 'a', 'l', '\n',
        'b', 'e', 'n', 'i', 'g', 'h', 't', 'e', 'd', '\n',
        'b', 'e', 'n', 'i', 'g', 'h', 't', 'e', 'd', 'l', 'y', '\n',
        'b', 'e', 'n', 'i', 'g', 'n', '\n',
        'b', 'e', 'n', 'i', 'g', 'n', 'i', 't', 'y', '\n',
        'b', 'e', 'n', 'i', 'g', 'n', 'l', 'y', '\n',
        'b', 'e', 'n', 'j', 'a', 'm', 'i', 'n', '\n',
        'b', 'e', 'n', 't', '\n',
        'b', 'e', 'n', 'z', 'e', 'n', 'e', '\n',
        'b', 'e', 'q', 'u', 'e', 'a', 't', 'h', '\n',
        'b', 'e', 'q', 'u', 'e', 'a', 't', 'h', 'e', 'd', '\n',
        'b', 'e', 'q', 'u', 'e', 'a', 't', 'h', 'i', 'n', 'g', '\n',
        'b', 'e', 'q', 'u', 'e', 's', 't', '\n',
        'b', 'e', 'q', 'u', 'e', 's', 't', 's', '\n',
        'b', 'e', 'r', 'a', 't', 'e', '\n',
        'b', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'b', 'e', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'b', 'e', 'r', 'b', 'e', 'r', '\n',
        'b', 'e', 'r', 'e', 'a', 'v', 'e', '\n',
        'b', 'e', 'r', 'e', 'a', 'v', 'e', 'd', '\n',
        'b', 'e', 'r', 'e', 'a', 'v', 'e', 'm', 'e', 'n', 't', '\n',
        'b', 'e', 'r', 'e', 'a', 'v', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'b', 'e', 'r', 'e', 'a', 'v', 'i', 'n', 'g', '\n',
        'b', 'e', 'r', 'e', 'f', 't', '\n',
        'b', 'e', 'r', 'e', 't', '\n',
        'b', 'e', 'r', 'e', 't', 's', '\n',
        'b', 'e', 'r', 'g', 's', '\n',
        'b', 'e', 'r', 'k', '\n',
        'b', 'e', 'r', 'l', 'i', 'n', '\n',
        'b', 'e', 'r', 'l', 'i', 'n', 'e', 'r', '\n',
        'b', 'e', 'r', 'm', 'u', 'd', 'a', '\n',
        'b', 'e', 'r', 'n', '\n',
        'b', 'e', 'r', 'r', 'i', 'e', 's', '\n',
        'b', 'e', 'r', 'r', 'y', '\n',
        'b', 'e', 'r', 's', 'e', 'r', 'k', '\n',
        'b', 'e', 'r', 't', 'h', '\n',
        'b', 'e', 'r', 't', 'h', 'e', 'd', '\n',
        'b', 'e', 'r', 't', 'h', 's', '\n',
        'b', 'e', 'r', 'y', 'l', '\n',
        'b', 'e', 'r', 'y', 'l', 'l', 'i', 'u', 'm', '\n',
        'b', 'e', 's', 'e', 'e', 'c', 'h', '\n',
        'b', 'e', 's', 'e', 'e', 'c', 'h', 'e', 'd', '\n',
        'b', 'e', 's', 'e', 'e', 'c', 'h', 'e', 's', '\n',
        'b', 'e', 's', 'e', 'e', 'c', 'h', 'i', 'n', 'g', '\n',
        'b', 'e', 's', 'e', 'e', 'c', 'h', 'i', 'n', 'g', 'l', 'y', '\n',
        'b', 'e', 's', 'e', 't', '\n',
        'b', 'e', 's', 'e', 't', 's', '\n',
        'b', 'e', 's', 'e', 't', 't', 'i', 'n', 'g', '\n',
        'b', 'e', 's', 'i', 'd', 'e', '\n',
        'b', 'e', 's', 'i', 'd', 'e', 's', '\n',
        'b', 'e', 's', 'i', 'e', 'g', 'e', '\n',
        'b', 'e', 's', 'i', 'e', 'g', 'e', 'd', '\n',
        'b', 'e', 's', 'i', 'e', 'g', 'i', 'n', 'g', '\n',
        'b', 'e', 's', 'm', 'i', 'r', 'c', 'h', '\n',
        'b', 'e', 's', 'o', 't', '\n',
        'b', 'e', 's', 'o', 't', 't', 'e', 'd', '\n',
        'b', 'e', 's', 'p', 'a', 't', 't', 'e', 'r', 'e', 'd', '\n',
        'b', 'e', 's', 'p', 'e', 'a', 'k', '\n',
        'b', 'e', 's', 'p', 'e', 'a', 'k', 'i', 'n', 'g', '\n',
        'b', 'e', 's', 'p', 'e', 'a', 'k', 's', '\n',
        'b', 'e', 's', 'p', 'e', 'c', 't', 'a', 'c', 'l', 'e', 'd', '\n',
        'b', 'e', 's', 'p', 'o', 'k', 'e', '\n',
        'b', 'e', 's', 't', '\n',
        'b', 'e', 's', 't', 'i', 'a', 'l', '\n',
        'b', 'e', 's', 't', 'i', 'a', 'l', 'i', 't', 'y', '\n',
        'b', 'e', 's', 't', 'i', 'a', 'r', 'y', '\n',
        'b', 'e', 's', 't', 'i', 'r', '\n',
        'b', 'e', 's', 't', 'i', 'r', 'r', 'e', 'd', '\n',
        'b', 'e', 's', 't', 'i', 'r', 'r', 'i', 'n', 'g', '\n',
        'b', 'e', 's', 't', 'k', 'n', 'o', 'w', 'n', '\n',
        'b', 'e', 's', 't', 'o', 'w', '\n',
        'b', 'e', 's', 't', 'o', 'w', 'a', 'l', '\n',
        'b', 'e', 's', 't', 'o', 'w', 'a', 'l', 's', '\n',
        'b', 'e', 's', 't', 'o', 'w', 'e', 'd', '\n',
        'b', 'e', 's', 't', 'o', 'w', 'i', 'n', 'g', '\n',
        'b', 'e', 's', 't', 'o', 'w', 's', '\n',
        'b', 'e', 's', 't', 'r', 'i', 'd', 'e', '\n',
        'b', 'e', 's', 't', 'r', 'o', 'd', 'e', '\n',
        'b', 'e', 's', 't', 's', '\n',
        'b', 'e', 's', 't', 's', 'e', 'l', 'l', 'e', 'r', '\n',
        'b', 'e', 's', 't', 's', 'e', 'l', 'l', 'e', 'r', 's', '\n',
        'b', 'e', 's', 't', 's', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'b', 'e', 't', '\n',
        'b', 'e', 't', 'a', '\n',
        'b', 'e', 't', 'e', 'l', '\n',
        'b', 'e', 't', 'i', 'd', 'e', '\n',
        'b', 'e', 't', 'i', 'm', 'e', 's', '\n',
        'b', 'e', 't', 'o', 'k', 'e', 'n', '\n',
        'b', 'e', 't', 'o', 'k', 'e', 'n', 'e', 'd', '\n',
        'b', 'e', 't', 'o', 'k', 'e', 'n', 's', '\n',
        'b', 'e', 't', 'r', 'a', 'y', '\n',
        'b', 'e', 't', 'r', 'a', 'y', 'a', 'l', '\n',
        'b', 'e', 't', 'r', 'a', 'y', 'a', 'l', 's', '\n',
        'b', 'e', 't', 'r', 'a', 'y', 'e', 'd', '\n',
        'b', 'e', 't', 'r', 'a', 'y', 'e', 'r', '\n',
        'b', 'e', 't', 'r', 'a', 'y', 'e', 'r', 's', '\n',
        'b', 'e', 't', 'r', 'a', 'y', 'i', 'n', 'g', '\n',
        'b', 'e', 't', 'r', 'a', 'y', 's', '\n',
        'b', 'e', 't', 'r', 'o', 't', 'h', '\n',
        'b', 'e', 't', 'r', 'o', 't', 'h', 'a', 'l', '\n',
        'b', 'e', 't', 'r', 'o', 't', 'h', 'e', 'd', '\n',
        'b', 'e', 't', 'r', 'o', 't', 'h', 's', '\n',
        'b', 'e', 't', 's', '\n',
        'b', 'e', 't', 't', 'e', 'd', '\n',
        'b', 'e', 't', 't', 'e', 'r', '\n',
        'b', 'e', 't', 't', 'e', 'r', 'e', 'd', '\n',
        'b', 'e', 't', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'b', 'e', 't', 't', 'e', 'r', 'm', 'e', 'n', 't', '\n',
        'b', 'e', 't', 't', 'e', 'r', 's', '\n',
        'b', 'e', 't', 't', 'i', 'n', 'g', '\n',
        'b', 'e', 't', 'w', 'e', 'e', 'n', '\n',
        'b', 'e', 't', 'w', 'i', 'x', 't', '\n',
        'b', 'e', 'v', 'e', 'l', '\n',
        'b', 'e', 'v', 'e', 'l', 'l', 'e', 'd', '\n',
        'b', 'e', 'v', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'b', 'e', 'v', 'e', 'l', 's', '\n',
        'b', 'e', 'v', 'e', 'r', 'a', 'g', 'e', '\n',
        'b', 'e', 'v', 'e', 'r', 'a', 'g', 'e', 's', '\n',
        'b', 'e', 'v', 'v', 'y', '\n',
        'b', 'e', 'v', 'y', '\n',
        'b', 'e', 'w', 'a', 'i', 'l', '\n',
        'b', 'e', 'w', 'a', 'i', 'l', 'e', 'd', '\n',
        'b', 'e', 'w', 'a', 'i', 'l', 'i', 'n', 'g', '\n',
        'b', 'e', 'w', 'a', 'i', 'l', 's', '\n',
        'b', 'e', 'w', 'a', 'r', 'e', '\n',
        'b', 'e', 'w', 'h', 'i', 's', 'k', 'e', 'r', 'e', 'd', '\n',
        'b', 'e', 'w', 'i', 'l', 'd', 'e', 'r', '\n',
        'b', 'e', 'w', 'i', 'l', 'd', 'e', 'r', 'e', 'd', '\n',
        'b', 'e', 'w', 'i', 'l', 'd', 'e', 'r', 'i', 'n', 'g', '\n',
        'b', 'e', 'w', 'i', 'l', 'd', 'e', 'r', 'i', 'n', 'g', 'l', 'y', '\n',
        'b', 'e', 'w', 'i', 'l', 'd', 'e', 'r', 'm', 'e', 'n', 't', '\n',
        'b', 'e', 'w', 'i', 'l', 'd', 'e', 'r', 's', '\n',
        'b', 'e', 'w', 'i', 't', 'c', 'h', '\n',
        'b', 'e', 'w', 'i', 't', 'c', 'h', 'e', 'd', '\n',
        'b', 'e', 'w', 'i', 't', 'c', 'h', 'i', 'n', 'g', '\n',
        'b', 'e', 'y', 'o', 'n', 'd', '\n',
        'b', 'i', 'a', 'n', 'n', 'u', 'a', 'l', '\n',
        'b', 'i', 'a', 's', '\n',
        'b', 'i', 'a', 's', 'e', 'd', '\n',
        'b', 'i', 'a', 's', 'e', 's', '\n',
        'b', 'i', 'a', 's', 'i', 'n', 'g', '\n',
        'b', 'i', 'a', 's', 's', 'e', 'd', '\n',
        'b', 'i', 'a', 's', 's', 'e', 's', '\n',
        'b', 'i', 'a', 's', 's', 'i', 'n', 'g', '\n',
        'b', 'i', 'b', '\n',
        'b', 'i', 'b', 'l', 'e', '\n',
        'b', 'i', 'b', 'l', 'e', 's', '\n',
        'b', 'i', 'b', 'l', 'i', 'c', 'a', 'l', '\n',
        'b', 'i', 'b', 'l', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'b', 'i', 'b', 'l', 'i', 'c', 'i', 's', 't', 's', '\n',
        'b', 'i', 'b', 'l', 'i', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', '\n',
        'b', 'i', 'b', 'l', 'i', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', 'a', 'l', '\n',
        'b', 'i', 'b', 'l', 'i', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'e', 's', '\n',
        'b', 'i', 'b', 'l', 'i', 'o', 'g', 'r', 'a', 'p', 'h', 'y', '\n',
        'b', 'i', 'b', 'l', 'i', 'o', 'p', 'h', 'i', 'l', 'e', '\n',
        'b', 'i', 'b', 's', '\n',
        'b', 'i', 'c', 'a', 'm', 'e', 'r', 'a', 'l', '\n',
        'b', 'i', 'c', 'a', 'r', 'b', '\n',
        'b', 'i', 'c', 'a', 'r', 'b', 'o', 'n', 'a', 't', 'e', '\n',
        'b', 'i', 'c', 'e', 'n', 't', 'e', 'n', 'a', 'r', 'y', '\n',
        'b', 'i', 'c', 'e', 'n', 't', 'e', 'n', 'n', 'i', 'a', 'l', '\n',
        'b', 'i', 'c', 'e', 'p', 's', '\n',
        'b', 'i', 'c', 'k', 'e', 'r', '\n',
        'b', 'i', 'c', 'k', 'e', 'r', 'i', 'n', 'g', '\n',
        'b', 'i', 'c', 'k', 'e', 'r', 'i', 'n', 'g', 's', '\n',
        'b', 'i', 'c', 'y', 'c', 'l', 'e', '\n',
        'b', 'i', 'c', 'y', 'c', 'l', 'e', 'd', '\n',
        'b', 'i', 'c', 'y', 'c', 'l', 'e', 's', '\n',
        'b', 'i', 'c', 'y', 'c', 'l', 'i', 'n', 'g', '\n',
        'b', 'i', 'd', '\n',
        'b', 'i', 'd', 'd', 'e', 'n', '\n',
        'b', 'i', 'd', 'd', 'e', 'r', '\n',
        'b', 'i', 'd', 'd', 'e', 'r', 's', '\n',
        'b', 'i', 'd', 'd', 'i', 'n', 'g', '\n',
        'b', 'i', 'd', 'd', 'i', 'n', 'g', 's', '\n',
        'b', 'i', 'd', 'e', '\n',
        'b', 'i', 'd', 'e', 'd', '\n',
        'b', 'i', 'd', 'e', 's', '\n',
        'b', 'i', 'd', 'e', 't', '\n',
        'b', 'i', 'd', 'i', 'n', 'g', '\n',
        'b', 'i', 'd', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'b', 'i', 'd', 's', '\n',
        'b', 'i', 'e', 'n', 'n', 'i', 'a', 'l', '\n',
        'b', 'i', 'e', 'n', 'n', 'i', 'a', 'l', 's', '\n',
        'b', 'i', 'e', 'r', '\n',
        'b', 'i', 'f', 'o', 'c', 'a', 'l', '\n',
        'b', 'i', 'f', 'o', 'c', 'a', 'l', 's', '\n',
        'b', 'i', 'f', 'u', 'r', 'c', 'a', 't', 'e', 'd', '\n',
        'b', 'i', 'f', 'u', 'r', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'b', 'i', 'f', 'u', 'r', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'b', 'i', 'g', '\n',
        'b', 'i', 'g', 'a', 'm', 'i', 's', 't', '\n',
        'b', 'i', 'g', 'a', 'm', 'i', 's', 't', 's', '\n',
        'b', 'i', 'g', 'a', 'm', 'o', 'u', 's', '\n',
        'b', 'i', 'g', 'a', 'm', 'y', '\n',
        'b', 'i', 'g', 'a', 'p', 'p', 'l', 'e', '\n',
        'b', 'i', 'g', 'b', 'e', 'n', '\n',
        'b', 'i', 'g', 'g', 'e', 'r', '\n',
        'b', 'i', 'g', 'g', 'e', 's', 't', '\n',
        'b', 'i', 'g', 'g', 'i', 's', 'h', '\n',
        'b', 'i', 'g', 'h', 'e', 'a', 'd', 's', '\n',
        'b', 'i', 'g', 'n', 'e', 's', 's', '\n',
        'b', 'i', 'g', 'o', 't', '\n',
        'b', 'i', 'g', 'o', 't', 'e', 'd', '\n',
        'b', 'i', 'g', 'o', 't', 'r', 'y', '\n',
        'b', 'i', 'g', 'o', 't', 's', '\n',
        'b', 'i', 'j', 'o', 'u', '\n',
        'b', 'i', 'j', 'o', 'u', 'x', '\n',
        'b', 'i', 'k', 'e', '\n',
        'b', 'i', 'k', 'e', 'r', '\n',
        'b', 'i', 'k', 'e', 's', '\n',
        'b', 'i', 'k', 'i', 'n', 'g', '\n',
        'b', 'i', 'k', 'i', 'n', 'i', '\n',
        'b', 'i', 'k', 'i', 'n', 'i', 's', '\n',
        'b', 'i', 'l', 'a', 'b', 'i', 'a', 'l', '\n',
        'b', 'i', 'l', 'a', 't', 'e', 'r', 'a', 'l', '\n',
        'b', 'i', 'l', 'a', 't', 'e', 'r', 'a', 'l', 'l', 'y', '\n',
        'b', 'i', 'l', 'e', '\n',
        'b', 'i', 'l', 'e', 's', '\n',
        'b', 'i', 'l', 'g', 'e', '\n',
        'b', 'i', 'l', 'g', 'e', 's', '\n',
        'b', 'i', 'l', 'h', 'a', 'r', 'z', 'i', 'a', '\n',
        'b', 'i', 'l', 'i', 'a', 'r', 'y', '\n',
        'b', 'i', 'l', 'i', 'n', 'g', 'u', 'a', 'l', '\n',
        'b', 'i', 'l', 'i', 'n', 'g', 'u', 'a', 'l', 'i', 's', 'm', '\n',
        'b', 'i', 'l', 'i', 'n', 'g', 'u', 'a', 'l', 's', '\n',
        'b', 'i', 'l', 'i', 'o', 'u', 's', '\n',
        'b', 'i', 'l', 'l', '\n',
        'b', 'i', 'l', 'l', 'a', 'b', 'l', 'e', '\n',
        'b', 'i', 'l', 'l', 'b', 'o', 'a', 'r', 'd', '\n',
        'b', 'i', 'l', 'l', 'b', 'o', 'a', 'r', 'd', 's', '\n',
        'b', 'i', 'l', 'l', 'e', 'd', '\n',
        'b', 'i', 'l', 'l', 'e', 't', '\n',
        'b', 'i', 'l', 'l', 'e', 't', 'e', 'd', '\n',
        'b', 'i', 'l', 'l', 'e', 't', 'i', 'n', 'g', '\n',
        'b', 'i', 'l', 'l', 'e', 't', 's', '\n',
        'b', 'i', 'l', 'l', 'i', 'a', 'r', 'd', '\n',
        'b', 'i', 'l', 'l', 'i', 'a', 'r', 'd', 's', '\n',
        'b', 'i', 'l', 'l', 'i', 'n', 'g', '\n',
        'b', 'i', 'l', 'l', 'i', 'n', 'g', 's', '\n',
        'b', 'i', 'l', 'l', 'i', 'o', 'n', '\n',
        'b', 'i', 'l', 'l', 'i', 'o', 'n', 'a', 'i', 'r', 'e', '\n',
        'b', 'i', 'l', 'l', 'i', 'o', 'n', 'a', 'i', 'r', 'e', 's', '\n',
        'b', 'i', 'l', 'l', 'i', 'o', 'n', 's', '\n',
        'b', 'i', 'l', 'l', 'i', 'o', 'n', 't', 'h', '\n',
        'b', 'i', 'l', 'l', 'o', 'w', '\n',
        'b', 'i', 'l', 'l', 'o', 'w', 'e', 'd', '\n',
        'b', 'i', 'l', 'l', 'o', 'w', 'i', 'n', 'g', '\n',
        'b', 'i', 'l', 'l', 'o', 'w', 's', '\n',
        'b', 'i', 'l', 'l', 'o', 'w', 'y', '\n',
        'b', 'i', 'l', 'l', 'p', 'o', 's', 't', 'e', 'r', 's', '\n',
        'b', 'i', 'l', 'l', 's', '\n',
        'b', 'i', 'l', 'l', 'y', '\n',
        'b', 'i', 'l', 't', 'o', 'n', 'g', '\n',
        'b', 'i', 'm', 'b', 'o', '\n',
        'b', 'i', 'm', 'o', 'd', 'a', 'l', '\n',
        'b', 'i', 'm', 'o', 'n', 't', 'h', 'l', 'y', '\n',
        'b', 'i', 'n', '\n',
        'b', 'i', 'n', 'a', 'r', 'i', 'e', 's', '\n',
        'b', 'i', 'n', 'a', 'r', 'y', '\n',
        'b', 'i', 'n', 'd', '\n',
        'b', 'i', 'n', 'd', 'e', 'r', '\n',
        'b', 'i', 'n', 'd', 'e', 'r', 's', '\n',
        'b', 'i', 'n', 'd', 'e', 'r', 'y', '\n',
        'b', 'i', 'n', 'd', 'i', 'n', 'g', '\n',
        'b', 'i', 'n', 'd', 'i', 'n', 'g', 's', '\n',
        'b', 'i', 'n', 'd', 's', '\n',
        'b', 'i', 'n', 'd', 'w', 'e', 'e', 'd', '\n',
        'b', 'i', 'n', 'g', '\n',
        'b', 'i', 'n', 'g', 'e', '\n',
        'b', 'i', 'n', 'g', 'o', '\n',
        'b', 'i', 'n', 'n', 'a', 'c', 'l', 'e', '\n',
        'b', 'i', 'n', 'o', 'c', 'u', 'l', 'a', 'r', '\n',
        'b', 'i', 'n', 'o', 'c', 'u', 'l', 'a', 'r', 's', '\n',
        'b', 'i', 'n', 'o', 'd', 'a', 'l', '\n',
        'b', 'i', 'n', 'o', 'm', 'i', 'a', 'l', '\n',
        'b', 'i', 'n', 's', '\n',
        'b', 'i', 'o', 'c', 'h', 'e', 'm', 'i', 'c', 'a', 'l', '\n',
        'b', 'i', 'o', 'c', 'h', 'e', 'm', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'b', 'i', 'o', 'c', 'h', 'e', 'm', 'i', 's', 't', '\n',
        'b', 'i', 'o', 'c', 'h', 'e', 'm', 'i', 's', 't', 'r', 'y', '\n',
        'b', 'i', 'o', 'c', 'h', 'e', 'm', 'i', 's', 't', 's', '\n',
        'b', 'i', 'o', 'd', 'e', 'g', 'r', 'a', 'd', 'a', 'b', 'l', 'e', '\n',
        'b', 'i', 'o', 'd', 'i', 'v', 'e', 'r', 's', 'i', 't', 'y', '\n',
        'b', 'i', 'o', 'e', 'n', 'g', 'i', 'n', 'e', 'e', 'r', 'i', 'n', 'g', '\n',
        'b', 'i', 'o', 'f', 'e', 'e', 'd', 'b', 'a', 'c', 'k', '\n',
        'b', 'i', 'o', 'g', 'e', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', 'a', 'l', '\n',
        'b', 'i', 'o', 'g', 'r', 'a', 'p', 'h', 'e', 'r', '\n',
        'b', 'i', 'o', 'g', 'r', 'a', 'p', 'h', 'e', 'r', 's', '\n',
        'b', 'i', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', 'a', 'l', '\n',
        'b', 'i', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'b', 'i', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'e', 's', '\n',
        'b', 'i', 'o', 'g', 'r', 'a', 'p', 'h', 'y', '\n',
        'b', 'i', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'b', 'i', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'b', 'i', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'b', 'i', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'b', 'i', 'o', 'l', 'o', 'g', 'y', '\n',
        'b', 'i', 'o', 'm', 'a', 's', 's', '\n',
        'b', 'i', 'o', 'm', 'e', 'd', 'i', 'c', 'a', 'l', '\n',
        'b', 'i', 'o', 'm', 'e', 't', 'r', 'i', 'c', '\n',
        'b', 'i', 'o', 'm', 'e', 't', 'r', 'i', 'c', 's', '\n',
        'b', 'i', 'o', 'm', 'e', 't', 'r', 'y', '\n',
        'b', 'i', 'o', 'm', 'o', 'r', 'p', 'h', '\n',
        'b', 'i', 'o', 'n', 'i', 'c', '\n',
        'b', 'i', 'o', 'n', 'i', 'c', 's', '\n',
        'b', 'i', 'o', 'p', 'h', 'y', 's', 'i', 'c', 'a', 'l', '\n',
        'b', 'i', 'o', 'p', 's', 'i', 'e', 's', '\n',
        'b', 'i', 'o', 'p', 's', 'y', '\n',
        'b', 'i', 'o', 'r', 'h', 'y', 't', 'h', 'm', '\n',
        'b', 'i', 'o', 'r', 'h', 'y', 't', 'h', 'm', 's', '\n',
        'b', 'i', 'o', 's', 'c', 'o', 'p', 'e', '\n',
        'b', 'i', 'o', 's', 'p', 'h', 'e', 'r', 'e', '\n',
        'b', 'i', 'o', 's', 'p', 'h', 'e', 'r', 'e', 's', '\n',
        'b', 'i', 'o', 's', 'y', 'n', 't', 'h', 'e', 's', 'i', 's', '\n',
        'b', 'i', 'o', 't', 'a', '\n',
        'b', 'i', 'o', 't', 'e', 'c', 'h', 'n', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'b', 'i', 'o', 't', 'e', 'c', 'h', 'n', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'b', 'i', 'o', 't', 'e', 'c', 'h', 'n', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'b', 'i', 'o', 't', 'e', 'c', 'h', 'n', 'o', 'l', 'o', 'g', 'y', '\n',
        'b', 'i', 'o', 't', 'i', 'c', '\n',
        'b', 'i', 'p', 'a', 'r', 't', 'i', 's', 'a', 'n', '\n',
        'b', 'i', 'p', 'a', 'r', 't', 'i', 't', 'e', '\n',
        'b', 'i', 'p', 'e', 'd', '\n',
        'b', 'i', 'p', 'e', 'd', 'a', 'l', '\n',
        'b', 'i', 'p', 'e', 'd', 'a', 'l', 'i', 's', 'm', '\n',
        'b', 'i', 'p', 'e', 'd', 's', '\n',
        'b', 'i', 'p', 'l', 'a', 'n', 'e', '\n',
        'b', 'i', 'p', 'l', 'a', 'n', 'e', 's', '\n',
        'b', 'i', 'p', 'o', 'l', 'a', 'r', '\n',
        'b', 'i', 'r', 'c', 'h', '\n',
        'b', 'i', 'r', 'c', 'h', 'e', 'd', '\n',
        'b', 'i', 'r', 'c', 'h', 'e', 's', '\n',
        'b', 'i', 'r', 'd', '\n',
        'b', 'i', 'r', 'd', 'b', 'a', 't', 'h', '\n',
        'b', 'i', 'r', 'd', 'b', 'a', 't', 'h', 's', '\n',
        'b', 'i', 'r', 'd', 'c', 'a', 'g', 'e', '\n',
        'b', 'i', 'r', 'd', 'c', 'a', 'g', 'e', 's', '\n',
        'b', 'i', 'r', 'd', 'i', 'e', '\n',
        'b', 'i', 'r', 'd', 'i', 'e', 's', '\n',
        'b', 'i', 'r', 'd', 's', '\n',
        'b', 'i', 'r', 'd', 's', 'o', 'n', 'g', '\n',
        'b', 'i', 'r', 'd', 't', 'a', 'b', 'l', 'e', 's', '\n',
        'b', 'i', 'r', 'd', 'w', 'a', 't', 'c', 'h', 'e', 'r', '\n',
        'b', 'i', 'r', 'd', 'w', 'a', 't', 'c', 'h', 'e', 'r', 's', '\n',
        'b', 'i', 'r', 'd', 'w', 'a', 't', 'c', 'h', 'i', 'n', 'g', '\n',
        'b', 'i', 'r', 'e', 'f', 'r', 'i', 'n', 'g', 'e', 'n', 'c', 'e', '\n',
        'b', 'i', 'r', 'e', 'f', 'r', 'i', 'n', 'g', 'e', 'n', 't', '\n',
        'b', 'i', 'r', 't', 'h', '\n',
        'b', 'i', 'r', 't', 'h', 'd', 'a', 'y', '\n',
        'b', 'i', 'r', 't', 'h', 'd', 'a', 'y', 's', '\n',
        'b', 'i', 'r', 't', 'h', 'm', 'a', 'r', 'k', '\n',
        'b', 'i', 'r', 't', 'h', 'm', 'a', 'r', 'k', 's', '\n',
        'b', 'i', 'r', 't', 'h', 'p', 'l', 'a', 'c', 'e', '\n',
        'b', 'i', 'r', 't', 'h', 'r', 'a', 't', 'e', '\n',
        'b', 'i', 'r', 't', 'h', 'r', 'i', 'g', 'h', 't', '\n',
        'b', 'i', 'r', 't', 'h', 'r', 'i', 'g', 'h', 't', 's', '\n',
        'b', 'i', 'r', 't', 'h', 's', '\n',
        'b', 'i', 's', 'c', 'u', 'i', 't', '\n',
        'b', 'i', 's', 'c', 'u', 'i', 't', 's', '\n',
        'b', 'i', 's', 'c', 'u', 'i', 't', 'y', '\n',
        'b', 'i', 's', 'e', 'c', 't', '\n',
        'b', 'i', 's', 'e', 'c', 't', 'e', 'd', '\n',
        'b', 'i', 's', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'b', 'i', 's', 'e', 'c', 't', 's', '\n',
        'b', 'i', 's', 'e', 'x', 'u', 'a', 'l', '\n',
        'b', 'i', 's', 'e', 'x', 'u', 'a', 'l', 'i', 't', 'y', '\n',
        'b', 'i', 's', 'e', 'x', 'u', 'a', 'l', 's', '\n',
        'b', 'i', 's', 'h', 'o', 'p', '\n',
        'b', 'i', 's', 'h', 'o', 'p', 'r', 'i', 'c', '\n',
        'b', 'i', 's', 'h', 'o', 'p', 'r', 'i', 'c', 's', '\n',
        'b', 'i', 's', 'h', 'o', 'p', 's', '\n',
        'b', 'i', 's', 'm', 'a', 'r', 'c', 'k', '\n',
        'b', 'i', 's', 'm', 'u', 't', 'h', '\n',
        'b', 'i', 's', 'o', 'n', '\n',
        'b', 'i', 's', 'o', 'n', 's', '\n',
        'b', 'i', 's', 's', 'a', 'u', '\n',
        'b', 'i', 's', 't', 'a', 'b', 'l', 'e', '\n',
        'b', 'i', 's', 't', 'r', 'o', '\n',
        'b', 'i', 't', '\n',
        'b', 'i', 't', 'c', 'h', '\n',
        'b', 'i', 't', 'c', 'h', 'e', 's', '\n',
        'b', 'i', 't', 'c', 'h', 'i', 'n', 'e', 's', 's', '\n',
        'b', 'i', 't', 'c', 'h', 'i', 'n', 'g', '\n',
        'b', 'i', 't', 'c', 'h', 'y', '\n',
        'b', 'i', 't', 'e', '\n',
        'b', 'i', 't', 'e', 'r', '\n',
        'b', 'i', 't', 'e', 'r', 's', '\n',
        'b', 'i', 't', 'e', 's', '\n',
        'b', 'i', 't', 'i', 'n', 'g', '\n',
        'b', 'i', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'b', 'i', 't', 'm', 'a', 'p', '\n',
        'b', 'i', 't', 's', '\n',
        'b', 'i', 't', 't', 'e', 'n', '\n',
        'b', 'i', 't', 't', 'e', 'r', '\n',
        'b', 'i', 't', 't', 'e', 'r', 'e', 's', 't', '\n',
        'b', 'i', 't', 't', 'e', 'r', 'l', 'y', '\n',
        'b', 'i', 't', 't', 'e', 'r', 'n', '\n',
        'b', 'i', 't', 't', 'e', 'r', 'n', 'e', 's', 's', '\n',
        'b', 'i', 't', 't', 'e', 'r', 's', '\n',
        'b', 'i', 't', 't', 'e', 'r', 's', 'w', 'e', 'e', 't', '\n',
        'b', 'i', 't', 't', 'i', 'n', 'e', 's', 's', '\n',
        'b', 'i', 't', 't', 's', '\n',
        'b', 'i', 't', 't', 'y', '\n',
        'b', 'i', 't', 'u', 'm', 'e', 'n', '\n',
        'b', 'i', 't', 'u', 'm', 'i', 'n', 'o', 'u', 's', '\n',
        'b', 'i', 'v', 'a', 'l', 'v', 'e', '\n',
        'b', 'i', 'v', 'a', 'l', 'v', 'e', 's', '\n',
        'b', 'i', 'v', 'o', 'u', 'a', 'c', '\n',
        'b', 'i', 'v', 'o', 'u', 'a', 'c', 'k', 'e', 'd', '\n',
        'b', 'i', 'v', 'o', 'u', 'a', 'c', 's', '\n',
        'b', 'i', 'w', 'e', 'e', 'k', 'l', 'y', '\n',
        'b', 'i', 'z', '\n',
        'b', 'i', 'z', 'a', 'r', 'r', 'e', '\n',
        'b', 'i', 'z', 'a', 'r', 'r', 'e', 'l', 'y', '\n',
        'b', 'i', 'z', 'a', 'r', 'r', 'e', 'n', 'e', 's', 's', '\n',
        'b', 'l', 'a', 'b', '\n',
        'b', 'l', 'a', 'b', 'b', 'e', 'd', '\n',
        'b', 'l', 'a', 'b', 'b', 'e', 'r', '\n',
        'b', 'l', 'a', 'b', 'b', 'e', 'r', 'i', 'n', 'g', '\n',
        'b', 'l', 'a', 'b', 's', '\n',
        'b', 'l', 'a', 'c', 'k', '\n',
        'b', 'l', 'a', 'c', 'k', 'b', 'a', 'l', 'l', '\n',
        'b', 'l', 'a', 'c', 'k', 'b', 'a', 'l', 'l', 'e', 'd', '\n',
        'b', 'l', 'a', 'c', 'k', 'b', 'a', 'l', 'l', 'i', 'n', 'g', '\n',
        'b', 'l', 'a', 'c', 'k', 'b', 'e', 'r', 'r', 'i', 'e', 's', '\n',
        'b', 'l', 'a', 'c', 'k', 'b', 'e', 'r', 'r', 'y', '\n',
        'b', 'l', 'a', 'c', 'k', 'b', 'i', 'r', 'd', '\n',
        'b', 'l', 'a', 'c', 'k', 'b', 'i', 'r', 'd', 's', '\n',
        'b', 'l', 'a', 'c', 'k', 'b', 'o', 'a', 'r', 'd', '\n',
        'b', 'l', 'a', 'c', 'k', 'b', 'o', 'a', 'r', 'd', 's', '\n',
        'b', 'l', 'a', 'c', 'k', 'c', 'u', 'r', 'r', 'a', 'n', 't', '\n',
        'b', 'l', 'a', 'c', 'k', 'c', 'u', 'r', 'r', 'a', 'n', 't', 's', '\n',
        'b', 'l', 'a', 'c', 'k', 'e', 'd', '\n',
        'b', 'l', 'a', 'c', 'k', 'e', 'n', '\n',
        'b', 'l', 'a', 'c', 'k', 'e', 'n', 'e', 'd', '\n',
        'b', 'l', 'a', 'c', 'k', 'e', 'n', 'i', 'n', 'g', '\n',
        'b', 'l', 'a', 'c', 'k', 'e', 'n', 's', '\n',
        'b', 'l', 'a', 'c', 'k', 'e', 'r', '\n',
        'b', 'l', 'a', 'c', 'k', 'e', 's', 't', '\n',
        'b', 'l', 'a', 'c', 'k', 'f', 'l', 'y', '\n',
        'b', 'l', 'a', 'c', 'k', 'g', 'u', 'a', 'r', 'd', '\n',
        'b', 'l', 'a', 'c', 'k', 'h', 'e', 'a', 'd', '\n',
        'b', 'l', 'a', 'c', 'k', 'h', 'e', 'a', 'd', 's', '\n',
        'b', 'l', 'a', 'c', 'k', 'i', 'n', 'g', '\n',
        'b', 'l', 'a', 'c', 'k', 'i', 's', 'h', '\n',
        'b', 'l', 'a', 'c', 'k', 'j', 'a', 'c', 'k', '\n',
        'b', 'l', 'a', 'c', 'k', 'l', 'e', 'g', '\n',
        'b', 'l', 'a', 'c', 'k', 'l', 'i', 's', 't', '\n',
        'b', 'l', 'a', 'c', 'k', 'l', 'i', 's', 't', 'e', 'd', '\n',
        'b', 'l', 'a', 'c', 'k', 'l', 'i', 's', 't', 'i', 'n', 'g', '\n',
        'b', 'l', 'a', 'c', 'k', 'l', 'i', 's', 't', 's', '\n',
        'b', 'l', 'a', 'c', 'k', 'l', 'y', '\n',
        'b', 'l', 'a', 'c', 'k', 'm', 'a', 'i', 'l', '\n',
        'b', 'l', 'a', 'c', 'k', 'm', 'a', 'i', 'l', 'e', 'd', '\n',
        'b', 'l', 'a', 'c', 'k', 'm', 'a', 'i', 'l', 'e', 'r', '\n',
        'b', 'l', 'a', 'c', 'k', 'm', 'a', 'i', 'l', 'e', 'r', 's', '\n',
        'b', 'l', 'a', 'c', 'k', 'm', 'a', 'i', 'l', 'i', 'n', 'g', '\n',
        'b', 'l', 'a', 'c', 'k', 'm', 'a', 'i', 'l', 's', '\n',
        'b', 'l', 'a', 'c', 'k', 'n', 'e', 's', 's', '\n',
        'b', 'l', 'a', 'c', 'k', 'o', 'u', 't', '\n',
        'b', 'l', 'a', 'c', 'k', 'o', 'u', 't', 's', '\n',
        'b', 'l', 'a', 'c', 'k', 's', '\n',
        'b', 'l', 'a', 'c', 'k', 's', 'e', 'a', '\n',
        'b', 'l', 'a', 'c', 'k', 's', 'h', 'i', 'r', 't', 's', '\n',
        'b', 'l', 'a', 'c', 'k', 's', 'm', 'i', 't', 'h', '\n',
        'b', 'l', 'a', 'c', 'k', 's', 'm', 'i', 't', 'h', 's', '\n',
        'b', 'l', 'a', 'c', 'k', 't', 'h', 'o', 'r', 'n', '\n',
        'b', 'l', 'a', 'd', 'd', 'e', 'r', '\n',
        'b', 'l', 'a', 'd', 'd', 'e', 'r', 's', '\n',
        'b', 'l', 'a', 'd', 'e', '\n',
        'b', 'l', 'a', 'd', 'e', 'd', '\n',
        'b', 'l', 'a', 'd', 'e', 's', '\n',
        'b', 'l', 'a', 'h', '\n',
        'b', 'l', 'a', 'm', 'e', '\n',
        'b', 'l', 'a', 'm', 'e', 'a', 'b', 'l', 'e', '\n',
        'b', 'l', 'a', 'm', 'e', 'd', '\n',
        'b', 'l', 'a', 'm', 'e', 'f', 'u', 'l', '\n',
        'b', 'l', 'a', 'm', 'e', 'l', 'e', 's', 's', '\n',
        'b', 'l', 'a', 'm', 'e', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'b', 'l', 'a', 'm', 'e', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'b', 'l', 'a', 'm', 'e', 's', '\n',
        'b', 'l', 'a', 'm', 'e', 'w', 'o', 'r', 't', 'h', 'y', '\n',
        'b', 'l', 'a', 'm', 'i', 'n', 'g', '\n',
        'b', 'l', 'a', 'n', 'c', 'h', '\n',
        'b', 'l', 'a', 'n', 'c', 'h', 'e', 'd', '\n',
        'b', 'l', 'a', 'n', 'c', 'h', 'i', 'n', 'g', '\n',
        'b', 'l', 'a', 'n', 'c', 'm', 'a', 'n', 'g', 'e', '\n',
        'b', 'l', 'a', 'n', 'd', '\n',
        'b', 'l', 'a', 'n', 'd', 'e', 's', 't', '\n',
        'b', 'l', 'a', 'n', 'd', 'i', 's', 'h', 'm', 'e', 'n', 't', 's', '\n',
        'b', 'l', 'a', 'n', 'd', 'l', 'y', '\n',
        'b', 'l', 'a', 'n', 'd', 'n', 'e', 's', 's', '\n',
        'b', 'l', 'a', 'n', 'k', '\n',
        'b', 'l', 'a', 'n', 'k', 'e', 'd', '\n',
        'b', 'l', 'a', 'n', 'k', 'e', 'r', '\n',
        'b', 'l', 'a', 'n', 'k', 'e', 't', '\n',
        'b', 'l', 'a', 'n', 'k', 'e', 't', 'e', 'd', '\n',
        'b', 'l', 'a', 'n', 'k', 'e', 't', 'i', 'n', 'g', '\n',
        'b', 'l', 'a', 'n', 'k', 'e', 't', 's', '\n',
        'b', 'l', 'a', 'n', 'k', 'i', 'n', 'g', '\n',
        'b', 'l', 'a', 'n', 'k', 'l', 'y', '\n',
        'b', 'l', 'a', 'n', 'k', 'n', 'e', 's', 's', '\n',
        'b', 'l', 'a', 'n', 'k', 's', '\n',
        'b', 'l', 'a', 'r', 'e', '\n',
        'b', 'l', 'a', 'r', 'e', 'd', '\n',
        'b', 'l', 'a', 'r', 'e', 's', '\n',
        'b', 'l', 'a', 'r', 'i', 'n', 'g', '\n',
        'b', 'l', 'a', 's', 'e', '\n',
        'b', 'l', 'a', 's', 'p', 'h', 'e', 'm', 'e', '\n',
        'b', 'l', 'a', 's', 'p', 'h', 'e', 'm', 'e', 'd', '\n',
        'b', 'l', 'a', 's', 'p', 'h', 'e', 'm', 'e', 'r', '\n',
        'b', 'l', 'a', 's', 'p', 'h', 'e', 'm', 'e', 'r', 's', '\n',
        'b', 'l', 'a', 's', 'p', 'h', 'e', 'm', 'i', 'e', 's', '\n',
        'b', 'l', 'a', 's', 'p', 'h', 'e', 'm', 'i', 'n', 'g', '\n',
        'b', 'l', 'a', 's', 'p', 'h', 'e', 'm', 'o', 'u', 's', '\n',
        'b', 'l', 'a', 's', 'p', 'h', 'e', 'm', 'o', 'u', 's', 'l', 'y', '\n',
        'b', 'l', 'a', 's', 'p', 'h', 'e', 'm', 'y', '\n',
        'b', 'l', 'a', 's', 't', '\n',
        'b', 'l', 'a', 's', 't', 'e', 'd', '\n',
        'b', 'l', 'a', 's', 't', 'e', 'r', '\n',
        'b', 'l', 'a', 's', 't', 'e', 'r', 's', '\n',
        'b', 'l', 'a', 's', 't', 'i', 'n', 'g', '\n',
        'b', 'l', 'a', 's', 't', 's', '\n',
        'b', 'l', 'a', 't', '\n',
        'b', 'l', 'a', 't', 'a', 'n', 'c', 'y', '\n',
        'b', 'l', 'a', 't', 'a', 'n', 't', '\n',
        'b', 'l', 'a', 't', 'a', 'n', 't', 'l', 'y', '\n',
        'b', 'l', 'a', 'z', 'e', '\n',
        'b', 'l', 'a', 'z', 'e', 'd', '\n',
        'b', 'l', 'a', 'z', 'e', 'r', '\n',
        'b', 'l', 'a', 'z', 'e', 'r', 's', '\n',
        'b', 'l', 'a', 'z', 'e', 's', '\n',
        'b', 'l', 'a', 'z', 'i', 'n', 'g', '\n',
        'b', 'l', 'e', 'a', 'c', 'h', '\n',
        'b', 'l', 'e', 'a', 'c', 'h', 'e', 'd', '\n',
        'b', 'l', 'e', 'a', 'c', 'h', 'e', 'r', '\n',
        'b', 'l', 'e', 'a', 'c', 'h', 'e', 'r', 's', '\n',
        'b', 'l', 'e', 'a', 'c', 'h', 'e', 's', '\n',
        'b', 'l', 'e', 'a', 'c', 'h', 'i', 'n', 'g', '\n',
        'b', 'l', 'e', 'a', 'k', '\n',
        'b', 'l', 'e', 'a', 'k', 'e', 'r', '\n',
        'b', 'l', 'e', 'a', 'k', 'e', 's', 't', '\n',
        'b', 'l', 'e', 'a', 'k', 'l', 'y', '\n',
        'b', 'l', 'e', 'a', 'k', 'n', 'e', 's', 's', '\n',
        'b', 'l', 'e', 'a', 'r', 'i', 'l', 'y', '\n',
        'b', 'l', 'e', 'a', 'r', 'y', '\n',
        'b', 'l', 'e', 'a', 'r', 'y', 'e', 'y', 'e', 'd', '\n',
        'b', 'l', 'e', 'a', 't', '\n',
        'b', 'l', 'e', 'a', 't', 'e', 'd', '\n',
        'b', 'l', 'e', 'a', 't', 'i', 'n', 'g', '\n',
        'b', 'l', 'e', 'a', 't', 's', '\n',
        'b', 'l', 'e', 'd', '\n',
        'b', 'l', 'e', 'e', 'd', '\n',
        'b', 'l', 'e', 'e', 'd', 'e', 'r', '\n',
        'b', 'l', 'e', 'e', 'd', 'e', 'r', 's', '\n',
        'b', 'l', 'e', 'e', 'd', 'i', 'n', 'g', '\n',
        'b', 'l', 'e', 'e', 'd', 's', '\n',
        'b', 'l', 'e', 'e', 'p', '\n',
        'b', 'l', 'e', 'e', 'p', 'e', 'd', '\n',
        'b', 'l', 'e', 'e', 'p', 'e', 'r', '\n',
        'b', 'l', 'e', 'e', 'p', 'i', 'n', 'g', '\n',
        'b', 'l', 'e', 'e', 'p', 's', '\n',
        'b', 'l', 'e', 'm', 'i', 's', 'h', '\n',
        'b', 'l', 'e', 'm', 'i', 's', 'h', 'e', 'd', '\n',
        'b', 'l', 'e', 'm', 'i', 's', 'h', 'e', 's', '\n',
        'b', 'l', 'e', 'n', 'c', 'h', '\n',
        'b', 'l', 'e', 'n', 'c', 'h', 'e', 'd', '\n',
        'b', 'l', 'e', 'n', 'd', '\n',
        'b', 'l', 'e', 'n', 'd', 'e', 'd', '\n',
        'b', 'l', 'e', 'n', 'd', 'e', 'r', '\n',
        'b', 'l', 'e', 'n', 'd', 'e', 'r', 's', '\n',
        'b', 'l', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'b', 'l', 'e', 'n', 'd', 's', '\n',
        'b', 'l', 'e', 's', 'b', 'o', 'k', '\n',
        'b', 'l', 'e', 's', 's', '\n',
        'b', 'l', 'e', 's', 's', 'e', 'd', '\n',
        'b', 'l', 'e', 's', 's', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'b', 'l', 'e', 's', 's', 'e', 's', '\n',
        'b', 'l', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'b', 'l', 'e', 's', 's', 'i', 'n', 'g', 's', '\n',
        'b', 'l', 'e', 'w', '\n',
        'b', 'l', 'i', 'g', 'h', 't', '\n',
        'b', 'l', 'i', 'g', 'h', 't', 'e', 'd', '\n',
        'b', 'l', 'i', 'g', 'h', 't', 'i', 'n', 'g', '\n',
        'b', 'l', 'i', 'g', 'h', 't', 's', '\n',
        'b', 'l', 'i', 'm', 'p', '\n',
        'b', 'l', 'i', 'm', 'p', 's', '\n',
        'b', 'l', 'i', 'n', 'd', '\n',
        'b', 'l', 'i', 'n', 'd', 'e', 'd', '\n',
        'b', 'l', 'i', 'n', 'd', 'e', 'r', '\n',
        'b', 'l', 'i', 'n', 'd', 'e', 's', 't', '\n',
        'b', 'l', 'i', 'n', 'd', 'f', 'o', 'l', 'd', '\n',
        'b', 'l', 'i', 'n', 'd', 'f', 'o', 'l', 'd', 'e', 'd', '\n',
        'b', 'l', 'i', 'n', 'd', 'f', 'o', 'l', 'd', 's', '\n',
        'b', 'l', 'i', 'n', 'd', 'i', 'n', 'g', '\n',
        'b', 'l', 'i', 'n', 'd', 'i', 'n', 'g', 'l', 'y', '\n',
        'b', 'l', 'i', 'n', 'd', 'l', 'y', '\n',
        'b', 'l', 'i', 'n', 'd', 'n', 'e', 's', 's', '\n',
        'b', 'l', 'i', 'n', 'd', 's', '\n',
        'b', 'l', 'i', 'n', 'k', '\n',
        'b', 'l', 'i', 'n', 'k', 'e', 'd', '\n',
        'b', 'l', 'i', 'n', 'k', 'e', 'r', '\n',
        'b', 'l', 'i', 'n', 'k', 'e', 'r', 'e', 'd', '\n',
        'b', 'l', 'i', 'n', 'k', 'e', 'r', 'i', 'n', 'g', '\n',
        'b', 'l', 'i', 'n', 'k', 'e', 'r', 's', '\n',
        'b', 'l', 'i', 'n', 'k', 'i', 'n', 'g', '\n',
        'b', 'l', 'i', 'n', 'k', 's', '\n',
        'b', 'l', 'i', 'p', '\n',
        'b', 'l', 'i', 'p', 's', '\n',
        'b', 'l', 'i', 's', 's', '\n',
        'b', 'l', 'i', 's', 's', 'f', 'u', 'l', '\n',
        'b', 'l', 'i', 's', 's', 'f', 'u', 'l', 'l', 'y', '\n',
        'b', 'l', 'i', 's', 't', 'e', 'r', '\n',
        'b', 'l', 'i', 's', 't', 'e', 'r', 'e', 'd', '\n',
        'b', 'l', 'i', 's', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'b', 'l', 'i', 's', 't', 'e', 'r', 'i', 'n', 'g', 'l', 'y', '\n',
        'b', 'l', 'i', 's', 't', 'e', 'r', 's', '\n',
        'b', 'l', 'i', 't', 'h', 'e', '\n',
        'b', 'l', 'i', 't', 'h', 'e', 'l', 'y', '\n',
        'b', 'l', 'i', 't', 'h', 'e', 'r', 'i', 'n', 'g', '\n',
        'b', 'l', 'i', 't', 'z', '\n',
        'b', 'l', 'i', 't', 'z', 'k', 'r', 'i', 'e', 'g', '\n',
        'b', 'l', 'i', 'z', 'z', 'a', 'r', 'd', '\n',
        'b', 'l', 'i', 'z', 'z', 'a', 'r', 'd', 's', '\n',
        'b', 'l', 'o', 'a', 't', '\n',
        'b', 'l', 'o', 'a', 't', 'e', 'd', '\n',
        'b', 'l', 'o', 'a', 't', 'i', 'n', 'g', '\n',
        'b', 'l', 'o', 'b', '\n',
        'b', 'l', 'o', 'b', 's', '\n',
        'b', 'l', 'o', 'c', '\n',
        'b', 'l', 'o', 'c', 'k', '\n',
        'b', 'l', 'o', 'c', 'k', 'a', 'd', 'e', '\n',
        'b', 'l', 'o', 'c', 'k', 'a', 'd', 'e', 'd', '\n',
        'b', 'l', 'o', 'c', 'k', 'a', 'd', 'e', 's', '\n',
        'b', 'l', 'o', 'c', 'k', 'a', 'd', 'i', 'n', 'g', '\n',
        'b', 'l', 'o', 'c', 'k', 'a', 'g', 'e', '\n',
        'b', 'l', 'o', 'c', 'k', 'a', 'g', 'e', 's', '\n',
        'b', 'l', 'o', 'c', 'k', 'b', 'u', 's', 't', 'e', 'r', '\n',
        'b', 'l', 'o', 'c', 'k', 'b', 'u', 's', 't', 'e', 'r', 's', '\n',
        'b', 'l', 'o', 'c', 'k', 'b', 'u', 's', 't', 'i', 'n', 'g', '\n',
        'b', 'l', 'o', 'c', 'k', 'e', 'd', '\n',
        'b', 'l', 'o', 'c', 'k', 'e', 'r', 's', '\n',
        'b', 'l', 'o', 'c', 'k', 'h', 'e', 'a', 'd', '\n',
        'b', 'l', 'o', 'c', 'k', 'h', 'e', 'a', 'd', 's', '\n',
        'b', 'l', 'o', 'c', 'k', 'i', 'n', 'g', '\n',
        'b', 'l', 'o', 'c', 'k', 'i', 's', 'h', '\n',
        'b', 'l', 'o', 'c', 'k', 's', '\n',
        'b', 'l', 'o', 'c', 'k', 'y', '\n',
        'b', 'l', 'o', 'c', 's', '\n',
        'b', 'l', 'o', 'k', 'e', '\n',
        'b', 'l', 'o', 'k', 'e', 's', '\n',
        'b', 'l', 'o', 'n', 'd', '\n',
        'b', 'l', 'o', 'n', 'd', 'e', '\n',
        'b', 'l', 'o', 'n', 'd', 'e', 'r', '\n',
        'b', 'l', 'o', 'n', 'd', 'e', 's', '\n',
        'b', 'l', 'o', 'n', 'd', 'e', 's', 't', '\n',
        'b', 'l', 'o', 'n', 'd', 'h', 'a', 'i', 'r', 'e', 'd', '\n',
        'b', 'l', 'o', 'n', 'd', 's', '\n',
        'b', 'l', 'o', 'o', 'd', '\n',
        'b', 'l', 'o', 'o', 'd', 'b', 'a', 't', 'h', '\n',
        'b', 'l', 'o', 'o', 'd', 'c', 'u', 'r', 'd', 'l', 'i', 'n', 'g', '\n',
        'b', 'l', 'o', 'o', 'd', 'e', 'd', '\n',
        'b', 'l', 'o', 'o', 'd', 'h', 'o', 'u', 'n', 'd', '\n',
        'b', 'l', 'o', 'o', 'd', 'h', 'o', 'u', 'n', 'd', 's', '\n',
        'b', 'l', 'o', 'o', 'd', 'i', 'e', 'd', '\n',
        'b', 'l', 'o', 'o', 'd', 'i', 'e', 'r', '\n',
        'b', 'l', 'o', 'o', 'd', 'i', 'e', 's', '\n',
        'b', 'l', 'o', 'o', 'd', 'i', 'e', 's', 't', '\n',
        'b', 'l', 'o', 'o', 'd', 'i', 'l', 'y', '\n',
        'b', 'l', 'o', 'o', 'd', 'l', 'e', 's', 's', '\n',
        'b', 'l', 'o', 'o', 'd', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'b', 'l', 'o', 'o', 'd', 'l', 'e', 't', 't', 'i', 'n', 'g', '\n',
        'b', 'l', 'o', 'o', 'd', 'l', 'i', 'n', 'e', '\n',
        'b', 'l', 'o', 'o', 'd', 'l', 'u', 's', 't', '\n',
        'b', 'l', 'o', 'o', 'd', 'r', 'e', 'd', '\n',
        'b', 'l', 'o', 'o', 'd', 's', '\n',
        'b', 'l', 'o', 'o', 'd', 's', 'h', 'e', 'd', '\n',
        'b', 'l', 'o', 'o', 'd', 's', 'h', 'o', 't', '\n',
        'b', 'l', 'o', 'o', 'd', 's', 'p', 'o', 'r', 't', '\n',
        'b', 'l', 'o', 'o', 'd', 's', 'p', 'o', 'r', 't', 's', '\n',
        'b', 'l', 'o', 'o', 'd', 's', 't', 'a', 'i', 'n', '\n',
        'b', 'l', 'o', 'o', 'd', 's', 't', 'a', 'i', 'n', 'e', 'd', '\n',
        'b', 'l', 'o', 'o', 'd', 's', 't', 'a', 'i', 'n', 's', '\n',
        'b', 'l', 'o', 'o', 'd', 's', 't', 'o', 'c', 'k', '\n',
        'b', 'l', 'o', 'o', 'd', 's', 't', 'o', 'n', 'e', '\n',
        'b', 'l', 'o', 'o', 'd', 's', 't', 'r', 'e', 'a', 'm', '\n',
        'b', 'l', 'o', 'o', 'd', 's', 'u', 'c', 'k', 'e', 'r', 's', '\n',
        'b', 'l', 'o', 'o', 'd', 't', 'h', 'i', 'r', 's', 't', 'i', 'e', 'r', '\n',
        'b', 'l', 'o', 'o', 'd', 't', 'h', 'i', 'r', 's', 't', 'i', 'e', 's', 't', '\n',
        'b', 'l', 'o', 'o', 'd', 't', 'h', 'i', 'r', 's', 't', 'y', '\n',
        'b', 'l', 'o', 'o', 'd', 'w', 'o', 'r', 'm', '\n',
        'b', 'l', 'o', 'o', 'd', 'y', '\n',
        'b', 'l', 'o', 'o', 'd', 'y', 'm', 'i', 'n', 'd', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'b', 'l', 'o', 'o', 'm', '\n',
        'b', 'l', 'o', 'o', 'm', 'e', 'd', '\n',
        'b', 'l', 'o', 'o', 'm', 'e', 'r', '\n',
        'b', 'l', 'o', 'o', 'm', 'e', 'r', 's', '\n',
        'b', 'l', 'o', 'o', 'm', 'i', 'n', 'g', '\n',
        'b', 'l', 'o', 'o', 'm', 's', '\n',
        'b', 'l', 'o', 'o', 'm', 'y', '\n',
        'b', 'l', 'o', 's', 's', 'o', 'm', '\n',
        'b', 'l', 'o', 's', 's', 'o', 'm', 'e', 'd', '\n',
        'b', 'l', 'o', 's', 's', 'o', 'm', 'i', 'n', 'g', '\n',
        'b', 'l', 'o', 's', 's', 'o', 'm', 's', '\n',
        'b', 'l', 'o', 't', '\n',
        'b', 'l', 'o', 't', 'c', 'h', '\n',
        'b', 'l', 'o', 't', 'c', 'h', 'e', 'd', '\n',
        'b', 'l', 'o', 't', 'c', 'h', 'e', 's', '\n',
        'b', 'l', 'o', 't', 'c', 'h', 'y', '\n',
        'b', 'l', 'o', 't', 's', '\n',
        'b', 'l', 'o', 't', 't', 'e', 'd', '\n',
        'b', 'l', 'o', 't', 't', 'e', 'r', '\n',
        'b', 'l', 'o', 't', 't', 'i', 'n', 'g', '\n',
        'b', 'l', 'o', 'u', 's', 'e', '\n',
        'b', 'l', 'o', 'u', 's', 'e', 's', '\n',
        'b', 'l', 'o', 'w', '\n',
        'b', 'l', 'o', 'w', 'd', 'r', 'i', 'e', 'd', '\n',
        'b', 'l', 'o', 'w', 'd', 'r', 'y', 'i', 'n', 'g', '\n',
        'b', 'l', 'o', 'w', 'e', 'd', '\n',
        'b', 'l', 'o', 'w', 'e', 'r', '\n',
        'b', 'l', 'o', 'w', 'e', 'r', 's', '\n',
        'b', 'l', 'o', 'w', 'f', 'l', 'y', '\n',
        'b', 'l', 'o', 'w', 'i', 'n', 'g', '\n',
        'b', 'l', 'o', 'w', 'l', 'a', 'm', 'p', '\n',
        'b', 'l', 'o', 'w', 'n', '\n',
        'b', 'l', 'o', 'w', 'p', 'i', 'p', 'e', '\n',
        'b', 'l', 'o', 'w', 'p', 'i', 'p', 'e', 's', '\n',
        'b', 'l', 'o', 'w', 's', '\n',
        'b', 'l', 'o', 'w', 't', 'o', 'r', 'c', 'h', '\n',
        'b', 'l', 'o', 'w', 't', 'o', 'r', 'c', 'h', 'e', 's', '\n',
        'b', 'l', 'o', 'w', 'u', 'p', '\n',
        'b', 'l', 'u', 'b', 'b', 'e', 'r', '\n',
        'b', 'l', 'u', 'b', 'b', 'e', 'r', 'e', 'd', '\n',
        'b', 'l', 'u', 'b', 'b', 'e', 'r', 'i', 'n', 'g', '\n',
        'b', 'l', 'u', 'd', 'g', 'e', 'o', 'n', '\n',
        'b', 'l', 'u', 'd', 'g', 'e', 'o', 'n', 'e', 'd', '\n',
        'b', 'l', 'u', 'd', 'g', 'e', 'o', 'n', 'i', 'n', 'g', '\n',
        'b', 'l', 'u', 'd', 'g', 'e', 'o', 'n', 's', '\n',
        'b', 'l', 'u', 'e', '\n',
        'b', 'l', 'u', 'e', 'b', 'e', 'l', 'l', '\n',
        'b', 'l', 'u', 'e', 'b', 'e', 'l', 'l', 's', '\n',
        'b', 'l', 'u', 'e', 'b', 'e', 'r', 'r', 'i', 'e', 's', '\n',
        'b', 'l', 'u', 'e', 'b', 'e', 'r', 'r', 'y', '\n',
        'b', 'l', 'u', 'e', 'b', 'i', 'r', 'd', '\n',
        'b', 'l', 'u', 'e', 'b', 'i', 'r', 'd', 's', '\n',
        'b', 'l', 'u', 'e', 'b', 'l', 'o', 'o', 'd', 'e', 'd', '\n',
        'b', 'l', 'u', 'e', 'b', 'o', 't', 't', 'l', 'e', '\n',
        'b', 'l', 'u', 'e', 'b', 'o', 't', 't', 'l', 'e', 's', '\n',
        'b', 'l', 'u', 'e', 'c', 'o', 'l', 'l', 'a', 'r', '\n',
        'b', 'l', 'u', 'e', 'i', 's', 'h', '\n',
        'b', 'l', 'u', 'e', 'm', 'o', 'o', 'n', '\n',
        'b', 'l', 'u', 'e', 'n', 'e', 's', 's', '\n',
        'b', 'l', 'u', 'e', 'n', 'i', 'l', 'e', '\n',
        'b', 'l', 'u', 'e', 'p', 'r', 'i', 'n', 't', '\n',
        'b', 'l', 'u', 'e', 'p', 'r', 'i', 'n', 't', 's', '\n',
        'b', 'l', 'u', 'e', 'r', '\n',
        'b', 'l', 'u', 'e', 's', '\n',
        'b', 'l', 'u', 'e', 's', 't', '\n',
        'b', 'l', 'u', 'e', 's', 'y', '\n',
        'b', 'l', 'u', 'f', 'f', '\n',
        'b', 'l', 'u', 'f', 'f', 'e', 'd', '\n',
        'b', 'l', 'u', 'f', 'f', 'e', 'r', '\n',
        'b', 'l', 'u', 'f', 'f', 'e', 'r', 's', '\n',
        'b', 'l', 'u', 'f', 'f', 'i', 'n', 'g', '\n',
        'b', 'l', 'u', 'f', 'f', 's', '\n',
        'b', 'l', 'u', 'i', 's', 'h', '\n',
        'b', 'l', 'u', 'n', 'd', 'e', 'r', '\n',
        'b', 'l', 'u', 'n', 'd', 'e', 'r', 'b', 'u', 's', 's', '\n',
        'b', 'l', 'u', 'n', 'd', 'e', 'r', 'e', 'd', '\n',
        'b', 'l', 'u', 'n', 'd', 'e', 'r', 'i', 'n', 'g', '\n',
        'b', 'l', 'u', 'n', 'd', 'e', 'r', 'i', 'n', 'g', 's', '\n',
        'b', 'l', 'u', 'n', 'd', 'e', 'r', 's', '\n',
        'b', 'l', 'u', 'n', 't', '\n',
        'b', 'l', 'u', 'n', 't', 'e', 'd', '\n',
        'b', 'l', 'u', 'n', 't', 'e', 'r', '\n',
        'b', 'l', 'u', 'n', 't', 'e', 's', 't', '\n',
        'b', 'l', 'u', 'n', 't', 'i', 'n', 'g', '\n',
        'b', 'l', 'u', 'n', 't', 'l', 'y', '\n',
        'b', 'l', 'u', 'n', 't', 'n', 'e', 's', 's', '\n',
        'b', 'l', 'u', 'n', 't', 's', '\n',
        'b', 'l', 'u', 'r', '\n',
        'b', 'l', 'u', 'r', 'b', '\n',
        'b', 'l', 'u', 'r', 'b', 's', '\n',
        'b', 'l', 'u', 'r', 'r', 'e', 'd', '\n',
        'b', 'l', 'u', 'r', 'r', 'i', 'n', 'g', '\n',
        'b', 'l', 'u', 'r', 'r', 'y', '\n',
        'b', 'l', 'u', 'r', 's', '\n',
        'b', 'l', 'u', 'r', 't', '\n',
        'b', 'l', 'u', 'r', 't', 'e', 'd', '\n',
        'b', 'l', 'u', 'r', 't', 'i', 'n', 'g', '\n',
        'b', 'l', 'u', 'r', 't', 's', '\n',
        'b', 'l', 'u', 's', 'h', '\n',
        'b', 'l', 'u', 's', 'h', 'e', 'd', '\n',
        'b', 'l', 'u', 's', 'h', 'e', 'r', '\n',
        'b', 'l', 'u', 's', 'h', 'e', 'r', 's', '\n',
        'b', 'l', 'u', 's', 'h', 'e', 's', '\n',
        'b', 'l', 'u', 's', 'h', 'i', 'n', 'g', '\n',
        'b', 'l', 'u', 's', 'h', 'i', 'n', 'g', 'l', 'y', '\n',
        'b', 'l', 'u', 's', 't', 'e', 'r', '\n',
        'b', 'l', 'u', 's', 't', 'e', 'r', 'e', 'd', '\n',
        'b', 'l', 'u', 's', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'b', 'l', 'u', 's', 't', 'e', 'r', 's', '\n',
        'b', 'l', 'u', 's', 't', 'e', 'r', 'y', '\n',
        'b', 'm', 'u', 's', '\n',
        'b', 'o', 'a', '\n',
        'b', 'o', 'a', 'r', '\n',
        'b', 'o', 'a', 'r', 'd', '\n',
        'b', 'o', 'a', 'r', 'd', 'e', 'd', '\n',
        'b', 'o', 'a', 'r', 'd', 'e', 'r', '\n',
        'b', 'o', 'a', 'r', 'd', 'e', 'r', 's', '\n',
        'b', 'o', 'a', 'r', 'd', 'g', 'a', 'm', 'e', 's', '\n',
        'b', 'o', 'a', 'r', 'd', 'i', 'n', 'g', '\n',
        'b', 'o', 'a', 'r', 'd', 'i', 'n', 'g', 's', '\n',
        'b', 'o', 'a', 'r', 'd', 'r', 'o', 'o', 'm', '\n',
        'b', 'o', 'a', 'r', 'd', 'r', 'o', 'o', 'm', 's', '\n',
        'b', 'o', 'a', 'r', 'd', 's', '\n',
        'b', 'o', 'a', 'r', 's', '\n',
        'b', 'o', 'a', 's', '\n',
        'b', 'o', 'a', 's', 't', '\n',
        'b', 'o', 'a', 's', 't', 'e', 'd', '\n',
        'b', 'o', 'a', 's', 't', 'e', 'r', '\n',
        'b', 'o', 'a', 's', 't', 'e', 'r', 's', '\n',
        'b', 'o', 'a', 's', 't', 'f', 'u', 'l', '\n',
        'b', 'o', 'a', 's', 't', 'f', 'u', 'l', 'l', 'y', '\n',
        'b', 'o', 'a', 's', 't', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'b', 'o', 'a', 's', 't', 'i', 'n', 'g', '\n',
        'b', 'o', 'a', 's', 't', 's', '\n',
        'b', 'o', 'a', 't', '\n',
        'b', 'o', 'a', 't', 'e', 'd', '\n',
        'b', 'o', 'a', 't', 'e', 'r', '\n',
        'b', 'o', 'a', 't', 'e', 'r', 's', '\n',
        'b', 'o', 'a', 't', 'h', 'o', 'u', 's', 'e', '\n',
        'b', 'o', 'a', 't', 'h', 'o', 'u', 's', 'e', 's', '\n',
        'b', 'o', 'a', 't', 'i', 'n', 'g', '\n',
        'b', 'o', 'a', 't', 'l', 'o', 'a', 'd', '\n',
        'b', 'o', 'a', 't', 'm', 'a', 'n', '\n',
        'b', 'o', 'a', 't', 'm', 'e', 'n', '\n',
        'b', 'o', 'a', 't', 's', '\n',
        'b', 'o', 'a', 't', 's', 'w', 'a', 'i', 'n', '\n',
        'b', 'o', 'b', '\n',
        'b', 'o', 'b', 'b', 'e', 'd', '\n',
        'b', 'o', 'b', 'b', 'i', 'e', 's', '\n',
        'b', 'o', 'b', 'b', 'i', 'n', '\n',
        'b', 'o', 'b', 'b', 'i', 'n', 'g', '\n',
        'b', 'o', 'b', 'b', 'i', 'n', 's', '\n',
        'b', 'o', 'b', 'b', 'l', 'e', '\n',
        'b', 'o', 'b', 'b', 'l', 'e', 's', '\n',
        'b', 'o', 'b', 'b', 'y', '\n',
        'b', 'o', 'b', 'c', 'a', 't', '\n',
        'b', 'o', 'b', 's', '\n',
        'b', 'o', 'b', 's', 'l', 'e', 'd', '\n',
        'b', 'o', 'b', 't', 'a', 'i', 'l', '\n',
        'b', 'o', 'b', 't', 'a', 'i', 'l', 's', '\n',
        'b', 'o', 'd', 'e', '\n',
        'b', 'o', 'd', 'e', 'd', '\n',
        'b', 'o', 'd', 'e', 's', '\n',
        'b', 'o', 'd', 'i', 'c', 'e', '\n',
        'b', 'o', 'd', 'i', 'c', 'e', 's', '\n',
        'b', 'o', 'd', 'i', 'e', 'd', '\n',
        'b', 'o', 'd', 'i', 'e', 's', '\n',
        'b', 'o', 'd', 'i', 'l', 'e', 's', 's', '\n',
        'b', 'o', 'd', 'i', 'l', 'y', '\n',
        'b', 'o', 'd', 'i', 'n', 'g', '\n',
        'b', 'o', 'd', 'k', 'i', 'n', '\n',
        'b', 'o', 'd', 'y', '\n',
        'b', 'o', 'd', 'y', 'b', 'u', 'i', 'l', 'd', 'i', 'n', 'g', '\n',
        'b', 'o', 'd', 'y', 'g', 'u', 'a', 'r', 'd', '\n',
        'b', 'o', 'd', 'y', 'g', 'u', 'a', 'r', 'd', 's', '\n',
        'b', 'o', 'd', 'y', 'w', 'o', 'r', 'k', '\n',
        'b', 'o', 'e', 'r', '\n',
        'b', 'o', 'e', 'r', 's', '\n',
        'b', 'o', 'e', 'r', 'w', 'a', 'r', '\n',
        'b', 'o', 'f', 'f', 'i', 'n', '\n',
        'b', 'o', 'f', 'f', 'i', 'n', 's', '\n',
        'b', 'o', 'g', '\n',
        'b', 'o', 'g', 'e', 'y', '\n',
        'b', 'o', 'g', 'e', 'y', 'm', 'a', 'n', '\n',
        'b', 'o', 'g', 'e', 'y', 'm', 'e', 'n', '\n',
        'b', 'o', 'g', 'e', 'y', 's', '\n',
        'b', 'o', 'g', 'g', 'e', 'd', '\n',
        'b', 'o', 'g', 'g', 'i', 'e', 's', 't', '\n',
        'b', 'o', 'g', 'g', 'i', 'n', 'g', '\n',
        'b', 'o', 'g', 'g', 'l', 'e', '\n',
        'b', 'o', 'g', 'g', 'l', 'e', 'd', '\n',
        'b', 'o', 'g', 'g', 'l', 'e', 's', '\n',
        'b', 'o', 'g', 'g', 'l', 'i', 'n', 'g', '\n',
        'b', 'o', 'g', 'g', 'l', 'i', 'n', 'g', 'l', 'y', '\n',
        'b', 'o', 'g', 'g', 'y', '\n',
        'b', 'o', 'g', 'i', 'e', 's', '\n',
        'b', 'o', 'g', 's', '\n',
        'b', 'o', 'g', 'u', 's', '\n',
        'b', 'o', 'g', 'y', '\n',
        'b', 'o', 'h', 'e', 'm', 'i', 'a', 'n', '\n',
        'b', 'o', 'i', 'l', '\n',
        'b', 'o', 'i', 'l', 'e', 'd', '\n',
        'b', 'o', 'i', 'l', 'e', 'r', '\n',
        'b', 'o', 'i', 'l', 'e', 'r', 'm', 'a', 'k', 'e', 'r', 's', '\n',
        'b', 'o', 'i', 'l', 'e', 'r', 's', '\n',
        'b', 'o', 'i', 'l', 'i', 'n', 'g', '\n',
        'b', 'o', 'i', 'l', 's', '\n',
        'b', 'o', 'i', 's', 't', 'e', 'r', 'o', 'u', 's', '\n',
        'b', 'o', 'i', 's', 't', 'e', 'r', 'o', 'u', 's', 'l', 'y', '\n',
        'b', 'o', 'l', 'a', '\n',
        'b', 'o', 'l', 'd', '\n',
        'b', 'o', 'l', 'd', 'e', 'r', '\n',
        'b', 'o', 'l', 'd', 'e', 's', 't', '\n',
        'b', 'o', 'l', 'd', 'f', 'a', 'c', 'e', '\n',
        'b', 'o', 'l', 'd', 'l', 'y', '\n',
        'b', 'o', 'l', 'd', 'n', 'e', 's', 's', '\n',
        'b', 'o', 'l', 'e', '\n',
        'b', 'o', 'l', 'e', 'r', 'o', '\n',
        'b', 'o', 'l', 'e', 'y', 'n', '\n',
        'b', 'o', 'l', 'i', 'v', 'i', 'a', '\n',
        'b', 'o', 'l', 'l', 'a', 'r', 'd', '\n',
        'b', 'o', 'l', 'l', 'a', 'r', 'd', 's', '\n',
        'b', 'o', 'l', 'o', 'g', 'n', 'a', '\n',
        'b', 'o', 'l', 's', 't', 'e', 'r', '\n',
        'b', 'o', 'l', 's', 't', 'e', 'r', 'e', 'd', '\n',
        'b', 'o', 'l', 's', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'b', 'o', 'l', 's', 't', 'e', 'r', 's', '\n',
        'b', 'o', 'l', 't', '\n',
        'b', 'o', 'l', 't', 'e', 'd', '\n',
        'b', 'o', 'l', 't', 'i', 'n', 'g', '\n',
        'b', 'o', 'l', 't', 's', '\n',
        'b', 'o', 'm', 'b', '\n',
        'b', 'o', 'm', 'b', 'a', 'r', 'd', '\n',
        'b', 'o', 'm', 'b', 'a', 'r', 'd', 'e', 'd', '\n',
        'b', 'o', 'm', 'b', 'a', 'r', 'd', 'i', 'e', 'r', '\n',
        'b', 'o', 'm', 'b', 'a', 'r', 'd', 'i', 'n', 'g', '\n',
        'b', 'o', 'm', 'b', 'a', 'r', 'd', 'm', 'e', 'n', 't', '\n',
        'b', 'o', 'm', 'b', 'a', 'r', 'd', 'm', 'e', 'n', 't', 's', '\n',
        'b', 'o', 'm', 'b', 'a', 'r', 'd', 's', '\n',
        'b', 'o', 'm', 'b', 'a', 's', 't', '\n',
        'b', 'o', 'm', 'b', 'a', 's', 't', 'i', 'c', '\n',
        'b', 'o', 'm', 'b', 'a', 's', 't', 's', '\n',
        'b', 'o', 'm', 'b', 'a', 'y', '\n',
        'b', 'o', 'm', 'b', 'e', 'd', '\n',
        'b', 'o', 'm', 'b', 'e', 'r', '\n',
        'b', 'o', 'm', 'b', 'e', 'r', 's', '\n',
        'b', 'o', 'm', 'b', 'i', 'n', 'g', '\n',
        'b', 'o', 'm', 'b', 'i', 'n', 'g', 's', '\n',
        'b', 'o', 'm', 'b', 's', '\n',
        'b', 'o', 'm', 'b', 's', 'h', 'e', 'l', 'l', '\n',
        'b', 'o', 'n', 'a', 'n', 'z', 'a', '\n',
        'b', 'o', 'n', 'a', 'n', 'z', 'a', 's', '\n',
        'b', 'o', 'n', 'b', 'o', 'n', '\n',
        'b', 'o', 'n', 'b', 'o', 'n', 's', '\n',
        'b', 'o', 'n', 'd', '\n',
        'b', 'o', 'n', 'd', 'a', 'g', 'e', '\n',
        'b', 'o', 'n', 'd', 'e', 'd', '\n',
        'b', 'o', 'n', 'd', 'h', 'o', 'l', 'd', 'e', 'r', 's', '\n',
        'b', 'o', 'n', 'd', 'i', 'n', 'g', '\n',
        'b', 'o', 'n', 'd', 'i', 'n', 'g', 's', '\n',
        'b', 'o', 'n', 'd', 's', '\n',
        'b', 'o', 'n', 'e', '\n',
        'b', 'o', 'n', 'e', 'd', '\n',
        'b', 'o', 'n', 'e', 'l', 'e', 's', 's', '\n',
        'b', 'o', 'n', 'e', 'm', 'e', 'a', 'l', '\n',
        'b', 'o', 'n', 'e', 's', '\n',
        'b', 'o', 'n', 'e', 'y', '\n',
        'b', 'o', 'n', 'f', 'i', 'r', 'e', '\n',
        'b', 'o', 'n', 'f', 'i', 'r', 'e', 's', '\n',
        'b', 'o', 'n', 'g', '\n',
        'b', 'o', 'n', 'g', 's', '\n',
        'b', 'o', 'n', 'i', 'e', 'r', '\n',
        'b', 'o', 'n', 'i', 'e', 's', 't', '\n',
        'b', 'o', 'n', 'n', '\n',
        'b', 'o', 'n', 'n', 'e', 't', '\n',
        'b', 'o', 'n', 'n', 'e', 't', 'e', 'd', '\n',
        'b', 'o', 'n', 'n', 'e', 't', 's', '\n',
        'b', 'o', 'n', 'n', 'i', 'e', '\n',
        'b', 'o', 'n', 'n', 'i', 'e', 's', 't', '\n',
        'b', 'o', 'n', 'n', 'y', '\n',
        'b', 'o', 'n', 'o', 'b', 'o', '\n',
        'b', 'o', 'n', 's', 'a', 'i', '\n',
        'b', 'o', 'n', 'u', 's', '\n',
        'b', 'o', 'n', 'u', 's', 'e', 's', '\n',
        'b', 'o', 'n', 'y', '\n',
        'b', 'o', 'o', '\n',
        'b', 'o', 'o', 'b', 'i', 'e', 's', '\n',
        'b', 'o', 'o', 'b', 'o', 'o', '\n',
        'b', 'o', 'o', 'b', 'y', '\n',
        'b', 'o', 'o', 'b', 'y', 't', 'r', 'a', 'p', '\n',
        'b', 'o', 'o', 'b', 'y', 't', 'r', 'a', 'p', 'p', 'e', 'd', '\n',
        'b', 'o', 'o', 'b', 'y', 't', 'r', 'a', 'p', 's', '\n',
        'b', 'o', 'o', 'e', 'd', '\n',
        'b', 'o', 'o', 'h', 'o', 'o', '\n',
        'b', 'o', 'o', 'i', 'n', 'g', '\n',
        'b', 'o', 'o', 'k', '\n',
        'b', 'o', 'o', 'k', 'a', 'b', 'l', 'e', '\n',
        'b', 'o', 'o', 'k', 'b', 'i', 'n', 'd', 'e', 'r', '\n',
        'b', 'o', 'o', 'k', 'b', 'i', 'n', 'd', 'e', 'r', 's', '\n',
        'b', 'o', 'o', 'k', 'b', 'i', 'n', 'd', 'i', 'n', 'g', '\n',
        'b', 'o', 'o', 'k', 'c', 'a', 's', 'e', '\n',
        'b', 'o', 'o', 'k', 'c', 'a', 's', 'e', 's', '\n',
        'b', 'o', 'o', 'k', 'e', 'd', '\n',
        'b', 'o', 'o', 'k', 'e', 'n', 'd', 's', '\n',
        'b', 'o', 'o', 'k', 'e', 'r', 's', '\n',
        'b', 'o', 'o', 'k', 'i', 'e', '\n',
        'b', 'o', 'o', 'k', 'i', 'e', 's', '\n',
        'b', 'o', 'o', 'k', 'i', 'n', 'g', '\n',
        'b', 'o', 'o', 'k', 'i', 'n', 'g', 's', '\n',
        'b', 'o', 'o', 'k', 'i', 's', 'h', '\n',
        'b', 'o', 'o', 'k', 'k', 'e', 'e', 'p', 'e', 'r', '\n',
        'b', 'o', 'o', 'k', 'k', 'e', 'e', 'p', 'i', 'n', 'g', '\n',
        'b', 'o', 'o', 'k', 'l', 'e', 't', '\n',
        'b', 'o', 'o', 'k', 'l', 'e', 't', 's', '\n',
        'b', 'o', 'o', 'k', 'm', 'a', 'k', 'e', 'r', '\n',
        'b', 'o', 'o', 'k', 'm', 'a', 'k', 'e', 'r', 's', '\n',
        'b', 'o', 'o', 'k', 'm', 'a', 'k', 'i', 'n', 'g', '\n',
        'b', 'o', 'o', 'k', 'm', 'a', 'r', 'k', '\n',
        'b', 'o', 'o', 'k', 'm', 'a', 'r', 'k', 's', '\n',
        'b', 'o', 'o', 'k', 's', '\n',
        'b', 'o', 'o', 'k', 's', 'e', 'l', 'l', 'e', 'r', '\n',
        'b', 'o', 'o', 'k', 's', 'e', 'l', 'l', 'e', 'r', 's', '\n',
        'b', 'o', 'o', 'k', 's', 'h', 'e', 'l', 'f', '\n',
        'b', 'o', 'o', 'k', 's', 'h', 'e', 'l', 'v', 'e', 's', '\n',
        'b', 'o', 'o', 'k', 's', 'h', 'o', 'p', '\n',
        'b', 'o', 'o', 'k', 's', 'h', 'o', 'p', 's', '\n',
        'b', 'o', 'o', 'k', 's', 't', 'a', 'l', 'l', '\n',
        'b', 'o', 'o', 'k', 's', 't', 'a', 'l', 'l', 's', '\n',
        'b', 'o', 'o', 'k', 'w', 'o', 'r', 'k', '\n',
        'b', 'o', 'o', 'k', 'w', 'o', 'r', 'm', '\n',
        'b', 'o', 'o', 'k', 'w', 'o', 'r', 'm', 's', '\n',
        'b', 'o', 'o', 'm', '\n',
        'b', 'o', 'o', 'm', 'e', 'd', '\n',
        'b', 'o', 'o', 'm', 'e', 'r', '\n',
        'b', 'o', 'o', 'm', 'e', 'r', 'a', 'n', 'g', '\n',
        'b', 'o', 'o', 'm', 'e', 'r', 'a', 'n', 'g', 'i', 'n', 'g', '\n',
        'b', 'o', 'o', 'm', 'e', 'r', 'a', 'n', 'g', 's', '\n',
        'b', 'o', 'o', 'm', 'i', 'n', 'g', '\n',
        'b', 'o', 'o', 'm', 's', '\n',
        'b', 'o', 'o', 'n', '\n',
        'b', 'o', 'o', 'n', 's', '\n',
        'b', 'o', 'o', 'r', '\n',
        'b', 'o', 'o', 'r', 'i', 's', 'h', '\n',
        'b', 'o', 'o', 'r', 'i', 's', 'h', 'l', 'y', '\n',
        'b', 'o', 'o', 'r', 'i', 's', 'h', 'n', 'e', 's', 's', '\n',
        'b', 'o', 'o', 'r', 's', '\n',
        'b', 'o', 'o', 's', '\n',
        'b', 'o', 'o', 's', 't', '\n',
        'b', 'o', 'o', 's', 't', 'e', 'd', '\n',
        'b', 'o', 'o', 's', 't', 'e', 'r', '\n',
        'b', 'o', 'o', 's', 't', 'e', 'r', 's', '\n',
        'b', 'o', 'o', 's', 't', 'i', 'n', 'g', '\n',
        'b', 'o', 'o', 's', 't', 's', '\n',
        'b', 'o', 'o', 't', '\n',
        'b', 'o', 'o', 't', 'e', 'd', '\n',
        'b', 'o', 'o', 't', 'e', 'e', 's', '\n',
        'b', 'o', 'o', 't', 'h', '\n',
        'b', 'o', 'o', 't', 'h', 's', '\n',
        'b', 'o', 'o', 't', 'i', 'n', 'g', '\n',
        'b', 'o', 'o', 't', 'l', 'a', 'c', 'e', '\n',
        'b', 'o', 'o', 't', 'l', 'a', 'c', 'e', 's', '\n',
        'b', 'o', 'o', 't', 'l', 'e', 'g', '\n',
        'b', 'o', 'o', 't', 'l', 'e', 's', 's', '\n',
        'b', 'o', 'o', 't', 'p', 'r', 'i', 'n', 't', 's', '\n',
        'b', 'o', 'o', 't', 's', '\n',
        'b', 'o', 'o', 't', 's', 't', 'r', 'a', 'p', '\n',
        'b', 'o', 'o', 't', 's', 't', 'r', 'a', 'p', 's', '\n',
        'b', 'o', 'o', 't', 'y', '\n',
        'b', 'o', 'o', 'z', 'e', '\n',
        'b', 'o', 'o', 'z', 'e', 'd', '\n',
        'b', 'o', 'o', 'z', 'e', 'r', '\n',
        'b', 'o', 'o', 'z', 'e', 'r', 's', '\n',
        'b', 'o', 'o', 'z', 'e', 's', '\n',
        'b', 'o', 'p', '\n',
        'b', 'o', 'p', 's', '\n',
        'b', 'o', 'r', 'a', 'c', 'i', 'c', '\n',
        'b', 'o', 'r', 'a', 't', 'e', '\n',
        'b', 'o', 'r', 'a', 't', 'e', 's', '\n',
        'b', 'o', 'r', 'a', 'x', '\n',
        'b', 'o', 'r', 'd', 'e', 'a', 'u', 'x', '\n',
        'b', 'o', 'r', 'd', 'e', 'r', '\n',
        'b', 'o', 'r', 'd', 'e', 'r', 'e', 'd', '\n',
        'b', 'o', 'r', 'd', 'e', 'r', 'e', 'r', '\n',
        'b', 'o', 'r', 'd', 'e', 'r', 'i', 'n', 'g', '\n',
        'b', 'o', 'r', 'd', 'e', 'r', 'l', 'i', 'n', 'e', '\n',
        'b', 'o', 'r', 'd', 'e', 'r', 's', '\n',
        'b', 'o', 'r', 'e', '\n',
        'b', 'o', 'r', 'e', 'a', 'l', '\n',
        'b', 'o', 'r', 'e', 'd', '\n',
        'b', 'o', 'r', 'e', 'd', 'o', 'm', '\n',
        'b', 'o', 'r', 'e', 'h', 'o', 'l', 'e', '\n',
        'b', 'o', 'r', 'e', 'h', 'o', 'l', 'e', 's', '\n',
        'b', 'o', 'r', 'e', 'r', '\n',
        'b', 'o', 'r', 'e', 'r', 's', '\n',
        'b', 'o', 'r', 'e', 's', '\n',
        'b', 'o', 'r', 'i', 'n', 'g', '\n',
        'b', 'o', 'r', 'i', 'n', 'g', 'l', 'y', '\n',
        'b', 'o', 'r', 'n', '\n',
        'b', 'o', 'r', 'n', 'a', 'g', 'a', 'i', 'n', '\n',
        'b', 'o', 'r', 'n', 'e', '\n',
        'b', 'o', 'r', 'n', 'e', 'o', '\n',
        'b', 'o', 'r', 'o', 'n', '\n',
        'b', 'o', 'r', 'o', 'u', 'g', 'h', '\n',
        'b', 'o', 'r', 'o', 'u', 'g', 'h', 's', '\n',
        'b', 'o', 'r', 'r', 'o', 'w', '\n',
        'b', 'o', 'r', 'r', 'o', 'w', 'a', 'b', 'l', 'e', '\n',
        'b', 'o', 'r', 'r', 'o', 'w', 'e', 'd', '\n',
        'b', 'o', 'r', 'r', 'o', 'w', 'e', 'r', '\n',
        'b', 'o', 'r', 'r', 'o', 'w', 'e', 'r', 's', '\n',
        'b', 'o', 'r', 'r', 'o', 'w', 'i', 'n', 'g', '\n',
        'b', 'o', 'r', 'r', 'o', 'w', 'i', 'n', 'g', 's', '\n',
        'b', 'o', 'r', 'r', 'o', 'w', 's', '\n',
        'b', 'o', 'r', 's', 't', 'a', 'l', '\n',
        'b', 'o', 'r', 's', 't', 'a', 'l', 's', '\n',
        'b', 'o', 's', 'n', 'i', 'a', '\n',
        'b', 'o', 's', 'o', 'm', '\n',
        'b', 'o', 's', 'o', 'm', 's', '\n',
        'b', 'o', 's', 'o', 'n', '\n',
        'b', 'o', 's', 'o', 'n', 's', '\n',
        'b', 'o', 's', 's', '\n',
        'b', 'o', 's', 's', 'e', 'd', '\n',
        'b', 'o', 's', 's', 'e', 's', '\n',
        'b', 'o', 's', 's', 'i', 'e', 'r', '\n',
        'b', 'o', 's', 's', 'i', 'e', 's', 't', '\n',
        'b', 'o', 's', 's', 'i', 'n', 'e', 's', 's', '\n',
        'b', 'o', 's', 's', 'i', 'n', 'g', '\n',
        'b', 'o', 's', 's', 'y', '\n',
        'b', 'o', 's', 't', 'o', 'n', '\n',
        'b', 'o', 's', 'u', 'n', '\n',
        'b', 'o', 't', 'a', 'n', 'i', 'c', '\n',
        'b', 'o', 't', 'a', 'n', 'i', 'c', 'a', 'l', '\n',
        'b', 'o', 't', 'a', 'n', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'b', 'o', 't', 'a', 'n', 'i', 's', 't', '\n',
        'b', 'o', 't', 'a', 'n', 'i', 's', 't', 's', '\n',
        'b', 'o', 't', 'a', 'n', 'y', '\n',
        'b', 'o', 't', 'c', 'h', '\n',
        'b', 'o', 't', 'c', 'h', 'e', 'd', '\n',
        'b', 'o', 't', 'h', '\n',
        'b', 'o', 't', 'h', 'e', 'r', '\n',
        'b', 'o', 't', 'h', 'e', 'r', 'e', 'd', '\n',
        'b', 'o', 't', 'h', 'e', 'r', 'i', 'n', 'g', '\n',
        'b', 'o', 't', 'h', 'e', 'r', 's', '\n',
        'b', 'o', 't', 'h', 'e', 'r', 's', 'o', 'm', 'e', '\n',
        'b', 'o', 't', 'h', 'y', '\n',
        'b', 'o', 't', 's', 'w', 'a', 'n', 'a', '\n',
        'b', 'o', 't', 't', 'l', 'e', '\n',
        'b', 'o', 't', 't', 'l', 'e', 'd', '\n',
        'b', 'o', 't', 't', 'l', 'e', 'f', 'e', 'd', '\n',
        'b', 'o', 't', 't', 'l', 'e', 'f', 'e', 'e', 'd', '\n',
        'b', 'o', 't', 't', 'l', 'e', 'n', 'e', 'c', 'k', '\n',
        'b', 'o', 't', 't', 'l', 'e', 'n', 'e', 'c', 'k', 's', '\n',
        'b', 'o', 't', 't', 'l', 'e', 'r', '\n',
        'b', 'o', 't', 't', 'l', 'e', 's', '\n',
        'b', 'o', 't', 't', 'l', 'i', 'n', 'g', '\n',
        'b', 'o', 't', 't', 'o', 'm', '\n',
        'b', 'o', 't', 't', 'o', 'm', 'e', 'd', '\n',
        'b', 'o', 't', 't', 'o', 'm', 'i', 'n', 'g', '\n',
        'b', 'o', 't', 't', 'o', 'm', 'l', 'e', 's', 's', '\n',
        'b', 'o', 't', 't', 'o', 'm', 'm', 'o', 's', 't', '\n',
        'b', 'o', 't', 't', 'o', 'm', 's', '\n',
        'b', 'o', 't', 'u', 'l', 'i', 's', 'm', '\n',
        'b', 'o', 'u', 'd', 'o', 'i', 'r', '\n',
        'b', 'o', 'u', 'd', 'o', 'i', 'r', 's', '\n',
        'b', 'o', 'u', 'f', 'f', 'a', 'n', 't', '\n',
        'b', 'o', 'u', 'g', 'a', 'i', 'n', 'v', 'i', 'l', 'l', 'e', 'a', '\n',
        'b', 'o', 'u', 'g', 'h', '\n',
        'b', 'o', 'u', 'g', 'h', 's', '\n',
        'b', 'o', 'u', 'g', 'h', 't', '\n',
        'b', 'o', 'u', 'l', 'd', 'e', 'r', '\n',
        'b', 'o', 'u', 'l', 'd', 'e', 'r', 's', '\n',
        'b', 'o', 'u', 'l', 'e', 'v', 'a', 'r', 'd', '\n',
        'b', 'o', 'u', 'l', 'e', 'v', 'a', 'r', 'd', 's', '\n',
        'b', 'o', 'u', 'n', 'c', 'e', '\n',
        'b', 'o', 'u', 'n', 'c', 'e', 'd', '\n',
        'b', 'o', 'u', 'n', 'c', 'e', 'r', '\n',
        'b', 'o', 'u', 'n', 'c', 'e', 'r', 's', '\n',
        'b', 'o', 'u', 'n', 'c', 'e', 's', '\n',
        'b', 'o', 'u', 'n', 'c', 'i', 'e', 'r', '\n',
        'b', 'o', 'u', 'n', 'c', 'i', 'e', 's', 't', '\n',
        'b', 'o', 'u', 'n', 'c', 'i', 'n', 'g', '\n',
        'b', 'o', 'u', 'n', 'c', 'y', '\n',
        'b', 'o', 'u', 'n', 'd', '\n',
        'b', 'o', 'u', 'n', 'd', 'a', 'r', 'i', 'e', 's', '\n',
        'b', 'o', 'u', 'n', 'd', 'a', 'r', 'y', '\n',
        'b', 'o', 'u', 'n', 'd', 'e', 'd', '\n',
        'b', 'o', 'u', 'n', 'd', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'b', 'o', 'u', 'n', 'd', 'e', 'r', '\n',
        'b', 'o', 'u', 'n', 'd', 'e', 'r', 's', '\n',
        'b', 'o', 'u', 'n', 'd', 'i', 'n', 'g', '\n',
        'b', 'o', 'u', 'n', 'd', 'l', 'e', 's', 's', '\n',
        'b', 'o', 'u', 'n', 'd', 's', '\n',
        'b', 'o', 'u', 'n', 't', 'e', 'o', 'u', 's', '\n',
        'b', 'o', 'u', 'n', 't', 'i', 'e', 's', '\n',
        'b', 'o', 'u', 'n', 't', 'i', 'f', 'u', 'l', '\n',
        'b', 'o', 'u', 'n', 't', 'i', 'f', 'u', 'l', 'l', 'y', '\n',
        'b', 'o', 'u', 'n', 't', 'y', '\n',
        'b', 'o', 'u', 'q', 'u', 'e', 't', '\n',
        'b', 'o', 'u', 'q', 'u', 'e', 't', 's', '\n',
        'b', 'o', 'u', 'r', 'b', 'o', 'n', '\n',
        'b', 'o', 'u', 'r', 'b', 'o', 'n', 's', '\n',
        'b', 'o', 'u', 'r', 'g', 'e', 'o', 'i', 's', '\n',
        'b', 'o', 'u', 'r', 'g', 'e', 'o', 'i', 's', 'i', 'e', '\n',
        'b', 'o', 'u', 't', '\n',
        'b', 'o', 'u', 't', 'i', 'q', 'u', 'e', '\n',
        'b', 'o', 'u', 't', 'i', 'q', 'u', 'e', 's', '\n',
        'b', 'o', 'u', 't', 's', '\n',
        'b', 'o', 'v', 'i', 'n', 'e', '\n',
        'b', 'o', 'w', '\n',
        'b', 'o', 'w', 'd', 'l', 'e', 'r', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'b', 'o', 'w', 'd', 'l', 'e', 'r', 'i', 's', 'e', 'd', '\n',
        'b', 'o', 'w', 'd', 'l', 'e', 'r', 'i', 's', 'i', 'n', 'g', '\n',
        'b', 'o', 'w', 'e', 'd', '\n',
        'b', 'o', 'w', 'e', 'l', '\n',
        'b', 'o', 'w', 'e', 'l', 's', '\n',
        'b', 'o', 'w', 'e', 'r', '\n',
        'b', 'o', 'w', 'e', 'r', 's', '\n',
        'b', 'o', 'w', 'i', 'e', '\n',
        'b', 'o', 'w', 'i', 'n', 'g', '\n',
        'b', 'o', 'w', 'l', '\n',
        'b', 'o', 'w', 'l', 'd', 'e', 'r', '\n',
        'b', 'o', 'w', 'l', 'e', 'd', '\n',
        'b', 'o', 'w', 'l', 'e', 'r', '\n',
        'b', 'o', 'w', 'l', 'e', 'r', 's', '\n',
        'b', 'o', 'w', 'l', 'i', 'n', 'e', 's', '\n',
        'b', 'o', 'w', 'l', 'i', 'n', 'g', '\n',
        'b', 'o', 'w', 'l', 's', '\n',
        'b', 'o', 'w', 'm', 'a', 'n', '\n',
        'b', 'o', 'w', 'm', 'e', 'n', '\n',
        'b', 'o', 'w', 's', '\n',
        'b', 'o', 'w', 's', 'p', 'r', 'i', 't', '\n',
        'b', 'o', 'w', 's', 't', 'r', 'i', 'n', 'g', '\n',
        'b', 'o', 'x', '\n',
        'b', 'o', 'x', 'e', 'd', '\n',
        'b', 'o', 'x', 'e', 'r', '\n',
        'b', 'o', 'x', 'e', 'r', 's', '\n',
        'b', 'o', 'x', 'e', 's', '\n',
        'b', 'o', 'x', 'f', 'u', 'l', '\n',
        'b', 'o', 'x', 'i', 'n', 'g', '\n',
        'b', 'o', 'x', 'o', 'f', 'f', 'i', 'c', 'e', '\n',
        'b', 'o', 'x', 't', 'o', 'p', 's', '\n',
        'b', 'o', 'x', 'w', 'o', 'o', 'd', '\n',
        'b', 'o', 'x', 'y', '\n',
        'b', 'o', 'y', '\n',
        'b', 'o', 'y', 'c', 'o', 't', 't', '\n',
        'b', 'o', 'y', 'c', 'o', 't', 't', 'e', 'd', '\n',
        'b', 'o', 'y', 'c', 'o', 't', 't', 'i', 'n', 'g', '\n',
        'b', 'o', 'y', 'c', 'o', 't', 't', 's', '\n',
        'b', 'o', 'y', 'f', 'r', 'i', 'e', 'n', 'd', '\n',
        'b', 'o', 'y', 'f', 'r', 'i', 'e', 'n', 'd', 's', '\n',
        'b', 'o', 'y', 'h', 'o', 'o', 'd', '\n',
        'b', 'o', 'y', 'i', 's', 'h', '\n',
        'b', 'o', 'y', 'i', 's', 'h', 'l', 'y', '\n',
        'b', 'o', 'y', 's', '\n',
        'b', 'o', 'y', 's', 'c', 'o', 'u', 't', '\n',
        'b', 'r', 'a', '\n',
        'b', 'r', 'a', 'b', 'b', 'l', 'e', '\n',
        'b', 'r', 'a', 'b', 'b', 'l', 'e', 'd', '\n',
        'b', 'r', 'a', 'b', 'b', 'l', 'e', 's', '\n',
        'b', 'r', 'a', 'c', 'e', '\n',
        'b', 'r', 'a', 'c', 'e', 'd', '\n',
        'b', 'r', 'a', 'c', 'e', 'l', 'e', 't', '\n',
        'b', 'r', 'a', 'c', 'e', 'l', 'e', 't', 's', '\n',
        'b', 'r', 'a', 'c', 'e', 'r', '\n',
        'b', 'r', 'a', 'c', 'e', 's', '\n',
        'b', 'r', 'a', 'c', 'h', 'i', 'o', 'p', 'o', 'd', 's', '\n',
        'b', 'r', 'a', 'c', 'i', 'n', 'g', '\n',
        'b', 'r', 'a', 'c', 'i', 'n', 'g', 'l', 'y', '\n',
        'b', 'r', 'a', 'c', 'k', 'e', 'n', '\n',
        'b', 'r', 'a', 'c', 'k', 'e', 't', '\n',
        'b', 'r', 'a', 'c', 'k', 'e', 't', 'e', 'd', '\n',
        'b', 'r', 'a', 'c', 'k', 'e', 't', 'i', 'n', 'g', '\n',
        'b', 'r', 'a', 'c', 'k', 'e', 't', 's', '\n',
        'b', 'r', 'a', 'c', 'k', 'i', 's', 'h', '\n',
        'b', 'r', 'a', 'd', 'a', 'w', 'l', '\n',
        'b', 'r', 'a', 'd', 'y', 'c', 'a', 'r', 'd', 'i', 'a', '\n',
        'b', 'r', 'a', 'g', '\n',
        'b', 'r', 'a', 'g', 'g', 'a', 'r', 't', '\n',
        'b', 'r', 'a', 'g', 'g', 'a', 'r', 't', 's', '\n',
        'b', 'r', 'a', 'g', 'g', 'e', 'd', '\n',
        'b', 'r', 'a', 'g', 'g', 'i', 'n', 'g', '\n',
        'b', 'r', 'a', 'g', 's', '\n',
        'b', 'r', 'a', 'h', 'm', 'a', 'n', '\n',
        'b', 'r', 'a', 'h', 'm', 's', '\n',
        'b', 'r', 'a', 'i', 'd', '\n',
        'b', 'r', 'a', 'i', 'd', 'e', 'd', '\n',
        'b', 'r', 'a', 'i', 'd', 'i', 'n', 'g', '\n',
        'b', 'r', 'a', 'i', 'd', 's', '\n',
        'b', 'r', 'a', 'i', 'l', '\n',
        'b', 'r', 'a', 'i', 'l', 'l', 'e', '\n',
        'b', 'r', 'a', 'i', 'n', '\n',
        'b', 'r', 'a', 'i', 'n', 'c', 'e', 'l', 'l', '\n',
        'b', 'r', 'a', 'i', 'n', 'c', 'e', 'l', 'l', 's', '\n',
        'b', 'r', 'a', 'i', 'n', 'c', 'h', 'i', 'l', 'd', '\n',
        'b', 'r', 'a', 'i', 'n', 'd', 'a', 'm', 'a', 'g', 'e', 'd', '\n',
        'b', 'r', 'a', 'i', 'n', 'd', 'e', 'a', 'd', '\n',
        'b', 'r', 'a', 'i', 'n', 'i', 'e', 'r', '\n',
        'b', 'r', 'a', 'i', 'n', 'l', 'e', 's', 's', '\n',
        'b', 'r', 'a', 'i', 'n', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'b', 'r', 'a', 'i', 'n', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'b', 'r', 'a', 'i', 'n', 'p', 'o', 'w', 'e', 'r', '\n',
        'b', 'r', 'a', 'i', 'n', 's', '\n',
        'b', 'r', 'a', 'i', 'n', 's', 't', 'o', 'r', 'm', '\n',
        'b', 'r', 'a', 'i', 'n', 's', 't', 'o', 'r', 'm', 'i', 'n', 'g', '\n',
        'b', 'r', 'a', 'i', 'n', 's', 't', 'o', 'r', 'm', 's', '\n',
        'b', 'r', 'a', 'i', 'n', 't', 'e', 'a', 's', 'e', 'r', 's', '\n',
        'b', 'r', 'a', 'i', 'n', 't', 'e', 'a', 's', 'i', 'n', 'g', '\n',
        'b', 'r', 'a', 'i', 'n', 'w', 'a', 's', 'h', '\n',
        'b', 'r', 'a', 'i', 'n', 'w', 'a', 's', 'h', 'e', 'd', '\n',
        'b', 'r', 'a', 'i', 'n', 'w', 'a', 's', 'h', 'i', 'n', 'g', '\n',
        'b', 'r', 'a', 'i', 'n', 'w', 'a', 'v', 'e', '\n',
        'b', 'r', 'a', 'i', 'n', 'w', 'a', 'v', 'e', 's', '\n',
        'b', 'r', 'a', 'i', 'n', 'y', '\n',
        'b', 'r', 'a', 'i', 's', 'e', '\n',
        'b', 'r', 'a', 'i', 's', 'e', 'd', '\n',
        'b', 'r', 'a', 'k', 'e', '\n',
        'b', 'r', 'a', 'k', 'e', '\n',
        'b', 'r', 'a', 'k', 'e', 'd', '\n',
        'b', 'r', 'a', 'k', 'e', 's', '\n',
        'b', 'r', 'a', 'k', 'i', 'n', 'g', '\n',
        'b', 'r', 'a', 'm', 'b', 'l', 'e', '\n',
        'b', 'r', 'a', 'm', 'b', 'l', 'e', 's', '\n',
        'b', 'r', 'a', 'n', '\n',
        'b', 'r', 'a', 'n', 'c', 'h', '\n',
        'b', 'r', 'a', 'n', 'c', 'h', 'e', 'd', '\n',
        'b', 'r', 'a', 'n', 'c', 'h', 'e', 's', '\n',
        'b', 'r', 'a', 'n', 'c', 'h', 'i', 'n', 'g', '\n',
        'b', 'r', 'a', 'n', 'c', 'h', 'y', '\n',
        'b', 'r', 'a', 'n', 'd', '\n',
        'b', 'r', 'a', 'n', 'd', 'e', 'd', '\n',
        'b', 'r', 'a', 'n', 'd', 'i', 'e', 's', '\n',
        'b', 'r', 'a', 'n', 'd', 'i', 'n', 'g', '\n',
        'b', 'r', 'a', 'n', 'd', 'i', 's', 'h', '\n',
        'b', 'r', 'a', 'n', 'd', 'i', 's', 'h', 'e', 'd', '\n',
        'b', 'r', 'a', 'n', 'd', 'i', 's', 'h', 'e', 's', '\n',
        'b', 'r', 'a', 'n', 'd', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'b', 'r', 'a', 'n', 'd', 's', '\n',
        'b', 'r', 'a', 'n', 'd', 'y', '\n',
        'b', 'r', 'a', 'n', 's', '\n',
        'b', 'r', 'a', 's', '\n',
        'b', 'r', 'a', 's', 'h', '\n',
        'b', 'r', 'a', 's', 'h', 'e', 'r', '\n',
        'b', 'r', 'a', 's', 'h', 'l', 'y', '\n',
        'b', 'r', 'a', 's', 'h', 'n', 'e', 's', 's', '\n',
        'b', 'r', 'a', 's', 'i', 'e', 'r', 's', '\n',
        'b', 'r', 'a', 's', 'i', 'l', '\n',
        'b', 'r', 'a', 's', 'i', 'l', 'i', 'a', '\n',
        'b', 'r', 'a', 's', 's', '\n',
        'b', 'r', 'a', 's', 's', 'e', 'r', 'i', 'e', '\n',
        'b', 'r', 'a', 's', 's', 'e', 's', '\n',
        'b', 'r', 'a', 's', 's', 'i', 'e', 'r', 'e', '\n',
        'b', 'r', 'a', 's', 's', 'y', '\n',
        'b', 'r', 'a', 't', '\n',
        'b', 'r', 'a', 't', 's', '\n',
        'b', 'r', 'a', 't', 't', 'y', '\n',
        'b', 'r', 'a', 'v', 'a', 'd', 'o', '\n',
        'b', 'r', 'a', 'v', 'e', '\n',
        'b', 'r', 'a', 'v', 'e', 'd', '\n',
        'b', 'r', 'a', 'v', 'e', 'l', 'y', '\n',
        'b', 'r', 'a', 'v', 'e', 'r', '\n',
        'b', 'r', 'a', 'v', 'e', 'r', 'y', '\n',
        'b', 'r', 'a', 'v', 'e', 's', '\n',
        'b', 'r', 'a', 'v', 'e', 's', 't', '\n',
        'b', 'r', 'a', 'v', 'i', 'n', 'g', '\n',
        'b', 'r', 'a', 'v', 'o', '\n',
        'b', 'r', 'a', 'w', '\n',
        'b', 'r', 'a', 'w', 'l', '\n',
        'b', 'r', 'a', 'w', 'l', 'e', 'd', '\n',
        'b', 'r', 'a', 'w', 'l', 'e', 'r', '\n',
        'b', 'r', 'a', 'w', 'l', 'i', 'n', 'g', '\n',
        'b', 'r', 'a', 'w', 'l', 's', '\n',
        'b', 'r', 'a', 'w', 'n', '\n',
        'b', 'r', 'a', 'w', 'n', 'i', 'e', 'r', '\n',
        'b', 'r', 'a', 'w', 'n', 'i', 'e', 's', 't', '\n',
        'b', 'r', 'a', 'w', 'n', 'y', '\n',
        'b', 'r', 'a', 'y', '\n',
        'b', 'r', 'a', 'y', 'e', 'd', '\n',
        'b', 'r', 'a', 'y', 'i', 'n', 'g', '\n',
        'b', 'r', 'a', 'y', 's', '\n',
        'b', 'r', 'a', 'z', 'e', '\n',
        'b', 'r', 'a', 'z', 'e', 'n', '\n',
        'b', 'r', 'a', 'z', 'e', 'n', 'e', 'd', '\n',
        'b', 'r', 'a', 'z', 'e', 'n', 'l', 'y', '\n',
        'b', 'r', 'a', 'z', 'e', 'n', 'n', 'e', 's', 's', '\n',
        'b', 'r', 'a', 'z', 'i', 'e', 'r', '\n',
        'b', 'r', 'a', 'z', 'i', 'e', 'r', 's', '\n',
        'b', 'r', 'a', 'z', 'i', 'l', '\n',
        'b', 'r', 'a', 'z', 'i', 'n', 'g', '\n',
        'b', 'r', 'e', 'a', 'c', 'h', '\n',
        'b', 'r', 'e', 'a', 'c', 'h', 'e', 'd', '\n',
        'b', 'r', 'e', 'a', 'c', 'h', 'e', 's', '\n',
        'b', 'r', 'e', 'a', 'c', 'h', 'i', 'n', 'g', '\n',
        'b', 'r', 'e', 'a', 'd', '\n',
        'b', 'r', 'e', 'a', 'd', 'a', 'n', 'd', 'b', 'u', 't', 't', 'e', 'r', '\n',
        'b', 'r', 'e', 'a', 'd', 'b', 'o', 'a', 'r', 'd', '\n',
        'b', 'r', 'e', 'a', 'd', 'b', 'o', 'a', 'r', 'd', 's', '\n',
        'b', 'r', 'e', 'a', 'd', 'c', 'r', 'u', 'm', 'b', 's', '\n',
        'b', 'r', 'e', 'a', 'd', 'e', 'd', '\n',
        'b', 'r', 'e', 'a', 'd', 'f', 'r', 'u', 'i', 't', '\n',
        'b', 'r', 'e', 'a', 'd', 'l', 'i', 'n', 'e', '\n',
        'b', 'r', 'e', 'a', 'd', 's', '\n',
        'b', 'r', 'e', 'a', 'd', 't', 'h', '\n',
        'b', 'r', 'e', 'a', 'd', 't', 'h', 's', '\n',
        'b', 'r', 'e', 'a', 'd', 'w', 'i', 'n', 'n', 'e', 'r', '\n',
        'b', 'r', 'e', 'a', 'd', 'w', 'i', 'n', 'n', 'e', 'r', 's', '\n',
        'b', 'r', 'e', 'a', 'k', '\n',
        'b', 'r', 'e', 'a', 'k', 'a', 'b', 'l', 'e', '\n',
        'b', 'r', 'e', 'a', 'k', 'a', 'g', 'e', '\n',
        'b', 'r', 'e', 'a', 'k', 'a', 'g', 'e', 's', '\n',
        'b', 'r', 'e', 'a', 'k', 'a', 'w', 'a', 'y', '\n',
        'b', 'r', 'e', 'a', 'k', 'a', 'w', 'a', 'y', 's', '\n',
        'b', 'r', 'e', 'a', 'k', 'd', 'o', 'w', 'n', '\n',
        'b', 'r', 'e', 'a', 'k', 'd', 'o', 'w', 'n', 's', '\n',
        'b', 'r', 'e', 'a', 'k', 'e', 'r', '\n',
        'b', 'r', 'e', 'a', 'k', 'e', 'r', 's', '\n',
        'b', 'r', 'e', 'a', 'k', 'f', 'a', 's', 't', '\n',
        'b', 'r', 'e', 'a', 'k', 'f', 'a', 's', 't', 'e', 'd', '\n',
        'b', 'r', 'e', 'a', 'k', 'f', 'a', 's', 't', 'i', 'n', 'g', '\n',
        'b', 'r', 'e', 'a', 'k', 'f', 'a', 's', 't', 's', '\n',
        'b', 'r', 'e', 'a', 'k', 'i', 'n', '\n',
        'b', 'r', 'e', 'a', 'k', 'i', 'n', 'g', '\n',
        'b', 'r', 'e', 'a', 'k', 'i', 'n', 's', '\n',
        'b', 'r', 'e', 'a', 'k', 'n', 'e', 'c', 'k', '\n',
        'b', 'r', 'e', 'a', 'k', 'o', 'u', 't', '\n',
        'b', 'r', 'e', 'a', 'k', 'p', 'o', 'i', 'n', 't', '\n',
        'b', 'r', 'e', 'a', 'k', 'p', 'o', 'i', 'n', 't', 's', '\n',
        'b', 'r', 'e', 'a', 'k', 's', '\n',
        'b', 'r', 'e', 'a', 'k', 't', 'h', 'r', 'o', 'u', 'g', 'h', '\n',
        'b', 'r', 'e', 'a', 'k', 't', 'h', 'r', 'o', 'u', 'g', 'h', 's', '\n',
        'b', 'r', 'e', 'a', 'k', 'u', 'p', '\n',
        'b', 'r', 'e', 'a', 'k', 'u', 'p', 's', '\n',
        'b', 'r', 'e', 'a', 'k', 'w', 'a', 't', 'e', 'r', '\n',
        'b', 'r', 'e', 'a', 'k', 'w', 'a', 't', 'e', 'r', 's', '\n',
        'b', 'r', 'e', 'a', 'm', '\n',
        'b', 'r', 'e', 'a', 's', 't', '\n',
        'b', 'r', 'e', 'a', 's', 't', 'b', 'o', 'n', 'e', '\n',
        'b', 'r', 'e', 'a', 's', 't', 'e', 'd', '\n',
        'b', 'r', 'e', 'a', 's', 't', 'f', 'e', 'e', 'd', '\n',
        'b', 'r', 'e', 'a', 's', 't', 'f', 'e', 'e', 'd', 'i', 'n', 'g', '\n',
        'b', 'r', 'e', 'a', 's', 't', 'i', 'n', 'g', '\n',
        'b', 'r', 'e', 'a', 's', 't', 'p', 'l', 'a', 't', 'e', '\n',
        'b', 'r', 'e', 'a', 's', 't', 's', '\n',
        'b', 'r', 'e', 'a', 's', 't', 's', 't', 'r', 'o', 'k', 'e', '\n',
        'b', 'r', 'e', 'a', 't', 'h', '\n',
        'b', 'r', 'e', 'a', 't', 'h', 'a', 'b', 'l', 'e', '\n',
        'b', 'r', 'e', 'a', 't', 'h', 'a', 'l', 'y', 's', 'e', 'd', '\n',
        'b', 'r', 'e', 'a', 't', 'h', 'a', 'l', 'y', 's', 'e', 'r', '\n',
        'b', 'r', 'e', 'a', 't', 'h', 'a', 'l', 'y', 's', 'e', 'r', 's', '\n',
        'b', 'r', 'e', 'a', 't', 'h', 'e', '\n',
        'b', 'r', 'e', 'a', 't', 'h', 'e', 'd', '\n',
        'b', 'r', 'e', 'a', 't', 'h', 'e', 'r', '\n',
        'b', 'r', 'e', 'a', 't', 'h', 'e', 's', '\n',
        'b', 'r', 'e', 'a', 't', 'h', 'i', 'n', 'g', '\n',
        'b', 'r', 'e', 'a', 't', 'h', 'i', 'n', 'g', 's', '\n',
        'b', 'r', 'e', 'a', 't', 'h', 'i', 'n', 'g', 's', 'p', 'a', 'c', 'e', '\n',
        'b', 'r', 'e', 'a', 't', 'h', 'l', 'e', 's', 's', '\n',
        'b', 'r', 'e', 'a', 't', 'h', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'b', 'r', 'e', 'a', 't', 'h', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'b', 'r', 'e', 'a', 't', 'h', 's', '\n',
        'b', 'r', 'e', 'a', 't', 'h', 't', 'a', 'k', 'i', 'n', 'g', '\n',
        'b', 'r', 'e', 'a', 't', 'h', 't', 'a', 'k', 'i', 'n', 'g', 'l', 'y', '\n',
        'b', 'r', 'e', 'a', 't', 'h', 'y', '\n',
        'b', 'r', 'e', 'c', 'c', 'i', 'a', 's', '\n',
        'b', 'r', 'e', 'c', 'c', 'i', 'a', 't', 'e', 'd', '\n',
        'b', 'r', 'e', 'd', '\n',
        'b', 'r', 'e', 'e', 'c', 'h', '\n',
        'b', 'r', 'e', 'e', 'c', 'h', 'e', 's', '\n',
        'b', 'r', 'e', 'e', 'd', '\n',
        'b', 'r', 'e', 'e', 'd', 'e', 'r', '\n',
        'b', 'r', 'e', 'e', 'd', 'e', 'r', 's', '\n',
        'b', 'r', 'e', 'e', 'd', 'i', 'n', 'g', '\n',
        'b', 'r', 'e', 'e', 'd', 's', '\n',
        'b', 'r', 'e', 'e', 'z', 'e', '\n',
        'b', 'r', 'e', 'e', 'z', 'e', 'd', '\n',
        'b', 'r', 'e', 'e', 'z', 'e', 's', '\n',
        'b', 'r', 'e', 'e', 'z', 'i', 'e', 'r', '\n',
        'b', 'r', 'e', 'e', 'z', 'i', 'e', 's', 't', '\n',
        'b', 'r', 'e', 'e', 'z', 'i', 'l', 'y', '\n',
        'b', 'r', 'e', 'e', 'z', 'i', 'n', 'g', '\n',
        'b', 'r', 'e', 'e', 'z', 'y', '\n',
        'b', 'r', 'e', 't', 'h', 'r', 'e', 'n', '\n',
        'b', 'r', 'e', 't', 'o', 'n', '\n',
        'b', 'r', 'e', 'v', 'i', 'a', 'r', 'y', '\n',
        'b', 'r', 'e', 'v', 'i', 't', 'y', '\n',
        'b', 'r', 'e', 'w', '\n',
        'b', 'r', 'e', 'w', 'a', 'g', 'e', '\n',
        'b', 'r', 'e', 'w', 'e', 'd', '\n',
        'b', 'r', 'e', 'w', 'e', 'r', '\n',
        'b', 'r', 'e', 'w', 'e', 'r', 'i', 'e', 's', '\n',
        'b', 'r', 'e', 'w', 'e', 'r', 's', '\n',
        'b', 'r', 'e', 'w', 'e', 'r', 'y', '\n',
        'b', 'r', 'e', 'w', 'i', 'n', 'g', '\n',
        'b', 'r', 'e', 'w', 's', '\n',
        'b', 'r', 'i', 'a', 'r', '\n',
        'b', 'r', 'i', 'b', 'e', '\n',
        'b', 'r', 'i', 'b', 'e', 'd', '\n',
        'b', 'r', 'i', 'b', 'e', 'r', '\n',
        'b', 'r', 'i', 'b', 'e', 'r', 's', '\n',
        'b', 'r', 'i', 'b', 'e', 'r', 'y', '\n',
        'b', 'r', 'i', 'b', 'e', 's', '\n',
        'b', 'r', 'i', 'b', 'i', 'n', 'g', '\n',
        'b', 'r', 'i', 'c', 'a', 'b', 'r', 'a', 'c', '\n',
        'b', 'r', 'i', 'c', 'k', '\n',
        'b', 'r', 'i', 'c', 'k', 'b', 'a', 't', '\n',
        'b', 'r', 'i', 'c', 'k', 'b', 'a', 't', 's', '\n',
        'b', 'r', 'i', 'c', 'k', 'e', 'd', '\n',
        'b', 'r', 'i', 'c', 'k', 'i', 'n', 'g', '\n',
        'b', 'r', 'i', 'c', 'k', 'l', 'a', 'y', 'e', 'r', '\n',
        'b', 'r', 'i', 'c', 'k', 'l', 'a', 'y', 'e', 'r', 's', '\n',
        'b', 'r', 'i', 'c', 'k', 'l', 'a', 'y', 'i', 'n', 'g', '\n',
        'b', 'r', 'i', 'c', 'k', 'r', 'e', 'd', '\n',
        'b', 'r', 'i', 'c', 'k', 's', '\n',
        'b', 'r', 'i', 'c', 'k', 'w', 'o', 'r', 'k', '\n',
        'b', 'r', 'i', 'd', 'a', 'l', '\n',
        'b', 'r', 'i', 'd', 'a', 'l', 's', '\n',
        'b', 'r', 'i', 'd', 'e', '\n',
        'b', 'r', 'i', 'd', 'e', 'g', 'r', 'o', 'o', 'm', '\n',
        'b', 'r', 'i', 'd', 'e', 'g', 'r', 'o', 'o', 'm', 's', '\n',
        'b', 'r', 'i', 'd', 'e', 's', '\n',
        'b', 'r', 'i', 'd', 'e', 's', 'm', 'a', 'i', 'd', '\n',
        'b', 'r', 'i', 'd', 'e', 's', 'm', 'a', 'i', 'd', 's', '\n',
        'b', 'r', 'i', 'd', 'g', 'e', '\n',
        'b', 'r', 'i', 'd', 'g', 'e', 'b', 'u', 'i', 'l', 'd', 'i', 'n', 'g', '\n',
        'b', 'r', 'i', 'd', 'g', 'e', 'd', '\n',
        'b', 'r', 'i', 'd', 'g', 'e', 'h', 'e', 'a', 'd', '\n',
        'b', 'r', 'i', 'd', 'g', 'e', 's', '\n',
        'b', 'r', 'i', 'd', 'g', 'i', 'n', 'g', '\n',
        'b', 'r', 'i', 'd', 'l', 'e', '\n',
        'b', 'r', 'i', 'd', 'l', 'e', 'd', '\n',
        'b', 'r', 'i', 'd', 'l', 'e', 's', '\n',
        'b', 'r', 'i', 'd', 'l', 'e', 'w', 'a', 'y', '\n',
        'b', 'r', 'i', 'd', 'l', 'e', 'w', 'a', 'y', 's', '\n',
        'b', 'r', 'i', 'd', 'l', 'i', 'n', 'g', '\n',
        'b', 'r', 'i', 'e', 'f', '\n',
        'b', 'r', 'i', 'e', 'f', 'c', 'a', 's', 'e', '\n',
        'b', 'r', 'i', 'e', 'f', 'c', 'a', 's', 'e', 's', '\n',
        'b', 'r', 'i', 'e', 'f', 'e', 'd', '\n',
        'b', 'r', 'i', 'e', 'f', 'e', 'r', '\n',
        'b', 'r', 'i', 'e', 'f', 'e', 's', 't', '\n',
        'b', 'r', 'i', 'e', 'f', 'i', 'n', 'g', '\n',
        'b', 'r', 'i', 'e', 'f', 'i', 'n', 'g', 's', '\n',
        'b', 'r', 'i', 'e', 'f', 'l', 'y', '\n',
        'b', 'r', 'i', 'e', 'f', 's', '\n',
        'b', 'r', 'i', 'e', 'r', 's', '\n',
        'b', 'r', 'i', 'g', '\n',
        'b', 'r', 'i', 'g', 'a', 'd', 'e', '\n',
        'b', 'r', 'i', 'g', 'a', 'd', 'e', 's', '\n',
        'b', 'r', 'i', 'g', 'a', 'd', 'i', 'e', 'r', '\n',
        'b', 'r', 'i', 'g', 'a', 'd', 'i', 'e', 'r', 's', '\n',
        'b', 'r', 'i', 'g', 'a', 'n', 'd', '\n',
        'b', 'r', 'i', 'g', 'a', 'n', 'd', 's', '\n',
        'b', 'r', 'i', 'g', 'h', 't', '\n',
        'b', 'r', 'i', 'g', 'h', 't', 'e', 'n', '\n',
        'b', 'r', 'i', 'g', 'h', 't', 'e', 'n', 'e', 'd', '\n',
        'b', 'r', 'i', 'g', 'h', 't', 'e', 'n', 'i', 'n', 'g', '\n',
        'b', 'r', 'i', 'g', 'h', 't', 'e', 'n', 's', '\n',
        'b', 'r', 'i', 'g', 'h', 't', 'e', 'r', '\n',
        'b', 'r', 'i', 'g', 'h', 't', 'e', 's', 't', '\n',
        'b', 'r', 'i', 'g', 'h', 't', 'e', 'y', 'e', 'd', '\n',
        'b', 'r', 'i', 'g', 'h', 't', 'l', 'y', '\n',
        'b', 'r', 'i', 'g', 'h', 't', 'n', 'e', 's', 's', '\n',
        'b', 'r', 'i', 'g', 'h', 't', 'n', 'e', 's', 's', 'e', 's', '\n',
        'b', 'r', 'i', 'g', 'h', 't', 'o', 'n', '\n',
        'b', 'r', 'i', 'l', 'l', 'i', 'a', 'n', 'c', 'e', '\n',
        'b', 'r', 'i', 'l', 'l', 'i', 'a', 'n', 'c', 'y', '\n',
        'b', 'r', 'i', 'l', 'l', 'i', 'a', 'n', 't', '\n',
        'b', 'r', 'i', 'l', 'l', 'i', 'a', 'n', 't', 'l', 'y', '\n',
        'b', 'r', 'i', 'm', '\n',
        'b', 'r', 'i', 'm', 'm', 'e', 'd', '\n',
        'b', 'r', 'i', 'm', 'm', 'i', 'n', 'g', '\n',
        'b', 'r', 'i', 'm', 's', '\n',
        'b', 'r', 'i', 'm', 's', 't', 'o', 'n', 'e', '\n',
        'b', 'r', 'i', 'n', 'd', 'l', 'e', 'd', '\n',
        'b', 'r', 'i', 'n', 'e', '\n',
        'b', 'r', 'i', 'n', 'e', 's', '\n',
        'b', 'r', 'i', 'n', 'g', '\n',
        'b', 'r', 'i', 'n', 'g', 'e', 'r', '\n',
        'b', 'r', 'i', 'n', 'g', 'i', 'n', 'g', '\n',
        'b', 'r', 'i', 'n', 'g', 's', '\n',
        'b', 'r', 'i', 'n', 'k', '\n',
        'b', 'r', 'i', 'n', 'k', 'm', 'a', 'n', 's', 'h', 'i', 'p', '\n',
        'b', 'r', 'i', 'n', 'k', 's', '\n',
        'b', 'r', 'i', 'n', 'y', '\n',
        'b', 'r', 'i', 'o', '\n',
        'b', 'r', 'i', 'o', 'c', 'h', 'e', '\n',
        'b', 'r', 'i', 'q', 'u', 'e', 't', 't', 'e', 's', '\n',
        'b', 'r', 'i', 's', 'b', 'a', 'n', 'e', '\n',
        'b', 'r', 'i', 's', 'k', '\n',
        'b', 'r', 'i', 's', 'k', 'e', 'r', '\n',
        'b', 'r', 'i', 's', 'k', 'e', 's', 't', '\n',
        'b', 'r', 'i', 's', 'k', 'l', 'y', '\n',
        'b', 'r', 'i', 's', 'k', 'n', 'e', 's', 's', '\n',
        'b', 'r', 'i', 's', 't', 'l', 'e', '\n',
        'b', 'r', 'i', 's', 't', 'l', 'e', 'd', '\n',
        'b', 'r', 'i', 's', 't', 'l', 'e', 's', '\n',
        'b', 'r', 'i', 's', 't', 'l', 'i', 'n', 'g', '\n',
        'b', 'r', 'i', 's', 't', 'l', 'y', '\n',
        'b', 'r', 'i', 't', '\n',
        'b', 'r', 'i', 't', 'a', 'i', 'n', '\n',
        'b', 'r', 'i', 't', 'i', 's', 'h', '\n',
        'b', 'r', 'i', 't', 'o', 'n', 's', '\n',
        'b', 'r', 'i', 't', 't', 'l', 'e', '\n',
        'b', 'r', 'i', 't', 't', 'l', 'e', 'n', 'e', 's', 's', '\n',
        'b', 'r', 'o', 'a', 'c', 'h', '\n',
        'b', 'r', 'o', 'a', 'c', 'h', 'e', 'd', '\n',
        'b', 'r', 'o', 'a', 'c', 'h', 'e', 's', '\n',
        'b', 'r', 'o', 'a', 'c', 'h', 'i', 'n', 'g', '\n',
        'b', 'r', 'o', 'a', 'd', '\n',
        'b', 'r', 'o', 'a', 'd', 'b', 'a', 'n', 'd', '\n',
        'b', 'r', 'o', 'a', 'd', 'c', 'a', 's', 't', '\n',
        'b', 'r', 'o', 'a', 'd', 'c', 'a', 's', 't', 'e', 'r', '\n',
        'b', 'r', 'o', 'a', 'd', 'c', 'a', 's', 't', 'e', 'r', 's', '\n',
        'b', 'r', 'o', 'a', 'd', 'c', 'a', 's', 't', 'i', 'n', 'g', '\n',
        'b', 'r', 'o', 'a', 'd', 'c', 'a', 's', 't', 's', '\n',
        'b', 'r', 'o', 'a', 'd', 'e', 'n', '\n',
        'b', 'r', 'o', 'a', 'd', 'e', 'n', 'e', 'd', '\n',
        'b', 'r', 'o', 'a', 'd', 'e', 'n', 'i', 'n', 'g', '\n',
        'b', 'r', 'o', 'a', 'd', 'e', 'n', 's', '\n',
        'b', 'r', 'o', 'a', 'd', 'e', 'r', '\n',
        'b', 'r', 'o', 'a', 'd', 'e', 's', 't', '\n',
        'b', 'r', 'o', 'a', 'd', 'l', 'e', 'a', 'v', 'e', 'd', '\n',
        'b', 'r', 'o', 'a', 'd', 'l', 'o', 'o', 'm', '\n',
        'b', 'r', 'o', 'a', 'd', 'l', 'y', '\n',
        'b', 'r', 'o', 'a', 'd', 'm', 'i', 'n', 'd', 'e', 'd', '\n',
        'b', 'r', 'o', 'a', 'd', 'm', 'i', 'n', 'd', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'b', 'r', 'o', 'a', 'd', 'n', 'e', 's', 's', '\n',
        'b', 'r', 'o', 'a', 'd', 's', 'h', 'e', 'e', 't', '\n',
        'b', 'r', 'o', 'a', 'd', 's', 'h', 'e', 'e', 't', 's', '\n',
        'b', 'r', 'o', 'a', 'd', 's', 'i', 'd', 'e', '\n',
        'b', 'r', 'o', 'a', 'd', 's', 'i', 'd', 'e', 's', '\n',
        'b', 'r', 'o', 'a', 'd', 's', 'w', 'o', 'r', 'd', '\n',
        'b', 'r', 'o', 'a', 'd', 's', 'w', 'o', 'r', 'd', 's', '\n',
        'b', 'r', 'o', 'a', 'd', 'w', 'a', 'y', '\n',
        'b', 'r', 'o', 'c', 'a', 'd', 'e', '\n',
        'b', 'r', 'o', 'c', 'a', 'd', 'e', 'd', '\n',
        'b', 'r', 'o', 'c', 'c', 'o', 'l', 'i', '\n',
        'b', 'r', 'o', 'c', 'h', 'u', 'r', 'e', '\n',
        'b', 'r', 'o', 'c', 'h', 'u', 'r', 'e', 's', '\n',
        'b', 'r', 'o', 'g', 'u', 'e', '\n',
        'b', 'r', 'o', 'g', 'u', 'e', 's', '\n',
        'b', 'r', 'o', 'i', 'l', '\n',
        'b', 'r', 'o', 'i', 'l', 'e', 'd', '\n',
        'b', 'r', 'o', 'i', 'l', 'e', 'r', '\n',
        'b', 'r', 'o', 'i', 'l', 'i', 'n', 'g', '\n',
        'b', 'r', 'o', 'i', 'l', 's', '\n',
        'b', 'r', 'o', 'k', 'e', '\n',
        'b', 'r', 'o', 'k', 'e', 'n', '\n',
        'b', 'r', 'o', 'k', 'e', 'n', 'h', 'e', 'a', 'r', 't', 'e', 'd', '\n',
        'b', 'r', 'o', 'k', 'e', 'n', 'l', 'y', '\n',
        'b', 'r', 'o', 'k', 'e', 'r', '\n',
        'b', 'r', 'o', 'k', 'e', 'r', 'a', 'g', 'e', '\n',
        'b', 'r', 'o', 'k', 'e', 'r', 'e', 'd', '\n',
        'b', 'r', 'o', 'k', 'e', 'r', 's', '\n',
        'b', 'r', 'o', 'k', 'i', 'n', 'g', '\n',
        'b', 'r', 'o', 'm', 'i', 'd', 'e', '\n',
        'b', 'r', 'o', 'm', 'i', 'd', 'e', 's', '\n',
        'b', 'r', 'o', 'm', 'i', 'n', 'e', '\n',
        'b', 'r', 'o', 'n', 'c', 'h', 'i', '\n',
        'b', 'r', 'o', 'n', 'c', 'h', 'i', 'a', 'l', '\n',
        'b', 'r', 'o', 'n', 'c', 'h', 'i', 't', 'i', 's', '\n',
        'b', 'r', 'o', 'n', 'c', 'o', '\n',
        'b', 'r', 'o', 'n', 't', 'o', 's', 'a', 'u', 'r', 'u', 's', '\n',
        'b', 'r', 'o', 'n', 'z', 'e', '\n',
        'b', 'r', 'o', 'n', 'z', 'e', 'd', '\n',
        'b', 'r', 'o', 'n', 'z', 'e', 's', '\n',
        'b', 'r', 'o', 'o', 'c', 'h', '\n',
        'b', 'r', 'o', 'o', 'c', 'h', 'e', 's', '\n',
        'b', 'r', 'o', 'o', 'd', '\n',
        'b', 'r', 'o', 'o', 'd', 'e', 'd', '\n',
        'b', 'r', 'o', 'o', 'd', 'i', 'n', 'e', 's', 's', '\n',
        'b', 'r', 'o', 'o', 'd', 'i', 'n', 'g', '\n',
        'b', 'r', 'o', 'o', 'd', 'i', 'n', 'g', 'l', 'y', '\n',
        'b', 'r', 'o', 'o', 'd', 's', '\n',
        'b', 'r', 'o', 'o', 'd', 'y', '\n',
        'b', 'r', 'o', 'o', 'k', '\n',
        'b', 'r', 'o', 'o', 'k', 'l', 'y', 'n', '\n',
        'b', 'r', 'o', 'o', 'k', 's', '\n',
        'b', 'r', 'o', 'o', 'm', '\n',
        'b', 'r', 'o', 'o', 'm', 's', '\n',
        'b', 'r', 'o', 'o', 'm', 's', 't', 'i', 'c', 'k', '\n',
        'b', 'r', 'o', 'o', 'm', 's', 't', 'i', 'c', 'k', 's', '\n',
        'b', 'r', 'o', 't', 'h', '\n',
        'b', 'r', 'o', 't', 'h', 'e', 'l', '\n',
        'b', 'r', 'o', 't', 'h', 'e', 'l', 's', '\n',
        'b', 'r', 'o', 't', 'h', 'e', 'r', '\n',
        'b', 'r', 'o', 't', 'h', 'e', 'r', 'h', 'o', 'o', 'd', '\n',
        'b', 'r', 'o', 't', 'h', 'e', 'r', 'i', 'n', 'l', 'a', 'w', '\n',
        'b', 'r', 'o', 't', 'h', 'e', 'r', 'l', 'y', '\n',
        'b', 'r', 'o', 't', 'h', 'e', 'r', 's', '\n',
        'b', 'r', 'o', 't', 'h', 'e', 'r', 's', 'i', 'n', 'l', 'a', 'w', '\n',
        'b', 'r', 'o', 't', 'h', 's', '\n',
        'b', 'r', 'o', 'u', 'g', 'h', 't', '\n',
        'b', 'r', 'o', 'u', 'h', 'a', 'h', 'a', '\n',
        'b', 'r', 'o', 'w', '\n',
        'b', 'r', 'o', 'w', 'b', 'e', 'a', 't', '\n',
        'b', 'r', 'o', 'w', 'b', 'e', 'a', 't', 'e', 'n', '\n',
        'b', 'r', 'o', 'w', 'b', 'e', 'a', 't', 'i', 'n', 'g', '\n',
        'b', 'r', 'o', 'w', 'n', '\n',
        'b', 'r', 'o', 'w', 'n', 'e', 'd', '\n',
        'b', 'r', 'o', 'w', 'n', 'e', 'r', '\n',
        'b', 'r', 'o', 'w', 'n', 'e', 's', 't', '\n',
        'b', 'r', 'o', 'w', 'n', 'i', 'e', '\n',
        'b', 'r', 'o', 'w', 'n', 'i', 'e', 's', '\n',
        'b', 'r', 'o', 'w', 'n', 'i', 'n', 'g', '\n',
        'b', 'r', 'o', 'w', 'n', 'i', 's', 'h', '\n',
        'b', 'r', 'o', 'w', 'n', 'n', 'e', 's', 's', '\n',
        'b', 'r', 'o', 'w', 'n', 's', '\n',
        'b', 'r', 'o', 'w', 's', '\n',
        'b', 'r', 'o', 'w', 's', 'e', '\n',
        'b', 'r', 'o', 'w', 's', 'e', 'd', '\n',
        'b', 'r', 'o', 'w', 's', 'e', 'r', '\n',
        'b', 'r', 'o', 'w', 's', 'e', 'r', 's', '\n',
        'b', 'r', 'o', 'w', 's', 'e', 's', '\n',
        'b', 'r', 'o', 'w', 's', 'i', 'n', 'g', '\n',
        'b', 'r', 'u', 'i', 's', 'e', '\n',
        'b', 'r', 'u', 'i', 's', 'e', 'd', '\n',
        'b', 'r', 'u', 'i', 's', 'e', 'r', '\n',
        'b', 'r', 'u', 'i', 's', 'e', 'r', 's', '\n',
        'b', 'r', 'u', 'i', 's', 'e', 's', '\n',
        'b', 'r', 'u', 'i', 's', 'i', 'n', 'g', '\n',
        'b', 'r', 'u', 'n', 'c', 'h', '\n',
        'b', 'r', 'u', 'n', 'c', 'h', 'e', 's', '\n',
        'b', 'r', 'u', 'n', 'e', 'i', '\n',
        'b', 'r', 'u', 'n', 'e', 't', '\n',
        'b', 'r', 'u', 'n', 'e', 't', 's', '\n',
        'b', 'r', 'u', 'n', 'e', 't', 't', 'e', '\n',
        'b', 'r', 'u', 'n', 'e', 't', 't', 'e', 's', '\n',
        'b', 'r', 'u', 'n', 't', '\n',
        'b', 'r', 'u', 'n', 't', 's', '\n',
        'b', 'r', 'u', 's', 'h', '\n',
        'b', 'r', 'u', 's', 'h', 'e', 'd', '\n',
        'b', 'r', 'u', 's', 'h', 'e', 's', '\n',
        'b', 'r', 'u', 's', 'h', 'i', 'n', 'g', '\n',
        'b', 'r', 'u', 's', 'h', 'o', 'f', 'f', '\n',
        'b', 'r', 'u', 's', 'h', 'u', 'p', '\n',
        'b', 'r', 'u', 's', 'h', 'w', 'o', 'o', 'd', '\n',
        'b', 'r', 'u', 's', 'h', 'w', 'o', 'r', 'k', '\n',
        'b', 'r', 'u', 's', 'h', 'y', '\n',
        'b', 'r', 'u', 's', 'q', 'u', 'e', '\n',
        'b', 'r', 'u', 's', 'q', 'u', 'e', 'l', 'y', '\n',
        'b', 'r', 'u', 's', 'q', 'u', 'e', 'n', 'e', 's', 's', '\n',
        'b', 'r', 'u', 's', 's', 'e', 'l', 's', '\n',
        'b', 'r', 'u', 't', 'a', 'l', '\n',
        'b', 'r', 'u', 't', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'b', 'r', 'u', 't', 'a', 'l', 'i', 's', 'e', '\n',
        'b', 'r', 'u', 't', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'b', 'r', 'u', 't', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'b', 'r', 'u', 't', 'a', 'l', 'i', 's', 'm', '\n',
        'b', 'r', 'u', 't', 'a', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'b', 'r', 'u', 't', 'a', 'l', 'i', 't', 'y', '\n',
        'b', 'r', 'u', 't', 'a', 'l', 'l', 'y', '\n',
        'b', 'r', 'u', 't', 'e', '\n',
        'b', 'r', 'u', 't', 'e', 's', '\n',
        'b', 'r', 'u', 't', 'i', 's', 'h', '\n',
        'b', 'r', 'u', 't', 'i', 's', 'h', 'n', 'e', 's', 's', '\n',
        'b', 'r', 'u', 't', 'u', 's', '\n',
        'b', 'u', 'b', '\n',
        'b', 'u', 'b', 'b', 'l', 'e', '\n',
        'b', 'u', 'b', 'b', 'l', 'e', 'd', '\n',
        'b', 'u', 'b', 'b', 'l', 'e', 'g', 'u', 'm', '\n',
        'b', 'u', 'b', 'b', 'l', 'e', 's', '\n',
        'b', 'u', 'b', 'b', 'l', 'i', 'e', 'r', '\n',
        'b', 'u', 'b', 'b', 'l', 'i', 'e', 's', 't', '\n',
        'b', 'u', 'b', 'b', 'l', 'i', 'n', 'g', '\n',
        'b', 'u', 'b', 'b', 'l', 'y', '\n',
        'b', 'u', 'b', 'o', 'n', 'i', 'c', '\n',
        'b', 'u', 'c', 'c', 'a', 'n', 'e', 'e', 'r', '\n',
        'b', 'u', 'c', 'c', 'a', 'n', 'e', 'e', 'r', 'i', 'n', 'g', '\n',
        'b', 'u', 'c', 'c', 'a', 'n', 'e', 'e', 'r', 's', '\n',
        'b', 'u', 'c', 'k', '\n',
        'b', 'u', 'c', 'k', 'e', 'd', '\n',
        'b', 'u', 'c', 'k', 'e', 't', '\n',
        'b', 'u', 'c', 'k', 'e', 't', 'f', 'u', 'l', '\n',
        'b', 'u', 'c', 'k', 'e', 't', 'f', 'u', 'l', 's', '\n',
        'b', 'u', 'c', 'k', 'e', 't', 'i', 'n', 'g', '\n',
        'b', 'u', 'c', 'k', 'e', 't', 's', '\n',
        'b', 'u', 'c', 'k', 'i', 'n', 'g', '\n',
        'b', 'u', 'c', 'k', 'l', 'e', '\n',
        'b', 'u', 'c', 'k', 'l', 'e', 'd', '\n',
        'b', 'u', 'c', 'k', 'l', 'e', 'r', '\n',
        'b', 'u', 'c', 'k', 'l', 'e', 'r', 's', '\n',
        'b', 'u', 'c', 'k', 'l', 'e', 's', '\n',
        'b', 'u', 'c', 'k', 'l', 'i', 'n', 'g', '\n',
        'b', 'u', 'c', 'k', 'm', 'i', 'n', 's', 't', 'e', 'r', 'f', 'u', 'l', 'l', 'e', 'r', 'e', 'n', 'e', '\n',
        'b', 'u', 'c', 'k', 'p', 'a', 's', 's', 'i', 'n', 'g', '\n',
        'b', 'u', 'c', 'k', 's', '\n',
        'b', 'u', 'c', 'k', 's', 'h', 'o', 't', '\n',
        'b', 'u', 'c', 'k', 's', 'k', 'i', 'n', '\n',
        'b', 'u', 'c', 'o', 'l', 'i', 'c', '\n',
        'b', 'u', 'd', '\n',
        'b', 'u', 'd', 'a', 'p', 'e', 's', 't', '\n',
        'b', 'u', 'd', 'd', 'e', 'd', '\n',
        'b', 'u', 'd', 'd', 'h', 'i', 's', 'm', '\n',
        'b', 'u', 'd', 'd', 'h', 'i', 's', 't', '\n',
        'b', 'u', 'd', 'd', 'i', 'e', 's', '\n',
        'b', 'u', 'd', 'd', 'i', 'n', 'g', '\n',
        'b', 'u', 'd', 'd', 'i', 'n', 'g', 's', '\n',
        'b', 'u', 'd', 'd', 'y', '\n',
        'b', 'u', 'd', 'g', 'e', '\n',
        'b', 'u', 'd', 'g', 'e', 'd', '\n',
        'b', 'u', 'd', 'g', 'e', 'r', 'i', 'g', 'a', 'r', '\n',
        'b', 'u', 'd', 'g', 'e', 't', '\n',
        'b', 'u', 'd', 'g', 'e', 't', 'a', 'r', 'y', '\n',
        'b', 'u', 'd', 'g', 'e', 't', 'e', 'd', '\n',
        'b', 'u', 'd', 'g', 'e', 't', 'i', 'n', 'g', '\n',
        'b', 'u', 'd', 'g', 'e', 't', 's', '\n',
        'b', 'u', 'd', 'g', 'i', 'e', '\n',
        'b', 'u', 'd', 'g', 'i', 'e', 's', '\n',
        'b', 'u', 'd', 'g', 'i', 'n', 'g', '\n',
        'b', 'u', 'd', 's', '\n',
        'b', 'u', 'f', 'f', '\n',
        'b', 'u', 'f', 'f', 'a', 'l', 'o', '\n',
        'b', 'u', 'f', 'f', 'e', 'r', '\n',
        'b', 'u', 'f', 'f', 'e', 'r', 'e', 'd', '\n',
        'b', 'u', 'f', 'f', 'e', 'r', 'i', 'n', 'g', '\n',
        'b', 'u', 'f', 'f', 'e', 'r', 's', '\n',
        'b', 'u', 'f', 'f', 'e', 't', '\n',
        'b', 'u', 'f', 'f', 'e', 't', 'e', 'd', '\n',
        'b', 'u', 'f', 'f', 'e', 't', 'i', 'n', 'g', '\n',
        'b', 'u', 'f', 'f', 'e', 't', 'i', 'n', 'g', 's', '\n',
        'b', 'u', 'f', 'f', 'e', 't', 's', '\n',
        'b', 'u', 'f', 'f', 'i', 'n', 'g', '\n',
        'b', 'u', 'f', 'f', 'o', 'o', 'n', '\n',
        'b', 'u', 'f', 'f', 'o', 'o', 'n', 'e', 'r', 'y', '\n',
        'b', 'u', 'f', 'f', 'o', 'o', 'n', 's', '\n',
        'b', 'u', 'f', 'f', 's', '\n',
        'b', 'u', 'g', '\n',
        'b', 'u', 'g', 'b', 'e', 'a', 'r', '\n',
        'b', 'u', 'g', 'b', 'e', 'a', 'r', 's', '\n',
        'b', 'u', 'g', 'e', 'y', 'e', 'd', '\n',
        'b', 'u', 'g', 'g', 'e', 'd', '\n',
        'b', 'u', 'g', 'g', 'e', 'r', '\n',
        'b', 'u', 'g', 'g', 'e', 'r', 'e', 'd', '\n',
        'b', 'u', 'g', 'g', 'e', 'r', 'i', 'n', 'g', '\n',
        'b', 'u', 'g', 'g', 'e', 'r', 's', '\n',
        'b', 'u', 'g', 'g', 'e', 'r', 'y', '\n',
        'b', 'u', 'g', 'g', 'i', 'e', 's', '\n',
        'b', 'u', 'g', 'g', 'i', 'n', 'g', '\n',
        'b', 'u', 'g', 'g', 'y', '\n',
        'b', 'u', 'g', 'l', 'e', '\n',
        'b', 'u', 'g', 'l', 'e', 'r', '\n',
        'b', 'u', 'g', 'l', 'e', 'r', 's', '\n',
        'b', 'u', 'g', 'l', 'e', 's', '\n',
        'b', 'u', 'g', 's', '\n',
        'b', 'u', 'i', 'l', 'd', '\n',
        'b', 'u', 'i', 'l', 'd', 'e', 'r', '\n',
        'b', 'u', 'i', 'l', 'd', 'e', 'r', 's', '\n',
        'b', 'u', 'i', 'l', 'd', 'i', 'n', 'g', '\n',
        'b', 'u', 'i', 'l', 'd', 'i', 'n', 'g', 's', '\n',
        'b', 'u', 'i', 'l', 'd', 's', '\n',
        'b', 'u', 'i', 'l', 'd', 'u', 'p', '\n',
        'b', 'u', 'i', 'l', 'd', 'u', 'p', 's', '\n',
        'b', 'u', 'i', 'l', 't', '\n',
        'b', 'u', 'i', 'l', 't', 'i', 'n', '\n',
        'b', 'u', 'i', 'l', 't', 'u', 'p', '\n',
        'b', 'u', 'l', 'b', '\n',
        'b', 'u', 'l', 'b', 'o', 'u', 's', '\n',
        'b', 'u', 'l', 'b', 's', '\n',
        'b', 'u', 'l', 'g', 'a', 'r', 'i', 'a', '\n',
        'b', 'u', 'l', 'g', 'e', '\n',
        'b', 'u', 'l', 'g', 'e', 'd', '\n',
        'b', 'u', 'l', 'g', 'e', 's', '\n',
        'b', 'u', 'l', 'g', 'i', 'n', 'g', '\n',
        'b', 'u', 'l', 'g', 'y', '\n',
        'b', 'u', 'l', 'i', 'm', 'i', 'a', '\n',
        'b', 'u', 'l', 'i', 'm', 'i', 'c', '\n',
        'b', 'u', 'l', 'k', '\n',
        'b', 'u', 'l', 'k', 'h', 'e', 'a', 'd', '\n',
        'b', 'u', 'l', 'k', 'h', 'e', 'a', 'd', 's', '\n',
        'b', 'u', 'l', 'k', 'i', 'e', 'r', '\n',
        'b', 'u', 'l', 'k', 'i', 'e', 's', 't', '\n',
        'b', 'u', 'l', 'k', 's', '\n',
        'b', 'u', 'l', 'k', 'y', '\n',
        'b', 'u', 'l', 'l', '\n',
        'b', 'u', 'l', 'l', 'd', 'o', 'g', '\n',
        'b', 'u', 'l', 'l', 'd', 'o', 'g', 's', '\n',
        'b', 'u', 'l', 'l', 'd', 'o', 'z', 'e', '\n',
        'b', 'u', 'l', 'l', 'd', 'o', 'z', 'e', 'd', '\n',
        'b', 'u', 'l', 'l', 'd', 'o', 'z', 'e', 'r', '\n',
        'b', 'u', 'l', 'l', 'd', 'o', 'z', 'e', 'r', 's', '\n',
        'b', 'u', 'l', 'l', 'd', 'o', 'z', 'i', 'n', 'g', '\n',
        'b', 'u', 'l', 'l', 'e', 't', '\n',
        'b', 'u', 'l', 'l', 'e', 't', 'i', 'n', '\n',
        'b', 'u', 'l', 'l', 'e', 't', 'i', 'n', 's', '\n',
        'b', 'u', 'l', 'l', 'e', 't', 'p', 'r', 'o', 'o', 'f', '\n',
        'b', 'u', 'l', 'l', 'e', 't', 's', '\n',
        'b', 'u', 'l', 'l', 'f', 'i', 'g', 'h', 't', '\n',
        'b', 'u', 'l', 'l', 'f', 'i', 'g', 'h', 't', 'i', 'n', 'g', '\n',
        'b', 'u', 'l', 'l', 'f', 'i', 'n', 'c', 'h', '\n',
        'b', 'u', 'l', 'l', 'f', 'r', 'o', 'g', '\n',
        'b', 'u', 'l', 'l', 'i', 'e', 'd', '\n',
        'b', 'u', 'l', 'l', 'i', 'e', 's', '\n',
        'b', 'u', 'l', 'l', 'i', 'o', 'n', '\n',
        'b', 'u', 'l', 'l', 'i', 's', 'h', '\n',
        'b', 'u', 'l', 'l', 'o', 'c', 'k', '\n',
        'b', 'u', 'l', 'l', 'o', 'c', 'k', 's', '\n',
        'b', 'u', 'l', 'l', 's', '\n',
        'b', 'u', 'l', 'l', 'y', '\n',
        'b', 'u', 'l', 'l', 'y', 'i', 'n', 'g', '\n',
        'b', 'u', 'l', 'r', 'u', 's', 'h', 'e', 's', '\n',
        'b', 'u', 'l', 'w', 'a', 'r', 'k', '\n',
        'b', 'u', 'l', 'w', 'a', 'r', 'k', 's', '\n',
        'b', 'u', 'm', '\n',
        'b', 'u', 'm', 'b', 'l', 'e', '\n',
        'b', 'u', 'm', 'b', 'l', 'e', 'd', '\n',
        'b', 'u', 'm', 'b', 'l', 'e', 'r', '\n',
        'b', 'u', 'm', 'b', 'l', 'e', 'r', 's', '\n',
        'b', 'u', 'm', 'b', 'l', 'e', 's', '\n',
        'b', 'u', 'm', 'b', 'l', 'i', 'n', 'g', '\n',
        'b', 'u', 'm', 'p', '\n',
        'b', 'u', 'm', 'p', 'e', 'd', '\n',
        'b', 'u', 'm', 'p', 'e', 'r', '\n',
        'b', 'u', 'm', 'p', 'e', 'r', 's', '\n',
        'b', 'u', 'm', 'p', 'i', 'e', 'r', '\n',
        'b', 'u', 'm', 'p', 'i', 'e', 's', 't', '\n',
        'b', 'u', 'm', 'p', 'i', 'n', 'g', '\n',
        'b', 'u', 'm', 'p', 'k', 'i', 'n', '\n',
        'b', 'u', 'm', 'p', 'k', 'i', 'n', 's', '\n',
        'b', 'u', 'm', 'p', 's', '\n',
        'b', 'u', 'm', 'p', 't', 'i', 'o', 'u', 's', '\n',
        'b', 'u', 'm', 'p', 'y', '\n',
        'b', 'u', 'm', 's', '\n',
        'b', 'u', 'n', '\n',
        'b', 'u', 'n', 'c', 'h', '\n',
        'b', 'u', 'n', 'c', 'h', 'e', 'd', '\n',
        'b', 'u', 'n', 'c', 'h', 'e', 's', '\n',
        'b', 'u', 'n', 'c', 'h', 'i', 'n', 'g', '\n',
        'b', 'u', 'n', 'd', 'l', 'e', '\n',
        'b', 'u', 'n', 'd', 'l', 'e', 'd', '\n',
        'b', 'u', 'n', 'd', 'l', 'e', 's', '\n',
        'b', 'u', 'n', 'd', 'l', 'i', 'n', 'g', '\n',
        'b', 'u', 'n', 'g', '\n',
        'b', 'u', 'n', 'g', 'a', 'l', 'o', 'w', '\n',
        'b', 'u', 'n', 'g', 'a', 'l', 'o', 'w', 's', '\n',
        'b', 'u', 'n', 'g', 'e', 'e', '\n',
        'b', 'u', 'n', 'g', 'l', 'e', '\n',
        'b', 'u', 'n', 'g', 'l', 'e', 'd', '\n',
        'b', 'u', 'n', 'g', 'l', 'e', 'r', '\n',
        'b', 'u', 'n', 'g', 'l', 'e', 'r', 's', '\n',
        'b', 'u', 'n', 'g', 'l', 'e', 's', '\n',
        'b', 'u', 'n', 'g', 'l', 'i', 'n', 'g', '\n',
        'b', 'u', 'n', 'i', 'o', 'n', '\n',
        'b', 'u', 'n', 'i', 'o', 'n', 's', '\n',
        'b', 'u', 'n', 'k', '\n',
        'b', 'u', 'n', 'k', 'e', 'd', '\n',
        'b', 'u', 'n', 'k', 'e', 'r', '\n',
        'b', 'u', 'n', 'k', 'e', 'r', 'e', 'd', '\n',
        'b', 'u', 'n', 'k', 'e', 'r', 's', '\n',
        'b', 'u', 'n', 'k', 's', '\n',
        'b', 'u', 'n', 'k', 'u', 'm', '\n',
        'b', 'u', 'n', 'n', 'i', 'e', 's', '\n',
        'b', 'u', 'n', 'n', 'y', '\n',
        'b', 'u', 'n', 's', '\n',
        'b', 'u', 'n', 't', 'i', 'n', 'g', '\n',
        'b', 'u', 'n', 'y', 'a', 'n', '\n',
        'b', 'u', 'o', 'y', '\n',
        'b', 'u', 'o', 'y', 'a', 'n', 'c', 'y', '\n',
        'b', 'u', 'o', 'y', 'a', 'n', 't', '\n',
        'b', 'u', 'o', 'y', 'a', 'n', 't', 'l', 'y', '\n',
        'b', 'u', 'o', 'y', 'e', 'd', '\n',
        'b', 'u', 'o', 'y', 's', '\n',
        'b', 'u', 'r', '\n',
        'b', 'u', 'r', 'b', 'l', 'e', '\n',
        'b', 'u', 'r', 'b', 'l', 'e', 'd', '\n',
        'b', 'u', 'r', 'b', 'l', 'e', 's', '\n',
        'b', 'u', 'r', 'b', 'l', 'i', 'n', 'g', '\n',
        'b', 'u', 'r', 'd', 'e', 'n', '\n',
        'b', 'u', 'r', 'd', 'e', 'n', 'e', 'd', '\n',
        'b', 'u', 'r', 'd', 'e', 'n', 'i', 'n', 'g', '\n',
        'b', 'u', 'r', 'd', 'e', 'n', 's', '\n',
        'b', 'u', 'r', 'd', 'e', 'n', 's', 'o', 'm', 'e', '\n',
        'b', 'u', 'r', 'd', 'o', 'c', 'k', '\n',
        'b', 'u', 'r', 'e', 'a', 'u', '\n',
        'b', 'u', 'r', 'e', 'a', 'u', 'c', 'r', 'a', 'c', 'i', 'e', 's', '\n',
        'b', 'u', 'r', 'e', 'a', 'u', 'c', 'r', 'a', 'c', 'y', '\n',
        'b', 'u', 'r', 'e', 'a', 'u', 'c', 'r', 'a', 't', '\n',
        'b', 'u', 'r', 'e', 'a', 'u', 'c', 'r', 'a', 't', 'i', 'c', '\n',
        'b', 'u', 'r', 'e', 'a', 'u', 'c', 'r', 'a', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'b', 'u', 'r', 'e', 'a', 'u', 'c', 'r', 'a', 't', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'b', 'u', 'r', 'e', 'a', 'u', 'c', 'r', 'a', 't', 's', '\n',
        'b', 'u', 'r', 'e', 'a', 'u', 's', '\n',
        'b', 'u', 'r', 'e', 'a', 'u', 'x', '\n',
        'b', 'u', 'r', 'e', 't', 't', 'e', '\n',
        'b', 'u', 'r', 'g', '\n',
        'b', 'u', 'r', 'g', 'e', 'o', 'n', '\n',
        'b', 'u', 'r', 'g', 'e', 'o', 'n', 'e', 'd', '\n',
        'b', 'u', 'r', 'g', 'e', 'o', 'n', 'i', 'n', 'g', '\n',
        'b', 'u', 'r', 'g', 'e', 'o', 'n', 's', '\n',
        'b', 'u', 'r', 'g', 'e', 'r', '\n',
        'b', 'u', 'r', 'g', 'e', 'r', 's', '\n',
        'b', 'u', 'r', 'g', 'h', 'e', 'r', 's', '\n',
        'b', 'u', 'r', 'g', 'l', 'a', 'r', '\n',
        'b', 'u', 'r', 'g', 'l', 'a', 'r', 'i', 'e', 's', '\n',
        'b', 'u', 'r', 'g', 'l', 'a', 'r', 's', '\n',
        'b', 'u', 'r', 'g', 'l', 'a', 'r', 'y', '\n',
        'b', 'u', 'r', 'g', 'l', 'e', '\n',
        'b', 'u', 'r', 'g', 'l', 'e', 'd', '\n',
        'b', 'u', 'r', 'g', 'l', 'e', 's', '\n',
        'b', 'u', 'r', 'g', 'l', 'i', 'n', 'g', '\n',
        'b', 'u', 'r', 'g', 'u', 'n', 'd', 'y', '\n',
        'b', 'u', 'r', 'i', 'a', 'l', '\n',
        'b', 'u', 'r', 'i', 'a', 'l', 's', '\n',
        'b', 'u', 'r', 'i', 'e', 'd', '\n',
        'b', 'u', 'r', 'i', 'e', 's', '\n',
        'b', 'u', 'r', 'l', 'e', 's', 'q', 'u', 'e', '\n',
        'b', 'u', 'r', 'l', 'e', 's', 'q', 'u', 'i', 'n', 'g', '\n',
        'b', 'u', 'r', 'l', 'i', 'e', 'r', '\n',
        'b', 'u', 'r', 'l', 'i', 'e', 's', 't', '\n',
        'b', 'u', 'r', 'l', 'y', '\n',
        'b', 'u', 'r', 'm', 'a', '\n',
        'b', 'u', 'r', 'm', 'e', 's', 'e', '\n',
        'b', 'u', 'r', 'n', '\n',
        'b', 'u', 'r', 'n', 'e', 'd', '\n',
        'b', 'u', 'r', 'n', 'e', 'r', '\n',
        'b', 'u', 'r', 'n', 'e', 'r', 's', '\n',
        'b', 'u', 'r', 'n', 'i', 'n', 'g', '\n',
        'b', 'u', 'r', 'n', 'i', 'n', 'g', 's', '\n',
        'b', 'u', 'r', 'n', 'i', 's', 'h', 'e', 'd', '\n',
        'b', 'u', 'r', 'n', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'b', 'u', 'r', 'n', 's', '\n',
        'b', 'u', 'r', 'n', 't', '\n',
        'b', 'u', 'r', 'p', '\n',
        'b', 'u', 'r', 'p', 'e', 'd', '\n',
        'b', 'u', 'r', 'p', 'i', 'n', 'g', '\n',
        'b', 'u', 'r', 'p', 's', '\n',
        'b', 'u', 'r', 'r', '\n',
        'b', 'u', 'r', 'r', 'o', 'w', '\n',
        'b', 'u', 'r', 'r', 'o', 'w', 'e', 'd', '\n',
        'b', 'u', 'r', 'r', 'o', 'w', 'i', 'n', 'g', '\n',
        'b', 'u', 'r', 'r', 'o', 'w', 's', '\n',
        'b', 'u', 'r', 's', '\n',
        'b', 'u', 'r', 's', 'a', 'r', '\n',
        'b', 'u', 'r', 's', 'a', 'r', 'i', 'e', 's', '\n',
        'b', 'u', 'r', 's', 'a', 'r', 's', '\n',
        'b', 'u', 'r', 's', 'a', 'r', 'y', '\n',
        'b', 'u', 'r', 's', 't', '\n',
        'b', 'u', 'r', 's', 't', 'e', 'd', '\n',
        'b', 'u', 'r', 's', 't', 'i', 'n', 'g', '\n',
        'b', 'u', 'r', 's', 't', 's', '\n',
        'b', 'u', 'r', 'u', 'n', 'd', 'i', '\n',
        'b', 'u', 'r', 'y', '\n',
        'b', 'u', 'r', 'y', 'i', 'n', 'g', '\n',
        'b', 'u', 's', '\n',
        'b', 'u', 's', 'e', 's', '\n',
        'b', 'u', 's', 'h', '\n',
        'b', 'u', 's', 'h', 'e', 'l', '\n',
        'b', 'u', 's', 'h', 'e', 'l', 's', '\n',
        'b', 'u', 's', 'h', 'e', 's', '\n',
        'b', 'u', 's', 'h', 'f', 'i', 'r', 'e', '\n',
        'b', 'u', 's', 'h', 'i', 'e', 'r', '\n',
        'b', 'u', 's', 'h', 'i', 'e', 's', 't', '\n',
        'b', 'u', 's', 'h', 'i', 'n', 'e', 's', 's', '\n',
        'b', 'u', 's', 'h', 'i', 'n', 'g', '\n',
        'b', 'u', 's', 'h', 'l', 'a', 'n', 'd', '\n',
        'b', 'u', 's', 'h', 'm', 'a', 'n', '\n',
        'b', 'u', 's', 'h', 'm', 'e', 'n', '\n',
        'b', 'u', 's', 'h', 'y', '\n',
        'b', 'u', 's', 'i', 'e', 'd', '\n',
        'b', 'u', 's', 'i', 'e', 'r', '\n',
        'b', 'u', 's', 'i', 'e', 's', '\n',
        'b', 'u', 's', 'i', 'e', 's', 't', '\n',
        'b', 'u', 's', 'i', 'l', 'y', '\n',
        'b', 'u', 's', 'i', 'n', 'e', 's', 's', '\n',
        'b', 'u', 's', 'i', 'n', 'e', 's', 's', 'e', 's', '\n',
        'b', 'u', 's', 'i', 'n', 'e', 's', 's', 'l', 'i', 'k', 'e', '\n',
        'b', 'u', 's', 'i', 'n', 'e', 's', 's', 'm', 'a', 'n', '\n',
        'b', 'u', 's', 'i', 'n', 'e', 's', 's', 'm', 'e', 'n', '\n',
        'b', 'u', 's', 'i', 'n', 'e', 's', 's', 'w', 'o', 'm', 'a', 'n', '\n',
        'b', 'u', 's', 'k', '\n',
        'b', 'u', 's', 'k', 'e', 'r', '\n',
        'b', 'u', 's', 'k', 'e', 'r', 's', '\n',
        'b', 'u', 's', 'k', 'i', 'n', 'g', '\n',
        'b', 'u', 's', 'm', 'a', 'n', '\n',
        'b', 'u', 's', 'm', 'e', 'n', '\n',
        'b', 'u', 's', 's', 'e', 'd', '\n',
        'b', 'u', 's', 's', 'i', 'n', 'g', '\n',
        'b', 'u', 's', 't', '\n',
        'b', 'u', 's', 't', 'a', 'r', 'd', '\n',
        'b', 'u', 's', 't', 'a', 'r', 'd', 's', '\n',
        'b', 'u', 's', 't', 'e', 'd', '\n',
        'b', 'u', 's', 't', 'e', 'r', 's', '\n',
        'b', 'u', 's', 't', 'i', 'e', 'r', '\n',
        'b', 'u', 's', 't', 'i', 'n', 'g', '\n',
        'b', 'u', 's', 't', 'l', 'e', '\n',
        'b', 'u', 's', 't', 'l', 'e', 'd', '\n',
        'b', 'u', 's', 't', 'l', 'e', 's', '\n',
        'b', 'u', 's', 't', 'l', 'i', 'n', 'g', '\n',
        'b', 'u', 's', 't', 's', '\n',
        'b', 'u', 's', 't', 'y', '\n',
        'b', 'u', 's', 'y', '\n',
        'b', 'u', 's', 'y', 'b', 'o', 'd', 'i', 'e', 's', '\n',
        'b', 'u', 's', 'y', 'b', 'o', 'd', 'y', '\n',
        'b', 'u', 's', 'y', 'i', 'n', 'g', '\n',
        'b', 'u', 't', '\n',
        'b', 'u', 't', 'a', 'n', 'e', '\n',
        'b', 'u', 't', 'c', 'h', 'e', 'r', '\n',
        'b', 'u', 't', 'c', 'h', 'e', 'r', 'e', 'd', '\n',
        'b', 'u', 't', 'c', 'h', 'e', 'r', 'i', 'n', 'g', '\n',
        'b', 'u', 't', 'c', 'h', 'e', 'r', 's', '\n',
        'b', 'u', 't', 'c', 'h', 'e', 'r', 'y', '\n',
        'b', 'u', 't', 'l', 'e', 'r', '\n',
        'b', 'u', 't', 'l', 'e', 'r', 's', '\n',
        'b', 'u', 't', 's', '\n',
        'b', 'u', 't', 't', '\n',
        'b', 'u', 't', 't', 'e', 'd', '\n',
        'b', 'u', 't', 't', 'e', 'r', '\n',
        'b', 'u', 't', 't', 'e', 'r', 'c', 'u', 'p', '\n',
        'b', 'u', 't', 't', 'e', 'r', 'c', 'u', 'p', 's', '\n',
        'b', 'u', 't', 't', 'e', 'r', 'e', 'd', '\n',
        'b', 'u', 't', 't', 'e', 'r', 'f', 'a', 't', '\n',
        'b', 'u', 't', 't', 'e', 'r', 'f', 'l', 'i', 'e', 's', '\n',
        'b', 'u', 't', 't', 'e', 'r', 'f', 'l', 'y', '\n',
        'b', 'u', 't', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'b', 'u', 't', 't', 'e', 'r', 'm', 'i', 'l', 'k', '\n',
        'b', 'u', 't', 't', 'e', 'r', 's', '\n',
        'b', 'u', 't', 't', 'e', 'r', 's', 'c', 'o', 't', 'c', 'h', '\n',
        'b', 'u', 't', 't', 'e', 'r', 'y', '\n',
        'b', 'u', 't', 't', 'i', 'n', 'g', '\n',
        'b', 'u', 't', 't', 'o', 'c', 'k', '\n',
        'b', 'u', 't', 't', 'o', 'c', 'k', 's', '\n',
        'b', 'u', 't', 't', 'o', 'n', '\n',
        'b', 'u', 't', 't', 'o', 'n', 'e', 'd', '\n',
        'b', 'u', 't', 't', 'o', 'n', 'h', 'o', 'l', 'e', '\n',
        'b', 'u', 't', 't', 'o', 'n', 'h', 'o', 'l', 'e', 'd', '\n',
        'b', 'u', 't', 't', 'o', 'n', 'h', 'o', 'l', 'e', 's', '\n',
        'b', 'u', 't', 't', 'o', 'n', 'i', 'n', 'g', '\n',
        'b', 'u', 't', 't', 'o', 'n', 's', '\n',
        'b', 'u', 't', 't', 'r', 'e', 's', 's', '\n',
        'b', 'u', 't', 't', 'r', 'e', 's', 's', 'e', 'd', '\n',
        'b', 'u', 't', 't', 'r', 'e', 's', 's', 'e', 's', '\n',
        'b', 'u', 't', 't', 'r', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'b', 'u', 't', 't', 's', '\n',
        'b', 'u', 'x', 'o', 'm', '\n',
        'b', 'u', 'y', '\n',
        'b', 'u', 'y', 'e', 'r', '\n',
        'b', 'u', 'y', 'e', 'r', 's', '\n',
        'b', 'u', 'y', 'i', 'n', 'g', '\n',
        'b', 'u', 'y', 'o', 'u', 't', '\n',
        'b', 'u', 'y', 's', '\n',
        'b', 'u', 'z', 'z', '\n',
        'b', 'u', 'z', 'z', 'a', 'r', 'd', '\n',
        'b', 'u', 'z', 'z', 'a', 'r', 'd', 's', '\n',
        'b', 'u', 'z', 'z', 'e', 'd', '\n',
        'b', 'u', 'z', 'z', 'e', 'r', '\n',
        'b', 'u', 'z', 'z', 'e', 'r', 's', '\n',
        'b', 'u', 'z', 'z', 'e', 's', '\n',
        'b', 'u', 'z', 'z', 'i', 'n', 'g', '\n',
        'b', 'u', 'z', 'z', 'w', 'o', 'r', 'd', 's', '\n',
        'b', 'y', '\n',
        'b', 'y', 'e', '\n',
        'b', 'y', 'e', 'b', 'y', 'e', '\n',
        'b', 'y', 'e', 'l', 'a', 'w', '\n',
        'b', 'y', 'e', 'l', 'a', 'w', 's', '\n',
        'b', 'y', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'b', 'y', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'b', 'y', 'e', 's', '\n',
        'b', 'y', 'g', 'o', 'n', 'e', '\n',
        'b', 'y', 'g', 'o', 'n', 'e', 's', '\n',
        'b', 'y', 'l', 'a', 'w', '\n',
        'b', 'y', 'l', 'a', 'w', 's', '\n',
        'b', 'y', 'l', 'i', 'n', 'e', '\n',
        'b', 'y', 'p', 'a', 's', 's', '\n',
        'b', 'y', 'p', 'a', 's', 's', 'e', 'd', '\n',
        'b', 'y', 'p', 'a', 's', 's', 'e', 's', '\n',
        'b', 'y', 'p', 'a', 's', 's', 'i', 'n', 'g', '\n',
        'b', 'y', 'p', 'a', 't', 'h', '\n',
        'b', 'y', 'p', 'a', 't', 'h', 's', '\n',
        'b', 'y', 'p', 'r', 'o', 'd', 'u', 'c', 't', '\n',
        'b', 'y', 'p', 'r', 'o', 'd', 'u', 'c', 't', 's', '\n',
        'b', 'y', 's', 't', 'a', 'n', 'd', 'e', 'r', '\n',
        'b', 'y', 's', 't', 'a', 'n', 'd', 'e', 'r', 's', '\n',
        'b', 'y', 't', 'e', '\n',
        'b', 'y', 't', 'e', 's', '\n',
        'b', 'y', 'w', 'a', 'y', '\n',
        'b', 'y', 'w', 'a', 'y', 's', '\n',
        'b', 'y', 'w', 'o', 'r', 'd', '\n',
        'c', 'a', 'b', '\n',
        'c', 'a', 'b', 'a', 'l', '\n',
        'c', 'a', 'b', 'a', 'l', 's', '\n',
        'c', 'a', 'b', 'a', 'r', 'e', 't', '\n',
        'c', 'a', 'b', 'a', 'r', 'e', 't', 's', '\n',
        'c', 'a', 'b', 'b', 'a', 'g', 'e', '\n',
        'c', 'a', 'b', 'b', 'a', 'g', 'e', 's', '\n',
        'c', 'a', 'b', 'b', 'y', '\n',
        'c', 'a', 'b', 'i', 'n', '\n',
        'c', 'a', 'b', 'i', 'n', 'e', 't', '\n',
        'c', 'a', 'b', 'i', 'n', 'e', 't', 'm', 'a', 'k', 'e', 'r', '\n',
        'c', 'a', 'b', 'i', 'n', 'e', 't', 's', '\n',
        'c', 'a', 'b', 'i', 'n', 's', '\n',
        'c', 'a', 'b', 'l', 'e', '\n',
        'c', 'a', 'b', 'l', 'e', 'd', '\n',
        'c', 'a', 'b', 'l', 'e', 's', '\n',
        'c', 'a', 'b', 'l', 'e', 'w', 'a', 'y', '\n',
        'c', 'a', 'b', 'l', 'i', 'n', 'g', '\n',
        'c', 'a', 'b', 'm', 'a', 'n', '\n',
        'c', 'a', 'b', 'm', 'e', 'n', '\n',
        'c', 'a', 'b', 'o', 'o', 'd', 'l', 'e', '\n',
        'c', 'a', 'b', 'o', 'o', 's', 'e', '\n',
        'c', 'a', 'b', 'r', 'i', 'o', 'l', 'e', 't', '\n',
        'c', 'a', 'b', 's', '\n',
        'c', 'a', 'c', 'a', 'o', '\n',
        'c', 'a', 'c', 'h', 'e', '\n',
        'c', 'a', 'c', 'h', 'e', 'd', '\n',
        'c', 'a', 'c', 'h', 'e', 's', '\n',
        'c', 'a', 'c', 'h', 'e', 't', '\n',
        'c', 'a', 'c', 'h', 'i', 'n', 'g', '\n',
        'c', 'a', 'c', 'k', 'l', 'e', '\n',
        'c', 'a', 'c', 'k', 'l', 'e', 'd', '\n',
        'c', 'a', 'c', 'k', 'l', 'e', 's', '\n',
        'c', 'a', 'c', 'k', 'l', 'i', 'n', 'g', '\n',
        'c', 'a', 'c', 'o', 'p', 'h', 'o', 'n', 'o', 'u', 's', '\n',
        'c', 'a', 'c', 'o', 'p', 'h', 'o', 'n', 'y', '\n',
        'c', 'a', 'c', 't', 'i', '\n',
        'c', 'a', 'c', 't', 'u', 's', '\n',
        'c', 'a', 'c', 't', 'u', 's', 'e', 's', '\n',
        'c', 'a', 'd', '\n',
        'c', 'a', 'd', 'a', 'v', 'e', 'r', '\n',
        'c', 'a', 'd', 'a', 'v', 'e', 'r', 'o', 'u', 's', '\n',
        'c', 'a', 'd', 'a', 'v', 'e', 'r', 's', '\n',
        'c', 'a', 'd', 'd', 'i', 'e', '\n',
        'c', 'a', 'd', 'd', 'i', 'e', 'd', '\n',
        'c', 'a', 'd', 'd', 'i', 'e', 's', '\n',
        'c', 'a', 'd', 'd', 'y', '\n',
        'c', 'a', 'd', 'd', 'y', 'i', 'n', 'g', '\n',
        'c', 'a', 'd', 'e', '\n',
        'c', 'a', 'd', 'e', 'n', 'c', 'e', '\n',
        'c', 'a', 'd', 'e', 'n', 'c', 'e', 's', '\n',
        'c', 'a', 'd', 'e', 'n', 'z', 'a', '\n',
        'c', 'a', 'd', 'e', 'n', 'z', 'a', 's', '\n',
        'c', 'a', 'd', 'e', 't', '\n',
        'c', 'a', 'd', 'e', 't', 's', '\n',
        'c', 'a', 'd', 'g', 'e', '\n',
        'c', 'a', 'd', 'g', 'e', 'd', '\n',
        'c', 'a', 'd', 'g', 'e', 'r', '\n',
        'c', 'a', 'd', 'g', 'e', 's', '\n',
        'c', 'a', 'd', 'm', 'i', 'u', 'm', '\n',
        'c', 'a', 'd', 's', '\n',
        'c', 'a', 'e', 's', 'a', 'r', '\n',
        'c', 'a', 'f', 'e', '\n',
        'c', 'a', 'f', 'e', 's', '\n',
        'c', 'a', 'f', 'e', 't', 'e', 'r', 'i', 'a', '\n',
        'c', 'a', 'f', 'e', 't', 'e', 'r', 'i', 'a', 's', '\n',
        'c', 'a', 'f', 't', 'a', 'n', '\n',
        'c', 'a', 'f', 't', 'a', 'n', 's', '\n',
        'c', 'a', 'g', 'e', '\n',
        'c', 'a', 'g', 'e', 'd', '\n',
        'c', 'a', 'g', 'e', 's', '\n',
        'c', 'a', 'g', 'e', 'y', '\n',
        'c', 'a', 'g', 'i', 'e', 's', 't', '\n',
        'c', 'a', 'g', 'i', 'n', 'g', '\n',
        'c', 'a', 'g', 'o', 'u', 'l', 'e', '\n',
        'c', 'a', 'g', 'o', 'u', 'l', 'e', 's', '\n',
        'c', 'a', 'g', 'y', '\n',
        'c', 'a', 'h', 'o', 'o', 't', 's', '\n',
        'c', 'a', 'i', 'm', 'a', 'n', '\n',
        'c', 'a', 'i', 'm', 'a', 'n', 's', '\n',
        'c', 'a', 'i', 'n', '\n',
        'c', 'a', 'i', 'r', 'n', '\n',
        'c', 'a', 'i', 'r', 'n', 's', '\n',
        'c', 'a', 'i', 'r', 'o', '\n',
        'c', 'a', 'j', 'o', 'l', 'e', '\n',
        'c', 'a', 'j', 'o', 'l', 'e', 'd', '\n',
        'c', 'a', 'j', 'o', 'l', 'i', 'n', 'g', '\n',
        'c', 'a', 'k', 'e', '\n',
        'c', 'a', 'k', 'e', 'd', '\n',
        'c', 'a', 'k', 'e', 's', '\n',
        'c', 'a', 'k', 'i', 'n', 'g', '\n',
        'c', 'a', 'l', 'a', 'm', 'i', 't', 'i', 'e', 's', '\n',
        'c', 'a', 'l', 'a', 'm', 'i', 't', 'o', 'u', 's', '\n',
        'c', 'a', 'l', 'a', 'm', 'i', 't', 'o', 'u', 's', 'l', 'y', '\n',
        'c', 'a', 'l', 'a', 'm', 'i', 't', 'y', '\n',
        'c', 'a', 'l', 'c', 'a', 'r', 'e', 'o', 'u', 's', '\n',
        'c', 'a', 'l', 'c', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'a', 'l', 'c', 'i', 'f', 'i', 'e', 'd', '\n',
        'c', 'a', 'l', 'c', 'i', 'f', 'y', '\n',
        'c', 'a', 'l', 'c', 'i', 't', 'e', '\n',
        'c', 'a', 'l', 'c', 'i', 'u', 'm', '\n',
        'c', 'a', 'l', 'c', 'u', 'l', 'a', 'b', 'l', 'e', '\n',
        'c', 'a', 'l', 'c', 'u', 'l', 'a', 't', 'e', '\n',
        'c', 'a', 'l', 'c', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'c', 'a', 'l', 'c', 'u', 'l', 'a', 't', 'e', 'd', 'l', 'y', '\n',
        'c', 'a', 'l', 'c', 'u', 'l', 'a', 't', 'e', 's', '\n',
        'c', 'a', 'l', 'c', 'u', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'a', 'l', 'c', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'a', 'l', 'c', 'u', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'a', 'l', 'c', 'u', 'l', 'a', 't', 'i', 'v', 'e', '\n',
        'c', 'a', 'l', 'c', 'u', 'l', 'a', 't', 'o', 'r', '\n',
        'c', 'a', 'l', 'c', 'u', 'l', 'a', 't', 'o', 'r', 's', '\n',
        'c', 'a', 'l', 'c', 'u', 'l', 'u', 's', '\n',
        'c', 'a', 'l', 'c', 'u', 't', 't', 'a', '\n',
        'c', 'a', 'l', 'd', 'e', 'r', 'a', '\n',
        'c', 'a', 'l', 'd', 'r', 'o', 'n', '\n',
        'c', 'a', 'l', 'd', 'r', 'o', 'n', 's', '\n',
        'c', 'a', 'l', 'e', 'n', 'd', 'a', 'r', '\n',
        'c', 'a', 'l', 'e', 'n', 'd', 'a', 'r', 's', '\n',
        'c', 'a', 'l', 'f', '\n',
        'c', 'a', 'l', 'i', 'b', 'r', 'a', 't', 'e', '\n',
        'c', 'a', 'l', 'i', 'b', 'r', 'a', 't', 'e', 'd', '\n',
        'c', 'a', 'l', 'i', 'b', 'r', 'a', 't', 'e', 's', '\n',
        'c', 'a', 'l', 'i', 'b', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'a', 'l', 'i', 'b', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'a', 'l', 'i', 'b', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'a', 'l', 'i', 'b', 'r', 'a', 't', 'o', 'r', '\n',
        'c', 'a', 'l', 'i', 'b', 'r', 'a', 't', 'o', 'r', 's', '\n',
        'c', 'a', 'l', 'i', 'b', 'r', 'e', '\n',
        'c', 'a', 'l', 'i', 'c', 'o', '\n',
        'c', 'a', 'l', 'i', 'f', '\n',
        'c', 'a', 'l', 'i', 'f', 'o', 'r', 'n', 'i', 'a', '\n',
        'c', 'a', 'l', 'i', 'p', 'e', 'r', '\n',
        'c', 'a', 'l', 'i', 'p', 'e', 'r', 's', '\n',
        'c', 'a', 'l', 'i', 'p', 'h', '\n',
        'c', 'a', 'l', 'l', '\n',
        'c', 'a', 'l', 'l', 'a', 'b', 'l', 'e', '\n',
        'c', 'a', 'l', 'l', 'e', 'd', '\n',
        'c', 'a', 'l', 'l', 'e', 'r', '\n',
        'c', 'a', 'l', 'l', 'e', 'r', 's', '\n',
        'c', 'a', 'l', 'l', 'g', 'i', 'r', 'l', '\n',
        'c', 'a', 'l', 'l', 'g', 'i', 'r', 'l', 's', '\n',
        'c', 'a', 'l', 'l', 'i', 'g', 'r', 'a', 'p', 'h', 'e', 'r', '\n',
        'c', 'a', 'l', 'l', 'i', 'g', 'r', 'a', 'p', 'h', 'i', 'c', '\n',
        'c', 'a', 'l', 'l', 'i', 'g', 'r', 'a', 'p', 'h', 'y', '\n',
        'c', 'a', 'l', 'l', 'i', 'n', 'g', '\n',
        'c', 'a', 'l', 'l', 'i', 'n', 'g', 's', '\n',
        'c', 'a', 'l', 'l', 'i', 'p', 'e', 'r', '\n',
        'c', 'a', 'l', 'l', 'i', 'p', 'e', 'r', 's', '\n',
        'c', 'a', 'l', 'l', 'i', 's', 't', 'h', 'e', 'n', 'i', 'c', 's', '\n',
        'c', 'a', 'l', 'l', 'o', 'u', 's', '\n',
        'c', 'a', 'l', 'l', 'o', 'u', 's', 'e', 'd', '\n',
        'c', 'a', 'l', 'l', 'o', 'u', 's', 'l', 'y', '\n',
        'c', 'a', 'l', 'l', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'c', 'a', 'l', 'l', 'o', 'w', '\n',
        'c', 'a', 'l', 'l', 'o', 'w', 'n', 'e', 's', 's', '\n',
        'c', 'a', 'l', 'l', 's', '\n',
        'c', 'a', 'l', 'l', 'u', 'p', '\n',
        'c', 'a', 'l', 'l', 'u', 's', '\n',
        'c', 'a', 'l', 'm', '\n',
        'c', 'a', 'l', 'm', 'e', 'd', '\n',
        'c', 'a', 'l', 'm', 'e', 'r', '\n',
        'c', 'a', 'l', 'm', 'e', 's', 't', '\n',
        'c', 'a', 'l', 'm', 'i', 'n', 'g', '\n',
        'c', 'a', 'l', 'm', 'l', 'y', '\n',
        'c', 'a', 'l', 'm', 'n', 'e', 's', 's', '\n',
        'c', 'a', 'l', 'm', 's', '\n',
        'c', 'a', 'l', 'o', 'r', 'i', 'e', '\n',
        'c', 'a', 'l', 'o', 'r', 'i', 'e', 's', '\n',
        'c', 'a', 'l', 'o', 'r', 'i', 'f', 'i', 'c', '\n',
        'c', 'a', 'l', 'o', 'r', 'i', 'm', 'e', 't', 'e', 'r', '\n',
        'c', 'a', 'l', 'o', 'r', 'i', 'm', 'e', 't', 'e', 'r', 's', '\n',
        'c', 'a', 'l', 'o', 'r', 'i', 'm', 'e', 't', 'r', 'y', '\n',
        'c', 'a', 'l', 'o', 'r', 'y', '\n',
        'c', 'a', 'l', 'u', 'm', 'n', 'i', 'a', 't', 'e', '\n',
        'c', 'a', 'l', 'u', 'm', 'n', 'i', 'e', 's', '\n',
        'c', 'a', 'l', 'u', 'm', 'n', 'y', '\n',
        'c', 'a', 'l', 'v', 'a', 'r', 'y', '\n',
        'c', 'a', 'l', 'v', 'e', '\n',
        'c', 'a', 'l', 'v', 'e', 's', '\n',
        'c', 'a', 'l', 'v', 'i', 'n', '\n',
        'c', 'a', 'l', 'v', 'i', 'n', 'g', '\n',
        'c', 'a', 'l', 'y', 'p', 's', 'o', '\n',
        'c', 'a', 'm', '\n',
        'c', 'a', 'm', 'a', 'r', 'a', 'd', 'e', 'r', 'i', 'e', '\n',
        'c', 'a', 'm', 'b', 'e', 'r', '\n',
        'c', 'a', 'm', 'b', 'o', 'd', 'i', 'a', '\n',
        'c', 'a', 'm', 'c', 'o', 'r', 'd', 'e', 'r', '\n',
        'c', 'a', 'm', 'c', 'o', 'r', 'd', 'e', 'r', 's', '\n',
        'c', 'a', 'm', 'e', '\n',
        'c', 'a', 'm', 'e', 'l', '\n',
        'c', 'a', 'm', 'e', 'l', 'h', 'a', 'i', 'r', '\n',
        'c', 'a', 'm', 'e', 'l', 'o', 't', '\n',
        'c', 'a', 'm', 'e', 'l', 's', '\n',
        'c', 'a', 'm', 'e', 'o', '\n',
        'c', 'a', 'm', 'e', 'r', 'a', '\n',
        'c', 'a', 'm', 'e', 'r', 'a', 'm', 'a', 'n', '\n',
        'c', 'a', 'm', 'e', 'r', 'a', 'm', 'e', 'n', '\n',
        'c', 'a', 'm', 'e', 'r', 'a', 's', '\n',
        'c', 'a', 'm', 'e', 'r', 'a', 'w', 'o', 'r', 'k', '\n',
        'c', 'a', 'm', 'i', 's', 'o', 'l', 'e', '\n',
        'c', 'a', 'm', 'o', 'm', 'i', 'l', 'e', '\n',
        'c', 'a', 'm', 'o', 'u', 'f', 'l', 'a', 'g', 'e', '\n',
        'c', 'a', 'm', 'o', 'u', 'f', 'l', 'a', 'g', 'e', 'd', '\n',
        'c', 'a', 'm', 'o', 'u', 'f', 'l', 'a', 'g', 'e', 's', '\n',
        'c', 'a', 'm', 'o', 'u', 'f', 'l', 'a', 'g', 'i', 'n', 'g', '\n',
        'c', 'a', 'm', 'p', '\n',
        'c', 'a', 'm', 'p', 'a', 'i', 'g', 'n', '\n',
        'c', 'a', 'm', 'p', 'a', 'i', 'g', 'n', 'e', 'd', '\n',
        'c', 'a', 'm', 'p', 'a', 'i', 'g', 'n', 'e', 'r', '\n',
        'c', 'a', 'm', 'p', 'a', 'i', 'g', 'n', 'e', 'r', 's', '\n',
        'c', 'a', 'm', 'p', 'a', 'i', 'g', 'n', 'i', 'n', 'g', '\n',
        'c', 'a', 'm', 'p', 'a', 'i', 'g', 'n', 's', '\n',
        'c', 'a', 'm', 'p', 'a', 'n', 'i', 'l', 'e', '\n',
        'c', 'a', 'm', 'p', 'a', 'n', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'c', 'a', 'm', 'p', 'a', 'n', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'c', 'a', 'm', 'p', 'a', 'n', 'o', 'l', 'o', 'g', 'y', '\n',
        'c', 'a', 'm', 'p', 'e', 'd', '\n',
        'c', 'a', 'm', 'p', 'e', 'r', '\n',
        'c', 'a', 'm', 'p', 'e', 'r', 's', '\n',
        'c', 'a', 'm', 'p', 'f', 'i', 'r', 'e', '\n',
        'c', 'a', 'm', 'p', 'f', 'i', 'r', 'e', 's', '\n',
        'c', 'a', 'm', 'p', 'h', 'o', 'r', '\n',
        'c', 'a', 'm', 'p', 'i', 'n', 'g', '\n',
        'c', 'a', 'm', 'p', 's', '\n',
        'c', 'a', 'm', 'p', 's', 'i', 't', 'e', '\n',
        'c', 'a', 'm', 'p', 's', 'i', 't', 'e', 's', '\n',
        'c', 'a', 'm', 'p', 'u', 's', '\n',
        'c', 'a', 'm', 'p', 'u', 's', 'e', 's', '\n',
        'c', 'a', 'm', 's', '\n',
        'c', 'a', 'm', 's', 'h', 'a', 'f', 't', '\n',
        'c', 'a', 'n', '\n',
        'c', 'a', 'n', 'a', 'a', 'n', '\n',
        'c', 'a', 'n', 'a', 'd', 'a', '\n',
        'c', 'a', 'n', 'a', 'd', 'i', 'a', 'n', '\n',
        'c', 'a', 'n', 'a', 'l', '\n',
        'c', 'a', 'n', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'a', 'n', 'a', 'l', 's', '\n',
        'c', 'a', 'n', 'a', 'p', 'e', '\n',
        'c', 'a', 'n', 'a', 'p', 'e', 's', '\n',
        'c', 'a', 'n', 'a', 'r', 'd', '\n',
        'c', 'a', 'n', 'a', 'r', 'i', 'e', 's', '\n',
        'c', 'a', 'n', 'a', 'r', 'y', '\n',
        'c', 'a', 'n', 'b', 'e', 'r', 'r', 'a', '\n',
        'c', 'a', 'n', 'c', 'a', 'n', '\n',
        'c', 'a', 'n', 'c', 'e', 'l', '\n',
        'c', 'a', 'n', 'c', 'e', 'l', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'a', 'n', 'c', 'e', 'l', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'a', 'n', 'c', 'e', 'l', 'l', 'e', 'd', '\n',
        'c', 'a', 'n', 'c', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'c', 'a', 'n', 'c', 'e', 'l', 's', '\n',
        'c', 'a', 'n', 'c', 'e', 'r', '\n',
        'c', 'a', 'n', 'c', 'e', 'r', 'o', 'u', 's', '\n',
        'c', 'a', 'n', 'c', 'e', 'r', 's', '\n',
        'c', 'a', 'n', 'd', 'e', 'l', 'a', 'b', 'r', 'a', '\n',
        'c', 'a', 'n', 'd', 'e', 'l', 'a', 's', '\n',
        'c', 'a', 'n', 'd', 'i', 'd', '\n',
        'c', 'a', 'n', 'd', 'i', 'd', 'a', 'c', 'y', '\n',
        'c', 'a', 'n', 'd', 'i', 'd', 'a', 't', 'e', '\n',
        'c', 'a', 'n', 'd', 'i', 'd', 'a', 't', 'e', 's', '\n',
        'c', 'a', 'n', 'd', 'i', 'd', 'a', 't', 'u', 'r', 'e', '\n',
        'c', 'a', 'n', 'd', 'i', 'd', 'a', 't', 'u', 'r', 'e', 's', '\n',
        'c', 'a', 'n', 'd', 'i', 'd', 'l', 'y', '\n',
        'c', 'a', 'n', 'd', 'i', 'e', 's', '\n',
        'c', 'a', 'n', 'd', 'l', 'e', '\n',
        'c', 'a', 'n', 'd', 'l', 'e', 'l', 'i', 'g', 'h', 't', '\n',
        'c', 'a', 'n', 'd', 'l', 'e', 'l', 'i', 't', '\n',
        'c', 'a', 'n', 'd', 'l', 'e', 'p', 'o', 'w', 'e', 'r', '\n',
        'c', 'a', 'n', 'd', 'l', 'e', 's', '\n',
        'c', 'a', 'n', 'd', 'l', 'e', 's', 't', 'i', 'c', 'k', '\n',
        'c', 'a', 'n', 'd', 'l', 'e', 's', 't', 'i', 'c', 'k', 's', '\n',
        'c', 'a', 'n', 'd', 'o', 'u', 'r', '\n',
        'c', 'a', 'n', 'd', 'y', '\n',
        'c', 'a', 'n', 'e', '\n',
        'c', 'a', 'n', 'e', 'd', '\n',
        'c', 'a', 'n', 'e', 's', '\n',
        'c', 'a', 'n', 'i', 'n', 'e', '\n',
        'c', 'a', 'n', 'i', 'n', 'e', 's', '\n',
        'c', 'a', 'n', 'i', 'n', 'g', '\n',
        'c', 'a', 'n', 'i', 'n', 'g', 's', '\n',
        'c', 'a', 'n', 'i', 's', 't', 'e', 'r', '\n',
        'c', 'a', 'n', 'i', 's', 't', 'e', 'r', 's', '\n',
        'c', 'a', 'n', 'n', 'a', 'b', 'i', 's', '\n',
        'c', 'a', 'n', 'n', 'e', 'd', '\n',
        'c', 'a', 'n', 'n', 'e', 'l', '\n',
        'c', 'a', 'n', 'n', 'e', 'r', 'y', '\n',
        'c', 'a', 'n', 'n', 'e', 's', '\n',
        'c', 'a', 'n', 'n', 'i', 'b', 'a', 'l', '\n',
        'c', 'a', 'n', 'n', 'i', 'b', 'a', 'l', 'i', 's', 'e', '\n',
        'c', 'a', 'n', 'n', 'i', 'b', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'c', 'a', 'n', 'n', 'i', 'b', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'c', 'a', 'n', 'n', 'i', 'b', 'a', 'l', 'i', 's', 'm', '\n',
        'c', 'a', 'n', 'n', 'i', 'b', 'a', 'l', 'i', 's', 't', 'i', 'c', '\n',
        'c', 'a', 'n', 'n', 'i', 'b', 'a', 'l', 's', '\n',
        'c', 'a', 'n', 'n', 'i', 'l', 'y', '\n',
        'c', 'a', 'n', 'n', 'i', 'n', 'g', '\n',
        'c', 'a', 'n', 'n', 'o', 'n', '\n',
        'c', 'a', 'n', 'n', 'o', 'n', 'b', 'a', 'l', 'l', '\n',
        'c', 'a', 'n', 'n', 'o', 'n', 'b', 'a', 'l', 'l', 's', '\n',
        'c', 'a', 'n', 'n', 'o', 'n', 'e', 'd', '\n',
        'c', 'a', 'n', 'n', 'o', 'n', 'i', 'n', 'g', '\n',
        'c', 'a', 'n', 'n', 'o', 'n', 's', '\n',
        'c', 'a', 'n', 'n', 'o', 't', '\n',
        'c', 'a', 'n', 'n', 'u', 'l', 'a', '\n',
        'c', 'a', 'n', 'n', 'y', '\n',
        'c', 'a', 'n', 'o', 'e', '\n',
        'c', 'a', 'n', 'o', 'e', 'd', '\n',
        'c', 'a', 'n', 'o', 'e', 'i', 'n', 'g', '\n',
        'c', 'a', 'n', 'o', 'e', 'i', 's', 't', '\n',
        'c', 'a', 'n', 'o', 'e', 'i', 's', 't', 's', '\n',
        'c', 'a', 'n', 'o', 'e', 's', '\n',
        'c', 'a', 'n', 'o', 'n', '\n',
        'c', 'a', 'n', 'o', 'n', 'i', 'c', '\n',
        'c', 'a', 'n', 'o', 'n', 'i', 'c', 'a', 'l', '\n',
        'c', 'a', 'n', 'o', 'n', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'c', 'a', 'n', 'o', 'n', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'a', 'n', 'o', 'n', 'i', 's', 'e', '\n',
        'c', 'a', 'n', 'o', 'n', 'i', 's', 'e', 'd', '\n',
        'c', 'a', 'n', 'o', 'n', 'r', 'y', '\n',
        'c', 'a', 'n', 'o', 'n', 's', '\n',
        'c', 'a', 'n', 'o', 'p', 'e', 'n', 'e', 'r', '\n',
        'c', 'a', 'n', 'o', 'p', 'i', 'e', 'd', '\n',
        'c', 'a', 'n', 'o', 'p', 'i', 'e', 's', '\n',
        'c', 'a', 'n', 'o', 'p', 'y', '\n',
        'c', 'a', 'n', 's', '\n',
        'c', 'a', 'n', 't', '\n',
        'c', 'a', 'n', 't', 'a', 'l', 'o', 'u', 'p', 'e', '\n',
        'c', 'a', 'n', 't', 'a', 'n', 'k', 'e', 'r', 'o', 'u', 's', '\n',
        'c', 'a', 'n', 't', 'a', 't', 'a', '\n',
        'c', 'a', 'n', 't', 'a', 't', 'a', 's', '\n',
        'c', 'a', 'n', 't', 'e', 'd', '\n',
        'c', 'a', 'n', 't', 'e', 'e', 'n', '\n',
        'c', 'a', 'n', 't', 'e', 'e', 'n', 's', '\n',
        'c', 'a', 'n', 't', 'e', 'r', '\n',
        'c', 'a', 'n', 't', 'e', 'r', 'e', 'd', '\n',
        'c', 'a', 'n', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'c', 'a', 'n', 't', 'e', 'r', 's', '\n',
        'c', 'a', 'n', 't', 'i', 'c', 'l', 'e', '\n',
        'c', 'a', 'n', 't', 'i', 'c', 'l', 'e', 's', '\n',
        'c', 'a', 'n', 't', 'i', 'l', 'e', 'v', 'e', 'r', '\n',
        'c', 'a', 'n', 't', 'i', 'l', 'e', 'v', 'e', 'r', 'e', 'd', '\n',
        'c', 'a', 'n', 't', 'o', 'n', '\n',
        'c', 'a', 'n', 't', 'o', 'n', 's', '\n',
        'c', 'a', 'n', 't', 'o', 'r', '\n',
        'c', 'a', 'n', 'v', 'a', 's', '\n',
        'c', 'a', 'n', 'v', 'a', 's', 'e', 'd', '\n',
        'c', 'a', 'n', 'v', 'a', 's', 'e', 's', '\n',
        'c', 'a', 'n', 'v', 'a', 's', 's', '\n',
        'c', 'a', 'n', 'v', 'a', 's', 's', 'e', 'd', '\n',
        'c', 'a', 'n', 'v', 'a', 's', 's', 'e', 'r', '\n',
        'c', 'a', 'n', 'v', 'a', 's', 's', 'e', 'r', 's', '\n',
        'c', 'a', 'n', 'v', 'a', 's', 's', 'e', 's', '\n',
        'c', 'a', 'n', 'v', 'a', 's', 's', 'i', 'n', 'g', '\n',
        'c', 'a', 'n', 'y', 'o', 'n', '\n',
        'c', 'a', 'n', 'y', 'o', 'n', 's', '\n',
        'c', 'a', 'p', '\n',
        'c', 'a', 'p', 'a', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'c', 'a', 'p', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'c', 'a', 'p', 'a', 'b', 'l', 'e', '\n',
        'c', 'a', 'p', 'a', 'b', 'l', 'y', '\n',
        'c', 'a', 'p', 'a', 'c', 'i', 'o', 'u', 's', '\n',
        'c', 'a', 'p', 'a', 'c', 'i', 't', 'a', 'n', 'c', 'e', '\n',
        'c', 'a', 'p', 'a', 'c', 'i', 't', 'i', 'e', 's', '\n',
        'c', 'a', 'p', 'a', 'c', 'i', 't', 'i', 'v', 'e', '\n',
        'c', 'a', 'p', 'a', 'c', 'i', 't', 'o', 'r', '\n',
        'c', 'a', 'p', 'a', 'c', 'i', 't', 'o', 'r', 's', '\n',
        'c', 'a', 'p', 'a', 'c', 'i', 't', 'y', '\n',
        'c', 'a', 'p', 'a', 'r', 'i', 's', 'o', 'n', 'e', 'd', '\n',
        'c', 'a', 'p', 'e', '\n',
        'c', 'a', 'p', 'e', 'd', '\n',
        'c', 'a', 'p', 'e', 'r', '\n',
        'c', 'a', 'p', 'e', 'r', 'e', 'd', '\n',
        'c', 'a', 'p', 'e', 'r', 'i', 'n', 'g', '\n',
        'c', 'a', 'p', 'e', 'r', 's', '\n',
        'c', 'a', 'p', 'e', 's', '\n',
        'c', 'a', 'p', 'e', 't', 'o', 'w', 'n', '\n',
        'c', 'a', 'p', 'i', 'l', 'l', 'a', 'r', 'i', 'e', 's', '\n',
        'c', 'a', 'p', 'i', 'l', 'l', 'a', 'r', 'y', '\n',
        'c', 'a', 'p', 'i', 't', 'a', '\n',
        'c', 'a', 'p', 'i', 't', 'a', 'l', '\n',
        'c', 'a', 'p', 'i', 't', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'a', 'p', 'i', 't', 'a', 'l', 'i', 's', 'e', '\n',
        'c', 'a', 'p', 'i', 't', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'c', 'a', 'p', 'i', 't', 'a', 'l', 'i', 's', 'e', 's', '\n',
        'c', 'a', 'p', 'i', 't', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'c', 'a', 'p', 'i', 't', 'a', 'l', 'i', 's', 'm', '\n',
        'c', 'a', 'p', 'i', 't', 'a', 'l', 'i', 's', 't', '\n',
        'c', 'a', 'p', 'i', 't', 'a', 'l', 'i', 's', 't', 'i', 'c', '\n',
        'c', 'a', 'p', 'i', 't', 'a', 'l', 'i', 's', 't', 's', '\n',
        'c', 'a', 'p', 'i', 't', 'a', 'l', 'l', 'y', '\n',
        'c', 'a', 'p', 'i', 't', 'a', 'l', 's', '\n',
        'c', 'a', 'p', 'i', 't', 'a', 't', 'e', '\n',
        'c', 'a', 'p', 'i', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'a', 'p', 'i', 't', 'o', 'l', '\n',
        'c', 'a', 'p', 'i', 't', 'u', 'l', 'a', 't', 'e', '\n',
        'c', 'a', 'p', 'i', 't', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'c', 'a', 'p', 'i', 't', 'u', 'l', 'a', 't', 'e', 's', '\n',
        'c', 'a', 'p', 'i', 't', 'u', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'a', 'p', 'i', 't', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'a', 'p', 'p', 'e', 'd', '\n',
        'c', 'a', 'p', 'p', 'i', 'n', 'g', '\n',
        'c', 'a', 'p', 'p', 'u', 'c', 'c', 'i', 'n', 'o', '\n',
        'c', 'a', 'p', 'r', 'i', '\n',
        'c', 'a', 'p', 'r', 'i', 'c', 'e', '\n',
        'c', 'a', 'p', 'r', 'i', 'c', 'e', 's', '\n',
        'c', 'a', 'p', 'r', 'i', 'c', 'i', 'o', 'u', 's', '\n',
        'c', 'a', 'p', 'r', 'i', 'c', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'c', 'a', 'p', 'r', 'i', 'c', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'c', 'a', 'p', 'r', 'i', 'o', 'l', 'e', '\n',
        'c', 'a', 'p', 'r', 'i', 's', '\n',
        'c', 'a', 'p', 's', '\n',
        'c', 'a', 'p', 's', 'i', 'z', 'e', '\n',
        'c', 'a', 'p', 's', 'i', 'z', 'e', 'd', '\n',
        'c', 'a', 'p', 's', 'i', 'z', 'e', 's', '\n',
        'c', 'a', 'p', 's', 'i', 'z', 'i', 'n', 'g', '\n',
        'c', 'a', 'p', 's', 't', 'a', 'n', '\n',
        'c', 'a', 'p', 's', 't', 'a', 'n', 's', '\n',
        'c', 'a', 'p', 's', 'u', 'l', 'e', '\n',
        'c', 'a', 'p', 's', 'u', 'l', 'e', 's', '\n',
        'c', 'a', 'p', 't', 'a', 'i', 'n', '\n',
        'c', 'a', 'p', 't', 'a', 'i', 'n', 'c', 'y', '\n',
        'c', 'a', 'p', 't', 'a', 'i', 'n', 'e', 'd', '\n',
        'c', 'a', 'p', 't', 'a', 'i', 'n', 'i', 'n', 'g', '\n',
        'c', 'a', 'p', 't', 'a', 'i', 'n', 's', '\n',
        'c', 'a', 'p', 't', 'i', 'o', 'n', '\n',
        'c', 'a', 'p', 't', 'i', 'o', 'n', 'e', 'd', '\n',
        'c', 'a', 'p', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'a', 'p', 't', 'i', 'o', 'u', 's', '\n',
        'c', 'a', 'p', 't', 'i', 'v', 'a', 't', 'e', '\n',
        'c', 'a', 'p', 't', 'i', 'v', 'a', 't', 'e', 'd', '\n',
        'c', 'a', 'p', 't', 'i', 'v', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'a', 'p', 't', 'i', 'v', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'a', 'p', 't', 'i', 'v', 'e', '\n',
        'c', 'a', 'p', 't', 'i', 'v', 'e', 's', '\n',
        'c', 'a', 'p', 't', 'i', 'v', 'i', 't', 'y', '\n',
        'c', 'a', 'p', 't', 'o', 'r', '\n',
        'c', 'a', 'p', 't', 'o', 'r', 's', '\n',
        'c', 'a', 'p', 't', 'u', 'r', 'e', '\n',
        'c', 'a', 'p', 't', 'u', 'r', 'e', 'd', '\n',
        'c', 'a', 'p', 't', 'u', 'r', 'e', 's', '\n',
        'c', 'a', 'p', 't', 'u', 'r', 'i', 'n', 'g', '\n',
        'c', 'a', 'p', 'y', 'b', 'a', 'r', 'a', '\n',
        'c', 'a', 'r', '\n',
        'c', 'a', 'r', 'a', 'b', 'i', 'n', 'i', 'e', 'r', 'i', '\n',
        'c', 'a', 'r', 'a', 'c', 'a', 'l', '\n',
        'c', 'a', 'r', 'a', 'c', 'a', 'l', 's', '\n',
        'c', 'a', 'r', 'a', 'f', 'e', '\n',
        'c', 'a', 'r', 'a', 'm', 'e', 'l', '\n',
        'c', 'a', 'r', 'a', 'm', 'e', 'l', 'i', 's', 'e', 'd', '\n',
        'c', 'a', 'r', 'a', 'm', 'e', 'l', 's', '\n',
        'c', 'a', 'r', 'a', 'p', 'a', 'c', 'e', '\n',
        'c', 'a', 'r', 'a', 't', '\n',
        'c', 'a', 'r', 'a', 't', 's', '\n',
        'c', 'a', 'r', 'a', 'v', 'a', 'n', '\n',
        'c', 'a', 'r', 'a', 'v', 'a', 'n', 'n', 'i', 'n', 'g', '\n',
        'c', 'a', 'r', 'a', 'v', 'a', 'n', 's', '\n',
        'c', 'a', 'r', 'a', 'v', 'e', 'l', '\n',
        'c', 'a', 'r', 'a', 'w', 'a', 'y', '\n',
        'c', 'a', 'r', 'b', 'i', 'd', 'e', '\n',
        'c', 'a', 'r', 'b', 'i', 'n', 'e', '\n',
        'c', 'a', 'r', 'b', 'i', 'n', 'e', 's', '\n',
        'c', 'a', 'r', 'b', 'o', 'h', 'y', 'd', 'r', 'a', 't', 'e', '\n',
        'c', 'a', 'r', 'b', 'o', 'h', 'y', 'd', 'r', 'a', 't', 'e', 's', '\n',
        'c', 'a', 'r', 'b', 'o', 'l', 'i', 'c', '\n',
        'c', 'a', 'r', 'b', 'o', 'n', '\n',
        'c', 'a', 'r', 'b', 'o', 'n', 'a', 'c', 'e', 'o', 'u', 's', '\n',
        'c', 'a', 'r', 'b', 'o', 'n', 'a', 't', 'e', '\n',
        'c', 'a', 'r', 'b', 'o', 'n', 'a', 't', 'e', 'd', '\n',
        'c', 'a', 'r', 'b', 'o', 'n', 'a', 't', 'e', 's', '\n',
        'c', 'a', 'r', 'b', 'o', 'n', 'i', 'c', '\n',
        'c', 'a', 'r', 'b', 'o', 'n', 'i', 'f', 'e', 'r', 'o', 'u', 's', '\n',
        'c', 'a', 'r', 'b', 'o', 'n', 'i', 's', 'e', '\n',
        'c', 'a', 'r', 'b', 'o', 'n', 's', '\n',
        'c', 'a', 'r', 'b', 'o', 'n', 'y', 'l', '\n',
        'c', 'a', 'r', 'b', 'o', 'r', 'u', 'n', 'd', 'u', 'm', '\n',
        'c', 'a', 'r', 'b', 'o', 'x', 'y', 'l', '\n',
        'c', 'a', 'r', 'b', 'u', 'n', 'c', 'l', 'e', '\n',
        'c', 'a', 'r', 'b', 'u', 'n', 'c', 'l', 'e', 's', '\n',
        'c', 'a', 'r', 'b', 'u', 'r', 'e', 't', 't', 'o', 'r', '\n',
        'c', 'a', 'r', 'b', 'u', 'r', 'e', 't', 't', 'o', 'r', 's', '\n',
        'c', 'a', 'r', 'c', 'a', 's', 'e', '\n',
        'c', 'a', 'r', 'c', 'a', 's', 'e', 's', '\n',
        'c', 'a', 'r', 'c', 'a', 's', 's', '\n',
        'c', 'a', 'r', 'c', 'a', 's', 's', 'e', 's', '\n',
        'c', 'a', 'r', 'c', 'i', 'n', 'o', 'g', 'e', 'n', '\n',
        'c', 'a', 'r', 'c', 'i', 'n', 'o', 'g', 'e', 'n', 'e', 's', 'i', 's', '\n',
        'c', 'a', 'r', 'c', 'i', 'n', 'o', 'g', 'e', 'n', 'i', 'c', '\n',
        'c', 'a', 'r', 'c', 'i', 'n', 'o', 'g', 'e', 'n', 's', '\n',
        'c', 'a', 'r', 'c', 'i', 'n', 'o', 'm', 'a', '\n',
        'c', 'a', 'r', 'c', 'i', 'n', 'o', 'm', 'a', 's', '\n',
        'c', 'a', 'r', 'd', '\n',
        'c', 'a', 'r', 'd', 'b', 'o', 'a', 'r', 'd', '\n',
        'c', 'a', 'r', 'd', 'e', 'd', '\n',
        'c', 'a', 'r', 'd', 'h', 'o', 'l', 'd', 'e', 'r', 's', '\n',
        'c', 'a', 'r', 'd', 'i', 'a', 'c', '\n',
        'c', 'a', 'r', 'd', 'i', 'f', 'f', '\n',
        'c', 'a', 'r', 'd', 'i', 'g', 'a', 'n', '\n',
        'c', 'a', 'r', 'd', 'i', 'g', 'a', 'n', 's', '\n',
        'c', 'a', 'r', 'd', 'i', 'n', 'a', 'l', '\n',
        'c', 'a', 'r', 'd', 'i', 'n', 'a', 'l', 'i', 't', 'y', '\n',
        'c', 'a', 'r', 'd', 'i', 'n', 'a', 'l', 's', '\n',
        'c', 'a', 'r', 'd', 'i', 'n', 'g', '\n',
        'c', 'a', 'r', 'd', 'i', 'o', 'i', 'd', '\n',
        'c', 'a', 'r', 'd', 'i', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'c', 'a', 'r', 'd', 'i', 'o', 'l', 'o', 'g', 'y', '\n',
        'c', 'a', 'r', 'd', 'i', 'o', 'p', 'u', 'l', 'm', 'o', 'n', 'a', 'r', 'y', '\n',
        'c', 'a', 'r', 'd', 'i', 'o', 'v', 'a', 's', 'c', 'u', 'l', 'a', 'r', '\n',
        'c', 'a', 'r', 'd', 's', '\n',
        'c', 'a', 'r', 'e', '\n',
        'c', 'a', 'r', 'e', 'd', '\n',
        'c', 'a', 'r', 'e', 'e', 'r', '\n',
        'c', 'a', 'r', 'e', 'e', 'r', 'e', 'd', '\n',
        'c', 'a', 'r', 'e', 'e', 'r', 'i', 'n', 'g', '\n',
        'c', 'a', 'r', 'e', 'e', 'r', 'i', 's', 'm', '\n',
        'c', 'a', 'r', 'e', 'e', 'r', 'i', 's', 't', '\n',
        'c', 'a', 'r', 'e', 'e', 'r', 'i', 's', 't', 's', '\n',
        'c', 'a', 'r', 'e', 'e', 'r', 's', '\n',
        'c', 'a', 'r', 'e', 'f', 'r', 'e', 'e', '\n',
        'c', 'a', 'r', 'e', 'f', 'u', 'l', '\n',
        'c', 'a', 'r', 'e', 'f', 'u', 'l', 'l', 'y', '\n',
        'c', 'a', 'r', 'e', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'c', 'a', 'r', 'e', 'l', 'e', 's', 's', '\n',
        'c', 'a', 'r', 'e', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'c', 'a', 'r', 'e', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'c', 'a', 'r', 'e', 'r', '\n',
        'c', 'a', 'r', 'e', 'r', 's', '\n',
        'c', 'a', 'r', 'e', 's', '\n',
        'c', 'a', 'r', 'e', 's', 's', '\n',
        'c', 'a', 'r', 'e', 's', 's', 'e', 'd', '\n',
        'c', 'a', 'r', 'e', 's', 's', 'e', 's', '\n',
        'c', 'a', 'r', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'c', 'a', 'r', 'e', 's', 's', 'i', 'n', 'g', 'l', 'y', '\n',
        'c', 'a', 'r', 'e', 't', 'a', 'k', 'e', 'r', '\n',
        'c', 'a', 'r', 'e', 't', 'a', 'k', 'e', 'r', 's', '\n',
        'c', 'a', 'r', 'e', 't', 's', '\n',
        'c', 'a', 'r', 'e', 'w', 'o', 'r', 'n', '\n',
        'c', 'a', 'r', 'g', 'o', '\n',
        'c', 'a', 'r', 'i', 'b', 'o', 'u', '\n',
        'c', 'a', 'r', 'i', 'c', 'a', 't', 'u', 'r', 'e', '\n',
        'c', 'a', 'r', 'i', 'c', 'a', 't', 'u', 'r', 'e', 'd', '\n',
        'c', 'a', 'r', 'i', 'c', 'a', 't', 'u', 'r', 'e', 's', '\n',
        'c', 'a', 'r', 'i', 'c', 'a', 't', 'u', 'r', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'a', 'r', 'i', 'e', 's', '\n',
        'c', 'a', 'r', 'i', 'n', 'g', '\n',
        'c', 'a', 'r', 'm', 'i', 'n', 'e', '\n',
        'c', 'a', 'r', 'n', 'a', 'g', 'e', '\n',
        'c', 'a', 'r', 'n', 'a', 'g', 'e', 's', '\n',
        'c', 'a', 'r', 'n', 'a', 'l', '\n',
        'c', 'a', 'r', 'n', 'a', 'l', 'i', 't', 'y', '\n',
        'c', 'a', 'r', 'n', 'a', 'l', 'l', 'y', '\n',
        'c', 'a', 'r', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'a', 'r', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'a', 'r', 'n', 'i', 'v', 'a', 'l', '\n',
        'c', 'a', 'r', 'n', 'i', 'v', 'a', 'l', 's', '\n',
        'c', 'a', 'r', 'n', 'i', 'v', 'o', 'r', 'e', '\n',
        'c', 'a', 'r', 'n', 'i', 'v', 'o', 'r', 'e', 's', '\n',
        'c', 'a', 'r', 'n', 'i', 'v', 'o', 'r', 'o', 'u', 's', '\n',
        'c', 'a', 'r', 'n', 'i', 'v', 'o', 'r', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'c', 'a', 'r', 'o', 'l', '\n',
        'c', 'a', 'r', 'o', 'l', 's', '\n',
        'c', 'a', 'r', 'o', 't', 'e', 'n', 'e', '\n',
        'c', 'a', 'r', 'o', 't', 'i', 'd', '\n',
        'c', 'a', 'r', 'o', 't', 'i', 'n', '\n',
        'c', 'a', 'r', 'o', 'u', 's', 'e', '\n',
        'c', 'a', 'r', 'o', 'u', 's', 'e', 'l', '\n',
        'c', 'a', 'r', 'o', 'u', 's', 'i', 'n', 'g', '\n',
        'c', 'a', 'r', 'p', '\n',
        'c', 'a', 'r', 'p', 'a', 'l', '\n',
        'c', 'a', 'r', 'p', 'e', 'n', 't', 'e', 'r', '\n',
        'c', 'a', 'r', 'p', 'e', 'n', 't', 'e', 'r', 's', '\n',
        'c', 'a', 'r', 'p', 'e', 'n', 't', 'r', 'y', '\n',
        'c', 'a', 'r', 'p', 'e', 't', '\n',
        'c', 'a', 'r', 'p', 'e', 't', 'e', 'd', '\n',
        'c', 'a', 'r', 'p', 'e', 't', 'i', 'n', 'g', '\n',
        'c', 'a', 'r', 'p', 'e', 't', 's', '\n',
        'c', 'a', 'r', 'p', 'i', 'n', 'g', '\n',
        'c', 'a', 'r', 'p', 'o', 'r', 't', '\n',
        'c', 'a', 'r', 'p', 'o', 'r', 't', 's', '\n',
        'c', 'a', 'r', 'p', 's', '\n',
        'c', 'a', 'r', 'r', 'e', 'l', '\n',
        'c', 'a', 'r', 'r', 'i', 'a', 'g', 'e', '\n',
        'c', 'a', 'r', 'r', 'i', 'a', 'g', 'e', 's', '\n',
        'c', 'a', 'r', 'r', 'i', 'a', 'g', 'e', 'w', 'a', 'y', '\n',
        'c', 'a', 'r', 'r', 'i', 'a', 'g', 'e', 'w', 'a', 'y', 's', '\n',
        'c', 'a', 'r', 'r', 'i', 'e', 'd', '\n',
        'c', 'a', 'r', 'r', 'i', 'e', 'r', '\n',
        'c', 'a', 'r', 'r', 'i', 'e', 'r', 's', '\n',
        'c', 'a', 'r', 'r', 'i', 'e', 's', '\n',
        'c', 'a', 'r', 'r', 'i', 'o', 'n', '\n',
        'c', 'a', 'r', 'r', 'o', 't', '\n',
        'c', 'a', 'r', 'r', 'o', 't', 's', '\n',
        'c', 'a', 'r', 'r', 'o', 't', 'y', '\n',
        'c', 'a', 'r', 'r', 'y', '\n',
        'c', 'a', 'r', 'r', 'y', 'c', 'o', 't', '\n',
        'c', 'a', 'r', 'r', 'y', 'i', 'n', 'g', '\n',
        'c', 'a', 'r', 's', '\n',
        'c', 'a', 'r', 's', 'i', 'c', 'k', '\n',
        'c', 'a', 'r', 't', '\n',
        'c', 'a', 'r', 't', 'e', 'd', '\n',
        'c', 'a', 'r', 't', 'e', 'l', '\n',
        'c', 'a', 'r', 't', 'e', 'l', 's', '\n',
        'c', 'a', 'r', 't', 'e', 'r', '\n',
        'c', 'a', 'r', 't', 'h', 'o', 'r', 's', 'e', 's', '\n',
        'c', 'a', 'r', 't', 'i', 'l', 'a', 'g', 'e', '\n',
        'c', 'a', 'r', 't', 'i', 'n', 'g', '\n',
        'c', 'a', 'r', 't', 'l', 'o', 'a', 'd', '\n',
        'c', 'a', 'r', 't', 'l', 'o', 'a', 'd', 's', '\n',
        'c', 'a', 'r', 't', 'o', 'g', 'r', 'a', 'p', 'h', 'e', 'r', '\n',
        'c', 'a', 'r', 't', 'o', 'g', 'r', 'a', 'p', 'h', 'e', 'r', 's', '\n',
        'c', 'a', 'r', 't', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', '\n',
        'c', 'a', 'r', 't', 'o', 'g', 'r', 'a', 'p', 'h', 'y', '\n',
        'c', 'a', 'r', 't', 'o', 'n', '\n',
        'c', 'a', 'r', 't', 'o', 'n', 's', '\n',
        'c', 'a', 'r', 't', 'o', 'o', 'n', '\n',
        'c', 'a', 'r', 't', 'o', 'o', 'n', 'i', 's', 't', '\n',
        'c', 'a', 'r', 't', 'o', 'o', 'n', 'i', 's', 't', 's', '\n',
        'c', 'a', 'r', 't', 'o', 'o', 'n', 's', '\n',
        'c', 'a', 'r', 't', 'o', 'u', 'c', 'h', 'e', '\n',
        'c', 'a', 'r', 't', 'r', 'i', 'd', 'g', 'e', '\n',
        'c', 'a', 'r', 't', 'r', 'i', 'd', 'g', 'e', 's', '\n',
        'c', 'a', 'r', 't', 's', '\n',
        'c', 'a', 'r', 't', 'w', 'h', 'e', 'e', 'l', '\n',
        'c', 'a', 'r', 't', 'w', 'h', 'e', 'e', 'l', 's', '\n',
        'c', 'a', 'r', 'v', 'e', '\n',
        'c', 'a', 'r', 'v', 'e', 'd', '\n',
        'c', 'a', 'r', 'v', 'e', 'r', '\n',
        'c', 'a', 'r', 'v', 'e', 'r', 's', '\n',
        'c', 'a', 'r', 'v', 'e', 'r', 'y', '\n',
        'c', 'a', 'r', 'v', 'e', 's', '\n',
        'c', 'a', 'r', 'v', 'i', 'n', 'g', '\n',
        'c', 'a', 'r', 'v', 'i', 'n', 'g', 's', '\n',
        'c', 'a', 'r', 'y', 'a', 't', 'i', 'd', 's', '\n',
        'c', 'a', 's', 'a', 'n', 'o', 'v', 'a', '\n',
        'c', 'a', 's', 'c', 'a', 'd', 'e', '\n',
        'c', 'a', 's', 'c', 'a', 'd', 'e', 'd', '\n',
        'c', 'a', 's', 'c', 'a', 'd', 'e', 's', '\n',
        'c', 'a', 's', 'c', 'a', 'd', 'i', 'n', 'g', '\n',
        'c', 'a', 's', 'c', 'a', 'r', 'a', '\n',
        'c', 'a', 's', 'e', '\n',
        'c', 'a', 's', 'e', 'b', 'o', 'o', 'k', '\n',
        'c', 'a', 's', 'e', 'd', '\n',
        'c', 'a', 's', 'e', 'l', 'o', 'a', 'd', '\n',
        'c', 'a', 's', 'e', 'l', 'o', 'a', 'd', 's', '\n',
        'c', 'a', 's', 'e', 'm', 'e', 'n', 't', '\n',
        'c', 'a', 's', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'c', 'a', 's', 'e', 's', '\n',
        'c', 'a', 's', 'e', 'w', 'o', 'r', 'k', '\n',
        'c', 'a', 's', 'h', '\n',
        'c', 'a', 's', 'h', 'b', 'o', 'x', '\n',
        'c', 'a', 's', 'h', 'e', 'd', '\n',
        'c', 'a', 's', 'h', 'e', 's', '\n',
        'c', 'a', 's', 'h', 'e', 'w', '\n',
        'c', 'a', 's', 'h', 'i', 'e', 'r', '\n',
        'c', 'a', 's', 'h', 'i', 'e', 'r', 's', '\n',
        'c', 'a', 's', 'h', 'i', 'n', 'g', '\n',
        'c', 'a', 's', 'h', 'l', 'e', 's', 's', '\n',
        'c', 'a', 's', 'h', 'm', 'e', 'r', 'e', '\n',
        'c', 'a', 's', 'i', 'n', 'g', '\n',
        'c', 'a', 's', 'i', 'n', 'g', 's', '\n',
        'c', 'a', 's', 'i', 'n', 'o', '\n',
        'c', 'a', 's', 'k', '\n',
        'c', 'a', 's', 'k', 'e', 't', '\n',
        'c', 'a', 's', 'k', 'e', 't', 's', '\n',
        'c', 'a', 's', 'k', 's', '\n',
        'c', 'a', 's', 's', 'a', 'v', 'a', '\n',
        'c', 'a', 's', 's', 'e', 'r', 'o', 'l', 'e', '\n',
        'c', 'a', 's', 's', 'e', 'r', 'o', 'l', 'e', 's', '\n',
        'c', 'a', 's', 's', 'e', 't', 't', 'e', '\n',
        'c', 'a', 's', 's', 'e', 't', 't', 'e', 's', '\n',
        'c', 'a', 's', 's', 'o', 'c', 'k', '\n',
        'c', 'a', 's', 's', 'o', 'c', 'k', 's', '\n',
        'c', 'a', 's', 's', 'o', 'w', 'a', 'r', 'y', '\n',
        'c', 'a', 's', 't', '\n',
        'c', 'a', 's', 't', 'a', 'n', 'e', 't', '\n',
        'c', 'a', 's', 't', 'a', 'n', 'e', 't', 's', '\n',
        'c', 'a', 's', 't', 'a', 'w', 'a', 'y', '\n',
        'c', 'a', 's', 't', 'a', 'w', 'a', 'y', 's', '\n',
        'c', 'a', 's', 't', 'e', '\n',
        'c', 'a', 's', 't', 'e', 'l', 'l', 'a', 't', 'e', 'd', '\n',
        'c', 'a', 's', 't', 'e', 'r', '\n',
        'c', 'a', 's', 't', 'e', 'r', 's', '\n',
        'c', 'a', 's', 't', 'e', 's', '\n',
        'c', 'a', 's', 't', 'i', 'g', 'a', 't', 'e', '\n',
        'c', 'a', 's', 't', 'i', 'g', 'a', 't', 'e', 'd', '\n',
        'c', 'a', 's', 't', 'i', 'g', 'a', 't', 'e', 's', '\n',
        'c', 'a', 's', 't', 'i', 'g', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'a', 's', 't', 'i', 'n', 'g', '\n',
        'c', 'a', 's', 't', 'i', 'n', 'g', 's', '\n',
        'c', 'a', 's', 't', 'i', 'r', 'o', 'n', '\n',
        'c', 'a', 's', 't', 'l', 'e', '\n',
        'c', 'a', 's', 't', 'l', 'e', 'd', '\n',
        'c', 'a', 's', 't', 'l', 'e', 's', '\n',
        'c', 'a', 's', 't', 'l', 'i', 'n', 'g', '\n',
        'c', 'a', 's', 't', 'o', 'f', 'f', '\n',
        'c', 'a', 's', 't', 'o', 'f', 'f', 's', '\n',
        'c', 'a', 's', 't', 'o', 'r', '\n',
        'c', 'a', 's', 't', 'o', 'r', 's', '\n',
        'c', 'a', 's', 't', 'r', 'a', 't', 'e', '\n',
        'c', 'a', 's', 't', 'r', 'a', 't', 'e', 'd', '\n',
        'c', 'a', 's', 't', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'a', 's', 't', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'a', 's', 't', 'r', 'a', 't', 'o', '\n',
        'c', 'a', 's', 't', 's', '\n',
        'c', 'a', 's', 'u', 'a', 'l', '\n',
        'c', 'a', 's', 'u', 'a', 'l', 'l', 'y', '\n',
        'c', 'a', 's', 'u', 'a', 'l', 'n', 'e', 's', 's', '\n',
        'c', 'a', 's', 'u', 'a', 'l', 's', '\n',
        'c', 'a', 's', 'u', 'a', 'l', 't', 'i', 'e', 's', '\n',
        'c', 'a', 's', 'u', 'a', 'l', 't', 'y', '\n',
        'c', 'a', 's', 'u', 'i', 's', 't', 'r', 'y', '\n',
        'c', 'a', 't', '\n',
        'c', 'a', 't', 'a', 'c', 'l', 'y', 's', 'm', '\n',
        'c', 'a', 't', 'a', 'c', 'l', 'y', 's', 'm', 'i', 'c', '\n',
        'c', 'a', 't', 'a', 'c', 'o', 'm', 'b', '\n',
        'c', 'a', 't', 'a', 'c', 'o', 'm', 'b', 's', '\n',
        'c', 'a', 't', 'a', 'l', 'e', 'p', 's', 'y', '\n',
        'c', 'a', 't', 'a', 'l', 'o', 'g', 'u', 'e', '\n',
        'c', 'a', 't', 'a', 'l', 'o', 'g', 'u', 'e', 'd', '\n',
        'c', 'a', 't', 'a', 'l', 'o', 'g', 'u', 'e', 'r', '\n',
        'c', 'a', 't', 'a', 'l', 'o', 'g', 'u', 'e', 'r', 's', '\n',
        'c', 'a', 't', 'a', 'l', 'o', 'g', 'u', 'e', 's', '\n',
        'c', 'a', 't', 'a', 'l', 'o', 'g', 'u', 'i', 'n', 'g', '\n',
        'c', 'a', 't', 'a', 'l', 'y', 's', 'e', '\n',
        'c', 'a', 't', 'a', 'l', 'y', 's', 'e', 'd', '\n',
        'c', 'a', 't', 'a', 'l', 'y', 's', 'e', 's', '\n',
        'c', 'a', 't', 'a', 'l', 'y', 's', 'i', 'n', 'g', '\n',
        'c', 'a', 't', 'a', 'l', 'y', 's', 'i', 's', '\n',
        'c', 'a', 't', 'a', 'l', 'y', 's', 't', '\n',
        'c', 'a', 't', 'a', 'l', 'y', 's', 't', 's', '\n',
        'c', 'a', 't', 'a', 'l', 'y', 't', 'i', 'c', '\n',
        'c', 'a', 't', 'a', 'm', 'a', 'r', 'a', 'n', '\n',
        'c', 'a', 't', 'a', 'm', 'a', 'r', 'a', 'n', 's', '\n',
        'c', 'a', 't', 'a', 'n', 'd', 'd', 'o', 'g', '\n',
        'c', 'a', 't', 'a', 'p', 'u', 'l', 't', '\n',
        'c', 'a', 't', 'a', 'p', 'u', 'l', 't', 'e', 'd', '\n',
        'c', 'a', 't', 'a', 'p', 'u', 'l', 't', 'i', 'n', 'g', '\n',
        'c', 'a', 't', 'a', 'p', 'u', 'l', 't', 's', '\n',
        'c', 'a', 't', 'a', 'r', 'a', 'c', 't', '\n',
        'c', 'a', 't', 'a', 'r', 'a', 'c', 't', 's', '\n',
        'c', 'a', 't', 'a', 'r', 'r', 'h', '\n',
        'c', 'a', 't', 'a', 's', 't', 'r', 'o', 'p', 'h', 'e', '\n',
        'c', 'a', 't', 'a', 's', 't', 'r', 'o', 'p', 'h', 'e', 's', '\n',
        'c', 'a', 't', 'a', 's', 't', 'r', 'o', 'p', 'h', 'i', 'c', '\n',
        'c', 'a', 't', 'a', 's', 't', 'r', 'o', 'p', 'h', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'c', 'a', 't', 'a', 't', 'o', 'n', 'i', 'c', '\n',
        'c', 'a', 't', 'c', 'a', 'l', 'l', 's', '\n',
        'c', 'a', 't', 'c', 'h', '\n',
        'c', 'a', 't', 'c', 'h', 'e', 'd', '\n',
        'c', 'a', 't', 'c', 'h', 'e', 'r', '\n',
        'c', 'a', 't', 'c', 'h', 'e', 'r', 's', '\n',
        'c', 'a', 't', 'c', 'h', 'e', 's', '\n',
        'c', 'a', 't', 'c', 'h', 'i', 'e', 'r', '\n',
        'c', 'a', 't', 'c', 'h', 'i', 'e', 's', 't', '\n',
        'c', 'a', 't', 'c', 'h', 'i', 'n', 'g', '\n',
        'c', 'a', 't', 'c', 'h', 'm', 'e', 'n', 't', '\n',
        'c', 'a', 't', 'c', 'h', 'p', 'h', 'r', 'a', 's', 'e', '\n',
        'c', 'a', 't', 'c', 'h', 'p', 'h', 'r', 'a', 's', 'e', 's', '\n',
        'c', 'a', 't', 'c', 'h', 'w', 'o', 'r', 'd', '\n',
        'c', 'a', 't', 'c', 'h', 'w', 'o', 'r', 'd', 's', '\n',
        'c', 'a', 't', 'c', 'h', 'y', '\n',
        'c', 'a', 't', 'e', 'c', 'h', 'i', 's', 'm', '\n',
        'c', 'a', 't', 'e', 'c', 'h', 'i', 's', 'm', 's', '\n',
        'c', 'a', 't', 'e', 'c', 'h', 'i', 's', 't', '\n',
        'c', 'a', 't', 'e', 'c', 'h', 'i', 's', 't', 's', '\n',
        'c', 'a', 't', 'e', 'g', 'o', 'r', 'i', 'c', 'a', 'l', '\n',
        'c', 'a', 't', 'e', 'g', 'o', 'r', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'c', 'a', 't', 'e', 'g', 'o', 'r', 'i', 'e', 's', '\n',
        'c', 'a', 't', 'e', 'g', 'o', 'r', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'a', 't', 'e', 'g', 'o', 'r', 'i', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'a', 't', 'e', 'g', 'o', 'r', 'i', 's', 'e', '\n',
        'c', 'a', 't', 'e', 'g', 'o', 'r', 'i', 's', 'e', 'd', '\n',
        'c', 'a', 't', 'e', 'g', 'o', 'r', 'i', 's', 'e', 's', '\n',
        'c', 'a', 't', 'e', 'g', 'o', 'r', 'i', 's', 'i', 'n', 'g', '\n',
        'c', 'a', 't', 'e', 'g', 'o', 'r', 'y', '\n',
        'c', 'a', 't', 'e', 'r', '\n',
        'c', 'a', 't', 'e', 'r', 'e', 'd', '\n',
        'c', 'a', 't', 'e', 'r', 'e', 'r', '\n',
        'c', 'a', 't', 'e', 'r', 'e', 'r', 's', '\n',
        'c', 'a', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'c', 'a', 't', 'e', 'r', 'p', 'i', 'l', 'l', 'a', 'r', '\n',
        'c', 'a', 't', 'e', 'r', 'p', 'i', 'l', 'l', 'a', 'r', 's', '\n',
        'c', 'a', 't', 'e', 'r', 's', '\n',
        'c', 'a', 't', 'e', 'r', 'w', 'a', 'u', 'l', '\n',
        'c', 'a', 't', 'e', 'r', 'w', 'a', 'u', 'l', 's', '\n',
        'c', 'a', 't', 'f', 'i', 's', 'h', '\n',
        'c', 'a', 't', 'g', 'u', 't', '\n',
        'c', 'a', 't', 'g', 'u', 't', 's', '\n',
        'c', 'a', 't', 'h', 'a', 'r', 's', 'i', 's', '\n',
        'c', 'a', 't', 'h', 'a', 'r', 't', 'i', 'c', '\n',
        'c', 'a', 't', 'h', 'e', 'd', 'r', 'a', 'l', '\n',
        'c', 'a', 't', 'h', 'e', 'd', 'r', 'a', 'l', 's', '\n',
        'c', 'a', 't', 'h', 'e', 't', 'e', 'r', '\n',
        'c', 'a', 't', 'h', 'e', 't', 'e', 'r', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'a', 't', 'h', 'e', 't', 'e', 'r', 's', '\n',
        'c', 'a', 't', 'h', 'o', 'd', 'e', '\n',
        'c', 'a', 't', 'h', 'o', 'd', 'e', 's', '\n',
        'c', 'a', 't', 'h', 'o', 'l', 'i', 'c', '\n',
        'c', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'a', 't', 'i', 'o', 'n', 'i', 'c', '\n',
        'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'a', 't', 'l', 'i', 'k', 'e', '\n',
        'c', 'a', 't', 'n', 'a', 'p', '\n',
        'c', 'a', 't', 'n', 'i', 'p', '\n',
        'c', 'a', 't', 's', '\n',
        'c', 'a', 't', 's', 'u', 'i', 't', '\n',
        'c', 'a', 't', 't', 'e', 'r', 'y', '\n',
        'c', 'a', 't', 't', 'l', 'e', '\n',
        'c', 'a', 't', 'w', 'a', 'l', 'k', '\n',
        'c', 'a', 't', 'w', 'a', 'l', 'k', 's', '\n',
        'c', 'a', 'u', 'c', 'u', 's', '\n',
        'c', 'a', 'u', 'c', 'u', 's', 'e', 's', '\n',
        'c', 'a', 'u', 'd', 'a', 'l', '\n',
        'c', 'a', 'u', 'g', 'h', 't', '\n',
        'c', 'a', 'u', 'l', 'd', 'r', 'o', 'n', '\n',
        'c', 'a', 'u', 'l', 'd', 'r', 'o', 'n', 's', '\n',
        'c', 'a', 'u', 'l', 'i', 'f', 'l', 'o', 'w', 'e', 'r', '\n',
        'c', 'a', 'u', 'l', 'i', 'f', 'l', 'o', 'w', 'e', 'r', 's', '\n',
        'c', 'a', 'u', 'l', 'k', 'i', 'n', 'g', '\n',
        'c', 'a', 'u', 's', 'a', 'l', '\n',
        'c', 'a', 'u', 's', 'a', 'l', 'i', 't', 'y', '\n',
        'c', 'a', 'u', 's', 'a', 'l', 'l', 'y', '\n',
        'c', 'a', 'u', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'a', 'u', 's', 'a', 't', 'i', 'v', 'e', '\n',
        'c', 'a', 'u', 's', 'e', '\n',
        'c', 'a', 'u', 's', 'e', 'd', '\n',
        'c', 'a', 'u', 's', 'e', 's', '\n',
        'c', 'a', 'u', 's', 'e', 'w', 'a', 'y', '\n',
        'c', 'a', 'u', 's', 'e', 'w', 'a', 'y', 's', '\n',
        'c', 'a', 'u', 's', 'i', 'n', 'g', '\n',
        'c', 'a', 'u', 's', 't', 'i', 'c', '\n',
        'c', 'a', 'u', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'c', 'a', 'u', 's', 't', 'i', 'c', 's', '\n',
        'c', 'a', 'u', 't', 'e', 'r', 'i', 's', 'e', '\n',
        'c', 'a', 'u', 't', 'e', 'r', 'i', 's', 'i', 'n', 'g', '\n',
        'c', 'a', 'u', 't', 'i', 'o', 'n', '\n',
        'c', 'a', 'u', 't', 'i', 'o', 'n', 'a', 'r', 'y', '\n',
        'c', 'a', 'u', 't', 'i', 'o', 'n', 'e', 'd', '\n',
        'c', 'a', 'u', 't', 'i', 'o', 'n', 'i', 'n', 'g', '\n',
        'c', 'a', 'u', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'a', 'u', 't', 'i', 'o', 'u', 's', '\n',
        'c', 'a', 'u', 't', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'c', 'a', 'u', 't', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'c', 'a', 'v', 'a', 'l', 'c', 'a', 'd', 'e', '\n',
        'c', 'a', 'v', 'a', 'l', 'i', 'e', 'r', '\n',
        'c', 'a', 'v', 'a', 'l', 'i', 'e', 'r', 'l', 'y', '\n',
        'c', 'a', 'v', 'a', 'l', 'i', 'e', 'r', 's', '\n',
        'c', 'a', 'v', 'a', 'l', 'r', 'y', '\n',
        'c', 'a', 'v', 'a', 'l', 'r', 'y', 'm', 'a', 'n', '\n',
        'c', 'a', 'v', 'a', 'l', 'r', 'y', 'm', 'e', 'n', '\n',
        'c', 'a', 'v', 'e', '\n',
        'c', 'a', 'v', 'e', 'a', 't', '\n',
        'c', 'a', 'v', 'e', 'a', 't', 's', '\n',
        'c', 'a', 'v', 'e', 'd', '\n',
        'c', 'a', 'v', 'e', 'i', 'n', '\n',
        'c', 'a', 'v', 'e', 'm', 'a', 'n', '\n',
        'c', 'a', 'v', 'e', 'm', 'e', 'n', '\n',
        'c', 'a', 'v', 'e', 'r', '\n',
        'c', 'a', 'v', 'e', 'r', 'n', '\n',
        'c', 'a', 'v', 'e', 'r', 'n', 'o', 'u', 's', '\n',
        'c', 'a', 'v', 'e', 'r', 'n', 's', '\n',
        'c', 'a', 'v', 'e', 'r', 's', '\n',
        'c', 'a', 'v', 'e', 's', '\n',
        'c', 'a', 'v', 'i', 'a', 'r', '\n',
        'c', 'a', 'v', 'i', 'a', 'r', 'e', '\n',
        'c', 'a', 'v', 'i', 'a', 'r', 's', '\n',
        'c', 'a', 'v', 'i', 'n', 'g', '\n',
        'c', 'a', 'v', 'i', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'a', 'v', 'i', 't', 'i', 'e', 's', '\n',
        'c', 'a', 'v', 'i', 't', 'y', '\n',
        'c', 'a', 'v', 'o', 'r', 't', '\n',
        'c', 'a', 'v', 'o', 'r', 't', 'e', 'd', '\n',
        'c', 'a', 'v', 'o', 'r', 't', 'i', 'n', 'g', '\n',
        'c', 'a', 'v', 'o', 'r', 't', 's', '\n',
        'c', 'a', 'w', '\n',
        'c', 'a', 'w', 'i', 'n', 'g', '\n',
        'c', 'a', 'y', 'm', 'a', 'n', '\n',
        'c', 'a', 'y', 'm', 'a', 'n', 's', '\n',
        'c', 'e', 'a', 's', 'e', '\n',
        'c', 'e', 'a', 's', 'e', 'd', '\n',
        'c', 'e', 'a', 's', 'e', 'f', 'i', 'r', 'e', '\n',
        'c', 'e', 'a', 's', 'e', 'f', 'i', 'r', 'e', 's', '\n',
        'c', 'e', 'a', 's', 'e', 'l', 'e', 's', 's', '\n',
        'c', 'e', 'a', 's', 'e', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'c', 'e', 'a', 's', 'e', 's', '\n',
        'c', 'e', 'a', 's', 'i', 'n', 'g', '\n',
        'c', 'e', 'd', 'a', 'r', '\n',
        'c', 'e', 'd', 'a', 'r', 's', '\n',
        'c', 'e', 'd', 'a', 'r', 'w', 'o', 'o', 'd', '\n',
        'c', 'e', 'd', 'e', '\n',
        'c', 'e', 'd', 'e', 'd', '\n',
        'c', 'e', 'd', 'i', 'l', 'l', 'a', '\n',
        'c', 'e', 'd', 'i', 'n', 'g', '\n',
        'c', 'e', 'i', 'l', 'i', 'd', 'h', '\n',
        'c', 'e', 'i', 'l', 'i', 'd', 'h', 's', '\n',
        'c', 'e', 'i', 'l', 'i', 'n', 'g', '\n',
        'c', 'e', 'i', 'l', 'i', 'n', 'g', 's', '\n',
        'c', 'e', 'l', 'a', 'n', 'd', 'i', 'n', 'e', '\n',
        'c', 'e', 'l', 'e', 'b', '\n',
        'c', 'e', 'l', 'e', 'b', 'r', 'a', 'n', 't', '\n',
        'c', 'e', 'l', 'e', 'b', 'r', 'a', 'n', 't', 's', '\n',
        'c', 'e', 'l', 'e', 'b', 'r', 'a', 't', 'e', '\n',
        'c', 'e', 'l', 'e', 'b', 'r', 'a', 't', 'e', 'd', '\n',
        'c', 'e', 'l', 'e', 'b', 'r', 'a', 't', 'e', 's', '\n',
        'c', 'e', 'l', 'e', 'b', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'e', 'l', 'e', 'b', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'e', 'l', 'e', 'b', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'e', 'l', 'e', 'b', 'r', 'a', 't', 'o', 'r', 'y', '\n',
        'c', 'e', 'l', 'e', 'b', 'r', 'i', 't', 'i', 'e', 's', '\n',
        'c', 'e', 'l', 'e', 'b', 'r', 'i', 't', 'y', '\n',
        'c', 'e', 'l', 'e', 'r', 'i', 'a', 'c', '\n',
        'c', 'e', 'l', 'e', 'r', 'y', '\n',
        'c', 'e', 'l', 'e', 's', 't', 'i', 'a', 'l', '\n',
        'c', 'e', 'l', 'e', 's', 't', 'i', 'a', 'l', 'l', 'y', '\n',
        'c', 'e', 'l', 'i', 'b', 'a', 'c', 'y', '\n',
        'c', 'e', 'l', 'i', 'b', 'a', 't', 'e', '\n',
        'c', 'e', 'l', 'l', '\n',
        'c', 'e', 'l', 'l', 'a', 'r', '\n',
        'c', 'e', 'l', 'l', 'a', 'r', 's', '\n',
        'c', 'e', 'l', 'l', 'i', 's', 't', '\n',
        'c', 'e', 'l', 'l', 'i', 's', 't', 's', '\n',
        'c', 'e', 'l', 'l', 'o', '\n',
        'c', 'e', 'l', 'l', 'o', 'p', 'h', 'a', 'n', 'e', '\n',
        'c', 'e', 'l', 'l', 's', '\n',
        'c', 'e', 'l', 'l', 'u', 'l', 'a', 'r', '\n',
        'c', 'e', 'l', 'l', 'u', 'l', 'i', 't', 'e', '\n',
        'c', 'e', 'l', 'l', 'u', 'l', 'o', 'i', 'd', '\n',
        'c', 'e', 'l', 'l', 'u', 'l', 'o', 's', 'e', '\n',
        'c', 'e', 'l', 's', 'i', 'u', 's', '\n',
        'c', 'e', 'l', 't', 'i', 'c', '\n',
        'c', 'e', 'm', 'e', 'n', 't', '\n',
        'c', 'e', 'm', 'e', 'n', 't', 'e', 'd', '\n',
        'c', 'e', 'm', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'c', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'c', 'e', 'm', 'e', 't', 'e', 'r', 'i', 'e', 's', '\n',
        'c', 'e', 'm', 'e', 't', 'e', 'r', 'y', '\n',
        'c', 'e', 'n', 'o', 't', 'a', 'p', 'h', '\n',
        'c', 'e', 'n', 's', 'e', 'r', '\n',
        'c', 'e', 'n', 's', 'o', 'r', '\n',
        'c', 'e', 'n', 's', 'o', 'r', 'e', 'd', '\n',
        'c', 'e', 'n', 's', 'o', 'r', 'i', 'a', 'l', '\n',
        'c', 'e', 'n', 's', 'o', 'r', 'i', 'n', 'g', '\n',
        'c', 'e', 'n', 's', 'o', 'r', 'i', 'o', 'u', 's', '\n',
        'c', 'e', 'n', 's', 'o', 'r', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'c', 'e', 'n', 's', 'o', 'r', 's', '\n',
        'c', 'e', 'n', 's', 'o', 'r', 's', 'h', 'i', 'p', '\n',
        'c', 'e', 'n', 's', 'u', 'r', 'e', '\n',
        'c', 'e', 'n', 's', 'u', 'r', 'e', 'd', '\n',
        'c', 'e', 'n', 's', 'u', 'r', 'e', 's', '\n',
        'c', 'e', 'n', 's', 'u', 'r', 'i', 'n', 'g', '\n',
        'c', 'e', 'n', 's', 'u', 's', '\n',
        'c', 'e', 'n', 's', 'u', 's', 'e', 's', '\n',
        'c', 'e', 'n', 't', '\n',
        'c', 'e', 'n', 't', 'a', 'u', 'r', '\n',
        'c', 'e', 'n', 't', 'a', 'u', 'r', 's', '\n',
        'c', 'e', 'n', 't', 'e', 'n', 'a', 'r', 'i', 'a', 'n', 's', '\n',
        'c', 'e', 'n', 't', 'e', 'n', 'a', 'r', 'y', '\n',
        'c', 'e', 'n', 't', 'e', 'n', 'n', 'i', 'a', 'l', '\n',
        'c', 'e', 'n', 't', 'i', 'g', 'r', 'a', 'd', 'e', '\n',
        'c', 'e', 'n', 't', 'i', 'm', 'e', '\n',
        'c', 'e', 'n', 't', 'i', 'm', 'e', 's', '\n',
        'c', 'e', 'n', 't', 'i', 'm', 'e', 't', 'r', 'e', '\n',
        'c', 'e', 'n', 't', 'i', 'm', 'e', 't', 'r', 'e', 's', '\n',
        'c', 'e', 'n', 't', 'i', 'p', 'e', 'd', 'e', '\n',
        'c', 'e', 'n', 't', 'i', 'p', 'e', 'd', 'e', 's', '\n',
        'c', 'e', 'n', 't', 'r', 'a', 'l', '\n',
        'c', 'e', 'n', 't', 'r', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'e', 'n', 't', 'r', 'a', 'l', 'i', 's', 'e', '\n',
        'c', 'e', 'n', 't', 'r', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'c', 'e', 'n', 't', 'r', 'a', 'l', 'i', 's', 'e', 'r', '\n',
        'c', 'e', 'n', 't', 'r', 'a', 'l', 'i', 's', 'e', 'r', 's', '\n',
        'c', 'e', 'n', 't', 'r', 'a', 'l', 'i', 's', 'e', 's', '\n',
        'c', 'e', 'n', 't', 'r', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'c', 'e', 'n', 't', 'r', 'a', 'l', 'i', 's', 'm', '\n',
        'c', 'e', 'n', 't', 'r', 'a', 'l', 'i', 's', 't', '\n',
        'c', 'e', 'n', 't', 'r', 'a', 'l', 'i', 't', 'y', '\n',
        'c', 'e', 'n', 't', 'r', 'a', 'l', 'l', 'y', '\n',
        'c', 'e', 'n', 't', 'r', 'e', '\n',
        'c', 'e', 'n', 't', 'r', 'e', 'd', '\n',
        'c', 'e', 'n', 't', 'r', 'e', 'f', 'o', 'l', 'd', '\n',
        'c', 'e', 'n', 't', 'r', 'e', 'f', 'o', 'l', 'd', 's', '\n',
        'c', 'e', 'n', 't', 'r', 'e', 'i', 'n', 'g', '\n',
        'c', 'e', 'n', 't', 'r', 'e', 'p', 'i', 'e', 'c', 'e', '\n',
        'c', 'e', 'n', 't', 'r', 'e', 'p', 'i', 'e', 'c', 'e', 's', '\n',
        'c', 'e', 'n', 't', 'r', 'e', 's', '\n',
        'c', 'e', 'n', 't', 'r', 'i', 'c', '\n',
        'c', 'e', 'n', 't', 'r', 'i', 'f', 'u', 'g', 'a', 'l', '\n',
        'c', 'e', 'n', 't', 'r', 'i', 'f', 'u', 'g', 'a', 'l', 'l', 'y', '\n',
        'c', 'e', 'n', 't', 'r', 'i', 'f', 'u', 'g', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'e', 'n', 't', 'r', 'i', 'f', 'u', 'g', 'e', '\n',
        'c', 'e', 'n', 't', 'r', 'i', 'f', 'u', 'g', 'e', 'd', '\n',
        'c', 'e', 'n', 't', 'r', 'i', 'f', 'u', 'g', 'e', 's', '\n',
        'c', 'e', 'n', 't', 'r', 'i', 'f', 'u', 'g', 'i', 'n', 'g', '\n',
        'c', 'e', 'n', 't', 'r', 'i', 'n', 'g', '\n',
        'c', 'e', 'n', 't', 'r', 'i', 'p', 'e', 't', 'a', 'l', '\n',
        'c', 'e', 'n', 't', 'r', 'i', 's', 't', '\n',
        'c', 'e', 'n', 't', 'r', 'i', 's', 't', 's', '\n',
        'c', 'e', 'n', 't', 'r', 'o', 'i', 'd', '\n',
        'c', 'e', 'n', 't', 'r', 'o', 'i', 'd', 's', '\n',
        'c', 'e', 'n', 't', 's', '\n',
        'c', 'e', 'n', 't', 'u', 'r', 'i', 'e', 's', '\n',
        'c', 'e', 'n', 't', 'u', 'r', 'i', 'o', 'n', '\n',
        'c', 'e', 'n', 't', 'u', 'r', 'i', 'o', 'n', 's', '\n',
        'c', 'e', 'n', 't', 'u', 'r', 'y', '\n',
        'c', 'e', 'p', 'h', 'a', 'l', 'o', 'p', 'o', 'd', 's', '\n',
        'c', 'e', 'r', 'a', 'm', 'i', 'c', '\n',
        'c', 'e', 'r', 'a', 'm', 'i', 'c', 's', '\n',
        'c', 'e', 'r', 'a', 'm', 'i', 's', 't', '\n',
        'c', 'e', 'r', 'e', 'a', 'l', '\n',
        'c', 'e', 'r', 'e', 'a', 'l', 's', '\n',
        'c', 'e', 'r', 'e', 'b', 'e', 'l', 'l', 'u', 'm', '\n',
        'c', 'e', 'r', 'e', 'b', 'r', 'a', 'l', '\n',
        'c', 'e', 'r', 'e', 'b', 'r', 'u', 'm', '\n',
        'c', 'e', 'r', 'e', 'm', 'o', 'n', 'i', 'a', 'l', '\n',
        'c', 'e', 'r', 'e', 'm', 'o', 'n', 'i', 'a', 'l', 'l', 'y', '\n',
        'c', 'e', 'r', 'e', 'm', 'o', 'n', 'i', 'a', 'l', 's', '\n',
        'c', 'e', 'r', 'e', 'm', 'o', 'n', 'i', 'e', 's', '\n',
        'c', 'e', 'r', 'e', 'm', 'o', 'n', 'i', 'o', 'u', 's', '\n',
        'c', 'e', 'r', 'e', 'm', 'o', 'n', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'c', 'e', 'r', 'e', 'm', 'o', 'n', 'y', '\n',
        'c', 'e', 'r', 'e', 's', '\n',
        'c', 'e', 'r', 'i', 's', 'e', '\n',
        'c', 'e', 'r', 't', 'a', 'i', 'n', '\n',
        'c', 'e', 'r', 't', 'a', 'i', 'n', 'l', 'y', '\n',
        'c', 'e', 'r', 't', 'a', 'i', 'n', 't', 'i', 'e', 's', '\n',
        'c', 'e', 'r', 't', 'a', 'i', 'n', 't', 'y', '\n',
        'c', 'e', 'r', 't', 'i', 'f', 'i', 'a', 'b', 'l', 'e', '\n',
        'c', 'e', 'r', 't', 'i', 'f', 'i', 'a', 'b', 'l', 'y', '\n',
        'c', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', '\n',
        'c', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 'd', '\n',
        'c', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 's', '\n',
        'c', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'e', 'r', 't', 'i', 'f', 'i', 'e', 'd', '\n',
        'c', 'e', 'r', 't', 'i', 'f', 'i', 'e', 's', '\n',
        'c', 'e', 'r', 't', 'i', 'f', 'y', '\n',
        'c', 'e', 'r', 't', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'c', 'e', 'r', 't', 'i', 't', 'u', 'd', 'e', '\n',
        'c', 'e', 'r', 't', 'i', 't', 'u', 'd', 'e', 's', '\n',
        'c', 'e', 'r', 'v', 'i', 'c', 'a', 'l', '\n',
        'c', 'e', 'r', 'v', 'i', 'x', '\n',
        'c', 'e', 's', 's', '\n',
        'c', 'e', 's', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'e', 's', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'e', 's', 's', 'i', 'o', 'n', '\n',
        'c', 'e', 's', 's', 'p', 'i', 't', '\n',
        'c', 'e', 's', 's', 'p', 'o', 'o', 'l', '\n',
        'c', 'e', 's', 's', 'p', 'o', 'o', 'l', 's', '\n',
        'c', 'e', 't', 'a', 'c', 'e', 'a', 'n', '\n',
        'c', 'e', 'y', 'l', 'o', 'n', '\n',
        'c', 'h', 'a', 'c', 'h', 'a', '\n',
        'c', 'h', 'a', 'd', '\n',
        'c', 'h', 'a', 'f', 'e', '\n',
        'c', 'h', 'a', 'f', 'e', 'd', '\n',
        'c', 'h', 'a', 'f', 'e', 's', '\n',
        'c', 'h', 'a', 'f', 'f', '\n',
        'c', 'h', 'a', 'f', 'f', 'e', 'd', '\n',
        'c', 'h', 'a', 'f', 'f', 'i', 'n', 'c', 'h', '\n',
        'c', 'h', 'a', 'f', 'f', 'i', 'n', 'c', 'h', 'e', 's', '\n',
        'c', 'h', 'a', 'f', 'f', 'i', 'n', 'g', '\n',
        'c', 'h', 'a', 'f', 'i', 'n', 'g', '\n',
        'c', 'h', 'a', 'g', 'r', 'i', 'n', '\n',
        'c', 'h', 'a', 'g', 'r', 'i', 'n', 'e', 'd', '\n',
        'c', 'h', 'a', 'i', 'n', '\n',
        'c', 'h', 'a', 'i', 'n', 'e', 'd', '\n',
        'c', 'h', 'a', 'i', 'n', 'i', 'n', 'g', '\n',
        'c', 'h', 'a', 'i', 'n', 's', '\n',
        'c', 'h', 'a', 'i', 'n', 's', 'a', 'w', '\n',
        'c', 'h', 'a', 'i', 'n', 's', 'a', 'w', 's', '\n',
        'c', 'h', 'a', 'i', 'n', 's', 'm', 'o', 'k', 'e', '\n',
        'c', 'h', 'a', 'i', 'n', 's', 'm', 'o', 'k', 'e', 'd', '\n',
        'c', 'h', 'a', 'i', 'n', 's', 'm', 'o', 'k', 'i', 'n', 'g', '\n',
        'c', 'h', 'a', 'i', 'r', '\n',
        'c', 'h', 'a', 'i', 'r', 'e', 'd', '\n',
        'c', 'h', 'a', 'i', 'r', 'i', 'n', 'g', '\n',
        'c', 'h', 'a', 'i', 'r', 'l', 'i', 'f', 't', '\n',
        'c', 'h', 'a', 'i', 'r', 'm', 'a', 'n', '\n',
        'c', 'h', 'a', 'i', 'r', 'm', 'a', 'n', 's', 'h', 'i', 'p', '\n',
        'c', 'h', 'a', 'i', 'r', 'm', 'a', 'n', 's', 'h', 'i', 'p', 's', '\n',
        'c', 'h', 'a', 'i', 'r', 'm', 'e', 'n', '\n',
        'c', 'h', 'a', 'i', 'r', 'p', 'e', 'r', 's', 'o', 'n', '\n',
        'c', 'h', 'a', 'i', 'r', 'p', 'e', 'r', 's', 'o', 'n', 's', '\n',
        'c', 'h', 'a', 'i', 'r', 's', '\n',
        'c', 'h', 'a', 'i', 'r', 'w', 'o', 'm', 'a', 'n', '\n',
        'c', 'h', 'a', 'i', 'r', 'w', 'o', 'm', 'e', 'n', '\n',
        'c', 'h', 'a', 'l', 'd', 'r', 'o', 'n', 'x', 'x', 'x', 'x', 'x', 'x', 'x', 'x', 'x', 'x', 'x', 'x', 'x', 'x', '\n',
        'c', 'h', 'a', 'l', 'e', 't', '\n',
        'c', 'h', 'a', 'l', 'e', 't', 's', '\n',
        'c', 'h', 'a', 'l', 'i', 'c', 'e', '\n',
        'c', 'h', 'a', 'l', 'i', 'c', 'e', 's', '\n',
        'c', 'h', 'a', 'l', 'k', '\n',
        'c', 'h', 'a', 'l', 'k', 'e', 'd', '\n',
        'c', 'h', 'a', 'l', 'k', 'i', 'n', 'g', '\n',
        'c', 'h', 'a', 'l', 'k', 's', '\n',
        'c', 'h', 'a', 'l', 'k', 'y', '\n',
        'c', 'h', 'a', 'l', 'l', 'e', 'n', 'g', 'e', '\n',
        'c', 'h', 'a', 'l', 'l', 'e', 'n', 'g', 'e', 'd', '\n',
        'c', 'h', 'a', 'l', 'l', 'e', 'n', 'g', 'e', 'r', '\n',
        'c', 'h', 'a', 'l', 'l', 'e', 'n', 'g', 'e', 'r', 's', '\n',
        'c', 'h', 'a', 'l', 'l', 'e', 'n', 'g', 'e', 's', '\n',
        'c', 'h', 'a', 'l', 'l', 'e', 'n', 'g', 'i', 'n', 'g', '\n',
        'c', 'h', 'a', 'l', 'l', 'e', 'n', 'g', 'i', 'n', 'g', 'l', 'y', '\n',
        'c', 'h', 'a', 'm', 'b', 'e', 'r', '\n',
        'c', 'h', 'a', 'm', 'b', 'e', 'r', 'e', 'd', '\n',
        'c', 'h', 'a', 'm', 'b', 'e', 'r', 'l', 'a', 'i', 'n', '\n',
        'c', 'h', 'a', 'm', 'b', 'e', 'r', 'l', 'a', 'i', 'n', 's', '\n',
        'c', 'h', 'a', 'm', 'b', 'e', 'r', 'm', 'a', 'i', 'd', '\n',
        'c', 'h', 'a', 'm', 'b', 'e', 'r', 'm', 'a', 'i', 'd', 's', '\n',
        'c', 'h', 'a', 'm', 'b', 'e', 'r', 'p', 'o', 't', '\n',
        'c', 'h', 'a', 'm', 'b', 'e', 'r', 'p', 'o', 't', 's', '\n',
        'c', 'h', 'a', 'm', 'b', 'e', 'r', 's', '\n',
        'c', 'h', 'a', 'm', 'e', 'l', 'e', 'o', 'n', '\n',
        'c', 'h', 'a', 'm', 'e', 'l', 'e', 'o', 'n', 's', '\n',
        'c', 'h', 'a', 'm', 'f', 'e', 'r', '\n',
        'c', 'h', 'a', 'm', 'f', 'e', 'r', 'e', 'd', '\n',
        'c', 'h', 'a', 'm', 'o', 'i', 's', '\n',
        'c', 'h', 'a', 'm', 'o', 'm', 'i', 'l', 'e', '\n',
        'c', 'h', 'a', 'm', 'p', '\n',
        'c', 'h', 'a', 'm', 'p', 'a', 'g', 'n', 'e', '\n',
        'c', 'h', 'a', 'm', 'p', 'a', 'g', 'n', 'e', 's', '\n',
        'c', 'h', 'a', 'm', 'p', 'i', 'n', 'g', '\n',
        'c', 'h', 'a', 'm', 'p', 'i', 'o', 'n', '\n',
        'c', 'h', 'a', 'm', 'p', 'i', 'o', 'n', 'e', 'd', '\n',
        'c', 'h', 'a', 'm', 'p', 'i', 'o', 'n', 'i', 'n', 'g', '\n',
        'c', 'h', 'a', 'm', 'p', 'i', 'o', 'n', 's', '\n',
        'c', 'h', 'a', 'm', 'p', 'i', 'o', 'n', 's', 'h', 'i', 'p', '\n',
        'c', 'h', 'a', 'm', 'p', 'i', 'o', 'n', 's', 'h', 'i', 'p', 's', '\n',
        'c', 'h', 'a', 'm', 'p', 's', '\n',
        'c', 'h', 'a', 'n', 'c', 'e', '\n',
        'c', 'h', 'a', 'n', 'c', 'e', 'd', '\n',
        'c', 'h', 'a', 'n', 'c', 'e', 'l', '\n',
        'c', 'h', 'a', 'n', 'c', 'e', 'l', 'l', 'e', 'r', 'y', '\n',
        'c', 'h', 'a', 'n', 'c', 'e', 'l', 'l', 'o', 'r', '\n',
        'c', 'h', 'a', 'n', 'c', 'e', 'l', 'l', 'o', 'r', 's', '\n',
        'c', 'h', 'a', 'n', 'c', 'e', 'l', 'l', 'o', 'r', 's', 'h', 'i', 'p', '\n',
        'c', 'h', 'a', 'n', 'c', 'e', 'r', '\n',
        'c', 'h', 'a', 'n', 'c', 'e', 'r', 'y', '\n',
        'c', 'h', 'a', 'n', 'c', 'e', 's', '\n',
        'c', 'h', 'a', 'n', 'c', 'i', 'e', 'r', '\n',
        'c', 'h', 'a', 'n', 'c', 'i', 'e', 's', 't', '\n',
        'c', 'h', 'a', 'n', 'c', 'i', 'n', 'g', '\n',
        'c', 'h', 'a', 'n', 'c', 'y', '\n',
        'c', 'h', 'a', 'n', 'd', 'e', 'l', 'i', 'e', 'r', '\n',
        'c', 'h', 'a', 'n', 'd', 'e', 'l', 'i', 'e', 'r', 's', '\n',
        'c', 'h', 'a', 'n', 'd', 'l', 'e', 'r', '\n',
        'c', 'h', 'a', 'n', 'g', 'e', '\n',
        'c', 'h', 'a', 'n', 'g', 'e', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'c', 'h', 'a', 'n', 'g', 'e', 'a', 'b', 'l', 'e', '\n',
        'c', 'h', 'a', 'n', 'g', 'e', 'd', '\n',
        'c', 'h', 'a', 'n', 'g', 'e', 'l', 'e', 's', 's', '\n',
        'c', 'h', 'a', 'n', 'g', 'e', 'l', 'i', 'n', 'g', '\n',
        'c', 'h', 'a', 'n', 'g', 'e', 'o', 'v', 'e', 'r', '\n',
        'c', 'h', 'a', 'n', 'g', 'e', 'o', 'v', 'e', 'r', 's', '\n',
        'c', 'h', 'a', 'n', 'g', 'e', 'r', '\n',
        'c', 'h', 'a', 'n', 'g', 'e', 'r', 's', '\n',
        'c', 'h', 'a', 'n', 'g', 'e', 's', '\n',
        'c', 'h', 'a', 'n', 'g', 'i', 'n', 'g', '\n',
        'c', 'h', 'a', 'n', 'n', 'e', 'l', '\n',
        'c', 'h', 'a', 'n', 'n', 'e', 'l', 'l', 'e', 'd', '\n',
        'c', 'h', 'a', 'n', 'n', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'c', 'h', 'a', 'n', 'n', 'e', 'l', 's', '\n',
        'c', 'h', 'a', 'n', 't', '\n',
        'c', 'h', 'a', 'n', 't', 'e', 'd', '\n',
        'c', 'h', 'a', 'n', 't', 'e', 'r', '\n',
        'c', 'h', 'a', 'n', 't', 'e', 'u', 's', 'e', '\n',
        'c', 'h', 'a', 'n', 't', 'i', 'n', 'g', '\n',
        'c', 'h', 'a', 'n', 't', 'i', 'n', 'g', 's', '\n',
        'c', 'h', 'a', 'n', 't', 'r', 'i', 'e', 's', '\n',
        'c', 'h', 'a', 'n', 't', 'r', 'y', '\n',
        'c', 'h', 'a', 'n', 't', 's', '\n',
        'c', 'h', 'a', 'o', 's', '\n',
        'c', 'h', 'a', 'o', 't', 'i', 'c', '\n',
        'c', 'h', 'a', 'o', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'c', 'h', 'a', 'p', '\n',
        'c', 'h', 'a', 'p', 'e', 'l', '\n',
        'c', 'h', 'a', 'p', 'e', 'l', 's', '\n',
        'c', 'h', 'a', 'p', 'e', 'r', 'o', 'n', '\n',
        'c', 'h', 'a', 'p', 'e', 'r', 'o', 'n', 'e', '\n',
        'c', 'h', 'a', 'p', 'e', 'r', 'o', 'n', 'e', 'd', '\n',
        'c', 'h', 'a', 'p', 'e', 'r', 'o', 'n', 'e', 's', '\n',
        'c', 'h', 'a', 'p', 'l', 'a', 'i', 'n', '\n',
        'c', 'h', 'a', 'p', 'l', 'a', 'i', 'n', 'c', 'y', '\n',
        'c', 'h', 'a', 'p', 'l', 'a', 'i', 'n', 's', '\n',
        'c', 'h', 'a', 'p', 'l', 'a', 'i', 'n', 'x', 'x', 'x', 'x', 'x', 'x', 'x', 'x', '\n',
        'c', 'h', 'a', 'p', 'm', 'a', 'n', '\n',
        'c', 'h', 'a', 'p', 'p', 'e', 'd', '\n',
        'c', 'h', 'a', 'p', 'p', 'i', 'n', 'g', '\n',
        'c', 'h', 'a', 'p', 's', '\n',
        'c', 'h', 'a', 'p', 't', 'e', 'r', '\n',
        'c', 'h', 'a', 'p', 't', 'e', 'r', 's', '\n',
        'c', 'h', 'a', 'r', '\n',
        'c', 'h', 'a', 'r', 'a', 'b', 'a', 'n', 'c', '\n',
        'c', 'h', 'a', 'r', 'a', 'c', 't', 'e', 'r', '\n',
        'c', 'h', 'a', 'r', 'a', 'c', 't', 'e', 'r', 'f', 'u', 'l', '\n',
        'c', 'h', 'a', 'r', 'a', 'c', 't', 'e', 'r', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'h', 'a', 'r', 'a', 'c', 't', 'e', 'r', 'i', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'h', 'a', 'r', 'a', 'c', 't', 'e', 'r', 'i', 's', 'e', '\n',
        'c', 'h', 'a', 'r', 'a', 'c', 't', 'e', 'r', 'i', 's', 'e', 'd', '\n',
        'c', 'h', 'a', 'r', 'a', 'c', 't', 'e', 'r', 'i', 's', 'e', 's', '\n',
        'c', 'h', 'a', 'r', 'a', 'c', 't', 'e', 'r', 'i', 's', 'i', 'n', 'g', '\n',
        'c', 'h', 'a', 'r', 'a', 'c', 't', 'e', 'r', 'i', 's', 't', 'i', 'c', '\n',
        'c', 'h', 'a', 'r', 'a', 'c', 't', 'e', 'r', 'i', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'c', 'h', 'a', 'r', 'a', 'c', 't', 'e', 'r', 'i', 's', 't', 'i', 'c', 's', '\n',
        'c', 'h', 'a', 'r', 'a', 'c', 't', 'e', 'r', 'l', 'e', 's', 's', '\n',
        'c', 'h', 'a', 'r', 'a', 'c', 't', 'e', 'r', 's', '\n',
        'c', 'h', 'a', 'r', 'a', 'd', 'e', '\n',
        'c', 'h', 'a', 'r', 'a', 'd', 'e', 's', '\n',
        'c', 'h', 'a', 'r', 'c', 'o', 'a', 'l', '\n',
        'c', 'h', 'a', 'r', 'c', 'u', 't', 'e', 'r', 'i', 'e', '\n',
        'c', 'h', 'a', 'r', 'e', 'd', '\n',
        'c', 'h', 'a', 'r', 'g', 'e', '\n',
        'c', 'h', 'a', 'r', 'g', 'e', 'a', 'b', 'l', 'e', '\n',
        'c', 'h', 'a', 'r', 'g', 'e', 'd', '\n',
        'c', 'h', 'a', 'r', 'g', 'e', 'r', '\n',
        'c', 'h', 'a', 'r', 'g', 'e', 'r', 's', '\n',
        'c', 'h', 'a', 'r', 'g', 'e', 's', '\n',
        'c', 'h', 'a', 'r', 'g', 'i', 'n', 'g', '\n',
        'c', 'h', 'a', 'r', 'i', 'o', 't', '\n',
        'c', 'h', 'a', 'r', 'i', 'o', 't', 'e', 'e', 'r', '\n',
        'c', 'h', 'a', 'r', 'i', 'o', 't', 'e', 'e', 'r', 's', '\n',
        'c', 'h', 'a', 'r', 'i', 'o', 't', 's', '\n',
        'c', 'h', 'a', 'r', 'i', 's', 'm', 'a', '\n',
        'c', 'h', 'a', 'r', 'i', 's', 'm', 'a', 's', '\n',
        'c', 'h', 'a', 'r', 'i', 's', 'm', 'a', 't', 'i', 'c', '\n',
        'c', 'h', 'a', 'r', 'i', 's', 'm', 'a', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'c', 'h', 'a', 'r', 'i', 's', 'm', 'a', 't', 'i', 'c', 's', '\n',
        'c', 'h', 'a', 'r', 'i', 't', 'a', 'b', 'l', 'e', '\n',
        'c', 'h', 'a', 'r', 'i', 't', 'a', 'b', 'l', 'y', '\n',
        'c', 'h', 'a', 'r', 'i', 't', 'i', 'e', 's', '\n',
        'c', 'h', 'a', 'r', 'i', 't', 'y', '\n',
        'c', 'h', 'a', 'r', 'l', 'a', 'd', 'y', '\n',
        'c', 'h', 'a', 'r', 'l', 'a', 't', 'a', 'n', '\n',
        'c', 'h', 'a', 'r', 'l', 'a', 't', 'a', 'n', 's', '\n',
        'c', 'h', 'a', 'r', 'l', 'e', 's', '\n',
        'c', 'h', 'a', 'r', 'l', 'i', 'e', '\n',
        'c', 'h', 'a', 'r', 'm', '\n',
        'c', 'h', 'a', 'r', 'm', 'e', 'd', '\n',
        'c', 'h', 'a', 'r', 'm', 'e', 'r', '\n',
        'c', 'h', 'a', 'r', 'm', 'e', 'r', 's', '\n',
        'c', 'h', 'a', 'r', 'm', 'i', 'n', 'g', '\n',
        'c', 'h', 'a', 'r', 'm', 'i', 'n', 'g', 'l', 'y', '\n',
        'c', 'h', 'a', 'r', 'm', 'l', 'e', 's', 's', '\n',
        'c', 'h', 'a', 'r', 'm', 's', '\n',
        'c', 'h', 'a', 'r', 'o', 'n', '\n',
        'c', 'h', 'a', 'r', 'r', 'e', 'd', '\n',
        'c', 'h', 'a', 'r', 'r', 'i', 'n', 'g', '\n',
        'c', 'h', 'a', 'r', 's', '\n',
        'c', 'h', 'a', 'r', 't', '\n',
        'c', 'h', 'a', 'r', 't', 'e', 'd', '\n',
        'c', 'h', 'a', 'r', 't', 'e', 'r', '\n',
        'c', 'h', 'a', 'r', 't', 'e', 'r', 'e', 'd', '\n',
        'c', 'h', 'a', 'r', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'c', 'h', 'a', 'r', 't', 'e', 'r', 's', '\n',
        'c', 'h', 'a', 'r', 't', 'i', 'n', 'g', '\n',
        'c', 'h', 'a', 'r', 't', 'i', 's', 't', 's', '\n',
        'c', 'h', 'a', 'r', 't', 's', '\n',
        'c', 'h', 'a', 'r', 'w', 'o', 'm', 'a', 'n', '\n',
        'c', 'h', 'a', 'r', 'y', '\n',
        'c', 'h', 'a', 's', 'e', '\n',
        'c', 'h', 'a', 's', 'e', 'd', '\n',
        'c', 'h', 'a', 's', 'e', 'r', '\n',
        'c', 'h', 'a', 's', 'e', 'r', 's', '\n',
        'c', 'h', 'a', 's', 'e', 's', '\n',
        'c', 'h', 'a', 's', 'i', 'n', 'g', '\n',
        'c', 'h', 'a', 's', 'm', '\n',
        'c', 'h', 'a', 's', 'm', 's', '\n',
        'c', 'h', 'a', 's', 's', 'i', 's', '\n',
        'c', 'h', 'a', 's', 't', 'e', '\n',
        'c', 'h', 'a', 's', 't', 'e', 'l', 'y', '\n',
        'c', 'h', 'a', 's', 't', 'e', 'n', 'e', 'd', '\n',
        'c', 'h', 'a', 's', 't', 'e', 'n', 'i', 'n', 'g', '\n',
        'c', 'h', 'a', 's', 't', 'i', 's', 'e', '\n',
        'c', 'h', 'a', 's', 't', 'i', 's', 'e', 'd', '\n',
        'c', 'h', 'a', 's', 't', 'i', 's', 'e', 'm', 'e', 'n', 't', '\n',
        'c', 'h', 'a', 's', 't', 'i', 's', 'e', 's', '\n',
        'c', 'h', 'a', 's', 't', 'i', 's', 'i', 'n', 'g', '\n',
        'c', 'h', 'a', 's', 't', 'i', 't', 'y', '\n',
        'c', 'h', 'a', 't', '\n',
        'c', 'h', 'a', 't', 'e', 'a', 'u', '\n',
        'c', 'h', 'a', 't', 's', '\n',
        'c', 'h', 'a', 't', 't', 'e', 'd', '\n',
        'c', 'h', 'a', 't', 't', 'e', 'l', '\n',
        'c', 'h', 'a', 't', 't', 'e', 'l', 's', '\n',
        'c', 'h', 'a', 't', 't', 'e', 'r', '\n',
        'c', 'h', 'a', 't', 't', 'e', 'r', 'b', 'o', 'x', '\n',
        'c', 'h', 'a', 't', 't', 'e', 'r', 'e', 'd', '\n',
        'c', 'h', 'a', 't', 't', 'e', 'r', 'e', 'r', '\n',
        'c', 'h', 'a', 't', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'c', 'h', 'a', 't', 't', 'e', 'r', 's', '\n',
        'c', 'h', 'a', 't', 't', 'i', 'l', 'y', '\n',
        'c', 'h', 'a', 't', 't', 'i', 'n', 'g', '\n',
        'c', 'h', 'a', 't', 't', 'y', '\n',
        'c', 'h', 'a', 'u', 'f', 'f', 'e', 'u', 'r', '\n',
        'c', 'h', 'a', 'u', 'f', 'f', 'e', 'u', 'r', 'e', 'd', '\n',
        'c', 'h', 'a', 'u', 'f', 'f', 'e', 'u', 'r', 's', '\n',
        'c', 'h', 'a', 'u', 'v', 'i', 'n', 'i', 's', 'm', '\n',
        'c', 'h', 'a', 'u', 'v', 'i', 'n', 'i', 's', 't', '\n',
        'c', 'h', 'a', 'u', 'v', 'i', 'n', 'i', 's', 't', 'i', 'c', '\n',
        'c', 'h', 'a', 'u', 'v', 'i', 'n', 'i', 's', 't', 's', '\n',
        'c', 'h', 'e', 'a', 'p', '\n',
        'c', 'h', 'e', 'a', 'p', 'e', 'n', '\n',
        'c', 'h', 'e', 'a', 'p', 'e', 'n', 'e', 'd', '\n',
        'c', 'h', 'e', 'a', 'p', 'e', 'n', 'i', 'n', 'g', '\n',
        'c', 'h', 'e', 'a', 'p', 'e', 'n', 's', '\n',
        'c', 'h', 'e', 'a', 'p', 'e', 'r', '\n',
        'c', 'h', 'e', 'a', 'p', 'e', 's', 't', '\n',
        'c', 'h', 'e', 'a', 'p', 'i', 's', 'h', '\n',
        'c', 'h', 'e', 'a', 'p', 'l', 'y', '\n',
        'c', 'h', 'e', 'a', 'p', 'n', 'e', 's', 's', '\n',
        'c', 'h', 'e', 'a', 'p', 's', 'k', 'a', 't', 'e', 's', '\n',
        'c', 'h', 'e', 'a', 't', '\n',
        'c', 'h', 'e', 'a', 't', 'e', 'd', '\n',
        'c', 'h', 'e', 'a', 't', 'e', 'r', '\n',
        'c', 'h', 'e', 'a', 't', 'e', 'r', 's', '\n',
        'c', 'h', 'e', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'h', 'e', 'a', 't', 's', '\n',
        'c', 'h', 'e', 'c', 'k', '\n',
        'c', 'h', 'e', 'c', 'k', 'e', 'd', '\n',
        'c', 'h', 'e', 'c', 'k', 'e', 'r', '\n',
        'c', 'h', 'e', 'c', 'k', 'e', 'r', 'e', 'd', '\n',
        'c', 'h', 'e', 'c', 'k', 'e', 'r', 'i', 'n', 'g', '\n',
        'c', 'h', 'e', 'c', 'k', 'e', 'r', 's', '\n',
        'c', 'h', 'e', 'c', 'k', 'i', 'n', '\n',
        'c', 'h', 'e', 'c', 'k', 'i', 'n', 'g', '\n',
        'c', 'h', 'e', 'c', 'k', 'l', 'i', 's', 't', '\n',
        'c', 'h', 'e', 'c', 'k', 'l', 'i', 's', 't', 's', '\n',
        'c', 'h', 'e', 'c', 'k', 'm', 'a', 't', 'e', '\n',
        'c', 'h', 'e', 'c', 'k', 'o', 'u', 't', '\n',
        'c', 'h', 'e', 'c', 'k', 'o', 'u', 't', 's', '\n',
        'c', 'h', 'e', 'c', 'k', 'p', 'o', 'i', 'n', 't', '\n',
        'c', 'h', 'e', 'c', 'k', 'p', 'o', 'i', 'n', 't', 's', '\n',
        'c', 'h', 'e', 'c', 'k', 's', '\n',
        'c', 'h', 'e', 'c', 'k', 'u', 'p', '\n',
        'c', 'h', 'e', 'c', 'k', 'u', 'p', 's', '\n',
        'c', 'h', 'e', 'd', 'd', 'a', 'r', '\n',
        'c', 'h', 'e', 'e', 'k', '\n',
        'c', 'h', 'e', 'e', 'k', 'b', 'o', 'n', 'e', '\n',
        'c', 'h', 'e', 'e', 'k', 'b', 'o', 'n', 'e', 's', '\n',
        'c', 'h', 'e', 'e', 'k', 'e', 'd', '\n',
        'c', 'h', 'e', 'e', 'k', 'i', 'e', 'r', '\n',
        'c', 'h', 'e', 'e', 'k', 'i', 'e', 's', 't', '\n',
        'c', 'h', 'e', 'e', 'k', 'i', 'l', 'y', '\n',
        'c', 'h', 'e', 'e', 'k', 'i', 'n', 'g', '\n',
        'c', 'h', 'e', 'e', 'k', 's', '\n',
        'c', 'h', 'e', 'e', 'k', 'y', '\n',
        'c', 'h', 'e', 'e', 'p', '\n',
        'c', 'h', 'e', 'e', 'p', 'i', 'n', 'g', '\n',
        'c', 'h', 'e', 'e', 'r', '\n',
        'c', 'h', 'e', 'e', 'r', 'e', 'd', '\n',
        'c', 'h', 'e', 'e', 'r', 'f', 'u', 'l', '\n',
        'c', 'h', 'e', 'e', 'r', 'f', 'u', 'l', 'l', 'y', '\n',
        'c', 'h', 'e', 'e', 'r', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'c', 'h', 'e', 'e', 'r', 'i', 'e', 'r', '\n',
        'c', 'h', 'e', 'e', 'r', 'i', 'e', 's', 't', '\n',
        'c', 'h', 'e', 'e', 'r', 'i', 'l', 'y', '\n',
        'c', 'h', 'e', 'e', 'r', 'i', 'n', 'g', '\n',
        'c', 'h', 'e', 'e', 'r', 'i', 'o', '\n',
        'c', 'h', 'e', 'e', 'r', 'l', 'e', 'a', 'd', 'e', 'r', '\n',
        'c', 'h', 'e', 'e', 'r', 'l', 'e', 'a', 'd', 'e', 'r', 's', '\n',
        'c', 'h', 'e', 'e', 'r', 'l', 'e', 's', 's', '\n',
        'c', 'h', 'e', 'e', 'r', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'c', 'h', 'e', 'e', 'r', 's', '\n',
        'c', 'h', 'e', 'e', 'r', 'y', '\n',
        'c', 'h', 'e', 'e', 's', 'e', '\n',
        'c', 'h', 'e', 'e', 's', 'e', 'b', 'o', 'a', 'r', 'd', '\n',
        'c', 'h', 'e', 'e', 's', 'e', 'b', 'u', 'r', 'g', 'e', 'r', '\n',
        'c', 'h', 'e', 'e', 's', 'e', 'b', 'u', 'r', 'g', 'e', 'r', 's', '\n',
        'c', 'h', 'e', 'e', 's', 'e', 'c', 'a', 'k', 'e', '\n',
        'c', 'h', 'e', 'e', 's', 'e', 'c', 'l', 'o', 't', 'h', '\n',
        'c', 'h', 'e', 'e', 's', 'e', 'm', 'a', 'k', 'i', 'n', 'g', '\n',
        'c', 'h', 'e', 'e', 's', 'e', 's', '\n',
        'c', 'h', 'e', 'e', 's', 'y', '\n',
        'c', 'h', 'e', 'e', 't', 'a', 'h', '\n',
        'c', 'h', 'e', 'e', 't', 'a', 'h', 's', '\n',
        'c', 'h', 'e', 'f', '\n',
        'c', 'h', 'e', 'f', 's', '\n',
        'c', 'h', 'e', 'k', 'o', 'v', '\n',
        'c', 'h', 'e', 'm', 'i', 'c', '\n',
        'c', 'h', 'e', 'm', 'i', 'c', 'a', 'l', '\n',
        'c', 'h', 'e', 'm', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'c', 'h', 'e', 'm', 'i', 'c', 'a', 'l', 's', '\n',
        'c', 'h', 'e', 'm', 'i', 'l', 'u', 'm', 'i', 'n', 'e', 's', 'c', 'e', 'n', 'c', 'e', '\n',
        'c', 'h', 'e', 'm', 'i', 'l', 'u', 'm', 'i', 'n', 'e', 's', 'c', 'e', 'n', 't', '\n',
        'c', 'h', 'e', 'm', 'i', 's', 'e', '\n',
        'c', 'h', 'e', 'm', 'i', 's', 't', '\n',
        'c', 'h', 'e', 'm', 'i', 's', 't', 'r', 'y', '\n',
        'c', 'h', 'e', 'm', 'i', 's', 't', 's', '\n',
        'c', 'h', 'e', 'm', 'o', 's', 'y', 'n', 't', 'h', 'e', 's', 'i', 's', '\n',
        'c', 'h', 'e', 'm', 'o', 't', 'h', 'e', 'r', 'a', 'p', 'e', 'u', 't', 'i', 'c', '\n',
        'c', 'h', 'e', 'm', 'o', 't', 'h', 'e', 'r', 'a', 'p', 'y', '\n',
        'c', 'h', 'e', 'q', 'u', 'e', '\n',
        'c', 'h', 'e', 'q', 'u', 'e', 'b', 'o', 'o', 'k', '\n',
        'c', 'h', 'e', 'q', 'u', 'e', 'b', 'o', 'o', 'k', 's', '\n',
        'c', 'h', 'e', 'q', 'u', 'e', 'r', '\n',
        'c', 'h', 'e', 'q', 'u', 'e', 'r', 'b', 'o', 'a', 'r', 'd', '\n',
        'c', 'h', 'e', 'q', 'u', 'e', 'r', 'e', 'd', '\n',
        'c', 'h', 'e', 'q', 'u', 'e', 'r', 'i', 'n', 'g', '\n',
        'c', 'h', 'e', 'q', 'u', 'e', 'r', 's', '\n',
        'c', 'h', 'e', 'q', 'u', 'e', 's', '\n',
        'c', 'h', 'e', 'r', 'i', 's', 'h', '\n',
        'c', 'h', 'e', 'r', 'i', 's', 'h', 'e', 'd', '\n',
        'c', 'h', 'e', 'r', 'i', 's', 'h', 'e', 's', '\n',
        'c', 'h', 'e', 'r', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'c', 'h', 'e', 'r', 'o', 'o', 't', '\n',
        'c', 'h', 'e', 'r', 'o', 'o', 't', 's', '\n',
        'c', 'h', 'e', 'r', 'r', 'i', 'e', 's', '\n',
        'c', 'h', 'e', 'r', 'r', 'y', '\n',
        'c', 'h', 'e', 'r', 'r', 'y', 'r', 'e', 'd', '\n',
        'c', 'h', 'e', 'r', 'u', 'b', '\n',
        'c', 'h', 'e', 'r', 'u', 'b', 'i', 'c', '\n',
        'c', 'h', 'e', 'r', 'u', 'b', 'i', 'm', '\n',
        'c', 'h', 'e', 'r', 'u', 'b', 's', '\n',
        'c', 'h', 'e', 's', 's', '\n',
        'c', 'h', 'e', 's', 's', 'b', 'o', 'a', 'r', 'd', '\n',
        'c', 'h', 'e', 's', 's', 'b', 'o', 'a', 'r', 'd', 's', '\n',
        'c', 'h', 'e', 's', 's', 'm', 'e', 'n', '\n',
        'c', 'h', 'e', 's', 't', '\n',
        'c', 'h', 'e', 's', 't', 'e', 'd', '\n',
        'c', 'h', 'e', 's', 't', 'e', 'r', '\n',
        'c', 'h', 'e', 's', 't', 'e', 'r', 'f', 'i', 'e', 'l', 'd', '\n',
        'c', 'h', 'e', 's', 't', 'n', 'u', 't', '\n',
        'c', 'h', 'e', 's', 't', 'n', 'u', 't', 's', '\n',
        'c', 'h', 'e', 's', 't', 's', '\n',
        'c', 'h', 'e', 's', 't', 'y', '\n',
        'c', 'h', 'e', 'v', 'a', 'l', 'i', 'e', 'r', '\n',
        'c', 'h', 'e', 'v', 'r', 'o', 'n', '\n',
        'c', 'h', 'e', 'v', 'r', 'o', 'n', 's', '\n',
        'c', 'h', 'e', 'w', '\n',
        'c', 'h', 'e', 'w', 'a', 'b', 'l', 'e', '\n',
        'c', 'h', 'e', 'w', 'e', 'd', '\n',
        'c', 'h', 'e', 'w', 'e', 'r', '\n',
        'c', 'h', 'e', 'w', 'i', 'e', 'r', '\n',
        'c', 'h', 'e', 'w', 'i', 'e', 's', 't', '\n',
        'c', 'h', 'e', 'w', 'i', 'n', 'g', '\n',
        'c', 'h', 'e', 'w', 's', '\n',
        'c', 'h', 'e', 'w', 'y', '\n',
        'c', 'h', 'i', 'c', '\n',
        'c', 'h', 'i', 'c', 'a', 'g', 'o', '\n',
        'c', 'h', 'i', 'c', 'a', 'n', 'e', '\n',
        'c', 'h', 'i', 'c', 'a', 'n', 'e', 'r', 'y', '\n',
        'c', 'h', 'i', 'c', 'k', '\n',
        'c', 'h', 'i', 'c', 'k', 'e', 'n', '\n',
        'c', 'h', 'i', 'c', 'k', 'e', 'n', 's', '\n',
        'c', 'h', 'i', 'c', 'k', 's', '\n',
        'c', 'h', 'i', 'c', 'o', 'r', 'y', '\n',
        'c', 'h', 'i', 'd', 'e', '\n',
        'c', 'h', 'i', 'd', 'e', 'd', '\n',
        'c', 'h', 'i', 'd', 'e', 's', '\n',
        'c', 'h', 'i', 'd', 'i', 'n', 'g', '\n',
        'c', 'h', 'i', 'e', 'f', '\n',
        'c', 'h', 'i', 'e', 'f', 'l', 'y', '\n',
        'c', 'h', 'i', 'e', 'f', 's', '\n',
        'c', 'h', 'i', 'e', 'f', 't', 'a', 'i', 'n', '\n',
        'c', 'h', 'i', 'e', 'f', 't', 'a', 'i', 'n', 's', '\n',
        'c', 'h', 'i', 'f', 'f', 'o', 'n', '\n',
        'c', 'h', 'i', 'h', 'u', 'a', 'h', 'u', 'a', '\n',
        'c', 'h', 'i', 'h', 'u', 'a', 'h', 'u', 'a', 's', '\n',
        'c', 'h', 'i', 'l', 'b', 'l', 'a', 'i', 'n', '\n',
        'c', 'h', 'i', 'l', 'b', 'l', 'a', 'i', 'n', 's', '\n',
        'c', 'h', 'i', 'l', 'd', '\n',
        'c', 'h', 'i', 'l', 'd', 'b', 'e', 'a', 'r', 'i', 'n', 'g', '\n',
        'c', 'h', 'i', 'l', 'd', 'b', 'i', 'r', 't', 'h', '\n',
        'c', 'h', 'i', 'l', 'd', 'c', 'a', 'r', 'e', '\n',
        'c', 'h', 'i', 'l', 'd', 'h', 'o', 'o', 'd', '\n',
        'c', 'h', 'i', 'l', 'd', 'h', 'o', 'o', 'd', 's', '\n',
        'c', 'h', 'i', 'l', 'd', 'i', 's', 'h', '\n',
        'c', 'h', 'i', 'l', 'd', 'i', 's', 'h', 'l', 'y', '\n',
        'c', 'h', 'i', 'l', 'd', 'i', 's', 'h', 'n', 'e', 's', 's', '\n',
        'c', 'h', 'i', 'l', 'd', 'l', 'e', 's', 's', '\n',
        'c', 'h', 'i', 'l', 'd', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'c', 'h', 'i', 'l', 'd', 'l', 'i', 'k', 'e', '\n',
        'c', 'h', 'i', 'l', 'd', 'l', 'y', '\n',
        'c', 'h', 'i', 'l', 'd', 'm', 'i', 'n', 'd', 'e', 'r', 's', '\n',
        'c', 'h', 'i', 'l', 'd', 'p', 'r', 'o', 'o', 'f', '\n',
        'c', 'h', 'i', 'l', 'd', 'r', 'e', 'n', '\n',
        'c', 'h', 'i', 'l', 'e', 'a', 'n', '\n',
        'c', 'h', 'i', 'l', 'i', '\n',
        'c', 'h', 'i', 'l', 'l', '\n',
        'c', 'h', 'i', 'l', 'l', 'e', 'd', '\n',
        'c', 'h', 'i', 'l', 'l', 'e', 'r', '\n',
        'c', 'h', 'i', 'l', 'l', 'e', 'r', 's', '\n',
        'c', 'h', 'i', 'l', 'l', 'i', '\n',
        'c', 'h', 'i', 'l', 'l', 'i', 'e', 'r', '\n',
        'c', 'h', 'i', 'l', 'l', 'i', 'e', 's', '\n',
        'c', 'h', 'i', 'l', 'l', 'i', 'e', 's', 't', '\n',
        'c', 'h', 'i', 'l', 'l', 'i', 'n', 'e', 's', 's', '\n',
        'c', 'h', 'i', 'l', 'l', 'i', 'n', 'g', '\n',
        'c', 'h', 'i', 'l', 'l', 'i', 'n', 'g', 'l', 'y', '\n',
        'c', 'h', 'i', 'l', 'l', 's', '\n',
        'c', 'h', 'i', 'l', 'l', 'y', '\n',
        'c', 'h', 'i', 'm', 'a', 'e', 'r', 'a', '\n',
        'c', 'h', 'i', 'm', 'a', 'e', 'r', 'i', 'c', 'a', 'l', '\n',
        'c', 'h', 'i', 'm', 'e', '\n',
        'c', 'h', 'i', 'm', 'e', 'd', '\n',
        'c', 'h', 'i', 'm', 'e', 'r', 'a', '\n',
        'c', 'h', 'i', 'm', 'e', 'r', 'a', 's', '\n',
        'c', 'h', 'i', 'm', 'e', 'r', 'i', 'c', 'a', 'l', '\n',
        'c', 'h', 'i', 'm', 'e', 's', '\n',
        'c', 'h', 'i', 'm', 'i', 'n', 'g', '\n',
        'c', 'h', 'i', 'm', 'n', 'e', 'y', '\n',
        'c', 'h', 'i', 'm', 'n', 'e', 'y', 's', '\n',
        'c', 'h', 'i', 'm', 'p', '\n',
        'c', 'h', 'i', 'm', 'p', 'a', 'n', 'z', 'e', 'e', '\n',
        'c', 'h', 'i', 'm', 'p', 'a', 'n', 'z', 'e', 'e', 's', '\n',
        'c', 'h', 'i', 'm', 'p', 's', '\n',
        'c', 'h', 'i', 'n', '\n',
        'c', 'h', 'i', 'n', 'a', '\n',
        'c', 'h', 'i', 'n', 'e', 's', 'e', '\n',
        'c', 'h', 'i', 'n', 'k', '\n',
        'c', 'h', 'i', 'n', 'k', 'e', 'd', '\n',
        'c', 'h', 'i', 'n', 'k', 'i', 'n', 'g', '\n',
        'c', 'h', 'i', 'n', 'k', 's', '\n',
        'c', 'h', 'i', 'n', 'l', 'e', 's', 's', '\n',
        'c', 'h', 'i', 'n', 'o', 'i', 's', 'e', 'r', 'i', 'e', '\n',
        'c', 'h', 'i', 'n', 's', '\n',
        'c', 'h', 'i', 'n', 't', 'z', '\n',
        'c', 'h', 'i', 'n', 't', 'z', 'y', '\n',
        'c', 'h', 'i', 'p', '\n',
        'c', 'h', 'i', 'p', 'b', 'o', 'a', 'r', 'd', '\n',
        'c', 'h', 'i', 'p', 'm', 'u', 'n', 'k', '\n',
        'c', 'h', 'i', 'p', 'p', 'e', 'd', '\n',
        'c', 'h', 'i', 'p', 'p', 'i', 'n', 'g', '\n',
        'c', 'h', 'i', 'p', 'p', 'i', 'n', 'g', 's', '\n',
        'c', 'h', 'i', 'p', 's', '\n',
        'c', 'h', 'i', 'r', 'a', 'l', '\n',
        'c', 'h', 'i', 'r', 'o', 'p', 'o', 'd', 'i', 's', 't', '\n',
        'c', 'h', 'i', 'r', 'o', 'p', 'o', 'd', 'y', '\n',
        'c', 'h', 'i', 'r', 'o', 'p', 'r', 'a', 'c', 't', 'i', 'c', '\n',
        'c', 'h', 'i', 'r', 'o', 'p', 'r', 'a', 'c', 't', 'o', 'r', '\n',
        'c', 'h', 'i', 'r', 'o', 'p', 'r', 'a', 'c', 't', 'o', 'r', 's', '\n',
        'c', 'h', 'i', 'r', 'p', '\n',
        'c', 'h', 'i', 'r', 'p', 'e', 'd', '\n',
        'c', 'h', 'i', 'r', 'p', 'i', 'n', 'g', '\n',
        'c', 'h', 'i', 'r', 'p', 's', '\n',
        'c', 'h', 'i', 'r', 'p', 'y', '\n',
        'c', 'h', 'i', 'r', 'r', 'u', 'p', 'e', 'd', '\n',
        'c', 'h', 'i', 's', 'e', 'l', '\n',
        'c', 'h', 'i', 's', 'e', 'l', 'e', 'd', '\n',
        'c', 'h', 'i', 's', 'e', 'l', 'l', 'e', 'd', '\n',
        'c', 'h', 'i', 's', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'c', 'h', 'i', 's', 'e', 'l', 's', '\n',
        'c', 'h', 'i', 't', '\n',
        'c', 'h', 'i', 't', 's', '\n',
        'c', 'h', 'i', 'v', 'a', 'l', 'r', 'i', 'c', '\n',
        'c', 'h', 'i', 'v', 'a', 'l', 'r', 'o', 'u', 's', '\n',
        'c', 'h', 'i', 'v', 'a', 'l', 'r', 'o', 'u', 's', 'l', 'y', '\n',
        'c', 'h', 'i', 'v', 'a', 'l', 'r', 'y', '\n',
        'c', 'h', 'i', 'v', 'e', 's', '\n',
        'c', 'h', 'i', 'v', 'v', 'i', 'e', 'd', '\n',
        'c', 'h', 'i', 'v', 'v', 'y', '\n',
        'c', 'h', 'i', 'v', 'v', 'y', 'i', 'n', 'g', '\n',
        'c', 'h', 'l', 'a', 'm', 'y', 'd', 'i', 'a', '\n',
        'c', 'h', 'l', 'o', 'r', 'a', 't', 'e', '\n',
        'c', 'h', 'l', 'o', 'r', 'i', 'd', 'e', '\n',
        'c', 'h', 'l', 'o', 'r', 'i', 'n', 'a', 't', 'e', 'd', '\n',
        'c', 'h', 'l', 'o', 'r', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'h', 'l', 'o', 'r', 'i', 'n', 'e', '\n',
        'c', 'h', 'l', 'o', 'r', 'o', 'f', 'l', 'u', 'o', 'r', 'o', 'c', 'a', 'r', 'b', 'o', 'n', '\n',
        'c', 'h', 'l', 'o', 'r', 'o', 'f', 'l', 'u', 'o', 'r', 'o', 'c', 'a', 'r', 'b', 'o', 'n', 's', '\n',
        'c', 'h', 'l', 'o', 'r', 'o', 'f', 'o', 'r', 'm', '\n',
        'c', 'h', 'l', 'o', 'r', 'o', 'f', 'o', 'r', 'm', 'e', 'd', '\n',
        'c', 'h', 'l', 'o', 'r', 'o', 'f', 'o', 'r', 'm', 'i', 'n', 'g', '\n',
        'c', 'h', 'l', 'o', 'r', 'o', 'p', 'h', 'y', 'l', 'l', '\n',
        'c', 'h', 'l', 'o', 'r', 'o', 'q', 'u', 'i', 'n', 'e', '\n',
        'c', 'h', 'o', 'c', 'k', '\n',
        'c', 'h', 'o', 'c', 'k', 'a', 'b', 'l', 'o', 'c', 'k', '\n',
        'c', 'h', 'o', 'c', 'k', 'f', 'u', 'l', 'l', '\n',
        'c', 'h', 'o', 'c', 'k', 's', '\n',
        'c', 'h', 'o', 'c', 'o', 'l', 'a', 't', 'e', '\n',
        'c', 'h', 'o', 'c', 'o', 'l', 'a', 't', 'e', 's', '\n',
        'c', 'h', 'o', 'i', 'c', 'e', '\n',
        'c', 'h', 'o', 'i', 'c', 'e', 's', '\n',
        'c', 'h', 'o', 'i', 'c', 'e', 's', 't', '\n',
        'c', 'h', 'o', 'i', 'r', '\n',
        'c', 'h', 'o', 'i', 'r', 'b', 'o', 'y', '\n',
        'c', 'h', 'o', 'i', 'r', 'b', 'o', 'y', 's', '\n',
        'c', 'h', 'o', 'i', 'r', 'm', 'a', 's', 't', 'e', 'r', '\n',
        'c', 'h', 'o', 'i', 'r', 's', '\n',
        'c', 'h', 'o', 'k', 'e', '\n',
        'c', 'h', 'o', 'k', 'e', 'd', '\n',
        'c', 'h', 'o', 'k', 'e', 'r', '\n',
        'c', 'h', 'o', 'k', 'e', 's', '\n',
        'c', 'h', 'o', 'k', 'i', 'n', 'g', '\n',
        'c', 'h', 'o', 'l', 'e', 'r', 'a', '\n',
        'c', 'h', 'o', 'l', 'e', 's', 't', 'e', 'r', 'o', 'l', '\n',
        'c', 'h', 'o', 'l', 'i', 'n', 'e', '\n',
        'c', 'h', 'o', 'm', 'p', '\n',
        'c', 'h', 'o', 'm', 'p', 'e', 'd', '\n',
        'c', 'h', 'o', 'm', 'p', 'i', 'n', 'g', '\n',
        'c', 'h', 'o', 'm', 'p', 's', '\n',
        'c', 'h', 'o', 'o', 's', 'e', '\n',
        'c', 'h', 'o', 'o', 's', 'e', 'r', '\n',
        'c', 'h', 'o', 'o', 's', 'e', 'r', 's', '\n',
        'c', 'h', 'o', 'o', 's', 'e', 's', '\n',
        'c', 'h', 'o', 'o', 's', 'e', 'y', '\n',
        'c', 'h', 'o', 'o', 's', 'i', 'e', 'r', '\n',
        'c', 'h', 'o', 'o', 's', 'i', 'n', 'g', '\n',
        'c', 'h', 'o', 'o', 's', 'y', '\n',
        'c', 'h', 'o', 'p', '\n',
        'c', 'h', 'o', 'p', 'i', 'n', '\n',
        'c', 'h', 'o', 'p', 'p', 'e', 'd', '\n',
        'c', 'h', 'o', 'p', 'p', 'e', 'r', '\n',
        'c', 'h', 'o', 'p', 'p', 'e', 'r', 's', '\n',
        'c', 'h', 'o', 'p', 'p', 'i', 'e', 'r', '\n',
        'c', 'h', 'o', 'p', 'p', 'i', 'e', 's', 't', '\n',
        'c', 'h', 'o', 'p', 'p', 'i', 'n', 'g', '\n',
        'c', 'h', 'o', 'p', 'p', 'y', '\n',
        'c', 'h', 'o', 'p', 's', '\n',
        'c', 'h', 'o', 'p', 's', 't', 'i', 'c', 'k', 's', '\n',
        'c', 'h', 'o', 'r', 'a', 'l', '\n',
        'c', 'h', 'o', 'r', 'a', 'l', 'e', '\n',
        'c', 'h', 'o', 'r', 'a', 'l', 'e', 's', '\n',
        'c', 'h', 'o', 'r', 'a', 'l', 's', '\n',
        'c', 'h', 'o', 'r', 'd', '\n',
        'c', 'h', 'o', 'r', 'd', 'a', 'l', '\n',
        'c', 'h', 'o', 'r', 'd', 's', '\n',
        'c', 'h', 'o', 'r', 'e', '\n',
        'c', 'h', 'o', 'r', 'e', 'a', '\n',
        'c', 'h', 'o', 'r', 'e', 'o', 'g', 'r', 'a', 'p', 'h', 'e', 'd', '\n',
        'c', 'h', 'o', 'r', 'e', 'o', 'g', 'r', 'a', 'p', 'h', 'e', 'r', '\n',
        'c', 'h', 'o', 'r', 'e', 'o', 'g', 'r', 'a', 'p', 'h', 'e', 'r', 's', '\n',
        'c', 'h', 'o', 'r', 'e', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', '\n',
        'c', 'h', 'o', 'r', 'e', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'n', 'g', '\n',
        'c', 'h', 'o', 'r', 'e', 'o', 'g', 'r', 'a', 'p', 'h', 'y', '\n',
        'c', 'h', 'o', 'r', 'e', 's', '\n',
        'c', 'h', 'o', 'r', 'i', 's', 't', 'e', 'r', '\n',
        'c', 'h', 'o', 'r', 'i', 's', 't', 'e', 'r', 's', '\n',
        'c', 'h', 'o', 'r', 't', 'l', 'e', '\n',
        'c', 'h', 'o', 'r', 't', 'l', 'e', 'd', '\n',
        'c', 'h', 'o', 'r', 't', 'l', 'e', 's', '\n',
        'c', 'h', 'o', 'r', 't', 'l', 'i', 'n', 'g', '\n',
        'c', 'h', 'o', 'r', 'u', 's', '\n',
        'c', 'h', 'o', 'r', 'u', 's', 'e', 'd', '\n',
        'c', 'h', 'o', 'r', 'u', 's', 'e', 's', '\n',
        'c', 'h', 'o', 's', 'e', '\n',
        'c', 'h', 'o', 's', 'e', 'n', '\n',
        'c', 'h', 'o', 'u', 'g', 'h', 's', '\n',
        'c', 'h', 'o', 'w', '\n',
        'c', 'h', 'r', 'i', 's', 't', '\n',
        'c', 'h', 'r', 'i', 's', 't', 'e', 'n', '\n',
        'c', 'h', 'r', 'i', 's', 't', 'e', 'n', 'e', 'd', '\n',
        'c', 'h', 'r', 'i', 's', 't', 'e', 'n', 'i', 'n', 'g', '\n',
        'c', 'h', 'r', 'i', 's', 't', 'e', 'n', 'i', 'n', 'g', 's', '\n',
        'c', 'h', 'r', 'i', 's', 't', 'i', 'a', 'n', '\n',
        'c', 'h', 'r', 'o', 'm', 'a', '\n',
        'c', 'h', 'r', 'o', 'm', 'a', 't', 'i', 'c', '\n',
        'c', 'h', 'r', 'o', 'm', 'a', 't', 'i', 'c', 'i', 's', 'm', '\n',
        'c', 'h', 'r', 'o', 'm', 'a', 't', 'o', 'g', 'r', 'a', 'p', 'h', '\n',
        'c', 'h', 'r', 'o', 'm', 'a', 't', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', '\n',
        'c', 'h', 'r', 'o', 'm', 'a', 't', 'o', 'g', 'r', 'a', 'p', 'h', 'y', '\n',
        'c', 'h', 'r', 'o', 'm', 'e', '\n',
        'c', 'h', 'r', 'o', 'm', 'e', 'd', '\n',
        'c', 'h', 'r', 'o', 'm', 'i', 't', 'e', '\n',
        'c', 'h', 'r', 'o', 'm', 'i', 'u', 'm', '\n',
        'c', 'h', 'r', 'o', 'm', 'o', 's', 'o', 'm', 'a', 'l', '\n',
        'c', 'h', 'r', 'o', 'm', 'o', 's', 'o', 'm', 'e', '\n',
        'c', 'h', 'r', 'o', 'm', 'o', 's', 'o', 'm', 'e', 's', '\n',
        'c', 'h', 'r', 'o', 'n', 'i', 'c', '\n',
        'c', 'h', 'r', 'o', 'n', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'c', 'h', 'r', 'o', 'n', 'i', 'c', 'l', 'e', '\n',
        'c', 'h', 'r', 'o', 'n', 'i', 'c', 'l', 'e', 'd', '\n',
        'c', 'h', 'r', 'o', 'n', 'i', 'c', 'l', 'e', 'r', '\n',
        'c', 'h', 'r', 'o', 'n', 'i', 'c', 'l', 'e', 'r', 's', '\n',
        'c', 'h', 'r', 'o', 'n', 'i', 'c', 'l', 'e', 's', '\n',
        'c', 'h', 'r', 'o', 'n', 'i', 'c', 'l', 'i', 'n', 'g', '\n',
        'c', 'h', 'r', 'o', 'n', 'o', 'g', 'r', 'a', 'p', 'h', '\n',
        'c', 'h', 'r', 'o', 'n', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'c', 'h', 'r', 'o', 'n', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'c', 'h', 'r', 'o', 'n', 'o', 'l', 'o', 'g', 'i', 'e', 's', '\n',
        'c', 'h', 'r', 'o', 'n', 'o', 'l', 'o', 'g', 'y', '\n',
        'c', 'h', 'r', 'o', 'n', 'o', 'm', 'e', 't', 'e', 'r', '\n',
        'c', 'h', 'r', 'o', 'n', 'o', 'm', 'e', 't', 'r', 'i', 'c', '\n',
        'c', 'h', 'r', 'y', 's', 'a', 'l', 'i', 's', '\n',
        'c', 'h', 'r', 'y', 's', 'a', 'n', 't', 'h', 'e', 'm', 'u', 'm', '\n',
        'c', 'h', 'r', 'y', 's', 'a', 'n', 't', 'h', 'e', 'm', 'u', 'm', 's', '\n',
        'c', 'h', 'u', 'b', 'b', 'i', 'n', 'e', 's', 's', '\n',
        'c', 'h', 'u', 'b', 'b', 'y', '\n',
        'c', 'h', 'u', 'c', 'k', '\n',
        'c', 'h', 'u', 'c', 'k', 'e', 'd', '\n',
        'c', 'h', 'u', 'c', 'k', 'i', 'n', 'g', '\n',
        'c', 'h', 'u', 'c', 'k', 'l', 'e', '\n',
        'c', 'h', 'u', 'c', 'k', 'l', 'e', 'd', '\n',
        'c', 'h', 'u', 'c', 'k', 'l', 'e', 's', '\n',
        'c', 'h', 'u', 'c', 'k', 'l', 'i', 'n', 'g', '\n',
        'c', 'h', 'u', 'c', 'k', 's', '\n',
        'c', 'h', 'u', 'f', 'f', '\n',
        'c', 'h', 'u', 'f', 'f', 'e', 'd', '\n',
        'c', 'h', 'u', 'g', '\n',
        'c', 'h', 'u', 'g', 'g', 'e', 'd', '\n',
        'c', 'h', 'u', 'g', 'g', 'i', 'n', 'g', '\n',
        'c', 'h', 'u', 'g', 's', '\n',
        'c', 'h', 'u', 'm', '\n',
        'c', 'h', 'u', 'm', 'p', '\n',
        'c', 'h', 'u', 'm', 's', '\n',
        'c', 'h', 'u', 'n', 'k', '\n',
        'c', 'h', 'u', 'n', 'k', 'i', 'e', 'r', '\n',
        'c', 'h', 'u', 'n', 'k', 's', '\n',
        'c', 'h', 'u', 'n', 'k', 'y', '\n',
        'c', 'h', 'u', 'n', 'n', 'e', 'l', '\n',
        'c', 'h', 'u', 'n', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'c', 'h', 'u', 'r', 'c', 'h', '\n',
        'c', 'h', 'u', 'r', 'c', 'h', 'e', 's', '\n',
        'c', 'h', 'u', 'r', 'c', 'h', 'g', 'o', 'e', 'r', '\n',
        'c', 'h', 'u', 'r', 'c', 'h', 'g', 'o', 'e', 'r', 's', '\n',
        'c', 'h', 'u', 'r', 'c', 'h', 'm', 'a', 'n', '\n',
        'c', 'h', 'u', 'r', 'c', 'h', 'm', 'e', 'n', '\n',
        'c', 'h', 'u', 'r', 'c', 'h', 'w', 'a', 'r', 'd', 'e', 'n', '\n',
        'c', 'h', 'u', 'r', 'c', 'h', 'w', 'a', 'r', 'd', 'e', 'n', 's', '\n',
        'c', 'h', 'u', 'r', 'c', 'h', 'y', 'a', 'r', 'd', '\n',
        'c', 'h', 'u', 'r', 'c', 'h', 'y', 'a', 'r', 'd', 's', '\n',
        'c', 'h', 'u', 'r', 'l', 'i', 's', 'h', '\n',
        'c', 'h', 'u', 'r', 'l', 'i', 's', 'h', 'l', 'y', '\n',
        'c', 'h', 'u', 'r', 'l', 'i', 's', 'h', 'n', 'e', 's', 's', '\n',
        'c', 'h', 'u', 'r', 'n', '\n',
        'c', 'h', 'u', 'r', 'n', 'e', 'd', '\n',
        'c', 'h', 'u', 'r', 'n', 'i', 'n', 'g', '\n',
        'c', 'h', 'u', 'r', 'n', 's', '\n',
        'c', 'h', 'u', 't', 'e', '\n',
        'c', 'h', 'u', 't', 'e', 's', '\n',
        'c', 'h', 'u', 't', 'n', 'e', 'y', '\n',
        'c', 'h', 'u', 't', 'z', 'p', 'a', 'h', '\n',
        'c', 'i', 'c', 'a', 'd', 'a', '\n',
        'c', 'i', 'c', 'a', 'd', 'a', 's', '\n',
        'c', 'i', 'c', 'e', 'r', 'o', '\n',
        'c', 'i', 'd', 'e', 'r', '\n',
        'c', 'i', 'd', 'e', 'r', 's', '\n',
        'c', 'i', 'g', 'a', 'r', '\n',
        'c', 'i', 'g', 'a', 'r', 'e', 't', '\n',
        'c', 'i', 'g', 'a', 'r', 'e', 't', 't', 'e', '\n',
        'c', 'i', 'g', 'a', 'r', 'e', 't', 't', 'e', 's', '\n',
        'c', 'i', 'g', 'a', 'r', 's', '\n',
        'c', 'i', 'l', 'i', 'a', '\n',
        'c', 'i', 'l', 'i', 'u', 'm', '\n',
        'c', 'i', 'n', 'c', 'h', '\n',
        'c', 'i', 'n', 'd', 'e', 'r', '\n',
        'c', 'i', 'n', 'd', 'e', 'r', 's', '\n',
        'c', 'i', 'n', 'e', '\n',
        'c', 'i', 'n', 'e', 'm', 'a', '\n',
        'c', 'i', 'n', 'e', 'm', 'a', 's', '\n',
        'c', 'i', 'n', 'e', 'm', 'a', 't', 'i', 'c', '\n',
        'c', 'i', 'n', 'e', 'm', 'a', 't', 'o', 'g', 'r', 'a', 'p', 'h', 'e', 'r', '\n',
        'c', 'i', 'n', 'e', 'm', 'a', 't', 'o', 'g', 'r', 'a', 'p', 'h', 'y', '\n',
        'c', 'i', 'n', 'n', 'a', 'm', 'o', 'n', '\n',
        'c', 'i', 'p', 'h', 'e', 'r', '\n',
        'c', 'i', 'p', 'h', 'e', 'r', 'e', 'd', '\n',
        'c', 'i', 'p', 'h', 'e', 'r', 's', '\n',
        'c', 'i', 'r', 'c', 'a', '\n',
        'c', 'i', 'r', 'c', 'a', 'd', 'i', 'a', 'n', '\n',
        'c', 'i', 'r', 'c', 'l', 'e', '\n',
        'c', 'i', 'r', 'c', 'l', 'e', 'd', '\n',
        'c', 'i', 'r', 'c', 'l', 'e', 's', '\n',
        'c', 'i', 'r', 'c', 'l', 'e', 't', '\n',
        'c', 'i', 'r', 'c', 'l', 'e', 't', 's', '\n',
        'c', 'i', 'r', 'c', 'l', 'i', 'n', 'g', '\n',
        'c', 'i', 'r', 'c', 'u', 'i', 't', '\n',
        'c', 'i', 'r', 'c', 'u', 'i', 't', 'o', 'u', 's', '\n',
        'c', 'i', 'r', 'c', 'u', 'i', 't', 'r', 'y', '\n',
        'c', 'i', 'r', 'c', 'u', 'i', 't', 's', '\n',
        'c', 'i', 'r', 'c', 'u', 'l', 'a', 'n', 't', '\n',
        'c', 'i', 'r', 'c', 'u', 'l', 'a', 'r', '\n',
        'c', 'i', 'r', 'c', 'u', 'l', 'a', 'r', 'i', 's', 'e', '\n',
        'c', 'i', 'r', 'c', 'u', 'l', 'a', 'r', 'i', 's', 'e', 'd', '\n',
        'c', 'i', 'r', 'c', 'u', 'l', 'a', 'r', 'i', 't', 'y', '\n',
        'c', 'i', 'r', 'c', 'u', 'l', 'a', 'r', 'l', 'y', '\n',
        'c', 'i', 'r', 'c', 'u', 'l', 'a', 'r', 's', '\n',
        'c', 'i', 'r', 'c', 'u', 'l', 'a', 't', 'e', '\n',
        'c', 'i', 'r', 'c', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'c', 'i', 'r', 'c', 'u', 'l', 'a', 't', 'e', 's', '\n',
        'c', 'i', 'r', 'c', 'u', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'i', 'r', 'c', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'i', 'r', 'c', 'u', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'i', 'r', 'c', 'u', 'l', 'a', 't', 'o', 'r', 'y', '\n',
        'c', 'i', 'r', 'c', 'u', 'm', 'c', 'i', 's', 'e', '\n',
        'c', 'i', 'r', 'c', 'u', 'm', 'c', 'i', 's', 'e', 'd', '\n',
        'c', 'i', 'r', 'c', 'u', 'm', 'c', 'i', 's', 'i', 'o', 'n', '\n',
        'c', 'i', 'r', 'c', 'u', 'm', 'f', 'e', 'r', 'e', 'n', 'c', 'e', '\n',
        'c', 'i', 'r', 'c', 'u', 'm', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 's', '\n',
        'c', 'i', 'r', 'c', 'u', 'm', 'f', 'e', 'r', 'e', 'n', 't', 'i', 'a', 'l', '\n',
        'c', 'i', 'r', 'c', 'u', 'm', 'f', 'l', 'e', 'x', '\n',
        'c', 'i', 'r', 'c', 'u', 'm', 'f', 'l', 'e', 'x', 'e', 's', '\n',
        'c', 'i', 'r', 'c', 'u', 'm', 'l', 'o', 'c', 'u', 't', 'i', 'o', 'n', '\n',
        'c', 'i', 'r', 'c', 'u', 'm', 'l', 'o', 'c', 'u', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'i', 'r', 'c', 'u', 'm', 'l', 'o', 'c', 'u', 't', 'o', 'r', 'y', '\n',
        'c', 'i', 'r', 'c', 'u', 'm', 'n', 'a', 'v', 'i', 'g', 'a', 't', 'e', '\n',
        'c', 'i', 'r', 'c', 'u', 'm', 'n', 'a', 'v', 'i', 'g', 'a', 't', 'e', 'd', '\n',
        'c', 'i', 'r', 'c', 'u', 'm', 'n', 'a', 'v', 'i', 'g', 'a', 't', 'e', 's', '\n',
        'c', 'i', 'r', 'c', 'u', 'm', 'n', 'a', 'v', 'i', 'g', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'i', 'r', 'c', 'u', 'm', 'n', 'a', 'v', 'i', 'g', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'c', 'i', 'r', 'c', 'u', 'm', 's', 'c', 'r', 'i', 'b', 'e', '\n',
        'c', 'i', 'r', 'c', 'u', 'm', 's', 'c', 'r', 'i', 'b', 'e', 'd', '\n',
        'c', 'i', 'r', 'c', 'u', 'm', 's', 'c', 'r', 'i', 'b', 'i', 'n', 'g', '\n',
        'c', 'i', 'r', 'c', 'u', 'm', 's', 'p', 'e', 'c', 't', '\n',
        'c', 'i', 'r', 'c', 'u', 'm', 's', 'p', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'c', 'i', 'r', 'c', 'u', 'm', 's', 'p', 'e', 'c', 't', 'l', 'y', '\n',
        'c', 'i', 'r', 'c', 'u', 'm', 's', 't', 'a', 'n', 'c', 'e', '\n',
        'c', 'i', 'r', 'c', 'u', 'm', 's', 't', 'a', 'n', 'c', 'e', 's', '\n',
        'c', 'i', 'r', 'c', 'u', 'm', 's', 't', 'a', 'n', 't', 'i', 'a', 'l', '\n',
        'c', 'i', 'r', 'c', 'u', 'm', 's', 't', 'a', 'n', 't', 'i', 'a', 'l', 'l', 'y', '\n',
        'c', 'i', 'r', 'c', 'u', 'm', 'v', 'e', 'n', 't', '\n',
        'c', 'i', 'r', 'c', 'u', 'm', 'v', 'e', 'n', 't', 'a', 'b', 'l', 'e', '\n',
        'c', 'i', 'r', 'c', 'u', 'm', 'v', 'e', 'n', 't', 'e', 'd', '\n',
        'c', 'i', 'r', 'c', 'u', 'm', 'v', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'c', 'i', 'r', 'c', 'u', 'm', 'v', 'e', 'n', 't', 'i', 'o', 'n', '\n',
        'c', 'i', 'r', 'c', 'u', 'm', 'v', 'e', 'n', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'i', 'r', 'c', 'u', 'm', 'v', 'e', 'n', 't', 's', '\n',
        'c', 'i', 'r', 'c', 'u', 's', '\n',
        'c', 'i', 'r', 'c', 'u', 's', 'e', 's', '\n',
        'c', 'i', 'r', 'r', 'h', 'o', 's', 'i', 's', '\n',
        'c', 'i', 'r', 'r', 'h', 'o', 't', 'i', 'c', '\n',
        'c', 'i', 'r', 'r', 'u', 's', '\n',
        'c', 'i', 's', 't', '\n',
        'c', 'i', 's', 't', 'e', 'r', 'n', '\n',
        'c', 'i', 's', 't', 'e', 'r', 'n', 's', '\n',
        'c', 'i', 't', 'a', 'd', 'e', 'l', '\n',
        'c', 'i', 't', 'a', 'd', 'e', 'l', 's', '\n',
        'c', 'i', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'i', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'i', 't', 'e', '\n',
        'c', 'i', 't', 'e', 'd', '\n',
        'c', 'i', 't', 'e', 's', '\n',
        'c', 'i', 't', 'h', 'e', 'r', 's', '\n',
        'c', 'i', 't', 'i', 'e', 's', '\n',
        'c', 'i', 't', 'i', 'n', 'g', '\n',
        'c', 'i', 't', 'i', 'z', 'e', 'n', '\n',
        'c', 'i', 't', 'i', 'z', 'e', 'n', 'r', 'y', '\n',
        'c', 'i', 't', 'i', 'z', 'e', 'n', 's', '\n',
        'c', 'i', 't', 'i', 'z', 'e', 'n', 's', 'h', 'i', 'p', '\n',
        'c', 'i', 't', 'r', 'a', 't', 'e', '\n',
        'c', 'i', 't', 'r', 'a', 't', 'e', 's', '\n',
        'c', 'i', 't', 'r', 'i', 'c', '\n',
        'c', 'i', 't', 'r', 'o', 'n', '\n',
        'c', 'i', 't', 'r', 'o', 'n', 's', '\n',
        'c', 'i', 't', 'r', 'u', 's', '\n',
        'c', 'i', 't', 'r', 'u', 's', 'e', 's', '\n',
        'c', 'i', 't', 't', 'e', 'r', 'n', '\n',
        'c', 'i', 't', 'y', '\n',
        'c', 'i', 't', 'y', 's', 'c', 'a', 'p', 'e', '\n',
        'c', 'i', 'v', 'i', 'c', '\n',
        'c', 'i', 'v', 'i', 'c', 's', '\n',
        'c', 'i', 'v', 'i', 'e', 's', '\n',
        'c', 'i', 'v', 'i', 'l', '\n',
        'c', 'i', 'v', 'i', 'l', 'i', 'a', 'n', '\n',
        'c', 'i', 'v', 'i', 'l', 'i', 'a', 'n', 's', '\n',
        'c', 'i', 'v', 'i', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'i', 'v', 'i', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'i', 'v', 'i', 'l', 'i', 's', 'e', '\n',
        'c', 'i', 'v', 'i', 'l', 'i', 's', 'e', 'd', '\n',
        'c', 'i', 'v', 'i', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'c', 'i', 'v', 'i', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'c', 'i', 'v', 'i', 'l', 'i', 't', 'y', '\n',
        'c', 'i', 'v', 'i', 'l', 'l', 'y', '\n',
        'c', 'l', 'a', 'c', 'k', 'i', 'n', 'g', '\n',
        'c', 'l', 'a', 'd', '\n',
        'c', 'l', 'a', 'd', 'd', 'i', 'n', 'g', '\n',
        'c', 'l', 'a', 'i', 'm', '\n',
        'c', 'l', 'a', 'i', 'm', 'a', 'b', 'l', 'e', '\n',
        'c', 'l', 'a', 'i', 'm', 'a', 'n', 't', '\n',
        'c', 'l', 'a', 'i', 'm', 'a', 'n', 't', 's', '\n',
        'c', 'l', 'a', 'i', 'm', 'e', 'd', '\n',
        'c', 'l', 'a', 'i', 'm', 'i', 'n', 'g', '\n',
        'c', 'l', 'a', 'i', 'm', 's', '\n',
        'c', 'l', 'a', 'i', 'r', 'v', 'o', 'y', 'a', 'n', 'c', 'e', '\n',
        'c', 'l', 'a', 'i', 'r', 'v', 'o', 'y', 'a', 'n', 't', '\n',
        'c', 'l', 'a', 'i', 'r', 'v', 'o', 'y', 'a', 'n', 't', 's', '\n',
        'c', 'l', 'a', 'm', '\n',
        'c', 'l', 'a', 'm', 'b', 'e', 'r', '\n',
        'c', 'l', 'a', 'm', 'b', 'e', 'r', 'e', 'd', '\n',
        'c', 'l', 'a', 'm', 'b', 'e', 'r', 'i', 'n', 'g', '\n',
        'c', 'l', 'a', 'm', 'b', 'e', 'r', 's', '\n',
        'c', 'l', 'a', 'm', 'm', 'e', 'd', '\n',
        'c', 'l', 'a', 'm', 'm', 'i', 'n', 'g', '\n',
        'c', 'l', 'a', 'm', 'm', 'y', '\n',
        'c', 'l', 'a', 'm', 'o', 'r', 'o', 'u', 's', '\n',
        'c', 'l', 'a', 'm', 'o', 'r', 'o', 'u', 's', 'l', 'y', '\n',
        'c', 'l', 'a', 'm', 'o', 'u', 'r', '\n',
        'c', 'l', 'a', 'm', 'o', 'u', 'r', 'e', 'd', '\n',
        'c', 'l', 'a', 'm', 'o', 'u', 'r', 'i', 'n', 'g', '\n',
        'c', 'l', 'a', 'm', 'o', 'u', 'r', 's', '\n',
        'c', 'l', 'a', 'm', 'p', '\n',
        'c', 'l', 'a', 'm', 'p', 'd', 'o', 'w', 'n', '\n',
        'c', 'l', 'a', 'm', 'p', 'e', 'd', '\n',
        'c', 'l', 'a', 'm', 'p', 'i', 'n', 'g', '\n',
        'c', 'l', 'a', 'm', 'p', 's', '\n',
        'c', 'l', 'a', 'm', 's', '\n',
        'c', 'l', 'a', 'n', '\n',
        'c', 'l', 'a', 'n', 'd', 'e', 's', 't', 'i', 'n', 'e', '\n',
        'c', 'l', 'a', 'n', 'd', 'e', 's', 't', 'i', 'n', 'e', 'l', 'y', '\n',
        'c', 'l', 'a', 'n', 'g', '\n',
        'c', 'l', 'a', 'n', 'g', 'e', 'd', '\n',
        'c', 'l', 'a', 'n', 'g', 'e', 'r', 's', '\n',
        'c', 'l', 'a', 'n', 'g', 'i', 'n', 'g', '\n',
        'c', 'l', 'a', 'n', 'k', '\n',
        'c', 'l', 'a', 'n', 'k', 'e', 'd', '\n',
        'c', 'l', 'a', 'n', 'k', 'i', 'n', 'g', '\n',
        'c', 'l', 'a', 'n', 'n', 'i', 's', 'h', '\n',
        'c', 'l', 'a', 'n', 's', '\n',
        'c', 'l', 'a', 'n', 's', 'm', 'e', 'n', '\n',
        'c', 'l', 'a', 'p', '\n',
        'c', 'l', 'a', 'p', 'p', 'e', 'd', '\n',
        'c', 'l', 'a', 'p', 'p', 'e', 'r', '\n',
        'c', 'l', 'a', 'p', 'p', 'e', 'r', 's', '\n',
        'c', 'l', 'a', 'p', 'p', 'i', 'n', 'g', '\n',
        'c', 'l', 'a', 'p', 's', '\n',
        'c', 'l', 'a', 'p', 't', 'r', 'a', 'p', '\n',
        'c', 'l', 'a', 'r', 'e', 't', '\n',
        'c', 'l', 'a', 'r', 'e', 't', 's', '\n',
        'c', 'l', 'a', 'r', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'l', 'a', 'r', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'l', 'a', 'r', 'i', 'f', 'i', 'e', 'd', '\n',
        'c', 'l', 'a', 'r', 'i', 'f', 'i', 'e', 's', '\n',
        'c', 'l', 'a', 'r', 'i', 'f', 'y', '\n',
        'c', 'l', 'a', 'r', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'c', 'l', 'a', 'r', 'i', 'n', 'e', 't', '\n',
        'c', 'l', 'a', 'r', 'i', 'n', 'e', 't', 's', '\n',
        'c', 'l', 'a', 'r', 'i', 'n', 'e', 't', 't', 'i', 's', 't', '\n',
        'c', 'l', 'a', 'r', 'i', 'o', 'n', '\n',
        'c', 'l', 'a', 'r', 'i', 't', 'y', '\n',
        'c', 'l', 'a', 's', 'h', '\n',
        'c', 'l', 'a', 's', 'h', 'e', 'd', '\n',
        'c', 'l', 'a', 's', 'h', 'e', 's', '\n',
        'c', 'l', 'a', 's', 'h', 'i', 'n', 'g', '\n',
        'c', 'l', 'a', 's', 'p', '\n',
        'c', 'l', 'a', 's', 'p', 'e', 'd', '\n',
        'c', 'l', 'a', 's', 'p', 'e', 'r', '\n',
        'c', 'l', 'a', 's', 'p', 'i', 'n', 'g', '\n',
        'c', 'l', 'a', 's', 'p', 's', '\n',
        'c', 'l', 'a', 's', 's', '\n',
        'c', 'l', 'a', 's', 's', 'e', 'd', '\n',
        'c', 'l', 'a', 's', 's', 'e', 's', '\n',
        'c', 'l', 'a', 's', 's', 'i', 'c', '\n',
        'c', 'l', 'a', 's', 's', 'i', 'c', 'a', 'l', '\n',
        'c', 'l', 'a', 's', 's', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'c', 'l', 'a', 's', 's', 'i', 'c', 'i', 's', 'm', '\n',
        'c', 'l', 'a', 's', 's', 'i', 'c', 'i', 's', 't', '\n',
        'c', 'l', 'a', 's', 's', 'i', 'c', 'i', 's', 't', 's', '\n',
        'c', 'l', 'a', 's', 's', 'i', 'c', 's', '\n',
        'c', 'l', 'a', 's', 's', 'i', 'e', 'r', '\n',
        'c', 'l', 'a', 's', 's', 'i', 'e', 's', 't', '\n',
        'c', 'l', 'a', 's', 's', 'i', 'f', 'i', 'a', 'b', 'l', 'e', '\n',
        'c', 'l', 'a', 's', 's', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'l', 'a', 's', 's', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'l', 'a', 's', 's', 'i', 'f', 'i', 'c', 'a', 't', 'o', 'r', 'y', '\n',
        'c', 'l', 'a', 's', 's', 'i', 'f', 'i', 'e', 'd', '\n',
        'c', 'l', 'a', 's', 's', 'i', 'f', 'i', 'e', 'r', '\n',
        'c', 'l', 'a', 's', 's', 'i', 'f', 'i', 'e', 'r', 's', '\n',
        'c', 'l', 'a', 's', 's', 'i', 'f', 'i', 'e', 's', '\n',
        'c', 'l', 'a', 's', 's', 'i', 'f', 'y', '\n',
        'c', 'l', 'a', 's', 's', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'c', 'l', 'a', 's', 's', 'i', 'n', 'g', '\n',
        'c', 'l', 'a', 's', 's', 'l', 'e', 's', 's', '\n',
        'c', 'l', 'a', 's', 's', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'c', 'l', 'a', 's', 's', 'm', 'a', 't', 'e', '\n',
        'c', 'l', 'a', 's', 's', 'm', 'a', 't', 'e', 's', '\n',
        'c', 'l', 'a', 's', 's', 'r', 'o', 'o', 'm', '\n',
        'c', 'l', 'a', 's', 's', 'r', 'o', 'o', 'm', 's', '\n',
        'c', 'l', 'a', 's', 's', 'y', '\n',
        'c', 'l', 'a', 't', 't', 'e', 'r', '\n',
        'c', 'l', 'a', 't', 't', 'e', 'r', 'e', 'd', '\n',
        'c', 'l', 'a', 't', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'c', 'l', 'a', 't', 't', 'e', 'r', 's', '\n',
        'c', 'l', 'a', 'u', 's', 'a', 'l', '\n',
        'c', 'l', 'a', 'u', 's', 'e', '\n',
        'c', 'l', 'a', 'u', 's', 'e', 's', '\n',
        'c', 'l', 'a', 'u', 's', 't', 'r', 'o', 'p', 'h', 'o', 'b', 'i', 'a', '\n',
        'c', 'l', 'a', 'u', 's', 't', 'r', 'o', 'p', 'h', 'o', 'b', 'i', 'c', '\n',
        'c', 'l', 'a', 'v', 'i', 'c', 'h', 'o', 'r', 'd', '\n',
        'c', 'l', 'a', 'v', 'i', 'c', 'l', 'e', '\n',
        'c', 'l', 'a', 'w', '\n',
        'c', 'l', 'a', 'w', 'e', 'd', '\n',
        'c', 'l', 'a', 'w', 'i', 'n', 'g', '\n',
        'c', 'l', 'a', 'w', 's', '\n',
        'c', 'l', 'a', 'y', '\n',
        'c', 'l', 'a', 'y', 'e', 'y', '\n',
        'c', 'l', 'a', 'y', 'm', 'o', 'r', 'e', '\n',
        'c', 'l', 'a', 'y', 'm', 'o', 'r', 'e', 's', '\n',
        'c', 'l', 'a', 'y', 's', '\n',
        'c', 'l', 'e', 'a', 'n', '\n',
        'c', 'l', 'e', 'a', 'n', 'c', 'u', 't', '\n',
        'c', 'l', 'e', 'a', 'n', 'e', 'd', '\n',
        'c', 'l', 'e', 'a', 'n', 'e', 'r', '\n',
        'c', 'l', 'e', 'a', 'n', 'e', 'r', 's', '\n',
        'c', 'l', 'e', 'a', 'n', 'e', 's', 't', '\n',
        'c', 'l', 'e', 'a', 'n', 'i', 'n', 'g', '\n',
        'c', 'l', 'e', 'a', 'n', 'l', 'i', 'n', 'e', 's', 's', '\n',
        'c', 'l', 'e', 'a', 'n', 'l', 'i', 'v', 'i', 'n', 'g', '\n',
        'c', 'l', 'e', 'a', 'n', 'l', 'y', '\n',
        'c', 'l', 'e', 'a', 'n', 'n', 'e', 's', 's', '\n',
        'c', 'l', 'e', 'a', 'n', 's', '\n',
        'c', 'l', 'e', 'a', 'n', 's', 'e', '\n',
        'c', 'l', 'e', 'a', 'n', 's', 'e', 'd', '\n',
        'c', 'l', 'e', 'a', 'n', 's', 'e', 'r', '\n',
        'c', 'l', 'e', 'a', 'n', 's', 'e', 's', '\n',
        'c', 'l', 'e', 'a', 'n', 's', 'h', 'a', 'v', 'e', 'n', '\n',
        'c', 'l', 'e', 'a', 'n', 's', 'i', 'n', 'g', '\n',
        'c', 'l', 'e', 'a', 'n', 'u', 'p', '\n',
        'c', 'l', 'e', 'a', 'r', '\n',
        'c', 'l', 'e', 'a', 'r', 'a', 'n', 'c', 'e', '\n',
        'c', 'l', 'e', 'a', 'r', 'a', 'n', 'c', 'e', 's', '\n',
        'c', 'l', 'e', 'a', 'r', 'c', 'u', 't', '\n',
        'c', 'l', 'e', 'a', 'r', 'e', 'd', '\n',
        'c', 'l', 'e', 'a', 'r', 'e', 'r', '\n',
        'c', 'l', 'e', 'a', 'r', 'e', 's', 't', '\n',
        'c', 'l', 'e', 'a', 'r', 'h', 'e', 'a', 'd', 'e', 'd', '\n',
        'c', 'l', 'e', 'a', 'r', 'i', 'n', 'g', '\n',
        'c', 'l', 'e', 'a', 'r', 'i', 'n', 'g', 's', '\n',
        'c', 'l', 'e', 'a', 'r', 'l', 'y', '\n',
        'c', 'l', 'e', 'a', 'r', 'n', 'e', 's', 's', '\n',
        'c', 'l', 'e', 'a', 'r', 's', '\n',
        'c', 'l', 'e', 'a', 'r', 's', 'i', 'g', 'h', 't', 'e', 'd', '\n',
        'c', 'l', 'e', 'a', 'r', 'u', 'p', '\n',
        'c', 'l', 'e', 'a', 'r', 'u', 'p', 's', '\n',
        'c', 'l', 'e', 'a', 'r', 'w', 'a', 'y', '\n',
        'c', 'l', 'e', 'a', 't', '\n',
        'c', 'l', 'e', 'a', 'v', 'a', 'g', 'e', '\n',
        'c', 'l', 'e', 'a', 'v', 'a', 'g', 'e', 's', '\n',
        'c', 'l', 'e', 'a', 'v', 'e', '\n',
        'c', 'l', 'e', 'a', 'v', 'e', 'd', '\n',
        'c', 'l', 'e', 'a', 'v', 'e', 'r', '\n',
        'c', 'l', 'e', 'a', 'v', 'e', 'r', 's', '\n',
        'c', 'l', 'e', 'a', 'v', 'e', 's', '\n',
        'c', 'l', 'e', 'a', 'v', 'i', 'n', 'g', '\n',
        'c', 'l', 'e', 'f', '\n',
        'c', 'l', 'e', 'f', 't', '\n',
        'c', 'l', 'e', 'f', 't', 's', '\n',
        'c', 'l', 'e', 'g', '\n',
        'c', 'l', 'e', 'm', 'a', 't', 'i', 's', '\n',
        'c', 'l', 'e', 'm', 'e', 'n', 'c', 'y', '\n',
        'c', 'l', 'e', 'm', 'e', 'n', 't', '\n',
        'c', 'l', 'e', 'n', 'c', 'h', '\n',
        'c', 'l', 'e', 'n', 'c', 'h', 'e', 'd', '\n',
        'c', 'l', 'e', 'n', 'c', 'h', 'e', 's', '\n',
        'c', 'l', 'e', 'n', 'c', 'h', 'i', 'n', 'g', '\n',
        'c', 'l', 'e', 'r', 'g', 'i', 'e', 's', '\n',
        'c', 'l', 'e', 'r', 'g', 'y', '\n',
        'c', 'l', 'e', 'r', 'g', 'y', 'm', 'a', 'n', '\n',
        'c', 'l', 'e', 'r', 'g', 'y', 'm', 'e', 'n', '\n',
        'c', 'l', 'e', 'r', 'i', 'c', '\n',
        'c', 'l', 'e', 'r', 'i', 'c', 'a', 'l', '\n',
        'c', 'l', 'e', 'r', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'c', 'l', 'e', 'r', 'i', 'c', 's', '\n',
        'c', 'l', 'e', 'r', 'k', '\n',
        'c', 'l', 'e', 'r', 'k', 's', '\n',
        'c', 'l', 'e', 'v', 'e', 'r', '\n',
        'c', 'l', 'e', 'v', 'e', 'r', 'e', 'r', '\n',
        'c', 'l', 'e', 'v', 'e', 'r', 'e', 's', 't', '\n',
        'c', 'l', 'e', 'v', 'e', 'r', 'l', 'y', '\n',
        'c', 'l', 'e', 'v', 'e', 'r', 'n', 'e', 's', 's', '\n',
        'c', 'l', 'i', 'c', 'h', 'e', '\n',
        'c', 'l', 'i', 'c', 'h', 'e', 's', '\n',
        'c', 'l', 'i', 'c', 'k', '\n',
        'c', 'l', 'i', 'c', 'k', 'e', 'd', '\n',
        'c', 'l', 'i', 'c', 'k', 'i', 'n', 'g', '\n',
        'c', 'l', 'i', 'c', 'k', 's', '\n',
        'c', 'l', 'i', 'e', 'n', 't', '\n',
        'c', 'l', 'i', 'e', 'n', 't', 'e', 'l', 'e', '\n',
        'c', 'l', 'i', 'e', 'n', 't', 's', '\n',
        'c', 'l', 'i', 'f', 'f', '\n',
        'c', 'l', 'i', 'f', 'f', 'h', 'a', 'n', 'g', 'e', 'r', '\n',
        'c', 'l', 'i', 'f', 'f', 's', '\n',
        'c', 'l', 'i', 'm', 'a', 'c', 't', 'i', 'c', '\n',
        'c', 'l', 'i', 'm', 'a', 't', 'e', '\n',
        'c', 'l', 'i', 'm', 'a', 't', 'e', 's', '\n',
        'c', 'l', 'i', 'm', 'a', 't', 'i', 'c', '\n',
        'c', 'l', 'i', 'm', 'a', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'c', 'l', 'i', 'm', 'a', 't', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'c', 'l', 'i', 'm', 'a', 't', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'c', 'l', 'i', 'm', 'a', 't', 'o', 'l', 'o', 'g', 'y', '\n',
        'c', 'l', 'i', 'm', 'a', 'x', '\n',
        'c', 'l', 'i', 'm', 'a', 'x', 'e', 'd', '\n',
        'c', 'l', 'i', 'm', 'a', 'x', 'e', 's', '\n',
        'c', 'l', 'i', 'm', 'a', 'x', 'i', 'n', 'g', '\n',
        'c', 'l', 'i', 'm', 'b', '\n',
        'c', 'l', 'i', 'm', 'b', 'a', 'b', 'l', 'e', '\n',
        'c', 'l', 'i', 'm', 'b', 'd', 'o', 'w', 'n', '\n',
        'c', 'l', 'i', 'm', 'b', 'e', 'd', '\n',
        'c', 'l', 'i', 'm', 'b', 'e', 'r', '\n',
        'c', 'l', 'i', 'm', 'b', 'e', 'r', 's', '\n',
        'c', 'l', 'i', 'm', 'b', 'i', 'n', 'g', '\n',
        'c', 'l', 'i', 'm', 'b', 's', '\n',
        'c', 'l', 'i', 'm', 'e', 's', '\n',
        'c', 'l', 'i', 'n', 'c', 'h', '\n',
        'c', 'l', 'i', 'n', 'c', 'h', 'e', 'd', '\n',
        'c', 'l', 'i', 'n', 'c', 'h', 'e', 's', '\n',
        'c', 'l', 'i', 'n', 'c', 'h', 'i', 'n', 'g', '\n',
        'c', 'l', 'i', 'n', 'g', '\n',
        'c', 'l', 'i', 'n', 'g', 'e', 'r', 's', '\n',
        'c', 'l', 'i', 'n', 'g', 'i', 'n', 'g', '\n',
        'c', 'l', 'i', 'n', 'g', 's', '\n',
        'c', 'l', 'i', 'n', 'i', 'c', '\n',
        'c', 'l', 'i', 'n', 'i', 'c', 'a', 'l', '\n',
        'c', 'l', 'i', 'n', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'c', 'l', 'i', 'n', 'i', 'c', 'i', 'a', 'n', '\n',
        'c', 'l', 'i', 'n', 'i', 'c', 'i', 'a', 'n', 's', '\n',
        'c', 'l', 'i', 'n', 'i', 'c', 's', '\n',
        'c', 'l', 'i', 'n', 'k', '\n',
        'c', 'l', 'i', 'n', 'k', 'e', 'd', '\n',
        'c', 'l', 'i', 'n', 'k', 'e', 'r', '\n',
        'c', 'l', 'i', 'n', 'k', 'i', 'n', 'g', '\n',
        'c', 'l', 'i', 'p', '\n',
        'c', 'l', 'i', 'p', 'b', 'o', 'a', 'r', 'd', '\n',
        'c', 'l', 'i', 'p', 'b', 'o', 'a', 'r', 'd', 's', '\n',
        'c', 'l', 'i', 'p', 'p', 'e', 'd', '\n',
        'c', 'l', 'i', 'p', 'p', 'e', 'r', '\n',
        'c', 'l', 'i', 'p', 'p', 'e', 'r', 's', '\n',
        'c', 'l', 'i', 'p', 'p', 'i', 'n', 'g', '\n',
        'c', 'l', 'i', 'p', 'p', 'i', 'n', 'g', 's', '\n',
        'c', 'l', 'i', 'p', 's', '\n',
        'c', 'l', 'i', 'q', 'u', 'e', '\n',
        'c', 'l', 'i', 'q', 'u', 'e', 's', '\n',
        'c', 'l', 'i', 'q', 'u', 'e', 'y', '\n',
        'c', 'l', 'i', 't', 'o', 'r', 'a', 'l', '\n',
        'c', 'l', 'i', 't', 'o', 'r', 'i', 's', '\n',
        'c', 'l', 'o', 'a', 'c', 'a', '\n',
        'c', 'l', 'o', 'a', 'k', '\n',
        'c', 'l', 'o', 'a', 'k', 'a', 'n', 'd', 'd', 'a', 'g', 'g', 'e', 'r', '\n',
        'c', 'l', 'o', 'a', 'k', 'e', 'd', '\n',
        'c', 'l', 'o', 'a', 'k', 'i', 'n', 'g', '\n',
        'c', 'l', 'o', 'a', 'k', 'r', 'o', 'o', 'm', '\n',
        'c', 'l', 'o', 'a', 'k', 'r', 'o', 'o', 'm', 's', '\n',
        'c', 'l', 'o', 'a', 'k', 's', '\n',
        'c', 'l', 'o', 'b', 'b', 'e', 'r', '\n',
        'c', 'l', 'o', 'c', 'k', '\n',
        'c', 'l', 'o', 'c', 'k', 'e', 'd', '\n',
        'c', 'l', 'o', 'c', 'k', 'i', 'n', 'g', '\n',
        'c', 'l', 'o', 'c', 'k', 'm', 'a', 'k', 'e', 'r', '\n',
        'c', 'l', 'o', 'c', 'k', 's', '\n',
        'c', 'l', 'o', 'c', 'k', 'w', 'i', 's', 'e', '\n',
        'c', 'l', 'o', 'c', 'k', 'w', 'o', 'r', 'k', '\n',
        'c', 'l', 'o', 'd', '\n',
        'c', 'l', 'o', 'd', 's', '\n',
        'c', 'l', 'o', 'g', '\n',
        'c', 'l', 'o', 'g', 'g', 'e', 'd', '\n',
        'c', 'l', 'o', 'g', 'g', 'i', 'n', 'g', '\n',
        'c', 'l', 'o', 'g', 's', '\n',
        'c', 'l', 'o', 'i', 's', 't', 'e', 'r', '\n',
        'c', 'l', 'o', 'i', 's', 't', 'e', 'r', 'e', 'd', '\n',
        'c', 'l', 'o', 'i', 's', 't', 'e', 'r', 's', '\n',
        'c', 'l', 'o', 'n', 'a', 'l', '\n',
        'c', 'l', 'o', 'n', 'e', '\n',
        'c', 'l', 'o', 'n', 'e', 'd', '\n',
        'c', 'l', 'o', 'n', 'e', 's', '\n',
        'c', 'l', 'o', 'n', 'i', 'n', 'g', '\n',
        'c', 'l', 'o', 's', 'a', 'b', 'l', 'e', '\n',
        'c', 'l', 'o', 's', 'e', '\n',
        'c', 'l', 'o', 's', 'e', 'd', '\n',
        'c', 'l', 'o', 's', 'e', 'd', 'c', 'i', 'r', 'c', 'u', 'i', 't', '\n',
        'c', 'l', 'o', 's', 'e', 'k', 'n', 'i', 't', '\n',
        'c', 'l', 'o', 's', 'e', 'l', 'y', '\n',
        'c', 'l', 'o', 's', 'e', 'n', 'e', 's', 's', '\n',
        'c', 'l', 'o', 's', 'e', 'r', '\n',
        'c', 'l', 'o', 's', 'e', 'r', 's', '\n',
        'c', 'l', 'o', 's', 'e', 's', '\n',
        'c', 'l', 'o', 's', 'e', 's', 't', '\n',
        'c', 'l', 'o', 's', 'e', 't', '\n',
        'c', 'l', 'o', 's', 'e', 't', 'e', 'd', '\n',
        'c', 'l', 'o', 's', 'e', 't', 's', '\n',
        'c', 'l', 'o', 's', 'e', 'u', 'p', '\n',
        'c', 'l', 'o', 's', 'e', 'u', 'p', 's', '\n',
        'c', 'l', 'o', 's', 'i', 'n', 'g', '\n',
        'c', 'l', 'o', 's', 'i', 'n', 'g', 's', '\n',
        'c', 'l', 'o', 's', 'u', 'r', 'e', '\n',
        'c', 'l', 'o', 's', 'u', 'r', 'e', 's', '\n',
        'c', 'l', 'o', 't', '\n',
        'c', 'l', 'o', 't', 'h', '\n',
        'c', 'l', 'o', 't', 'h', 'e', '\n',
        'c', 'l', 'o', 't', 'h', 'e', 'd', '\n',
        'c', 'l', 'o', 't', 'h', 'e', 's', '\n',
        'c', 'l', 'o', 't', 'h', 'e', 's', 'p', 'e', 'g', '\n',
        'c', 'l', 'o', 't', 'h', 'e', 's', 'p', 'e', 'g', 's', '\n',
        'c', 'l', 'o', 't', 'h', 'i', 'e', 'r', '\n',
        'c', 'l', 'o', 't', 'h', 'i', 'e', 'r', 's', '\n',
        'c', 'l', 'o', 't', 'h', 'i', 'n', 'g', '\n',
        'c', 'l', 'o', 't', 'h', 's', '\n',
        'c', 'l', 'o', 't', 's', '\n',
        'c', 'l', 'o', 't', 't', 'e', 'd', '\n',
        'c', 'l', 'o', 't', 't', 'i', 'n', 'g', '\n',
        'c', 'l', 'o', 'u', 'd', '\n',
        'c', 'l', 'o', 'u', 'd', 'b', 'u', 'r', 's', 't', '\n',
        'c', 'l', 'o', 'u', 'd', 'b', 'u', 'r', 's', 't', 's', '\n',
        'c', 'l', 'o', 'u', 'd', 'e', 'd', '\n',
        'c', 'l', 'o', 'u', 'd', 'i', 'e', 'r', '\n',
        'c', 'l', 'o', 'u', 'd', 'i', 'e', 's', 't', '\n',
        'c', 'l', 'o', 'u', 'd', 'i', 'n', 'e', 's', 's', '\n',
        'c', 'l', 'o', 'u', 'd', 'i', 'n', 'g', '\n',
        'c', 'l', 'o', 'u', 'd', 'l', 'e', 's', 's', '\n',
        'c', 'l', 'o', 'u', 'd', 's', '\n',
        'c', 'l', 'o', 'u', 'd', 's', 'c', 'a', 'p', 'e', '\n',
        'c', 'l', 'o', 'u', 'd', 's', 'c', 'a', 'p', 'e', 's', '\n',
        'c', 'l', 'o', 'u', 'd', 'y', '\n',
        'c', 'l', 'o', 'u', 't', '\n',
        'c', 'l', 'o', 'u', 't', 'e', 'd', '\n',
        'c', 'l', 'o', 'u', 't', 's', '\n',
        'c', 'l', 'o', 'v', 'e', '\n',
        'c', 'l', 'o', 'v', 'e', 'n', '\n',
        'c', 'l', 'o', 'v', 'e', 'r', '\n',
        'c', 'l', 'o', 'v', 'e', 's', '\n',
        'c', 'l', 'o', 'w', 'n', '\n',
        'c', 'l', 'o', 'w', 'n', 'e', 'd', '\n',
        'c', 'l', 'o', 'w', 'n', 'i', 'n', 'g', '\n',
        'c', 'l', 'o', 'w', 'n', 'i', 's', 'h', '\n',
        'c', 'l', 'o', 'w', 'n', 's', '\n',
        'c', 'l', 'o', 'y', 'i', 'n', 'g', '\n',
        'c', 'l', 'o', 'y', 'i', 'n', 'g', 'l', 'y', '\n',
        'c', 'l', 'u', 'b', '\n',
        'c', 'l', 'u', 'b', 'b', 'e', 'd', '\n',
        'c', 'l', 'u', 'b', 'b', 'i', 'n', 'g', '\n',
        'c', 'l', 'u', 'b', 'f', 'o', 'o', 't', 'e', 'd', '\n',
        'c', 'l', 'u', 'b', 'h', 'o', 'u', 's', 'e', '\n',
        'c', 'l', 'u', 'b', 'm', 'a', 'n', '\n',
        'c', 'l', 'u', 'b', 'r', 'o', 'o', 'm', '\n',
        'c', 'l', 'u', 'b', 's', '\n',
        'c', 'l', 'u', 'c', 'k', '\n',
        'c', 'l', 'u', 'c', 'k', 'e', 'd', '\n',
        'c', 'l', 'u', 'c', 'k', 'i', 'n', 'g', '\n',
        'c', 'l', 'u', 'c', 'k', 's', '\n',
        'c', 'l', 'u', 'e', '\n',
        'c', 'l', 'u', 'e', 'd', '\n',
        'c', 'l', 'u', 'e', 'd', 'u', 'p', '\n',
        'c', 'l', 'u', 'e', 'l', 'e', 's', 's', '\n',
        'c', 'l', 'u', 'e', 's', '\n',
        'c', 'l', 'u', 'm', 'b', 'e', 'r', '\n',
        'c', 'l', 'u', 'm', 'p', '\n',
        'c', 'l', 'u', 'm', 'p', 'e', 'd', '\n',
        'c', 'l', 'u', 'm', 'p', 'i', 'n', 'g', '\n',
        'c', 'l', 'u', 'm', 'p', 's', '\n',
        'c', 'l', 'u', 'm', 'p', 'y', '\n',
        'c', 'l', 'u', 'm', 's', 'i', 'e', 'r', '\n',
        'c', 'l', 'u', 'm', 's', 'i', 'e', 's', 't', '\n',
        'c', 'l', 'u', 'm', 's', 'i', 'l', 'y', '\n',
        'c', 'l', 'u', 'm', 's', 'i', 'n', 'e', 's', 's', '\n',
        'c', 'l', 'u', 'm', 's', 'y', '\n',
        'c', 'l', 'u', 'n', 'g', '\n',
        'c', 'l', 'u', 's', 't', 'e', 'r', '\n',
        'c', 'l', 'u', 's', 't', 'e', 'r', 'e', 'd', '\n',
        'c', 'l', 'u', 's', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'c', 'l', 'u', 's', 't', 'e', 'r', 's', '\n',
        'c', 'l', 'u', 't', 'c', 'h', '\n',
        'c', 'l', 'u', 't', 'c', 'h', 'e', 'd', '\n',
        'c', 'l', 'u', 't', 'c', 'h', 'e', 's', '\n',
        'c', 'l', 'u', 't', 'c', 'h', 'i', 'n', 'g', '\n',
        'c', 'l', 'u', 't', 't', 'e', 'r', '\n',
        'c', 'l', 'u', 't', 't', 'e', 'r', 'e', 'd', '\n',
        'c', 'l', 'u', 't', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'c', 'l', 'u', 't', 't', 'e', 'r', 's', '\n',
        'c', 'o', 'a', 'c', 'h', '\n',
        'c', 'o', 'a', 'c', 'h', 'e', 'd', '\n',
        'c', 'o', 'a', 'c', 'h', 'e', 's', '\n',
        'c', 'o', 'a', 'c', 'h', 'i', 'n', 'g', '\n',
        'c', 'o', 'a', 'c', 'h', 'l', 'o', 'a', 'd', '\n',
        'c', 'o', 'a', 'c', 'h', 'l', 'o', 'a', 'd', 's', '\n',
        'c', 'o', 'a', 'c', 'h', 'm', 'a', 'n', '\n',
        'c', 'o', 'a', 'c', 'h', 'm', 'e', 'n', '\n',
        'c', 'o', 'a', 'c', 'h', 'w', 'o', 'r', 'k', '\n',
        'c', 'o', 'a', 'c', 't', 'e', 'd', '\n',
        'c', 'o', 'a', 'c', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'a', 'c', 't', 's', '\n',
        'c', 'o', 'a', 'g', 'u', 'l', 'a', 't', 'e', '\n',
        'c', 'o', 'a', 'g', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'c', 'o', 'a', 'g', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'a', 'l', '\n',
        'c', 'o', 'a', 'l', 'b', 'l', 'a', 'c', 'k', '\n',
        'c', 'o', 'a', 'l', 'e', 's', 'c', 'e', '\n',
        'c', 'o', 'a', 'l', 'e', 's', 'c', 'e', 'd', '\n',
        'c', 'o', 'a', 'l', 'e', 's', 'c', 'e', 'n', 'c', 'e', '\n',
        'c', 'o', 'a', 'l', 'e', 's', 'c', 'e', 's', '\n',
        'c', 'o', 'a', 'l', 'e', 's', 'c', 'i', 'n', 'g', '\n',
        'c', 'o', 'a', 'l', 'f', 'a', 'c', 'e', '\n',
        'c', 'o', 'a', 'l', 'f', 'i', 'e', 'l', 'd', '\n',
        'c', 'o', 'a', 'l', 'f', 'i', 'e', 'l', 'd', 's', '\n',
        'c', 'o', 'a', 'l', 'i', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'a', 'l', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'a', 'l', 'm', 'i', 'n', 'e', 'r', 's', '\n',
        'c', 'o', 'a', 'l', 's', '\n',
        'c', 'o', 'a', 'p', 't', 's', '\n',
        'c', 'o', 'a', 'r', 's', 'e', '\n',
        'c', 'o', 'a', 'r', 's', 'e', 'l', 'y', '\n',
        'c', 'o', 'a', 'r', 's', 'e', 'n', 'e', 's', 's', '\n',
        'c', 'o', 'a', 'r', 's', 'e', 'n', 's', '\n',
        'c', 'o', 'a', 'r', 's', 'e', 'r', '\n',
        'c', 'o', 'a', 'r', 's', 'e', 's', 't', '\n',
        'c', 'o', 'a', 's', 't', '\n',
        'c', 'o', 'a', 's', 't', 'a', 'l', '\n',
        'c', 'o', 'a', 's', 't', 'e', 'd', '\n',
        'c', 'o', 'a', 's', 't', 'e', 'r', '\n',
        'c', 'o', 'a', 's', 't', 'e', 'r', 's', '\n',
        'c', 'o', 'a', 's', 't', 'g', 'u', 'a', 'r', 'd', '\n',
        'c', 'o', 'a', 's', 't', 'g', 'u', 'a', 'r', 'd', 's', '\n',
        'c', 'o', 'a', 's', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'a', 's', 't', 'l', 'a', 'n', 'd', 's', '\n',
        'c', 'o', 'a', 's', 't', 'l', 'i', 'n', 'e', '\n',
        'c', 'o', 'a', 's', 't', 'l', 'i', 'n', 'e', 's', '\n',
        'c', 'o', 'a', 's', 't', 's', '\n',
        'c', 'o', 'a', 't', '\n',
        'c', 'o', 'a', 't', 'e', 'd', '\n',
        'c', 'o', 'a', 't', 'h', 'a', 'n', 'g', 'e', 'r', '\n',
        'c', 'o', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'a', 't', 'i', 'n', 'g', 's', '\n',
        'c', 'o', 'a', 't', 's', '\n',
        'c', 'o', 'a', 'u', 't', 'h', 'o', 'r', '\n',
        'c', 'o', 'a', 'u', 't', 'h', 'o', 'r', 'e', 'd', '\n',
        'c', 'o', 'a', 'u', 't', 'h', 'o', 'r', 'i', 'n', 'g', '\n',
        'c', 'o', 'a', 'u', 't', 'h', 'o', 'r', 's', '\n',
        'c', 'o', 'a', 'x', '\n',
        'c', 'o', 'a', 'x', 'e', 'd', '\n',
        'c', 'o', 'a', 'x', 'e', 's', '\n',
        'c', 'o', 'a', 'x', 'i', 'a', 'l', '\n',
        'c', 'o', 'a', 'x', 'i', 'n', 'g', '\n',
        'c', 'o', 'a', 'x', 'i', 'n', 'g', 'l', 'y', '\n',
        'c', 'o', 'b', '\n',
        'c', 'o', 'b', 'a', 'l', 't', '\n',
        'c', 'o', 'b', 'b', 'l', 'e', '\n',
        'c', 'o', 'b', 'b', 'l', 'e', 'd', '\n',
        'c', 'o', 'b', 'b', 'l', 'e', 'r', '\n',
        'c', 'o', 'b', 'b', 'l', 'e', 'r', 's', '\n',
        'c', 'o', 'b', 'b', 'l', 'e', 's', '\n',
        'c', 'o', 'b', 'b', 'l', 'e', 's', 't', 'o', 'n', 'e', 's', '\n',
        'c', 'o', 'b', 'b', 'l', 'i', 'n', 'g', '\n',
        'c', 'o', 'b', 'l', 'e', '\n',
        'c', 'o', 'b', 'r', 'a', '\n',
        'c', 'o', 'b', 'r', 'a', 's', '\n',
        'c', 'o', 'b', 's', '\n',
        'c', 'o', 'b', 'w', 'e', 'b', '\n',
        'c', 'o', 'b', 'w', 'e', 'b', 'b', 'e', 'd', '\n',
        'c', 'o', 'b', 'w', 'e', 'b', 'b', 'y', '\n',
        'c', 'o', 'b', 'w', 'e', 'b', 's', '\n',
        'c', 'o', 'c', 'a', '\n',
        'c', 'o', 'c', 'a', 'i', 'n', '\n',
        'c', 'o', 'c', 'a', 'i', 'n', 'e', '\n',
        'c', 'o', 'c', 'h', 'l', 'e', 'a', '\n',
        'c', 'o', 'c', 'h', 'l', 'e', 'a', 'r', '\n',
        'c', 'o', 'c', 'k', '\n',
        'c', 'o', 'c', 'k', 'a', 't', 'o', 'o', '\n',
        'c', 'o', 'c', 'k', 'a', 't', 'o', 'o', 's', '\n',
        'c', 'o', 'c', 'k', 'a', 't', 'r', 'i', 'c', 'e', '\n',
        'c', 'o', 'c', 'k', 'a', 't', 'r', 'i', 'c', 'e', 's', '\n',
        'c', 'o', 'c', 'k', 'c', 'r', 'o', 'w', '\n',
        'c', 'o', 'c', 'k', 'e', 'd', '\n',
        'c', 'o', 'c', 'k', 'e', 'r', 'e', 'l', '\n',
        'c', 'o', 'c', 'k', 'e', 'r', 'e', 'l', 's', '\n',
        'c', 'o', 'c', 'k', 'e', 'y', 'e', 'd', '\n',
        'c', 'o', 'c', 'k', 'i', 'e', 'r', '\n',
        'c', 'o', 'c', 'k', 'i', 'e', 's', 't', '\n',
        'c', 'o', 'c', 'k', 'i', 'n', 'e', 's', 's', '\n',
        'c', 'o', 'c', 'k', 'i', 'n', 'g', '\n',
        'c', 'o', 'c', 'k', 'l', 'e', '\n',
        'c', 'o', 'c', 'k', 'l', 'e', 's', '\n',
        'c', 'o', 'c', 'k', 'n', 'e', 'y', '\n',
        'c', 'o', 'c', 'k', 'n', 'e', 'y', 's', '\n',
        'c', 'o', 'c', 'k', 'p', 'i', 't', '\n',
        'c', 'o', 'c', 'k', 'p', 'i', 't', 's', '\n',
        'c', 'o', 'c', 'k', 'r', 'o', 'a', 'c', 'h', '\n',
        'c', 'o', 'c', 'k', 'r', 'o', 'a', 'c', 'h', 'e', 's', '\n',
        'c', 'o', 'c', 'k', 's', '\n',
        'c', 'o', 'c', 'k', 's', 'h', 'i', 'e', 's', '\n',
        'c', 'o', 'c', 'k', 's', 'u', 'r', 'e', '\n',
        'c', 'o', 'c', 'k', 't', 'a', 'i', 'l', '\n',
        'c', 'o', 'c', 'k', 't', 'a', 'i', 'l', 's', '\n',
        'c', 'o', 'c', 'k', 'y', '\n',
        'c', 'o', 'c', 'o', 'a', '\n',
        'c', 'o', 'c', 'o', 'n', 'u', 't', '\n',
        'c', 'o', 'c', 'o', 'n', 'u', 't', 's', '\n',
        'c', 'o', 'c', 'o', 'o', 'n', '\n',
        'c', 'o', 'c', 'o', 'o', 'n', 'e', 'd', '\n',
        'c', 'o', 'c', 'o', 'o', 'n', 's', '\n',
        'c', 'o', 'd', '\n',
        'c', 'o', 'd', 'a', '\n',
        'c', 'o', 'd', 'd', 'l', 'e', '\n',
        'c', 'o', 'd', 'd', 'l', 'i', 'n', 'g', '\n',
        'c', 'o', 'd', 'e', '\n',
        'c', 'o', 'd', 'e', 'b', 'r', 'e', 'a', 'k', 'e', 'r', '\n',
        'c', 'o', 'd', 'e', 'd', '\n',
        'c', 'o', 'd', 'e', 'i', 'n', 'e', '\n',
        'c', 'o', 'd', 'e', 'n', 'a', 'm', 'e', '\n',
        'c', 'o', 'd', 'e', 'n', 'a', 'm', 'e', 'd', '\n',
        'c', 'o', 'd', 'e', 'r', '\n',
        'c', 'o', 'd', 'e', 'r', 's', '\n',
        'c', 'o', 'd', 'e', 's', '\n',
        'c', 'o', 'd', 'e', 'w', 'o', 'r', 'd', '\n',
        'c', 'o', 'd', 'e', 'w', 'o', 'r', 'd', 's', '\n',
        'c', 'o', 'd', 'e', 'x', '\n',
        'c', 'o', 'd', 'f', 'i', 's', 'h', '\n',
        'c', 'o', 'd', 'i', 'c', 'e', 's', '\n',
        'c', 'o', 'd', 'i', 'c', 'i', 'l', '\n',
        'c', 'o', 'd', 'i', 'c', 'i', 'l', 's', '\n',
        'c', 'o', 'd', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'd', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'd', 'i', 'f', 'i', 'e', 'd', '\n',
        'c', 'o', 'd', 'i', 'f', 'i', 'e', 's', '\n',
        'c', 'o', 'd', 'i', 'f', 'y', '\n',
        'c', 'o', 'd', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'c', 'o', 'd', 'i', 'n', 'g', '\n',
        'c', 'o', 'd', 'l', 'i', 'n', 'g', '\n',
        'c', 'o', 'd', 'p', 'i', 'e', 'c', 'e', '\n',
        'c', 'o', 'd', 's', '\n',
        'c', 'o', 'e', 'f', 'f', 'i', 'c', 'i', 'e', 'n', 't', '\n',
        'c', 'o', 'e', 'f', 'f', 'i', 'c', 'i', 'e', 'n', 't', 's', '\n',
        'c', 'o', 'e', 'l', 'e', 'n', 't', 'e', 'r', 'a', 't', 'e', 's', '\n',
        'c', 'o', 'e', 'r', 'c', 'e', '\n',
        'c', 'o', 'e', 'r', 'c', 'e', 'd', '\n',
        'c', 'o', 'e', 'r', 'c', 'e', 'r', '\n',
        'c', 'o', 'e', 'r', 'c', 'e', 's', '\n',
        'c', 'o', 'e', 'r', 'c', 'i', 'b', 'l', 'e', '\n',
        'c', 'o', 'e', 'r', 'c', 'i', 'n', 'g', '\n',
        'c', 'o', 'e', 'r', 'c', 'i', 'o', 'n', '\n',
        'c', 'o', 'e', 'r', 'c', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'e', 'r', 'c', 'i', 'v', 'e', '\n',
        'c', 'o', 'e', 'r', 'c', 'i', 'v', 'e', 'l', 'y', '\n',
        'c', 'o', 'e', 'v', 'a', 'l', '\n',
        'c', 'o', 'e', 'x', 'i', 's', 't', '\n',
        'c', 'o', 'e', 'x', 'i', 's', 't', 'e', 'd', '\n',
        'c', 'o', 'e', 'x', 'i', 's', 't', 'e', 'n', 'c', 'e', '\n',
        'c', 'o', 'e', 'x', 'i', 's', 't', 'e', 'n', 't', '\n',
        'c', 'o', 'e', 'x', 'i', 's', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'e', 'x', 'i', 's', 't', 's', '\n',
        'c', 'o', 'e', 'x', 't', 'e', 'n', 's', 'i', 'v', 'e', '\n',
        'c', 'o', 'f', 'f', 'e', 'e', '\n',
        'c', 'o', 'f', 'f', 'e', 'e', 's', '\n',
        'c', 'o', 'f', 'f', 'e', 'r', '\n',
        'c', 'o', 'f', 'f', 'e', 'r', 'd', 'a', 'm', '\n',
        'c', 'o', 'f', 'f', 'e', 'r', 'd', 'a', 'm', 's', '\n',
        'c', 'o', 'f', 'f', 'e', 'r', 's', '\n',
        'c', 'o', 'f', 'f', 'i', 'n', '\n',
        'c', 'o', 'f', 'f', 'i', 'n', 's', '\n',
        'c', 'o', 'g', '\n',
        'c', 'o', 'g', 'e', 'n', 'c', 'y', '\n',
        'c', 'o', 'g', 'e', 'n', 't', '\n',
        'c', 'o', 'g', 'e', 'n', 't', 'l', 'y', '\n',
        'c', 'o', 'g', 'i', 't', 'a', 't', 'e', '\n',
        'c', 'o', 'g', 'i', 't', 'a', 't', 'e', 'd', '\n',
        'c', 'o', 'g', 'i', 't', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'g', 'i', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'g', 'i', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'g', 'i', 't', 'a', 't', 'i', 'v', 'e', '\n',
        'c', 'o', 'g', 'n', 'a', 'c', '\n',
        'c', 'o', 'g', 'n', 'a', 'c', 's', '\n',
        'c', 'o', 'g', 'n', 'a', 't', 'e', '\n',
        'c', 'o', 'g', 'n', 'a', 't', 'e', 's', '\n',
        'c', 'o', 'g', 'n', 'i', 's', 'a', 'n', 'c', 'e', '\n',
        'c', 'o', 'g', 'n', 'i', 's', 'a', 'n', 't', '\n',
        'c', 'o', 'g', 'n', 'i', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'g', 'n', 'i', 't', 'i', 'v', 'e', '\n',
        'c', 'o', 'g', 'n', 'i', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'c', 'o', 'g', 'n', 'i', 'z', 'a', 'n', 'c', 'e', '\n',
        'c', 'o', 'g', 'n', 'i', 'z', 'a', 'n', 't', '\n',
        'c', 'o', 'g', 'n', 'o', 's', 'c', 'e', 'n', 't', 'i', '\n',
        'c', 'o', 'g', 's', '\n',
        'c', 'o', 'h', 'a', 'b', 'i', 't', '\n',
        'c', 'o', 'h', 'a', 'b', 'i', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'h', 'a', 'b', 'i', 't', 'e', 'e', 's', '\n',
        'c', 'o', 'h', 'a', 'b', 'i', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'h', 'e', 'r', 'e', '\n',
        'c', 'o', 'h', 'e', 'r', 'e', 'd', '\n',
        'c', 'o', 'h', 'e', 'r', 'e', 'n', 'c', 'e', '\n',
        'c', 'o', 'h', 'e', 'r', 'e', 'n', 'c', 'y', '\n',
        'c', 'o', 'h', 'e', 'r', 'e', 'n', 't', '\n',
        'c', 'o', 'h', 'e', 'r', 'e', 'n', 't', 'l', 'y', '\n',
        'c', 'o', 'h', 'e', 'r', 'e', 's', '\n',
        'c', 'o', 'h', 'e', 's', 'i', 'o', 'n', '\n',
        'c', 'o', 'h', 'e', 's', 'i', 'v', 'e', '\n',
        'c', 'o', 'h', 'e', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'c', 'o', 'h', 'e', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'c', 'o', 'h', 'o', 'r', 't', '\n',
        'c', 'o', 'h', 'o', 'r', 't', 's', '\n',
        'c', 'o', 'i', 'f', 'f', 'u', 'r', 'e', '\n',
        'c', 'o', 'i', 'l', '\n',
        'c', 'o', 'i', 'l', 'e', 'd', '\n',
        'c', 'o', 'i', 'l', 'i', 'n', 'g', '\n',
        'c', 'o', 'i', 'l', 's', '\n',
        'c', 'o', 'i', 'n', '\n',
        'c', 'o', 'i', 'n', 'a', 'g', 'e', '\n',
        'c', 'o', 'i', 'n', 'a', 'g', 'e', 's', '\n',
        'c', 'o', 'i', 'n', 'c', 'i', 'd', 'e', '\n',
        'c', 'o', 'i', 'n', 'c', 'i', 'd', 'e', 'd', '\n',
        'c', 'o', 'i', 'n', 'c', 'i', 'd', 'e', 'n', 'c', 'e', '\n',
        'c', 'o', 'i', 'n', 'c', 'i', 'd', 'e', 'n', 'c', 'e', 's', '\n',
        'c', 'o', 'i', 'n', 'c', 'i', 'd', 'e', 'n', 't', '\n',
        'c', 'o', 'i', 'n', 'c', 'i', 'd', 'e', 'n', 't', 'a', 'l', '\n',
        'c', 'o', 'i', 'n', 'c', 'i', 'd', 'e', 'n', 't', 'a', 'l', 'l', 'y', '\n',
        'c', 'o', 'i', 'n', 'c', 'i', 'd', 'e', 's', '\n',
        'c', 'o', 'i', 'n', 'c', 'i', 'd', 'i', 'n', 'g', '\n',
        'c', 'o', 'i', 'n', 'e', 'd', '\n',
        'c', 'o', 'i', 'n', 'e', 'r', '\n',
        'c', 'o', 'i', 'n', 'e', 'r', 's', '\n',
        'c', 'o', 'i', 'n', 'i', 'n', 'g', '\n',
        'c', 'o', 'i', 'n', 's', '\n',
        'c', 'o', 'i', 't', 'a', 'l', '\n',
        'c', 'o', 'i', 't', 'u', 's', '\n',
        'c', 'o', 'k', 'e', '\n',
        'c', 'o', 'l', '\n',
        'c', 'o', 'l', 'a', '\n',
        'c', 'o', 'l', 'a', 'n', 'd', 'e', 'r', '\n',
        'c', 'o', 'l', 'a', 's', '\n',
        'c', 'o', 'l', 'd', '\n',
        'c', 'o', 'l', 'd', 'b', 'l', 'o', 'o', 'd', 'e', 'd', '\n',
        'c', 'o', 'l', 'd', 'b', 'l', 'o', 'o', 'd', 'e', 'd', 'l', 'y', '\n',
        'c', 'o', 'l', 'd', 'e', 'r', '\n',
        'c', 'o', 'l', 'd', 'e', 's', 't', '\n',
        'c', 'o', 'l', 'd', 'h', 'e', 'a', 'r', 't', 'e', 'd', '\n',
        'c', 'o', 'l', 'd', 'i', 's', 'h', '\n',
        'c', 'o', 'l', 'd', 'l', 'y', '\n',
        'c', 'o', 'l', 'd', 'n', 'e', 's', 's', '\n',
        'c', 'o', 'l', 'd', 's', '\n',
        'c', 'o', 'l', 'd', 'w', 'a', 'r', '\n',
        'c', 'o', 'l', 'e', '\n',
        'c', 'o', 'l', 'e', 's', 'l', 'a', 'w', '\n',
        'c', 'o', 'l', 'i', 't', 'i', 's', '\n',
        'c', 'o', 'l', 'l', 'a', 'b', 'o', 'r', 'a', 't', 'e', '\n',
        'c', 'o', 'l', 'l', 'a', 'b', 'o', 'r', 'a', 't', 'e', 'd', '\n',
        'c', 'o', 'l', 'l', 'a', 'b', 'o', 'r', 'a', 't', 'e', 's', '\n',
        'c', 'o', 'l', 'l', 'a', 'b', 'o', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'l', 'l', 'a', 'b', 'o', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'l', 'l', 'a', 'b', 'o', 'r', 'a', 't', 'i', 'o', 'n', 'i', 's', 't', '\n',
        'c', 'o', 'l', 'l', 'a', 'b', 'o', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'l', 'l', 'a', 'b', 'o', 'r', 'a', 't', 'i', 'v', 'e', '\n',
        'c', 'o', 'l', 'l', 'a', 'b', 'o', 'r', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'c', 'o', 'l', 'l', 'a', 'b', 'o', 'r', 'a', 't', 'o', 'r', '\n',
        'c', 'o', 'l', 'l', 'a', 'b', 'o', 'r', 'a', 't', 'o', 'r', 's', '\n',
        'c', 'o', 'l', 'l', 'a', 'g', 'e', '\n',
        'c', 'o', 'l', 'l', 'a', 'g', 'e', 'n', '\n',
        'c', 'o', 'l', 'l', 'a', 'g', 'e', 's', '\n',
        'c', 'o', 'l', 'l', 'a', 'p', 's', 'e', '\n',
        'c', 'o', 'l', 'l', 'a', 'p', 's', 'e', 'd', '\n',
        'c', 'o', 'l', 'l', 'a', 'p', 's', 'e', 's', '\n',
        'c', 'o', 'l', 'l', 'a', 'p', 's', 'i', 'b', 'l', 'e', '\n',
        'c', 'o', 'l', 'l', 'a', 'p', 's', 'i', 'n', 'g', '\n',
        'c', 'o', 'l', 'l', 'a', 'r', '\n',
        'c', 'o', 'l', 'l', 'a', 'r', 'b', 'o', 'n', 'e', '\n',
        'c', 'o', 'l', 'l', 'a', 'r', 'e', 'd', '\n',
        'c', 'o', 'l', 'l', 'a', 'r', 'i', 'n', 'g', '\n',
        'c', 'o', 'l', 'l', 'a', 'r', 'l', 'e', 's', 's', '\n',
        'c', 'o', 'l', 'l', 'a', 'r', 's', '\n',
        'c', 'o', 'l', 'l', 'a', 't', 'e', '\n',
        'c', 'o', 'l', 'l', 'a', 't', 'e', 'd', '\n',
        'c', 'o', 'l', 'l', 'a', 't', 'e', 'r', 'a', 'l', '\n',
        'c', 'o', 'l', 'l', 'a', 't', 'e', 'r', 'a', 'l', 'l', 'y', '\n',
        'c', 'o', 'l', 'l', 'a', 't', 'e', 's', '\n',
        'c', 'o', 'l', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'l', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'l', 'l', 'e', 'a', 'g', 'u', 'e', '\n',
        'c', 'o', 'l', 'l', 'e', 'a', 'g', 'u', 'e', 's', '\n',
        'c', 'o', 'l', 'l', 'e', 'c', 't', '\n',
        'c', 'o', 'l', 'l', 'e', 'c', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'c', 'o', 'l', 'l', 'e', 'c', 't', 'a', 'b', 'l', 'e', '\n',
        'c', 'o', 'l', 'l', 'e', 'c', 't', 'a', 'b', 'l', 'e', 's', '\n',
        'c', 'o', 'l', 'l', 'e', 'c', 't', 'e', 'd', '\n',
        'c', 'o', 'l', 'l', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'l', 'l', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'l', 'l', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'l', 'l', 'e', 'c', 't', 'i', 'v', 'e', '\n',
        'c', 'o', 'l', 'l', 'e', 'c', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'c', 'o', 'l', 'l', 'e', 'c', 't', 'i', 'v', 'e', 's', '\n',
        'c', 'o', 'l', 'l', 'e', 'c', 't', 'i', 'v', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'l', 'l', 'e', 'c', 't', 'i', 'v', 'i', 's', 'm', '\n',
        'c', 'o', 'l', 'l', 'e', 'c', 't', 'i', 'v', 'i', 's', 't', '\n',
        'c', 'o', 'l', 'l', 'e', 'c', 't', 'i', 'v', 'i', 't', 'y', '\n',
        'c', 'o', 'l', 'l', 'e', 'c', 't', 'o', 'r', '\n',
        'c', 'o', 'l', 'l', 'e', 'c', 't', 'o', 'r', 's', '\n',
        'c', 'o', 'l', 'l', 'e', 'c', 't', 's', '\n',
        'c', 'o', 'l', 'l', 'e', 'g', 'e', '\n',
        'c', 'o', 'l', 'l', 'e', 'g', 'e', 's', '\n',
        'c', 'o', 'l', 'l', 'e', 'g', 'i', 'a', 'l', '\n',
        'c', 'o', 'l', 'l', 'e', 'g', 'i', 'a', 't', 'e', '\n',
        'c', 'o', 'l', 'l', 'i', 'd', 'e', '\n',
        'c', 'o', 'l', 'l', 'i', 'd', 'e', 'd', '\n',
        'c', 'o', 'l', 'l', 'i', 'd', 'e', 's', '\n',
        'c', 'o', 'l', 'l', 'i', 'd', 'i', 'n', 'g', '\n',
        'c', 'o', 'l', 'l', 'i', 'e', '\n',
        'c', 'o', 'l', 'l', 'i', 'e', 'r', '\n',
        'c', 'o', 'l', 'l', 'i', 'e', 'r', 'i', 'e', 's', '\n',
        'c', 'o', 'l', 'l', 'i', 'e', 'r', 's', '\n',
        'c', 'o', 'l', 'l', 'i', 'e', 'r', 'y', '\n',
        'c', 'o', 'l', 'l', 'i', 'e', 's', '\n',
        'c', 'o', 'l', 'l', 'i', 'm', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'l', 'l', 'i', 'm', 'a', 't', 'o', 'r', '\n',
        'c', 'o', 'l', 'l', 'i', 'n', 'e', 'a', 'r', '\n',
        'c', 'o', 'l', 'l', 'i', 'n', 's', '\n',
        'c', 'o', 'l', 'l', 'i', 's', 'i', 'o', 'n', '\n',
        'c', 'o', 'l', 'l', 'i', 's', 'i', 'o', 'n', 'a', 'l', '\n',
        'c', 'o', 'l', 'l', 'i', 's', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'l', 'l', 'o', 'c', 'a', 't', 'e', 'd', '\n',
        'c', 'o', 'l', 'l', 'o', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'l', 'l', 'o', 'c', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'c', 'o', 'l', 'l', 'o', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'l', 'l', 'o', 'i', 'd', '\n',
        'c', 'o', 'l', 'l', 'o', 'i', 'd', 'a', 'l', '\n',
        'c', 'o', 'l', 'l', 'o', 'i', 'd', 's', '\n',
        'c', 'o', 'l', 'l', 'o', 'q', 'u', 'i', 'a', '\n',
        'c', 'o', 'l', 'l', 'o', 'q', 'u', 'i', 'a', 'l', '\n',
        'c', 'o', 'l', 'l', 'o', 'q', 'u', 'i', 'a', 'l', 'i', 's', 'm', '\n',
        'c', 'o', 'l', 'l', 'o', 'q', 'u', 'i', 'a', 'l', 'i', 's', 'm', 's', '\n',
        'c', 'o', 'l', 'l', 'o', 'q', 'u', 'i', 'a', 'l', 'l', 'y', '\n',
        'c', 'o', 'l', 'l', 'o', 'q', 'u', 'i', 'u', 'm', '\n',
        'c', 'o', 'l', 'l', 'u', 'd', 'e', '\n',
        'c', 'o', 'l', 'l', 'u', 'd', 'e', 'd', '\n',
        'c', 'o', 'l', 'l', 'u', 'd', 'i', 'n', 'g', '\n',
        'c', 'o', 'l', 'l', 'u', 's', 'i', 'o', 'n', '\n',
        'c', 'o', 'l', 'o', 'b', 'u', 's', '\n',
        'c', 'o', 'l', 'o', 'g', 'n', 'e', '\n',
        'c', 'o', 'l', 'o', 'n', '\n',
        'c', 'o', 'l', 'o', 'n', 'e', 'l', '\n',
        'c', 'o', 'l', 'o', 'n', 'e', 'l', 's', '\n',
        'c', 'o', 'l', 'o', 'n', 'i', 'a', 'l', '\n',
        'c', 'o', 'l', 'o', 'n', 'i', 'a', 'l', 'i', 's', 'm', '\n',
        'c', 'o', 'l', 'o', 'n', 'i', 'a', 'l', 'i', 's', 't', '\n',
        'c', 'o', 'l', 'o', 'n', 'i', 'a', 'l', 'i', 's', 't', 's', '\n',
        'c', 'o', 'l', 'o', 'n', 'i', 'a', 'l', 's', '\n',
        'c', 'o', 'l', 'o', 'n', 'i', 'c', '\n',
        'c', 'o', 'l', 'o', 'n', 'i', 'e', 's', '\n',
        'c', 'o', 'l', 'o', 'n', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'l', 'o', 'n', 'i', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'l', 'o', 'n', 'i', 's', 'e', '\n',
        'c', 'o', 'l', 'o', 'n', 'i', 's', 'e', 'd', '\n',
        'c', 'o', 'l', 'o', 'n', 'i', 's', 'e', 'r', 's', '\n',
        'c', 'o', 'l', 'o', 'n', 'i', 's', 'i', 'n', 'g', '\n',
        'c', 'o', 'l', 'o', 'n', 'i', 's', 't', '\n',
        'c', 'o', 'l', 'o', 'n', 'i', 's', 't', 's', '\n',
        'c', 'o', 'l', 'o', 'n', 'n', 'a', 'd', 'e', '\n',
        'c', 'o', 'l', 'o', 'n', 'n', 'a', 'd', 'e', 'd', '\n',
        'c', 'o', 'l', 'o', 'n', 'n', 'a', 'd', 'e', 's', '\n',
        'c', 'o', 'l', 'o', 'n', 's', '\n',
        'c', 'o', 'l', 'o', 'n', 'y', '\n',
        'c', 'o', 'l', 'o', 's', 's', 'a', 'l', '\n',
        'c', 'o', 'l', 'o', 's', 's', 'a', 'l', 'l', 'y', '\n',
        'c', 'o', 'l', 'o', 's', 's', 'u', 's', '\n',
        'c', 'o', 'l', 'o', 's', 't', 'o', 'm', 'i', 'e', 's', '\n',
        'c', 'o', 'l', 'o', 's', 't', 'o', 'm', 'y', '\n',
        'c', 'o', 'l', 'o', 'u', 'r', '\n',
        'c', 'o', 'l', 'o', 'u', 'r', 'a', 'n', 't', '\n',
        'c', 'o', 'l', 'o', 'u', 'r', 'a', 'n', 't', 's', '\n',
        'c', 'o', 'l', 'o', 'u', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'l', 'o', 'u', 'r', 'b', 'l', 'i', 'n', 'd', '\n',
        'c', 'o', 'l', 'o', 'u', 'r', 'e', '\n',
        'c', 'o', 'l', 'o', 'u', 'r', 'f', 'u', 'l', '\n',
        'c', 'o', 'l', 'o', 'u', 'r', 'f', 'u', 'l', 'l', 'y', '\n',
        'c', 'o', 'l', 'o', 'u', 'r', 'i', 'n', 'g', '\n',
        'c', 'o', 'l', 'o', 'u', 'r', 'i', 'n', 'g', 's', '\n',
        'c', 'o', 'l', 'o', 'u', 'r', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'l', 'o', 'u', 'r', 'i', 's', 'e', '\n',
        'c', 'o', 'l', 'o', 'u', 'r', 'i', 's', 'e', 'd', '\n',
        'c', 'o', 'l', 'o', 'u', 'r', 'i', 's', 'i', 'n', 'g', '\n',
        'c', 'o', 'l', 'o', 'u', 'r', 'l', 'e', 's', 's', '\n',
        'c', 'o', 'l', 'o', 'u', 'r', 's', '\n',
        'c', 'o', 'l', 'o', 'u', 'r', 'y', '\n',
        'c', 'o', 'l', 's', '\n',
        'c', 'o', 'l', 't', '\n',
        'c', 'o', 'l', 't', 's', '\n',
        'c', 'o', 'l', 'u', 'm', 'b', 'u', 's', '\n',
        'c', 'o', 'l', 'u', 'm', 'n', '\n',
        'c', 'o', 'l', 'u', 'm', 'n', 'a', 'r', '\n',
        'c', 'o', 'l', 'u', 'm', 'n', 'e', 'd', '\n',
        'c', 'o', 'l', 'u', 'm', 'n', 'i', 's', 't', '\n',
        'c', 'o', 'l', 'u', 'm', 'n', 'i', 's', 't', 's', '\n',
        'c', 'o', 'l', 'u', 'm', 'n', 's', '\n',
        'c', 'o', 'm', 'a', '\n',
        'c', 'o', 'm', 'a', 's', '\n',
        'c', 'o', 'm', 'a', 't', 'o', 's', 'e', '\n',
        'c', 'o', 'm', 'b', '\n',
        'c', 'o', 'm', 'b', 'a', 't', '\n',
        'c', 'o', 'm', 'b', 'a', 't', 'a', 'n', 't', '\n',
        'c', 'o', 'm', 'b', 'a', 't', 'a', 'n', 't', 's', '\n',
        'c', 'o', 'm', 'b', 'a', 't', 'e', 'd', '\n',
        'c', 'o', 'm', 'b', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'b', 'a', 't', 'i', 'v', 'e', '\n',
        'c', 'o', 'm', 'b', 'a', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'c', 'o', 'm', 'b', 'a', 't', 's', '\n',
        'c', 'o', 'm', 'b', 'e', 'd', '\n',
        'c', 'o', 'm', 'b', 'e', 'r', '\n',
        'c', 'o', 'm', 'b', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'm', 'b', 'i', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'm', 'b', 'i', 'n', 'a', 't', 'o', 'r', 'i', 'a', 'l', '\n',
        'c', 'o', 'm', 'b', 'i', 'n', 'e', '\n',
        'c', 'o', 'm', 'b', 'i', 'n', 'e', 'd', '\n',
        'c', 'o', 'm', 'b', 'i', 'n', 'e', 's', '\n',
        'c', 'o', 'm', 'b', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'b', 'i', 'n', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'b', 's', '\n',
        'c', 'o', 'm', 'b', 'u', 's', 't', 'e', 'd', '\n',
        'c', 'o', 'm', 'b', 'u', 's', 't', 'i', 'b', 'l', 'e', '\n',
        'c', 'o', 'm', 'b', 'u', 's', 't', 'i', 'b', 'l', 'e', 's', '\n',
        'c', 'o', 'm', 'b', 'u', 's', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'm', 'b', 'u', 's', 't', 's', '\n',
        'c', 'o', 'm', 'e', '\n',
        'c', 'o', 'm', 'e', 'b', 'a', 'c', 'k', '\n',
        'c', 'o', 'm', 'e', 'd', 'i', 'a', 'n', '\n',
        'c', 'o', 'm', 'e', 'd', 'i', 'a', 'n', 's', '\n',
        'c', 'o', 'm', 'e', 'd', 'i', 'e', 's', '\n',
        'c', 'o', 'm', 'e', 'd', 'o', 'w', 'n', '\n',
        'c', 'o', 'm', 'e', 'd', 'y', '\n',
        'c', 'o', 'm', 'e', 'l', 'i', 'n', 'e', 's', 's', '\n',
        'c', 'o', 'm', 'e', 'l', 'y', '\n',
        'c', 'o', 'm', 'e', 'r', '\n',
        'c', 'o', 'm', 'e', 'r', 's', '\n',
        'c', 'o', 'm', 'e', 's', '\n',
        'c', 'o', 'm', 'e', 's', 't', 'i', 'b', 'l', 'e', '\n',
        'c', 'o', 'm', 'e', 's', 't', 'i', 'b', 'l', 'e', 's', '\n',
        'c', 'o', 'm', 'e', 't', '\n',
        'c', 'o', 'm', 'e', 't', 'a', 'r', 'y', '\n',
        'c', 'o', 'm', 'e', 't', 's', '\n',
        'c', 'o', 'm', 'f', 'o', 'r', 't', '\n',
        'c', 'o', 'm', 'f', 'o', 'r', 't', 'a', 'b', 'l', 'e', '\n',
        'c', 'o', 'm', 'f', 'o', 'r', 't', 'a', 'b', 'l', 'y', '\n',
        'c', 'o', 'm', 'f', 'o', 'r', 't', 'e', 'd', '\n',
        'c', 'o', 'm', 'f', 'o', 'r', 't', 'e', 'r', '\n',
        'c', 'o', 'm', 'f', 'o', 'r', 't', 'e', 'r', 's', '\n',
        'c', 'o', 'm', 'f', 'o', 'r', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'f', 'o', 'r', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'c', 'o', 'm', 'f', 'o', 'r', 't', 's', '\n',
        'c', 'o', 'm', 'f', 'y', '\n',
        'c', 'o', 'm', 'i', 'c', '\n',
        'c', 'o', 'm', 'i', 'c', 'a', 'l', '\n',
        'c', 'o', 'm', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'c', 'o', 'm', 'i', 'c', 's', '\n',
        'c', 'o', 'm', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'i', 'n', 'g', 's', '\n',
        'c', 'o', 'm', 'i', 't', 'y', '\n',
        'c', 'o', 'm', 'm', 'a', '\n',
        'c', 'o', 'm', 'm', 'a', 'n', 'd', '\n',
        'c', 'o', 'm', 'm', 'a', 'n', 'd', 'a', 'n', 't', '\n',
        'c', 'o', 'm', 'm', 'a', 'n', 'd', 'e', 'd', '\n',
        'c', 'o', 'm', 'm', 'a', 'n', 'd', 'e', 'e', 'r', '\n',
        'c', 'o', 'm', 'm', 'a', 'n', 'd', 'e', 'e', 'r', 'e', 'd', '\n',
        'c', 'o', 'm', 'm', 'a', 'n', 'd', 'e', 'e', 'r', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'm', 'a', 'n', 'd', 'e', 'r', '\n',
        'c', 'o', 'm', 'm', 'a', 'n', 'd', 'e', 'r', 's', '\n',
        'c', 'o', 'm', 'm', 'a', 'n', 'd', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'm', 'a', 'n', 'd', 'i', 'n', 'g', 'l', 'y', '\n',
        'c', 'o', 'm', 'm', 'a', 'n', 'd', 'm', 'e', 'n', 't', '\n',
        'c', 'o', 'm', 'm', 'a', 'n', 'd', 'm', 'e', 'n', 't', 's', '\n',
        'c', 'o', 'm', 'm', 'a', 'n', 'd', 'o', '\n',
        'c', 'o', 'm', 'm', 'a', 'n', 'd', 's', '\n',
        'c', 'o', 'm', 'm', 'a', 's', '\n',
        'c', 'o', 'm', 'm', 'e', 'm', 'o', 'r', 'a', 't', 'e', '\n',
        'c', 'o', 'm', 'm', 'e', 'm', 'o', 'r', 'a', 't', 'e', 'd', '\n',
        'c', 'o', 'm', 'm', 'e', 'm', 'o', 'r', 'a', 't', 'e', 's', '\n',
        'c', 'o', 'm', 'm', 'e', 'm', 'o', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'm', 'e', 'm', 'o', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'm', 'm', 'e', 'm', 'o', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'm', 'm', 'e', 'm', 'o', 'r', 'a', 't', 'i', 'v', 'e', '\n',
        'c', 'o', 'm', 'm', 'e', 'n', 'c', 'e', '\n',
        'c', 'o', 'm', 'm', 'e', 'n', 'c', 'e', 'd', '\n',
        'c', 'o', 'm', 'm', 'e', 'n', 'c', 'e', 'm', 'e', 'n', 't', '\n',
        'c', 'o', 'm', 'm', 'e', 'n', 'c', 'e', 's', '\n',
        'c', 'o', 'm', 'm', 'e', 'n', 'c', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'm', 'e', 'n', 'd', '\n',
        'c', 'o', 'm', 'm', 'e', 'n', 'd', 'a', 'b', 'l', 'e', '\n',
        'c', 'o', 'm', 'm', 'e', 'n', 'd', 'a', 'b', 'l', 'y', '\n',
        'c', 'o', 'm', 'm', 'e', 'n', 'd', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'm', 'm', 'e', 'n', 'd', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'm', 'm', 'e', 'n', 'd', 'e', 'd', '\n',
        'c', 'o', 'm', 'm', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'm', 'e', 'n', 'd', 's', '\n',
        'c', 'o', 'm', 'm', 'e', 'n', 's', 'u', 'r', 'a', 't', 'e', '\n',
        'c', 'o', 'm', 'm', 'e', 'n', 's', 'u', 'r', 'a', 't', 'e', 'l', 'y', '\n',
        'c', 'o', 'm', 'm', 'e', 'n', 't', '\n',
        'c', 'o', 'm', 'm', 'e', 'n', 't', 'a', 'r', 'i', 'e', 's', '\n',
        'c', 'o', 'm', 'm', 'e', 'n', 't', 'a', 'r', 'y', '\n',
        'c', 'o', 'm', 'm', 'e', 'n', 't', 'a', 't', 'e', '\n',
        'c', 'o', 'm', 'm', 'e', 'n', 't', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'm', 'e', 'n', 't', 'a', 't', 'o', 'r', '\n',
        'c', 'o', 'm', 'm', 'e', 'n', 't', 'a', 't', 'o', 'r', 's', '\n',
        'c', 'o', 'm', 'm', 'e', 'n', 't', 'e', 'd', '\n',
        'c', 'o', 'm', 'm', 'e', 'n', 't', 'e', 'r', '\n',
        'c', 'o', 'm', 'm', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'm', 'e', 'n', 't', 's', '\n',
        'c', 'o', 'm', 'm', 'e', 'r', 'c', 'e', '\n',
        'c', 'o', 'm', 'm', 'e', 'r', 'c', 'i', 'a', 'l', '\n',
        'c', 'o', 'm', 'm', 'e', 'r', 'c', 'i', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'm', 'm', 'e', 'r', 'c', 'i', 'a', 'l', 'i', 's', 'e', '\n',
        'c', 'o', 'm', 'm', 'e', 'r', 'c', 'i', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'c', 'o', 'm', 'm', 'e', 'r', 'c', 'i', 'a', 'l', 'i', 's', 'm', '\n',
        'c', 'o', 'm', 'm', 'e', 'r', 'c', 'i', 'a', 'l', 'l', 'y', '\n',
        'c', 'o', 'm', 'm', 'e', 'r', 'c', 'i', 'a', 'l', 's', '\n',
        'c', 'o', 'm', 'm', 'i', 's', 'e', 'r', 'a', 't', 'e', '\n',
        'c', 'o', 'm', 'm', 'i', 's', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'c', 'o', 'm', 'm', 'i', 's', 'e', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'm', 'i', 's', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'm', 'm', 'i', 's', 'e', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'm', 'm', 'i', 's', 's', 'a', 'r', '\n',
        'c', 'o', 'm', 'm', 'i', 's', 's', 'a', 'r', 'i', 'a', 't', '\n',
        'c', 'o', 'm', 'm', 'i', 's', 's', 'a', 'r', 's', '\n',
        'c', 'o', 'm', 'm', 'i', 's', 's', 'i', 'o', 'n', '\n',
        'c', 'o', 'm', 'm', 'i', 's', 's', 'i', 'o', 'n', 'a', 'i', 'r', 'e', '\n',
        'c', 'o', 'm', 'm', 'i', 's', 's', 'i', 'o', 'n', 'e', 'd', '\n',
        'c', 'o', 'm', 'm', 'i', 's', 's', 'i', 'o', 'n', 'e', 'r', '\n',
        'c', 'o', 'm', 'm', 'i', 's', 's', 'i', 'o', 'n', 'e', 'r', 's', '\n',
        'c', 'o', 'm', 'm', 'i', 's', 's', 'i', 'o', 'n', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'm', 'i', 's', 's', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'm', 'm', 'i', 't', '\n',
        'c', 'o', 'm', 'm', 'i', 't', 'm', 'e', 'n', 't', '\n',
        'c', 'o', 'm', 'm', 'i', 't', 'm', 'e', 'n', 't', 's', '\n',
        'c', 'o', 'm', 'm', 'i', 't', 's', '\n',
        'c', 'o', 'm', 'm', 'i', 't', 't', 'a', 'l', '\n',
        'c', 'o', 'm', 'm', 'i', 't', 't', 'e', 'd', '\n',
        'c', 'o', 'm', 'm', 'i', 't', 't', 'e', 'e', '\n',
        'c', 'o', 'm', 'm', 'i', 't', 't', 'e', 'e', 's', '\n',
        'c', 'o', 'm', 'm', 'i', 't', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'm', 'o', 'd', 'e', '\n',
        'c', 'o', 'm', 'm', 'o', 'd', 'e', 's', '\n',
        'c', 'o', 'm', 'm', 'o', 'd', 'i', 'o', 'u', 's', '\n',
        'c', 'o', 'm', 'm', 'o', 'd', 'i', 't', 'i', 'e', 's', '\n',
        'c', 'o', 'm', 'm', 'o', 'd', 'i', 't', 'y', '\n',
        'c', 'o', 'm', 'm', 'o', 'd', 'o', 'r', 'e', '\n',
        'c', 'o', 'm', 'm', 'o', 'd', 'o', 'r', 'e', 's', '\n',
        'c', 'o', 'm', 'm', 'o', 'n', '\n',
        'c', 'o', 'm', 'm', 'o', 'n', 'a', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'c', 'o', 'm', 'm', 'o', 'n', 'a', 'l', 'i', 't', 'y', '\n',
        'c', 'o', 'm', 'm', 'o', 'n', 'e', 'r', '\n',
        'c', 'o', 'm', 'm', 'o', 'n', 'e', 'r', 's', '\n',
        'c', 'o', 'm', 'm', 'o', 'n', 'e', 's', 't', '\n',
        'c', 'o', 'm', 'm', 'o', 'n', 'l', 'a', 'w', '\n',
        'c', 'o', 'm', 'm', 'o', 'n', 'l', 'y', '\n',
        'c', 'o', 'm', 'm', 'o', 'n', 'n', 'e', 's', 's', '\n',
        'c', 'o', 'm', 'm', 'o', 'n', 'p', 'l', 'a', 'c', 'e', '\n',
        'c', 'o', 'm', 'm', 'o', 'n', 'p', 'l', 'a', 'c', 'e', 's', '\n',
        'c', 'o', 'm', 'm', 'o', 'n', 's', '\n',
        'c', 'o', 'm', 'm', 'o', 'n', 's', 'e', 'n', 's', 'e', '\n',
        'c', 'o', 'm', 'm', 'o', 'n', 's', 'e', 'n', 's', 'i', 'c', 'a', 'l', '\n',
        'c', 'o', 'm', 'm', 'o', 'n', 'w', 'e', 'a', 'l', 't', 'h', '\n',
        'c', 'o', 'm', 'm', 'o', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'm', 'm', 'o', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'm', 'm', 'u', 'n', 'a', 'l', '\n',
        'c', 'o', 'm', 'm', 'u', 'n', 'a', 'l', 'i', 't', 'y', '\n',
        'c', 'o', 'm', 'm', 'u', 'n', 'a', 'l', 'l', 'y', '\n',
        'c', 'o', 'm', 'm', 'u', 'n', 'e', '\n',
        'c', 'o', 'm', 'm', 'u', 'n', 'e', 'd', '\n',
        'c', 'o', 'm', 'm', 'u', 'n', 'e', 's', '\n',
        'c', 'o', 'm', 'm', 'u', 'n', 'i', 'c', 'a', 'b', 'l', 'e', '\n',
        'c', 'o', 'm', 'm', 'u', 'n', 'i', 'c', 'a', 'n', 't', '\n',
        'c', 'o', 'm', 'm', 'u', 'n', 'i', 'c', 'a', 'n', 't', 's', '\n',
        'c', 'o', 'm', 'm', 'u', 'n', 'i', 'c', 'a', 't', 'e', '\n',
        'c', 'o', 'm', 'm', 'u', 'n', 'i', 'c', 'a', 't', 'e', 'd', '\n',
        'c', 'o', 'm', 'm', 'u', 'n', 'i', 'c', 'a', 't', 'e', 's', '\n',
        'c', 'o', 'm', 'm', 'u', 'n', 'i', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'm', 'u', 'n', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'm', 'm', 'u', 'n', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'm', 'm', 'u', 'n', 'i', 'c', 'a', 't', 'i', 'v', 'e', '\n',
        'c', 'o', 'm', 'm', 'u', 'n', 'i', 'c', 'a', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'c', 'o', 'm', 'm', 'u', 'n', 'i', 'c', 'a', 't', 'o', 'r', '\n',
        'c', 'o', 'm', 'm', 'u', 'n', 'i', 'c', 'a', 't', 'o', 'r', 's', '\n',
        'c', 'o', 'm', 'm', 'u', 'n', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'm', 'u', 'n', 'i', 'o', 'n', '\n',
        'c', 'o', 'm', 'm', 'u', 'n', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'm', 'm', 'u', 'n', 'i', 'q', 'u', 'e', '\n',
        'c', 'o', 'm', 'm', 'u', 'n', 'i', 'q', 'u', 'e', 's', '\n',
        'c', 'o', 'm', 'm', 'u', 'n', 'i', 's', 'm', '\n',
        'c', 'o', 'm', 'm', 'u', 'n', 'i', 's', 't', '\n',
        'c', 'o', 'm', 'm', 'u', 'n', 'i', 's', 't', 's', '\n',
        'c', 'o', 'm', 'm', 'u', 'n', 'i', 't', 'a', 'r', 'i', 'a', 'n', '\n',
        'c', 'o', 'm', 'm', 'u', 'n', 'i', 't', 'i', 'e', 's', '\n',
        'c', 'o', 'm', 'm', 'u', 'n', 'i', 't', 'y', '\n',
        'c', 'o', 'm', 'm', 'u', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'm', 'm', 'u', 't', 'a', 't', 'i', 'v', 'e', '\n',
        'c', 'o', 'm', 'm', 'u', 't', 'a', 't', 'i', 'v', 'i', 't', 'y', '\n',
        'c', 'o', 'm', 'm', 'u', 't', 'a', 't', 'o', 'r', '\n',
        'c', 'o', 'm', 'm', 'u', 't', 'e', '\n',
        'c', 'o', 'm', 'm', 'u', 't', 'e', 'd', '\n',
        'c', 'o', 'm', 'm', 'u', 't', 'e', 'r', '\n',
        'c', 'o', 'm', 'm', 'u', 't', 'e', 'r', 's', '\n',
        'c', 'o', 'm', 'm', 'u', 't', 'e', 's', '\n',
        'c', 'o', 'm', 'm', 'u', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'p', 'a', 'c', 't', '\n',
        'c', 'o', 'm', 'p', 'a', 'c', 't', 'e', 'd', '\n',
        'c', 'o', 'm', 'p', 'a', 'c', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'p', 'a', 'c', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'm', 'p', 'a', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'm', 'p', 'a', 'c', 't', 'l', 'y', '\n',
        'c', 'o', 'm', 'p', 'a', 'c', 't', 'n', 'e', 's', 's', '\n',
        'c', 'o', 'm', 'p', 'a', 'c', 't', 's', '\n',
        'c', 'o', 'm', 'p', 'a', 'n', 'i', 'e', 's', '\n',
        'c', 'o', 'm', 'p', 'a', 'n', 'i', 'o', 'n', '\n',
        'c', 'o', 'm', 'p', 'a', 'n', 'i', 'o', 'n', 'a', 'b', 'l', 'e', '\n',
        'c', 'o', 'm', 'p', 'a', 'n', 'i', 'o', 'n', 'a', 'b', 'l', 'y', '\n',
        'c', 'o', 'm', 'p', 'a', 'n', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'm', 'p', 'a', 'n', 'i', 'o', 'n', 's', 'h', 'i', 'p', '\n',
        'c', 'o', 'm', 'p', 'a', 'n', 'y', '\n',
        'c', 'o', 'm', 'p', 'a', 'r', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'c', 'o', 'm', 'p', 'a', 'r', 'a', 'b', 'l', 'e', '\n',
        'c', 'o', 'm', 'p', 'a', 'r', 'a', 'b', 'l', 'y', '\n',
        'c', 'o', 'm', 'p', 'a', 'r', 'a', 't', 'i', 'v', 'e', '\n',
        'c', 'o', 'm', 'p', 'a', 'r', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'c', 'o', 'm', 'p', 'a', 'r', 'a', 't', 'i', 'v', 'e', 's', '\n',
        'c', 'o', 'm', 'p', 'a', 'r', 'a', 't', 'o', 'r', '\n',
        'c', 'o', 'm', 'p', 'a', 'r', 'a', 't', 'o', 'r', 's', '\n',
        'c', 'o', 'm', 'p', 'a', 'r', 'e', '\n',
        'c', 'o', 'm', 'p', 'a', 'r', 'e', 'd', '\n',
        'c', 'o', 'm', 'p', 'a', 'r', 'e', 's', '\n',
        'c', 'o', 'm', 'p', 'a', 'r', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'p', 'a', 'r', 'i', 's', 'o', 'n', '\n',
        'c', 'o', 'm', 'p', 'a', 'r', 'i', 's', 'o', 'n', 's', '\n',
        'c', 'o', 'm', 'p', 'a', 'r', 't', 'm', 'e', 'n', 't', '\n',
        'c', 'o', 'm', 'p', 'a', 'r', 't', 'm', 'e', 'n', 't', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'm', 'p', 'a', 'r', 't', 'm', 'e', 'n', 't', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'c', 'o', 'm', 'p', 'a', 'r', 't', 'm', 'e', 'n', 't', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'p', 'a', 'r', 't', 'm', 'e', 'n', 't', 's', '\n',
        'c', 'o', 'm', 'p', 'a', 's', 's', '\n',
        'c', 'o', 'm', 'p', 'a', 's', 's', 'e', 'd', '\n',
        'c', 'o', 'm', 'p', 'a', 's', 's', 'e', 's', '\n',
        'c', 'o', 'm', 'p', 'a', 's', 's', 'i', 'o', 'n', '\n',
        'c', 'o', 'm', 'p', 'a', 's', 's', 'i', 'o', 'n', 'a', 't', 'e', '\n',
        'c', 'o', 'm', 'p', 'a', 's', 's', 'i', 'o', 'n', 'a', 't', 'e', 'l', 'y', '\n',
        'c', 'o', 'm', 'p', 'a', 't', 'i', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'c', 'o', 'm', 'p', 'a', 't', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'c', 'o', 'm', 'p', 'a', 't', 'i', 'b', 'l', 'e', '\n',
        'c', 'o', 'm', 'p', 'a', 't', 'i', 'b', 'l', 'e', 's', '\n',
        'c', 'o', 'm', 'p', 'a', 't', 'i', 'b', 'l', 'y', '\n',
        'c', 'o', 'm', 'p', 'a', 't', 'r', 'i', 'o', 't', '\n',
        'c', 'o', 'm', 'p', 'a', 't', 'r', 'i', 'o', 't', 's', '\n',
        'c', 'o', 'm', 'p', 'e', 'l', '\n',
        'c', 'o', 'm', 'p', 'e', 'l', 'l', 'e', 'd', '\n',
        'c', 'o', 'm', 'p', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'p', 'e', 'l', 'l', 'i', 'n', 'g', 'l', 'y', '\n',
        'c', 'o', 'm', 'p', 'e', 'l', 's', '\n',
        'c', 'o', 'm', 'p', 'e', 'n', 'd', 'i', 'a', '\n',
        'c', 'o', 'm', 'p', 'e', 'n', 'd', 'i', 'u', 'm', '\n',
        'c', 'o', 'm', 'p', 'e', 'n', 'd', 'i', 'u', 'm', 's', '\n',
        'c', 'o', 'm', 'p', 'e', 'n', 's', 'a', 't', 'e', '\n',
        'c', 'o', 'm', 'p', 'e', 'n', 's', 'a', 't', 'e', 'd', '\n',
        'c', 'o', 'm', 'p', 'e', 'n', 's', 'a', 't', 'e', 's', '\n',
        'c', 'o', 'm', 'p', 'e', 'n', 's', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'p', 'e', 'n', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'm', 'p', 'e', 'n', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'm', 'p', 'e', 'n', 's', 'a', 't', 'o', 'r', '\n',
        'c', 'o', 'm', 'p', 'e', 'n', 's', 'a', 't', 'o', 'r', 'y', '\n',
        'c', 'o', 'm', 'p', 'e', 'r', 'e', '\n',
        'c', 'o', 'm', 'p', 'e', 't', 'e', '\n',
        'c', 'o', 'm', 'p', 'e', 't', 'e', 'd', '\n',
        'c', 'o', 'm', 'p', 'e', 't', 'e', 'n', 'c', 'e', '\n',
        'c', 'o', 'm', 'p', 'e', 't', 'e', 'n', 'c', 'e', 's', '\n',
        'c', 'o', 'm', 'p', 'e', 't', 'e', 'n', 'c', 'i', 'e', 's', '\n',
        'c', 'o', 'm', 'p', 'e', 't', 'e', 'n', 'c', 'y', '\n',
        'c', 'o', 'm', 'p', 'e', 't', 'e', 'n', 't', '\n',
        'c', 'o', 'm', 'p', 'e', 't', 'e', 'n', 't', 'l', 'y', '\n',
        'c', 'o', 'm', 'p', 'e', 't', 'e', 's', '\n',
        'c', 'o', 'm', 'p', 'e', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'p', 'e', 't', 'i', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'm', 'p', 'e', 't', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'm', 'p', 'e', 't', 'i', 't', 'i', 'v', 'e', '\n',
        'c', 'o', 'm', 'p', 'e', 't', 'i', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'c', 'o', 'm', 'p', 'e', 't', 'i', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'c', 'o', 'm', 'p', 'e', 't', 'i', 't', 'o', 'r', '\n',
        'c', 'o', 'm', 'p', 'e', 't', 'i', 't', 'o', 'r', 's', '\n',
        'c', 'o', 'm', 'p', 'i', 'l', 'a', 'b', 'l', 'e', '\n',
        'c', 'o', 'm', 'p', 'i', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'm', 'p', 'i', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'm', 'p', 'i', 'l', 'e', '\n',
        'c', 'o', 'm', 'p', 'i', 'l', 'e', 'd', '\n',
        'c', 'o', 'm', 'p', 'i', 'l', 'e', 'r', '\n',
        'c', 'o', 'm', 'p', 'i', 'l', 'e', 'r', 's', '\n',
        'c', 'o', 'm', 'p', 'i', 'l', 'e', 's', '\n',
        'c', 'o', 'm', 'p', 'i', 'l', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'p', 'l', 'a', 'c', 'e', 'n', 'c', 'y', '\n',
        'c', 'o', 'm', 'p', 'l', 'a', 'c', 'e', 'n', 't', '\n',
        'c', 'o', 'm', 'p', 'l', 'a', 'c', 'e', 'n', 't', 'l', 'y', '\n',
        'c', 'o', 'm', 'p', 'l', 'a', 'i', 'n', '\n',
        'c', 'o', 'm', 'p', 'l', 'a', 'i', 'n', 'a', 'n', 't', '\n',
        'c', 'o', 'm', 'p', 'l', 'a', 'i', 'n', 'a', 'n', 't', 's', '\n',
        'c', 'o', 'm', 'p', 'l', 'a', 'i', 'n', 'e', 'd', '\n',
        'c', 'o', 'm', 'p', 'l', 'a', 'i', 'n', 'e', 'r', '\n',
        'c', 'o', 'm', 'p', 'l', 'a', 'i', 'n', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'p', 'l', 'a', 'i', 'n', 'i', 'n', 'g', 'l', 'y', '\n',
        'c', 'o', 'm', 'p', 'l', 'a', 'i', 'n', 's', '\n',
        'c', 'o', 'm', 'p', 'l', 'a', 'i', 'n', 't', '\n',
        'c', 'o', 'm', 'p', 'l', 'a', 'i', 'n', 't', 's', '\n',
        'c', 'o', 'm', 'p', 'l', 'a', 'i', 's', 'a', 'n', 't', '\n',
        'c', 'o', 'm', 'p', 'l', 'e', 'm', 'e', 'n', 't', '\n',
        'c', 'o', 'm', 'p', 'l', 'e', 'm', 'e', 'n', 't', 'a', 'r', 'i', 't', 'y', '\n',
        'c', 'o', 'm', 'p', 'l', 'e', 'm', 'e', 'n', 't', 'a', 'r', 'y', '\n',
        'c', 'o', 'm', 'p', 'l', 'e', 'm', 'e', 'n', 't', 'e', 'd', '\n',
        'c', 'o', 'm', 'p', 'l', 'e', 'm', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'p', 'l', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'c', 'o', 'm', 'p', 'l', 'e', 't', 'a', 'b', 'l', 'e', '\n',
        'c', 'o', 'm', 'p', 'l', 'e', 't', 'e', '\n',
        'c', 'o', 'm', 'p', 'l', 'e', 't', 'e', 'd', '\n',
        'c', 'o', 'm', 'p', 'l', 'e', 't', 'e', 'l', 'y', '\n',
        'c', 'o', 'm', 'p', 'l', 'e', 't', 'e', 'n', 'e', 's', 's', '\n',
        'c', 'o', 'm', 'p', 'l', 'e', 't', 'e', 's', '\n',
        'c', 'o', 'm', 'p', 'l', 'e', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'p', 'l', 'e', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'm', 'p', 'l', 'e', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'm', 'p', 'l', 'e', 'x', '\n',
        'c', 'o', 'm', 'p', 'l', 'e', 'x', 'e', 's', '\n',
        'c', 'o', 'm', 'p', 'l', 'e', 'x', 'i', 'o', 'n', '\n',
        'c', 'o', 'm', 'p', 'l', 'e', 'x', 'i', 'o', 'n', 'e', 'd', '\n',
        'c', 'o', 'm', 'p', 'l', 'e', 'x', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'm', 'p', 'l', 'e', 'x', 'i', 't', 'i', 'e', 's', '\n',
        'c', 'o', 'm', 'p', 'l', 'e', 'x', 'i', 't', 'y', '\n',
        'c', 'o', 'm', 'p', 'l', 'e', 'x', 'l', 'y', '\n',
        'c', 'o', 'm', 'p', 'l', 'i', 'a', 'n', 'c', 'e', '\n',
        'c', 'o', 'm', 'p', 'l', 'i', 'a', 'n', 't', '\n',
        'c', 'o', 'm', 'p', 'l', 'i', 'c', 'a', 't', 'e', '\n',
        'c', 'o', 'm', 'p', 'l', 'i', 'c', 'a', 't', 'e', 'd', '\n',
        'c', 'o', 'm', 'p', 'l', 'i', 'c', 'a', 't', 'e', 's', '\n',
        'c', 'o', 'm', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'm', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'm', 'p', 'l', 'i', 'c', 'i', 't', '\n',
        'c', 'o', 'm', 'p', 'l', 'i', 'c', 'i', 't', 'y', '\n',
        'c', 'o', 'm', 'p', 'l', 'i', 'e', 'd', '\n',
        'c', 'o', 'm', 'p', 'l', 'i', 'e', 's', '\n',
        'c', 'o', 'm', 'p', 'l', 'i', 'm', 'e', 'n', 't', '\n',
        'c', 'o', 'm', 'p', 'l', 'i', 'm', 'e', 'n', 't', 'a', 'r', 'y', '\n',
        'c', 'o', 'm', 'p', 'l', 'i', 'm', 'e', 'n', 't', 'e', 'd', '\n',
        'c', 'o', 'm', 'p', 'l', 'i', 'm', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'p', 'l', 'i', 'm', 'e', 'n', 't', 's', '\n',
        'c', 'o', 'm', 'p', 'l', 'o', 't', '\n',
        'c', 'o', 'm', 'p', 'l', 'y', '\n',
        'c', 'o', 'm', 'p', 'l', 'y', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', '\n',
        'c', 'o', 'm', 'p', 'o', 'n', 'e', 'n', 't', 's', '\n',
        'c', 'o', 'm', 'p', 'o', 'r', 't', '\n',
        'c', 'o', 'm', 'p', 'o', 's', 'e', '\n',
        'c', 'o', 'm', 'p', 'o', 's', 'e', 'd', '\n',
        'c', 'o', 'm', 'p', 'o', 's', 'e', 'd', 'l', 'y', '\n',
        'c', 'o', 'm', 'p', 'o', 's', 'e', 'r', '\n',
        'c', 'o', 'm', 'p', 'o', 's', 'e', 'r', 's', '\n',
        'c', 'o', 'm', 'p', 'o', 's', 'e', 's', '\n',
        'c', 'o', 'm', 'p', 'o', 's', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'p', 'o', 's', 'i', 't', 'e', '\n',
        'c', 'o', 'm', 'p', 'o', 's', 'i', 't', 'e', 's', '\n',
        'c', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'c', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'm', 'p', 'o', 's', 'i', 't', 'o', 'r', '\n',
        'c', 'o', 'm', 'p', 'o', 's', 'i', 't', 'o', 'r', 's', '\n',
        'c', 'o', 'm', 'p', 'o', 's', 't', '\n',
        'c', 'o', 'm', 'p', 'o', 's', 't', 's', '\n',
        'c', 'o', 'm', 'p', 'o', 's', 'u', 'r', 'e', '\n',
        'c', 'o', 'm', 'p', 'o', 'u', 'n', 'd', '\n',
        'c', 'o', 'm', 'p', 'o', 'u', 'n', 'd', 'e', 'd', '\n',
        'c', 'o', 'm', 'p', 'o', 'u', 'n', 'd', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'p', 'o', 'u', 'n', 'd', 's', '\n',
        'c', 'o', 'm', 'p', 'r', 'e', 'h', 'e', 'n', 'd', '\n',
        'c', 'o', 'm', 'p', 'r', 'e', 'h', 'e', 'n', 'd', 'e', 'd', '\n',
        'c', 'o', 'm', 'p', 'r', 'e', 'h', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'p', 'r', 'e', 'h', 'e', 'n', 'd', 's', '\n',
        'c', 'o', 'm', 'p', 'r', 'e', 'h', 'e', 'n', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'c', 'o', 'm', 'p', 'r', 'e', 'h', 'e', 'n', 's', 'i', 'b', 'l', 'e', '\n',
        'c', 'o', 'm', 'p', 'r', 'e', 'h', 'e', 'n', 's', 'i', 'b', 'l', 'y', '\n',
        'c', 'o', 'm', 'p', 'r', 'e', 'h', 'e', 'n', 's', 'i', 'o', 'n', '\n',
        'c', 'o', 'm', 'p', 'r', 'e', 'h', 'e', 'n', 's', 'i', 'v', 'e', '\n',
        'c', 'o', 'm', 'p', 'r', 'e', 'h', 'e', 'n', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'c', 'o', 'm', 'p', 'r', 'e', 'h', 'e', 'n', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'c', 'o', 'm', 'p', 'r', 'e', 'h', 'e', 'n', 's', 'i', 'v', 'e', 's', '\n',
        'c', 'o', 'm', 'p', 'r', 'e', 's', 's', '\n',
        'c', 'o', 'm', 'p', 'r', 'e', 's', 's', 'e', 'd', '\n',
        'c', 'o', 'm', 'p', 'r', 'e', 's', 's', 'e', 's', '\n',
        'c', 'o', 'm', 'p', 'r', 'e', 's', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'c', 'o', 'm', 'p', 'r', 'e', 's', 's', 'i', 'b', 'l', 'e', '\n',
        'c', 'o', 'm', 'p', 'r', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', '\n',
        'c', 'o', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 'a', 'l', '\n',
        'c', 'o', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'm', 'p', 'r', 'e', 's', 's', 'i', 'v', 'e', '\n',
        'c', 'o', 'm', 'p', 'r', 'e', 's', 's', 'o', 'r', '\n',
        'c', 'o', 'm', 'p', 'r', 'e', 's', 's', 'o', 'r', 's', '\n',
        'c', 'o', 'm', 'p', 'r', 'i', 's', 'e', '\n',
        'c', 'o', 'm', 'p', 'r', 'i', 's', 'e', 'd', '\n',
        'c', 'o', 'm', 'p', 'r', 'i', 's', 'e', 's', '\n',
        'c', 'o', 'm', 'p', 'r', 'i', 's', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'p', 'r', 'o', 'm', 'i', 's', 'e', '\n',
        'c', 'o', 'm', 'p', 'r', 'o', 'm', 'i', 's', 'e', 'd', '\n',
        'c', 'o', 'm', 'p', 'r', 'o', 'm', 'i', 's', 'e', 's', '\n',
        'c', 'o', 'm', 'p', 'r', 'o', 'm', 'i', 's', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'p', 't', 'r', 'o', 'l', 'l', 'e', 'r', '\n',
        'c', 'o', 'm', 'p', 'u', 'l', 's', 'i', 'o', 'n', '\n',
        'c', 'o', 'm', 'p', 'u', 'l', 's', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'm', 'p', 'u', 'l', 's', 'i', 'v', 'e', '\n',
        'c', 'o', 'm', 'p', 'u', 'l', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'c', 'o', 'm', 'p', 'u', 'l', 's', 'o', 'r', 'i', 'l', 'y', '\n',
        'c', 'o', 'm', 'p', 'u', 'l', 's', 'o', 'r', 'y', '\n',
        'c', 'o', 'm', 'p', 'u', 'n', 'c', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'm', 'p', 'u', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'c', 'o', 'm', 'p', 'u', 't', 'a', 'b', 'l', 'e', '\n',
        'c', 'o', 'm', 'p', 'u', 't', 'a', 'b', 'l', 'y', '\n',
        'c', 'o', 'm', 'p', 'u', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'm', 'p', 'u', 't', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'c', 'o', 'm', 'p', 'u', 't', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'c', 'o', 'm', 'p', 'u', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'm', 'p', 'u', 't', 'e', '\n',
        'c', 'o', 'm', 'p', 'u', 't', 'e', 'd', '\n',
        'c', 'o', 'm', 'p', 'u', 't', 'e', 'r', '\n',
        'c', 'o', 'm', 'p', 'u', 't', 'e', 'r', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'm', 'p', 'u', 't', 'e', 'r', 'i', 's', 'e', '\n',
        'c', 'o', 'm', 'p', 'u', 't', 'e', 'r', 'i', 's', 'e', 'd', '\n',
        'c', 'o', 'm', 'p', 'u', 't', 'e', 'r', 'i', 's', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'p', 'u', 't', 'e', 'r', 'l', 'i', 't', 'e', 'r', 'a', 't', 'e', '\n',
        'c', 'o', 'm', 'p', 'u', 't', 'e', 'r', 's', '\n',
        'c', 'o', 'm', 'p', 'u', 't', 'e', 's', '\n',
        'c', 'o', 'm', 'p', 'u', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'm', 'r', 'a', 'd', 'e', '\n',
        'c', 'o', 'm', 'r', 'a', 'd', 'e', 'i', 'n', 'a', 'r', 'm', 's', '\n',
        'c', 'o', 'm', 'r', 'a', 'd', 'e', 'l', 'y', '\n',
        'c', 'o', 'm', 'r', 'a', 'd', 'e', 's', '\n',
        'c', 'o', 'm', 'r', 'a', 'd', 'e', 's', 'h', 'i', 'p', '\n',
        'c', 'o', 'n', '\n',
        'c', 'o', 'n', 'a', 'k', 'r', 'y', '\n',
        'c', 'o', 'n', 'c', 'a', 't', 'e', 'n', 'a', 't', 'e', '\n',
        'c', 'o', 'n', 'c', 'a', 't', 'e', 'n', 'a', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 'c', 'a', 't', 'e', 'n', 'a', 't', 'e', 's', '\n',
        'c', 'o', 'n', 'c', 'a', 't', 'e', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'c', 'a', 't', 'e', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'c', 'a', 't', 'e', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 'c', 'a', 'v', 'e', '\n',
        'c', 'o', 'n', 'c', 'a', 'v', 'i', 't', 'y', '\n',
        'c', 'o', 'n', 'c', 'e', 'a', 'l', '\n',
        'c', 'o', 'n', 'c', 'e', 'a', 'l', 'e', 'd', '\n',
        'c', 'o', 'n', 'c', 'e', 'a', 'l', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'c', 'e', 'a', 'l', 'm', 'e', 'n', 't', '\n',
        'c', 'o', 'n', 'c', 'e', 'a', 'l', 's', '\n',
        'c', 'o', 'n', 'c', 'e', 'd', 'e', '\n',
        'c', 'o', 'n', 'c', 'e', 'd', 'e', 'd', '\n',
        'c', 'o', 'n', 'c', 'e', 'd', 'e', 's', '\n',
        'c', 'o', 'n', 'c', 'e', 'd', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'c', 'e', 'i', 't', '\n',
        'c', 'o', 'n', 'c', 'e', 'i', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 'c', 'e', 'i', 't', 's', '\n',
        'c', 'o', 'n', 'c', 'e', 'i', 'v', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'c', 'o', 'n', 'c', 'e', 'i', 'v', 'a', 'b', 'l', 'e', '\n',
        'c', 'o', 'n', 'c', 'e', 'i', 'v', 'a', 'b', 'l', 'y', '\n',
        'c', 'o', 'n', 'c', 'e', 'i', 'v', 'e', '\n',
        'c', 'o', 'n', 'c', 'e', 'i', 'v', 'e', 'd', '\n',
        'c', 'o', 'n', 'c', 'e', 'i', 'v', 'e', 's', '\n',
        'c', 'o', 'n', 'c', 'e', 'i', 'v', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'c', 'e', 'n', 't', 'r', 'a', 't', 'e', '\n',
        'c', 'o', 'n', 'c', 'e', 'n', 't', 'r', 'a', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 'c', 'e', 'n', 't', 'r', 'a', 't', 'e', 's', '\n',
        'c', 'o', 'n', 'c', 'e', 'n', 't', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'c', 'e', 'n', 't', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'c', 'e', 'n', 't', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 'c', 'e', 'n', 't', 'r', 'a', 't', 'o', 'r', '\n',
        'c', 'o', 'n', 'c', 'e', 'n', 't', 'r', 'a', 't', 'o', 'r', 's', '\n',
        'c', 'o', 'n', 'c', 'e', 'n', 't', 'r', 'i', 'c', '\n',
        'c', 'o', 'n', 'c', 'e', 'p', 't', '\n',
        'c', 'o', 'n', 'c', 'e', 'p', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'c', 'e', 'p', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 'c', 'e', 'p', 't', 's', '\n',
        'c', 'o', 'n', 'c', 'e', 'p', 't', 'u', 'a', 'l', '\n',
        'c', 'o', 'n', 'c', 'e', 'p', 't', 'u', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'c', 'e', 'p', 't', 'u', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 'c', 'e', 'p', 't', 'u', 'a', 'l', 'i', 's', 'e', '\n',
        'c', 'o', 'n', 'c', 'e', 'p', 't', 'u', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'c', 'o', 'n', 'c', 'e', 'p', 't', 'u', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'c', 'e', 'p', 't', 'u', 'a', 'l', 'l', 'y', '\n',
        'c', 'o', 'n', 'c', 'e', 'r', 'n', '\n',
        'c', 'o', 'n', 'c', 'e', 'r', 'n', 'e', 'd', '\n',
        'c', 'o', 'n', 'c', 'e', 'r', 'n', 'e', 'd', 'l', 'y', '\n',
        'c', 'o', 'n', 'c', 'e', 'r', 'n', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'c', 'e', 'r', 'n', 's', '\n',
        'c', 'o', 'n', 'c', 'e', 'r', 't', '\n',
        'c', 'o', 'n', 'c', 'e', 'r', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 'c', 'e', 'r', 't', 'g', 'o', 'e', 'r', 's', '\n',
        'c', 'o', 'n', 'c', 'e', 'r', 't', 'i', '\n',
        'c', 'o', 'n', 'c', 'e', 'r', 't', 'i', 'n', 'a', '\n',
        'c', 'o', 'n', 'c', 'e', 'r', 't', 'o', '\n',
        'c', 'o', 'n', 'c', 'e', 'r', 't', 's', '\n',
        'c', 'o', 'n', 'c', 'e', 's', 's', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'c', 'e', 's', 's', 'i', 'o', 'n', 'a', 'l', '\n',
        'c', 'o', 'n', 'c', 'e', 's', 's', 'i', 'o', 'n', 'a', 'r', 'y', '\n',
        'c', 'o', 'n', 'c', 'e', 's', 's', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 'c', 'i', 'e', 'r', 'g', 'e', '\n',
        'c', 'o', 'n', 'c', 'i', 'l', 'i', 'a', 'r', '\n',
        'c', 'o', 'n', 'c', 'i', 'l', 'i', 'a', 't', 'e', '\n',
        'c', 'o', 'n', 'c', 'i', 'l', 'i', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'c', 'i', 'l', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'c', 'i', 'l', 'i', 'a', 't', 'o', 'r', '\n',
        'c', 'o', 'n', 'c', 'i', 'l', 'i', 'a', 't', 'o', 'r', 'y', '\n',
        'c', 'o', 'n', 'c', 'i', 's', 'e', '\n',
        'c', 'o', 'n', 'c', 'i', 's', 'e', 'l', 'y', '\n',
        'c', 'o', 'n', 'c', 'i', 's', 'e', 'n', 'e', 's', 's', '\n',
        'c', 'o', 'n', 'c', 'l', 'a', 'v', 'e', '\n',
        'c', 'o', 'n', 'c', 'l', 'a', 'v', 'e', 's', '\n',
        'c', 'o', 'n', 'c', 'l', 'u', 'd', 'e', '\n',
        'c', 'o', 'n', 'c', 'l', 'u', 'd', 'e', 'd', '\n',
        'c', 'o', 'n', 'c', 'l', 'u', 'd', 'e', 's', '\n',
        'c', 'o', 'n', 'c', 'l', 'u', 'd', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'c', 'l', 'u', 's', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'c', 'l', 'u', 's', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 'c', 'l', 'u', 's', 'i', 'v', 'e', '\n',
        'c', 'o', 'n', 'c', 'l', 'u', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'c', 'o', 'n', 'c', 'o', 'c', 't', '\n',
        'c', 'o', 'n', 'c', 'o', 'c', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 'c', 'o', 'c', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'c', 'o', 'c', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'c', 'o', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 'c', 'o', 'c', 't', 's', '\n',
        'c', 'o', 'n', 'c', 'o', 'm', 'i', 't', 'a', 'n', 't', '\n',
        'c', 'o', 'n', 'c', 'o', 'm', 'i', 't', 'a', 'n', 't', 'l', 'y', '\n',
        'c', 'o', 'n', 'c', 'o', 'r', 'd', '\n',
        'c', 'o', 'n', 'c', 'o', 'r', 'd', 'a', 'n', 'c', 'e', '\n',
        'c', 'o', 'n', 'c', 'o', 'r', 'd', 'a', 'n', 'c', 'e', 's', '\n',
        'c', 'o', 'n', 'c', 'o', 'r', 'd', 'a', 'n', 't', '\n',
        'c', 'o', 'n', 'c', 'o', 'r', 'd', 'a', 't', '\n',
        'c', 'o', 'n', 'c', 'o', 'r', 'd', 's', '\n',
        'c', 'o', 'n', 'c', 'o', 'u', 'r', 's', 'e', '\n',
        'c', 'o', 'n', 'c', 'o', 'u', 'r', 's', 'e', 's', '\n',
        'c', 'o', 'n', 'c', 'r', 'e', 't', 'e', '\n',
        'c', 'o', 'n', 'c', 'r', 'e', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 'c', 'r', 'e', 't', 'e', 'l', 'y', '\n',
        'c', 'o', 'n', 'c', 'r', 'e', 't', 'e', 'n', 'e', 's', 's', '\n',
        'c', 'o', 'n', 'c', 'r', 'e', 't', 'e', 's', '\n',
        'c', 'o', 'n', 'c', 'r', 'e', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'c', 'r', 'e', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 'c', 'u', 'b', 'i', 'n', 'e', '\n',
        'c', 'o', 'n', 'c', 'u', 'b', 'i', 'n', 'e', 's', '\n',
        'c', 'o', 'n', 'c', 'u', 'r', '\n',
        'c', 'o', 'n', 'c', 'u', 'r', 'r', 'e', 'd', '\n',
        'c', 'o', 'n', 'c', 'u', 'r', 'r', 'e', 'n', 'c', 'e', '\n',
        'c', 'o', 'n', 'c', 'u', 'r', 'r', 'e', 'n', 'c', 'y', '\n',
        'c', 'o', 'n', 'c', 'u', 'r', 'r', 'e', 'n', 't', '\n',
        'c', 'o', 'n', 'c', 'u', 'r', 'r', 'e', 'n', 't', 'l', 'y', '\n',
        'c', 'o', 'n', 'c', 'u', 'r', 'r', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'c', 'u', 'r', 's', '\n',
        'c', 'o', 'n', 'c', 'u', 's', 's', '\n',
        'c', 'o', 'n', 'c', 'u', 's', 's', 'e', 'd', '\n',
        'c', 'o', 'n', 'c', 'u', 's', 's', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'd', 'e', 'm', 'n', '\n',
        'c', 'o', 'n', 'd', 'e', 'm', 'n', 'a', 'b', 'l', 'e', '\n',
        'c', 'o', 'n', 'd', 'e', 'm', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'd', 'e', 'm', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 'd', 'e', 'm', 'n', 'a', 't', 'o', 'r', 'y', '\n',
        'c', 'o', 'n', 'd', 'e', 'm', 'n', 'e', 'd', '\n',
        'c', 'o', 'n', 'd', 'e', 'm', 'n', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'd', 'e', 'm', 'n', 's', '\n',
        'c', 'o', 'n', 'd', 'e', 'n', 's', 'a', 't', 'e', '\n',
        'c', 'o', 'n', 'd', 'e', 'n', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'd', 'e', 'n', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 'd', 'e', 'n', 's', 'e', '\n',
        'c', 'o', 'n', 'd', 'e', 'n', 's', 'e', 'd', '\n',
        'c', 'o', 'n', 'd', 'e', 'n', 's', 'e', 'r', '\n',
        'c', 'o', 'n', 'd', 'e', 'n', 's', 'e', 'r', 's', '\n',
        'c', 'o', 'n', 'd', 'e', 'n', 's', 'e', 's', '\n',
        'c', 'o', 'n', 'd', 'e', 'n', 's', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'd', 'e', 's', 'c', 'e', 'n', 'd', '\n',
        'c', 'o', 'n', 'd', 'e', 's', 'c', 'e', 'n', 'd', 'e', 'd', '\n',
        'c', 'o', 'n', 'd', 'e', 's', 'c', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'd', 'e', 's', 'c', 'e', 'n', 'd', 'i', 'n', 'g', 'l', 'y', '\n',
        'c', 'o', 'n', 'd', 'e', 's', 'c', 'e', 'n', 'd', 's', '\n',
        'c', 'o', 'n', 'd', 'e', 's', 'c', 'e', 'n', 's', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'd', 'i', 'm', 'e', 'n', 't', '\n',
        'c', 'o', 'n', 'd', 'i', 'm', 'e', 'n', 't', 's', '\n',
        'c', 'o', 'n', 'd', 'i', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'd', 'i', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'c', 'o', 'n', 'd', 'i', 't', 'i', 'o', 'n', 'a', 'l', 'i', 't', 'y', '\n',
        'c', 'o', 'n', 'd', 'i', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'c', 'o', 'n', 'd', 'i', 't', 'i', 'o', 'n', 'a', 'l', 's', '\n',
        'c', 'o', 'n', 'd', 'i', 't', 'i', 'o', 'n', 'e', 'd', '\n',
        'c', 'o', 'n', 'd', 'i', 't', 'i', 'o', 'n', 'e', 'r', '\n',
        'c', 'o', 'n', 'd', 'i', 't', 'i', 'o', 'n', 'e', 'r', 's', '\n',
        'c', 'o', 'n', 'd', 'i', 't', 'i', 'o', 'n', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'd', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 'd', 'o', 'l', 'e', '\n',
        'c', 'o', 'n', 'd', 'o', 'l', 'e', 'd', '\n',
        'c', 'o', 'n', 'd', 'o', 'l', 'e', 'n', 'c', 'e', '\n',
        'c', 'o', 'n', 'd', 'o', 'l', 'e', 'n', 'c', 'e', 's', '\n',
        'c', 'o', 'n', 'd', 'o', 'l', 'e', 's', '\n',
        'c', 'o', 'n', 'd', 'o', 'n', 'a', 'b', 'l', 'e', '\n',
        'c', 'o', 'n', 'd', 'o', 'n', 'e', '\n',
        'c', 'o', 'n', 'd', 'o', 'n', 'e', 'd', '\n',
        'c', 'o', 'n', 'd', 'o', 'n', 'e', 's', '\n',
        'c', 'o', 'n', 'd', 'o', 'n', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'd', 'o', 'r', '\n',
        'c', 'o', 'n', 'd', 'o', 'r', 's', '\n',
        'c', 'o', 'n', 'd', 'u', 'c', 'i', 'v', 'e', '\n',
        'c', 'o', 'n', 'd', 'u', 'c', 't', '\n',
        'c', 'o', 'n', 'd', 'u', 'c', 't', 'a', 'n', 'c', 'e', '\n',
        'c', 'o', 'n', 'd', 'u', 'c', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 'd', 'u', 'c', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'd', 'u', 'c', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'd', 'u', 'c', 't', 'i', 'v', 'e', '\n',
        'c', 'o', 'n', 'd', 'u', 'c', 't', 'i', 'v', 'i', 't', 'i', 'e', 's', '\n',
        'c', 'o', 'n', 'd', 'u', 'c', 't', 'i', 'v', 'i', 't', 'y', '\n',
        'c', 'o', 'n', 'd', 'u', 'c', 't', 'o', 'r', '\n',
        'c', 'o', 'n', 'd', 'u', 'c', 't', 'o', 'r', 's', '\n',
        'c', 'o', 'n', 'd', 'u', 'c', 't', 'r', 'e', 's', 's', '\n',
        'c', 'o', 'n', 'd', 'u', 'c', 't', 's', '\n',
        'c', 'o', 'n', 'd', 'u', 'i', 't', '\n',
        'c', 'o', 'n', 'd', 'u', 'i', 't', 's', '\n',
        'c', 'o', 'n', 'e', '\n',
        'c', 'o', 'n', 'e', 'd', '\n',
        'c', 'o', 'n', 'e', 's', '\n',
        'c', 'o', 'n', 'f', 'a', 'b', 'u', 'l', 'a', 't', 'e', '\n',
        'c', 'o', 'n', 'f', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'f', 'e', 'c', 't', 'i', 'o', 'n', 'e', 'r', '\n',
        'c', 'o', 'n', 'f', 'e', 'c', 't', 'i', 'o', 'n', 'e', 'r', 's', '\n',
        'c', 'o', 'n', 'f', 'e', 'c', 't', 'i', 'o', 'n', 'e', 'r', 'y', '\n',
        'c', 'o', 'n', 'f', 'e', 'c', 't', 'i', 'o', 'n', 'i', 's', 't', '\n',
        'c', 'o', 'n', 'f', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 'f', 'e', 'd', 'e', 'r', 'a', 'c', 'y', '\n',
        'c', 'o', 'n', 'f', 'e', 'd', 'e', 'r', 'a', 't', 'e', '\n',
        'c', 'o', 'n', 'f', 'e', 'd', 'e', 'r', 'a', 't', 'e', 's', '\n',
        'c', 'o', 'n', 'f', 'e', 'd', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'f', 'e', 'd', 'e', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 'f', 'e', 'r', '\n',
        'c', 'o', 'n', 'f', 'e', 'r', 'e', 'n', 'c', 'e', '\n',
        'c', 'o', 'n', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 's', '\n',
        'c', 'o', 'n', 'f', 'e', 'r', 'e', 'n', 'c', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'f', 'e', 'r', 'm', 'e', 'n', 't', '\n',
        'c', 'o', 'n', 'f', 'e', 'r', 'r', 'e', 'd', '\n',
        'c', 'o', 'n', 'f', 'e', 'r', 'r', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'f', 'e', 'r', 's', '\n',
        'c', 'o', 'n', 'f', 'e', 's', 's', '\n',
        'c', 'o', 'n', 'f', 'e', 's', 's', 'e', 'd', '\n',
        'c', 'o', 'n', 'f', 'e', 's', 's', 'e', 's', '\n',
        'c', 'o', 'n', 'f', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'f', 'e', 's', 's', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'f', 'e', 's', 's', 'i', 'o', 'n', 'a', 'l', '\n',
        'c', 'o', 'n', 'f', 'e', 's', 's', 'i', 'o', 'n', 'a', 'l', 's', '\n',
        'c', 'o', 'n', 'f', 'e', 's', 's', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 'f', 'e', 's', 's', 'o', 'r', '\n',
        'c', 'o', 'n', 'f', 'e', 's', 's', 'o', 'r', 's', '\n',
        'c', 'o', 'n', 'f', 'e', 't', 't', 'i', '\n',
        'c', 'o', 'n', 'f', 'i', 'd', 'a', 'n', 't', '\n',
        'c', 'o', 'n', 'f', 'i', 'd', 'a', 'n', 't', 'e', '\n',
        'c', 'o', 'n', 'f', 'i', 'd', 'a', 'n', 't', 'e', 's', '\n',
        'c', 'o', 'n', 'f', 'i', 'd', 'a', 'n', 't', 's', '\n',
        'c', 'o', 'n', 'f', 'i', 'd', 'e', '\n',
        'c', 'o', 'n', 'f', 'i', 'd', 'e', 'd', '\n',
        'c', 'o', 'n', 'f', 'i', 'd', 'e', 'n', 'c', 'e', '\n',
        'c', 'o', 'n', 'f', 'i', 'd', 'e', 'n', 'c', 'e', 's', '\n',
        'c', 'o', 'n', 'f', 'i', 'd', 'e', 'n', 't', '\n',
        'c', 'o', 'n', 'f', 'i', 'd', 'e', 'n', 't', 'i', 'a', 'l', '\n',
        'c', 'o', 'n', 'f', 'i', 'd', 'e', 'n', 't', 'i', 'a', 'l', 'i', 't', 'y', '\n',
        'c', 'o', 'n', 'f', 'i', 'd', 'e', 'n', 't', 'i', 'a', 'l', 'l', 'y', '\n',
        'c', 'o', 'n', 'f', 'i', 'd', 'e', 'n', 't', 'l', 'y', '\n',
        'c', 'o', 'n', 'f', 'i', 'd', 'e', 's', '\n',
        'c', 'o', 'n', 'f', 'i', 'd', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'f', 'i', 'd', 'i', 'n', 'g', 'l', 'y', '\n',
        'c', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 'b', 'l', 'e', '\n',
        'c', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'e', '\n',
        'c', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'e', 'd', '\n',
        'c', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'e', 's', '\n',
        'c', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'f', 'i', 'n', 'e', '\n',
        'c', 'o', 'n', 'f', 'i', 'n', 'e', 'd', '\n',
        'c', 'o', 'n', 'f', 'i', 'n', 'e', 'm', 'e', 'n', 't', '\n',
        'c', 'o', 'n', 'f', 'i', 'n', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'c', 'o', 'n', 'f', 'i', 'n', 'e', 's', '\n',
        'c', 'o', 'n', 'f', 'i', 'n', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'f', 'i', 'r', 'm', '\n',
        'c', 'o', 'n', 'f', 'i', 'r', 'm', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'f', 'i', 'r', 'm', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 'f', 'i', 'r', 'm', 'a', 't', 'o', 'r', 'y', '\n',
        'c', 'o', 'n', 'f', 'i', 'r', 'm', 'e', 'd', '\n',
        'c', 'o', 'n', 'f', 'i', 'r', 'm', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'f', 'i', 'r', 'm', 's', '\n',
        'c', 'o', 'n', 'f', 'i', 's', 'c', 'a', 't', 'e', '\n',
        'c', 'o', 'n', 'f', 'i', 's', 'c', 'a', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 'f', 'i', 's', 'c', 'a', 't', 'e', 's', '\n',
        'c', 'o', 'n', 'f', 'i', 's', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'f', 'i', 's', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'f', 'i', 's', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 'f', 'i', 's', 'c', 'a', 't', 'o', 'r', 'y', '\n',
        'c', 'o', 'n', 'f', 'l', 'a', 'g', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'f', 'l', 'a', 'g', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 'f', 'l', 'a', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 'f', 'l', 'a', 't', 'e', 's', '\n',
        'c', 'o', 'n', 'f', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'f', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'f', 'l', 'i', 'c', 't', '\n',
        'c', 'o', 'n', 'f', 'l', 'i', 'c', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 'f', 'l', 'i', 'c', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'f', 'l', 'i', 'c', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'c', 'o', 'n', 'f', 'l', 'i', 'c', 't', 's', '\n',
        'c', 'o', 'n', 'f', 'l', 'i', 'c', 't', 'u', 'a', 'l', '\n',
        'c', 'o', 'n', 'f', 'l', 'u', 'e', 'n', 'c', 'e', '\n',
        'c', 'o', 'n', 'f', 'l', 'u', 'e', 'n', 't', '\n',
        'c', 'o', 'n', 'f', 'o', 'c', 'a', 'l', '\n',
        'c', 'o', 'n', 'f', 'o', 'r', 'm', '\n',
        'c', 'o', 'n', 'f', 'o', 'r', 'm', 'a', 'b', 'l', 'e', '\n',
        'c', 'o', 'n', 'f', 'o', 'r', 'm', 'a', 'l', '\n',
        'c', 'o', 'n', 'f', 'o', 'r', 'm', 'a', 'n', 'c', 'e', '\n',
        'c', 'o', 'n', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'c', 'o', 'n', 'f', 'o', 'r', 'm', 'e', 'd', '\n',
        'c', 'o', 'n', 'f', 'o', 'r', 'm', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'f', 'o', 'r', 'm', 'i', 's', 'm', '\n',
        'c', 'o', 'n', 'f', 'o', 'r', 'm', 'i', 's', 't', '\n',
        'c', 'o', 'n', 'f', 'o', 'r', 'm', 'i', 's', 't', 's', '\n',
        'c', 'o', 'n', 'f', 'o', 'r', 'm', 'i', 't', 'y', '\n',
        'c', 'o', 'n', 'f', 'o', 'r', 'm', 's', '\n',
        'c', 'o', 'n', 'f', 'o', 'u', 'n', 'd', '\n',
        'c', 'o', 'n', 'f', 'o', 'u', 'n', 'd', 'e', 'd', '\n',
        'c', 'o', 'n', 'f', 'o', 'u', 'n', 'd', 'e', 'd', 'l', 'y', '\n',
        'c', 'o', 'n', 'f', 'o', 'u', 'n', 'd', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'f', 'o', 'u', 'n', 'd', 's', '\n',
        'c', 'o', 'n', 'f', 'r', 'o', 'n', 't', '\n',
        'c', 'o', 'n', 'f', 'r', 'o', 'n', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'f', 'r', 'o', 'n', 't', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'c', 'o', 'n', 'f', 'r', 'o', 'n', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 'f', 'r', 'o', 'n', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 'f', 'r', 'o', 'n', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'f', 'r', 'o', 'n', 't', 's', '\n',
        'c', 'o', 'n', 'f', 'u', 's', 'a', 'b', 'l', 'e', '\n',
        'c', 'o', 'n', 'f', 'u', 's', 'e', '\n',
        'c', 'o', 'n', 'f', 'u', 's', 'e', 'd', '\n',
        'c', 'o', 'n', 'f', 'u', 's', 'e', 'd', 'l', 'y', '\n',
        'c', 'o', 'n', 'f', 'u', 's', 'e', 'r', '\n',
        'c', 'o', 'n', 'f', 'u', 's', 'e', 's', '\n',
        'c', 'o', 'n', 'f', 'u', 's', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'f', 'u', 's', 'i', 'n', 'g', 'l', 'y', '\n',
        'c', 'o', 'n', 'f', 'u', 's', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'f', 'u', 's', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 'g', 'a', '\n',
        'c', 'o', 'n', 'g', 'e', 'a', 'l', '\n',
        'c', 'o', 'n', 'g', 'e', 'a', 'l', 'e', 'd', '\n',
        'c', 'o', 'n', 'g', 'e', 'a', 'l', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'g', 'e', 'a', 'l', 's', '\n',
        'c', 'o', 'n', 'g', 'e', 'n', 'i', 'a', 'l', '\n',
        'c', 'o', 'n', 'g', 'e', 'n', 'i', 'a', 'l', 'i', 't', 'y', '\n',
        'c', 'o', 'n', 'g', 'e', 'n', 'i', 't', 'a', 'l', '\n',
        'c', 'o', 'n', 'g', 'e', 'n', 'i', 't', 'a', 'l', 'l', 'y', '\n',
        'c', 'o', 'n', 'g', 'e', 'r', '\n',
        'c', 'o', 'n', 'g', 'e', 's', 't', '\n',
        'c', 'o', 'n', 'g', 'e', 's', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 'g', 'e', 's', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'g', 'e', 's', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'g', 'e', 's', 't', 'i', 'v', 'e', '\n',
        'c', 'o', 'n', 'g', 'l', 'o', 'm', 'e', 'r', 'a', 't', 'e', '\n',
        'c', 'o', 'n', 'g', 'l', 'o', 'm', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 'g', 'l', 'o', 'm', 'e', 'r', 'a', 't', 'e', 's', '\n',
        'c', 'o', 'n', 'g', 'l', 'o', 'm', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'g', 'o', '\n',
        'c', 'o', 'n', 'g', 'r', 'a', 't', 'u', 'l', 'a', 't', 'e', '\n',
        'c', 'o', 'n', 'g', 'r', 'a', 't', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 'g', 'r', 'a', 't', 'u', 'l', 'a', 't', 'e', 's', '\n',
        'c', 'o', 'n', 'g', 'r', 'a', 't', 'u', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'g', 'r', 'a', 't', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'g', 'r', 'a', 't', 'u', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 'g', 'r', 'a', 't', 'u', 'l', 'a', 't', 'o', 'r', 'y', '\n',
        'c', 'o', 'n', 'g', 'r', 'e', 'g', 'a', 't', 'e', '\n',
        'c', 'o', 'n', 'g', 'r', 'e', 'g', 'a', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 'g', 'r', 'e', 'g', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'g', 'r', 'e', 'g', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'g', 'r', 'e', 'g', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'c', 'o', 'n', 'g', 'r', 'e', 'g', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 'g', 'r', 'e', 's', 's', '\n',
        'c', 'o', 'n', 'g', 'r', 'e', 's', 's', 'e', 's', '\n',
        'c', 'o', 'n', 'g', 'r', 'e', 's', 's', 'i', 'o', 'n', 'a', 'l', '\n',
        'c', 'o', 'n', 'g', 'r', 'e', 's', 's', 'm', 'a', 'n', '\n',
        'c', 'o', 'n', 'g', 'r', 'e', 's', 's', 'm', 'e', 'n', '\n',
        'c', 'o', 'n', 'g', 'r', 'u', 'e', 'n', 'c', 'e', '\n',
        'c', 'o', 'n', 'g', 'r', 'u', 'e', 'n', 'c', 'e', 's', '\n',
        'c', 'o', 'n', 'g', 'r', 'u', 'e', 'n', 'c', 'y', '\n',
        'c', 'o', 'n', 'g', 'r', 'u', 'e', 'n', 't', '\n',
        'c', 'o', 'n', 'g', 'r', 'u', 'e', 'n', 't', 'i', 'a', 'l', '\n',
        'c', 'o', 'n', 'g', 'r', 'u', 'i', 't', 'y', '\n',
        'c', 'o', 'n', 'i', 'c', '\n',
        'c', 'o', 'n', 'i', 'c', 'a', 'l', '\n',
        'c', 'o', 'n', 'i', 'c', 's', '\n',
        'c', 'o', 'n', 'i', 'f', 'e', 'r', '\n',
        'c', 'o', 'n', 'i', 'f', 'e', 'r', 'o', 'u', 's', '\n',
        'c', 'o', 'n', 'i', 'f', 'e', 'r', 's', '\n',
        'c', 'o', 'n', 'j', 'e', 'c', 't', 'u', 'r', 'a', 'l', '\n',
        'c', 'o', 'n', 'j', 'e', 'c', 't', 'u', 'r', 'e', '\n',
        'c', 'o', 'n', 'j', 'e', 'c', 't', 'u', 'r', 'e', 'd', '\n',
        'c', 'o', 'n', 'j', 'e', 'c', 't', 'u', 'r', 'e', 's', '\n',
        'c', 'o', 'n', 'j', 'e', 'c', 't', 'u', 'r', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'j', 'o', 'i', 'n', '\n',
        'c', 'o', 'n', 'j', 'o', 'i', 'n', 'e', 'd', '\n',
        'c', 'o', 'n', 'j', 'o', 'i', 'n', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'j', 'o', 'i', 'n', 't', '\n',
        'c', 'o', 'n', 'j', 'u', 'g', 'a', 'c', 'y', '\n',
        'c', 'o', 'n', 'j', 'u', 'g', 'a', 'l', '\n',
        'c', 'o', 'n', 'j', 'u', 'g', 'a', 't', 'e', '\n',
        'c', 'o', 'n', 'j', 'u', 'g', 'a', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 'j', 'u', 'g', 'a', 't', 'e', 's', '\n',
        'c', 'o', 'n', 'j', 'u', 'g', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'j', 'u', 'g', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'j', 'u', 'g', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 'j', 'u', 'n', 'c', 't', '\n',
        'c', 'o', 'n', 'j', 'u', 'n', 'c', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'j', 'u', 'n', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 'j', 'u', 'n', 'c', 't', 'i', 'v', 'e', '\n',
        'c', 'o', 'n', 'j', 'u', 'n', 'c', 't', 'i', 'v', 'i', 't', 'i', 's', '\n',
        'c', 'o', 'n', 'j', 'u', 'n', 'c', 't', 'u', 'r', 'e', 's', '\n',
        'c', 'o', 'n', 'j', 'u', 'r', 'e', '\n',
        'c', 'o', 'n', 'j', 'u', 'r', 'e', 'd', '\n',
        'c', 'o', 'n', 'j', 'u', 'r', 'e', 'r', '\n',
        'c', 'o', 'n', 'j', 'u', 'r', 'e', 'r', 's', '\n',
        'c', 'o', 'n', 'j', 'u', 'r', 'e', 's', '\n',
        'c', 'o', 'n', 'j', 'u', 'r', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'j', 'u', 'r', 'o', 'r', '\n',
        'c', 'o', 'n', 'j', 'u', 'r', 'o', 'r', 's', '\n',
        'c', 'o', 'n', 'j', 'u', 'r', 'y', '\n',
        'c', 'o', 'n', 'k', '\n',
        'c', 'o', 'n', 'k', 'e', 'r', '\n',
        'c', 'o', 'n', 'k', 'e', 'r', 's', '\n',
        'c', 'o', 'n', 'm', 'a', 'n', '\n',
        'c', 'o', 'n', 'm', 'e', 'n', '\n',
        'c', 'o', 'n', 'n', 'e', 'c', 't', '\n',
        'c', 'o', 'n', 'n', 'e', 'c', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 'n', 'e', 'c', 't', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'c', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', 'l', 'e', 's', 's', '\n',
        'c', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'v', 'e', '\n',
        'c', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'v', 'e', 's', '\n',
        'c', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'v', 'i', 't', 'y', '\n',
        'c', 'o', 'n', 'n', 'e', 'c', 't', 'o', 'r', '\n',
        'c', 'o', 'n', 'n', 'e', 'c', 't', 'o', 'r', 's', '\n',
        'c', 'o', 'n', 'n', 'e', 'c', 't', 's', '\n',
        'c', 'o', 'n', 'n', 'e', 'd', '\n',
        'c', 'o', 'n', 'n', 'e', 'x', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'n', 'e', 'x', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 'n', 'i', 'v', 'a', 'n', 'c', 'e', '\n',
        'c', 'o', 'n', 'n', 'i', 'v', 'e', '\n',
        'c', 'o', 'n', 'n', 'i', 'v', 'e', 'd', '\n',
        'c', 'o', 'n', 'n', 'i', 'v', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'n', 'o', 'i', 's', 's', 'e', 'u', 'r', '\n',
        'c', 'o', 'n', 'n', 'o', 'i', 's', 's', 'e', 'u', 'r', 's', '\n',
        'c', 'o', 'n', 'n', 'o', 'i', 's', 's', 'e', 'u', 'r', 's', 'h', 'i', 'p', '\n',
        'c', 'o', 'n', 'n', 'o', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'n', 'o', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 'n', 'o', 't', 'e', '\n',
        'c', 'o', 'n', 'n', 'o', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 'n', 'o', 't', 'e', 's', '\n',
        'c', 'o', 'n', 'n', 'o', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'q', 'u', 'e', 'r', '\n',
        'c', 'o', 'n', 'q', 'u', 'e', 'r', 'a', 'b', 'l', 'e', '\n',
        'c', 'o', 'n', 'q', 'u', 'e', 'r', 'e', 'd', '\n',
        'c', 'o', 'n', 'q', 'u', 'e', 'r', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'q', 'u', 'e', 'r', 'o', 'r', '\n',
        'c', 'o', 'n', 'q', 'u', 'e', 'r', 'o', 'r', 's', '\n',
        'c', 'o', 'n', 'q', 'u', 'e', 'r', 's', '\n',
        'c', 'o', 'n', 'q', 'u', 'e', 's', 't', '\n',
        'c', 'o', 'n', 'q', 'u', 'e', 's', 't', 's', '\n',
        'c', 'o', 'n', 'q', 'u', 'i', 's', 't', 'a', 'd', 'o', 'r', '\n',
        'c', 'o', 'n', 'q', 'u', 'i', 's', 't', 'a', 'd', 'o', 'r', 'e', 's', '\n',
        'c', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 's', 'a', 'n', 'g', 'u', 'i', 'n', 'e', 'o', 'u', 's', '\n',
        'c', 'o', 'n', 's', 'a', 'n', 'g', 'u', 'i', 'n', 'i', 't', 'y', '\n',
        'c', 'o', 'n', 's', 'c', 'i', 'e', 'n', 'c', 'e', '\n',
        'c', 'o', 'n', 's', 'c', 'i', 'e', 'n', 'c', 'e', 's', '\n',
        'c', 'o', 'n', 's', 'c', 'i', 'e', 'n', 'c', 'e', 's', 't', 'r', 'i', 'c', 'k', 'e', 'n', '\n',
        'c', 'o', 'n', 's', 'c', 'i', 'e', 'n', 't', 'i', 'o', 'u', 's', '\n',
        'c', 'o', 'n', 's', 'c', 'i', 'e', 'n', 't', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'c', 'o', 'n', 's', 'c', 'i', 'e', 'n', 't', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'c', 'o', 'n', 's', 'c', 'i', 'o', 'n', 'a', 'b', 'l', 'e', '\n',
        'c', 'o', 'n', 's', 'c', 'i', 'o', 'u', 's', '\n',
        'c', 'o', 'n', 's', 'c', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'c', 'o', 'n', 's', 'c', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'c', 'o', 'n', 's', 'c', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', 'e', 's', '\n',
        'c', 'o', 'n', 's', 'c', 'r', 'i', 'p', 't', '\n',
        'c', 'o', 'n', 's', 'c', 'r', 'i', 'p', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 's', 'c', 'r', 'i', 'p', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 's', 'c', 'r', 'i', 'p', 't', 's', '\n',
        'c', 'o', 'n', 's', 'e', 'c', 'r', 'a', 't', 'e', '\n',
        'c', 'o', 'n', 's', 'e', 'c', 'r', 'a', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 's', 'e', 'c', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 's', 'e', 'c', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 's', 'e', 'c', 'u', 't', 'i', 'v', 'e', '\n',
        'c', 'o', 'n', 's', 'e', 'c', 'u', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'c', 'o', 'n', 's', 'e', 'n', 's', 'u', 'a', 'l', '\n',
        'c', 'o', 'n', 's', 'e', 'n', 's', 'u', 'a', 'l', 'l', 'y', '\n',
        'c', 'o', 'n', 's', 'e', 'n', 's', 'u', 's', '\n',
        'c', 'o', 'n', 's', 'e', 'n', 't', '\n',
        'c', 'o', 'n', 's', 'e', 'n', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 's', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 's', 'e', 'n', 't', 's', '\n',
        'c', 'o', 'n', 's', 'e', 'q', 'u', 'e', 'n', 'c', 'e', '\n',
        'c', 'o', 'n', 's', 'e', 'q', 'u', 'e', 'n', 'c', 'e', 's', '\n',
        'c', 'o', 'n', 's', 'e', 'q', 'u', 'e', 'n', 't', '\n',
        'c', 'o', 'n', 's', 'e', 'q', 'u', 'e', 'n', 't', 'i', 'a', 'l', '\n',
        'c', 'o', 'n', 's', 'e', 'q', 'u', 'e', 'n', 't', 'i', 'a', 'l', 'l', 'y', '\n',
        'c', 'o', 'n', 's', 'e', 'q', 'u', 'e', 'n', 't', 'l', 'y', '\n',
        'c', 'o', 'n', 's', 'e', 'r', 'v', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 's', 'e', 'r', 'v', 'a', 't', 'i', 'o', 'n', 'i', 's', 't', '\n',
        'c', 'o', 'n', 's', 'e', 'r', 'v', 'a', 't', 'i', 'o', 'n', 'i', 's', 't', 's', '\n',
        'c', 'o', 'n', 's', 'e', 'r', 'v', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 's', 'e', 'r', 'v', 'a', 't', 'i', 's', 'm', '\n',
        'c', 'o', 'n', 's', 'e', 'r', 'v', 'a', 't', 'i', 'v', 'e', '\n',
        'c', 'o', 'n', 's', 'e', 'r', 'v', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'c', 'o', 'n', 's', 'e', 'r', 'v', 'a', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'c', 'o', 'n', 's', 'e', 'r', 'v', 'a', 't', 'i', 'v', 'e', 's', '\n',
        'c', 'o', 'n', 's', 'e', 'r', 'v', 'a', 't', 'o', 'i', 'r', 'e', '\n',
        'c', 'o', 'n', 's', 'e', 'r', 'v', 'a', 't', 'o', 'r', '\n',
        'c', 'o', 'n', 's', 'e', 'r', 'v', 'a', 't', 'o', 'r', 'i', 'e', 's', '\n',
        'c', 'o', 'n', 's', 'e', 'r', 'v', 'a', 't', 'o', 'r', 's', '\n',
        'c', 'o', 'n', 's', 'e', 'r', 'v', 'a', 't', 'o', 'r', 'y', '\n',
        'c', 'o', 'n', 's', 'e', 'r', 'v', 'e', '\n',
        'c', 'o', 'n', 's', 'e', 'r', 'v', 'e', 'd', '\n',
        'c', 'o', 'n', 's', 'e', 'r', 'v', 'e', 's', '\n',
        'c', 'o', 'n', 's', 'e', 'r', 'v', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 's', 'i', 'd', 'e', 'r', '\n',
        'c', 'o', 'n', 's', 'i', 'd', 'e', 'r', 'a', 'b', 'l', 'e', '\n',
        'c', 'o', 'n', 's', 'i', 'd', 'e', 'r', 'a', 'b', 'l', 'y', '\n',
        'c', 'o', 'n', 's', 'i', 'd', 'e', 'r', 'a', 't', 'e', '\n',
        'c', 'o', 'n', 's', 'i', 'd', 'e', 'r', 'a', 't', 'e', 'l', 'y', '\n',
        'c', 'o', 'n', 's', 'i', 'd', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 's', 'i', 'd', 'e', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 's', 'i', 'd', 'e', 'r', 'e', 'd', '\n',
        'c', 'o', 'n', 's', 'i', 'd', 'e', 'r', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 's', 'i', 'd', 'e', 'r', 's', '\n',
        'c', 'o', 'n', 's', 'i', 'g', 'n', '\n',
        'c', 'o', 'n', 's', 'i', 'g', 'n', 'e', 'd', '\n',
        'c', 'o', 'n', 's', 'i', 'g', 'n', 'e', 'e', '\n',
        'c', 'o', 'n', 's', 'i', 'g', 'n', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 's', 'i', 'g', 'n', 'm', 'e', 'n', 't', '\n',
        'c', 'o', 'n', 's', 'i', 'g', 'n', 'm', 'e', 'n', 't', 's', '\n',
        'c', 'o', 'n', 's', 'i', 'g', 'n', 's', '\n',
        'c', 'o', 'n', 's', 'i', 's', 't', '\n',
        'c', 'o', 'n', 's', 'i', 's', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 's', 'i', 's', 't', 'e', 'n', 'c', 'i', 'e', 's', '\n',
        'c', 'o', 'n', 's', 'i', 's', 't', 'e', 'n', 'c', 'y', '\n',
        'c', 'o', 'n', 's', 'i', 's', 't', 'e', 'n', 't', '\n',
        'c', 'o', 'n', 's', 'i', 's', 't', 'e', 'n', 't', 'l', 'y', '\n',
        'c', 'o', 'n', 's', 'i', 's', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 's', 'i', 's', 't', 's', '\n',
        'c', 'o', 'n', 's', 'o', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 's', 'o', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 's', 'o', 'l', 'e', '\n',
        'c', 'o', 'n', 's', 'o', 'l', 'e', 'd', '\n',
        'c', 'o', 'n', 's', 'o', 'l', 'e', 's', '\n',
        'c', 'o', 'n', 's', 'o', 'l', 'i', 'd', 'a', 't', 'e', '\n',
        'c', 'o', 'n', 's', 'o', 'l', 'i', 'd', 'a', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 's', 'o', 'l', 'i', 'd', 'a', 't', 'e', 's', '\n',
        'c', 'o', 'n', 's', 'o', 'l', 'i', 'd', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 's', 'o', 'l', 'i', 'd', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 's', 'o', 'l', 'i', 'd', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 's', 'o', 'l', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 's', 'o', 'l', 'i', 'n', 'g', 'l', 'y', '\n',
        'c', 'o', 'n', 's', 'o', 'n', 'a', 'n', 'c', 'e', '\n',
        'c', 'o', 'n', 's', 'o', 'n', 'a', 'n', 't', '\n',
        'c', 'o', 'n', 's', 'o', 'n', 'a', 'n', 't', 'a', 'l', '\n',
        'c', 'o', 'n', 's', 'o', 'n', 'a', 'n', 't', 's', '\n',
        'c', 'o', 'n', 's', 'o', 'r', 't', '\n',
        'c', 'o', 'n', 's', 'o', 'r', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 's', 'o', 'r', 't', 'i', 'a', '\n',
        'c', 'o', 'n', 's', 'o', 'r', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 's', 'o', 'r', 't', 'i', 'u', 'm', '\n',
        'c', 'o', 'n', 's', 'o', 'r', 't', 's', '\n',
        'c', 'o', 'n', 's', 'p', 'e', 'c', 'i', 'f', 'i', 'c', '\n',
        'c', 'o', 'n', 's', 'p', 'i', 'c', 'u', 'o', 'u', 's', '\n',
        'c', 'o', 'n', 's', 'p', 'i', 'c', 'u', 'o', 'u', 's', 'l', 'y', '\n',
        'c', 'o', 'n', 's', 'p', 'i', 'c', 'u', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'c', 'o', 'n', 's', 'p', 'i', 'r', 'a', 'c', 'i', 'e', 's', '\n',
        'c', 'o', 'n', 's', 'p', 'i', 'r', 'a', 'c', 'y', '\n',
        'c', 'o', 'n', 's', 'p', 'i', 'r', 'a', 't', 'o', 'r', '\n',
        'c', 'o', 'n', 's', 'p', 'i', 'r', 'a', 't', 'o', 'r', 'i', 'a', 'l', '\n',
        'c', 'o', 'n', 's', 'p', 'i', 'r', 'a', 't', 'o', 'r', 'i', 'a', 'l', 'l', 'y', '\n',
        'c', 'o', 'n', 's', 'p', 'i', 'r', 'a', 't', 'o', 'r', 's', '\n',
        'c', 'o', 'n', 's', 'p', 'i', 'r', 'e', '\n',
        'c', 'o', 'n', 's', 'p', 'i', 'r', 'e', 'd', '\n',
        'c', 'o', 'n', 's', 'p', 'i', 'r', 'e', 's', '\n',
        'c', 'o', 'n', 's', 'p', 'i', 'r', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 's', 't', 'a', 'b', 'l', 'e', '\n',
        'c', 'o', 'n', 's', 't', 'a', 'b', 'l', 'e', 's', '\n',
        'c', 'o', 'n', 's', 't', 'a', 'b', 'u', 'l', 'a', 'r', 'i', 'e', 's', '\n',
        'c', 'o', 'n', 's', 't', 'a', 'b', 'u', 'l', 'a', 'r', 'y', '\n',
        'c', 'o', 'n', 's', 't', 'a', 'n', 'c', 'y', '\n',
        'c', 'o', 'n', 's', 't', 'a', 'n', 't', '\n',
        'c', 'o', 'n', 's', 't', 'a', 'n', 't', 'l', 'y', '\n',
        'c', 'o', 'n', 's', 't', 'a', 'n', 't', 's', '\n',
        'c', 'o', 'n', 's', 't', 'e', 'l', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 's', 't', 'e', 'l', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 's', 't', 'e', 'r', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 's', 't', 'e', 'r', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 's', 't', 'i', 'p', 'a', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 's', 't', 'i', 'p', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 's', 't', 'i', 't', 'u', 'e', 'n', 'c', 'i', 'e', 's', '\n',
        'c', 'o', 'n', 's', 't', 'i', 't', 'u', 'e', 'n', 'c', 'y', '\n',
        'c', 'o', 'n', 's', 't', 'i', 't', 'u', 'e', 'n', 't', '\n',
        'c', 'o', 'n', 's', 't', 'i', 't', 'u', 'e', 'n', 't', 's', '\n',
        'c', 'o', 'n', 's', 't', 'i', 't', 'u', 't', 'e', '\n',
        'c', 'o', 'n', 's', 't', 'i', 't', 'u', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 's', 't', 'i', 't', 'u', 't', 'e', 's', '\n',
        'c', 'o', 'n', 's', 't', 'i', 't', 'u', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 's', 't', 'i', 't', 'u', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 's', 't', 'i', 't', 'u', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'c', 'o', 'n', 's', 't', 'i', 't', 'u', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 'm', '\n',
        'c', 'o', 'n', 's', 't', 'i', 't', 'u', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 't', 's', '\n',
        'c', 'o', 'n', 's', 't', 'i', 't', 'u', 't', 'i', 'o', 'n', 'a', 'l', 'i', 't', 'y', '\n',
        'c', 'o', 'n', 's', 't', 'i', 't', 'u', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'c', 'o', 'n', 's', 't', 'i', 't', 'u', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 's', 't', 'i', 't', 'u', 't', 'i', 'v', 'e', '\n',
        'c', 'o', 'n', 's', 't', 'i', 't', 'u', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'c', 'o', 'n', 's', 't', 'r', 'a', 'i', 'n', '\n',
        'c', 'o', 'n', 's', 't', 'r', 'a', 'i', 'n', 'e', 'd', '\n',
        'c', 'o', 'n', 's', 't', 'r', 'a', 'i', 'n', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 's', 't', 'r', 'a', 'i', 'n', 's', '\n',
        'c', 'o', 'n', 's', 't', 'r', 'a', 'i', 'n', 't', '\n',
        'c', 'o', 'n', 's', 't', 'r', 'a', 'i', 'n', 't', 's', '\n',
        'c', 'o', 'n', 's', 't', 'r', 'i', 'c', 't', '\n',
        'c', 'o', 'n', 's', 't', 'r', 'i', 'c', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 's', 't', 'r', 'i', 'c', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 's', 't', 'r', 'i', 'c', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 's', 't', 'r', 'i', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 's', 't', 'r', 'i', 'c', 't', 'i', 'v', 'e', '\n',
        'c', 'o', 'n', 's', 't', 'r', 'i', 'c', 't', 'o', 'r', '\n',
        'c', 'o', 'n', 's', 't', 'r', 'i', 'c', 't', 'o', 'r', 's', '\n',
        'c', 'o', 'n', 's', 't', 'r', 'i', 'c', 't', 's', '\n',
        'c', 'o', 'n', 's', 't', 'r', 'u', 'c', 't', '\n',
        'c', 'o', 'n', 's', 't', 'r', 'u', 'c', 't', 'a', 'b', 'l', 'e', '\n',
        'c', 'o', 'n', 's', 't', 'r', 'u', 'c', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 's', 't', 'r', 'u', 'c', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 's', 't', 'r', 'u', 'c', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 's', 't', 'r', 'u', 'c', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'c', 'o', 'n', 's', 't', 'r', 'u', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 's', 't', 'r', 'u', 'c', 't', 'i', 'v', 'e', '\n',
        'c', 'o', 'n', 's', 't', 'r', 'u', 'c', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'c', 'o', 'n', 's', 't', 'r', 'u', 'c', 't', 'i', 'v', 'i', 's', 'm', '\n',
        'c', 'o', 'n', 's', 't', 'r', 'u', 'c', 't', 'i', 'v', 'i', 's', 't', '\n',
        'c', 'o', 'n', 's', 't', 'r', 'u', 'c', 't', 'o', 'r', '\n',
        'c', 'o', 'n', 's', 't', 'r', 'u', 'c', 't', 'o', 'r', 's', '\n',
        'c', 'o', 'n', 's', 't', 'r', 'u', 'c', 't', 's', '\n',
        'c', 'o', 'n', 's', 't', 'r', 'u', 'e', '\n',
        'c', 'o', 'n', 's', 't', 'r', 'u', 'e', 'd', '\n',
        'c', 'o', 'n', 's', 't', 'r', 'u', 'e', 's', '\n',
        'c', 'o', 'n', 's', 't', 'r', 'u', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 's', 'u', 'l', '\n',
        'c', 'o', 'n', 's', 'u', 'l', 'a', 'r', '\n',
        'c', 'o', 'n', 's', 'u', 'l', 'a', 't', 'e', '\n',
        'c', 'o', 'n', 's', 'u', 'l', 'a', 't', 'e', 's', '\n',
        'c', 'o', 'n', 's', 'u', 'l', 's', '\n',
        'c', 'o', 'n', 's', 'u', 'l', 't', '\n',
        'c', 'o', 'n', 's', 'u', 'l', 't', 'a', 'n', 'c', 'i', 'e', 's', '\n',
        'c', 'o', 'n', 's', 'u', 'l', 't', 'a', 'n', 'c', 'y', '\n',
        'c', 'o', 'n', 's', 'u', 'l', 't', 'a', 'n', 't', '\n',
        'c', 'o', 'n', 's', 'u', 'l', 't', 'a', 'n', 't', 's', '\n',
        'c', 'o', 'n', 's', 'u', 'l', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 's', 'u', 'l', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 's', 'u', 'l', 't', 'a', 't', 'i', 'v', 'e', '\n',
        'c', 'o', 'n', 's', 'u', 'l', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 's', 'u', 'l', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 's', 'u', 'l', 't', 's', '\n',
        'c', 'o', 'n', 's', 'u', 'm', 'a', 'b', 'l', 'e', '\n',
        'c', 'o', 'n', 's', 'u', 'm', 'a', 'b', 'l', 'e', 's', '\n',
        'c', 'o', 'n', 's', 'u', 'm', 'e', '\n',
        'c', 'o', 'n', 's', 'u', 'm', 'e', 'd', '\n',
        'c', 'o', 'n', 's', 'u', 'm', 'e', 'r', '\n',
        'c', 'o', 'n', 's', 'u', 'm', 'e', 'r', 'i', 's', 'm', '\n',
        'c', 'o', 'n', 's', 'u', 'm', 'e', 'r', 'i', 's', 't', '\n',
        'c', 'o', 'n', 's', 'u', 'm', 'e', 'r', 's', '\n',
        'c', 'o', 'n', 's', 'u', 'm', 'e', 's', '\n',
        'c', 'o', 'n', 's', 'u', 'm', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 's', 'u', 'm', 'm', 'a', 't', 'e', '\n',
        'c', 'o', 'n', 's', 'u', 'm', 'm', 'a', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 's', 'u', 'm', 'm', 'a', 't', 'e', 'l', 'y', '\n',
        'c', 'o', 'n', 's', 'u', 'm', 'm', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 's', 'u', 'm', 'p', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 's', 'u', 'm', 'p', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 's', 'u', 'm', 'p', 't', 'i', 'v', 'e', '\n',
        'c', 'o', 'n', 't', 'a', 'c', 't', '\n',
        'c', 'o', 'n', 't', 'a', 'c', 't', 'a', 'b', 'l', 'e', '\n',
        'c', 'o', 'n', 't', 'a', 'c', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 't', 'a', 'c', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 't', 'a', 'c', 't', 's', '\n',
        'c', 'o', 'n', 't', 'a', 'g', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 't', 'a', 'g', 'i', 'o', 'u', 's', '\n',
        'c', 'o', 'n', 't', 'a', 'i', 'n', '\n',
        'c', 'o', 'n', 't', 'a', 'i', 'n', 'a', 'b', 'l', 'e', '\n',
        'c', 'o', 'n', 't', 'a', 'i', 'n', 'e', 'd', '\n',
        'c', 'o', 'n', 't', 'a', 'i', 'n', 'e', 'r', '\n',
        'c', 'o', 'n', 't', 'a', 'i', 'n', 'e', 'r', 's', '\n',
        'c', 'o', 'n', 't', 'a', 'i', 'n', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 't', 'a', 'i', 'n', 'm', 'e', 'n', 't', '\n',
        'c', 'o', 'n', 't', 'a', 'i', 'n', 's', '\n',
        'c', 'o', 'n', 't', 'a', 'm', 'i', 'n', 'a', 'n', 't', '\n',
        'c', 'o', 'n', 't', 'a', 'm', 'i', 'n', 'a', 'n', 't', 's', '\n',
        'c', 'o', 'n', 't', 'a', 'm', 'i', 'n', 'a', 't', 'e', '\n',
        'c', 'o', 'n', 't', 'a', 'm', 'i', 'n', 'a', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 't', 'a', 'm', 'i', 'n', 'a', 't', 'e', 's', '\n',
        'c', 'o', 'n', 't', 'a', 'm', 'i', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 't', 'a', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 't', 'e', 'm', 'p', 'l', 'a', 't', 'e', '\n',
        'c', 'o', 'n', 't', 'e', 'm', 'p', 'l', 'a', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 't', 'e', 'm', 'p', 'l', 'a', 't', 'e', 's', '\n',
        'c', 'o', 'n', 't', 'e', 'm', 'p', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 't', 'e', 'm', 'p', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 't', 'e', 'm', 'p', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 't', 'e', 'm', 'p', 'l', 'a', 't', 'i', 'v', 'e', '\n',
        'c', 'o', 'n', 't', 'e', 'm', 'p', 'o', 'r', 'a', 'n', 'e', 'i', 't', 'y', '\n',
        'c', 'o', 'n', 't', 'e', 'm', 'p', 'o', 'r', 'a', 'n', 'e', 'o', 'u', 's', '\n',
        'c', 'o', 'n', 't', 'e', 'm', 'p', 'o', 'r', 'a', 'n', 'e', 'o', 'u', 's', 'l', 'y', '\n',
        'c', 'o', 'n', 't', 'e', 'm', 'p', 'o', 'r', 'a', 'r', 'i', 'e', 's', '\n',
        'c', 'o', 'n', 't', 'e', 'm', 'p', 'o', 'r', 'a', 'r', 'y', '\n',
        'c', 'o', 'n', 't', 'e', 'm', 'p', 't', '\n',
        'c', 'o', 'n', 't', 'e', 'm', 'p', 't', 'i', 'b', 'l', 'e', '\n',
        'c', 'o', 'n', 't', 'e', 'm', 'p', 't', 'i', 'b', 'l', 'y', '\n',
        'c', 'o', 'n', 't', 'e', 'm', 'p', 't', 'u', 'o', 'u', 's', '\n',
        'c', 'o', 'n', 't', 'e', 'm', 'p', 't', 'u', 'o', 'u', 's', 'l', 'y', '\n',
        'c', 'o', 'n', 't', 'e', 'n', 'd', '\n',
        'c', 'o', 'n', 't', 'e', 'n', 'd', 'e', 'd', '\n',
        'c', 'o', 'n', 't', 'e', 'n', 'd', 'e', 'r', '\n',
        'c', 'o', 'n', 't', 'e', 'n', 'd', 'e', 'r', 's', '\n',
        'c', 'o', 'n', 't', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 't', 'e', 'n', 'd', 's', '\n',
        'c', 'o', 'n', 't', 'e', 'n', 't', '\n',
        'c', 'o', 'n', 't', 'e', 'n', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 't', 'e', 'n', 't', 'e', 'd', 'l', 'y', '\n',
        'c', 'o', 'n', 't', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 't', 'e', 'n', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 't', 'e', 'n', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 't', 'e', 'n', 't', 'i', 'o', 'u', 's', '\n',
        'c', 'o', 'n', 't', 'e', 'n', 't', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'c', 'o', 'n', 't', 'e', 'n', 't', 'm', 'e', 'n', 't', '\n',
        'c', 'o', 'n', 't', 'e', 'n', 't', 's', '\n',
        'c', 'o', 'n', 't', 'e', 's', 't', '\n',
        'c', 'o', 'n', 't', 'e', 's', 't', 'a', 'b', 'l', 'e', '\n',
        'c', 'o', 'n', 't', 'e', 's', 't', 'a', 'n', 't', '\n',
        'c', 'o', 'n', 't', 'e', 's', 't', 'a', 'n', 't', 's', '\n',
        'c', 'o', 'n', 't', 'e', 's', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 't', 'e', 's', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 't', 'e', 's', 't', 's', '\n',
        'c', 'o', 'n', 't', 'e', 'x', 't', '\n',
        'c', 'o', 'n', 't', 'e', 'x', 't', 's', '\n',
        'c', 'o', 'n', 't', 'e', 'x', 't', 'u', 'a', 'l', '\n',
        'c', 'o', 'n', 't', 'e', 'x', 't', 'u', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 't', 'e', 'x', 't', 'u', 'a', 'l', 'l', 'y', '\n',
        'c', 'o', 'n', 't', 'i', 'g', 'u', 'i', 't', 'y', '\n',
        'c', 'o', 'n', 't', 'i', 'g', 'u', 'o', 'u', 's', '\n',
        'c', 'o', 'n', 't', 'i', 'g', 'u', 'o', 'u', 's', 'l', 'y', '\n',
        'c', 'o', 'n', 't', 'i', 'n', 'e', 'n', 'c', 'e', '\n',
        'c', 'o', 'n', 't', 'i', 'n', 'e', 'n', 't', '\n',
        'c', 'o', 'n', 't', 'i', 'n', 'e', 'n', 't', 'a', 'l', '\n',
        'c', 'o', 'n', 't', 'i', 'n', 'e', 'n', 't', 'a', 'l', 's', '\n',
        'c', 'o', 'n', 't', 'i', 'n', 'e', 'n', 't', 's', '\n',
        'c', 'o', 'n', 't', 'i', 'n', 'g', 'e', 'n', 'c', 'i', 'e', 's', '\n',
        'c', 'o', 'n', 't', 'i', 'n', 'g', 'e', 'n', 'c', 'y', '\n',
        'c', 'o', 'n', 't', 'i', 'n', 'g', 'e', 'n', 't', '\n',
        'c', 'o', 'n', 't', 'i', 'n', 'g', 'e', 'n', 't', 'l', 'y', '\n',
        'c', 'o', 'n', 't', 'i', 'n', 'g', 'e', 'n', 't', 's', '\n',
        'c', 'o', 'n', 't', 'i', 'n', 'u', 'a', '\n',
        'c', 'o', 'n', 't', 'i', 'n', 'u', 'a', 'b', 'l', 'e', '\n',
        'c', 'o', 'n', 't', 'i', 'n', 'u', 'a', 'l', '\n',
        'c', 'o', 'n', 't', 'i', 'n', 'u', 'a', 'l', 'l', 'y', '\n',
        'c', 'o', 'n', 't', 'i', 'n', 'u', 'a', 'n', 'c', 'e', '\n',
        'c', 'o', 'n', 't', 'i', 'n', 'u', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 't', 'i', 'n', 'u', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 't', 'i', 'n', 'u', 'e', '\n',
        'c', 'o', 'n', 't', 'i', 'n', 'u', 'e', 'd', '\n',
        'c', 'o', 'n', 't', 'i', 'n', 'u', 'e', 's', '\n',
        'c', 'o', 'n', 't', 'i', 'n', 'u', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 't', 'i', 'n', 'u', 'i', 't', 'i', 'e', 's', '\n',
        'c', 'o', 'n', 't', 'i', 'n', 'u', 'i', 't', 'y', '\n',
        'c', 'o', 'n', 't', 'i', 'n', 'u', 'o', 'u', 's', '\n',
        'c', 'o', 'n', 't', 'i', 'n', 'u', 'o', 'u', 's', 'l', 'y', '\n',
        'c', 'o', 'n', 't', 'i', 'n', 'u', 'u', 'm', '\n',
        'c', 'o', 'n', 't', 'o', 'r', 't', '\n',
        'c', 'o', 'n', 't', 'o', 'r', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 't', 'o', 'r', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 't', 'o', 'r', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 't', 'o', 'r', 't', 'i', 'o', 'n', 'i', 's', 't', '\n',
        'c', 'o', 'n', 't', 'o', 'r', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 't', 'o', 'r', 't', 's', '\n',
        'c', 'o', 'n', 't', 'o', 'u', 'r', '\n',
        'c', 'o', 'n', 't', 'o', 'u', 'r', 'e', 'd', '\n',
        'c', 'o', 'n', 't', 'o', 'u', 'r', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 't', 'o', 'u', 'r', 's', '\n',
        'c', 'o', 'n', 't', 'r', 'a', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'b', 'a', 'n', 'd', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'c', 'e', 'p', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'c', 'e', 'p', 't', 'i', 'v', 'e', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'c', 'e', 'p', 't', 'i', 'v', 'e', 's', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'c', 't', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'c', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'c', 't', 'i', 'b', 'l', 'e', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'c', 't', 'i', 'l', 'e', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'c', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'c', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'c', 't', 'o', 'r', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'c', 't', 'o', 'r', 's', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'c', 't', 's', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'c', 't', 'u', 'a', 'l', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'c', 't', 'u', 'a', 'l', 'l', 'y', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'd', 'i', 'c', 't', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'd', 'i', 'c', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'd', 'i', 'c', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'd', 'i', 'c', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'd', 'i', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'd', 'i', 'c', 't', 'o', 'r', 'i', 'l', 'y', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'd', 'i', 'c', 't', 'o', 'r', 'y', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'd', 'i', 'c', 't', 's', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'd', 'i', 's', 't', 'i', 'n', 'c', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'f', 'l', 'o', 'w', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'f', 'l', 'o', 'w', 's', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'i', 'n', 'd', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'i', 'n', 'd', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'l', 't', 'o', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'p', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'p', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'p', 'u', 'n', 't', 'a', 'l', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'r', 'i', 'l', 'y', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'r', 'i', 'n', 'e', 's', 's', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'r', 'i', 'w', 'i', 's', 'e', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'r', 'y', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 's', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 's', 't', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 's', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 's', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 's', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 's', 't', 'i', 'v', 'e', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 's', 't', 's', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 's', 't', 'y', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'v', 'e', 'n', 'e', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'v', 'e', 'n', 'e', 'd', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'v', 'e', 'n', 'e', 's', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'v', 'e', 'n', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'v', 'e', 'n', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 't', 'r', 'a', 'v', 'e', 'n', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 't', 'r', 'e', 't', 'e', 'm', 'p', 's', '\n',
        'c', 'o', 'n', 't', 'r', 'i', 'b', 'u', 't', 'e', '\n',
        'c', 'o', 'n', 't', 'r', 'i', 'b', 'u', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 't', 'r', 'i', 'b', 'u', 't', 'e', 's', '\n',
        'c', 'o', 'n', 't', 'r', 'i', 'b', 'u', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 't', 'r', 'i', 'b', 'u', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 't', 'r', 'i', 'b', 'u', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 't', 'r', 'i', 'b', 'u', 't', 'o', 'r', '\n',
        'c', 'o', 'n', 't', 'r', 'i', 'b', 'u', 't', 'o', 'r', 's', '\n',
        'c', 'o', 'n', 't', 'r', 'i', 'b', 'u', 't', 'o', 'r', 'y', '\n',
        'c', 'o', 'n', 't', 'r', 'i', 't', 'e', '\n',
        'c', 'o', 'n', 't', 'r', 'i', 't', 'e', 'l', 'y', '\n',
        'c', 'o', 'n', 't', 'r', 'i', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 't', 'r', 'i', 'v', 'a', 'n', 'c', 'e', '\n',
        'c', 'o', 'n', 't', 'r', 'i', 'v', 'a', 'n', 'c', 'e', 's', '\n',
        'c', 'o', 'n', 't', 'r', 'i', 'v', 'e', '\n',
        'c', 'o', 'n', 't', 'r', 'i', 'v', 'e', 'd', '\n',
        'c', 'o', 'n', 't', 'r', 'i', 'v', 'e', 's', '\n',
        'c', 'o', 'n', 't', 'r', 'i', 'v', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 't', 'r', 'o', 'l', '\n',
        'c', 'o', 'n', 't', 'r', 'o', 'l', 'l', 'a', 'b', 'l', 'e', '\n',
        'c', 'o', 'n', 't', 'r', 'o', 'l', 'l', 'e', 'd', '\n',
        'c', 'o', 'n', 't', 'r', 'o', 'l', 'l', 'e', 'r', '\n',
        'c', 'o', 'n', 't', 'r', 'o', 'l', 'l', 'e', 'r', 's', '\n',
        'c', 'o', 'n', 't', 'r', 'o', 'l', 'l', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 't', 'r', 'o', 'l', 's', '\n',
        'c', 'o', 'n', 't', 'r', 'o', 'v', 'e', 'r', 's', 'i', 'a', 'l', '\n',
        'c', 'o', 'n', 't', 'r', 'o', 'v', 'e', 'r', 's', 'i', 'a', 'l', 'l', 'y', '\n',
        'c', 'o', 'n', 't', 'r', 'o', 'v', 'e', 'r', 's', 'i', 'e', 's', '\n',
        'c', 'o', 'n', 't', 'r', 'o', 'v', 'e', 'r', 's', 'y', '\n',
        'c', 'o', 'n', 't', 'r', 'o', 'v', 'e', 'r', 't', '\n',
        'c', 'o', 'n', 't', 'r', 'o', 'v', 'e', 'r', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 't', 'u', 'm', 'e', 'l', 'y', '\n',
        'c', 'o', 'n', 't', 'u', 's', 'e', '\n',
        'c', 'o', 'n', 't', 'u', 's', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 't', 'u', 's', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 'u', 'n', 'd', 'r', 'u', 'm', '\n',
        'c', 'o', 'n', 'u', 'n', 'd', 'r', 'u', 'm', 's', '\n',
        'c', 'o', 'n', 'u', 'r', 'b', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'u', 'r', 'b', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 'v', 'a', 'l', 'e', 's', 'c', 'e', '\n',
        'c', 'o', 'n', 'v', 'a', 'l', 'e', 's', 'c', 'e', 'n', 'c', 'e', '\n',
        'c', 'o', 'n', 'v', 'a', 'l', 'e', 's', 'c', 'e', 'n', 't', '\n',
        'c', 'o', 'n', 'v', 'a', 'l', 'e', 's', 'c', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'v', 'e', 'c', 't', '\n',
        'c', 'o', 'n', 'v', 'e', 'c', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 'v', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'v', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'v', 'e', 'c', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'c', 'o', 'n', 'v', 'e', 'c', 't', 'i', 'v', 'e', '\n',
        'c', 'o', 'n', 'v', 'e', 'c', 't', 'o', 'r', '\n',
        'c', 'o', 'n', 'v', 'e', 'c', 't', 's', '\n',
        'c', 'o', 'n', 'v', 'e', 'n', 'e', '\n',
        'c', 'o', 'n', 'v', 'e', 'n', 'e', 'd', '\n',
        'c', 'o', 'n', 'v', 'e', 'n', 'e', 'r', '\n',
        'c', 'o', 'n', 'v', 'e', 'n', 'e', 's', '\n',
        'c', 'o', 'n', 'v', 'e', 'n', 'i', 'e', 'n', 'c', 'e', '\n',
        'c', 'o', 'n', 'v', 'e', 'n', 'i', 'e', 'n', 'c', 'e', 's', '\n',
        'c', 'o', 'n', 'v', 'e', 'n', 'i', 'e', 'n', 't', '\n',
        'c', 'o', 'n', 'v', 'e', 'n', 'i', 'e', 'n', 't', 'l', 'y', '\n',
        'c', 'o', 'n', 'v', 'e', 'n', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'v', 'e', 'n', 'o', 'r', '\n',
        'c', 'o', 'n', 'v', 'e', 'n', 'o', 'r', 's', '\n',
        'c', 'o', 'n', 'v', 'e', 'n', 't', '\n',
        'c', 'o', 'n', 'v', 'e', 'n', 't', 'i', 'c', 'l', 'e', '\n',
        'c', 'o', 'n', 'v', 'e', 'n', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'v', 'e', 'n', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'c', 'o', 'n', 'v', 'e', 'n', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 'm', '\n',
        'c', 'o', 'n', 'v', 'e', 'n', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 't', '\n',
        'c', 'o', 'n', 'v', 'e', 'n', 't', 'i', 'o', 'n', 'a', 'l', 'i', 't', 'y', '\n',
        'c', 'o', 'n', 'v', 'e', 'n', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'c', 'o', 'n', 'v', 'e', 'n', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 'v', 'e', 'n', 't', 's', '\n',
        'c', 'o', 'n', 'v', 'e', 'r', 'g', 'e', '\n',
        'c', 'o', 'n', 'v', 'e', 'r', 'g', 'e', 'd', '\n',
        'c', 'o', 'n', 'v', 'e', 'r', 'g', 'e', 'n', 'c', 'e', '\n',
        'c', 'o', 'n', 'v', 'e', 'r', 'g', 'e', 'n', 'c', 'e', 's', '\n',
        'c', 'o', 'n', 'v', 'e', 'r', 'g', 'e', 'n', 't', '\n',
        'c', 'o', 'n', 'v', 'e', 'r', 'g', 'e', 's', '\n',
        'c', 'o', 'n', 'v', 'e', 'r', 'g', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'v', 'e', 'r', 's', 'a', 'n', 't', '\n',
        'c', 'o', 'n', 'v', 'e', 'r', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'v', 'e', 'r', 's', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'c', 'o', 'n', 'v', 'e', 'r', 's', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 't', '\n',
        'c', 'o', 'n', 'v', 'e', 'r', 's', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 't', 's', '\n',
        'c', 'o', 'n', 'v', 'e', 'r', 's', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'c', 'o', 'n', 'v', 'e', 'r', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 'v', 'e', 'r', 's', 'a', 'z', 'i', 'o', 'n', 'e', '\n',
        'c', 'o', 'n', 'v', 'e', 'r', 's', 'e', '\n',
        'c', 'o', 'n', 'v', 'e', 'r', 's', 'e', 'd', '\n',
        'c', 'o', 'n', 'v', 'e', 'r', 's', 'e', 'l', 'y', '\n',
        'c', 'o', 'n', 'v', 'e', 'r', 's', 'e', 's', '\n',
        'c', 'o', 'n', 'v', 'e', 'r', 's', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'v', 'e', 'r', 's', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'v', 'e', 'r', 's', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 'v', 'e', 'r', 't', '\n',
        'c', 'o', 'n', 'v', 'e', 'r', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 'v', 'e', 'r', 't', 'e', 'r', '\n',
        'c', 'o', 'n', 'v', 'e', 'r', 't', 'e', 'r', 's', '\n',
        'c', 'o', 'n', 'v', 'e', 'r', 't', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'c', 'o', 'n', 'v', 'e', 'r', 't', 'i', 'b', 'l', 'e', '\n',
        'c', 'o', 'n', 'v', 'e', 'r', 't', 'i', 'b', 'l', 'e', 's', '\n',
        'c', 'o', 'n', 'v', 'e', 'r', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'v', 'e', 'r', 't', 'o', 'r', '\n',
        'c', 'o', 'n', 'v', 'e', 'r', 't', 'o', 'r', 's', '\n',
        'c', 'o', 'n', 'v', 'e', 'r', 't', 's', '\n',
        'c', 'o', 'n', 'v', 'e', 'x', '\n',
        'c', 'o', 'n', 'v', 'e', 'x', 'i', 't', 'y', '\n',
        'c', 'o', 'n', 'v', 'e', 'y', '\n',
        'c', 'o', 'n', 'v', 'e', 'y', 'a', 'n', 'c', 'e', '\n',
        'c', 'o', 'n', 'v', 'e', 'y', 'a', 'n', 'c', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'v', 'e', 'y', 'e', 'd', '\n',
        'c', 'o', 'n', 'v', 'e', 'y', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'v', 'e', 'y', 'o', 'r', '\n',
        'c', 'o', 'n', 'v', 'e', 'y', 'o', 'r', 's', '\n',
        'c', 'o', 'n', 'v', 'e', 'y', 's', '\n',
        'c', 'o', 'n', 'v', 'i', 'c', 't', '\n',
        'c', 'o', 'n', 'v', 'i', 'c', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 'v', 'i', 'c', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'v', 'i', 'c', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'v', 'i', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 'v', 'i', 'c', 't', 's', '\n',
        'c', 'o', 'n', 'v', 'i', 'n', 'c', 'e', '\n',
        'c', 'o', 'n', 'v', 'i', 'n', 'c', 'e', 'd', '\n',
        'c', 'o', 'n', 'v', 'i', 'n', 'c', 'e', 's', '\n',
        'c', 'o', 'n', 'v', 'i', 'n', 'c', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'v', 'i', 'n', 'c', 'i', 'n', 'g', 'l', 'y', '\n',
        'c', 'o', 'n', 'v', 'i', 'v', 'i', 'a', 'l', '\n',
        'c', 'o', 'n', 'v', 'i', 'v', 'i', 'a', 'l', 'i', 't', 'y', '\n',
        'c', 'o', 'n', 'v', 'o', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'v', 'o', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 'v', 'o', 'l', 'u', 't', 'e', 'd', '\n',
        'c', 'o', 'n', 'v', 'o', 'l', 'u', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'v', 'o', 'l', 'u', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 'v', 'o', 'l', 'v', 'e', '\n',
        'c', 'o', 'n', 'v', 'o', 'l', 'v', 'e', 'd', '\n',
        'c', 'o', 'n', 'v', 'o', 'y', '\n',
        'c', 'o', 'n', 'v', 'o', 'y', 's', '\n',
        'c', 'o', 'n', 'v', 'u', 'l', 's', 'e', '\n',
        'c', 'o', 'n', 'v', 'u', 'l', 's', 'e', 'd', '\n',
        'c', 'o', 'n', 'v', 'u', 'l', 's', 'e', 's', '\n',
        'c', 'o', 'n', 'v', 'u', 'l', 's', 'i', 'n', 'g', '\n',
        'c', 'o', 'n', 'v', 'u', 'l', 's', 'i', 'o', 'n', '\n',
        'c', 'o', 'n', 'v', 'u', 'l', 's', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'n', 'v', 'u', 'l', 's', 'i', 'v', 'e', '\n',
        'c', 'o', 'n', 'v', 'u', 'l', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'c', 'o', 'n', 'y', '\n',
        'c', 'o', 'o', '\n',
        'c', 'o', 'o', 'e', 'd', '\n',
        'c', 'o', 'o', 'i', 'n', 'g', '\n',
        'c', 'o', 'o', 'k', '\n',
        'c', 'o', 'o', 'k', 'b', 'o', 'o', 'k', '\n',
        'c', 'o', 'o', 'k', 'b', 'o', 'o', 'k', 's', '\n',
        'c', 'o', 'o', 'k', 'e', 'd', '\n',
        'c', 'o', 'o', 'k', 'e', 'r', '\n',
        'c', 'o', 'o', 'k', 'e', 'r', 's', '\n',
        'c', 'o', 'o', 'k', 'e', 'r', 'y', '\n',
        'c', 'o', 'o', 'k', 'i', 'e', 's', '\n',
        'c', 'o', 'o', 'k', 'i', 'n', 'g', '\n',
        'c', 'o', 'o', 'k', 's', '\n',
        'c', 'o', 'o', 'k', 'w', 'a', 'r', 'e', '\n',
        'c', 'o', 'o', 'l', '\n',
        'c', 'o', 'o', 'l', 'a', 'n', 't', '\n',
        'c', 'o', 'o', 'l', 'a', 'n', 't', 's', '\n',
        'c', 'o', 'o', 'l', 'e', 'd', '\n',
        'c', 'o', 'o', 'l', 'e', 'r', '\n',
        'c', 'o', 'o', 'l', 'e', 'r', 's', '\n',
        'c', 'o', 'o', 'l', 'e', 's', 't', '\n',
        'c', 'o', 'o', 'l', 'i', 'n', 'g', '\n',
        'c', 'o', 'o', 'l', 'n', 'e', 's', 's', '\n',
        'c', 'o', 'o', 'l', 's', '\n',
        'c', 'o', 'o', 'n', '\n',
        'c', 'o', 'o', 'n', 's', '\n',
        'c', 'o', 'o', 'p', '\n',
        'c', 'o', 'o', 'p', 'e', 'd', '\n',
        'c', 'o', 'o', 'p', 'e', 'r', '\n',
        'c', 'o', 'o', 'p', 'e', 'r', 'a', 't', 'e', '\n',
        'c', 'o', 'o', 'p', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'c', 'o', 'o', 'p', 'e', 'r', 'a', 't', 'e', 's', '\n',
        'c', 'o', 'o', 'p', 'e', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'o', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'o', 'p', 'e', 'r', 'a', 't', 'i', 'v', 'e', '\n',
        'c', 'o', 'o', 'p', 'e', 'r', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'c', 'o', 'o', 'p', 'e', 'r', 'a', 't', 'i', 'v', 'e', 's', '\n',
        'c', 'o', 'o', 'p', 'e', 'r', 's', '\n',
        'c', 'o', 'o', 'p', 's', '\n',
        'c', 'o', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'e', '\n',
        'c', 'o', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'e', 'd', '\n',
        'c', 'o', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'e', 's', '\n',
        'c', 'o', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'o', 'r', '\n',
        'c', 'o', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'o', 'r', 's', '\n',
        'c', 'o', 'o', 's', '\n',
        'c', 'o', 'p', '\n',
        'c', 'o', 'p', 'e', '\n',
        'c', 'o', 'p', 'e', 'd', '\n',
        'c', 'o', 'p', 'e', 's', '\n',
        'c', 'o', 'p', 'i', 'e', 'd', '\n',
        'c', 'o', 'p', 'i', 'e', 'r', '\n',
        'c', 'o', 'p', 'i', 'e', 'r', 's', '\n',
        'c', 'o', 'p', 'i', 'e', 's', '\n',
        'c', 'o', 'p', 'i', 'l', 'o', 't', '\n',
        'c', 'o', 'p', 'i', 'n', 'g', '\n',
        'c', 'o', 'p', 'i', 'o', 'u', 's', '\n',
        'c', 'o', 'p', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'c', 'o', 'p', 'l', 'a', 'n', 'a', 'r', '\n',
        'c', 'o', 'p', 'o', 'u', 't', '\n',
        'c', 'o', 'p', 'o', 'u', 't', 's', '\n',
        'c', 'o', 'p', 'p', 'e', 'r', '\n',
        'c', 'o', 'p', 'p', 'e', 'r', 'p', 'l', 'a', 't', 'e', '\n',
        'c', 'o', 'p', 'p', 'e', 'r', 's', '\n',
        'c', 'o', 'p', 'p', 'e', 'r', 'y', '\n',
        'c', 'o', 'p', 'p', 'i', 'c', 'e', '\n',
        'c', 'o', 'p', 'p', 'i', 'c', 'e', 'd', '\n',
        'c', 'o', 'p', 'p', 'i', 'c', 'e', 's', '\n',
        'c', 'o', 'p', 'p', 'i', 'c', 'i', 'n', 'g', '\n',
        'c', 'o', 'p', 'r', 'a', '\n',
        'c', 'o', 'p', 'r', 'o', 'c', 'e', 's', 's', 'o', 'r', '\n',
        'c', 'o', 'p', 'r', 'o', 'c', 'e', 's', 's', 'o', 'r', 's', '\n',
        'c', 'o', 'p', 'r', 'o', 'd', 'u', 'c', 'e', 'd', '\n',
        'c', 'o', 'p', 'r', 'o', 'l', 'i', 't', 'e', '\n',
        'c', 'o', 'p', 'r', 'o', 'p', 'h', 'a', 'g', 'o', 'u', 's', '\n',
        'c', 'o', 'p', 's', '\n',
        'c', 'o', 'p', 's', 'e', '\n',
        'c', 'o', 'p', 's', 'e', 's', '\n',
        'c', 'o', 'p', 'u', 'l', 'a', 't', 'e', '\n',
        'c', 'o', 'p', 'u', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'p', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'p', 'u', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'p', 'u', 'l', 'a', 't', 'o', 'r', 'y', '\n',
        'c', 'o', 'p', 'y', '\n',
        'c', 'o', 'p', 'y', 'a', 'b', 'l', 'e', '\n',
        'c', 'o', 'p', 'y', 'c', 'a', 't', '\n',
        'c', 'o', 'p', 'y', 'c', 'a', 't', 's', '\n',
        'c', 'o', 'p', 'y', 'i', 'n', 'g', '\n',
        'c', 'o', 'p', 'y', 'i', 's', 't', '\n',
        'c', 'o', 'p', 'y', 'i', 's', 't', 's', '\n',
        'c', 'o', 'p', 'y', 'r', 'i', 'g', 'h', 't', '\n',
        'c', 'o', 'p', 'y', 'r', 'i', 'g', 'h', 't', 'a', 'b', 'l', 'e', '\n',
        'c', 'o', 'p', 'y', 'r', 'i', 'g', 'h', 't', 'e', 'd', '\n',
        'c', 'o', 'p', 'y', 'r', 'i', 'g', 'h', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'p', 'y', 'r', 'i', 'g', 'h', 't', 's', '\n',
        'c', 'o', 'p', 'y', 'w', 'r', 'i', 't', 'e', 'r', '\n',
        'c', 'o', 'q', 'u', 'e', 't', 't', 'e', '\n',
        'c', 'o', 'q', 'u', 'e', 't', 't', 'e', 's', '\n',
        'c', 'o', 'q', 'u', 'e', 't', 't', 'i', 's', 'h', '\n',
        'c', 'o', 'q', 'u', 'e', 't', 't', 'i', 's', 'h', 'l', 'y', '\n',
        'c', 'o', 'r', '\n',
        'c', 'o', 'r', 'a', 'c', 'l', 'e', '\n',
        'c', 'o', 'r', 'a', 'l', '\n',
        'c', 'o', 'r', 'a', 'l', 'l', 'i', 'n', 'e', '\n',
        'c', 'o', 'r', 'a', 'l', 's', '\n',
        'c', 'o', 'r', 'd', '\n',
        'c', 'o', 'r', 'd', 'a', 'g', 'e', '\n',
        'c', 'o', 'r', 'd', 'a', 't', 'e', '\n',
        'c', 'o', 'r', 'd', 'e', 'd', '\n',
        'c', 'o', 'r', 'd', 'i', 'a', 'l', '\n',
        'c', 'o', 'r', 'd', 'i', 'a', 'l', 'i', 't', 'y', '\n',
        'c', 'o', 'r', 'd', 'i', 'a', 'l', 'l', 'y', '\n',
        'c', 'o', 'r', 'd', 'i', 'a', 'l', 's', '\n',
        'c', 'o', 'r', 'd', 'i', 'l', 'l', 'e', 'r', 'a', '\n',
        'c', 'o', 'r', 'd', 'i', 't', 'e', '\n',
        'c', 'o', 'r', 'd', 'l', 'e', 's', 's', '\n',
        'c', 'o', 'r', 'd', 'o', 'n', '\n',
        'c', 'o', 'r', 'd', 'o', 'n', 'e', 'd', '\n',
        'c', 'o', 'r', 'd', 'o', 'n', 's', '\n',
        'c', 'o', 'r', 'd', 's', '\n',
        'c', 'o', 'r', 'd', 'u', 'r', 'o', 'y', '\n',
        'c', 'o', 'r', 'd', 'u', 'r', 'o', 'y', 's', '\n',
        'c', 'o', 'r', 'e', '\n',
        'c', 'o', 'r', 'e', 's', '\n',
        'c', 'o', 'r', 'e', 's', 'p', 'o', 'n', 'd', 'e', 'n', 't', '\n',
        'c', 'o', 'r', 'g', 'i', '\n',
        'c', 'o', 'r', 'g', 'i', 's', '\n',
        'c', 'o', 'r', 'i', 'a', 'n', 'd', 'e', 'r', '\n',
        'c', 'o', 'r', 'i', 'n', 't', 'h', '\n',
        'c', 'o', 'r', 'k', '\n',
        'c', 'o', 'r', 'k', 'a', 'g', 'e', '\n',
        'c', 'o', 'r', 'k', 'e', 'd', '\n',
        'c', 'o', 'r', 'k', 's', '\n',
        'c', 'o', 'r', 'k', 's', 'c', 'r', 'e', 'w', '\n',
        'c', 'o', 'r', 'k', 's', 'c', 'r', 'e', 'w', 's', '\n',
        'c', 'o', 'r', 'k', 'y', '\n',
        'c', 'o', 'r', 'm', 'o', 'r', 'a', 'n', 't', '\n',
        'c', 'o', 'r', 'm', 'o', 'r', 'a', 'n', 't', 's', '\n',
        'c', 'o', 'r', 'n', '\n',
        'c', 'o', 'r', 'n', 'c', 'r', 'a', 'k', 'e', '\n',
        'c', 'o', 'r', 'n', 'e', 'a', '\n',
        'c', 'o', 'r', 'n', 'e', 'a', 'l', '\n',
        'c', 'o', 'r', 'n', 'e', 'a', 's', '\n',
        'c', 'o', 'r', 'n', 'e', 'd', '\n',
        'c', 'o', 'r', 'n', 'e', 'r', '\n',
        'c', 'o', 'r', 'n', 'e', 'r', 'e', 'd', '\n',
        'c', 'o', 'r', 'n', 'e', 'r', 'i', 'n', 'g', '\n',
        'c', 'o', 'r', 'n', 'e', 'r', 's', '\n',
        'c', 'o', 'r', 'n', 'e', 'r', 's', 't', 'o', 'n', 'e', '\n',
        'c', 'o', 'r', 'n', 'e', 'r', 's', 't', 'o', 'n', 'e', 's', '\n',
        'c', 'o', 'r', 'n', 'e', 't', '\n',
        'c', 'o', 'r', 'n', 'e', 't', 's', '\n',
        'c', 'o', 'r', 'n', 'f', 'i', 'e', 'l', 'd', '\n',
        'c', 'o', 'r', 'n', 'f', 'i', 'e', 'l', 'd', 's', '\n',
        'c', 'o', 'r', 'n', 'f', 'l', 'a', 'k', 'e', '\n',
        'c', 'o', 'r', 'n', 'f', 'l', 'a', 'k', 'e', 's', '\n',
        'c', 'o', 'r', 'n', 'f', 'l', 'o', 'u', 'r', '\n',
        'c', 'o', 'r', 'n', 'f', 'l', 'o', 'w', 'e', 'r', '\n',
        'c', 'o', 'r', 'n', 'f', 'l', 'o', 'w', 'e', 'r', 's', '\n',
        'c', 'o', 'r', 'n', 'i', 'c', 'e', '\n',
        'c', 'o', 'r', 'n', 'i', 'c', 'e', 's', '\n',
        'c', 'o', 'r', 'n', 'i', 's', 'h', '\n',
        'c', 'o', 'r', 'n', 'm', 'e', 'a', 'l', '\n',
        'c', 'o', 'r', 'n', 's', '\n',
        'c', 'o', 'r', 'n', 'u', 'c', 'o', 'p', 'i', 'a', '\n',
        'c', 'o', 'r', 'n', 'y', '\n',
        'c', 'o', 'r', 'o', 'l', 'l', 'a', 'r', 'i', 'e', 's', '\n',
        'c', 'o', 'r', 'o', 'l', 'l', 'a', 'r', 'y', '\n',
        'c', 'o', 'r', 'o', 'n', 'a', '\n',
        'c', 'o', 'r', 'o', 'n', 'a', 'l', '\n',
        'c', 'o', 'r', 'o', 'n', 'a', 'r', 'i', 'e', 's', '\n',
        'c', 'o', 'r', 'o', 'n', 'a', 'r', 'y', '\n',
        'c', 'o', 'r', 'o', 'n', 'a', 's', '\n',
        'c', 'o', 'r', 'o', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'r', 'o', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'r', 'o', 'n', 'e', 'r', '\n',
        'c', 'o', 'r', 'o', 'n', 'e', 'r', 's', '\n',
        'c', 'o', 'r', 'o', 'n', 'e', 't', '\n',
        'c', 'o', 'r', 'o', 'n', 'e', 't', 's', '\n',
        'c', 'o', 'r', 'p', 'o', 'r', 'a', '\n',
        'c', 'o', 'r', 'p', 'o', 'r', 'a', 'l', '\n',
        'c', 'o', 'r', 'p', 'o', 'r', 'a', 'l', 's', '\n',
        'c', 'o', 'r', 'p', 'o', 'r', 'a', 't', 'e', '\n',
        'c', 'o', 'r', 'p', 'o', 'r', 'a', 't', 'e', 'l', 'y', '\n',
        'c', 'o', 'r', 'p', 'o', 'r', 'a', 't', 'e', 's', '\n',
        'c', 'o', 'r', 'p', 'o', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'r', 'p', 'o', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'r', 'p', 'o', 'r', 'a', 't', 'i', 's', 'm', '\n',
        'c', 'o', 'r', 'p', 'o', 'r', 'a', 't', 'i', 's', 't', '\n',
        'c', 'o', 'r', 'p', 'o', 'r', 'e', 'a', 'l', '\n',
        'c', 'o', 'r', 'p', 'o', 'r', 'e', 'a', 'l', 'l', 'y', '\n',
        'c', 'o', 'r', 'p', 's', '\n',
        'c', 'o', 'r', 'p', 's', 'e', '\n',
        'c', 'o', 'r', 'p', 's', 'e', 's', '\n',
        'c', 'o', 'r', 'p', 'u', 'l', 'e', 'n', 't', '\n',
        'c', 'o', 'r', 'p', 'u', 's', '\n',
        'c', 'o', 'r', 'p', 'u', 's', 'c', 'l', 'e', '\n',
        'c', 'o', 'r', 'p', 'u', 's', 'c', 'l', 'e', 's', '\n',
        'c', 'o', 'r', 'p', 'u', 's', 'c', 'u', 'l', 'a', 'r', '\n',
        'c', 'o', 'r', 'r', 'a', 'l', '\n',
        'c', 'o', 'r', 'r', 'a', 'l', 'l', 'e', 'd', '\n',
        'c', 'o', 'r', 'r', 'a', 'l', 's', '\n',
        'c', 'o', 'r', 'r', 'e', 'c', 't', '\n',
        'c', 'o', 'r', 'r', 'e', 'c', 't', 'a', 'b', 'l', 'e', '\n',
        'c', 'o', 'r', 'r', 'e', 'c', 't', 'e', 'd', '\n',
        'c', 'o', 'r', 'r', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'r', 'r', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'r', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'c', 'o', 'r', 'r', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'r', 'r', 'e', 'c', 't', 'i', 'v', 'e', '\n',
        'c', 'o', 'r', 'r', 'e', 'c', 't', 'l', 'y', '\n',
        'c', 'o', 'r', 'r', 'e', 'c', 't', 'n', 'e', 's', 's', '\n',
        'c', 'o', 'r', 'r', 'e', 'c', 't', 'o', 'r', '\n',
        'c', 'o', 'r', 'r', 'e', 'c', 't', 'o', 'r', 's', '\n',
        'c', 'o', 'r', 'r', 'e', 'c', 't', 's', '\n',
        'c', 'o', 'r', 'r', 'e', 'l', 'a', 't', 'e', '\n',
        'c', 'o', 'r', 'r', 'e', 'l', 'a', 't', 'e', 'd', '\n',
        'c', 'o', 'r', 'r', 'e', 'l', 'a', 't', 'e', 's', '\n',
        'c', 'o', 'r', 'r', 'e', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'r', 'r', 'e', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'r', 'r', 'e', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'r', 'r', 'e', 'l', 'a', 't', 'i', 'v', 'e', '\n',
        'c', 'o', 'r', 'r', 'e', 's', 'p', 'o', 'n', 'd', '\n',
        'c', 'o', 'r', 'r', 'e', 's', 'p', 'o', 'n', 'd', 'e', 'd', '\n',
        'c', 'o', 'r', 'r', 'e', 's', 'p', 'o', 'n', 'd', 'e', 'n', 'c', 'e', '\n',
        'c', 'o', 'r', 'r', 'e', 's', 'p', 'o', 'n', 'd', 'e', 'n', 'c', 'e', 's', '\n',
        'c', 'o', 'r', 'r', 'e', 's', 'p', 'o', 'n', 'd', 'e', 'n', 't', '\n',
        'c', 'o', 'r', 'r', 'e', 's', 'p', 'o', 'n', 'd', 'e', 'n', 't', 's', '\n',
        'c', 'o', 'r', 'r', 'e', 's', 'p', 'o', 'n', 'd', 'i', 'n', 'g', '\n',
        'c', 'o', 'r', 'r', 'e', 's', 'p', 'o', 'n', 'd', 'i', 'n', 'g', 'l', 'y', '\n',
        'c', 'o', 'r', 'r', 'e', 's', 'p', 'o', 'n', 'd', 's', '\n',
        'c', 'o', 'r', 'r', 'i', 'd', 'o', 'r', '\n',
        'c', 'o', 'r', 'r', 'i', 'd', 'o', 'r', 's', '\n',
        'c', 'o', 'r', 'r', 'i', 'g', 'e', 'n', 'd', 'a', '\n',
        'c', 'o', 'r', 'r', 'o', 'b', 'o', 'r', 'a', 't', 'e', '\n',
        'c', 'o', 'r', 'r', 'o', 'b', 'o', 'r', 'a', 't', 'e', 'd', '\n',
        'c', 'o', 'r', 'r', 'o', 'b', 'o', 'r', 'a', 't', 'e', 's', '\n',
        'c', 'o', 'r', 'r', 'o', 'b', 'o', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'r', 'r', 'o', 'b', 'o', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'r', 'r', 'o', 'b', 'o', 'r', 'a', 't', 'i', 'v', 'e', '\n',
        'c', 'o', 'r', 'r', 'o', 'b', 'o', 'r', 'a', 't', 'o', 'r', 'y', '\n',
        'c', 'o', 'r', 'r', 'o', 'd', 'e', '\n',
        'c', 'o', 'r', 'r', 'o', 'd', 'e', 'd', '\n',
        'c', 'o', 'r', 'r', 'o', 'd', 'e', 's', '\n',
        'c', 'o', 'r', 'r', 'o', 'd', 'i', 'n', 'g', '\n',
        'c', 'o', 'r', 'r', 'o', 's', 'i', 'o', 'n', '\n',
        'c', 'o', 'r', 'r', 'o', 's', 'i', 'v', 'e', '\n',
        'c', 'o', 'r', 'r', 'u', 'g', 'a', 't', 'e', 'd', '\n',
        'c', 'o', 'r', 'r', 'u', 'g', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'r', 'r', 'u', 'p', 't', '\n',
        'c', 'o', 'r', 'r', 'u', 'p', 't', 'e', 'd', '\n',
        'c', 'o', 'r', 'r', 'u', 'p', 't', 'i', 'b', 'l', 'e', '\n',
        'c', 'o', 'r', 'r', 'u', 'p', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'r', 'r', 'u', 'p', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'r', 'r', 'u', 'p', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'o', 'r', 'r', 'u', 'p', 't', 'l', 'y', '\n',
        'c', 'o', 'r', 'r', 'u', 'p', 't', 's', '\n',
        'c', 'o', 'r', 's', 'a', 'g', 'e', '\n',
        'c', 'o', 'r', 's', 'e', '\n',
        'c', 'o', 'r', 's', 'e', 't', '\n',
        'c', 'o', 'r', 's', 'e', 't', 's', '\n',
        'c', 'o', 'r', 's', 'i', 'c', 'a', '\n',
        'c', 'o', 'r', 's', 'l', 'e', 't', '\n',
        'c', 'o', 'r', 't', 'e', 'g', 'e', '\n',
        'c', 'o', 'r', 't', 'e', 'x', '\n',
        'c', 'o', 'r', 't', 'i', 'c', 'a', 'l', '\n',
        'c', 'o', 'r', 't', 'i', 'c', 'o', 's', 't', 'e', 'r', 'o', 'i', 'd', '\n',
        'c', 'o', 'r', 't', 'i', 'c', 'o', 's', 't', 'e', 'r', 'o', 'i', 'd', 's', '\n',
        'c', 'o', 'r', 't', 'i', 's', 'o', 'l', '\n',
        'c', 'o', 'r', 't', 'i', 's', 'o', 'n', 'e', '\n',
        'c', 'o', 'r', 'u', 's', 'c', 'a', 't', 'e', 's', '\n',
        'c', 'o', 'r', 'v', 'e', 't', 't', 'e', '\n',
        'c', 'o', 'r', 'v', 'e', 't', 't', 'e', 's', '\n',
        'c', 'o', 's', 'i', 'e', 'r', '\n',
        'c', 'o', 's', 'i', 'e', 's', 't', '\n',
        'c', 'o', 's', 'i', 'l', 'y', '\n',
        'c', 'o', 's', 'i', 'n', 'e', '\n',
        'c', 'o', 's', 'i', 'n', 'e', 's', '\n',
        'c', 'o', 's', 'i', 'n', 'e', 's', 's', '\n',
        'c', 'o', 's', 'm', 'e', 't', 'i', 'c', '\n',
        'c', 'o', 's', 'm', 'e', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'c', 'o', 's', 'm', 'e', 't', 'i', 'c', 's', '\n',
        'c', 'o', 's', 'm', 'i', 'c', '\n',
        'c', 'o', 's', 'm', 'i', 'c', 'a', 'l', '\n',
        'c', 'o', 's', 'm', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'c', 'o', 's', 'm', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'c', 'o', 's', 'm', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'c', 'o', 's', 'm', 'o', 'l', 'o', 'g', 'i', 'e', 's', '\n',
        'c', 'o', 's', 'm', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'c', 'o', 's', 'm', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'c', 'o', 's', 'm', 'o', 'l', 'o', 'g', 'y', '\n',
        'c', 'o', 's', 'm', 'o', 'n', 'a', 'u', 't', '\n',
        'c', 'o', 's', 'm', 'o', 'n', 'a', 'u', 't', 's', '\n',
        'c', 'o', 's', 'm', 'o', 'p', 'o', 'l', 'i', 't', 'a', 'n', '\n',
        'c', 'o', 's', 'm', 'o', 'p', 'o', 'l', 'i', 't', 'a', 'n', 's', '\n',
        'c', 'o', 's', 'm', 'o', 's', '\n',
        'c', 'o', 's', 's', 'a', 'c', 'k', 's', '\n',
        'c', 'o', 's', 's', 'e', 't', '\n',
        'c', 'o', 's', 's', 'e', 't', 'e', 'd', '\n',
        'c', 'o', 's', 's', 'e', 't', 's', '\n',
        'c', 'o', 's', 't', '\n',
        'c', 'o', 's', 't', 'a', 'r', '\n',
        'c', 'o', 's', 't', 'a', 'r', 'r', 'e', 'd', '\n',
        'c', 'o', 's', 't', 'a', 'r', 'r', 'i', 'n', 'g', '\n',
        'c', 'o', 's', 't', 'a', 'r', 's', '\n',
        'c', 'o', 's', 't', 'c', 'u', 't', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 's', 't', 'e', 'd', '\n',
        'c', 'o', 's', 't', 'e', 'f', 'f', 'e', 'c', 't', 'i', 'v', 'e', '\n',
        'c', 'o', 's', 't', 'e', 'f', 'f', 'e', 'c', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'c', 'o', 's', 't', 'e', 'f', 'f', 'i', 'c', 'i', 'e', 'n', 't', '\n',
        'c', 'o', 's', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 's', 't', 'i', 'n', 'g', 's', '\n',
        'c', 'o', 's', 't', 'i', 'v', 'e', '\n',
        'c', 'o', 's', 't', 'l', 'e', 's', 's', '\n',
        'c', 'o', 's', 't', 'l', 'i', 'e', 'r', '\n',
        'c', 'o', 's', 't', 'l', 'i', 'e', 's', 't', '\n',
        'c', 'o', 's', 't', 'l', 'i', 'n', 'e', 's', 's', '\n',
        'c', 'o', 's', 't', 'l', 'y', '\n',
        'c', 'o', 's', 't', 's', '\n',
        'c', 'o', 's', 't', 'u', 'm', 'e', '\n',
        'c', 'o', 's', 't', 'u', 'm', 'e', 'd', '\n',
        'c', 'o', 's', 't', 'u', 'm', 'e', 's', '\n',
        'c', 'o', 's', 'y', '\n',
        'c', 'o', 't', '\n',
        'c', 'o', 't', 'e', 'r', 'i', 'e', '\n',
        'c', 'o', 't', 'e', 'r', 'm', 'i', 'n', 'o', 'u', 's', '\n',
        'c', 'o', 't', 's', '\n',
        'c', 'o', 't', 't', 'a', 'g', 'e', '\n',
        'c', 'o', 't', 't', 'a', 'g', 'e', 's', '\n',
        'c', 'o', 't', 't', 'o', 'n', '\n',
        'c', 'o', 't', 't', 'o', 'n', 'e', 'd', '\n',
        'c', 'o', 't', 't', 'o', 'n', 's', '\n',
        'c', 'o', 'u', 'c', 'h', '\n',
        'c', 'o', 'u', 'c', 'h', 'e', 'd', '\n',
        'c', 'o', 'u', 'c', 'h', 'e', 's', '\n',
        'c', 'o', 'u', 'c', 'h', 'i', 'n', 'g', '\n',
        'c', 'o', 'u', 'g', 'a', 'r', '\n',
        'c', 'o', 'u', 'g', 'a', 'r', 's', '\n',
        'c', 'o', 'u', 'g', 'h', '\n',
        'c', 'o', 'u', 'g', 'h', 'e', 'd', '\n',
        'c', 'o', 'u', 'g', 'h', 'i', 'n', 'g', '\n',
        'c', 'o', 'u', 'g', 'h', 's', '\n',
        'c', 'o', 'u', 'l', 'd', '\n',
        'c', 'o', 'u', 'l', 'o', 'i', 'r', '\n',
        'c', 'o', 'u', 'l', 'o', 'm', 'b', '\n',
        'c', 'o', 'u', 'l', 'o', 'm', 'b', 's', '\n',
        'c', 'o', 'u', 'n', 'c', 'i', 'l', '\n',
        'c', 'o', 'u', 'n', 'c', 'i', 'l', 'l', 'o', 'r', '\n',
        'c', 'o', 'u', 'n', 'c', 'i', 'l', 'l', 'o', 'r', 's', '\n',
        'c', 'o', 'u', 'n', 'c', 'i', 'l', 's', '\n',
        'c', 'o', 'u', 'n', 's', 'e', 'l', '\n',
        'c', 'o', 'u', 'n', 's', 'e', 'l', 'l', 'e', 'd', '\n',
        'c', 'o', 'u', 'n', 's', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'c', 'o', 'u', 'n', 's', 'e', 'l', 'l', 'o', 'r', '\n',
        'c', 'o', 'u', 'n', 's', 'e', 'l', 'l', 'o', 'r', 's', '\n',
        'c', 'o', 'u', 'n', 's', 'e', 'l', 's', '\n',
        'c', 'o', 'u', 'n', 't', '\n',
        'c', 'o', 'u', 'n', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'c', 'o', 'u', 'n', 't', 'a', 'b', 'l', 'e', '\n',
        'c', 'o', 'u', 'n', 't', 'a', 'b', 'l', 'y', '\n',
        'c', 'o', 'u', 'n', 't', 'd', 'o', 'w', 'n', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'd', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'n', 'a', 'n', 'c', 'e', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'n', 'a', 'n', 'c', 'e', 'd', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'n', 'a', 'n', 'c', 'e', 's', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'n', 'a', 'n', 'c', 'i', 'n', 'g', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 'a', 'c', 't', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 'a', 'c', 't', 'e', 'd', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 'a', 'c', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 'a', 'c', 't', 's', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 'a', 't', 't', 'a', 'c', 'k', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 'a', 't', 't', 'a', 'c', 'k', 'e', 'd', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 'a', 't', 't', 'a', 'c', 'k', 's', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 'b', 'a', 'l', 'a', 'n', 'c', 'e', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 'b', 'a', 'l', 'a', 'n', 'c', 'e', 'd', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 'b', 'a', 'l', 'a', 'n', 'c', 'i', 'n', 'g', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 'e', 'd', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 'f', 'e', 'i', 't', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 'f', 'e', 'i', 't', 'e', 'd', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 'f', 'e', 'i', 't', 'e', 'r', 's', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 'f', 'e', 'i', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 'f', 'e', 'i', 't', 's', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 'f', 'o', 'i', 'l', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 'f', 'o', 'i', 'l', 's', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 'i', 'n', 't', 'e', 'l', 'l', 'i', 'g', 'e', 'n', 'c', 'e', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 'i', 'n', 't', 'u', 'i', 't', 'i', 'v', 'e', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 'm', 'a', 'n', 'd', 'e', 'd', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 'm', 'e', 'a', 's', 'u', 'r', 'e', 's', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 'o', 'f', 'f', 'e', 'n', 's', 'i', 'v', 'e', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 'p', 'a', 'n', 'e', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 'p', 'a', 'r', 't', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 'p', 'a', 'r', 't', 's', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 'p', 'o', 'i', 'n', 't', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 'p', 'o', 'i', 'n', 't', 'e', 'd', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 'p', 'o', 'i', 'n', 't', 's', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 'p', 'o', 'i', 's', 'e', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 'p', 'r', 'o', 'd', 'u', 'c', 't', 'i', 'v', 'e', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 'r', 'e', 'v', 'o', 'l', 'u', 't', 'i', 'o', 'n', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 'r', 'e', 'v', 'o', 'l', 'u', 't', 'i', 'o', 'n', 'a', 'r', 'i', 'e', 's', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 'r', 'e', 'v', 'o', 'l', 'u', 't', 'i', 'o', 'n', 'a', 'r', 'y', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 's', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 's', 'i', 'g', 'n', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 's', 'i', 'g', 'n', 'e', 'd', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 'r', 's', 'i', 'g', 'n', 's', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 's', 's', '\n',
        'c', 'o', 'u', 'n', 't', 'e', 's', 's', 'e', 's', '\n',
        'c', 'o', 'u', 'n', 't', 'i', 'e', 's', '\n',
        'c', 'o', 'u', 'n', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'u', 'n', 't', 'l', 'e', 's', 's', '\n',
        'c', 'o', 'u', 'n', 't', 'r', 'i', 'e', 's', '\n',
        'c', 'o', 'u', 'n', 't', 'r', 'y', '\n',
        'c', 'o', 'u', 'n', 't', 'r', 'y', 'm', 'a', 'n', '\n',
        'c', 'o', 'u', 'n', 't', 'r', 'y', 'm', 'e', 'n', '\n',
        'c', 'o', 'u', 'n', 't', 'r', 'y', 's', 'i', 'd', 'e', '\n',
        'c', 'o', 'u', 'n', 't', 'r', 'y', 'w', 'i', 'd', 'e', '\n',
        'c', 'o', 'u', 'n', 't', 's', '\n',
        'c', 'o', 'u', 'n', 't', 'y', '\n',
        'c', 'o', 'u', 'p', '\n',
        'c', 'o', 'u', 'p', 'e', '\n',
        'c', 'o', 'u', 'p', 'e', 's', '\n',
        'c', 'o', 'u', 'p', 'l', 'e', '\n',
        'c', 'o', 'u', 'p', 'l', 'e', 'd', '\n',
        'c', 'o', 'u', 'p', 'l', 'e', 'r', '\n',
        'c', 'o', 'u', 'p', 'l', 'e', 'r', 's', '\n',
        'c', 'o', 'u', 'p', 'l', 'e', 's', '\n',
        'c', 'o', 'u', 'p', 'l', 'e', 't', '\n',
        'c', 'o', 'u', 'p', 'l', 'e', 't', 's', '\n',
        'c', 'o', 'u', 'p', 'l', 'i', 'n', 'g', '\n',
        'c', 'o', 'u', 'p', 'l', 'i', 'n', 'g', 's', '\n',
        'c', 'o', 'u', 'p', 'o', 'n', '\n',
        'c', 'o', 'u', 'p', 'o', 'n', 's', '\n',
        'c', 'o', 'u', 'p', 's', '\n',
        'c', 'o', 'u', 'r', 'a', 'g', 'e', '\n',
        'c', 'o', 'u', 'r', 'a', 'g', 'e', 'o', 'u', 's', '\n',
        'c', 'o', 'u', 'r', 'a', 'g', 'e', 'o', 'u', 's', 'l', 'y', '\n',
        'c', 'o', 'u', 'r', 'g', 'e', 't', 't', 'e', '\n',
        'c', 'o', 'u', 'r', 'g', 'e', 't', 't', 'e', 's', '\n',
        'c', 'o', 'u', 'r', 'i', 'e', 'r', '\n',
        'c', 'o', 'u', 'r', 'i', 'e', 'r', 's', '\n',
        'c', 'o', 'u', 'r', 's', 'e', '\n',
        'c', 'o', 'u', 'r', 's', 'e', 'b', 'o', 'o', 'k', '\n',
        'c', 'o', 'u', 'r', 's', 'e', 'd', '\n',
        'c', 'o', 'u', 'r', 's', 'e', 's', '\n',
        'c', 'o', 'u', 'r', 's', 'e', 'w', 'o', 'r', 'k', '\n',
        'c', 'o', 'u', 'r', 's', 'i', 'n', 'g', '\n',
        'c', 'o', 'u', 'r', 't', '\n',
        'c', 'o', 'u', 'r', 't', 'e', 'd', '\n',
        'c', 'o', 'u', 'r', 't', 'e', 'o', 'u', 's', '\n',
        'c', 'o', 'u', 'r', 't', 'e', 'o', 'u', 's', 'l', 'y', '\n',
        'c', 'o', 'u', 'r', 't', 'e', 's', 'a', 'n', '\n',
        'c', 'o', 'u', 'r', 't', 'e', 's', 'a', 'n', 's', '\n',
        'c', 'o', 'u', 'r', 't', 'e', 's', 'i', 'e', 's', '\n',
        'c', 'o', 'u', 'r', 't', 'e', 's', 'y', '\n',
        'c', 'o', 'u', 'r', 't', 'h', 'o', 'u', 's', 'e', '\n',
        'c', 'o', 'u', 'r', 't', 'i', 'e', 'r', '\n',
        'c', 'o', 'u', 'r', 't', 'i', 'e', 'r', 's', '\n',
        'c', 'o', 'u', 'r', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'u', 'r', 't', 'l', 'y', '\n',
        'c', 'o', 'u', 'r', 't', 'm', 'a', 'r', 't', 'i', 'a', 'l', '\n',
        'c', 'o', 'u', 'r', 't', 'r', 'o', 'o', 'm', '\n',
        'c', 'o', 'u', 'r', 't', 'r', 'o', 'o', 'm', 's', '\n',
        'c', 'o', 'u', 'r', 't', 's', '\n',
        'c', 'o', 'u', 'r', 't', 's', 'h', 'i', 'p', '\n',
        'c', 'o', 'u', 'r', 't', 's', 'h', 'i', 'p', 's', '\n',
        'c', 'o', 'u', 'r', 't', 'y', 'a', 'r', 'd', '\n',
        'c', 'o', 'u', 'r', 't', 'y', 'a', 'r', 'd', 's', '\n',
        'c', 'o', 'u', 's', 'c', 'o', 'u', 's', '\n',
        'c', 'o', 'u', 's', 'i', 'n', '\n',
        'c', 'o', 'u', 's', 'i', 'n', 'l', 'y', '\n',
        'c', 'o', 'u', 's', 'i', 'n', 's', '\n',
        'c', 'o', 'u', 't', 'h', 'e', 'r', '\n',
        'c', 'o', 'u', 't', 'u', 'r', 'e', '\n',
        'c', 'o', 'u', 't', 'u', 'r', 'i', 'e', 'r', '\n',
        'c', 'o', 'u', 't', 'u', 'r', 'i', 'e', 'r', 's', '\n',
        'c', 'o', 'v', 'a', 'l', 'e', 'n', 't', '\n',
        'c', 'o', 'v', 'a', 'l', 'e', 'n', 't', 'l', 'y', '\n',
        'c', 'o', 'v', 'a', 'r', 'i', 'a', 'n', 'c', 'e', '\n',
        'c', 'o', 'v', 'a', 'r', 'i', 'a', 'n', 'c', 'e', 's', '\n',
        'c', 'o', 'v', 'e', '\n',
        'c', 'o', 'v', 'e', 'n', '\n',
        'c', 'o', 'v', 'e', 'n', 'a', 'n', 't', '\n',
        'c', 'o', 'v', 'e', 'n', 'a', 'n', 't', 'e', 'd', '\n',
        'c', 'o', 'v', 'e', 'n', 'a', 'n', 't', 'e', 'r', 's', '\n',
        'c', 'o', 'v', 'e', 'n', 'a', 'n', 't', 's', '\n',
        'c', 'o', 'v', 'e', 'n', 's', '\n',
        'c', 'o', 'v', 'e', 'r', '\n',
        'c', 'o', 'v', 'e', 'r', 'a', 'g', 'e', '\n',
        'c', 'o', 'v', 'e', 'r', 'a', 'g', 'e', 's', '\n',
        'c', 'o', 'v', 'e', 'r', 'a', 'l', 'l', 's', '\n',
        'c', 'o', 'v', 'e', 'r', 'e', 'd', '\n',
        'c', 'o', 'v', 'e', 'r', 'i', 'n', 'g', '\n',
        'c', 'o', 'v', 'e', 'r', 'i', 'n', 'g', 's', '\n',
        'c', 'o', 'v', 'e', 'r', 'l', 'e', 't', '\n',
        'c', 'o', 'v', 'e', 'r', 'l', 'e', 't', 's', '\n',
        'c', 'o', 'v', 'e', 'r', 's', '\n',
        'c', 'o', 'v', 'e', 'r', 's', 'h', 'e', 'e', 't', '\n',
        'c', 'o', 'v', 'e', 'r', 't', '\n',
        'c', 'o', 'v', 'e', 'r', 't', 'l', 'y', '\n',
        'c', 'o', 'v', 'e', 'r', 't', 's', '\n',
        'c', 'o', 'v', 'e', 'r', 'u', 'p', '\n',
        'c', 'o', 'v', 'e', 'r', 'u', 'p', 's', '\n',
        'c', 'o', 'v', 'e', 's', '\n',
        'c', 'o', 'v', 'e', 't', '\n',
        'c', 'o', 'v', 'e', 't', 'e', 'd', '\n',
        'c', 'o', 'v', 'e', 't', 'i', 'n', 'g', '\n',
        'c', 'o', 'v', 'e', 't', 'o', 'u', 's', '\n',
        'c', 'o', 'v', 'e', 't', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'c', 'o', 'v', 'e', 't', 's', '\n',
        'c', 'o', 'w', '\n',
        'c', 'o', 'w', 'a', 'r', 'd', '\n',
        'c', 'o', 'w', 'a', 'r', 'd', 'i', 'c', 'e', '\n',
        'c', 'o', 'w', 'a', 'r', 'd', 'l', 'y', '\n',
        'c', 'o', 'w', 'a', 'r', 'd', 's', '\n',
        'c', 'o', 'w', 'b', 'o', 'y', '\n',
        'c', 'o', 'w', 'b', 'o', 'y', 's', '\n',
        'c', 'o', 'w', 'e', 'd', '\n',
        'c', 'o', 'w', 'e', 'r', '\n',
        'c', 'o', 'w', 'e', 'r', 'e', 'd', '\n',
        'c', 'o', 'w', 'e', 'r', 'i', 'n', 'g', '\n',
        'c', 'o', 'w', 'e', 'r', 's', '\n',
        'c', 'o', 'w', 'g', 'i', 'r', 'l', '\n',
        'c', 'o', 'w', 'g', 'i', 'r', 'l', 's', '\n',
        'c', 'o', 'w', 'h', 'a', 'n', 'd', '\n',
        'c', 'o', 'w', 'h', 'e', 'r', 'd', '\n',
        'c', 'o', 'w', 'i', 'n', 'g', '\n',
        'c', 'o', 'w', 'l', '\n',
        'c', 'o', 'w', 'l', 'e', 'd', '\n',
        'c', 'o', 'w', 'l', 'i', 'n', 'g', '\n',
        'c', 'o', 'w', 'o', 'r', 'k', 'e', 'r', '\n',
        'c', 'o', 'w', 'o', 'r', 'k', 'e', 'r', 's', '\n',
        'c', 'o', 'w', 'r', 'i', 't', 'e', 'r', '\n',
        'c', 'o', 'w', 'r', 'i', 't', 't', 'e', 'n', '\n',
        'c', 'o', 'w', 's', '\n',
        'c', 'o', 'w', 's', 'h', 'e', 'd', '\n',
        'c', 'o', 'w', 's', 'h', 'e', 'd', 's', '\n',
        'c', 'o', 'w', 's', 'l', 'i', 'p', '\n',
        'c', 'o', 'w', 's', 'l', 'i', 'p', 's', '\n',
        'c', 'o', 'x', '\n',
        'c', 'o', 'x', 'c', 'o', 'm', 'b', '\n',
        'c', 'o', 'x', 'c', 'o', 'm', 'b', 's', '\n',
        'c', 'o', 'x', 'e', 'd', '\n',
        'c', 'o', 'x', 'e', 's', '\n',
        'c', 'o', 'x', 'i', 'n', 'g', '\n',
        'c', 'o', 'x', 's', 'w', 'a', 'i', 'n', '\n',
        'c', 'o', 'y', '\n',
        'c', 'o', 'y', 'l', 'y', '\n',
        'c', 'o', 'y', 'n', 'e', 's', 's', '\n',
        'c', 'o', 'y', 'o', 't', 'e', '\n',
        'c', 'o', 'y', 'o', 't', 'e', 's', '\n',
        'c', 'o', 'z', 'i', 'e', 'r', '\n',
        'c', 'r', 'a', 'b', '\n',
        'c', 'r', 'a', 'b', 'b', 'y', '\n',
        'c', 'r', 'a', 'b', 's', '\n',
        'c', 'r', 'a', 'c', 'k', '\n',
        'c', 'r', 'a', 'c', 'k', 'a', 'b', 'l', 'e', '\n',
        'c', 'r', 'a', 'c', 'k', 'd', 'o', 'w', 'n', '\n',
        'c', 'r', 'a', 'c', 'k', 'd', 'o', 'w', 'n', 's', '\n',
        'c', 'r', 'a', 'c', 'k', 'e', 'd', '\n',
        'c', 'r', 'a', 'c', 'k', 'e', 'r', '\n',
        'c', 'r', 'a', 'c', 'k', 'e', 'r', 's', '\n',
        'c', 'r', 'a', 'c', 'k', 'i', 'n', 'g', '\n',
        'c', 'r', 'a', 'c', 'k', 'l', 'e', '\n',
        'c', 'r', 'a', 'c', 'k', 'l', 'e', 'd', '\n',
        'c', 'r', 'a', 'c', 'k', 'l', 'e', 's', '\n',
        'c', 'r', 'a', 'c', 'k', 'l', 'i', 'n', 'g', '\n',
        'c', 'r', 'a', 'c', 'k', 'l', 'y', '\n',
        'c', 'r', 'a', 'c', 'k', 'p', 'o', 't', '\n',
        'c', 'r', 'a', 'c', 'k', 'p', 'o', 't', 's', '\n',
        'c', 'r', 'a', 'c', 'k', 's', '\n',
        'c', 'r', 'a', 'd', 'l', 'e', '\n',
        'c', 'r', 'a', 'd', 'l', 'e', 'd', '\n',
        'c', 'r', 'a', 'd', 'l', 'e', 's', '\n',
        'c', 'r', 'a', 'd', 'l', 'i', 'n', 'g', '\n',
        'c', 'r', 'a', 'f', 't', '\n',
        'c', 'r', 'a', 'f', 't', 'e', 'd', '\n',
        'c', 'r', 'a', 'f', 't', 'e', 'r', '\n',
        'c', 'r', 'a', 'f', 't', 'i', 'e', 'r', '\n',
        'c', 'r', 'a', 'f', 't', 'i', 'e', 's', 't', '\n',
        'c', 'r', 'a', 'f', 't', 'i', 'l', 'y', '\n',
        'c', 'r', 'a', 'f', 't', 'i', 'n', 'g', '\n',
        'c', 'r', 'a', 'f', 't', 's', '\n',
        'c', 'r', 'a', 'f', 't', 's', 'm', 'a', 'n', '\n',
        'c', 'r', 'a', 'f', 't', 's', 'm', 'a', 'n', 's', 'h', 'i', 'p', '\n',
        'c', 'r', 'a', 'f', 't', 's', 'm', 'e', 'n', '\n',
        'c', 'r', 'a', 'f', 't', 's', 'p', 'e', 'o', 'p', 'l', 'e', '\n',
        'c', 'r', 'a', 'f', 't', 'y', '\n',
        'c', 'r', 'a', 'g', '\n',
        'c', 'r', 'a', 'g', 'g', 'y', '\n',
        'c', 'r', 'a', 'g', 's', '\n',
        'c', 'r', 'a', 'm', '\n',
        'c', 'r', 'a', 'm', 'm', 'e', 'd', '\n',
        'c', 'r', 'a', 'm', 'm', 'e', 'r', '\n',
        'c', 'r', 'a', 'm', 'm', 'i', 'n', 'g', '\n',
        'c', 'r', 'a', 'm', 'p', '\n',
        'c', 'r', 'a', 'm', 'p', 'e', 'd', '\n',
        'c', 'r', 'a', 'm', 'p', 'i', 'n', 'g', '\n',
        'c', 'r', 'a', 'm', 'p', 'o', 'n', '\n',
        'c', 'r', 'a', 'm', 'p', 'o', 'n', 's', '\n',
        'c', 'r', 'a', 'm', 'p', 's', '\n',
        'c', 'r', 'a', 'm', 's', '\n',
        'c', 'r', 'a', 'n', '\n',
        'c', 'r', 'a', 'n', 'b', 'e', 'r', 'r', 'i', 'e', 's', '\n',
        'c', 'r', 'a', 'n', 'b', 'e', 'r', 'r', 'y', '\n',
        'c', 'r', 'a', 'n', 'e', '\n',
        'c', 'r', 'a', 'n', 'e', 'd', '\n',
        'c', 'r', 'a', 'n', 'e', 's', '\n',
        'c', 'r', 'a', 'n', 'i', 'a', 'l', '\n',
        'c', 'r', 'a', 'n', 'i', 'n', 'g', '\n',
        'c', 'r', 'a', 'n', 'i', 'u', 'm', '\n',
        'c', 'r', 'a', 'n', 'k', '\n',
        'c', 'r', 'a', 'n', 'k', 'e', 'd', '\n',
        'c', 'r', 'a', 'n', 'k', 'i', 'n', 'g', '\n',
        'c', 'r', 'a', 'n', 'k', 's', '\n',
        'c', 'r', 'a', 'n', 'k', 's', 'h', 'a', 'f', 't', '\n',
        'c', 'r', 'a', 'n', 'k', 'y', '\n',
        'c', 'r', 'a', 'n', 'n', 'i', 'e', 's', '\n',
        'c', 'r', 'a', 'n', 'n', 'y', '\n',
        'c', 'r', 'a', 'p', '\n',
        'c', 'r', 'a', 's', 'h', '\n',
        'c', 'r', 'a', 's', 'h', 'e', 'd', '\n',
        'c', 'r', 'a', 's', 'h', 'e', 'r', '\n',
        'c', 'r', 'a', 's', 'h', 'e', 'r', 's', '\n',
        'c', 'r', 'a', 's', 'h', 'e', 's', '\n',
        'c', 'r', 'a', 's', 'h', 'i', 'n', 'g', '\n',
        'c', 'r', 'a', 's', 'h', 'i', 'n', 'g', 'l', 'y', '\n',
        'c', 'r', 'a', 's', 'h', 'l', 'a', 'n', 'd', '\n',
        'c', 'r', 'a', 's', 'h', 'l', 'a', 'n', 'd', 'e', 'd', '\n',
        'c', 'r', 'a', 's', 'h', 'l', 'a', 'n', 'd', 'i', 'n', 'g', '\n',
        'c', 'r', 'a', 's', 's', '\n',
        'c', 'r', 'a', 's', 's', 'e', 'r', '\n',
        'c', 'r', 'a', 's', 's', 'l', 'y', '\n',
        'c', 'r', 'a', 's', 's', 'n', 'e', 's', 's', '\n',
        'c', 'r', 'a', 't', 'e', '\n',
        'c', 'r', 'a', 't', 'e', 'f', 'u', 'l', '\n',
        'c', 'r', 'a', 't', 'e', 'r', '\n',
        'c', 'r', 'a', 't', 'e', 'r', 'e', 'd', '\n',
        'c', 'r', 'a', 't', 'e', 'r', 's', '\n',
        'c', 'r', 'a', 't', 'e', 's', '\n',
        'c', 'r', 'a', 'v', 'a', 't', '\n',
        'c', 'r', 'a', 'v', 'a', 't', 's', '\n',
        'c', 'r', 'a', 'v', 'e', '\n',
        'c', 'r', 'a', 'v', 'e', 'd', '\n',
        'c', 'r', 'a', 'v', 'e', 'n', '\n',
        'c', 'r', 'a', 'v', 'e', 'n', 'l', 'y', '\n',
        'c', 'r', 'a', 'v', 'e', 's', '\n',
        'c', 'r', 'a', 'v', 'i', 'n', 'g', '\n',
        'c', 'r', 'a', 'v', 'i', 'n', 'g', 's', '\n',
        'c', 'r', 'a', 'w', 'l', '\n',
        'c', 'r', 'a', 'w', 'l', 'e', 'd', '\n',
        'c', 'r', 'a', 'w', 'l', 'e', 'r', '\n',
        'c', 'r', 'a', 'w', 'l', 'e', 'r', 's', '\n',
        'c', 'r', 'a', 'w', 'l', 'i', 'n', 'g', '\n',
        'c', 'r', 'a', 'w', 'l', 's', '\n',
        'c', 'r', 'a', 'w', 's', '\n',
        'c', 'r', 'a', 'y', 'f', 'i', 's', 'h', '\n',
        'c', 'r', 'a', 'y', 'o', 'n', '\n',
        'c', 'r', 'a', 'y', 'o', 'n', 'e', 'd', '\n',
        'c', 'r', 'a', 'y', 'o', 'n', 's', '\n',
        'c', 'r', 'a', 'z', 'e', '\n',
        'c', 'r', 'a', 'z', 'e', 'd', '\n',
        'c', 'r', 'a', 'z', 'e', 's', '\n',
        'c', 'r', 'a', 'z', 'i', 'e', 'r', '\n',
        'c', 'r', 'a', 'z', 'i', 'e', 's', 't', '\n',
        'c', 'r', 'a', 'z', 'i', 'l', 'y', '\n',
        'c', 'r', 'a', 'z', 'i', 'n', 'e', 's', 's', '\n',
        'c', 'r', 'a', 'z', 'y', '\n',
        'c', 'r', 'e', 'a', 'k', '\n',
        'c', 'r', 'e', 'a', 'k', 'e', 'd', '\n',
        'c', 'r', 'e', 'a', 'k', 'i', 'e', 'r', '\n',
        'c', 'r', 'e', 'a', 'k', 'i', 'e', 's', 't', '\n',
        'c', 'r', 'e', 'a', 'k', 'i', 'n', 'g', '\n',
        'c', 'r', 'e', 'a', 'k', 's', '\n',
        'c', 'r', 'e', 'a', 'k', 'y', '\n',
        'c', 'r', 'e', 'a', 'm', '\n',
        'c', 'r', 'e', 'a', 'm', 'e', 'd', '\n',
        'c', 'r', 'e', 'a', 'm', 'e', 'r', '\n',
        'c', 'r', 'e', 'a', 'm', 'e', 'r', 'y', '\n',
        'c', 'r', 'e', 'a', 'm', 'i', 'e', 'r', '\n',
        'c', 'r', 'e', 'a', 'm', 'i', 'e', 's', 't', '\n',
        'c', 'r', 'e', 'a', 'm', 'i', 'n', 'g', '\n',
        'c', 'r', 'e', 'a', 'm', 's', '\n',
        'c', 'r', 'e', 'a', 'm', 'y', '\n',
        'c', 'r', 'e', 'a', 's', 'e', '\n',
        'c', 'r', 'e', 'a', 's', 'e', 'd', '\n',
        'c', 'r', 'e', 'a', 's', 'e', 's', '\n',
        'c', 'r', 'e', 'a', 's', 'i', 'n', 'g', '\n',
        'c', 'r', 'e', 'a', 't', 'a', 'b', 'l', 'e', '\n',
        'c', 'r', 'e', 'a', 't', 'e', '\n',
        'c', 'r', 'e', 'a', 't', 'e', 'd', '\n',
        'c', 'r', 'e', 'a', 't', 'e', 's', '\n',
        'c', 'r', 'e', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'r', 'e', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'r', 'e', 'a', 't', 'i', 'o', 'n', 'i', 's', 'm', '\n',
        'c', 'r', 'e', 'a', 't', 'i', 'o', 'n', 'i', 's', 't', '\n',
        'c', 'r', 'e', 'a', 't', 'i', 'o', 'n', 'i', 's', 't', 's', '\n',
        'c', 'r', 'e', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'r', 'e', 'a', 't', 'i', 'v', 'e', '\n',
        'c', 'r', 'e', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'c', 'r', 'e', 'a', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'c', 'r', 'e', 'a', 't', 'i', 'v', 'i', 't', 'y', '\n',
        'c', 'r', 'e', 'a', 't', 'o', 'r', '\n',
        'c', 'r', 'e', 'a', 't', 'o', 'r', 's', '\n',
        'c', 'r', 'e', 'a', 't', 'u', 'r', 'e', '\n',
        'c', 'r', 'e', 'a', 't', 'u', 'r', 'e', 's', '\n',
        'c', 'r', 'e', 'c', 'h', 'e', '\n',
        'c', 'r', 'e', 'c', 'h', 'e', 's', '\n',
        'c', 'r', 'e', 'd', 'e', 'n', 'c', 'e', '\n',
        'c', 'r', 'e', 'd', 'e', 'n', 't', 'i', 'a', 'l', 's', '\n',
        'c', 'r', 'e', 'd', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'c', 'r', 'e', 'd', 'i', 'b', 'l', 'e', '\n',
        'c', 'r', 'e', 'd', 'i', 'b', 'l', 'y', '\n',
        'c', 'r', 'e', 'd', 'i', 't', '\n',
        'c', 'r', 'e', 'd', 'i', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'c', 'r', 'e', 'd', 'i', 't', 'a', 'b', 'l', 'e', '\n',
        'c', 'r', 'e', 'd', 'i', 't', 'a', 'b', 'l', 'y', '\n',
        'c', 'r', 'e', 'd', 'i', 't', 'e', 'd', '\n',
        'c', 'r', 'e', 'd', 'i', 't', 'i', 'n', 'g', '\n',
        'c', 'r', 'e', 'd', 'i', 't', 'o', 'r', '\n',
        'c', 'r', 'e', 'd', 'i', 't', 'o', 'r', 's', '\n',
        'c', 'r', 'e', 'd', 'i', 't', 's', '\n',
        'c', 'r', 'e', 'd', 'i', 't', 'w', 'o', 'r', 't', 'h', 'i', 'n', 'e', 's', 's', '\n',
        'c', 'r', 'e', 'd', 'i', 't', 'w', 'o', 'r', 't', 'h', 'y', '\n',
        'c', 'r', 'e', 'd', 'o', '\n',
        'c', 'r', 'e', 'd', 'u', 'l', 'i', 't', 'y', '\n',
        'c', 'r', 'e', 'd', 'u', 'l', 'o', 'u', 's', '\n',
        'c', 'r', 'e', 'e', 'd', '\n',
        'c', 'r', 'e', 'e', 'd', 's', '\n',
        'c', 'r', 'e', 'e', 'k', '\n',
        'c', 'r', 'e', 'e', 'k', 's', '\n',
        'c', 'r', 'e', 'e', 'l', '\n',
        'c', 'r', 'e', 'e', 'p', '\n',
        'c', 'r', 'e', 'e', 'p', 'e', 'r', '\n',
        'c', 'r', 'e', 'e', 'p', 'e', 'r', 's', '\n',
        'c', 'r', 'e', 'e', 'p', 'i', 'n', 'g', '\n',
        'c', 'r', 'e', 'e', 'p', 's', '\n',
        'c', 'r', 'e', 'e', 'p', 'y', '\n',
        'c', 'r', 'e', 'm', 'a', 't', 'e', '\n',
        'c', 'r', 'e', 'm', 'a', 't', 'e', 'd', '\n',
        'c', 'r', 'e', 'm', 'a', 't', 'e', 's', '\n',
        'c', 'r', 'e', 'm', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'r', 'e', 'm', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'r', 'e', 'm', 'a', 't', 'o', 'r', 'i', 'a', '\n',
        'c', 'r', 'e', 'm', 'a', 't', 'o', 'r', 'i', 'u', 'm', '\n',
        'c', 'r', 'e', 'm', 'e', '\n',
        'c', 'r', 'e', 'n', 'e', 'l', 'l', 'a', 't', 'e', 'd', '\n',
        'c', 'r', 'e', 'n', 'e', 'l', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'r', 'e', 'n', 'e', 'l', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'r', 'e', 'o', 'l', 'e', '\n',
        'c', 'r', 'e', 'o', 'l', 'e', 's', '\n',
        'c', 'r', 'e', 'o', 's', 'o', 't', 'e', '\n',
        'c', 'r', 'e', 'p', 'e', '\n',
        'c', 'r', 'e', 'p', 't', '\n',
        'c', 'r', 'e', 'p', 'u', 's', 'c', 'u', 'l', 'a', 'r', '\n',
        'c', 'r', 'e', 's', 'c', 'e', 'n', 'd', 'o', '\n',
        'c', 'r', 'e', 's', 'c', 'e', 'n', 't', '\n',
        'c', 'r', 'e', 's', 'c', 'e', 'n', 't', 's', '\n',
        'c', 'r', 'e', 's', 's', '\n',
        'c', 'r', 'e', 's', 't', '\n',
        'c', 'r', 'e', 's', 't', 'e', 'd', '\n',
        'c', 'r', 'e', 's', 't', 'f', 'a', 'l', 'l', 'e', 'n', '\n',
        'c', 'r', 'e', 's', 't', 'i', 'n', 'g', '\n',
        'c', 'r', 'e', 's', 't', 's', '\n',
        'c', 'r', 'e', 't', 'a', 'c', 'e', 'o', 'u', 's', '\n',
        'c', 'r', 'e', 't', 'a', 'n', '\n',
        'c', 'r', 'e', 't', 'a', 'n', 's', '\n',
        'c', 'r', 'e', 't', 'e', '\n',
        'c', 'r', 'e', 't', 'i', 'n', '\n',
        'c', 'r', 'e', 't', 'i', 'n', 'o', 'u', 's', '\n',
        'c', 'r', 'e', 't', 'i', 'n', 's', '\n',
        'c', 'r', 'e', 'v', 'a', 's', 's', 'e', '\n',
        'c', 'r', 'e', 'v', 'a', 's', 's', 'e', 's', '\n',
        'c', 'r', 'e', 'v', 'i', 'c', 'e', '\n',
        'c', 'r', 'e', 'v', 'i', 'c', 'e', 's', '\n',
        'c', 'r', 'e', 'w', '\n',
        'c', 'r', 'e', 'w', 'e', 'd', '\n',
        'c', 'r', 'e', 'w', 'i', 'n', 'g', '\n',
        'c', 'r', 'e', 'w', 'm', 'a', 'n', '\n',
        'c', 'r', 'e', 'w', 'm', 'e', 'n', '\n',
        'c', 'r', 'e', 'w', 's', '\n',
        'c', 'r', 'i', 'b', '\n',
        'c', 'r', 'i', 'b', 'b', 'a', 'g', 'e', '\n',
        'c', 'r', 'i', 'b', 'b', 'e', 'd', '\n',
        'c', 'r', 'i', 'b', 'b', 'i', 'n', 'g', '\n',
        'c', 'r', 'i', 'b', 's', '\n',
        'c', 'r', 'i', 'c', 'k', '\n',
        'c', 'r', 'i', 'c', 'k', 'e', 't', '\n',
        'c', 'r', 'i', 'c', 'k', 'e', 't', 'e', 'r', '\n',
        'c', 'r', 'i', 'c', 'k', 'e', 't', 'e', 'r', 's', '\n',
        'c', 'r', 'i', 'c', 'k', 'e', 't', 'i', 'n', 'g', '\n',
        'c', 'r', 'i', 'c', 'k', 'e', 't', 's', '\n',
        'c', 'r', 'i', 'e', 'd', '\n',
        'c', 'r', 'i', 'e', 'r', '\n',
        'c', 'r', 'i', 'e', 's', '\n',
        'c', 'r', 'i', 'm', '\n',
        'c', 'r', 'i', 'm', 'e', '\n',
        'c', 'r', 'i', 'm', 'e', 'a', '\n',
        'c', 'r', 'i', 'm', 'e', 's', '\n',
        'c', 'r', 'i', 'm', 'i', 'n', 'a', 'l', '\n',
        'c', 'r', 'i', 'm', 'i', 'n', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'r', 'i', 'm', 'i', 'n', 'a', 'l', 'i', 's', 'e', '\n',
        'c', 'r', 'i', 'm', 'i', 'n', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'c', 'r', 'i', 'm', 'i', 'n', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'c', 'r', 'i', 'm', 'i', 'n', 'a', 'l', 'i', 't', 'y', '\n',
        'c', 'r', 'i', 'm', 'i', 'n', 'a', 'l', 'l', 'y', '\n',
        'c', 'r', 'i', 'm', 'i', 'n', 'a', 'l', 's', '\n',
        'c', 'r', 'i', 'm', 'i', 'n', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'c', 'r', 'i', 'm', 'i', 'n', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'c', 'r', 'i', 'm', 'i', 'n', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'c', 'r', 'i', 'm', 'i', 'n', 'o', 'l', 'o', 'g', 'y', '\n',
        'c', 'r', 'i', 'm', 'p', '\n',
        'c', 'r', 'i', 'm', 'p', 'e', 'd', '\n',
        'c', 'r', 'i', 'm', 'p', 'i', 'n', 'g', '\n',
        'c', 'r', 'i', 'm', 's', 'o', 'n', '\n',
        'c', 'r', 'i', 'n', 'g', 'e', '\n',
        'c', 'r', 'i', 'n', 'g', 'e', 'd', '\n',
        'c', 'r', 'i', 'n', 'g', 'e', 's', '\n',
        'c', 'r', 'i', 'n', 'g', 'i', 'n', 'g', '\n',
        'c', 'r', 'i', 'n', 'k', 'l', 'e', '\n',
        'c', 'r', 'i', 'n', 'k', 'l', 'e', 'd', '\n',
        'c', 'r', 'i', 'n', 'k', 'l', 'i', 'n', 'g', '\n',
        'c', 'r', 'i', 'n', 'k', 'l', 'y', '\n',
        'c', 'r', 'i', 'n', 'o', 'l', 'i', 'n', 'e', '\n',
        'c', 'r', 'i', 'p', 'p', 'l', 'e', '\n',
        'c', 'r', 'i', 'p', 'p', 'l', 'e', 'd', '\n',
        'c', 'r', 'i', 'p', 'p', 'l', 'e', 's', '\n',
        'c', 'r', 'i', 'p', 'p', 'l', 'i', 'n', 'g', '\n',
        'c', 'r', 'i', 'p', 'p', 'l', 'i', 'n', 'g', 'l', 'y', '\n',
        'c', 'r', 'i', 's', 'e', 's', '\n',
        'c', 'r', 'i', 's', 'i', 's', '\n',
        'c', 'r', 'i', 's', 'p', '\n',
        'c', 'r', 'i', 's', 'p', 'e', 'd', '\n',
        'c', 'r', 'i', 's', 'p', 'e', 'r', '\n',
        'c', 'r', 'i', 's', 'p', 'i', 'e', 'r', '\n',
        'c', 'r', 'i', 's', 'p', 'i', 'e', 's', 't', '\n',
        'c', 'r', 'i', 's', 'p', 'l', 'y', '\n',
        'c', 'r', 'i', 's', 'p', 'n', 'e', 's', 's', '\n',
        'c', 'r', 'i', 's', 'p', 's', '\n',
        'c', 'r', 'i', 's', 'p', 'y', '\n',
        'c', 'r', 'i', 's', 's', 'c', 'r', 'o', 's', 's', 'e', 'd', '\n',
        'c', 'r', 'i', 's', 's', 'c', 'r', 'o', 's', 's', 'e', 's', '\n',
        'c', 'r', 'i', 't', 'e', 'r', 'i', 'a', '\n',
        'c', 'r', 'i', 't', 'e', 'r', 'i', 'o', 'n', '\n',
        'c', 'r', 'i', 't', 'i', 'c', '\n',
        'c', 'r', 'i', 't', 'i', 'c', 'a', 'l', '\n',
        'c', 'r', 'i', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'c', 'r', 'i', 't', 'i', 'c', 'i', 's', 'e', '\n',
        'c', 'r', 'i', 't', 'i', 'c', 'i', 's', 'e', 'd', '\n',
        'c', 'r', 'i', 't', 'i', 'c', 'i', 's', 'e', 's', '\n',
        'c', 'r', 'i', 't', 'i', 'c', 'i', 's', 'i', 'n', 'g', '\n',
        'c', 'r', 'i', 't', 'i', 'c', 'i', 's', 'm', '\n',
        'c', 'r', 'i', 't', 'i', 'c', 'i', 's', 'm', 's', '\n',
        'c', 'r', 'i', 't', 'i', 'c', 's', '\n',
        'c', 'r', 'i', 't', 'i', 'q', 'u', 'e', '\n',
        'c', 'r', 'i', 't', 'i', 'q', 'u', 'e', 's', '\n',
        'c', 'r', 'i', 't', 't', 'e', 'r', '\n',
        'c', 'r', 'o', 'a', 'k', '\n',
        'c', 'r', 'o', 'a', 'k', 'e', 'd', '\n',
        'c', 'r', 'o', 'a', 'k', 'i', 'e', 'r', '\n',
        'c', 'r', 'o', 'a', 'k', 'i', 'e', 's', 't', '\n',
        'c', 'r', 'o', 'a', 'k', 'i', 'n', 'g', '\n',
        'c', 'r', 'o', 'a', 'k', 's', '\n',
        'c', 'r', 'o', 'a', 't', 'i', 'a', '\n',
        'c', 'r', 'o', 'a', 't', 'i', 'a', 'n', '\n',
        'c', 'r', 'o', 'c', 'h', 'e', 't', '\n',
        'c', 'r', 'o', 'c', 'h', 'e', 't', 'e', 'd', '\n',
        'c', 'r', 'o', 'c', 'h', 'e', 't', 's', '\n',
        'c', 'r', 'o', 'c', 'k', '\n',
        'c', 'r', 'o', 'c', 'k', 'e', 'r', 'y', '\n',
        'c', 'r', 'o', 'c', 'k', 's', '\n',
        'c', 'r', 'o', 'c', 'o', 'd', 'i', 'l', 'e', '\n',
        'c', 'r', 'o', 'c', 'o', 'd', 'i', 'l', 'e', 's', '\n',
        'c', 'r', 'o', 'c', 'u', 's', '\n',
        'c', 'r', 'o', 'c', 'u', 's', 'e', 's', '\n',
        'c', 'r', 'o', 'f', 't', '\n',
        'c', 'r', 'o', 'f', 't', 'e', 'r', '\n',
        'c', 'r', 'o', 'f', 't', 'e', 'r', 's', '\n',
        'c', 'r', 'o', 'f', 't', 'i', 'n', 'g', '\n',
        'c', 'r', 'o', 'f', 't', 's', '\n',
        'c', 'r', 'o', 'i', 's', 's', 'a', 'n', 't', '\n',
        'c', 'r', 'o', 'i', 's', 's', 'a', 'n', 't', 's', '\n',
        'c', 'r', 'o', 'n', 'e', '\n',
        'c', 'r', 'o', 'n', 'e', 's', '\n',
        'c', 'r', 'o', 'n', 'i', 'e', 's', '\n',
        'c', 'r', 'o', 'n', 'y', '\n',
        'c', 'r', 'o', 'o', 'k', '\n',
        'c', 'r', 'o', 'o', 'k', 'e', 'd', '\n',
        'c', 'r', 'o', 'o', 'k', 'e', 'd', 'l', 'y', '\n',
        'c', 'r', 'o', 'o', 'k', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'c', 'r', 'o', 'o', 'k', 'i', 'n', 'g', '\n',
        'c', 'r', 'o', 'o', 'k', 's', '\n',
        'c', 'r', 'o', 'o', 'n', '\n',
        'c', 'r', 'o', 'o', 'n', 'e', 'd', '\n',
        'c', 'r', 'o', 'o', 'n', 'e', 'r', '\n',
        'c', 'r', 'o', 'o', 'n', 'e', 'r', 's', '\n',
        'c', 'r', 'o', 'o', 'n', 'i', 'n', 'g', '\n',
        'c', 'r', 'o', 'o', 'n', 's', '\n',
        'c', 'r', 'o', 'p', '\n',
        'c', 'r', 'o', 'p', 'p', 'e', 'd', '\n',
        'c', 'r', 'o', 'p', 'p', 'e', 'r', '\n',
        'c', 'r', 'o', 'p', 'p', 'e', 'r', 's', '\n',
        'c', 'r', 'o', 'p', 'p', 'i', 'n', 'g', '\n',
        'c', 'r', 'o', 'p', 's', '\n',
        'c', 'r', 'o', 'q', 'u', 'e', 't', '\n',
        'c', 'r', 'o', 'q', 'u', 'e', 't', 'e', 'd', '\n',
        'c', 'r', 'o', 'q', 'u', 'e', 't', 'i', 'n', 'g', '\n',
        'c', 'r', 'o', 'q', 'u', 'e', 't', 't', 'e', '\n',
        'c', 'r', 'o', 'r', 'e', 's', '\n',
        'c', 'r', 'o', 's', 'i', 'e', 'r', '\n',
        'c', 'r', 'o', 's', 'i', 'e', 'r', 's', '\n',
        'c', 'r', 'o', 's', 's', '\n',
        'c', 'r', 'o', 's', 's', '-', 'b', 'u', 'n', '\n',
        'c', 'r', 'o', 's', 's', 'b', 'a', 'r', '\n',
        'c', 'r', 'o', 's', 's', 'b', 'a', 'r', 's', '\n',
        'c', 'r', 'o', 's', 's', 'b', 'o', 'n', 'e', 's', '\n',
        'c', 'r', 'o', 's', 's', 'b', 'o', 'w', '\n',
        'c', 'r', 'o', 's', 's', 'b', 'o', 'w', 's', '\n',
        'c', 'r', 'o', 's', 's', 'b', 'r', 'e', 'd', '\n',
        'c', 'r', 'o', 's', 's', 'c', 'h', 'e', 'c', 'k', '\n',
        'c', 'r', 'o', 's', 's', 'c', 'h', 'e', 'c', 'k', 'e', 'd', '\n',
        'c', 'r', 'o', 's', 's', 'c', 'h', 'e', 'c', 'k', 'i', 'n', 'g', '\n',
        'c', 'r', 'o', 's', 's', 'c', 'h', 'e', 'c', 'k', 's', '\n',
        'c', 'r', 'o', 's', 's', 'c', 'o', 'u', 'n', 't', 'r', 'y', '\n',
        'c', 'r', 'o', 's', 's', 'e', 'd', '\n',
        'c', 'r', 'o', 's', 's', 'e', 'r', '\n',
        'c', 'r', 'o', 's', 's', 'e', 's', '\n',
        'c', 'r', 'o', 's', 's', 'e', 'x', 'a', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'r', 'o', 's', 's', 'e', 'x', 'a', 'm', 'i', 'n', 'e', '\n',
        'c', 'r', 'o', 's', 's', 'e', 'x', 'a', 'm', 'i', 'n', 'e', 'd', '\n',
        'c', 'r', 'o', 's', 's', 'e', 'x', 'a', 'm', 'i', 'n', 'e', 's', '\n',
        'c', 'r', 'o', 's', 's', 'e', 'x', 'a', 'm', 'i', 'n', 'i', 'n', 'g', '\n',
        'c', 'r', 'o', 's', 's', 'f', 'e', 'r', 't', 'i', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'r', 'o', 's', 's', 'f', 'i', 'r', 'e', '\n',
        'c', 'r', 'o', 's', 's', 'i', 'n', 'g', '\n',
        'c', 'r', 'o', 's', 's', 'i', 'n', 'g', 's', '\n',
        'c', 'r', 'o', 's', 's', 'l', 'y', '\n',
        'c', 'r', 'o', 's', 's', 'n', 'e', 's', 's', '\n',
        'c', 'r', 'o', 's', 's', 'o', 'v', 'e', 'r', '\n',
        'c', 'r', 'o', 's', 's', 'o', 'v', 'e', 'r', 's', '\n',
        'c', 'r', 'o', 's', 's', 'r', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'e', '\n',
        'c', 'r', 'o', 's', 's', 'r', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 'd', '\n',
        'c', 'r', 'o', 's', 's', 'r', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 's', '\n',
        'c', 'r', 'o', 's', 's', 'r', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'i', 'n', 'g', '\n',
        'c', 'r', 'o', 's', 's', 'r', 'o', 'a', 'd', 's', '\n',
        'c', 'r', 'o', 's', 's', 's', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'c', 'r', 'o', 's', 's', 's', 'e', 'c', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'c', 'r', 'o', 's', 's', 's', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'r', 'o', 's', 's', 't', 'a', 'l', 'k', '\n',
        'c', 'r', 'o', 's', 's', 'w', 'a', 'y', 's', '\n',
        'c', 'r', 'o', 's', 's', 'w', 'i', 'n', 'd', '\n',
        'c', 'r', 'o', 's', 's', 'w', 'i', 'n', 'd', 's', '\n',
        'c', 'r', 'o', 's', 's', 'w', 'o', 'r', 'd', '\n',
        'c', 'r', 'o', 's', 's', 'w', 'o', 'r', 'd', 's', '\n',
        'c', 'r', 'o', 't', 'c', 'h', '\n',
        'c', 'r', 'o', 't', 'c', 'h', 'e', 't', '\n',
        'c', 'r', 'o', 't', 'c', 'h', 'e', 't', 'i', 'n', 'e', 's', 's', '\n',
        'c', 'r', 'o', 't', 'c', 'h', 'e', 't', 'y', '\n',
        'c', 'r', 'o', 't', 'c', 'h', 'l', 'e', 's', 's', '\n',
        'c', 'r', 'o', 'u', 'c', 'h', '\n',
        'c', 'r', 'o', 'u', 'c', 'h', 'e', 'd', '\n',
        'c', 'r', 'o', 'u', 'c', 'h', 'e', 's', '\n',
        'c', 'r', 'o', 'u', 'c', 'h', 'i', 'n', 'g', '\n',
        'c', 'r', 'o', 'u', 'p', '\n',
        'c', 'r', 'o', 'u', 'p', 'i', 'e', 'r', '\n',
        'c', 'r', 'o', 'u', 't', 'o', 'n', 's', '\n',
        'c', 'r', 'o', 'w', '\n',
        'c', 'r', 'o', 'w', 'b', 'a', 'r', '\n',
        'c', 'r', 'o', 'w', 'b', 'a', 'r', 's', '\n',
        'c', 'r', 'o', 'w', 'd', '\n',
        'c', 'r', 'o', 'w', 'd', 'e', 'd', '\n',
        'c', 'r', 'o', 'w', 'd', 'i', 'n', 'g', '\n',
        'c', 'r', 'o', 'w', 'd', 's', '\n',
        'c', 'r', 'o', 'w', 'e', 'd', '\n',
        'c', 'r', 'o', 'w', 'i', 'n', 'g', '\n',
        'c', 'r', 'o', 'w', 'n', '\n',
        'c', 'r', 'o', 'w', 'n', 'e', 'd', '\n',
        'c', 'r', 'o', 'w', 'n', 'i', 'n', 'g', '\n',
        'c', 'r', 'o', 'w', 'n', 's', '\n',
        'c', 'r', 'o', 'w', 's', '\n',
        'c', 'r', 'o', 'z', 'i', 'e', 'r', '\n',
        'c', 'r', 'o', 'z', 'i', 'e', 'r', 's', '\n',
        'c', 'r', 'u', 'c', 'i', 'a', 'l', '\n',
        'c', 'r', 'u', 'c', 'i', 'a', 'l', 'l', 'y', '\n',
        'c', 'r', 'u', 'c', 'i', 'a', 't', 'e', '\n',
        'c', 'r', 'u', 'c', 'i', 'b', 'l', 'e', '\n',
        'c', 'r', 'u', 'c', 'i', 'b', 'l', 'e', 's', '\n',
        'c', 'r', 'u', 'c', 'i', 'f', 'i', 'a', 'b', 'l', 'e', '\n',
        'c', 'r', 'u', 'c', 'i', 'f', 'i', 'e', 'd', '\n',
        'c', 'r', 'u', 'c', 'i', 'f', 'i', 'x', '\n',
        'c', 'r', 'u', 'c', 'i', 'f', 'i', 'x', 'e', 's', '\n',
        'c', 'r', 'u', 'c', 'i', 'f', 'i', 'x', 'i', 'o', 'n', '\n',
        'c', 'r', 'u', 'c', 'i', 'f', 'i', 'x', 'i', 'o', 'n', 's', '\n',
        'c', 'r', 'u', 'c', 'i', 'f', 'o', 'r', 'm', '\n',
        'c', 'r', 'u', 'c', 'i', 'f', 'y', '\n',
        'c', 'r', 'u', 'c', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'c', 'r', 'u', 'd', 'e', '\n',
        'c', 'r', 'u', 'd', 'e', 'l', 'y', '\n',
        'c', 'r', 'u', 'd', 'e', 'n', 'e', 's', 's', '\n',
        'c', 'r', 'u', 'd', 'e', 'r', '\n',
        'c', 'r', 'u', 'd', 'e', 's', 't', '\n',
        'c', 'r', 'u', 'd', 'i', 't', 'i', 'e', 's', '\n',
        'c', 'r', 'u', 'd', 'i', 't', 'y', '\n',
        'c', 'r', 'u', 'e', 'l', '\n',
        'c', 'r', 'u', 'e', 'l', 'e', 'r', '\n',
        'c', 'r', 'u', 'e', 'l', 'e', 's', 't', '\n',
        'c', 'r', 'u', 'e', 'l', 'l', 'e', 'r', '\n',
        'c', 'r', 'u', 'e', 'l', 'l', 'e', 's', 't', '\n',
        'c', 'r', 'u', 'e', 'l', 'l', 'y', '\n',
        'c', 'r', 'u', 'e', 'l', 'n', 'e', 's', 's', '\n',
        'c', 'r', 'u', 'e', 'l', 't', 'i', 'e', 's', '\n',
        'c', 'r', 'u', 'e', 'l', 't', 'y', '\n',
        'c', 'r', 'u', 'i', 's', 'e', '\n',
        'c', 'r', 'u', 'i', 's', 'e', 'd', '\n',
        'c', 'r', 'u', 'i', 's', 'e', 'r', '\n',
        'c', 'r', 'u', 'i', 's', 'e', 'r', 's', '\n',
        'c', 'r', 'u', 'i', 's', 'e', 's', '\n',
        'c', 'r', 'u', 'i', 's', 'i', 'n', 'g', '\n',
        'c', 'r', 'u', 'l', 'l', 'e', 'r', '\n',
        'c', 'r', 'u', 'm', 'b', '\n',
        'c', 'r', 'u', 'm', 'b', 'i', 'n', 'g', '\n',
        'c', 'r', 'u', 'm', 'b', 'l', 'e', '\n',
        'c', 'r', 'u', 'm', 'b', 'l', 'e', 'd', '\n',
        'c', 'r', 'u', 'm', 'b', 'l', 'e', 's', '\n',
        'c', 'r', 'u', 'm', 'b', 'l', 'i', 'e', 'r', '\n',
        'c', 'r', 'u', 'm', 'b', 'l', 'i', 'e', 's', 't', '\n',
        'c', 'r', 'u', 'm', 'b', 'l', 'i', 'n', 'g', '\n',
        'c', 'r', 'u', 'm', 'b', 'l', 'y', '\n',
        'c', 'r', 'u', 'm', 'b', 's', '\n',
        'c', 'r', 'u', 'm', 'b', 'y', '\n',
        'c', 'r', 'u', 'm', 'm', 'y', '\n',
        'c', 'r', 'u', 'm', 'p', 'e', 't', '\n',
        'c', 'r', 'u', 'm', 'p', 'e', 't', 's', '\n',
        'c', 'r', 'u', 'm', 'p', 'l', 'e', '\n',
        'c', 'r', 'u', 'm', 'p', 'l', 'e', 'd', '\n',
        'c', 'r', 'u', 'm', 'p', 'l', 'e', 's', '\n',
        'c', 'r', 'u', 'm', 'p', 'l', 'i', 'n', 'g', '\n',
        'c', 'r', 'u', 'n', 'c', 'h', '\n',
        'c', 'r', 'u', 'n', 'c', 'h', 'e', 'd', '\n',
        'c', 'r', 'u', 'n', 'c', 'h', 'e', 'r', '\n',
        'c', 'r', 'u', 'n', 'c', 'h', 'e', 'r', 's', '\n',
        'c', 'r', 'u', 'n', 'c', 'h', 'e', 's', '\n',
        'c', 'r', 'u', 'n', 'c', 'h', 'i', 'e', 'r', '\n',
        'c', 'r', 'u', 'n', 'c', 'h', 'i', 'e', 's', 't', '\n',
        'c', 'r', 'u', 'n', 'c', 'h', 'i', 'n', 'g', '\n',
        'c', 'r', 'u', 'n', 'c', 'h', 'y', '\n',
        'c', 'r', 'u', 's', 'a', 'd', 'e', '\n',
        'c', 'r', 'u', 's', 'a', 'd', 'e', 'd', '\n',
        'c', 'r', 'u', 's', 'a', 'd', 'e', 'r', '\n',
        'c', 'r', 'u', 's', 'a', 'd', 'e', 'r', 's', '\n',
        'c', 'r', 'u', 's', 'a', 'd', 'e', 's', '\n',
        'c', 'r', 'u', 's', 'a', 'd', 'i', 'n', 'g', '\n',
        'c', 'r', 'u', 's', 'h', '\n',
        'c', 'r', 'u', 's', 'h', 'e', 'd', '\n',
        'c', 'r', 'u', 's', 'h', 'e', 'r', '\n',
        'c', 'r', 'u', 's', 'h', 'e', 'r', 's', '\n',
        'c', 'r', 'u', 's', 'h', 'e', 's', '\n',
        'c', 'r', 'u', 's', 'h', 'i', 'n', 'g', '\n',
        'c', 'r', 'u', 's', 'h', 'i', 'n', 'g', 'l', 'y', '\n',
        'c', 'r', 'u', 's', 't', '\n',
        'c', 'r', 'u', 's', 't', 'a', 'c', 'e', 'a', 'n', '\n',
        'c', 'r', 'u', 's', 't', 'a', 'c', 'e', 'a', 'n', 's', '\n',
        'c', 'r', 'u', 's', 't', 'a', 'l', '\n',
        'c', 'r', 'u', 's', 't', 'e', 'd', '\n',
        'c', 'r', 'u', 's', 't', 'i', 'e', 'r', '\n',
        'c', 'r', 'u', 's', 't', 'i', 'e', 's', 't', '\n',
        'c', 'r', 'u', 's', 't', 's', '\n',
        'c', 'r', 'u', 's', 't', 'y', '\n',
        'c', 'r', 'u', 't', 'c', 'h', '\n',
        'c', 'r', 'u', 't', 'c', 'h', 'e', 's', '\n',
        'c', 'r', 'u', 'x', '\n',
        'c', 'r', 'u', 'x', 'e', 's', '\n',
        'c', 'r', 'y', '\n',
        'c', 'r', 'y', 'i', 'n', 'g', '\n',
        'c', 'r', 'y', 'i', 'n', 'g', 's', '\n',
        'c', 'r', 'y', 'o', 'g', 'e', 'n', 'i', 'c', '\n',
        'c', 'r', 'y', 'o', 'g', 'e', 'n', 'i', 'c', 's', '\n',
        'c', 'r', 'y', 'o', 's', 't', 'a', 't', '\n',
        'c', 'r', 'y', 'p', 't', '\n',
        'c', 'r', 'y', 'p', 't', 'a', 'n', 'a', 'l', 'y', 's', 'i', 's', '\n',
        'c', 'r', 'y', 'p', 't', 'a', 'n', 'a', 'l', 'y', 's', 't', '\n',
        'c', 'r', 'y', 'p', 't', 'a', 'n', 'a', 'l', 'y', 't', 'i', 'c', '\n',
        'c', 'r', 'y', 'p', 't', 'i', 'c', '\n',
        'c', 'r', 'y', 'p', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'c', 'r', 'y', 'p', 't', 'o', 'g', 'r', 'a', 'm', '\n',
        'c', 'r', 'y', 'p', 't', 'o', 'g', 'r', 'a', 'p', 'h', 'e', 'r', '\n',
        'c', 'r', 'y', 'p', 't', 'o', 'g', 'r', 'a', 'p', 'h', 'e', 'r', 's', '\n',
        'c', 'r', 'y', 'p', 't', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', '\n',
        'c', 'r', 'y', 'p', 't', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'c', 'r', 'y', 'p', 't', 'o', 'g', 'r', 'a', 'p', 'h', 'y', '\n',
        'c', 'r', 'y', 'p', 't', 'o', 'l', 'o', 'g', 'y', '\n',
        'c', 'r', 'y', 'p', 't', 's', '\n',
        'c', 'r', 'y', 's', 't', 'a', 'l', '\n',
        'c', 'r', 'y', 's', 't', 'a', 'l', 'c', 'l', 'e', 'a', 'r', '\n',
        'c', 'r', 'y', 's', 't', 'a', 'l', 'l', 'i', 'n', 'e', '\n',
        'c', 'r', 'y', 's', 't', 'a', 'l', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'r', 'y', 's', 't', 'a', 'l', 'l', 'i', 's', 'e', '\n',
        'c', 'r', 'y', 's', 't', 'a', 'l', 'l', 'i', 's', 'e', 'd', '\n',
        'c', 'r', 'y', 's', 't', 'a', 'l', 'l', 'i', 's', 'e', 's', '\n',
        'c', 'r', 'y', 's', 't', 'a', 'l', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'c', 'r', 'y', 's', 't', 'a', 'l', 'l', 'o', 'g', 'r', 'a', 'p', 'h', 'e', 'r', '\n',
        'c', 'r', 'y', 's', 't', 'a', 'l', 'l', 'o', 'g', 'r', 'a', 'p', 'h', 'e', 'r', 's', '\n',
        'c', 'r', 'y', 's', 't', 'a', 'l', 'l', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', '\n',
        'c', 'r', 'y', 's', 't', 'a', 'l', 'l', 'o', 'g', 'r', 'a', 'p', 'h', 'y', '\n',
        'c', 'r', 'y', 's', 't', 'a', 'l', 's', '\n',
        'c', 'u', 'b', '\n',
        'c', 'u', 'b', 'a', '\n',
        'c', 'u', 'b', 'a', 'n', '\n',
        'c', 'u', 'b', 'a', 'n', 's', '\n',
        'c', 'u', 'b', 'e', '\n',
        'c', 'u', 'b', 'e', 'd', '\n',
        'c', 'u', 'b', 'e', 's', '\n',
        'c', 'u', 'b', 'i', 'c', '\n',
        'c', 'u', 'b', 'i', 'c', 'a', 'l', '\n',
        'c', 'u', 'b', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'c', 'u', 'b', 'i', 'c', 'l', 'e', '\n',
        'c', 'u', 'b', 'i', 'c', 'l', 'e', 's', '\n',
        'c', 'u', 'b', 'i', 'n', 'g', '\n',
        'c', 'u', 'b', 'i', 's', 'm', '\n',
        'c', 'u', 'b', 'i', 's', 't', '\n',
        'c', 'u', 'b', 'i', 's', 't', 'i', 'c', '\n',
        'c', 'u', 'b', 'i', 's', 't', 's', '\n',
        'c', 'u', 'b', 'i', 't', '\n',
        'c', 'u', 'b', 'i', 't', 's', '\n',
        'c', 'u', 'b', 'o', 'i', 'd', '\n',
        'c', 'u', 'b', 's', '\n',
        'c', 'u', 'c', 'k', 'o', 'l', 'd', '\n',
        'c', 'u', 'c', 'k', 'o', 'l', 'd', 'e', 'd', '\n',
        'c', 'u', 'c', 'k', 'o', 'o', '\n',
        'c', 'u', 'c', 'k', 'o', 'o', 's', '\n',
        'c', 'u', 'c', 'u', 'm', 'b', 'e', 'r', '\n',
        'c', 'u', 'c', 'u', 'm', 'b', 'e', 'r', 's', '\n',
        'c', 'u', 'd', '\n',
        'c', 'u', 'd', 'd', 'l', 'e', '\n',
        'c', 'u', 'd', 'd', 'l', 'e', 'd', '\n',
        'c', 'u', 'd', 'd', 'l', 'e', 's', '\n',
        'c', 'u', 'd', 'd', 'l', 'i', 'e', 'r', '\n',
        'c', 'u', 'd', 'd', 'l', 'i', 'e', 's', 't', '\n',
        'c', 'u', 'd', 'd', 'l', 'i', 'n', 'e', 's', 's', '\n',
        'c', 'u', 'd', 'd', 'l', 'i', 'n', 'g', '\n',
        'c', 'u', 'd', 'd', 'l', 'y', '\n',
        'c', 'u', 'd', 'g', 'e', 'l', '\n',
        'c', 'u', 'd', 'g', 'e', 'l', 's', '\n',
        'c', 'u', 'd', 's', '\n',
        'c', 'u', 'e', '\n',
        'c', 'u', 'e', 'd', '\n',
        'c', 'u', 'e', 'i', 'n', 'g', '\n',
        'c', 'u', 'e', 's', '\n',
        'c', 'u', 'f', 'f', '\n',
        'c', 'u', 'f', 'f', 'e', 'd', '\n',
        'c', 'u', 'f', 'f', 'i', 'n', 'g', '\n',
        'c', 'u', 'f', 'f', 's', '\n',
        'c', 'u', 'i', 'n', 'g', '\n',
        'c', 'u', 'i', 'r', 'a', 's', 's', '\n',
        'c', 'u', 'i', 's', 'i', 'n', 'e', '\n',
        'c', 'u', 'l', 'd', 'e', 's', 'a', 'c', '\n',
        'c', 'u', 'l', 'i', 'n', 'a', 'r', 'y', '\n',
        'c', 'u', 'l', 'l', '\n',
        'c', 'u', 'l', 'l', 'e', 'd', '\n',
        'c', 'u', 'l', 'l', 'i', 'n', 'g', '\n',
        'c', 'u', 'l', 'l', 's', '\n',
        'c', 'u', 'l', 'm', 'i', 'n', 'a', 't', 'e', '\n',
        'c', 'u', 'l', 'm', 'i', 'n', 'a', 't', 'e', 'd', '\n',
        'c', 'u', 'l', 'm', 'i', 'n', 'a', 't', 'e', 's', '\n',
        'c', 'u', 'l', 'm', 'i', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'u', 'l', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'u', 'l', 'p', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'c', 'u', 'l', 'p', 'a', 'b', 'l', 'e', '\n',
        'c', 'u', 'l', 'p', 'a', 'b', 'l', 'y', '\n',
        'c', 'u', 'l', 'p', 'r', 'i', 't', '\n',
        'c', 'u', 'l', 'p', 'r', 'i', 't', 's', '\n',
        'c', 'u', 'l', 't', '\n',
        'c', 'u', 'l', 't', 'i', 'v', 'a', 'b', 'l', 'e', '\n',
        'c', 'u', 'l', 't', 'i', 'v', 'a', 'r', '\n',
        'c', 'u', 'l', 't', 'i', 'v', 'a', 't', 'e', '\n',
        'c', 'u', 'l', 't', 'i', 'v', 'a', 't', 'e', 'd', '\n',
        'c', 'u', 'l', 't', 'i', 'v', 'a', 't', 'e', 's', '\n',
        'c', 'u', 'l', 't', 'i', 'v', 'a', 't', 'i', 'n', 'g', '\n',
        'c', 'u', 'l', 't', 'i', 'v', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'u', 'l', 't', 'i', 'v', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'u', 'l', 't', 'i', 'v', 'a', 't', 'o', 'r', '\n',
        'c', 'u', 'l', 't', 'i', 'v', 'a', 't', 'o', 'r', 's', '\n',
        'c', 'u', 'l', 't', 's', '\n',
        'c', 'u', 'l', 't', 'u', 'r', 'a', 'l', '\n',
        'c', 'u', 'l', 't', 'u', 'r', 'a', 'l', 'l', 'y', '\n',
        'c', 'u', 'l', 't', 'u', 'r', 'e', '\n',
        'c', 'u', 'l', 't', 'u', 'r', 'e', 'd', '\n',
        'c', 'u', 'l', 't', 'u', 'r', 'e', 's', '\n',
        'c', 'u', 'l', 't', 'u', 'r', 'i', 'n', 'g', '\n',
        'c', 'u', 'l', 't', 'u', 's', '\n',
        'c', 'u', 'l', 'v', 'e', 'r', 't', '\n',
        'c', 'u', 'm', 'b', 'e', 'r', 's', 'o', 'm', 'e', '\n',
        'c', 'u', 'm', 'b', 'e', 'r', 's', 'o', 'm', 'e', 'l', 'y', '\n',
        'c', 'u', 'm', 'l', 'a', 'u', 'd', 'e', '\n',
        'c', 'u', 'm', 'm', 'e', 'r', 'b', 'u', 'n', 'd', '\n',
        'c', 'u', 'm', 'u', 'l', 'a', 't', 'i', 'v', 'e', '\n',
        'c', 'u', 'm', 'u', 'l', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'c', 'u', 'm', 'u', 'l', 'u', 's', '\n',
        'c', 'u', 'n', 'e', 'i', 'f', 'o', 'r', 'm', '\n',
        'c', 'u', 'n', 'n', 'i', 'l', 'i', 'n', 'g', 'u', 's', '\n',
        'c', 'u', 'n', 'n', 'i', 'n', 'g', '\n',
        'c', 'u', 'n', 'n', 'i', 'n', 'g', 'l', 'y', '\n',
        'c', 'u', 'p', '\n',
        'c', 'u', 'p', 'b', 'o', 'a', 'r', 'd', '\n',
        'c', 'u', 'p', 'b', 'o', 'a', 'r', 'd', 's', '\n',
        'c', 'u', 'p', 'f', 'u', 'l', '\n',
        'c', 'u', 'p', 'i', 'd', '\n',
        'c', 'u', 'p', 'i', 'd', 'i', 'n', 'o', 'u', 's', 'l', 'y', '\n',
        'c', 'u', 'p', 'i', 'd', 'i', 't', 'y', '\n',
        'c', 'u', 'p', 'o', 'l', 'a', '\n',
        'c', 'u', 'p', 'o', 'l', 'a', 's', '\n',
        'c', 'u', 'p', 'p', 'e', 'd', '\n',
        'c', 'u', 'p', 'p', 'i', 'n', 'g', '\n',
        'c', 'u', 'p', 'r', 'o', 'u', 's', '\n',
        'c', 'u', 'p', 's', '\n',
        'c', 'u', 'r', '\n',
        'c', 'u', 'r', 'a', 'b', 'l', 'e', '\n',
        'c', 'u', 'r', 'a', 'r', 'e', '\n',
        'c', 'u', 'r', 'a', 't', 'e', '\n',
        'c', 'u', 'r', 'a', 't', 'e', 'd', '\n',
        'c', 'u', 'r', 'a', 't', 'e', 's', '\n',
        'c', 'u', 'r', 'a', 't', 'i', 'v', 'e', '\n',
        'c', 'u', 'r', 'a', 't', 'o', 'r', '\n',
        'c', 'u', 'r', 'a', 't', 'o', 'r', 'i', 'a', 'l', '\n',
        'c', 'u', 'r', 'a', 't', 'o', 'r', 's', '\n',
        'c', 'u', 'r', 'a', 't', 'o', 'r', 's', 'h', 'i', 'p', 's', '\n',
        'c', 'u', 'r', 'b', '\n',
        'c', 'u', 'r', 'b', 'e', 'd', '\n',
        'c', 'u', 'r', 'b', 'i', 'n', 'g', '\n',
        'c', 'u', 'r', 'b', 's', '\n',
        'c', 'u', 'r', 'd', '\n',
        'c', 'u', 'r', 'd', 'l', 'e', '\n',
        'c', 'u', 'r', 'd', 'l', 'e', 'd', '\n',
        'c', 'u', 'r', 'd', 'l', 'e', 's', '\n',
        'c', 'u', 'r', 'd', 'l', 'i', 'n', 'g', '\n',
        'c', 'u', 'r', 'd', 's', '\n',
        'c', 'u', 'r', 'e', '\n',
        'c', 'u', 'r', 'e', 'd', '\n',
        'c', 'u', 'r', 'e', 'r', '\n',
        'c', 'u', 'r', 'e', 's', '\n',
        'c', 'u', 'r', 'f', 'e', 'w', '\n',
        'c', 'u', 'r', 'f', 'e', 'w', 's', '\n',
        'c', 'u', 'r', 'i', 'a', '\n',
        'c', 'u', 'r', 'i', 'a', 'l', '\n',
        'c', 'u', 'r', 'i', 'e', '\n',
        'c', 'u', 'r', 'i', 'e', 's', '\n',
        'c', 'u', 'r', 'i', 'n', 'g', '\n',
        'c', 'u', 'r', 'i', 'o', '\n',
        'c', 'u', 'r', 'i', 'o', 's', 'i', 't', 'i', 'e', 's', '\n',
        'c', 'u', 'r', 'i', 'o', 's', 'i', 't', 'y', '\n',
        'c', 'u', 'r', 'i', 'o', 'u', 's', '\n',
        'c', 'u', 'r', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'c', 'u', 'r', 'l', '\n',
        'c', 'u', 'r', 'l', 'e', 'd', '\n',
        'c', 'u', 'r', 'l', 'e', 'r', 's', '\n',
        'c', 'u', 'r', 'l', 'e', 'w', '\n',
        'c', 'u', 'r', 'l', 'e', 'w', 's', '\n',
        'c', 'u', 'r', 'l', 'i', 'c', 'u', 'e', 's', '\n',
        'c', 'u', 'r', 'l', 'i', 'e', 'r', '\n',
        'c', 'u', 'r', 'l', 'i', 'e', 's', 't', '\n',
        'c', 'u', 'r', 'l', 'i', 'n', 'e', 's', 's', '\n',
        'c', 'u', 'r', 'l', 'i', 'n', 'g', '\n',
        'c', 'u', 'r', 'l', 's', '\n',
        'c', 'u', 'r', 'l', 'y', '\n',
        'c', 'u', 'r', 'm', 'u', 'd', 'g', 'e', 'o', 'n', 's', '\n',
        'c', 'u', 'r', 'r', 'a', 'n', 't', '\n',
        'c', 'u', 'r', 'r', 'a', 'n', 't', 's', '\n',
        'c', 'u', 'r', 'r', 'e', 'n', 'c', 'i', 'e', 's', '\n',
        'c', 'u', 'r', 'r', 'e', 'n', 'c', 'y', '\n',
        'c', 'u', 'r', 'r', 'e', 'n', 't', '\n',
        'c', 'u', 'r', 'r', 'e', 'n', 't', 'l', 'y', '\n',
        'c', 'u', 'r', 'r', 'e', 'n', 't', 's', '\n',
        'c', 'u', 'r', 'r', 'i', 'c', 'l', 'e', '\n',
        'c', 'u', 'r', 'r', 'i', 'c', 'u', 'l', 'a', '\n',
        'c', 'u', 'r', 'r', 'i', 'c', 'u', 'l', 'a', 'r', '\n',
        'c', 'u', 'r', 'r', 'i', 'c', 'u', 'l', 'u', 'm', '\n',
        'c', 'u', 'r', 'r', 'i', 'e', 'd', '\n',
        'c', 'u', 'r', 'r', 'i', 'e', 's', '\n',
        'c', 'u', 'r', 'r', 'y', '\n',
        'c', 'u', 'r', 'r', 'y', 'i', 'n', 'g', '\n',
        'c', 'u', 'r', 's', '\n',
        'c', 'u', 'r', 's', 'e', '\n',
        'c', 'u', 'r', 's', 'e', 'd', '\n',
        'c', 'u', 'r', 's', 'e', 's', '\n',
        'c', 'u', 'r', 's', 'i', 'n', 'g', '\n',
        'c', 'u', 'r', 's', 'i', 'v', 'e', '\n',
        'c', 'u', 'r', 's', 'o', 'r', '\n',
        'c', 'u', 'r', 's', 'o', 'r', 'i', 'l', 'y', '\n',
        'c', 'u', 'r', 's', 'o', 'r', 's', '\n',
        'c', 'u', 'r', 's', 'o', 'r', 'y', '\n',
        'c', 'u', 'r', 't', '\n',
        'c', 'u', 'r', 't', 'a', 'i', 'l', '\n',
        'c', 'u', 'r', 't', 'a', 'i', 'l', 'e', 'd', '\n',
        'c', 'u', 'r', 't', 'a', 'i', 'l', 'i', 'n', 'g', '\n',
        'c', 'u', 'r', 't', 'a', 'i', 'l', 'm', 'e', 'n', 't', '\n',
        'c', 'u', 'r', 't', 'a', 'i', 'l', 'm', 'e', 'n', 't', 's', '\n',
        'c', 'u', 'r', 't', 'a', 'i', 'l', 's', '\n',
        'c', 'u', 'r', 't', 'a', 'i', 'n', '\n',
        'c', 'u', 'r', 't', 'a', 'i', 'n', 'e', 'd', '\n',
        'c', 'u', 'r', 't', 'a', 'i', 'n', 'i', 'n', 'g', '\n',
        'c', 'u', 'r', 't', 'a', 'i', 'n', 's', '\n',
        'c', 'u', 'r', 't', 'i', 'l', 'a', 'g', 'e', '\n',
        'c', 'u', 'r', 't', 'l', 'y', '\n',
        'c', 'u', 'r', 't', 'n', 'e', 's', 's', '\n',
        'c', 'u', 'r', 't', 's', 'e', 'y', '\n',
        'c', 'u', 'r', 't', 's', 'e', 'y', 'e', 'd', '\n',
        'c', 'u', 'r', 't', 's', 'e', 'y', 'i', 'n', 'g', '\n',
        'c', 'u', 'r', 't', 's', 'e', 'y', 's', '\n',
        'c', 'u', 'r', 't', 's', 'i', 'e', 'd', '\n',
        'c', 'u', 'r', 't', 's', 'i', 'e', 's', '\n',
        'c', 'u', 'r', 't', 's', 'y', '\n',
        'c', 'u', 'r', 't', 's', 'y', 'i', 'n', 'g', '\n',
        'c', 'u', 'r', 'v', 'a', 'c', 'e', 'o', 'u', 's', '\n',
        'c', 'u', 'r', 'v', 'a', 't', 'u', 'r', 'e', '\n',
        'c', 'u', 'r', 'v', 'a', 't', 'u', 'r', 'e', 's', '\n',
        'c', 'u', 'r', 'v', 'e', '\n',
        'c', 'u', 'r', 'v', 'e', 'd', '\n',
        'c', 'u', 'r', 'v', 'e', 's', '\n',
        'c', 'u', 'r', 'v', 'i', 'l', 'i', 'n', 'e', 'a', 'r', '\n',
        'c', 'u', 'r', 'v', 'i', 'n', 'g', '\n',
        'c', 'u', 'r', 'v', 'y', '\n',
        'c', 'u', 's', 'h', 'i', 'o', 'n', '\n',
        'c', 'u', 's', 'h', 'i', 'o', 'n', 'e', 'd', '\n',
        'c', 'u', 's', 'h', 'i', 'o', 'n', 'i', 'n', 'g', '\n',
        'c', 'u', 's', 'h', 'i', 'o', 'n', 's', '\n',
        'c', 'u', 's', 'p', '\n',
        'c', 'u', 's', 'p', 's', '\n',
        'c', 'u', 's', 's', '\n',
        'c', 'u', 's', 's', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'c', 'u', 's', 't', 'a', 'r', 'd', '\n',
        'c', 'u', 's', 't', 'a', 'r', 'd', 's', '\n',
        'c', 'u', 's', 't', 'o', 'd', 'i', 'a', 'l', '\n',
        'c', 'u', 's', 't', 'o', 'd', 'i', 'a', 'n', '\n',
        'c', 'u', 's', 't', 'o', 'd', 'i', 'a', 'n', 's', '\n',
        'c', 'u', 's', 't', 'o', 'd', 'i', 'a', 'n', 's', 'h', 'i', 'p', '\n',
        'c', 'u', 's', 't', 'o', 'd', 'y', '\n',
        'c', 'u', 's', 't', 'o', 'm', '\n',
        'c', 'u', 's', 't', 'o', 'm', 'a', 'r', 'i', 'l', 'y', '\n',
        'c', 'u', 's', 't', 'o', 'm', 'a', 'r', 'y', '\n',
        'c', 'u', 's', 't', 'o', 'm', 'e', 'r', '\n',
        'c', 'u', 's', 't', 'o', 'm', 'e', 'r', 's', '\n',
        'c', 'u', 's', 't', 'o', 'm', 'i', 's', 'a', 'b', 'l', 'e', '\n',
        'c', 'u', 's', 't', 'o', 'm', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'c', 'u', 's', 't', 'o', 'm', 'i', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'c', 'u', 's', 't', 'o', 'm', 'i', 's', 'e', '\n',
        'c', 'u', 's', 't', 'o', 'm', 'i', 's', 'e', 'd', '\n',
        'c', 'u', 's', 't', 'o', 'm', 'i', 's', 'i', 'n', 'g', '\n',
        'c', 'u', 's', 't', 'o', 'm', 's', '\n',
        'c', 'u', 't', '\n',
        'c', 'u', 't', 'b', 'a', 'c', 'k', '\n',
        'c', 'u', 't', 'b', 'a', 'c', 'k', 's', '\n',
        'c', 'u', 't', 'e', '\n',
        'c', 'u', 't', 'e', 'l', 'y', '\n',
        'c', 'u', 't', 'e', 'n', 'e', 's', 's', '\n',
        'c', 'u', 't', 'e', 's', 't', '\n',
        'c', 'u', 't', 'i', 'c', 'l', 'e', '\n',
        'c', 'u', 't', 'i', 'c', 'l', 'e', 's', '\n',
        'c', 'u', 't', 'l', 'a', 's', 's', '\n',
        'c', 'u', 't', 'l', 'a', 's', 's', 'e', 's', '\n',
        'c', 'u', 't', 'l', 'e', 'r', '\n',
        'c', 'u', 't', 'l', 'e', 'r', 'y', '\n',
        'c', 'u', 't', 'l', 'e', 't', '\n',
        'c', 'u', 't', 'l', 'e', 't', 's', '\n',
        'c', 'u', 't', 'o', 'u', 't', '\n',
        'c', 'u', 't', 'o', 'u', 't', 's', '\n',
        'c', 'u', 't', 'p', 'r', 'i', 'c', 'e', '\n',
        'c', 'u', 't', 'r', 'a', 't', 'e', '\n',
        'c', 'u', 't', 's', '\n',
        'c', 'u', 't', 't', 'e', 'r', '\n',
        'c', 'u', 't', 't', 'e', 'r', 's', '\n',
        'c', 'u', 't', 't', 'h', 'r', 'o', 'a', 't', '\n',
        'c', 'u', 't', 't', 'i', 'n', 'g', '\n',
        'c', 'u', 't', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'c', 'u', 't', 't', 'i', 'n', 'g', 's', '\n',
        'c', 'u', 't', 't', 'l', 'e', '\n',
        'c', 'u', 't', 't', 'l', 'e', 'f', 'i', 's', 'h', '\n',
        'c', 'y', 'a', 'n', '\n',
        'c', 'y', 'a', 'n', 'i', 'd', 'e', '\n',
        'c', 'y', 'a', 'n', 'o', 'g', 'e', 'n', '\n',
        'c', 'y', 'b', 'e', 'r', 'n', 'e', 't', 'i', 'c', '\n',
        'c', 'y', 'b', 'e', 'r', 'n', 'e', 't', 'i', 'c', 's', '\n',
        'c', 'y', 'b', 'e', 'r', 'p', 'u', 'n', 'k', '\n',
        'c', 'y', 'b', 'e', 'r', 's', 'p', 'a', 'c', 'e', '\n',
        'c', 'y', 'b', 'o', 'r', 'g', '\n',
        'c', 'y', 'c', 'a', 'd', '\n',
        'c', 'y', 'c', 'a', 'd', 's', '\n',
        'c', 'y', 'c', 'l', 'e', '\n',
        'c', 'y', 'c', 'l', 'e', 'd', '\n',
        'c', 'y', 'c', 'l', 'e', 's', '\n',
        'c', 'y', 'c', 'l', 'e', 'w', 'a', 'y', '\n',
        'c', 'y', 'c', 'l', 'e', 'w', 'a', 'y', 's', '\n',
        'c', 'y', 'c', 'l', 'i', 'c', '\n',
        'c', 'y', 'c', 'l', 'i', 'c', 'a', 'l', '\n',
        'c', 'y', 'c', 'l', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'c', 'y', 'c', 'l', 'i', 'n', 'g', '\n',
        'c', 'y', 'c', 'l', 'i', 's', 't', '\n',
        'c', 'y', 'c', 'l', 'i', 's', 't', 's', '\n',
        'c', 'y', 'c', 'l', 'o', 'i', 'd', '\n',
        'c', 'y', 'c', 'l', 'o', 'n', 'e', '\n',
        'c', 'y', 'c', 'l', 'o', 'n', 'e', 's', '\n',
        'c', 'y', 'c', 'l', 'o', 'p', 's', '\n',
        'c', 'y', 'c', 'l', 'o', 't', 'r', 'o', 'n', '\n',
        'c', 'y', 'c', 'l', 'o', 't', 'r', 'o', 'n', 's', '\n',
        'c', 'y', 'g', 'n', 'e', 't', '\n',
        'c', 'y', 'g', 'n', 'e', 't', 's', '\n',
        'c', 'y', 'l', 'i', 'n', 'd', 'e', 'r', '\n',
        'c', 'y', 'l', 'i', 'n', 'd', 'e', 'r', 's', '\n',
        'c', 'y', 'l', 'i', 'n', 'd', 'r', 'i', 'c', 'a', 'l', '\n',
        'c', 'y', 'l', 'i', 'n', 'd', 'r', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'c', 'y', 'm', 'b', 'a', 'l', '\n',
        'c', 'y', 'm', 'b', 'a', 'l', 's', '\n',
        'c', 'y', 'n', 'i', 'c', '\n',
        'c', 'y', 'n', 'i', 'c', 'a', 'l', '\n',
        'c', 'y', 'n', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'c', 'y', 'n', 'i', 'c', 'i', 's', 'm', '\n',
        'c', 'y', 'n', 'i', 'c', 's', '\n',
        'c', 'y', 'p', 'h', 'e', 'r', '\n',
        'c', 'y', 'p', 'h', 'e', 'r', 's', '\n',
        'c', 'y', 'p', 'r', 'e', 's', 's', '\n',
        'c', 'y', 'p', 'r', 'e', 's', 's', 'e', 's', '\n',
        'c', 'y', 'p', 'r', 'i', 'a', 'n', '\n',
        'c', 'y', 'p', 'r', 'i', 'a', 'n', 's', '\n',
        'c', 'y', 'p', 'r', 'i', 'o', 't', '\n',
        'c', 'y', 'p', 'r', 'i', 'o', 't', 's', '\n',
        'c', 'y', 'p', 'r', 'u', 's', '\n',
        'c', 'y', 's', 't', '\n',
        'c', 'y', 's', 't', 'e', 'i', 'n', 'e', '\n',
        'c', 'y', 's', 't', 'i', 'c', '\n',
        'c', 'y', 's', 't', 'i', 'n', 'e', '\n',
        'c', 'y', 's', 't', 'i', 't', 'i', 's', '\n',
        'c', 'y', 's', 't', 's', '\n',
        'c', 'y', 't', 'o', 'c', 'h', 'r', 'o', 'm', 'e', '\n',
        'c', 'y', 't', 'o', 'g', 'e', 'n', 'e', 't', 'i', 'c', '\n',
        'c', 'y', 't', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'c', 'y', 't', 'o', 'l', 'o', 'g', 'y', '\n',
        'c', 'y', 't', 'o', 'p', 'l', 'a', 's', 'm', '\n',
        'c', 'y', 't', 'o', 'p', 'l', 'a', 's', 'm', 'i', 'c', '\n',
        'c', 'y', 't', 'o', 's', 'i', 'n', 'e', '\n',
        'c', 'y', 't', 'o', 't', 'o', 'x', 'i', 'c', '\n',
        'c', 'z', 'a', 'r', '\n',
        'c', 'z', 'a', 'r', 's', '\n',
        'c', 'z', 'e', 'c', 'h', '\n',
        'c', 'z', 'e', 'c', 'h', 's', '\n',
        'd', 'a', 'b', '\n',
        'd', 'a', 'b', 'b', 'e', 'd', '\n',
        'd', 'a', 'b', 'b', 'i', 'n', 'g', '\n',
        'd', 'a', 'b', 'b', 'l', 'e', '\n',
        'd', 'a', 'b', 'b', 'l', 'e', 'd', '\n',
        'd', 'a', 'b', 'b', 'l', 'e', 'r', '\n',
        'd', 'a', 'b', 'b', 'l', 'e', 's', '\n',
        'd', 'a', 'b', 'b', 'l', 'i', 'n', 'g', '\n',
        'd', 'a', 'b', 's', '\n',
        'd', 'a', 'c', 'e', '\n',
        'd', 'a', 'c', 'h', 'a', '\n',
        'd', 'a', 'c', 'h', 'a', 'u', '\n',
        'd', 'a', 'c', 'h', 's', 'h', 'u', 'n', 'd', '\n',
        'd', 'a', 'c', 't', 'y', 'l', '\n',
        'd', 'a', 'c', 't', 'y', 'l', 'i', 'c', '\n',
        'd', 'a', 'c', 't', 'y', 'l', 's', '\n',
        'd', 'a', 'd', '\n',
        'd', 'a', 'd', 'd', 'i', 'e', 's', '\n',
        'd', 'a', 'd', 'd', 'y', '\n',
        'd', 'a', 'd', 'd', 'y', 'l', 'o', 'n', 'g', 'l', 'e', 'g', 's', '\n',
        'd', 'a', 'd', 'o', '\n',
        'd', 'a', 'd', 's', '\n',
        'd', 'a', 'e', 'm', 'o', 'n', '\n',
        'd', 'a', 'e', 'm', 'o', 'n', 'i', 'c', '\n',
        'd', 'a', 'e', 'm', 'o', 'n', 's', '\n',
        'd', 'a', 'f', 'f', 'o', 'd', 'i', 'l', '\n',
        'd', 'a', 'f', 'f', 'o', 'd', 'i', 'l', 's', '\n',
        'd', 'a', 'f', 'f', 'y', '\n',
        'd', 'a', 'f', 't', '\n',
        'd', 'a', 'f', 't', 'e', 'r', '\n',
        'd', 'a', 'f', 't', 'e', 's', 't', '\n',
        'd', 'a', 'f', 't', 'n', 'e', 's', 's', '\n',
        'd', 'a', 'g', 'a', 'm', 'a', '\n',
        'd', 'a', 'g', 'g', 'a', '\n',
        'd', 'a', 'g', 'g', 'e', 'r', '\n',
        'd', 'a', 'g', 'g', 'e', 'r', 's', '\n',
        'd', 'a', 'h', 'l', 'i', 'a', '\n',
        'd', 'a', 'h', 'l', 'i', 'a', 's', '\n',
        'd', 'a', 'h', 'o', 'm', 'e', 'y', '\n',
        'd', 'a', 'i', 'l', 'i', 'e', 's', '\n',
        'd', 'a', 'i', 'l', 'y', '\n',
        'd', 'a', 'i', 'n', 't', 'i', 'e', 'r', '\n',
        'd', 'a', 'i', 'n', 't', 'i', 'e', 's', 't', '\n',
        'd', 'a', 'i', 'n', 't', 'i', 'l', 'y', '\n',
        'd', 'a', 'i', 'n', 't', 'i', 'n', 'e', 's', 's', '\n',
        'd', 'a', 'i', 'n', 't', 'y', '\n',
        'd', 'a', 'i', 'r', 'i', 'e', 's', '\n',
        'd', 'a', 'i', 'r', 'y', '\n',
        'd', 'a', 'i', 'r', 'y', 'i', 'n', 'g', '\n',
        'd', 'a', 'i', 'r', 'y', 'm', 'a', 'n', '\n',
        'd', 'a', 'i', 'r', 'y', 'm', 'e', 'n', '\n',
        'd', 'a', 'i', 's', '\n',
        'd', 'a', 'i', 's', 'i', 'e', 's', '\n',
        'd', 'a', 'i', 's', 'y', '\n',
        'd', 'a', 'k', 'a', 'r', '\n',
        'd', 'a', 'k', 'o', 'i', 't', 's', '\n',
        'd', 'a', 'l', 'e', '\n',
        'd', 'a', 'l', 'e', 's', '\n',
        'd', 'a', 'l', 'l', 'a', 's', '\n',
        'd', 'a', 'l', 'l', 'i', 'a', 'n', 'c', 'e', '\n',
        'd', 'a', 'l', 'l', 'i', 'e', 'd', '\n',
        'd', 'a', 'l', 'l', 'y', '\n',
        'd', 'a', 'l', 'l', 'y', 'i', 'n', 'g', '\n',
        'd', 'a', 'm', '\n',
        'd', 'a', 'm', 'a', 'g', 'e', '\n',
        'd', 'a', 'm', 'a', 'g', 'e', 'd', '\n',
        'd', 'a', 'm', 'a', 'g', 'e', 's', '\n',
        'd', 'a', 'm', 'a', 'g', 'i', 'n', 'g', '\n',
        'd', 'a', 'm', 'a', 'g', 'i', 'n', 'g', 'l', 'y', '\n',
        'd', 'a', 'm', 'a', 's', 'c', 'u', 's', '\n',
        'd', 'a', 'm', 'a', 's', 'k', '\n',
        'd', 'a', 'm', 'e', '\n',
        'd', 'a', 'm', 'e', 's', '\n',
        'd', 'a', 'm', 'm', 'e', 'd', '\n',
        'd', 'a', 'm', 'm', 'i', 'n', 'g', '\n',
        'd', 'a', 'm', 'n', '\n',
        'd', 'a', 'm', 'n', 'a', 'b', 'l', 'e', '\n',
        'd', 'a', 'm', 'n', 'a', 'b', 'l', 'y', '\n',
        'd', 'a', 'm', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'a', 'm', 'n', 'e', 'd', '\n',
        'd', 'a', 'm', 'n', 'i', 'f', 'y', '\n',
        'd', 'a', 'm', 'n', 'i', 'n', 'g', '\n',
        'd', 'a', 'm', 'n', 'i', 'n', 'g', 'l', 'y', '\n',
        'd', 'a', 'm', 'n', 's', '\n',
        'd', 'a', 'm', 'p', '\n',
        'd', 'a', 'm', 'p', 'e', 'd', '\n',
        'd', 'a', 'm', 'p', 'e', 'n', '\n',
        'd', 'a', 'm', 'p', 'e', 'n', 'e', 'd', '\n',
        'd', 'a', 'm', 'p', 'e', 'n', 'i', 'n', 'g', '\n',
        'd', 'a', 'm', 'p', 'e', 'n', 's', '\n',
        'd', 'a', 'm', 'p', 'e', 'r', '\n',
        'd', 'a', 'm', 'p', 'e', 'r', 's', '\n',
        'd', 'a', 'm', 'p', 'e', 's', 't', '\n',
        'd', 'a', 'm', 'p', 'i', 'n', 'g', '\n',
        'd', 'a', 'm', 'p', 'i', 's', 'h', '\n',
        'd', 'a', 'm', 'p', 'l', 'y', '\n',
        'd', 'a', 'm', 'p', 'n', 'e', 's', 's', '\n',
        'd', 'a', 'm', 'p', 's', '\n',
        'd', 'a', 'm', 's', '\n',
        'd', 'a', 'm', 's', 'e', 'l', '\n',
        'd', 'a', 'm', 's', 'e', 'l', 's', '\n',
        'd', 'a', 'm', 's', 'o', 'n', '\n',
        'd', 'a', 'm', 's', 'o', 'n', 's', '\n',
        'd', 'a', 'n', '\n',
        'd', 'a', 'n', 'c', 'e', '\n',
        'd', 'a', 'n', 'c', 'e', 'a', 'b', 'l', 'e', '\n',
        'd', 'a', 'n', 'c', 'e', 'd', '\n',
        'd', 'a', 'n', 'c', 'e', 'r', '\n',
        'd', 'a', 'n', 'c', 'e', 'r', 's', '\n',
        'd', 'a', 'n', 'c', 'e', 's', '\n',
        'd', 'a', 'n', 'c', 'i', 'n', 'g', '\n',
        'd', 'a', 'n', 'd', 'e', 'l', 'i', 'o', 'n', '\n',
        'd', 'a', 'n', 'd', 'e', 'l', 'i', 'o', 'n', 's', '\n',
        'd', 'a', 'n', 'd', 'i', 'e', 's', '\n',
        'd', 'a', 'n', 'd', 'r', 'u', 'f', 'f', '\n',
        'd', 'a', 'n', 'd', 'y', '\n',
        'd', 'a', 'n', 'e', '\n',
        'd', 'a', 'n', 'e', 's', '\n',
        'd', 'a', 'n', 'g', 'e', 'r', '\n',
        'd', 'a', 'n', 'g', 'e', 'r', 'o', 'u', 's', '\n',
        'd', 'a', 'n', 'g', 'e', 'r', 'o', 'u', 's', 'l', 'y', '\n',
        'd', 'a', 'n', 'g', 'e', 'r', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'd', 'a', 'n', 'g', 'e', 'r', 's', '\n',
        'd', 'a', 'n', 'g', 'l', 'e', '\n',
        'd', 'a', 'n', 'g', 'l', 'e', 'd', '\n',
        'd', 'a', 'n', 'g', 'l', 'e', 's', '\n',
        'd', 'a', 'n', 'g', 'l', 'i', 'n', 'g', '\n',
        'd', 'a', 'n', 'i', 'e', 'l', '\n',
        'd', 'a', 'n', 'i', 's', 'h', '\n',
        'd', 'a', 'n', 'k', '\n',
        'd', 'a', 'n', 'k', 'e', 's', 't', '\n',
        'd', 'a', 'n', 't', 'e', '\n',
        'd', 'a', 'n', 'u', 'b', 'e', '\n',
        'd', 'a', 'n', 'z', 'i', 'g', '\n',
        'd', 'a', 'p', 'p', 'e', 'r', '\n',
        'd', 'a', 'p', 'p', 'l', 'e', '\n',
        'd', 'a', 'p', 'p', 'l', 'e', 'd', '\n',
        'd', 'a', 'p', 'p', 'l', 'e', 's', '\n',
        'd', 'a', 'r', 'e', '\n',
        'd', 'a', 'r', 'e', 'd', '\n',
        'd', 'a', 'r', 'e', 'd', 'e', 'v', 'i', 'l', '\n',
        'd', 'a', 'r', 'e', 's', '\n',
        'd', 'a', 'r', 'i', 'n', 'g', '\n',
        'd', 'a', 'r', 'i', 'n', 'g', 'l', 'y', '\n',
        'd', 'a', 'r', 'k', '\n',
        'd', 'a', 'r', 'k', 'e', 'n', '\n',
        'd', 'a', 'r', 'k', 'e', 'n', 'e', 'd', '\n',
        'd', 'a', 'r', 'k', 'e', 'n', 'i', 'n', 'g', '\n',
        'd', 'a', 'r', 'k', 'e', 'n', 's', '\n',
        'd', 'a', 'r', 'k', 'e', 'r', '\n',
        'd', 'a', 'r', 'k', 'e', 's', 't', '\n',
        'd', 'a', 'r', 'k', 'i', 's', 'h', '\n',
        'd', 'a', 'r', 'k', 'l', 'y', '\n',
        'd', 'a', 'r', 'k', 'n', 'e', 's', 's', '\n',
        'd', 'a', 'r', 'k', 'r', 'o', 'o', 'm', '\n',
        'd', 'a', 'r', 'k', 'r', 'o', 'o', 'm', 's', '\n',
        'd', 'a', 'r', 'l', 'i', 'n', 'g', '\n',
        'd', 'a', 'r', 'l', 'i', 'n', 'g', 's', '\n',
        'd', 'a', 'r', 'n', '\n',
        'd', 'a', 'r', 'n', 'e', 'd', '\n',
        'd', 'a', 'r', 'n', 'i', 'n', 'g', '\n',
        'd', 'a', 'r', 'n', 's', '\n',
        'd', 'a', 'r', 't', '\n',
        'd', 'a', 'r', 't', 'b', 'o', 'a', 'r', 'd', '\n',
        'd', 'a', 'r', 't', 'b', 'o', 'a', 'r', 'd', 's', '\n',
        'd', 'a', 'r', 't', 'e', 'd', '\n',
        'd', 'a', 'r', 't', 'e', 'r', '\n',
        'd', 'a', 'r', 't', 'e', 'r', 's', '\n',
        'd', 'a', 'r', 't', 'i', 'n', 'g', '\n',
        'd', 'a', 'r', 't', 's', '\n',
        'd', 'a', 'r', 'w', 'i', 'n', '\n',
        'd', 'a', 's', 'h', '\n',
        'd', 'a', 's', 'h', 'b', 'o', 'a', 'r', 'd', '\n',
        'd', 'a', 's', 'h', 'e', 'd', '\n',
        'd', 'a', 's', 'h', 'e', 's', '\n',
        'd', 'a', 's', 'h', 'i', 'n', 'g', '\n',
        'd', 'a', 's', 's', 'i', 'e', '\n',
        'd', 'a', 's', 's', 'i', 'e', 's', '\n',
        'd', 'a', 's', 't', 'a', 'r', 'd', 'l', 'y', '\n',
        'd', 'a', 't', 'a', '\n',
        'd', 'a', 't', 'a', 'b', 'a', 's', 'e', '\n',
        'd', 'a', 't', 'a', 'b', 'a', 's', 'e', 's', '\n',
        'd', 'a', 't', 'a', 'b', 'l', 'e', '\n',
        'd', 'a', 't', 'e', '\n',
        'd', 'a', 't', 'e', 'd', '\n',
        'd', 'a', 't', 'e', 'l', 'i', 'n', 'e', '\n',
        'd', 'a', 't', 'e', 's', '\n',
        'd', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'a', 't', 'i', 'v', 'e', '\n',
        'd', 'a', 't', 'u', 'm', '\n',
        'd', 'a', 'u', 'b', '\n',
        'd', 'a', 'u', 'b', 'e', 'd', '\n',
        'd', 'a', 'u', 'b', 'e', 'r', '\n',
        'd', 'a', 'u', 'b', 'i', 'n', 'g', '\n',
        'd', 'a', 'u', 'g', 'h', 't', 'e', 'r', '\n',
        'd', 'a', 'u', 'g', 'h', 't', 'e', 'r', 'i', 'n', 'l', 'a', 'w', '\n',
        'd', 'a', 'u', 'g', 'h', 't', 'e', 'r', 's', '\n',
        'd', 'a', 'u', 'g', 'h', 't', 'e', 'r', 's', 'i', 'n', 'l', 'a', 'w', '\n',
        'd', 'a', 'u', 'n', 't', '\n',
        'd', 'a', 'u', 'n', 't', 'e', 'd', '\n',
        'd', 'a', 'u', 'n', 't', 'i', 'n', 'g', '\n',
        'd', 'a', 'u', 'n', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'd', 'a', 'u', 'n', 't', 'l', 'e', 's', 's', '\n',
        'd', 'a', 'u', 'n', 't', 's', '\n',
        'd', 'a', 'u', 'p', 'h', 'i', 'n', '\n',
        'd', 'a', 'u', 'p', 'h', 'i', 'n', 's', '\n',
        'd', 'a', 'v', 'i', 'd', '\n',
        'd', 'a', 'v', 'i', 'n', 'c', 'i', '\n',
        'd', 'a', 'w', 'd', 'l', 'e', '\n',
        'd', 'a', 'w', 'd', 'l', 'e', 'd', '\n',
        'd', 'a', 'w', 'd', 'l', 'i', 'n', 'g', '\n',
        'd', 'a', 'w', 'n', '\n',
        'd', 'a', 'w', 'n', 'e', 'd', '\n',
        'd', 'a', 'w', 'n', 'i', 'n', 'g', '\n',
        'd', 'a', 'w', 'n', 's', '\n',
        'd', 'a', 'y', '\n',
        'd', 'a', 'y', 'b', 'r', 'e', 'a', 'k', '\n',
        'd', 'a', 'y', 'c', 'a', 'r', 'e', '\n',
        'd', 'a', 'y', 'd', 'r', 'e', 'a', 'm', '\n',
        'd', 'a', 'y', 'd', 'r', 'e', 'a', 'm', 'i', 'n', 'g', '\n',
        'd', 'a', 'y', 'd', 'r', 'e', 'a', 'm', 's', '\n',
        'd', 'a', 'y', 'l', 'i', 'g', 'h', 't', '\n',
        'd', 'a', 'y', 'l', 'i', 'g', 'h', 't', 's', '\n',
        'd', 'a', 'y', 'l', 'o', 'n', 'g', '\n',
        'd', 'a', 'y', 'o', 'l', 'd', '\n',
        'd', 'a', 'y', 's', '\n',
        'd', 'a', 'y', 't', 'i', 'm', 'e', '\n',
        'd', 'a', 'z', 'e', '\n',
        'd', 'a', 'z', 'e', 'd', '\n',
        'd', 'a', 'z', 'e', 'd', 'l', 'y', '\n',
        'd', 'a', 'z', 'i', 'n', 'g', '\n',
        'd', 'a', 'z', 'z', 'l', 'e', '\n',
        'd', 'a', 'z', 'z', 'l', 'e', 'd', '\n',
        'd', 'a', 'z', 'z', 'l', 'e', 'r', '\n',
        'd', 'a', 'z', 'z', 'l', 'e', 's', '\n',
        'd', 'a', 'z', 'z', 'l', 'i', 'n', 'g', '\n',
        'd', 'a', 'z', 'z', 'l', 'i', 'n', 'g', 'l', 'y', '\n',
        'd', 'd', 'a', 'y', '\n',
        'd', 'e', 'a', 'c', 'o', 'n', '\n',
        'd', 'e', 'a', 'c', 'o', 'n', 'e', 's', 's', '\n',
        'd', 'e', 'a', 'c', 'o', 'n', 'e', 's', 's', 'e', 's', '\n',
        'd', 'e', 'a', 'c', 'o', 'n', 's', '\n',
        'd', 'e', 'a', 'c', 't', 'i', 'v', 'a', 't', 'e', '\n',
        'd', 'e', 'a', 'c', 't', 'i', 'v', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 'a', 'c', 't', 'i', 'v', 'a', 't', 'e', 's', '\n',
        'd', 'e', 'a', 'c', 't', 'i', 'v', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'a', 'c', 't', 'i', 'v', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'a', 'd', '\n',
        'd', 'e', 'a', 'd', 'b', 'e', 'a', 't', '\n',
        'd', 'e', 'a', 'd', 'e', 'n', '\n',
        'd', 'e', 'a', 'd', 'e', 'n', 'd', '\n',
        'd', 'e', 'a', 'd', 'e', 'n', 'e', 'd', '\n',
        'd', 'e', 'a', 'd', 'e', 'n', 'i', 'n', 'g', '\n',
        'd', 'e', 'a', 'd', 'e', 'n', 's', '\n',
        'd', 'e', 'a', 'd', 'e', 'r', '\n',
        'd', 'e', 'a', 'd', 'l', 'i', 'e', 'r', '\n',
        'd', 'e', 'a', 'd', 'l', 'i', 'e', 's', 't', '\n',
        'd', 'e', 'a', 'd', 'l', 'i', 'n', 'e', '\n',
        'd', 'e', 'a', 'd', 'l', 'i', 'n', 'e', 's', '\n',
        'd', 'e', 'a', 'd', 'l', 'o', 'c', 'k', '\n',
        'd', 'e', 'a', 'd', 'l', 'o', 'c', 'k', 'e', 'd', '\n',
        'd', 'e', 'a', 'd', 'l', 'o', 'c', 'k', 'i', 'n', 'g', '\n',
        'd', 'e', 'a', 'd', 'l', 'o', 'c', 'k', 's', '\n',
        'd', 'e', 'a', 'd', 'l', 'y', '\n',
        'd', 'e', 'a', 'd', 'n', 'e', 's', 's', '\n',
        'd', 'e', 'a', 'd', 'o', 'n', '\n',
        'd', 'e', 'a', 'd', 'p', 'a', 'n', '\n',
        'd', 'e', 'a', 'd', 's', 'e', 'a', '\n',
        'd', 'e', 'a', 'f', '\n',
        'd', 'e', 'a', 'f', 'a', 'n', 'd', 'd', 'u', 'm', 'b', '\n',
        'd', 'e', 'a', 'f', 'e', 'n', '\n',
        'd', 'e', 'a', 'f', 'e', 'n', 'e', 'd', '\n',
        'd', 'e', 'a', 'f', 'e', 'n', 'i', 'n', 'g', '\n',
        'd', 'e', 'a', 'f', 'e', 'n', 'i', 'n', 'g', 'l', 'y', '\n',
        'd', 'e', 'a', 'f', 'e', 'n', 's', '\n',
        'd', 'e', 'a', 'f', 'e', 'r', '\n',
        'd', 'e', 'a', 'f', 'e', 's', 't', '\n',
        'd', 'e', 'a', 'f', 'n', 'e', 's', 's', '\n',
        'd', 'e', 'a', 'l', '\n',
        'd', 'e', 'a', 'l', 'e', 'r', '\n',
        'd', 'e', 'a', 'l', 'e', 'r', 's', '\n',
        'd', 'e', 'a', 'l', 'e', 'r', 's', 'h', 'i', 'p', '\n',
        'd', 'e', 'a', 'l', 'e', 'r', 's', 'h', 'i', 'p', 's', '\n',
        'd', 'e', 'a', 'l', 'i', 'n', 'g', '\n',
        'd', 'e', 'a', 'l', 'i', 'n', 'g', 's', '\n',
        'd', 'e', 'a', 'l', 's', '\n',
        'd', 'e', 'a', 'l', 't', '\n',
        'd', 'e', 'a', 'n', '\n',
        'd', 'e', 'a', 'n', 'e', 'r', 'y', '\n',
        'd', 'e', 'a', 'n', 's', '\n',
        'd', 'e', 'a', 'r', '\n',
        'd', 'e', 'a', 'r', 'e', 'r', '\n',
        'd', 'e', 'a', 'r', 'e', 's', 't', '\n',
        'd', 'e', 'a', 'r', 'i', 'e', '\n',
        'd', 'e', 'a', 'r', 'i', 'e', 's', '\n',
        'd', 'e', 'a', 'r', 'l', 'y', '\n',
        'd', 'e', 'a', 'r', 'n', 'e', 's', 's', '\n',
        'd', 'e', 'a', 'r', 's', '\n',
        'd', 'e', 'a', 'r', 't', 'h', '\n',
        'd', 'e', 'a', 'r', 'y', '\n',
        'd', 'e', 'a', 't', 'h', '\n',
        'd', 'e', 'a', 't', 'h', 'b', 'e', 'd', '\n',
        'd', 'e', 'a', 't', 'h', 'l', 'e', 's', 's', '\n',
        'd', 'e', 'a', 't', 'h', 'l', 'y', '\n',
        'd', 'e', 'a', 't', 'h', 's', '\n',
        'd', 'e', 'b', '\n',
        'd', 'e', 'b', 'a', 'c', 'l', 'e', '\n',
        'd', 'e', 'b', 'a', 'c', 'l', 'e', 's', '\n',
        'd', 'e', 'b', 'a', 'r', '\n',
        'd', 'e', 'b', 'a', 'r', 'k', '\n',
        'd', 'e', 'b', 'a', 'r', 'r', 'e', 'd', '\n',
        'd', 'e', 'b', 'a', 'r', 's', '\n',
        'd', 'e', 'b', 'a', 's', 'e', '\n',
        'd', 'e', 'b', 'a', 's', 'e', 'd', '\n',
        'd', 'e', 'b', 'a', 's', 'e', 'm', 'e', 'n', 't', '\n',
        'd', 'e', 'b', 'a', 's', 'e', 'r', '\n',
        'd', 'e', 'b', 'a', 's', 'i', 'n', 'g', '\n',
        'd', 'e', 'b', 'a', 't', 'a', 'b', 'l', 'e', '\n',
        'd', 'e', 'b', 'a', 't', 'e', '\n',
        'd', 'e', 'b', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 'b', 'a', 't', 'e', 'r', '\n',
        'd', 'e', 'b', 'a', 't', 'e', 'r', 's', '\n',
        'd', 'e', 'b', 'a', 't', 'e', 's', '\n',
        'd', 'e', 'b', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'b', 'a', 'u', 'c', 'h', '\n',
        'd', 'e', 'b', 'a', 'u', 'c', 'h', 'e', 'd', '\n',
        'd', 'e', 'b', 'a', 'u', 'c', 'h', 'e', 'r', 'y', '\n',
        'd', 'e', 'b', 'e', 'n', 't', 'u', 'r', 'e', '\n',
        'd', 'e', 'b', 'e', 'n', 't', 'u', 'r', 'e', 's', '\n',
        'd', 'e', 'b', 'i', 'l', 'i', 't', 'a', 't', 'e', '\n',
        'd', 'e', 'b', 'i', 'l', 'i', 't', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 'b', 'i', 'l', 'i', 't', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'd', 'e', 'b', 'i', 't', '\n',
        'd', 'e', 'b', 'i', 't', 'e', 'd', '\n',
        'd', 'e', 'b', 'i', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'b', 'i', 't', 's', '\n',
        'd', 'e', 'b', 'o', 'n', 'a', 'i', 'r', '\n',
        'd', 'e', 'b', 'o', 'n', 'e', '\n',
        'd', 'e', 'b', 'o', 'n', 'e', 'd', '\n',
        'd', 'e', 'b', 'o', 'n', 'e', 's', '\n',
        'd', 'e', 'b', 'r', 'i', 'e', 'f', '\n',
        'd', 'e', 'b', 'r', 'i', 'e', 'f', 'e', 'd', '\n',
        'd', 'e', 'b', 'r', 'i', 'e', 'f', 'i', 'n', 'g', '\n',
        'd', 'e', 'b', 'r', 'i', 's', '\n',
        'd', 'e', 'b', 't', '\n',
        'd', 'e', 'b', 't', 'o', 'r', '\n',
        'd', 'e', 'b', 't', 'o', 'r', 's', '\n',
        'd', 'e', 'b', 't', 's', '\n',
        'd', 'e', 'b', 'u', 'g', '\n',
        'd', 'e', 'b', 'u', 'g', 'g', 'e', 'd', '\n',
        'd', 'e', 'b', 'u', 'g', 'g', 'e', 'r', '\n',
        'd', 'e', 'b', 'u', 'g', 'g', 'e', 'r', 's', '\n',
        'd', 'e', 'b', 'u', 'g', 'g', 'i', 'n', 'g', '\n',
        'd', 'e', 'b', 'u', 'g', 's', '\n',
        'd', 'e', 'b', 'u', 'n', 'k', '\n',
        'd', 'e', 'b', 'u', 'n', 'k', 's', '\n',
        'd', 'e', 'b', 'u', 't', '\n',
        'd', 'e', 'b', 'u', 't', 'a', 'n', 't', '\n',
        'd', 'e', 'b', 'u', 't', 'a', 'n', 't', 'e', '\n',
        'd', 'e', 'b', 'u', 't', 'a', 'n', 't', 'e', 's', '\n',
        'd', 'e', 'b', 'u', 't', 'a', 'n', 't', 's', '\n',
        'd', 'e', 'b', 'u', 't', 's', '\n',
        'd', 'e', 'c', 'a', 'd', 'e', '\n',
        'd', 'e', 'c', 'a', 'd', 'e', 'n', 'c', 'e', '\n',
        'd', 'e', 'c', 'a', 'd', 'e', 'n', 't', '\n',
        'd', 'e', 'c', 'a', 'd', 'e', 's', '\n',
        'd', 'e', 'c', 'a', 'f', '\n',
        'd', 'e', 'c', 'a', 'f', 'f', 'e', 'i', 'n', 'a', 't', 'e', '\n',
        'd', 'e', 'c', 'a', 'f', 'f', 'e', 'i', 'n', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 'c', 'a', 'g', 'o', 'n', '\n',
        'd', 'e', 'c', 'a', 'g', 'o', 'n', 's', '\n',
        'd', 'e', 'c', 'a', 'm', 'p', '\n',
        'd', 'e', 'c', 'a', 'm', 'p', 'e', 'd', '\n',
        'd', 'e', 'c', 'a', 'n', 't', '\n',
        'd', 'e', 'c', 'a', 'n', 't', 'e', 'd', '\n',
        'd', 'e', 'c', 'a', 'n', 't', 'e', 'r', '\n',
        'd', 'e', 'c', 'a', 'n', 't', 'e', 'r', 's', '\n',
        'd', 'e', 'c', 'a', 'n', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'c', 'a', 'n', 't', 's', '\n',
        'd', 'e', 'c', 'a', 'p', 'i', 't', 'a', 't', 'e', '\n',
        'd', 'e', 'c', 'a', 'p', 'i', 't', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 'c', 'a', 'p', 'i', 't', 'a', 't', 'e', 's', '\n',
        'd', 'e', 'c', 'a', 'p', 'i', 't', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'c', 'a', 'p', 'i', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'c', 'a', 'p', 'i', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'c', 'a', 'p', 'o', 'd', '\n',
        'd', 'e', 'c', 'a', 't', 'h', 'l', 'o', 'n', '\n',
        'd', 'e', 'c', 'a', 'y', '\n',
        'd', 'e', 'c', 'a', 'y', 'e', 'd', '\n',
        'd', 'e', 'c', 'a', 'y', 'i', 'n', 'g', '\n',
        'd', 'e', 'c', 'a', 'y', 's', '\n',
        'd', 'e', 'c', 'e', 'a', 's', 'e', '\n',
        'd', 'e', 'c', 'e', 'a', 's', 'e', 'd', '\n',
        'd', 'e', 'c', 'e', 'a', 's', 'e', 's', '\n',
        'd', 'e', 'c', 'e', 'i', 't', '\n',
        'd', 'e', 'c', 'e', 'i', 't', 'f', 'u', 'l', '\n',
        'd', 'e', 'c', 'e', 'i', 't', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'd', 'e', 'c', 'e', 'i', 't', 's', '\n',
        'd', 'e', 'c', 'e', 'i', 'v', 'e', '\n',
        'd', 'e', 'c', 'e', 'i', 'v', 'e', 'd', '\n',
        'd', 'e', 'c', 'e', 'i', 'v', 'e', 'r', '\n',
        'd', 'e', 'c', 'e', 'i', 'v', 'e', 's', '\n',
        'd', 'e', 'c', 'e', 'i', 'v', 'i', 'n', 'g', '\n',
        'd', 'e', 'c', 'e', 'l', 'e', 'r', 'a', 't', 'e', '\n',
        'd', 'e', 'c', 'e', 'l', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 'c', 'e', 'l', 'e', 'r', 'a', 't', 'e', 's', '\n',
        'd', 'e', 'c', 'e', 'l', 'e', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'c', 'e', 'l', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'c', 'e', 'l', 'e', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'c', 'e', 'm', 'b', 'e', 'r', '\n',
        'd', 'e', 'c', 'e', 'n', 'c', 'y', '\n',
        'd', 'e', 'c', 'e', 'n', 't', '\n',
        'd', 'e', 'c', 'e', 'n', 't', 'l', 'y', '\n',
        'd', 'e', 'c', 'e', 'n', 't', 'r', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'c', 'e', 'n', 't', 'r', 'a', 'l', 'i', 's', 'e', '\n',
        'd', 'e', 'c', 'e', 'n', 't', 'r', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'd', 'e', 'c', 'e', 'n', 't', 'r', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'd', 'e', 'c', 'e', 'p', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'c', 'e', 'p', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'c', 'e', 'p', 't', 'i', 'v', 'e', '\n',
        'd', 'e', 'c', 'e', 'p', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'd', 'e', 'c', 'i', 'b', 'e', 'l', '\n',
        'd', 'e', 'c', 'i', 'b', 'e', 'l', 's', '\n',
        'd', 'e', 'c', 'i', 'd', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'd', 'e', 'c', 'i', 'd', 'a', 'b', 'l', 'e', '\n',
        'd', 'e', 'c', 'i', 'd', 'e', '\n',
        'd', 'e', 'c', 'i', 'd', 'e', 'd', '\n',
        'd', 'e', 'c', 'i', 'd', 'e', 'd', 'l', 'y', '\n',
        'd', 'e', 'c', 'i', 'd', 'e', 'r', '\n',
        'd', 'e', 'c', 'i', 'd', 'e', 's', '\n',
        'd', 'e', 'c', 'i', 'd', 'i', 'n', 'g', '\n',
        'd', 'e', 'c', 'i', 'd', 'u', 'o', 'u', 's', '\n',
        'd', 'e', 'c', 'i', 'l', 'e', '\n',
        'd', 'e', 'c', 'i', 'l', 'e', 's', '\n',
        'd', 'e', 'c', 'i', 'l', 'i', 't', 'r', 'e', '\n',
        'd', 'e', 'c', 'i', 'm', 'a', 'l', '\n',
        'd', 'e', 'c', 'i', 'm', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'c', 'i', 'm', 'a', 'l', 'i', 's', 'e', '\n',
        'd', 'e', 'c', 'i', 'm', 'a', 'l', 's', '\n',
        'd', 'e', 'c', 'i', 'm', 'a', 't', 'e', '\n',
        'd', 'e', 'c', 'i', 'm', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 'c', 'i', 'm', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'c', 'i', 'm', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'c', 'i', 'm', 'e', 't', 'r', 'e', 's', '\n',
        'd', 'e', 'c', 'i', 'p', 'h', 'e', 'r', '\n',
        'd', 'e', 'c', 'i', 'p', 'h', 'e', 'r', 'a', 'b', 'l', 'e', '\n',
        'd', 'e', 'c', 'i', 'p', 'h', 'e', 'r', 'e', 'd', '\n',
        'd', 'e', 'c', 'i', 'p', 'h', 'e', 'r', 'i', 'n', 'g', '\n',
        'd', 'e', 'c', 'i', 'p', 'h', 'e', 'r', 'm', 'e', 'n', 't', '\n',
        'd', 'e', 'c', 'i', 'p', 'h', 'e', 'r', 'm', 'e', 'n', 't', 's', '\n',
        'd', 'e', 'c', 'i', 's', 'i', 'o', 'n', '\n',
        'd', 'e', 'c', 'i', 's', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'c', 'i', 's', 'i', 'v', 'e', '\n',
        'd', 'e', 'c', 'i', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'd', 'e', 'c', 'i', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'd', 'e', 'c', 'k', '\n',
        'd', 'e', 'c', 'k', 'c', 'h', 'a', 'i', 'r', '\n',
        'd', 'e', 'c', 'k', 'c', 'h', 'a', 'i', 'r', 's', '\n',
        'd', 'e', 'c', 'k', 'e', 'd', '\n',
        'd', 'e', 'c', 'k', 'e', 'r', '\n',
        'd', 'e', 'c', 'k', 'i', 'n', 'g', '\n',
        'd', 'e', 'c', 'k', 's', '\n',
        'd', 'e', 'c', 'l', 'a', 'i', 'm', '\n',
        'd', 'e', 'c', 'l', 'a', 'i', 'm', 'e', 'd', '\n',
        'd', 'e', 'c', 'l', 'a', 'i', 'm', 'i', 'n', 'g', '\n',
        'd', 'e', 'c', 'l', 'a', 'i', 'm', 's', '\n',
        'd', 'e', 'c', 'l', 'a', 'm', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'c', 'l', 'a', 'm', 'a', 't', 'o', 'r', 'y', '\n',
        'd', 'e', 'c', 'l', 'a', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'c', 'l', 'a', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'c', 'l', 'a', 'r', 'a', 't', 'i', 'v', 'e', '\n',
        'd', 'e', 'c', 'l', 'a', 'r', 'a', 't', 'o', 'r', 'y', '\n',
        'd', 'e', 'c', 'l', 'a', 'r', 'e', '\n',
        'd', 'e', 'c', 'l', 'a', 'r', 'e', 'd', '\n',
        'd', 'e', 'c', 'l', 'a', 'r', 'e', 'r', '\n',
        'd', 'e', 'c', 'l', 'a', 'r', 'e', 'r', 's', '\n',
        'd', 'e', 'c', 'l', 'a', 'r', 'e', 's', '\n',
        'd', 'e', 'c', 'l', 'a', 'r', 'i', 'n', 'g', '\n',
        'd', 'e', 'c', 'l', 'a', 's', 's', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'c', 'l', 'a', 's', 's', 'i', 'f', 'i', 'e', 'd', '\n',
        'd', 'e', 'c', 'l', 'e', 'n', 's', 'i', 'o', 'n', '\n',
        'd', 'e', 'c', 'l', 'e', 'n', 's', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'c', 'l', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'c', 'l', 'i', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'c', 'l', 'i', 'n', 'e', '\n',
        'd', 'e', 'c', 'l', 'i', 'n', 'e', 'd', '\n',
        'd', 'e', 'c', 'l', 'i', 'n', 'e', 's', '\n',
        'd', 'e', 'c', 'l', 'i', 'n', 'i', 'n', 'g', '\n',
        'd', 'e', 'c', 'l', 'i', 'v', 'i', 't', 'y', '\n',
        'd', 'e', 'c', 'o', '\n',
        'd', 'e', 'c', 'o', 'd', 'e', '\n',
        'd', 'e', 'c', 'o', 'd', 'e', 'd', '\n',
        'd', 'e', 'c', 'o', 'd', 'e', 'r', '\n',
        'd', 'e', 'c', 'o', 'd', 'e', 'r', 's', '\n',
        'd', 'e', 'c', 'o', 'd', 'e', 's', '\n',
        'd', 'e', 'c', 'o', 'd', 'i', 'n', 'g', '\n',
        'd', 'e', 'c', 'o', 'k', 'e', '\n',
        'd', 'e', 'c', 'o', 'l', 'o', 'n', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'c', 'o', 'm', 'm', 'i', 's', 's', 'i', 'o', 'n', '\n',
        'd', 'e', 'c', 'o', 'm', 'm', 'i', 's', 's', 'i', 'o', 'n', 'e', 'd', '\n',
        'd', 'e', 'c', 'o', 'm', 'm', 'i', 's', 's', 'i', 'o', 'n', 'i', 'n', 'g', '\n',
        'd', 'e', 'c', 'o', 'm', 'p', 'o', 's', 'a', 'b', 'l', 'e', '\n',
        'd', 'e', 'c', 'o', 'm', 'p', 'o', 's', 'e', '\n',
        'd', 'e', 'c', 'o', 'm', 'p', 'o', 's', 'e', 'd', '\n',
        'd', 'e', 'c', 'o', 'm', 'p', 'o', 's', 'e', 's', '\n',
        'd', 'e', 'c', 'o', 'm', 'p', 'o', 's', 'i', 'n', 'g', '\n',
        'd', 'e', 'c', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'c', 'o', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'c', 'o', 'm', 'p', 'r', 'e', 's', 's', '\n',
        'd', 'e', 'c', 'o', 'm', 'p', 'r', 'e', 's', 's', 'e', 'd', '\n',
        'd', 'e', 'c', 'o', 'm', 'p', 'r', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'd', 'e', 'c', 'o', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', '\n',
        'd', 'e', 'c', 'o', 'n', 'g', 'e', 's', 't', 'a', 'n', 't', 's', '\n',
        'd', 'e', 'c', 'o', 'n', 's', 't', 'r', 'u', 'c', 't', '\n',
        'd', 'e', 'c', 'o', 'n', 's', 't', 'r', 'u', 'c', 't', 'e', 'd', '\n',
        'd', 'e', 'c', 'o', 'n', 's', 't', 'r', 'u', 'c', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'c', 'o', 'n', 's', 't', 'r', 'u', 'c', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'c', 'o', 'n', 's', 't', 'r', 'u', 'c', 't', 'i', 'o', 'n', 'i', 's', 't', '\n',
        'd', 'e', 'c', 'o', 'n', 's', 't', 'r', 'u', 'c', 't', 'i', 'v', 'e', '\n',
        'd', 'e', 'c', 'o', 'n', 't', 'a', 'm', 'i', 'n', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 'c', 'o', 'n', 't', 'a', 'm', 'i', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'c', 'o', 'n', 't', 'a', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'c', 'o', 'n', 'v', 'o', 'l', 'u', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'c', 'o', 'n', 'v', 'o', 'l', 'v', 'e', '\n',
        'd', 'e', 'c', 'o', 'r', '\n',
        'd', 'e', 'c', 'o', 'r', 'a', 't', 'e', '\n',
        'd', 'e', 'c', 'o', 'r', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 'c', 'o', 'r', 'a', 't', 'e', 's', '\n',
        'd', 'e', 'c', 'o', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'c', 'o', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'c', 'o', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'c', 'o', 'r', 'a', 't', 'i', 'v', 'e', '\n',
        'd', 'e', 'c', 'o', 'r', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'd', 'e', 'c', 'o', 'r', 'a', 't', 'o', 'r', '\n',
        'd', 'e', 'c', 'o', 'r', 'a', 't', 'o', 'r', 's', '\n',
        'd', 'e', 'c', 'o', 'r', 'o', 'u', 's', '\n',
        'd', 'e', 'c', 'o', 'r', 'o', 'u', 's', 'l', 'y', '\n',
        'd', 'e', 'c', 'o', 'r', 's', '\n',
        'd', 'e', 'c', 'o', 'r', 'u', 'm', '\n',
        'd', 'e', 'c', 'o', 'u', 'p', 'l', 'e', '\n',
        'd', 'e', 'c', 'o', 'u', 'p', 'l', 'e', 'd', '\n',
        'd', 'e', 'c', 'o', 'u', 'p', 'l', 'i', 'n', 'g', '\n',
        'd', 'e', 'c', 'o', 'y', '\n',
        'd', 'e', 'c', 'o', 'y', 'e', 'd', '\n',
        'd', 'e', 'c', 'o', 'y', 'i', 'n', 'g', '\n',
        'd', 'e', 'c', 'o', 'y', 's', '\n',
        'd', 'e', 'c', 'r', 'e', 'a', 's', 'e', '\n',
        'd', 'e', 'c', 'r', 'e', 'a', 's', 'e', 'd', '\n',
        'd', 'e', 'c', 'r', 'e', 'a', 's', 'e', 's', '\n',
        'd', 'e', 'c', 'r', 'e', 'a', 's', 'i', 'n', 'g', '\n',
        'd', 'e', 'c', 'r', 'e', 'a', 's', 'i', 'n', 'g', 'l', 'y', '\n',
        'd', 'e', 'c', 'r', 'e', 'e', '\n',
        'd', 'e', 'c', 'r', 'e', 'e', 'd', '\n',
        'd', 'e', 'c', 'r', 'e', 'e', 'i', 'n', 'g', '\n',
        'd', 'e', 'c', 'r', 'e', 'e', 's', '\n',
        'd', 'e', 'c', 'r', 'e', 'm', 'e', 'n', 't', '\n',
        'd', 'e', 'c', 'r', 'e', 'm', 'e', 'n', 't', 'a', 'l', '\n',
        'd', 'e', 'c', 'r', 'e', 'm', 'e', 'n', 't', 'e', 'd', '\n',
        'd', 'e', 'c', 'r', 'e', 'm', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'c', 'r', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'd', 'e', 'c', 'r', 'e', 'p', 'i', 't', '\n',
        'd', 'e', 'c', 'r', 'e', 'p', 'i', 't', 'u', 'd', 'e', '\n',
        'd', 'e', 'c', 'r', 'i', 'e', 'd', '\n',
        'd', 'e', 'c', 'r', 'i', 'e', 's', '\n',
        'd', 'e', 'c', 'r', 'i', 'm', 'i', 'n', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'c', 'r', 'i', 'm', 'i', 'n', 'a', 'l', 'i', 's', 'e', '\n',
        'd', 'e', 'c', 'r', 'i', 'm', 'i', 'n', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'd', 'e', 'c', 'r', 'i', 'm', 'i', 'n', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'd', 'e', 'c', 'r', 'y', '\n',
        'd', 'e', 'c', 'r', 'y', 'i', 'n', 'g', '\n',
        'd', 'e', 'c', 'r', 'y', 'p', 't', '\n',
        'd', 'e', 'c', 'r', 'y', 'p', 't', 'e', 'd', '\n',
        'd', 'e', 'c', 'r', 'y', 'p', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'c', 'r', 'y', 'p', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'c', 'r', 'y', 'p', 't', 's', '\n',
        'd', 'e', 'c', 'u', 's', 't', 'o', 'm', 'i', 's', 'e', 'd', '\n',
        'd', 'e', 'd', 'i', 'c', 'a', 't', 'e', '\n',
        'd', 'e', 'd', 'i', 'c', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 'd', 'i', 'c', 'a', 't', 'e', 's', '\n',
        'd', 'e', 'd', 'i', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'd', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'd', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'd', 'u', 'c', 'e', '\n',
        'd', 'e', 'd', 'u', 'c', 'e', 'd', '\n',
        'd', 'e', 'd', 'u', 'c', 'e', 's', '\n',
        'd', 'e', 'd', 'u', 'c', 'i', 'b', 'l', 'e', '\n',
        'd', 'e', 'd', 'u', 'c', 'i', 'n', 'g', '\n',
        'd', 'e', 'd', 'u', 'c', 't', '\n',
        'd', 'e', 'd', 'u', 'c', 't', 'e', 'd', '\n',
        'd', 'e', 'd', 'u', 'c', 't', 'i', 'b', 'l', 'e', '\n',
        'd', 'e', 'd', 'u', 'c', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'd', 'u', 'c', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'd', 'u', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'd', 'u', 'c', 't', 'i', 'v', 'e', '\n',
        'd', 'e', 'd', 'u', 'c', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'd', 'e', 'd', 'u', 'c', 't', 's', '\n',
        'd', 'e', 'e', '\n',
        'd', 'e', 'e', 'd', '\n',
        'd', 'e', 'e', 'd', 's', '\n',
        'd', 'e', 'e', 'j', 'a', 'y', '\n',
        'd', 'e', 'e', 'm', '\n',
        'd', 'e', 'e', 'm', 'e', 'd', '\n',
        'd', 'e', 'e', 'm', 'i', 'n', 'g', '\n',
        'd', 'e', 'e', 'm', 's', '\n',
        'd', 'e', 'e', 'p', '\n',
        'd', 'e', 'e', 'p', 'e', 'n', '\n',
        'd', 'e', 'e', 'p', 'e', 'n', 'e', 'd', '\n',
        'd', 'e', 'e', 'p', 'e', 'n', 'i', 'n', 'g', '\n',
        'd', 'e', 'e', 'p', 'e', 'n', 's', '\n',
        'd', 'e', 'e', 'p', 'e', 'r', '\n',
        'd', 'e', 'e', 'p', 'e', 's', 't', '\n',
        'd', 'e', 'e', 'p', 'f', 'r', 'e', 'e', 'z', 'e', '\n',
        'd', 'e', 'e', 'p', 'f', 'r', 'e', 'e', 'z', 'i', 'n', 'g', '\n',
        'd', 'e', 'e', 'p', 'f', 'r', 'i', 'e', 'd', '\n',
        'd', 'e', 'e', 'p', 'f', 'r', 'o', 'z', 'e', 'n', '\n',
        'd', 'e', 'e', 'p', 'i', 's', 'h', '\n',
        'd', 'e', 'e', 'p', 'l', 'y', '\n',
        'd', 'e', 'e', 'p', 'n', 'e', 's', 's', '\n',
        'd', 'e', 'e', 'p', 'r', 'o', 'o', 't', 'e', 'd', '\n',
        'd', 'e', 'e', 'p', 's', '\n',
        'd', 'e', 'e', 'p', 's', 'e', 'a', '\n',
        'd', 'e', 'e', 'p', 's', 'e', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 'e', 'r', '\n',
        'd', 'e', 'e', 'r', 's', 't', 'a', 'l', 'k', 'e', 'r', '\n',
        'd', 'e', 'e', 'r', 's', 't', 'a', 'l', 'k', 'e', 'r', 's', '\n',
        'd', 'e', 'e', 'r', 's', 't', 'a', 'l', 'k', 'i', 'n', 'g', '\n',
        'd', 'e', 'f', 'a', 'c', 'e', '\n',
        'd', 'e', 'f', 'a', 'c', 'e', 'd', '\n',
        'd', 'e', 'f', 'a', 'c', 'e', 's', '\n',
        'd', 'e', 'f', 'a', 'c', 'i', 'n', 'g', '\n',
        'd', 'e', 'f', 'a', 'c', 't', 'o', '\n',
        'd', 'e', 'f', 'a', 'm', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'f', 'a', 'm', 'a', 't', 'o', 'r', 'y', '\n',
        'd', 'e', 'f', 'a', 'm', 'e', '\n',
        'd', 'e', 'f', 'a', 'm', 'e', 'd', '\n',
        'd', 'e', 'f', 'a', 'm', 'e', 'r', '\n',
        'd', 'e', 'f', 'a', 'm', 'e', 's', '\n',
        'd', 'e', 'f', 'a', 'm', 'i', 'n', 'g', '\n',
        'd', 'e', 'f', 'a', 'u', 'l', 't', '\n',
        'd', 'e', 'f', 'a', 'u', 'l', 't', 'e', 'd', '\n',
        'd', 'e', 'f', 'a', 'u', 'l', 't', 'e', 'r', '\n',
        'd', 'e', 'f', 'a', 'u', 'l', 't', 'e', 'r', 's', '\n',
        'd', 'e', 'f', 'a', 'u', 'l', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'f', 'a', 'u', 'l', 't', 's', '\n',
        'd', 'e', 'f', 'e', 'a', 't', '\n',
        'd', 'e', 'f', 'e', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 'f', 'e', 'a', 't', 'e', 'r', '\n',
        'd', 'e', 'f', 'e', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'f', 'e', 'a', 't', 'i', 's', 'm', '\n',
        'd', 'e', 'f', 'e', 'a', 't', 'i', 's', 't', '\n',
        'd', 'e', 'f', 'e', 'a', 't', 's', '\n',
        'd', 'e', 'f', 'e', 'c', 'a', 't', 'e', '\n',
        'd', 'e', 'f', 'e', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'f', 'e', 'c', 't', '\n',
        'd', 'e', 'f', 'e', 'c', 't', 'e', 'd', '\n',
        'd', 'e', 'f', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'f', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'f', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'f', 'e', 'c', 't', 'i', 'v', 'e', '\n',
        'd', 'e', 'f', 'e', 'c', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'd', 'e', 'f', 'e', 'c', 't', 'i', 'v', 'e', 's', '\n',
        'd', 'e', 'f', 'e', 'c', 't', 'o', 'r', '\n',
        'd', 'e', 'f', 'e', 'c', 't', 'o', 'r', 's', '\n',
        'd', 'e', 'f', 'e', 'c', 't', 's', '\n',
        'd', 'e', 'f', 'e', 'n', 'c', 'e', '\n',
        'd', 'e', 'f', 'e', 'n', 'c', 'e', 'l', 'e', 's', 's', '\n',
        'd', 'e', 'f', 'e', 'n', 'c', 'e', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'd', 'e', 'f', 'e', 'n', 'c', 'e', 's', '\n',
        'd', 'e', 'f', 'e', 'n', 'd', '\n',
        'd', 'e', 'f', 'e', 'n', 'd', 'a', 'n', 't', '\n',
        'd', 'e', 'f', 'e', 'n', 'd', 'a', 'n', 't', 's', '\n',
        'd', 'e', 'f', 'e', 'n', 'd', 'e', 'd', '\n',
        'd', 'e', 'f', 'e', 'n', 'd', 'e', 'r', '\n',
        'd', 'e', 'f', 'e', 'n', 'd', 'e', 'r', 's', '\n',
        'd', 'e', 'f', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'd', 'e', 'f', 'e', 'n', 'd', 's', '\n',
        'd', 'e', 'f', 'e', 'n', 'e', 's', 't', 'r', 'a', 't', 'e', '\n',
        'd', 'e', 'f', 'e', 'n', 'e', 's', 't', 'r', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 'f', 'e', 'n', 'e', 's', 't', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'f', 'e', 'n', 's', 'e', 's', '\n',
        'd', 'e', 'f', 'e', 'n', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'd', 'e', 'f', 'e', 'n', 's', 'i', 'b', 'l', 'e', '\n',
        'd', 'e', 'f', 'e', 'n', 's', 'i', 'v', 'e', '\n',
        'd', 'e', 'f', 'e', 'n', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'd', 'e', 'f', 'e', 'n', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'd', 'e', 'f', 'e', 'r', '\n',
        'd', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'e', '\n',
        'd', 'e', 'f', 'e', 'r', 'e', 'n', 't', 'i', 'a', 'l', '\n',
        'd', 'e', 'f', 'e', 'r', 'e', 'n', 't', 'i', 'a', 'l', 'l', 'y', '\n',
        'd', 'e', 'f', 'e', 'r', 'm', 'e', 'n', 't', '\n',
        'd', 'e', 'f', 'e', 'r', 'r', 'a', 'l', '\n',
        'd', 'e', 'f', 'e', 'r', 'r', 'e', 'd', '\n',
        'd', 'e', 'f', 'e', 'r', 'r', 'i', 'n', 'g', '\n',
        'd', 'e', 'f', 'e', 'r', 's', '\n',
        'd', 'e', 'f', 'i', 'a', 'n', 'c', 'e', '\n',
        'd', 'e', 'f', 'i', 'a', 'n', 't', '\n',
        'd', 'e', 'f', 'i', 'a', 'n', 't', 'l', 'y', '\n',
        'd', 'e', 'f', 'i', 'b', 'r', 'i', 'l', 'l', 'a', 't', 'o', 'r', '\n',
        'd', 'e', 'f', 'i', 'b', 'r', 'i', 'l', 'l', 'a', 't', 'o', 'r', 's', '\n',
        'd', 'e', 'f', 'i', 'c', 'i', 'e', 'n', 'c', 'i', 'e', 's', '\n',
        'd', 'e', 'f', 'i', 'c', 'i', 'e', 'n', 'c', 'y', '\n',
        'd', 'e', 'f', 'i', 'c', 'i', 'e', 'n', 't', '\n',
        'd', 'e', 'f', 'i', 'c', 'i', 't', '\n',
        'd', 'e', 'f', 'i', 'c', 'i', 't', 's', '\n',
        'd', 'e', 'f', 'i', 'e', 'd', '\n',
        'd', 'e', 'f', 'i', 'e', 'r', '\n',
        'd', 'e', 'f', 'i', 'e', 's', '\n',
        'd', 'e', 'f', 'i', 'l', 'e', '\n',
        'd', 'e', 'f', 'i', 'l', 'e', 'd', '\n',
        'd', 'e', 'f', 'i', 'l', 'e', 'm', 'e', 'n', 't', '\n',
        'd', 'e', 'f', 'i', 'l', 'e', 's', '\n',
        'd', 'e', 'f', 'i', 'l', 'i', 'n', 'g', '\n',
        'd', 'e', 'f', 'i', 'n', 'a', 'b', 'l', 'e', '\n',
        'd', 'e', 'f', 'i', 'n', 'a', 'b', 'l', 'y', '\n',
        'd', 'e', 'f', 'i', 'n', 'e', '\n',
        'd', 'e', 'f', 'i', 'n', 'e', 'd', '\n',
        'd', 'e', 'f', 'i', 'n', 'e', 'r', '\n',
        'd', 'e', 'f', 'i', 'n', 'e', 's', '\n',
        'd', 'e', 'f', 'i', 'n', 'i', 'n', 'g', '\n',
        'd', 'e', 'f', 'i', 'n', 'i', 't', 'e', '\n',
        'd', 'e', 'f', 'i', 'n', 'i', 't', 'e', 'l', 'y', '\n',
        'd', 'e', 'f', 'i', 'n', 'i', 't', 'e', 'n', 'e', 's', 's', '\n',
        'd', 'e', 'f', 'i', 'n', 'i', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'f', 'i', 'n', 'i', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'd', 'e', 'f', 'i', 'n', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'f', 'i', 'n', 'i', 't', 'i', 'v', 'e', '\n',
        'd', 'e', 'f', 'i', 'n', 'i', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'd', 'e', 'f', 'i', 'n', 'i', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'd', 'e', 'f', 'l', 'a', 't', 'a', 'b', 'l', 'e', '\n',
        'd', 'e', 'f', 'l', 'a', 't', 'e', '\n',
        'd', 'e', 'f', 'l', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 'f', 'l', 'a', 't', 'e', 's', '\n',
        'd', 'e', 'f', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'f', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'f', 'l', 'a', 't', 'i', 'o', 'n', 'a', 'r', 'y', '\n',
        'd', 'e', 'f', 'l', 'e', 'c', 't', '\n',
        'd', 'e', 'f', 'l', 'e', 'c', 't', 'e', 'd', '\n',
        'd', 'e', 'f', 'l', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'f', 'l', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'f', 'l', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'f', 'l', 'e', 'c', 't', 'o', 'r', '\n',
        'd', 'e', 'f', 'l', 'e', 'c', 't', 'o', 'r', 's', '\n',
        'd', 'e', 'f', 'l', 'e', 'c', 't', 's', '\n',
        'd', 'e', 'f', 'l', 'o', 'w', 'e', 'r', '\n',
        'd', 'e', 'f', 'l', 'o', 'w', 'e', 'r', 'i', 'n', 'g', '\n',
        'd', 'e', 'f', 'o', 'l', 'i', 'a', 'n', 't', 's', '\n',
        'd', 'e', 'f', 'o', 'l', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'f', 'o', 'r', 'e', 's', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'f', 'o', 'r', 'e', 's', 't', 'e', 'd', '\n',
        'd', 'e', 'f', 'o', 'r', 'm', '\n',
        'd', 'e', 'f', 'o', 'r', 'm', 'a', 'b', 'l', 'e', '\n',
        'd', 'e', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'f', 'o', 'r', 'm', 'e', 'd', '\n',
        'd', 'e', 'f', 'o', 'r', 'm', 'i', 'n', 'g', '\n',
        'd', 'e', 'f', 'o', 'r', 'm', 'i', 't', 'i', 'e', 's', '\n',
        'd', 'e', 'f', 'o', 'r', 'm', 'i', 't', 'y', '\n',
        'd', 'e', 'f', 'o', 'r', 'm', 's', '\n',
        'd', 'e', 'f', 'r', 'a', 'g', 'm', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'f', 'r', 'a', 'u', 'd', '\n',
        'd', 'e', 'f', 'r', 'a', 'u', 'd', 'e', 'd', '\n',
        'd', 'e', 'f', 'r', 'a', 'u', 'd', 'i', 'n', 'g', '\n',
        'd', 'e', 'f', 'r', 'a', 'u', 'd', 's', '\n',
        'd', 'e', 'f', 'r', 'a', 'y', '\n',
        'd', 'e', 'f', 'r', 'a', 'y', 'e', 'd', '\n',
        'd', 'e', 'f', 'r', 'o', 's', 't', '\n',
        'd', 'e', 'f', 'r', 'o', 's', 't', 'e', 'd', '\n',
        'd', 'e', 'f', 'r', 'o', 's', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'f', 'r', 'o', 's', 't', 's', '\n',
        'd', 'e', 'f', 't', '\n',
        'd', 'e', 'f', 't', 'e', 'r', '\n',
        'd', 'e', 'f', 't', 'l', 'y', '\n',
        'd', 'e', 'f', 't', 'n', 'e', 's', 's', '\n',
        'd', 'e', 'f', 'u', 'n', 'c', 't', '\n',
        'd', 'e', 'f', 'u', 's', 'e', '\n',
        'd', 'e', 'f', 'u', 's', 'e', 'd', '\n',
        'd', 'e', 'f', 'u', 's', 'e', 's', '\n',
        'd', 'e', 'f', 'u', 's', 'i', 'n', 'g', '\n',
        'd', 'e', 'f', 'y', '\n',
        'd', 'e', 'f', 'y', 'i', 'n', 'g', '\n',
        'd', 'e', 'g', 'a', 's', '\n',
        'd', 'e', 'g', 'a', 'u', 's', 's', '\n',
        'd', 'e', 'g', 'a', 'u', 's', 's', 'e', 'd', '\n',
        'd', 'e', 'g', 'a', 'u', 's', 's', 'i', 'n', 'g', '\n',
        'd', 'e', 'g', 'e', 'n', 'e', 'r', 'a', 'c', 'i', 'e', 's', '\n',
        'd', 'e', 'g', 'e', 'n', 'e', 'r', 'a', 'c', 'y', '\n',
        'd', 'e', 'g', 'e', 'n', 'e', 'r', 'a', 't', 'e', '\n',
        'd', 'e', 'g', 'e', 'n', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 'g', 'e', 'n', 'e', 'r', 'a', 't', 'e', 's', '\n',
        'd', 'e', 'g', 'e', 'n', 'e', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'g', 'e', 'n', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'g', 'e', 'n', 'e', 'r', 'a', 't', 'i', 'v', 'e', '\n',
        'd', 'e', 'g', 'r', 'a', 'd', 'a', 'b', 'l', 'e', '\n',
        'd', 'e', 'g', 'r', 'a', 'd', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'g', 'r', 'a', 'd', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'g', 'r', 'a', 'd', 'e', '\n',
        'd', 'e', 'g', 'r', 'a', 'd', 'e', 'd', '\n',
        'd', 'e', 'g', 'r', 'a', 'd', 'e', 's', '\n',
        'd', 'e', 'g', 'r', 'a', 'd', 'i', 'n', 'g', '\n',
        'd', 'e', 'g', 'r', 'e', 'a', 's', 'e', '\n',
        'd', 'e', 'g', 'r', 'e', 'e', '\n',
        'd', 'e', 'g', 'r', 'e', 'e', 's', '\n',
        'd', 'e', 'h', 'o', 'r', 'n', '\n',
        'd', 'e', 'h', 'u', 'm', 'a', 'n', 'i', 's', 'e', 'd', '\n',
        'd', 'e', 'h', 'u', 'm', 'a', 'n', 'i', 's', 'e', 's', '\n',
        'd', 'e', 'h', 'u', 'm', 'a', 'n', 'i', 's', 'i', 'n', 'g', '\n',
        'd', 'e', 'h', 'u', 'm', 'i', 'd', 'i', 'f', 'i', 'e', 'r', '\n',
        'd', 'e', 'h', 'y', 'd', 'r', 'a', 't', 'e', '\n',
        'd', 'e', 'h', 'y', 'd', 'r', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 'h', 'y', 'd', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'h', 'y', 'd', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'i', 'f', 'i', 'e', 'd', '\n',
        'd', 'e', 'i', 'f', 'i', 'e', 's', '\n',
        'd', 'e', 'i', 'f', 'y', '\n',
        'd', 'e', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'd', 'e', 'i', 's', 'm', '\n',
        'd', 'e', 'i', 's', 't', '\n',
        'd', 'e', 'i', 's', 't', 's', '\n',
        'd', 'e', 'i', 't', 'i', 'e', 's', '\n',
        'd', 'e', 'i', 't', 'y', '\n',
        'd', 'e', 'j', 'e', 'c', 't', '\n',
        'd', 'e', 'j', 'e', 'c', 't', 'e', 'd', '\n',
        'd', 'e', 'j', 'e', 'c', 't', 'e', 'd', 'l', 'y', '\n',
        'd', 'e', 'j', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'j', 'e', 'c', 't', 's', '\n',
        'd', 'e', 'k', 'l', 'e', 'r', 'k', '\n',
        'd', 'e', 'l', 'a', 't', 'e', '\n',
        'd', 'e', 'l', 'a', 'y', '\n',
        'd', 'e', 'l', 'a', 'y', 'e', 'd', '\n',
        'd', 'e', 'l', 'a', 'y', 'i', 'n', 'g', '\n',
        'd', 'e', 'l', 'a', 'y', 's', '\n',
        'd', 'e', 'l', 'e', 'c', 't', 'a', 'b', 'l', 'e', '\n',
        'd', 'e', 'l', 'e', 'c', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'l', 'e', 'g', 'a', 't', 'e', '\n',
        'd', 'e', 'l', 'e', 'g', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 'l', 'e', 'g', 'a', 't', 'e', 's', '\n',
        'd', 'e', 'l', 'e', 'g', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'l', 'e', 'g', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'l', 'e', 'g', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'l', 'e', 't', 'a', 'b', 'l', 'e', '\n',
        'd', 'e', 'l', 'e', 't', 'e', '\n',
        'd', 'e', 'l', 'e', 't', 'e', 'd', '\n',
        'd', 'e', 'l', 'e', 't', 'e', 'r', '\n',
        'd', 'e', 'l', 'e', 't', 'e', 'r', 'i', 'o', 'u', 's', '\n',
        'd', 'e', 'l', 'e', 't', 'e', 'r', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'd', 'e', 'l', 'e', 't', 'e', 's', '\n',
        'd', 'e', 'l', 'e', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'l', 'e', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'l', 'e', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'l', 'h', 'i', '\n',
        'd', 'e', 'l', 'i', '\n',
        'd', 'e', 'l', 'i', 'b', 'e', 'r', 'a', 't', 'e', '\n',
        'd', 'e', 'l', 'i', 'b', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 'l', 'i', 'b', 'e', 'r', 'a', 't', 'e', 'l', 'y', '\n',
        'd', 'e', 'l', 'i', 'b', 'e', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'l', 'i', 'b', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'l', 'i', 'b', 'e', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'l', 'i', 'b', 'e', 'r', 'a', 't', 'i', 'v', 'e', '\n',
        'd', 'e', 'l', 'i', 'b', 'l', 'e', '\n',
        'd', 'e', 'l', 'i', 'c', 'a', 'c', 'i', 'e', 's', '\n',
        'd', 'e', 'l', 'i', 'c', 'a', 'c', 'y', '\n',
        'd', 'e', 'l', 'i', 'c', 'a', 't', 'e', '\n',
        'd', 'e', 'l', 'i', 'c', 'a', 't', 'e', 'l', 'y', '\n',
        'd', 'e', 'l', 'i', 'c', 'a', 't', 'e', 's', 's', 'e', 'n', '\n',
        'd', 'e', 'l', 'i', 'c', 'a', 't', 'e', 's', 's', 'e', 'n', 's', '\n',
        'd', 'e', 'l', 'i', 'c', 'i', 'o', 'u', 's', '\n',
        'd', 'e', 'l', 'i', 'c', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'd', 'e', 'l', 'i', 'c', 't', '\n',
        'd', 'e', 'l', 'i', 'g', 'h', 't', '\n',
        'd', 'e', 'l', 'i', 'g', 'h', 't', 'e', 'd', '\n',
        'd', 'e', 'l', 'i', 'g', 'h', 't', 'e', 'd', 'l', 'y', '\n',
        'd', 'e', 'l', 'i', 'g', 'h', 't', 'f', 'u', 'l', '\n',
        'd', 'e', 'l', 'i', 'g', 'h', 't', 'f', 'u', 'l', 'l', 'y', '\n',
        'd', 'e', 'l', 'i', 'g', 'h', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'l', 'i', 'g', 'h', 't', 's', '\n',
        'd', 'e', 'l', 'i', 'l', 'a', 'h', '\n',
        'd', 'e', 'l', 'i', 'm', 'i', 't', '\n',
        'd', 'e', 'l', 'i', 'm', 'i', 't', 'e', 'd', '\n',
        'd', 'e', 'l', 'i', 'm', 'i', 't', 'e', 'r', '\n',
        'd', 'e', 'l', 'i', 'm', 'i', 't', 'e', 'r', 's', '\n',
        'd', 'e', 'l', 'i', 'm', 'i', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'l', 'i', 'm', 'i', 't', 's', '\n',
        'd', 'e', 'l', 'i', 'n', 'e', 'a', 't', 'e', '\n',
        'd', 'e', 'l', 'i', 'n', 'e', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 'l', 'i', 'n', 'e', 'a', 't', 'e', 's', '\n',
        'd', 'e', 'l', 'i', 'n', 'e', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'l', 'i', 'n', 'e', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'l', 'i', 'n', 'q', 'u', 'e', 'n', 'c', 'y', '\n',
        'd', 'e', 'l', 'i', 'n', 'q', 'u', 'e', 'n', 't', '\n',
        'd', 'e', 'l', 'i', 'n', 'q', 'u', 'e', 'n', 't', 's', '\n',
        'd', 'e', 'l', 'i', 'q', 'u', 'e', 's', 'c', 'e', 'd', '\n',
        'd', 'e', 'l', 'i', 'q', 'u', 'e', 's', 'c', 'e', 'n', 't', '\n',
        'd', 'e', 'l', 'i', 'r', 'i', 'o', 'u', 's', '\n',
        'd', 'e', 'l', 'i', 'r', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'd', 'e', 'l', 'i', 'r', 'i', 'u', 'm', '\n',
        'd', 'e', 'l', 'i', 'v', 'e', 'r', '\n',
        'd', 'e', 'l', 'i', 'v', 'e', 'r', 'a', 'b', 'l', 'e', '\n',
        'd', 'e', 'l', 'i', 'v', 'e', 'r', 'a', 'n', 'c', 'e', '\n',
        'd', 'e', 'l', 'i', 'v', 'e', 'r', 'e', 'd', '\n',
        'd', 'e', 'l', 'i', 'v', 'e', 'r', 'e', 'r', '\n',
        'd', 'e', 'l', 'i', 'v', 'e', 'r', 'e', 'r', 's', '\n',
        'd', 'e', 'l', 'i', 'v', 'e', 'r', 'i', 'e', 's', '\n',
        'd', 'e', 'l', 'i', 'v', 'e', 'r', 'i', 'n', 'g', '\n',
        'd', 'e', 'l', 'i', 'v', 'e', 'r', 's', '\n',
        'd', 'e', 'l', 'i', 'v', 'e', 'r', 'y', '\n',
        'd', 'e', 'l', 'l', '\n',
        'd', 'e', 'l', 'l', 's', '\n',
        'd', 'e', 'l', 'p', 'h', 'i', '\n',
        'd', 'e', 'l', 'p', 'h', 'i', 'n', 'i', 'u', 'm', 's', '\n',
        'd', 'e', 'l', 't', 'a', '\n',
        'd', 'e', 'l', 't', 'a', 's', '\n',
        'd', 'e', 'l', 't', 'o', 'i', 'd', '\n',
        'd', 'e', 'l', 't', 'o', 'i', 'd', 's', '\n',
        'd', 'e', 'l', 'u', 'd', 'e', '\n',
        'd', 'e', 'l', 'u', 'd', 'e', 'd', '\n',
        'd', 'e', 'l', 'u', 'd', 'e', 's', '\n',
        'd', 'e', 'l', 'u', 'd', 'i', 'n', 'g', '\n',
        'd', 'e', 'l', 'u', 'g', 'e', '\n',
        'd', 'e', 'l', 'u', 'g', 'e', 'd', '\n',
        'd', 'e', 'l', 'u', 'g', 'e', 's', '\n',
        'd', 'e', 'l', 'u', 'g', 'i', 'n', 'g', '\n',
        'd', 'e', 'l', 'u', 's', 'i', 'o', 'n', '\n',
        'd', 'e', 'l', 'u', 's', 'i', 'o', 'n', 'a', 'l', '\n',
        'd', 'e', 'l', 'u', 's', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'l', 'u', 's', 'i', 'v', 'e', '\n',
        'd', 'e', 'l', 'u', 'x', 'e', '\n',
        'd', 'e', 'l', 'v', 'e', '\n',
        'd', 'e', 'l', 'v', 'e', 'd', '\n',
        'd', 'e', 'l', 'v', 'e', 's', '\n',
        'd', 'e', 'l', 'v', 'i', 'n', 'g', '\n',
        'd', 'e', 'm', 'a', 'g', 'n', 'e', 't', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'm', 'a', 'g', 'n', 'e', 't', 'i', 's', 'e', '\n',
        'd', 'e', 'm', 'a', 'g', 'o', 'g', '\n',
        'd', 'e', 'm', 'a', 'g', 'o', 'g', 'i', 'c', '\n',
        'd', 'e', 'm', 'a', 'g', 'o', 'g', 'u', 'e', '\n',
        'd', 'e', 'm', 'a', 'g', 'o', 'g', 'u', 'e', 'r', 'y', '\n',
        'd', 'e', 'm', 'a', 'g', 'o', 'g', 'u', 'e', 's', '\n',
        'd', 'e', 'm', 'a', 'g', 'o', 'g', 'y', '\n',
        'd', 'e', 'm', 'a', 'n', 'd', '\n',
        'd', 'e', 'm', 'a', 'n', 'd', 'e', 'd', '\n',
        'd', 'e', 'm', 'a', 'n', 'd', 'e', 'r', '\n',
        'd', 'e', 'm', 'a', 'n', 'd', 'i', 'n', 'g', '\n',
        'd', 'e', 'm', 'a', 'n', 'd', 's', '\n',
        'd', 'e', 'm', 'a', 'r', 'c', 'a', 't', 'e', '\n',
        'd', 'e', 'm', 'a', 'r', 'c', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 'm', 'a', 'r', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'm', 'a', 'r', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'm', 'a', 'r', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'm', 'a', 't', 'e', 'r', 'i', 'a', 'l', 'i', 's', 'e', '\n',
        'd', 'e', 'm', 'a', 't', 'e', 'r', 'i', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'd', 'e', 'm', 'a', 't', 'e', 'r', 'i', 'a', 'l', 'i', 's', 'e', 's', '\n',
        'd', 'e', 'm', 'e', 'a', 'n', '\n',
        'd', 'e', 'm', 'e', 'a', 'n', 'e', 'd', '\n',
        'd', 'e', 'm', 'e', 'a', 'n', 'i', 'n', 'g', '\n',
        'd', 'e', 'm', 'e', 'a', 'n', 'o', 'u', 'r', '\n',
        'd', 'e', 'm', 'e', 'a', 'n', 's', '\n',
        'd', 'e', 'm', 'e', 'n', 't', '\n',
        'd', 'e', 'm', 'e', 'n', 't', 'e', 'd', '\n',
        'd', 'e', 'm', 'e', 'n', 't', 'e', 'd', 'l', 'y', '\n',
        'd', 'e', 'm', 'e', 'n', 't', 'i', 'a', '\n',
        'd', 'e', 'm', 'e', 'r', 'g', 'e', '\n',
        'd', 'e', 'm', 'e', 'r', 'i', 't', '\n',
        'd', 'e', 'm', 'i', 'g', 'o', 'd', '\n',
        'd', 'e', 'm', 'i', 'g', 'o', 'd', 's', '\n',
        'd', 'e', 'm', 'i', 'j', 'o', 'h', 'n', 's', '\n',
        'd', 'e', 'm', 'i', 'l', 'i', 't', 'a', 'r', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'm', 'i', 'l', 'i', 't', 'a', 'r', 'i', 's', 'e', 'd', '\n',
        'd', 'e', 'm', 'i', 's', 'e', '\n',
        'd', 'e', 'm', 'i', 's', 'e', 'd', '\n',
        'd', 'e', 'm', 'i', 's', 'e', 's', '\n',
        'd', 'e', 'm', 'i', 's', 't', '\n',
        'd', 'e', 'm', 'i', 's', 't', 's', '\n',
        'd', 'e', 'm', 'o', '\n',
        'd', 'e', 'm', 'o', 'b', 'i', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'm', 'o', 'b', 'i', 'l', 'i', 's', 'e', 'd', '\n',
        'd', 'e', 'm', 'o', 'b', 's', '\n',
        'd', 'e', 'm', 'o', 'c', 'r', 'a', 'c', 'i', 'e', 's', '\n',
        'd', 'e', 'm', 'o', 'c', 'r', 'a', 'c', 'y', '\n',
        'd', 'e', 'm', 'o', 'c', 'r', 'a', 't', '\n',
        'd', 'e', 'm', 'o', 'c', 'r', 'a', 't', 'i', 'c', '\n',
        'd', 'e', 'm', 'o', 'c', 'r', 'a', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'd', 'e', 'm', 'o', 'c', 'r', 'a', 't', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'm', 'o', 'c', 'r', 'a', 't', 'i', 's', 'i', 'n', 'g', '\n',
        'd', 'e', 'm', 'o', 'c', 'r', 'a', 't', 's', '\n',
        'd', 'e', 'm', 'o', 'd', 'u', 'l', 'a', 't', 'o', 'r', '\n',
        'd', 'e', 'm', 'o', 'g', 'r', 'a', 'p', 'h', 'e', 'r', '\n',
        'd', 'e', 'm', 'o', 'g', 'r', 'a', 'p', 'h', 'e', 'r', 's', '\n',
        'd', 'e', 'm', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', '\n',
        'd', 'e', 'm', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'd', 'e', 'm', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', 's', '\n',
        'd', 'e', 'm', 'o', 'g', 'r', 'a', 'p', 'h', 'y', '\n',
        'd', 'e', 'm', 'o', 'l', 'i', 's', 'h', '\n',
        'd', 'e', 'm', 'o', 'l', 'i', 's', 'h', 'e', 'd', '\n',
        'd', 'e', 'm', 'o', 'l', 'i', 's', 'h', 'e', 'r', '\n',
        'd', 'e', 'm', 'o', 'l', 'i', 's', 'h', 'e', 's', '\n',
        'd', 'e', 'm', 'o', 'l', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'd', 'e', 'm', 'o', 'l', 'i', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'm', 'o', 'l', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'm', 'o', 'n', '\n',
        'd', 'e', 'm', 'o', 'n', 'i', 'c', '\n',
        'd', 'e', 'm', 'o', 'n', 'i', 's', 'e', '\n',
        'd', 'e', 'm', 'o', 'n', 'o', 'l', 'o', 'g', 'y', '\n',
        'd', 'e', 'm', 'o', 'n', 's', '\n',
        'd', 'e', 'm', 'o', 'n', 's', 't', 'r', 'a', 'b', 'l', 'e', '\n',
        'd', 'e', 'm', 'o', 'n', 's', 't', 'r', 'a', 'b', 'l', 'y', '\n',
        'd', 'e', 'm', 'o', 'n', 's', 't', 'r', 'a', 't', 'e', '\n',
        'd', 'e', 'm', 'o', 'n', 's', 't', 'r', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 'm', 'o', 'n', 's', 't', 'r', 'a', 't', 'e', 's', '\n',
        'd', 'e', 'm', 'o', 'n', 's', 't', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'm', 'o', 'n', 's', 't', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'm', 'o', 'n', 's', 't', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'm', 'o', 'n', 's', 't', 'r', 'a', 't', 'i', 'v', 'e', '\n',
        'd', 'e', 'm', 'o', 'n', 's', 't', 'r', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'd', 'e', 'm', 'o', 'n', 's', 't', 'r', 'a', 't', 'i', 'v', 'e', 's', '\n',
        'd', 'e', 'm', 'o', 'n', 's', 't', 'r', 'a', 't', 'o', 'r', '\n',
        'd', 'e', 'm', 'o', 'n', 's', 't', 'r', 'a', 't', 'o', 'r', 's', '\n',
        'd', 'e', 'm', 'o', 'r', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'm', 'o', 'r', 'a', 'l', 'i', 's', 'e', '\n',
        'd', 'e', 'm', 'o', 'r', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'd', 'e', 'm', 'o', 'r', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'd', 'e', 'm', 'o', 't', 'e', '\n',
        'd', 'e', 'm', 'o', 't', 'e', 'd', '\n',
        'd', 'e', 'm', 'o', 't', 'e', 's', '\n',
        'd', 'e', 'm', 'o', 't', 'i', 'c', '\n',
        'd', 'e', 'm', 'o', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'm', 'o', 'u', 'n', 't', '\n',
        'd', 'e', 'm', 'o', 'u', 'n', 't', 'a', 'b', 'l', 'e', '\n',
        'd', 'e', 'm', 'o', 'u', 'n', 't', 'e', 'd', '\n',
        'd', 'e', 'm', 'o', 'u', 'n', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'm', 'u', 'r', '\n',
        'd', 'e', 'm', 'u', 'r', 'e', '\n',
        'd', 'e', 'm', 'u', 'r', 'e', 'l', 'y', '\n',
        'd', 'e', 'm', 'u', 'r', 'r', 'e', 'd', '\n',
        'd', 'e', 'm', 'u', 'r', 'r', 'i', 'n', 'g', '\n',
        'd', 'e', 'm', 'u', 'r', 's', '\n',
        'd', 'e', 'm', 'y', 's', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'm', 'y', 's', 't', 'i', 'f', 'y', '\n',
        'd', 'e', 'm', 'y', 's', 't', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'd', 'e', 'n', '\n',
        'd', 'e', 'n', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'n', 'a', 't', 'u', 'r', 'e', 'd', '\n',
        'd', 'e', 'n', 'a', 't', 'u', 'r', 'i', 'n', 'g', '\n',
        'd', 'e', 'n', 'd', 'r', 'i', 't', 'e', 's', '\n',
        'd', 'e', 'n', 'd', 'r', 'i', 't', 'i', 'c', '\n',
        'd', 'e', 'n', 'd', 'r', 'o', 'c', 'h', 'r', 'o', 'n', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'd', 'e', 'n', 'd', 'r', 'o', 'c', 'h', 'r', 'o', 'n', 'o', 'l', 'o', 'g', 'y', '\n',
        'd', 'e', 'n', 'i', 'a', 'b', 'l', 'e', '\n',
        'd', 'e', 'n', 'i', 'a', 'l', '\n',
        'd', 'e', 'n', 'i', 'a', 'l', 's', '\n',
        'd', 'e', 'n', 'i', 'e', 'd', '\n',
        'd', 'e', 'n', 'i', 'e', 'r', '\n',
        'd', 'e', 'n', 'i', 'e', 'r', 's', '\n',
        'd', 'e', 'n', 'i', 'e', 's', '\n',
        'd', 'e', 'n', 'i', 'g', 'r', 'a', 't', 'e', '\n',
        'd', 'e', 'n', 'i', 'g', 'r', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 'n', 'i', 'g', 'r', 'a', 't', 'e', 's', '\n',
        'd', 'e', 'n', 'i', 'g', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'n', 'i', 'g', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'n', 'i', 'g', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'n', 'i', 'm', '\n',
        'd', 'e', 'n', 'i', 'm', 's', '\n',
        'd', 'e', 'n', 'i', 'z', 'e', 'n', '\n',
        'd', 'e', 'n', 'i', 'z', 'e', 'n', 's', '\n',
        'd', 'e', 'n', 'm', 'a', 'r', 'k', '\n',
        'd', 'e', 'n', 'o', 'm', 'i', 'n', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 'n', 'o', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'n', 'o', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'd', 'e', 'n', 'o', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'n', 'o', 'm', 'i', 'n', 'a', 't', 'o', 'r', '\n',
        'd', 'e', 'n', 'o', 'm', 'i', 'n', 'a', 't', 'o', 'r', 's', '\n',
        'd', 'e', 'n', 'o', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'n', 'o', 't', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'd', 'e', 'n', 'o', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'n', 'o', 't', 'e', '\n',
        'd', 'e', 'n', 'o', 't', 'e', 'd', '\n',
        'd', 'e', 'n', 'o', 't', 'e', 's', '\n',
        'd', 'e', 'n', 'o', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'n', 'o', 'u', 'e', 'm', 'e', 'n', 't', '\n',
        'd', 'e', 'n', 'o', 'u', 'n', 'c', 'e', '\n',
        'd', 'e', 'n', 'o', 'u', 'n', 'c', 'e', 'd', '\n',
        'd', 'e', 'n', 'o', 'u', 'n', 'c', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'd', 'e', 'n', 'o', 'u', 'n', 'c', 'e', 's', '\n',
        'd', 'e', 'n', 'o', 'u', 'n', 'c', 'i', 'n', 'g', '\n',
        'd', 'e', 'n', 's', '\n',
        'd', 'e', 'n', 's', 'e', '\n',
        'd', 'e', 'n', 's', 'e', 'l', 'y', '\n',
        'd', 'e', 'n', 's', 'e', 'n', 'e', 's', 's', '\n',
        'd', 'e', 'n', 's', 'e', 'r', '\n',
        'd', 'e', 'n', 's', 'e', 's', 't', '\n',
        'd', 'e', 'n', 's', 'i', 't', 'i', 'e', 's', '\n',
        'd', 'e', 'n', 's', 'i', 't', 'o', 'm', 'e', 't', 'r', 'y', '\n',
        'd', 'e', 'n', 's', 'i', 't', 'y', '\n',
        'd', 'e', 'n', 't', '\n',
        'd', 'e', 'n', 't', 'a', 'l', '\n',
        'd', 'e', 'n', 't', 'e', 'd', '\n',
        'd', 'e', 'n', 't', 'i', 'n', '\n',
        'd', 'e', 'n', 't', 'i', 'n', 'e', '\n',
        'd', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'n', 't', 'i', 's', 't', '\n',
        'd', 'e', 'n', 't', 'i', 's', 't', 'r', 'y', '\n',
        'd', 'e', 'n', 't', 'i', 's', 't', 's', '\n',
        'd', 'e', 'n', 't', 'i', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'n', 't', 's', '\n',
        'd', 'e', 'n', 't', 'u', 'r', 'e', '\n',
        'd', 'e', 'n', 't', 'u', 'r', 'e', 's', '\n',
        'd', 'e', 'n', 'u', 'd', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'n', 'u', 'd', 'e', '\n',
        'd', 'e', 'n', 'u', 'd', 'e', 'd', '\n',
        'd', 'e', 'n', 'u', 'd', 'e', 's', '\n',
        'd', 'e', 'n', 'u', 'n', 'c', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'n', 'u', 'n', 'c', 'i', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'n', 'v', 'e', 'r', '\n',
        'd', 'e', 'n', 'y', '\n',
        'd', 'e', 'n', 'y', 'i', 'n', 'g', '\n',
        'd', 'e', 'o', 'd', 'o', 'r', 'a', 'n', 't', '\n',
        'd', 'e', 'o', 'd', 'o', 'r', 'a', 'n', 't', 's', '\n',
        'd', 'e', 'o', 'd', 'o', 'r', 'i', 's', 'e', 'd', '\n',
        'd', 'e', 'p', 'a', 'r', 't', '\n',
        'd', 'e', 'p', 'a', 'r', 't', 'e', 'd', '\n',
        'd', 'e', 'p', 'a', 'r', 't', 'e', 'r', '\n',
        'd', 'e', 'p', 'a', 'r', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'p', 'a', 'r', 't', 'm', 'e', 'n', 't', '\n',
        'd', 'e', 'p', 'a', 'r', 't', 'm', 'e', 'n', 't', 'a', 'l', '\n',
        'd', 'e', 'p', 'a', 'r', 't', 'm', 'e', 'n', 't', 'a', 'l', 'l', 'y', '\n',
        'd', 'e', 'p', 'a', 'r', 't', 'm', 'e', 'n', 't', 's', '\n',
        'd', 'e', 'p', 'a', 'r', 't', 's', '\n',
        'd', 'e', 'p', 'a', 'r', 't', 'u', 'r', 'e', '\n',
        'd', 'e', 'p', 'a', 'r', 't', 'u', 'r', 'e', 's', '\n',
        'd', 'e', 'p', 'e', 'n', 'd', '\n',
        'd', 'e', 'p', 'e', 'n', 'd', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'd', 'e', 'p', 'e', 'n', 'd', 'a', 'b', 'l', 'e', '\n',
        'd', 'e', 'p', 'e', 'n', 'd', 'a', 'n', 't', '\n',
        'd', 'e', 'p', 'e', 'n', 'd', 'a', 'n', 't', 's', '\n',
        'd', 'e', 'p', 'e', 'n', 'd', 'e', 'd', '\n',
        'd', 'e', 'p', 'e', 'n', 'd', 'e', 'n', 'c', 'e', '\n',
        'd', 'e', 'p', 'e', 'n', 'd', 'e', 'n', 'c', 'i', 'e', 's', '\n',
        'd', 'e', 'p', 'e', 'n', 'd', 'e', 'n', 'c', 'y', '\n',
        'd', 'e', 'p', 'e', 'n', 'd', 'e', 'n', 't', '\n',
        'd', 'e', 'p', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'd', 'e', 'p', 'e', 'n', 'd', 's', '\n',
        'd', 'e', 'p', 'e', 'r', 's', 'o', 'n', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'p', 'e', 'r', 's', 'o', 'n', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'd', 'e', 'p', 'i', 'c', 't', '\n',
        'd', 'e', 'p', 'i', 'c', 't', 'e', 'd', '\n',
        'd', 'e', 'p', 'i', 'c', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'p', 'i', 'c', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'p', 'i', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'p', 'i', 'c', 't', 's', '\n',
        'd', 'e', 'p', 'l', 'e', 't', 'e', '\n',
        'd', 'e', 'p', 'l', 'e', 't', 'e', 'd', '\n',
        'd', 'e', 'p', 'l', 'e', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'p', 'l', 'e', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'p', 'l', 'o', 'r', 'a', 'b', 'l', 'e', '\n',
        'd', 'e', 'p', 'l', 'o', 'r', 'a', 'b', 'l', 'y', '\n',
        'd', 'e', 'p', 'l', 'o', 'r', 'e', '\n',
        'd', 'e', 'p', 'l', 'o', 'r', 'e', 'd', '\n',
        'd', 'e', 'p', 'l', 'o', 'r', 'e', 's', '\n',
        'd', 'e', 'p', 'l', 'o', 'r', 'i', 'n', 'g', '\n',
        'd', 'e', 'p', 'l', 'o', 'y', '\n',
        'd', 'e', 'p', 'l', 'o', 'y', 'e', 'd', '\n',
        'd', 'e', 'p', 'l', 'o', 'y', 'i', 'n', 'g', '\n',
        'd', 'e', 'p', 'l', 'o', 'y', 'm', 'e', 'n', 't', '\n',
        'd', 'e', 'p', 'l', 'o', 'y', 'm', 'e', 'n', 't', 's', '\n',
        'd', 'e', 'p', 'l', 'o', 'y', 's', '\n',
        'd', 'e', 'p', 'o', 'l', 'a', 'r', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'p', 'o', 'l', 'a', 'r', 'i', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'p', 'o', 'l', 'i', 't', 'i', 'c', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'p', 'o', 'n', 'e', 'n', 't', '\n',
        'd', 'e', 'p', 'o', 'p', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 'p', 'o', 'p', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'p', 'o', 'r', 't', '\n',
        'd', 'e', 'p', 'o', 'r', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'p', 'o', 'r', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'p', 'o', 'r', 't', 'e', 'd', '\n',
        'd', 'e', 'p', 'o', 'r', 't', 'e', 'e', '\n',
        'd', 'e', 'p', 'o', 'r', 't', 'e', 'e', 's', '\n',
        'd', 'e', 'p', 'o', 'r', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'p', 'o', 'r', 't', 'm', 'e', 'n', 't', '\n',
        'd', 'e', 'p', 'o', 'r', 't', 's', '\n',
        'd', 'e', 'p', 'o', 's', 'e', '\n',
        'd', 'e', 'p', 'o', 's', 'e', 'd', '\n',
        'd', 'e', 'p', 'o', 's', 'i', 'n', 'g', '\n',
        'd', 'e', 'p', 'o', 's', 'i', 't', '\n',
        'd', 'e', 'p', 'o', 's', 'i', 't', 'a', 'r', 'y', '\n',
        'd', 'e', 'p', 'o', 's', 'i', 't', 'e', 'd', '\n',
        'd', 'e', 'p', 'o', 's', 'i', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'd', 'e', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'p', 'o', 's', 'i', 't', 'o', 'r', 'i', 'e', 's', '\n',
        'd', 'e', 'p', 'o', 's', 'i', 't', 'o', 'r', 's', '\n',
        'd', 'e', 'p', 'o', 's', 'i', 't', 'o', 'r', 'y', '\n',
        'd', 'e', 'p', 'o', 's', 'i', 't', 's', '\n',
        'd', 'e', 'p', 'o', 't', '\n',
        'd', 'e', 'p', 'o', 't', 's', '\n',
        'd', 'e', 'p', 'r', 'a', 'v', 'e', '\n',
        'd', 'e', 'p', 'r', 'a', 'v', 'e', 'd', '\n',
        'd', 'e', 'p', 'r', 'a', 'v', 'e', 's', '\n',
        'd', 'e', 'p', 'r', 'a', 'v', 'i', 'n', 'g', '\n',
        'd', 'e', 'p', 'r', 'a', 'v', 'i', 't', 'y', '\n',
        'd', 'e', 'p', 'r', 'e', 'c', 'a', 't', 'e', '\n',
        'd', 'e', 'p', 'r', 'e', 'c', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 'p', 'r', 'e', 'c', 'a', 't', 'e', 's', '\n',
        'd', 'e', 'p', 'r', 'e', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'p', 'r', 'e', 'c', 'a', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'd', 'e', 'p', 'r', 'e', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'p', 'r', 'e', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'p', 'r', 'e', 'c', 'a', 't', 'o', 'r', 'y', '\n',
        'd', 'e', 'p', 'r', 'e', 'c', 'i', 'a', 't', 'e', '\n',
        'd', 'e', 'p', 'r', 'e', 'c', 'i', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 'p', 'r', 'e', 'c', 'i', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'p', 'r', 'e', 'c', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'p', 'r', 'e', 'd', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'p', 'r', 'e', 'd', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'p', 'r', 'e', 's', 's', '\n',
        'd', 'e', 'p', 'r', 'e', 's', 's', 'a', 'n', 't', '\n',
        'd', 'e', 'p', 'r', 'e', 's', 's', 'a', 'n', 't', 's', '\n',
        'd', 'e', 'p', 'r', 'e', 's', 's', 'e', 'd', '\n',
        'd', 'e', 'p', 'r', 'e', 's', 's', 'e', 's', '\n',
        'd', 'e', 'p', 'r', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'd', 'e', 'p', 'r', 'e', 's', 's', 'i', 'n', 'g', 'l', 'y', '\n',
        'd', 'e', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', '\n',
        'd', 'e', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'p', 'r', 'e', 's', 's', 'i', 'v', 'e', '\n',
        'd', 'e', 'p', 'r', 'e', 's', 's', 'i', 'v', 'e', 's', '\n',
        'd', 'e', 'p', 'r', 'i', 'v', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'p', 'r', 'i', 'v', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'p', 'r', 'i', 'v', 'e', '\n',
        'd', 'e', 'p', 'r', 'i', 'v', 'e', 'd', '\n',
        'd', 'e', 'p', 'r', 'i', 'v', 'e', 's', '\n',
        'd', 'e', 'p', 'r', 'i', 'v', 'i', 'n', 'g', '\n',
        'd', 'e', 'p', 't', 'h', '\n',
        'd', 'e', 'p', 't', 'h', 's', '\n',
        'd', 'e', 'p', 'u', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'p', 'u', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'p', 'u', 't', 'e', '\n',
        'd', 'e', 'p', 'u', 't', 'e', 'd', '\n',
        'd', 'e', 'p', 'u', 't', 'e', 's', '\n',
        'd', 'e', 'p', 'u', 't', 'i', 'e', 's', '\n',
        'd', 'e', 'p', 'u', 't', 'i', 's', 'e', '\n',
        'd', 'e', 'p', 'u', 't', 'i', 's', 'e', 'd', '\n',
        'd', 'e', 'p', 'u', 't', 'i', 's', 'e', 's', '\n',
        'd', 'e', 'p', 'u', 't', 'i', 's', 'i', 'n', 'g', '\n',
        'd', 'e', 'p', 'u', 't', 'y', '\n',
        'd', 'e', 'r', 'a', 'i', 'l', '\n',
        'd', 'e', 'r', 'a', 'i', 'l', 'e', 'd', '\n',
        'd', 'e', 'r', 'a', 'i', 'l', 'i', 'n', 'g', '\n',
        'd', 'e', 'r', 'a', 'i', 'l', 'm', 'e', 'n', 't', '\n',
        'd', 'e', 'r', 'a', 'i', 'l', 's', '\n',
        'd', 'e', 'r', 'a', 'n', 'g', 'e', '\n',
        'd', 'e', 'r', 'a', 'n', 'g', 'e', 'd', '\n',
        'd', 'e', 'r', 'a', 'n', 'g', 'e', 'm', 'e', 'n', 't', '\n',
        'd', 'e', 'r', 'a', 't', 'e', '\n',
        'd', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 'r', 'a', 't', 'e', 's', '\n',
        'd', 'e', 'r', 'b', 'i', 'e', 's', '\n',
        'd', 'e', 'r', 'b', 'y', '\n',
        'd', 'e', 'r', 'e', 'g', 'u', 'l', 'a', 't', 'e', '\n',
        'd', 'e', 'r', 'e', 'g', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 'r', 'e', 'g', 'u', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'r', 'e', 'g', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'r', 'e', 'l', 'i', 'c', 't', '\n',
        'd', 'e', 'r', 'e', 'l', 'i', 'c', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'r', 'e', 'l', 'i', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'r', 'i', 'd', 'e', '\n',
        'd', 'e', 'r', 'i', 'd', 'e', 'd', '\n',
        'd', 'e', 'r', 'i', 'd', 'e', 'r', 's', '\n',
        'd', 'e', 'r', 'i', 'd', 'e', 's', '\n',
        'd', 'e', 'r', 'i', 'd', 'i', 'n', 'g', '\n',
        'd', 'e', 'r', 'i', 's', 'i', 'o', 'n', '\n',
        'd', 'e', 'r', 'i', 's', 'i', 'v', 'e', '\n',
        'd', 'e', 'r', 'i', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'd', 'e', 'r', 'i', 's', 'o', 'r', 'y', '\n',
        'd', 'e', 'r', 'i', 'v', 'a', 'b', 'l', 'e', '\n',
        'd', 'e', 'r', 'i', 'v', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'r', 'i', 'v', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'r', 'i', 'v', 'a', 't', 'i', 'v', 'e', '\n',
        'd', 'e', 'r', 'i', 'v', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'd', 'e', 'r', 'i', 'v', 'a', 't', 'i', 'v', 'e', 's', '\n',
        'd', 'e', 'r', 'i', 'v', 'e', '\n',
        'd', 'e', 'r', 'i', 'v', 'e', 'd', '\n',
        'd', 'e', 'r', 'i', 'v', 'e', 's', '\n',
        'd', 'e', 'r', 'i', 'v', 'i', 'n', 'g', '\n',
        'd', 'e', 'r', 'm', 'a', 'l', '\n',
        'd', 'e', 'r', 'm', 'a', 't', 'i', 't', 'i', 's', '\n',
        'd', 'e', 'r', 'm', 'a', 't', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'd', 'e', 'r', 'm', 'a', 't', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'd', 'e', 'r', 'm', 'a', 't', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'd', 'e', 'r', 'm', 'a', 't', 'o', 'l', 'o', 'g', 'y', '\n',
        'd', 'e', 'r', 'm', 'i', 'c', '\n',
        'd', 'e', 'r', 'm', 'i', 's', '\n',
        'd', 'e', 'r', 'o', 'g', 'a', 't', 'e', '\n',
        'd', 'e', 'r', 'o', 'g', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'r', 'o', 'g', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'r', 'o', 'g', 'a', 't', 'o', 'r', 'y', '\n',
        'd', 'e', 'r', 'r', 'i', 'c', 'k', '\n',
        'd', 'e', 'r', 'v', 'i', 's', 'h', 'e', 's', '\n',
        'd', 'e', 's', 'a', 'l', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 's', 'a', 'l', 't', '\n',
        'd', 'e', 's', 'a', 't', 'u', 'r', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 's', 'c', 'a', 'n', 't', '\n',
        'd', 'e', 's', 'c', 'e', 'n', 'd', '\n',
        'd', 'e', 's', 'c', 'e', 'n', 'd', 'a', 'n', 't', '\n',
        'd', 'e', 's', 'c', 'e', 'n', 'd', 'a', 'n', 't', 's', '\n',
        'd', 'e', 's', 'c', 'e', 'n', 'd', 'e', 'd', '\n',
        'd', 'e', 's', 'c', 'e', 'n', 'd', 'e', 'n', 't', '\n',
        'd', 'e', 's', 'c', 'e', 'n', 'd', 'e', 'r', '\n',
        'd', 'e', 's', 'c', 'e', 'n', 'd', 'e', 'r', 's', '\n',
        'd', 'e', 's', 'c', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'd', 'e', 's', 'c', 'e', 'n', 'd', 's', '\n',
        'd', 'e', 's', 'c', 'e', 'n', 't', '\n',
        'd', 'e', 's', 'c', 'e', 'n', 't', 's', '\n',
        'd', 'e', 's', 'c', 'r', 'i', 'b', 'a', 'b', 'l', 'e', '\n',
        'd', 'e', 's', 'c', 'r', 'i', 'b', 'e', '\n',
        'd', 'e', 's', 'c', 'r', 'i', 'b', 'e', 'd', '\n',
        'd', 'e', 's', 'c', 'r', 'i', 'b', 'e', 'r', '\n',
        'd', 'e', 's', 'c', 'r', 'i', 'b', 'e', 'r', 's', '\n',
        'd', 'e', 's', 'c', 'r', 'i', 'b', 'e', 's', '\n',
        'd', 'e', 's', 'c', 'r', 'i', 'b', 'i', 'n', 'g', '\n',
        'd', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'v', 'e', '\n',
        'd', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'd', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'd', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'v', 'i', 's', 'm', '\n',
        'd', 'e', 's', 'c', 'r', 'i', 'p', 't', 'o', 'r', '\n',
        'd', 'e', 's', 'c', 'r', 'i', 'p', 't', 'o', 'r', 's', '\n',
        'd', 'e', 's', 'e', 'c', 'r', 'a', 't', 'e', '\n',
        'd', 'e', 's', 'e', 'c', 'r', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 's', 'e', 'c', 'r', 'a', 't', 'e', 's', '\n',
        'd', 'e', 's', 'e', 'c', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 's', 'e', 'c', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 's', 'e', 'g', 'r', 'e', 'g', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 's', 'e', 'l', 'e', 'c', 't', 'e', 'd', '\n',
        'd', 'e', 's', 'e', 'n', 's', 'i', 't', 'i', 's', 'i', 'n', 'g', '\n',
        'd', 'e', 's', 'e', 'r', 't', '\n',
        'd', 'e', 's', 'e', 'r', 't', 'e', 'd', '\n',
        'd', 'e', 's', 'e', 'r', 't', 'e', 'r', '\n',
        'd', 'e', 's', 'e', 'r', 't', 'e', 'r', 's', '\n',
        'd', 'e', 's', 'e', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 's', 'e', 'r', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 's', 'e', 'r', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 's', 'e', 'r', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 's', 'e', 'r', 't', 's', '\n',
        'd', 'e', 's', 'e', 'r', 'v', 'e', '\n',
        'd', 'e', 's', 'e', 'r', 'v', 'e', 'd', '\n',
        'd', 'e', 's', 'e', 'r', 'v', 'e', 'd', 'l', 'y', '\n',
        'd', 'e', 's', 'e', 'r', 'v', 'e', 's', '\n',
        'd', 'e', 's', 'e', 'r', 'v', 'i', 'n', 'g', '\n',
        'd', 'e', 's', 'i', 'c', 'c', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 's', 'i', 'c', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 's', 'i', 'c', 'c', 'a', 't', 'o', 'r', '\n',
        'd', 'e', 's', 'i', 'd', 'e', 'r', 'a', 't', 'a', '\n',
        'd', 'e', 's', 'i', 'd', 'e', 'r', 'a', 't', 'u', 'm', '\n',
        'd', 'e', 's', 'i', 'g', 'n', '\n',
        'd', 'e', 's', 'i', 'g', 'n', 'a', 'b', 'l', 'e', '\n',
        'd', 'e', 's', 'i', 'g', 'n', 'a', 't', 'e', '\n',
        'd', 'e', 's', 'i', 'g', 'n', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 's', 'i', 'g', 'n', 'a', 't', 'e', 's', '\n',
        'd', 'e', 's', 'i', 'g', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 's', 'i', 'g', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 's', 'i', 'g', 'n', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'd', 'e', 's', 'i', 'g', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 's', 'i', 'g', 'n', 'a', 't', 'o', 'r', '\n',
        'd', 'e', 's', 'i', 'g', 'n', 'a', 't', 'o', 'r', 's', '\n',
        'd', 'e', 's', 'i', 'g', 'n', 'e', 'd', '\n',
        'd', 'e', 's', 'i', 'g', 'n', 'e', 'd', 'l', 'y', '\n',
        'd', 'e', 's', 'i', 'g', 'n', 'e', 'r', '\n',
        'd', 'e', 's', 'i', 'g', 'n', 'e', 'r', 's', '\n',
        'd', 'e', 's', 'i', 'g', 'n', 'i', 'n', 'g', '\n',
        'd', 'e', 's', 'i', 'g', 'n', 's', '\n',
        'd', 'e', 's', 'i', 'r', 'a', 'b', 'i', 'l', 'i', 'a', '\n',
        'd', 'e', 's', 'i', 'r', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'd', 'e', 's', 'i', 'r', 'a', 'b', 'l', 'e', '\n',
        'd', 'e', 's', 'i', 'r', 'a', 'b', 'l', 'e', 'n', 'e', 's', 's', '\n',
        'd', 'e', 's', 'i', 'r', 'a', 'b', 'l', 'y', '\n',
        'd', 'e', 's', 'i', 'r', 'e', '\n',
        'd', 'e', 's', 'i', 'r', 'e', 'd', '\n',
        'd', 'e', 's', 'i', 'r', 'e', 's', '\n',
        'd', 'e', 's', 'i', 'r', 'i', 'n', 'g', '\n',
        'd', 'e', 's', 'i', 'r', 'o', 'u', 's', '\n',
        'd', 'e', 's', 'i', 's', 't', '\n',
        'd', 'e', 's', 'i', 's', 't', 'e', 'd', '\n',
        'd', 'e', 's', 'i', 's', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 's', 'k', '\n',
        'd', 'e', 's', 'k', 'i', 'l', 'l', 'i', 'n', 'g', '\n',
        'd', 'e', 's', 'k', 's', '\n',
        'd', 'e', 's', 'k', 't', 'o', 'p', '\n',
        'd', 'e', 's', 'k', 't', 'o', 'p', 's', '\n',
        'd', 'e', 's', 'o', 'l', 'a', 't', 'e', '\n',
        'd', 'e', 's', 'o', 'l', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 's', 'o', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 's', 'o', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 's', 'o', 'r', 'p', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 's', 'p', 'a', 'i', 'r', '\n',
        'd', 'e', 's', 'p', 'a', 'i', 'r', 'e', 'd', '\n',
        'd', 'e', 's', 'p', 'a', 'i', 'r', 'i', 'n', 'g', '\n',
        'd', 'e', 's', 'p', 'a', 'i', 'r', 'i', 'n', 'g', 'l', 'y', '\n',
        'd', 'e', 's', 'p', 'a', 'i', 'r', 's', '\n',
        'd', 'e', 's', 'p', 'a', 't', 'c', 'h', '\n',
        'd', 'e', 's', 'p', 'a', 't', 'c', 'h', 'e', 'd', '\n',
        'd', 'e', 's', 'p', 'a', 't', 'c', 'h', 'e', 's', '\n',
        'd', 'e', 's', 'p', 'a', 't', 'c', 'h', 'i', 'n', 'g', '\n',
        'd', 'e', 's', 'p', 'e', 'r', 'a', 'd', 'o', '\n',
        'd', 'e', 's', 'p', 'e', 'r', 'a', 't', 'e', '\n',
        'd', 'e', 's', 'p', 'e', 'r', 'a', 't', 'e', 'l', 'y', '\n',
        'd', 'e', 's', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 's', 'p', 'i', 'c', 'a', 'b', 'l', 'e', '\n',
        'd', 'e', 's', 'p', 'i', 'c', 'a', 'b', 'l', 'y', '\n',
        'd', 'e', 's', 'p', 'i', 's', 'a', 'l', '\n',
        'd', 'e', 's', 'p', 'i', 's', 'e', '\n',
        'd', 'e', 's', 'p', 'i', 's', 'e', 'd', '\n',
        'd', 'e', 's', 'p', 'i', 's', 'e', 's', '\n',
        'd', 'e', 's', 'p', 'i', 's', 'i', 'n', 'g', '\n',
        'd', 'e', 's', 'p', 'i', 't', 'e', '\n',
        'd', 'e', 's', 'p', 'o', 'i', 'l', '\n',
        'd', 'e', 's', 'p', 'o', 'i', 'l', 'e', 'd', '\n',
        'd', 'e', 's', 'p', 'o', 'i', 'l', 'i', 'n', 'g', '\n',
        'd', 'e', 's', 'p', 'o', 'n', 'd', '\n',
        'd', 'e', 's', 'p', 'o', 'n', 'd', 'e', 'n', 'c', 'y', '\n',
        'd', 'e', 's', 'p', 'o', 'n', 'd', 'e', 'n', 't', '\n',
        'd', 'e', 's', 'p', 'o', 'n', 'd', 'e', 'n', 't', 'l', 'y', '\n',
        'd', 'e', 's', 'p', 'o', 't', '\n',
        'd', 'e', 's', 'p', 'o', 't', 'i', 'c', '\n',
        'd', 'e', 's', 'p', 'o', 't', 'i', 's', 'm', '\n',
        'd', 'e', 's', 'p', 'o', 't', 's', '\n',
        'd', 'e', 's', 's', 'e', 'r', 't', '\n',
        'd', 'e', 's', 's', 'e', 'r', 't', 's', '\n',
        'd', 'e', 's', 's', 'i', 'c', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 's', 's', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 's', 't', 'a', 'b', 'i', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 's', 't', 'a', 'b', 'i', 'l', 'i', 's', 'e', '\n',
        'd', 'e', 's', 't', 'a', 'b', 'i', 'l', 'i', 's', 'e', 'd', '\n',
        'd', 'e', 's', 't', 'a', 'b', 'i', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'd', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 's', 't', 'i', 'n', 'e', '\n',
        'd', 'e', 's', 't', 'i', 'n', 'e', 'd', '\n',
        'd', 'e', 's', 't', 'i', 'n', 'i', 'e', 's', '\n',
        'd', 'e', 's', 't', 'i', 'n', 'y', '\n',
        'd', 'e', 's', 't', 'i', 't', 'u', 't', 'e', '\n',
        'd', 'e', 's', 't', 'i', 't', 'u', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 's', 't', 'r', 'o', 'y', '\n',
        'd', 'e', 's', 't', 'r', 'o', 'y', 'a', 'b', 'l', 'e', '\n',
        'd', 'e', 's', 't', 'r', 'o', 'y', 'e', 'd', '\n',
        'd', 'e', 's', 't', 'r', 'o', 'y', 'e', 'r', '\n',
        'd', 'e', 's', 't', 'r', 'o', 'y', 'e', 'r', 's', '\n',
        'd', 'e', 's', 't', 'r', 'o', 'y', 'i', 'n', 'g', '\n',
        'd', 'e', 's', 't', 'r', 'o', 'y', 's', '\n',
        'd', 'e', 's', 't', 'r', 'u', 'c', 't', '\n',
        'd', 'e', 's', 't', 'r', 'u', 'c', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 's', 't', 'r', 'u', 'c', 't', 'i', 'v', 'e', '\n',
        'd', 'e', 's', 't', 'r', 'u', 'c', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'd', 'e', 's', 't', 'r', 'u', 'c', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'd', 'e', 's', 'u', 'e', 't', 'u', 'd', 'e', '\n',
        'd', 'e', 's', 'u', 'l', 't', 'o', 'r', 'i', 'l', 'y', '\n',
        'd', 'e', 's', 'u', 'l', 't', 'o', 'r', 'i', 'n', 'e', 's', 's', '\n',
        'd', 'e', 's', 'u', 'l', 't', 'o', 'r', 'y', '\n',
        'd', 'e', 't', 'a', 'c', 'h', '\n',
        'd', 'e', 't', 'a', 'c', 'h', 'a', 'b', 'l', 'e', '\n',
        'd', 'e', 't', 'a', 'c', 'h', 'e', 'd', '\n',
        'd', 'e', 't', 'a', 'c', 'h', 'e', 's', '\n',
        'd', 'e', 't', 'a', 'c', 'h', 'i', 'n', 'g', '\n',
        'd', 'e', 't', 'a', 'c', 'h', 'm', 'e', 'n', 't', '\n',
        'd', 'e', 't', 'a', 'c', 'h', 'm', 'e', 'n', 't', 's', '\n',
        'd', 'e', 't', 'a', 'i', 'l', '\n',
        'd', 'e', 't', 'a', 'i', 'l', 'e', 'd', '\n',
        'd', 'e', 't', 'a', 'i', 'l', 'i', 'n', 'g', '\n',
        'd', 'e', 't', 'a', 'i', 'l', 's', '\n',
        'd', 'e', 't', 'a', 'i', 'n', '\n',
        'd', 'e', 't', 'a', 'i', 'n', 'e', 'd', '\n',
        'd', 'e', 't', 'a', 'i', 'n', 'e', 'e', '\n',
        'd', 'e', 't', 'a', 'i', 'n', 'e', 'e', 's', '\n',
        'd', 'e', 't', 'a', 'i', 'n', 'e', 'r', '\n',
        'd', 'e', 't', 'a', 'i', 'n', 'i', 'n', 'g', '\n',
        'd', 'e', 't', 'a', 'i', 'n', 's', '\n',
        'd', 'e', 't', 'e', 'c', 't', '\n',
        'd', 'e', 't', 'e', 'c', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'd', 'e', 't', 'e', 'c', 't', 'a', 'b', 'l', 'e', '\n',
        'd', 'e', 't', 'e', 'c', 't', 'a', 'b', 'l', 'y', '\n',
        'd', 'e', 't', 'e', 'c', 't', 'e', 'd', '\n',
        'd', 'e', 't', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 't', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 't', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 't', 'e', 'c', 't', 'i', 'v', 'e', '\n',
        'd', 'e', 't', 'e', 'c', 't', 'i', 'v', 'e', 's', '\n',
        'd', 'e', 't', 'e', 'c', 't', 'o', 'r', '\n',
        'd', 'e', 't', 'e', 'c', 't', 'o', 'r', 's', '\n',
        'd', 'e', 't', 'e', 'c', 't', 's', '\n',
        'd', 'e', 't', 'e', 'n', 't', '\n',
        'd', 'e', 't', 'e', 'n', 't', 'e', '\n',
        'd', 'e', 't', 'e', 'n', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 't', 'e', 'n', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 't', 'e', 'r', '\n',
        'd', 'e', 't', 'e', 'r', 'g', 'e', 'n', 't', '\n',
        'd', 'e', 't', 'e', 'r', 'g', 'e', 'n', 't', 's', '\n',
        'd', 'e', 't', 'e', 'r', 'i', 'o', 'r', 'a', 't', 'e', '\n',
        'd', 'e', 't', 'e', 'r', 'i', 'o', 'r', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 't', 'e', 'r', 'i', 'o', 'r', 'a', 't', 'e', 's', '\n',
        'd', 'e', 't', 'e', 'r', 'i', 'o', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 't', 'e', 'r', 'i', 'o', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 't', 'e', 'r', 'm', 'i', 'n', 'a', 'b', 'l', 'e', '\n',
        'd', 'e', 't', 'e', 'r', 'm', 'i', 'n', 'a', 'c', 'y', '\n',
        'd', 'e', 't', 'e', 'r', 'm', 'i', 'n', 'a', 'n', 't', '\n',
        'd', 'e', 't', 'e', 'r', 'm', 'i', 'n', 'a', 'n', 't', 's', '\n',
        'd', 'e', 't', 'e', 'r', 'm', 'i', 'n', 'a', 't', 'e', '\n',
        'd', 'e', 't', 'e', 'r', 'm', 'i', 'n', 'a', 't', 'e', 'l', 'y', '\n',
        'd', 'e', 't', 'e', 'r', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 't', 'e', 'r', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 't', 'e', 'r', 'm', 'i', 'n', 'a', 't', 'i', 'v', 'e', '\n',
        'd', 'e', 't', 'e', 'r', 'm', 'i', 'n', 'e', '\n',
        'd', 'e', 't', 'e', 'r', 'm', 'i', 'n', 'e', 'd', '\n',
        'd', 'e', 't', 'e', 'r', 'm', 'i', 'n', 'e', 'd', 'l', 'y', '\n',
        'd', 'e', 't', 'e', 'r', 'm', 'i', 'n', 'e', 'r', '\n',
        'd', 'e', 't', 'e', 'r', 'm', 'i', 'n', 'e', 's', '\n',
        'd', 'e', 't', 'e', 'r', 'm', 'i', 'n', 'i', 'n', 'g', '\n',
        'd', 'e', 't', 'e', 'r', 'm', 'i', 'n', 'i', 's', 'm', '\n',
        'd', 'e', 't', 'e', 'r', 'm', 'i', 'n', 'i', 's', 't', '\n',
        'd', 'e', 't', 'e', 'r', 'm', 'i', 'n', 'i', 's', 't', 'i', 'c', '\n',
        'd', 'e', 't', 'e', 'r', 'm', 'i', 'n', 'i', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'd', 'e', 't', 'e', 'r', 'r', 'e', 'd', '\n',
        'd', 'e', 't', 'e', 'r', 'r', 'e', 'n', 'c', 'e', '\n',
        'd', 'e', 't', 'e', 'r', 'r', 'e', 'n', 't', '\n',
        'd', 'e', 't', 'e', 'r', 'r', 'e', 'n', 't', 's', '\n',
        'd', 'e', 't', 'e', 'r', 'r', 'i', 'n', 'g', '\n',
        'd', 'e', 't', 'e', 'r', 's', '\n',
        'd', 'e', 't', 'e', 's', 't', '\n',
        'd', 'e', 't', 'e', 's', 't', 'a', 'b', 'l', 'e', '\n',
        'd', 'e', 't', 'e', 's', 't', 'a', 'b', 'l', 'y', '\n',
        'd', 'e', 't', 'e', 's', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 't', 'e', 's', 't', 'e', 'd', '\n',
        'd', 'e', 't', 'e', 's', 't', 'e', 'r', '\n',
        'd', 'e', 't', 'e', 's', 't', 'e', 'r', 's', '\n',
        'd', 'e', 't', 'e', 's', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 't', 'e', 's', 't', 's', '\n',
        'd', 'e', 't', 'h', 'r', 'o', 'n', 'e', '\n',
        'd', 'e', 't', 'h', 'r', 'o', 'n', 'e', 'd', '\n',
        'd', 'e', 't', 'o', 'n', 'a', 't', 'e', '\n',
        'd', 'e', 't', 'o', 'n', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 't', 'o', 'n', 'a', 't', 'e', 's', '\n',
        'd', 'e', 't', 'o', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 't', 'o', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 't', 'o', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 't', 'o', 'n', 'a', 't', 'o', 'r', '\n',
        'd', 'e', 't', 'o', 'n', 'a', 't', 'o', 'r', 's', '\n',
        'd', 'e', 't', 'o', 'u', 'r', '\n',
        'd', 'e', 't', 'o', 'u', 'r', 'e', 'd', '\n',
        'd', 'e', 't', 'o', 'u', 'r', 's', '\n',
        'd', 'e', 't', 'o', 'x', '\n',
        'd', 'e', 't', 'o', 'x', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 't', 'o', 'x', 'i', 'f', 'y', '\n',
        'd', 'e', 't', 'r', 'a', 'c', 't', '\n',
        'd', 'e', 't', 'r', 'a', 'c', 't', 'e', 'd', '\n',
        'd', 'e', 't', 'r', 'a', 'c', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 't', 'r', 'a', 'c', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 't', 'r', 'a', 'c', 't', 'o', 'r', '\n',
        'd', 'e', 't', 'r', 'a', 'c', 't', 'o', 'r', 's', '\n',
        'd', 'e', 't', 'r', 'a', 'c', 't', 's', '\n',
        'd', 'e', 't', 'r', 'i', 'm', 'e', 'n', 't', '\n',
        'd', 'e', 't', 'r', 'i', 'm', 'e', 'n', 't', 'a', 'l', '\n',
        'd', 'e', 't', 'r', 'i', 'm', 'e', 'n', 't', 'a', 'l', 'l', 'y', '\n',
        'd', 'e', 't', 'r', 'i', 't', 'a', 'l', '\n',
        'd', 'e', 't', 'r', 'i', 't', 'u', 's', '\n',
        'd', 'e', 't', 'r', 'o', 'i', 't', '\n',
        'd', 'e', 'u', 'c', 'e', '\n',
        'd', 'e', 'u', 'c', 'e', 'd', '\n',
        'd', 'e', 'u', 'c', 'e', 's', '\n',
        'd', 'e', 'u', 't', 'e', 'r', 'i', 'u', 'm', '\n',
        'd', 'e', 'u', 't', 'e', 'r', 'o', 'n', '\n',
        'd', 'e', 'v', 'a', 'l', 'u', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'v', 'a', 'l', 'u', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'v', 'a', 'l', 'u', 'e', '\n',
        'd', 'e', 'v', 'a', 'l', 'u', 'e', 'd', '\n',
        'd', 'e', 'v', 'a', 'l', 'u', 'e', 's', '\n',
        'd', 'e', 'v', 'a', 'l', 'u', 'i', 'n', 'g', '\n',
        'd', 'e', 'v', 'a', 's', 't', 'a', 't', 'e', '\n',
        'd', 'e', 'v', 'a', 's', 't', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 'v', 'a', 's', 't', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'v', 'a', 's', 't', 'a', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'd', 'e', 'v', 'a', 's', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'v', 'e', 'l', 'o', 'p', '\n',
        'd', 'e', 'v', 'e', 'l', 'o', 'p', 'e', 'd', '\n',
        'd', 'e', 'v', 'e', 'l', 'o', 'p', 'e', 'r', '\n',
        'd', 'e', 'v', 'e', 'l', 'o', 'p', 'e', 'r', 's', '\n',
        'd', 'e', 'v', 'e', 'l', 'o', 'p', 'i', 'n', 'g', '\n',
        'd', 'e', 'v', 'e', 'l', 'o', 'p', 'm', 'e', 'n', 't', '\n',
        'd', 'e', 'v', 'e', 'l', 'o', 'p', 'm', 'e', 'n', 't', 'a', 'l', '\n',
        'd', 'e', 'v', 'e', 'l', 'o', 'p', 'm', 'e', 'n', 't', 'a', 'l', 'l', 'y', '\n',
        'd', 'e', 'v', 'e', 'l', 'o', 'p', 'm', 'e', 'n', 't', 's', '\n',
        'd', 'e', 'v', 'e', 'l', 'o', 'p', 's', '\n',
        'd', 'e', 'v', 'i', 'a', 'n', 'c', 'e', '\n',
        'd', 'e', 'v', 'i', 'a', 'n', 'c', 'y', '\n',
        'd', 'e', 'v', 'i', 'a', 'n', 't', '\n',
        'd', 'e', 'v', 'i', 'a', 'n', 't', 's', '\n',
        'd', 'e', 'v', 'i', 'a', 't', 'e', '\n',
        'd', 'e', 'v', 'i', 'a', 't', 'e', 'd', '\n',
        'd', 'e', 'v', 'i', 'a', 't', 'e', 's', '\n',
        'd', 'e', 'v', 'i', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'v', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'v', 'i', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'v', 'i', 'c', 'e', '\n',
        'd', 'e', 'v', 'i', 'c', 'e', 's', '\n',
        'd', 'e', 'v', 'i', 'l', '\n',
        'd', 'e', 'v', 'i', 'l', 'i', 's', 'h', '\n',
        'd', 'e', 'v', 'i', 'l', 'i', 's', 'h', 'l', 'y', '\n',
        'd', 'e', 'v', 'i', 'l', 'l', 'e', 'd', '\n',
        'd', 'e', 'v', 'i', 'l', 'm', 'e', 'n', 't', '\n',
        'd', 'e', 'v', 'i', 'l', 'r', 'y', '\n',
        'd', 'e', 'v', 'i', 'l', 's', '\n',
        'd', 'e', 'v', 'i', 'o', 'u', 's', '\n',
        'd', 'e', 'v', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'd', 'e', 'v', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'd', 'e', 'v', 'i', 's', 'a', 'l', '\n',
        'd', 'e', 'v', 'i', 's', 'e', '\n',
        'd', 'e', 'v', 'i', 's', 'e', 'd', '\n',
        'd', 'e', 'v', 'i', 's', 'e', 'r', '\n',
        'd', 'e', 'v', 'i', 's', 'e', 's', '\n',
        'd', 'e', 'v', 'i', 's', 'i', 'n', 'g', '\n',
        'd', 'e', 'v', 'o', 'i', 'c', 'e', '\n',
        'd', 'e', 'v', 'o', 'i', 'd', '\n',
        'd', 'e', 'v', 'o', 'i', 'r', '\n',
        'd', 'e', 'v', 'o', 'l', 'u', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'v', 'o', 'l', 'v', 'e', '\n',
        'd', 'e', 'v', 'o', 'l', 'v', 'e', 'd', '\n',
        'd', 'e', 'v', 'o', 'l', 'v', 'i', 'n', 'g', '\n',
        'd', 'e', 'v', 'o', 't', 'e', '\n',
        'd', 'e', 'v', 'o', 't', 'e', 'd', '\n',
        'd', 'e', 'v', 'o', 't', 'e', 'd', 'l', 'y', '\n',
        'd', 'e', 'v', 'o', 't', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'd', 'e', 'v', 'o', 't', 'e', 'e', '\n',
        'd', 'e', 'v', 'o', 't', 'e', 'e', 's', '\n',
        'd', 'e', 'v', 'o', 't', 'e', 's', '\n',
        'd', 'e', 'v', 'o', 't', 'i', 'n', 'g', '\n',
        'd', 'e', 'v', 'o', 't', 'i', 'o', 'n', '\n',
        'd', 'e', 'v', 'o', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'd', 'e', 'v', 'o', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'e', 'v', 'o', 'u', 'r', '\n',
        'd', 'e', 'v', 'o', 'u', 'r', 'e', 'd', '\n',
        'd', 'e', 'v', 'o', 'u', 'r', 'e', 'r', '\n',
        'd', 'e', 'v', 'o', 'u', 'r', 'e', 'r', 's', '\n',
        'd', 'e', 'v', 'o', 'u', 'r', 'i', 'n', 'g', '\n',
        'd', 'e', 'v', 'o', 'u', 'r', 's', '\n',
        'd', 'e', 'v', 'o', 'u', 't', '\n',
        'd', 'e', 'v', 'o', 'u', 't', 'l', 'y', '\n',
        'd', 'e', 'v', 'o', 'u', 't', 'n', 'e', 's', 's', '\n',
        'd', 'e', 'w', '\n',
        'd', 'e', 'w', 'd', 'r', 'o', 'p', '\n',
        'd', 'e', 'w', 'd', 'r', 'o', 'p', 's', '\n',
        'd', 'e', 'w', 's', '\n',
        'd', 'e', 'w', 'y', '\n',
        'd', 'e', 'x', 't', 'e', 'r', 'i', 't', 'y', '\n',
        'd', 'e', 'x', 't', 'e', 'r', 'o', 'u', 's', '\n',
        'd', 'e', 'x', 't', 'e', 'r', 'o', 'u', 's', 'l', 'y', '\n',
        'd', 'e', 'x', 't', 'r', 'a', 'l', '\n',
        'd', 'e', 'x', 't', 'r', 'o', 's', 'e', '\n',
        'd', 'e', 'x', 't', 'r', 'o', 'u', 's', '\n',
        'd', 'e', 'x', 't', 'r', 'o', 'u', 's', 'l', 'y', '\n',
        'd', 'h', 'o', 'w', '\n',
        'd', 'i', 'a', 'b', 'e', 't', 'e', 's', '\n',
        'd', 'i', 'a', 'b', 'e', 't', 'i', 'c', '\n',
        'd', 'i', 'a', 'b', 'e', 't', 'i', 'c', 's', '\n',
        'd', 'i', 'a', 'b', 'o', 'l', 'i', 'c', '\n',
        'd', 'i', 'a', 'b', 'o', 'l', 'i', 'c', 'a', 'l', '\n',
        'd', 'i', 'a', 'b', 'o', 'l', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'd', 'i', 'a', 'b', 'o', 'l', 'i', 's', 'm', '\n',
        'd', 'i', 'a', 'c', 'h', 'r', 'o', 'n', 'i', 'c', '\n',
        'd', 'i', 'a', 'c', 'o', 'n', 'a', 'l', '\n',
        'd', 'i', 'a', 'c', 'r', 'i', 't', 'i', 'c', 'a', 'l', '\n',
        'd', 'i', 'a', 'c', 'r', 'i', 't', 'i', 'c', 'a', 'l', 's', '\n',
        'd', 'i', 'a', 'c', 'r', 'i', 't', 'i', 'c', 's', '\n',
        'd', 'i', 'a', 'd', 'e', 'm', '\n',
        'd', 'i', 'a', 'd', 'e', 'm', 's', '\n',
        'd', 'i', 'a', 'g', 'n', 'o', 's', 'a', 'b', 'l', 'e', '\n',
        'd', 'i', 'a', 'g', 'n', 'o', 's', 'e', '\n',
        'd', 'i', 'a', 'g', 'n', 'o', 's', 'e', 'd', '\n',
        'd', 'i', 'a', 'g', 'n', 'o', 's', 'e', 's', '\n',
        'd', 'i', 'a', 'g', 'n', 'o', 's', 'i', 'n', 'g', '\n',
        'd', 'i', 'a', 'g', 'n', 'o', 's', 'i', 's', '\n',
        'd', 'i', 'a', 'g', 'n', 'o', 's', 't', 'i', 'c', '\n',
        'd', 'i', 'a', 'g', 'n', 'o', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'd', 'i', 'a', 'g', 'n', 'o', 's', 't', 'i', 'c', 'i', 'a', 'n', '\n',
        'd', 'i', 'a', 'g', 'n', 'o', 's', 't', 'i', 'c', 's', '\n',
        'd', 'i', 'a', 'g', 'o', 'n', 'a', 'l', '\n',
        'd', 'i', 'a', 'g', 'o', 'n', 'a', 'l', 'i', 's', 'e', '\n',
        'd', 'i', 'a', 'g', 'o', 'n', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'd', 'i', 'a', 'g', 'o', 'n', 'a', 'l', 'i', 's', 'e', 's', '\n',
        'd', 'i', 'a', 'g', 'o', 'n', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'd', 'i', 'a', 'g', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'd', 'i', 'a', 'g', 'o', 'n', 'a', 'l', 's', '\n',
        'd', 'i', 'a', 'g', 'r', 'a', 'm', '\n',
        'd', 'i', 'a', 'g', 'r', 'a', 'm', 'm', 'a', 't', 'i', 'c', '\n',
        'd', 'i', 'a', 'g', 'r', 'a', 'm', 'm', 'a', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'd', 'i', 'a', 'g', 'r', 'a', 'm', 's', '\n',
        'd', 'i', 'a', 'l', '\n',
        'd', 'i', 'a', 'l', 'e', 'c', 't', '\n',
        'd', 'i', 'a', 'l', 'e', 'c', 't', 'a', 'l', '\n',
        'd', 'i', 'a', 'l', 'e', 'c', 't', 'i', 'c', '\n',
        'd', 'i', 'a', 'l', 'e', 'c', 't', 'i', 'c', 'a', 'l', '\n',
        'd', 'i', 'a', 'l', 'e', 'c', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'd', 'i', 'a', 'l', 'e', 'c', 't', 'i', 'c', 's', '\n',
        'd', 'i', 'a', 'l', 'e', 'c', 't', 's', '\n',
        'd', 'i', 'a', 'l', 'i', 'n', 'g', '\n',
        'd', 'i', 'a', 'l', 'l', 'e', 'd', '\n',
        'd', 'i', 'a', 'l', 'l', 'e', 'r', '\n',
        'd', 'i', 'a', 'l', 'l', 'i', 'n', 'g', '\n',
        'd', 'i', 'a', 'l', 'o', 'g', '\n',
        'd', 'i', 'a', 'l', 'o', 'g', 'u', 'e', '\n',
        'd', 'i', 'a', 'l', 'o', 'g', 'u', 'e', 's', '\n',
        'd', 'i', 'a', 'l', 's', '\n',
        'd', 'i', 'a', 'l', 'y', 's', 'i', 's', '\n',
        'd', 'i', 'a', 'm', 'a', 'n', 't', 'e', '\n',
        'd', 'i', 'a', 'm', 'e', 't', 'e', 'r', '\n',
        'd', 'i', 'a', 'm', 'e', 't', 'e', 'r', 's', '\n',
        'd', 'i', 'a', 'm', 'e', 't', 'r', 'i', 'c', '\n',
        'd', 'i', 'a', 'm', 'e', 't', 'r', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'd', 'i', 'a', 'm', 'o', 'n', 'd', '\n',
        'd', 'i', 'a', 'm', 'o', 'n', 'd', 's', '\n',
        'd', 'i', 'a', 'n', 'a', '\n',
        'd', 'i', 'a', 'p', 'a', 's', 'o', 'n', '\n',
        'd', 'i', 'a', 'p', 'e', 'r', '\n',
        'd', 'i', 'a', 'p', 'e', 'r', 's', '\n',
        'd', 'i', 'a', 'p', 'h', 'a', 'n', 'o', 'u', 's', '\n',
        'd', 'i', 'a', 'p', 'h', 'r', 'a', 'g', 'm', '\n',
        'd', 'i', 'a', 'p', 'h', 'r', 'a', 'g', 'm', 'a', 't', 'i', 'c', '\n',
        'd', 'i', 'a', 'p', 'h', 'r', 'a', 'g', 'm', 's', '\n',
        'd', 'i', 'a', 'r', 'i', 'e', 's', '\n',
        'd', 'i', 'a', 'r', 'i', 's', 't', '\n',
        'd', 'i', 'a', 'r', 'r', 'h', 'e', 'a', '\n',
        'd', 'i', 'a', 'r', 'r', 'h', 'o', 'e', 'a', '\n',
        'd', 'i', 'a', 'r', 'r', 'h', 'o', 'e', 'a', 'l', '\n',
        'd', 'i', 'a', 'r', 'y', '\n',
        'd', 'i', 'a', 's', 'p', 'o', 'r', 'a', '\n',
        'd', 'i', 'a', 's', 't', 'o', 'l', 'i', 'c', '\n',
        'd', 'i', 'a', 't', 'h', 'e', 'r', 'm', 'y', '\n',
        'd', 'i', 'a', 't', 'o', 'm', '\n',
        'd', 'i', 'a', 't', 'o', 'm', 'i', 'c', '\n',
        'd', 'i', 'a', 't', 'o', 'm', 's', '\n',
        'd', 'i', 'a', 't', 'o', 'n', 'i', 'c', '\n',
        'd', 'i', 'a', 't', 'r', 'i', 'b', 'e', '\n',
        'd', 'i', 'a', 't', 'r', 'i', 'b', 'e', 's', '\n',
        'd', 'i', 'c', 'e', '\n',
        'd', 'i', 'c', 'e', 'd', '\n',
        'd', 'i', 'c', 'e', 's', '\n',
        'd', 'i', 'c', 'e', 'y', '\n',
        'd', 'i', 'c', 'h', 'l', 'o', 'r', 'i', 'd', 'e', '\n',
        'd', 'i', 'c', 'h', 'o', 't', 'o', 'm', 'i', 'e', 's', '\n',
        'd', 'i', 'c', 'h', 'o', 't', 'o', 'm', 'o', 'u', 's', '\n',
        'd', 'i', 'c', 'h', 'o', 't', 'o', 'm', 'y', '\n',
        'd', 'i', 'c', 'i', 'e', 's', 't', '\n',
        'd', 'i', 'c', 'i', 'n', 'g', '\n',
        'd', 'i', 'c', 'k', 'e', 'n', 's', '\n',
        'd', 'i', 'c', 't', 'a', 't', 'e', '\n',
        'd', 'i', 'c', 't', 'a', 't', 'e', 'd', '\n',
        'd', 'i', 'c', 't', 'a', 't', 'e', 's', '\n',
        'd', 'i', 'c', 't', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 'c', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 'c', 't', 'a', 't', 'o', 'r', '\n',
        'd', 'i', 'c', 't', 'a', 't', 'o', 'r', 'i', 'a', 'l', '\n',
        'd', 'i', 'c', 't', 'a', 't', 'o', 'r', 'i', 'a', 'l', 'l', 'y', '\n',
        'd', 'i', 'c', 't', 'a', 't', 'o', 'r', 's', '\n',
        'd', 'i', 'c', 't', 'a', 't', 'o', 'r', 's', 'h', 'i', 'p', '\n',
        'd', 'i', 'c', 't', 'a', 't', 'o', 'r', 's', 'h', 'i', 'p', 's', '\n',
        'd', 'i', 'c', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 'c', 't', 'i', 'o', 'n', 'a', 'r', 'i', 'e', 's', '\n',
        'd', 'i', 'c', 't', 'i', 'o', 'n', 'a', 'r', 'y', '\n',
        'd', 'i', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'i', 'c', 't', 'u', 'm', '\n',
        'd', 'i', 'd', '\n',
        'd', 'i', 'd', 'a', 'c', 't', 'i', 'c', '\n',
        'd', 'i', 'd', 'n', 't', '\n',
        'd', 'i', 'e', '\n',
        'd', 'i', 'e', 'd', '\n',
        'd', 'i', 'e', 'h', 'a', 'r', 'd', '\n',
        'd', 'i', 'e', 'h', 'a', 'r', 'd', 's', '\n',
        'd', 'i', 'e', 'l', 'e', 'c', 't', 'r', 'i', 'c', '\n',
        'd', 'i', 'e', 'l', 'e', 'c', 't', 'r', 'i', 'c', 's', '\n',
        'd', 'i', 'e', 's', '\n',
        'd', 'i', 'e', 's', 'e', 'l', '\n',
        'd', 'i', 'e', 's', 'e', 'l', 'e', 'l', 'e', 'c', 't', 'r', 'i', 'c', '\n',
        'd', 'i', 'e', 's', 'e', 'l', 's', '\n',
        'd', 'i', 'e', 't', '\n',
        'd', 'i', 'e', 't', 'a', 'r', 'y', '\n',
        'd', 'i', 'e', 't', 'e', 'd', '\n',
        'd', 'i', 'e', 't', 'e', 'r', '\n',
        'd', 'i', 'e', 't', 'e', 't', 'i', 'c', '\n',
        'd', 'i', 'e', 't', 'i', 'c', 'i', 'a', 'n', '\n',
        'd', 'i', 'e', 't', 'i', 'c', 'i', 'a', 'n', 's', '\n',
        'd', 'i', 'e', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 'e', 't', 'i', 't', 'i', 'a', 'n', '\n',
        'd', 'i', 'e', 't', 'i', 't', 'i', 'a', 'n', 's', '\n',
        'd', 'i', 'e', 't', 's', '\n',
        'd', 'i', 'f', 'f', 'e', 'r', '\n',
        'd', 'i', 'f', 'f', 'e', 'r', 'e', 'd', '\n',
        'd', 'i', 'f', 'f', 'e', 'r', 'e', 'n', 'c', 'e', '\n',
        'd', 'i', 'f', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 's', '\n',
        'd', 'i', 'f', 'f', 'e', 'r', 'e', 'n', 'c', 'i', 'n', 'g', '\n',
        'd', 'i', 'f', 'f', 'e', 'r', 'e', 'n', 't', '\n',
        'd', 'i', 'f', 'f', 'e', 'r', 'e', 'n', 't', 'i', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'd', 'i', 'f', 'f', 'e', 'r', 'e', 'n', 't', 'i', 'a', 'b', 'l', 'e', '\n',
        'd', 'i', 'f', 'f', 'e', 'r', 'e', 'n', 't', 'i', 'a', 'l', '\n',
        'd', 'i', 'f', 'f', 'e', 'r', 'e', 'n', 't', 'i', 'a', 'l', 'l', 'y', '\n',
        'd', 'i', 'f', 'f', 'e', 'r', 'e', 'n', 't', 'i', 'a', 'l', 's', '\n',
        'd', 'i', 'f', 'f', 'e', 'r', 'e', 'n', 't', 'i', 'a', 't', 'e', '\n',
        'd', 'i', 'f', 'f', 'e', 'r', 'e', 'n', 't', 'i', 'a', 't', 'e', 'd', '\n',
        'd', 'i', 'f', 'f', 'e', 'r', 'e', 'n', 't', 'i', 'a', 't', 'e', 's', '\n',
        'd', 'i', 'f', 'f', 'e', 'r', 'e', 'n', 't', 'i', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 'f', 'f', 'e', 'r', 'e', 'n', 't', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 'f', 'f', 'e', 'r', 'e', 'n', 't', 'i', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'i', 'f', 'f', 'e', 'r', 'e', 'n', 't', 'i', 'a', 't', 'o', 'r', 's', '\n',
        'd', 'i', 'f', 'f', 'e', 'r', 'e', 'n', 't', 'l', 'y', '\n',
        'd', 'i', 'f', 'f', 'e', 'r', 'i', 'n', 'g', '\n',
        'd', 'i', 'f', 'f', 'e', 'r', 's', '\n',
        'd', 'i', 'f', 'f', 'i', 'c', 'u', 'l', 't', '\n',
        'd', 'i', 'f', 'f', 'i', 'c', 'u', 'l', 't', 'i', 'e', 's', '\n',
        'd', 'i', 'f', 'f', 'i', 'c', 'u', 'l', 't', 'y', '\n',
        'd', 'i', 'f', 'f', 'i', 'd', 'e', 'n', 'c', 'e', '\n',
        'd', 'i', 'f', 'f', 'i', 'd', 'e', 'n', 't', '\n',
        'd', 'i', 'f', 'f', 'i', 'd', 'e', 'n', 't', 'l', 'y', '\n',
        'd', 'i', 'f', 'f', 'r', 'a', 'c', 't', '\n',
        'd', 'i', 'f', 'f', 'r', 'a', 'c', 't', 'e', 'd', '\n',
        'd', 'i', 'f', 'f', 'r', 'a', 'c', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 'f', 'f', 'r', 'a', 'c', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 'f', 'f', 'r', 'a', 'c', 't', 's', '\n',
        'd', 'i', 'f', 'f', 'u', 's', 'e', '\n',
        'd', 'i', 'f', 'f', 'u', 's', 'e', 'd', '\n',
        'd', 'i', 'f', 'f', 'u', 's', 'e', 'r', '\n',
        'd', 'i', 'f', 'f', 'u', 's', 'e', 'r', 's', '\n',
        'd', 'i', 'f', 'f', 'u', 's', 'e', 's', '\n',
        'd', 'i', 'f', 'f', 'u', 's', 'i', 'n', 'g', '\n',
        'd', 'i', 'f', 'f', 'u', 's', 'i', 'o', 'n', '\n',
        'd', 'i', 'f', 'f', 'u', 's', 'i', 'o', 'n', 'a', 'l', '\n',
        'd', 'i', 'f', 'f', 'u', 's', 'i', 'v', 'e', '\n',
        'd', 'i', 'f', 'f', 'u', 's', 'i', 'v', 'i', 't', 'y', '\n',
        'd', 'i', 'g', '\n',
        'd', 'i', 'g', 'e', 's', 't', '\n',
        'd', 'i', 'g', 'e', 's', 't', 'e', 'd', '\n',
        'd', 'i', 'g', 'e', 's', 't', 'e', 'r', '\n',
        'd', 'i', 'g', 'e', 's', 't', 'i', 'b', 'l', 'e', '\n',
        'd', 'i', 'g', 'e', 's', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 'g', 'e', 's', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 'g', 'e', 's', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'i', 'g', 'e', 's', 't', 'i', 'v', 'e', '\n',
        'd', 'i', 'g', 'e', 's', 't', 'i', 'v', 'e', 's', '\n',
        'd', 'i', 'g', 'e', 's', 't', 's', '\n',
        'd', 'i', 'g', 'g', 'e', 'r', '\n',
        'd', 'i', 'g', 'g', 'e', 'r', 's', '\n',
        'd', 'i', 'g', 'g', 'i', 'n', 'g', '\n',
        'd', 'i', 'g', 'g', 'i', 'n', 'g', 's', '\n',
        'd', 'i', 'g', 'i', 't', '\n',
        'd', 'i', 'g', 'i', 't', 'a', 'l', '\n',
        'd', 'i', 'g', 'i', 't', 'a', 'l', 'i', 's', '\n',
        'd', 'i', 'g', 'i', 't', 'a', 'l', 'l', 'y', '\n',
        'd', 'i', 'g', 'i', 't', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 'g', 'i', 't', 'i', 's', 'e', '\n',
        'd', 'i', 'g', 'i', 't', 'i', 's', 'e', 'd', '\n',
        'd', 'i', 'g', 'i', 't', 'i', 's', 'e', 'r', '\n',
        'd', 'i', 'g', 'i', 't', 'i', 's', 'e', 'r', 's', '\n',
        'd', 'i', 'g', 'i', 't', 'i', 's', 'i', 'n', 'g', '\n',
        'd', 'i', 'g', 'i', 't', 's', '\n',
        'd', 'i', 'g', 'n', 'i', 'f', 'i', 'e', 'd', '\n',
        'd', 'i', 'g', 'n', 'i', 'f', 'y', '\n',
        'd', 'i', 'g', 'n', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'd', 'i', 'g', 'n', 'i', 't', 'a', 'r', 'i', 'e', 's', '\n',
        'd', 'i', 'g', 'n', 'i', 't', 'a', 'r', 'y', '\n',
        'd', 'i', 'g', 'n', 'i', 't', 'i', 'e', 's', '\n',
        'd', 'i', 'g', 'n', 'i', 't', 'y', '\n',
        'd', 'i', 'g', 'r', 'a', 'p', 'h', 's', '\n',
        'd', 'i', 'g', 'r', 'e', 's', 's', '\n',
        'd', 'i', 'g', 'r', 'e', 's', 's', 'e', 'd', '\n',
        'd', 'i', 'g', 'r', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'd', 'i', 'g', 'r', 'e', 's', 's', 'i', 'o', 'n', '\n',
        'd', 'i', 'g', 'r', 'e', 's', 's', 'i', 'o', 'n', 's', '\n',
        'd', 'i', 'g', 's', '\n',
        'd', 'i', 'h', 'e', 'd', 'r', 'a', 'l', '\n',
        'd', 'i', 'k', 'e', 's', '\n',
        'd', 'i', 'k', 't', 'a', 't', '\n',
        'd', 'i', 'k', 't', 'a', 't', 's', '\n',
        'd', 'i', 'l', 'a', 'p', 'i', 'd', 'a', 't', 'e', 'd', '\n',
        'd', 'i', 'l', 'a', 'p', 'i', 'd', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 'l', 'a', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 'l', 'a', 't', 'e', '\n',
        'd', 'i', 'l', 'a', 't', 'e', 'd', '\n',
        'd', 'i', 'l', 'a', 't', 'e', 's', '\n',
        'd', 'i', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 'l', 'a', 't', 'o', 'r', '\n',
        'd', 'i', 'l', 'a', 't', 'o', 'r', 'y', '\n',
        'd', 'i', 'l', 'd', 'o', '\n',
        'd', 'i', 'l', 'e', 'm', 'm', 'a', '\n',
        'd', 'i', 'l', 'e', 'm', 'm', 'a', 's', '\n',
        'd', 'i', 'l', 'e', 't', 't', 'a', 'n', 't', 'e', '\n',
        'd', 'i', 'l', 'e', 't', 't', 'a', 'n', 't', 'e', 's', '\n',
        'd', 'i', 'l', 'i', 'g', 'e', 'n', 'c', 'e', '\n',
        'd', 'i', 'l', 'i', 'g', 'e', 'n', 't', '\n',
        'd', 'i', 'l', 'i', 'g', 'e', 'n', 't', 'l', 'y', '\n',
        'd', 'i', 'l', 'l', '\n',
        'd', 'i', 'l', 'l', 'y', '\n',
        'd', 'i', 'l', 'u', 'e', 'n', 't', '\n',
        'd', 'i', 'l', 'u', 't', 'e', '\n',
        'd', 'i', 'l', 'u', 't', 'e', 'd', '\n',
        'd', 'i', 'l', 'u', 't', 'e', 'r', '\n',
        'd', 'i', 'l', 'u', 't', 'e', 's', '\n',
        'd', 'i', 'l', 'u', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 'l', 'u', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 'l', 'u', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'i', 'm', '\n',
        'd', 'i', 'm', 'e', '\n',
        'd', 'i', 'm', 'e', 'n', 's', 'i', 'o', 'n', '\n',
        'd', 'i', 'm', 'e', 'n', 's', 'i', 'o', 'n', 'a', 'l', '\n',
        'd', 'i', 'm', 'e', 'n', 's', 'i', 'o', 'n', 'a', 'l', 'i', 't', 'y', '\n',
        'd', 'i', 'm', 'e', 'n', 's', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'd', 'i', 'm', 'e', 'n', 's', 'i', 'o', 'n', 'e', 'd', '\n',
        'd', 'i', 'm', 'e', 'n', 's', 'i', 'o', 'n', 'i', 'n', 'g', '\n',
        'd', 'i', 'm', 'e', 'n', 's', 'i', 'o', 'n', 'l', 'e', 's', 's', '\n',
        'd', 'i', 'm', 'e', 'n', 's', 'i', 'o', 'n', 's', '\n',
        'd', 'i', 'm', 'e', 'r', '\n',
        'd', 'i', 'm', 'e', 'r', 's', '\n',
        'd', 'i', 'm', 'e', 's', '\n',
        'd', 'i', 'm', 'i', 'n', 'i', 's', 'h', '\n',
        'd', 'i', 'm', 'i', 'n', 'i', 's', 'h', 'a', 'b', 'l', 'e', '\n',
        'd', 'i', 'm', 'i', 'n', 'i', 's', 'h', 'e', 'd', '\n',
        'd', 'i', 'm', 'i', 'n', 'i', 's', 'h', 'e', 's', '\n',
        'd', 'i', 'm', 'i', 'n', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'd', 'i', 'm', 'i', 'n', 'u', 'e', 'n', 'd', 'o', '\n',
        'd', 'i', 'm', 'i', 'n', 'u', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 'm', 'i', 'n', 'u', 't', 'i', 'v', 'e', '\n',
        'd', 'i', 'm', 'i', 'n', 'u', 't', 'i', 'v', 'e', 's', '\n',
        'd', 'i', 'm', 'l', 'y', '\n',
        'd', 'i', 'm', 'm', 'e', 'd', '\n',
        'd', 'i', 'm', 'm', 'e', 'r', '\n',
        'd', 'i', 'm', 'm', 'e', 'r', 's', '\n',
        'd', 'i', 'm', 'm', 'e', 's', 't', '\n',
        'd', 'i', 'm', 'm', 'i', 'n', 'g', '\n',
        'd', 'i', 'm', 'n', 'e', 's', 's', '\n',
        'd', 'i', 'm', 'o', 'r', 'p', 'h', 'i', 'c', '\n',
        'd', 'i', 'm', 'o', 'r', 'p', 'h', 'i', 's', 'm', '\n',
        'd', 'i', 'm', 'p', 'l', 'e', '\n',
        'd', 'i', 'm', 'p', 'l', 'e', 'd', '\n',
        'd', 'i', 'm', 'p', 'l', 'e', 's', '\n',
        'd', 'i', 'm', 's', '\n',
        'd', 'i', 'm', 'w', 'i', 't', '\n',
        'd', 'i', 'n', '\n',
        'd', 'i', 'n', 'a', 'r', '\n',
        'd', 'i', 'n', 'a', 'r', 's', '\n',
        'd', 'i', 'n', 'e', '\n',
        'd', 'i', 'n', 'e', 'd', '\n',
        'd', 'i', 'n', 'e', 'r', '\n',
        'd', 'i', 'n', 'e', 'r', 's', '\n',
        'd', 'i', 'n', 'e', 's', '\n',
        'd', 'i', 'n', 'g', '\n',
        'd', 'i', 'n', 'g', 'd', 'o', 'n', 'g', '\n',
        'd', 'i', 'n', 'g', 'e', 'd', '\n',
        'd', 'i', 'n', 'g', 'h', 'i', 'e', 's', '\n',
        'd', 'i', 'n', 'g', 'h', 'y', '\n',
        'd', 'i', 'n', 'g', 'i', 'e', 'r', '\n',
        'd', 'i', 'n', 'g', 'i', 'e', 's', 't', '\n',
        'd', 'i', 'n', 'g', 'i', 'n', 'e', 's', 's', '\n',
        'd', 'i', 'n', 'g', 'l', 'e', '\n',
        'd', 'i', 'n', 'g', 'o', '\n',
        'd', 'i', 'n', 'g', 'y', '\n',
        'd', 'i', 'n', 'i', 'n', 'g', '\n',
        'd', 'i', 'n', 'k', 'y', '\n',
        'd', 'i', 'n', 'n', 'e', 'r', '\n',
        'd', 'i', 'n', 'n', 'e', 'r', 's', '\n',
        'd', 'i', 'n', 'o', 's', 'a', 'u', 'r', '\n',
        'd', 'i', 'n', 'o', 's', 'a', 'u', 'r', 's', '\n',
        'd', 'i', 'n', 't', '\n',
        'd', 'i', 'n', 't', 's', '\n',
        'd', 'i', 'o', 'c', 'e', 's', 'a', 'n', '\n',
        'd', 'i', 'o', 'c', 'e', 's', 'e', '\n',
        'd', 'i', 'o', 'd', 'e', '\n',
        'd', 'i', 'o', 'd', 'e', 's', '\n',
        'd', 'i', 'o', 'p', 't', 'r', 'e', '\n',
        'd', 'i', 'o', 'p', 't', 'r', 'e', 's', '\n',
        'd', 'i', 'o', 'x', 'i', 'd', 'e', '\n',
        'd', 'i', 'o', 'x', 'i', 'd', 'e', 's', '\n',
        'd', 'i', 'o', 'x', 'i', 'n', '\n',
        'd', 'i', 'o', 'x', 'i', 'n', 's', '\n',
        'd', 'i', 'p', '\n',
        'd', 'i', 'p', 'h', 't', 'h', 'e', 'r', 'i', 'a', '\n',
        'd', 'i', 'p', 'h', 't', 'h', 'o', 'n', 'g', '\n',
        'd', 'i', 'p', 'h', 't', 'h', 'o', 'n', 'g', 's', '\n',
        'd', 'i', 'p', 'l', 'e', 'x', 'e', 'r', 's', '\n',
        'd', 'i', 'p', 'l', 'o', 'i', 'd', '\n',
        'd', 'i', 'p', 'l', 'o', 'm', 'a', '\n',
        'd', 'i', 'p', 'l', 'o', 'm', 'a', 'c', 'y', '\n',
        'd', 'i', 'p', 'l', 'o', 'm', 'a', 's', '\n',
        'd', 'i', 'p', 'l', 'o', 'm', 'a', 't', '\n',
        'd', 'i', 'p', 'l', 'o', 'm', 'a', 't', 'i', 'c', '\n',
        'd', 'i', 'p', 'l', 'o', 'm', 'a', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'd', 'i', 'p', 'l', 'o', 'm', 'a', 't', 's', '\n',
        'd', 'i', 'p', 'o', 'l', 'a', 'r', '\n',
        'd', 'i', 'p', 'o', 'l', 'e', '\n',
        'd', 'i', 'p', 'o', 'l', 'e', 's', '\n',
        'd', 'i', 'p', 'p', 'e', 'd', '\n',
        'd', 'i', 'p', 'p', 'e', 'r', '\n',
        'd', 'i', 'p', 'p', 'i', 'n', 'g', '\n',
        'd', 'i', 'p', 's', '\n',
        'd', 'i', 'p', 's', 'o', 'm', 'a', 'n', 'i', 'a', '\n',
        'd', 'i', 'p', 's', 'o', 'm', 'a', 'n', 'i', 'a', 'c', '\n',
        'd', 'i', 'p', 's', 'o', 'm', 'a', 'n', 'i', 'a', 'c', 's', '\n',
        'd', 'i', 'p', 's', 't', 'i', 'c', 'k', '\n',
        'd', 'i', 'p', 's', 't', 'i', 'c', 'k', 's', '\n',
        'd', 'i', 'r', 'e', '\n',
        'd', 'i', 'r', 'e', 'c', 't', '\n',
        'd', 'i', 'r', 'e', 'c', 't', 'e', 'd', '\n',
        'd', 'i', 'r', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'd', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'a', 'l', 'i', 't', 'y', '\n',
        'd', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'd', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'l', 'e', 's', 's', '\n',
        'd', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'i', 'r', 'e', 'c', 't', 'i', 'v', 'e', '\n',
        'd', 'i', 'r', 'e', 'c', 't', 'i', 'v', 'e', 's', '\n',
        'd', 'i', 'r', 'e', 'c', 't', 'l', 'y', '\n',
        'd', 'i', 'r', 'e', 'c', 't', 'n', 'e', 's', 's', '\n',
        'd', 'i', 'r', 'e', 'c', 't', 'o', 'r', '\n',
        'd', 'i', 'r', 'e', 'c', 't', 'o', 'r', 'a', 't', 'e', '\n',
        'd', 'i', 'r', 'e', 'c', 't', 'o', 'r', 'a', 't', 'e', 's', '\n',
        'd', 'i', 'r', 'e', 'c', 't', 'o', 'r', 'i', 'a', 'l', '\n',
        'd', 'i', 'r', 'e', 'c', 't', 'o', 'r', 'i', 'e', 's', '\n',
        'd', 'i', 'r', 'e', 'c', 't', 'o', 'r', 's', '\n',
        'd', 'i', 'r', 'e', 'c', 't', 'o', 'r', 's', 'h', 'i', 'p', '\n',
        'd', 'i', 'r', 'e', 'c', 't', 'o', 'r', 's', 'h', 'i', 'p', 's', '\n',
        'd', 'i', 'r', 'e', 'c', 't', 'o', 'r', 'y', '\n',
        'd', 'i', 'r', 'e', 'c', 't', 's', '\n',
        'd', 'i', 'r', 'e', 'l', 'y', '\n',
        'd', 'i', 'r', 'e', 'n', 'e', 's', 's', '\n',
        'd', 'i', 'r', 'e', 's', 't', '\n',
        'd', 'i', 'r', 'g', 'e', '\n',
        'd', 'i', 'r', 'g', 'e', 's', '\n',
        'd', 'i', 'r', 'i', 'g', 'i', 'b', 'l', 'e', '\n',
        'd', 'i', 'r', 'i', 'g', 'i', 's', 't', 'e', '\n',
        'd', 'i', 'r', 't', '\n',
        'd', 'i', 'r', 't', 'i', 'e', 'd', '\n',
        'd', 'i', 'r', 't', 'i', 'e', 'r', '\n',
        'd', 'i', 'r', 't', 'i', 'e', 's', '\n',
        'd', 'i', 'r', 't', 'i', 'e', 's', 't', '\n',
        'd', 'i', 'r', 't', 'i', 'l', 'y', '\n',
        'd', 'i', 'r', 't', 'i', 'n', 'e', 's', 's', '\n',
        'd', 'i', 'r', 't', 's', '\n',
        'd', 'i', 'r', 't', 'y', '\n',
        'd', 'i', 'r', 't', 'y', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'a', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'd', 'i', 's', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'd', 'i', 's', 'a', 'b', 'l', 'e', '\n',
        'd', 'i', 's', 'a', 'b', 'l', 'e', 'd', '\n',
        'd', 'i', 's', 'a', 'b', 'l', 'e', 'm', 'e', 'n', 't', '\n',
        'd', 'i', 's', 'a', 'b', 'l', 'e', 's', '\n',
        'd', 'i', 's', 'a', 'b', 'l', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'a', 'b', 'u', 's', 'e', '\n',
        'd', 'i', 's', 'a', 'b', 'u', 's', 'e', 'd', '\n',
        'd', 'i', 's', 'a', 'd', 'v', 'a', 'n', 't', 'a', 'g', 'e', '\n',
        'd', 'i', 's', 'a', 'd', 'v', 'a', 'n', 't', 'a', 'g', 'e', 'd', '\n',
        'd', 'i', 's', 'a', 'd', 'v', 'a', 'n', 't', 'a', 'g', 'e', 'o', 'u', 's', '\n',
        'd', 'i', 's', 'a', 'd', 'v', 'a', 'n', 't', 'a', 'g', 'e', 'o', 'u', 's', 'l', 'y', '\n',
        'd', 'i', 's', 'a', 'd', 'v', 'a', 'n', 't', 'a', 'g', 'e', 's', '\n',
        'd', 'i', 's', 'a', 'f', 'f', 'e', 'c', 't', 'e', 'd', '\n',
        'd', 'i', 's', 'a', 'f', 'f', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 'a', 'f', 'f', 'i', 'l', 'i', 'a', 't', 'e', '\n',
        'd', 'i', 's', 'a', 'f', 'f', 'i', 'l', 'i', 'a', 't', 'e', 'd', '\n',
        'd', 'i', 's', 'a', 'f', 'f', 'i', 'l', 'i', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'a', 'f', 'f', 'i', 'l', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 'a', 'g', 'g', 'r', 'e', 'g', 'a', 't', 'e', '\n',
        'd', 'i', 's', 'a', 'g', 'g', 'r', 'e', 'g', 'a', 't', 'e', 'd', '\n',
        'd', 'i', 's', 'a', 'g', 'g', 'r', 'e', 'g', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 'a', 'g', 'r', 'e', 'e', '\n',
        'd', 'i', 's', 'a', 'g', 'r', 'e', 'e', 'a', 'b', 'l', 'e', '\n',
        'd', 'i', 's', 'a', 'g', 'r', 'e', 'e', 'a', 'b', 'l', 'y', '\n',
        'd', 'i', 's', 'a', 'g', 'r', 'e', 'e', 'd', '\n',
        'd', 'i', 's', 'a', 'g', 'r', 'e', 'e', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'a', 'g', 'r', 'e', 'e', 'm', 'e', 'n', 't', '\n',
        'd', 'i', 's', 'a', 'g', 'r', 'e', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'd', 'i', 's', 'a', 'g', 'r', 'e', 'e', 's', '\n',
        'd', 'i', 's', 'a', 'l', 'l', 'o', 'w', '\n',
        'd', 'i', 's', 'a', 'l', 'l', 'o', 'w', 'e', 'd', '\n',
        'd', 'i', 's', 'a', 'l', 'l', 'o', 'w', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'a', 'l', 'l', 'o', 'w', 's', '\n',
        'd', 'i', 's', 'a', 'm', 'b', 'i', 'g', 'u', 'a', 't', 'e', '\n',
        'd', 'i', 's', 'a', 'm', 'b', 'i', 'g', 'u', 'a', 't', 'e', 'd', '\n',
        'd', 'i', 's', 'a', 'm', 'b', 'i', 'g', 'u', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'a', 'm', 'b', 'i', 'g', 'u', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 'a', 'p', 'p', 'e', 'a', 'r', '\n',
        'd', 'i', 's', 'a', 'p', 'p', 'e', 'a', 'r', 'a', 'n', 'c', 'e', '\n',
        'd', 'i', 's', 'a', 'p', 'p', 'e', 'a', 'r', 'a', 'n', 'c', 'e', 's', '\n',
        'd', 'i', 's', 'a', 'p', 'p', 'e', 'a', 'r', 'e', 'd', '\n',
        'd', 'i', 's', 'a', 'p', 'p', 'e', 'a', 'r', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'a', 'p', 'p', 'e', 'a', 'r', 's', '\n',
        'd', 'i', 's', 'a', 'p', 'p', 'o', 'i', 'n', 't', '\n',
        'd', 'i', 's', 'a', 'p', 'p', 'o', 'i', 'n', 't', 'e', 'd', '\n',
        'd', 'i', 's', 'a', 'p', 'p', 'o', 'i', 'n', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'a', 'p', 'p', 'o', 'i', 'n', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'd', 'i', 's', 'a', 'p', 'p', 'o', 'i', 'n', 't', 'm', 'e', 'n', 't', '\n',
        'd', 'i', 's', 'a', 'p', 'p', 'o', 'i', 'n', 't', 'm', 'e', 'n', 't', 's', '\n',
        'd', 'i', 's', 'a', 'p', 'p', 'o', 'i', 'n', 't', 's', '\n',
        'd', 'i', 's', 'a', 'p', 'p', 'r', 'o', 'b', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 'a', 'p', 'p', 'r', 'o', 'v', 'a', 'l', '\n',
        'd', 'i', 's', 'a', 'p', 'p', 'r', 'o', 'v', 'e', '\n',
        'd', 'i', 's', 'a', 'p', 'p', 'r', 'o', 'v', 'e', 'd', '\n',
        'd', 'i', 's', 'a', 'p', 'p', 'r', 'o', 'v', 'e', 's', '\n',
        'd', 'i', 's', 'a', 'p', 'p', 'r', 'o', 'v', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'a', 'p', 'p', 'r', 'o', 'v', 'i', 'n', 'g', 'l', 'y', '\n',
        'd', 'i', 's', 'a', 'r', 'm', '\n',
        'd', 'i', 's', 'a', 'r', 'm', 'a', 'm', 'e', 'n', 't', '\n',
        'd', 'i', 's', 'a', 'r', 'm', 'e', 'd', '\n',
        'd', 'i', 's', 'a', 'r', 'm', 'e', 'r', '\n',
        'd', 'i', 's', 'a', 'r', 'm', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'a', 'r', 'm', 'i', 'n', 'g', 'l', 'y', '\n',
        'd', 'i', 's', 'a', 'r', 'm', 's', '\n',
        'd', 'i', 's', 'a', 'r', 'r', 'a', 'n', 'g', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'a', 'r', 'r', 'a', 'y', '\n',
        'd', 'i', 's', 'a', 'r', 'r', 'a', 'y', 'e', 'd', '\n',
        'd', 'i', 's', 'a', 's', 's', 'e', 'm', 'b', 'l', 'e', '\n',
        'd', 'i', 's', 'a', 's', 's', 'e', 'm', 'b', 'l', 'e', 'd', '\n',
        'd', 'i', 's', 'a', 's', 's', 'e', 'm', 'b', 'l', 'e', 'r', '\n',
        'd', 'i', 's', 'a', 's', 's', 'e', 'm', 'b', 'l', 'e', 's', '\n',
        'd', 'i', 's', 'a', 's', 's', 'e', 'm', 'b', 'l', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'a', 's', 's', 'e', 'm', 'b', 'l', 'y', '\n',
        'd', 'i', 's', 'a', 's', 's', 'o', 'c', 'i', 'a', 't', 'e', '\n',
        'd', 'i', 's', 'a', 's', 's', 'o', 'c', 'i', 'a', 't', 'e', 'd', '\n',
        'd', 'i', 's', 'a', 's', 's', 'o', 'c', 'i', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'a', 's', 's', 'o', 'c', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 'a', 's', 't', 'e', 'r', '\n',
        'd', 'i', 's', 'a', 's', 't', 'e', 'r', 's', '\n',
        'd', 'i', 's', 'a', 's', 't', 'r', 'o', 'u', 's', '\n',
        'd', 'i', 's', 'a', 's', 't', 'r', 'o', 'u', 's', 'l', 'y', '\n',
        'd', 'i', 's', 'a', 'v', 'o', 'w', '\n',
        'd', 'i', 's', 'a', 'v', 'o', 'w', 'a', 'l', '\n',
        'd', 'i', 's', 'a', 'v', 'o', 'w', 'e', 'd', '\n',
        'd', 'i', 's', 'a', 'v', 'o', 'w', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'b', 'a', 'n', 'd', '\n',
        'd', 'i', 's', 'b', 'a', 'n', 'd', 'e', 'd', '\n',
        'd', 'i', 's', 'b', 'a', 'n', 'd', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'b', 'a', 'n', 'd', 'm', 'e', 'n', 't', '\n',
        'd', 'i', 's', 'b', 'a', 'n', 'd', 's', '\n',
        'd', 'i', 's', 'b', 'a', 'r', 's', '\n',
        'd', 'i', 's', 'b', 'e', 'l', 'i', 'e', 'f', '\n',
        'd', 'i', 's', 'b', 'e', 'l', 'i', 'e', 'v', 'e', '\n',
        'd', 'i', 's', 'b', 'e', 'l', 'i', 'e', 'v', 'e', 'd', '\n',
        'd', 'i', 's', 'b', 'e', 'l', 'i', 'e', 'v', 'e', 'r', '\n',
        'd', 'i', 's', 'b', 'e', 'l', 'i', 'e', 'v', 'e', 'r', 's', '\n',
        'd', 'i', 's', 'b', 'e', 'l', 'i', 'e', 'v', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'b', 'e', 'l', 'i', 'e', 'v', 'i', 'n', 'g', 'l', 'y', '\n',
        'd', 'i', 's', 'b', 'u', 'r', 's', 'e', '\n',
        'd', 'i', 's', 'b', 'u', 'r', 's', 'e', 'd', '\n',
        'd', 'i', 's', 'b', 'u', 'r', 's', 'e', 'm', 'e', 'n', 't', '\n',
        'd', 'i', 's', 'b', 'u', 'r', 's', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'd', 'i', 's', 'c', '\n',
        'd', 'i', 's', 'c', 'a', 'n', 't', '\n',
        'd', 'i', 's', 'c', 'a', 'r', 'd', '\n',
        'd', 'i', 's', 'c', 'a', 'r', 'd', 'e', 'd', '\n',
        'd', 'i', 's', 'c', 'a', 'r', 'd', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'c', 'a', 'r', 'd', 's', '\n',
        'd', 'i', 's', 'c', 'e', 'r', 'n', '\n',
        'd', 'i', 's', 'c', 'e', 'r', 'n', 'e', 'd', '\n',
        'd', 'i', 's', 'c', 'e', 'r', 'n', 'i', 'b', 'l', 'e', '\n',
        'd', 'i', 's', 'c', 'e', 'r', 'n', 'i', 'b', 'l', 'y', '\n',
        'd', 'i', 's', 'c', 'e', 'r', 'n', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'c', 'e', 'r', 'n', 'm', 'e', 'n', 't', '\n',
        'd', 'i', 's', 'c', 'e', 'r', 'n', 's', '\n',
        'd', 'i', 's', 'c', 'h', 'a', 'r', 'g', 'e', '\n',
        'd', 'i', 's', 'c', 'h', 'a', 'r', 'g', 'e', 'd', '\n',
        'd', 'i', 's', 'c', 'h', 'a', 'r', 'g', 'e', 's', '\n',
        'd', 'i', 's', 'c', 'h', 'a', 'r', 'g', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'c', 'i', 'p', 'l', 'e', '\n',
        'd', 'i', 's', 'c', 'i', 'p', 'l', 'e', 's', '\n',
        'd', 'i', 's', 'c', 'i', 'p', 'l', 'e', 's', 'h', 'i', 'p', '\n',
        'd', 'i', 's', 'c', 'i', 'p', 'l', 'i', 'n', 'a', 'r', 'i', 'a', 'n', '\n',
        'd', 'i', 's', 'c', 'i', 'p', 'l', 'i', 'n', 'a', 'r', 'i', 'a', 'n', 's', '\n',
        'd', 'i', 's', 'c', 'i', 'p', 'l', 'i', 'n', 'a', 'r', 'y', '\n',
        'd', 'i', 's', 'c', 'i', 'p', 'l', 'i', 'n', 'e', '\n',
        'd', 'i', 's', 'c', 'i', 'p', 'l', 'i', 'n', 'e', 'd', '\n',
        'd', 'i', 's', 'c', 'i', 'p', 'l', 'i', 'n', 'e', 's', '\n',
        'd', 'i', 's', 'c', 'i', 'p', 'l', 'i', 'n', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'c', 'l', 'a', 'i', 'm', '\n',
        'd', 'i', 's', 'c', 'l', 'a', 'i', 'm', 'e', 'd', '\n',
        'd', 'i', 's', 'c', 'l', 'a', 'i', 'm', 'e', 'r', '\n',
        'd', 'i', 's', 'c', 'l', 'a', 'i', 'm', 'e', 'r', 's', '\n',
        'd', 'i', 's', 'c', 'l', 'a', 'i', 'm', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'c', 'l', 'a', 'i', 'm', 's', '\n',
        'd', 'i', 's', 'c', 'l', 'o', 's', 'e', '\n',
        'd', 'i', 's', 'c', 'l', 'o', 's', 'e', 'd', '\n',
        'd', 'i', 's', 'c', 'l', 'o', 's', 'e', 's', '\n',
        'd', 'i', 's', 'c', 'l', 'o', 's', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'c', 'l', 'o', 's', 'u', 'r', 'e', '\n',
        'd', 'i', 's', 'c', 'l', 'o', 's', 'u', 'r', 'e', 's', '\n',
        'd', 'i', 's', 'c', 'o', '\n',
        'd', 'i', 's', 'c', 'o', 'g', 'r', 'a', 'p', 'h', 'y', '\n',
        'd', 'i', 's', 'c', 'o', 'l', 'o', 'u', 'r', '\n',
        'd', 'i', 's', 'c', 'o', 'l', 'o', 'u', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 'c', 'o', 'l', 'o', 'u', 'r', 'e', 'd', '\n',
        'd', 'i', 's', 'c', 'o', 'l', 'o', 'u', 'r', 's', '\n',
        'd', 'i', 's', 'c', 'o', 'm', 'f', 'i', 't', '\n',
        'd', 'i', 's', 'c', 'o', 'm', 'f', 'i', 't', 'e', 'd', '\n',
        'd', 'i', 's', 'c', 'o', 'm', 'f', 'i', 't', 'u', 'r', 'e', '\n',
        'd', 'i', 's', 'c', 'o', 'm', 'f', 'o', 'r', 't', '\n',
        'd', 'i', 's', 'c', 'o', 'm', 'f', 'o', 'r', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'c', 'o', 'm', 'f', 'o', 'r', 't', 's', '\n',
        'd', 'i', 's', 'c', 'o', 'n', 'c', 'e', 'r', 't', '\n',
        'd', 'i', 's', 'c', 'o', 'n', 'c', 'e', 'r', 't', 'e', 'd', '\n',
        'd', 'i', 's', 'c', 'o', 'n', 'c', 'e', 'r', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'c', 'o', 'n', 'c', 'e', 'r', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', '\n',
        'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'e', 'd', '\n',
        'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'i', 's', 'c', 'o', 'n', 'n', 'e', 'c', 't', 's', '\n',
        'd', 'i', 's', 'c', 'o', 'n', 's', 'o', 'l', 'a', 't', 'e', '\n',
        'd', 'i', 's', 'c', 'o', 'n', 's', 'o', 'l', 'a', 't', 'e', 'l', 'y', '\n',
        'd', 'i', 's', 'c', 'o', 'n', 's', 'o', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 'c', 'o', 'n', 't', 'e', 'n', 't', '\n',
        'd', 'i', 's', 'c', 'o', 'n', 't', 'e', 'n', 't', 'e', 'd', '\n',
        'd', 'i', 's', 'c', 'o', 'n', 't', 'e', 'n', 't', 'e', 'd', 'l', 'y', '\n',
        'd', 'i', 's', 'c', 'o', 'n', 't', 'e', 'n', 't', 's', '\n',
        'd', 'i', 's', 'c', 'o', 'n', 't', 'i', 'n', 'u', 'a', 'n', 'c', 'e', '\n',
        'd', 'i', 's', 'c', 'o', 'n', 't', 'i', 'n', 'u', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 'c', 'o', 'n', 't', 'i', 'n', 'u', 'e', '\n',
        'd', 'i', 's', 'c', 'o', 'n', 't', 'i', 'n', 'u', 'e', 'd', '\n',
        'd', 'i', 's', 'c', 'o', 'n', 't', 'i', 'n', 'u', 'e', 's', '\n',
        'd', 'i', 's', 'c', 'o', 'n', 't', 'i', 'n', 'u', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'c', 'o', 'n', 't', 'i', 'n', 'u', 'i', 't', 'i', 'e', 's', '\n',
        'd', 'i', 's', 'c', 'o', 'n', 't', 'i', 'n', 'u', 'i', 't', 'y', '\n',
        'd', 'i', 's', 'c', 'o', 'n', 't', 'i', 'n', 'u', 'o', 'u', 's', '\n',
        'd', 'i', 's', 'c', 'o', 'n', 't', 'i', 'n', 'u', 'o', 'u', 's', 'l', 'y', '\n',
        'd', 'i', 's', 'c', 'o', 'r', 'd', '\n',
        'd', 'i', 's', 'c', 'o', 'r', 'd', 'a', 'n', 'c', 'e', '\n',
        'd', 'i', 's', 'c', 'o', 'r', 'd', 'a', 'n', 't', '\n',
        'd', 'i', 's', 'c', 'o', 'r', 'd', 's', '\n',
        'd', 'i', 's', 'c', 'o', 't', 'h', 'e', 'q', 'u', 'e', '\n',
        'd', 'i', 's', 'c', 'o', 't', 'h', 'e', 'q', 'u', 'e', 's', '\n',
        'd', 'i', 's', 'c', 'o', 'u', 'n', 't', '\n',
        'd', 'i', 's', 'c', 'o', 'u', 'n', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'd', 'i', 's', 'c', 'o', 'u', 'n', 't', 'a', 'b', 'l', 'e', '\n',
        'd', 'i', 's', 'c', 'o', 'u', 'n', 't', 'e', 'd', '\n',
        'd', 'i', 's', 'c', 'o', 'u', 'n', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'c', 'o', 'u', 'n', 't', 's', '\n',
        'd', 'i', 's', 'c', 'o', 'u', 'r', 'a', 'g', 'e', '\n',
        'd', 'i', 's', 'c', 'o', 'u', 'r', 'a', 'g', 'e', 'd', '\n',
        'd', 'i', 's', 'c', 'o', 'u', 'r', 'a', 'g', 'e', 'm', 'e', 'n', 't', '\n',
        'd', 'i', 's', 'c', 'o', 'u', 'r', 'a', 'g', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'd', 'i', 's', 'c', 'o', 'u', 'r', 'a', 'g', 'e', 's', '\n',
        'd', 'i', 's', 'c', 'o', 'u', 'r', 'a', 'g', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'c', 'o', 'u', 'r', 'a', 'g', 'i', 'n', 'g', 'l', 'y', '\n',
        'd', 'i', 's', 'c', 'o', 'u', 'r', 's', 'e', '\n',
        'd', 'i', 's', 'c', 'o', 'u', 'r', 's', 'e', 'd', '\n',
        'd', 'i', 's', 'c', 'o', 'u', 'r', 's', 'e', 's', '\n',
        'd', 'i', 's', 'c', 'o', 'u', 'r', 's', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'c', 'o', 'u', 'r', 't', 'e', 'o', 'u', 's', '\n',
        'd', 'i', 's', 'c', 'o', 'u', 'r', 't', 'e', 'o', 'u', 's', 'l', 'y', '\n',
        'd', 'i', 's', 'c', 'o', 'u', 'r', 't', 'e', 's', 'y', '\n',
        'd', 'i', 's', 'c', 'o', 'v', 'e', 'r', '\n',
        'd', 'i', 's', 'c', 'o', 'v', 'e', 'r', 'a', 'b', 'l', 'e', '\n',
        'd', 'i', 's', 'c', 'o', 'v', 'e', 'r', 'e', 'd', '\n',
        'd', 'i', 's', 'c', 'o', 'v', 'e', 'r', 'e', 'r', '\n',
        'd', 'i', 's', 'c', 'o', 'v', 'e', 'r', 'e', 'r', 's', '\n',
        'd', 'i', 's', 'c', 'o', 'v', 'e', 'r', 'i', 'e', 's', '\n',
        'd', 'i', 's', 'c', 'o', 'v', 'e', 'r', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'c', 'o', 'v', 'e', 'r', 's', '\n',
        'd', 'i', 's', 'c', 'o', 'v', 'e', 'r', 'y', '\n',
        'd', 'i', 's', 'c', 'r', 'e', 'd', 'i', 't', '\n',
        'd', 'i', 's', 'c', 'r', 'e', 'd', 'i', 't', 'a', 'b', 'l', 'e', '\n',
        'd', 'i', 's', 'c', 'r', 'e', 'd', 'i', 't', 'e', 'd', '\n',
        'd', 'i', 's', 'c', 'r', 'e', 'd', 'i', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'c', 'r', 'e', 'd', 'i', 't', 's', '\n',
        'd', 'i', 's', 'c', 'r', 'e', 'e', 't', '\n',
        'd', 'i', 's', 'c', 'r', 'e', 'e', 't', 'l', 'y', '\n',
        'd', 'i', 's', 'c', 'r', 'e', 'e', 't', 'n', 'e', 's', 's', '\n',
        'd', 'i', 's', 'c', 'r', 'e', 'p', 'a', 'n', 'c', 'i', 'e', 's', '\n',
        'd', 'i', 's', 'c', 'r', 'e', 'p', 'a', 'n', 'c', 'y', '\n',
        'd', 'i', 's', 'c', 'r', 'e', 'p', 'a', 'n', 't', '\n',
        'd', 'i', 's', 'c', 'r', 'e', 't', 'e', '\n',
        'd', 'i', 's', 'c', 'r', 'e', 't', 'e', 'l', 'y', '\n',
        'd', 'i', 's', 'c', 'r', 'e', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 'c', 'r', 'e', 't', 'i', 'o', 'n', 'a', 'r', 'y', '\n',
        'd', 'i', 's', 'c', 'r', 'i', 'm', 'i', 'n', 'a', 'n', 't', '\n',
        'd', 'i', 's', 'c', 'r', 'i', 'm', 'i', 'n', 'a', 'n', 't', 's', '\n',
        'd', 'i', 's', 'c', 'r', 'i', 'm', 'i', 'n', 'a', 't', 'e', '\n',
        'd', 'i', 's', 'c', 'r', 'i', 'm', 'i', 'n', 'a', 't', 'e', 'd', '\n',
        'd', 'i', 's', 'c', 'r', 'i', 'm', 'i', 'n', 'a', 't', 'e', 's', '\n',
        'd', 'i', 's', 'c', 'r', 'i', 'm', 'i', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'c', 'r', 'i', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 'c', 'r', 'i', 'm', 'i', 'n', 'a', 't', 'i', 'v', 'e', '\n',
        'd', 'i', 's', 'c', 'r', 'i', 'm', 'i', 'n', 'a', 't', 'o', 'r', '\n',
        'd', 'i', 's', 'c', 'r', 'i', 'm', 'i', 'n', 'a', 't', 'o', 'r', 's', '\n',
        'd', 'i', 's', 'c', 'r', 'i', 'm', 'i', 'n', 'a', 't', 'o', 'r', 'y', '\n',
        'd', 'i', 's', 'c', 's', '\n',
        'd', 'i', 's', 'c', 'u', 'r', 's', 'i', 'v', 'e', '\n',
        'd', 'i', 's', 'c', 'u', 'r', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'd', 'i', 's', 'c', 'u', 's', '\n',
        'd', 'i', 's', 'c', 'u', 's', 's', '\n',
        'd', 'i', 's', 'c', 'u', 's', 's', 'a', 'b', 'l', 'e', '\n',
        'd', 'i', 's', 'c', 'u', 's', 's', 'e', 'd', '\n',
        'd', 'i', 's', 'c', 'u', 's', 's', 'e', 's', '\n',
        'd', 'i', 's', 'c', 'u', 's', 's', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'c', 'u', 's', 's', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 'c', 'u', 's', 's', 'i', 'o', 'n', 's', '\n',
        'd', 'i', 's', 'd', 'a', 'i', 'n', '\n',
        'd', 'i', 's', 'd', 'a', 'i', 'n', 'e', 'd', '\n',
        'd', 'i', 's', 'd', 'a', 'i', 'n', 'f', 'u', 'l', '\n',
        'd', 'i', 's', 'd', 'a', 'i', 'n', 'f', 'u', 'l', 'l', 'y', '\n',
        'd', 'i', 's', 'd', 'a', 'i', 'n', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'e', 'a', 's', 'e', '\n',
        'd', 'i', 's', 'e', 'a', 's', 'e', 'd', '\n',
        'd', 'i', 's', 'e', 'a', 's', 'e', 's', '\n',
        'd', 'i', 's', 'e', 'm', 'b', 'a', 'r', 'k', '\n',
        'd', 'i', 's', 'e', 'm', 'b', 'a', 'r', 'k', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 'e', 'm', 'b', 'a', 'r', 'k', 'e', 'd', '\n',
        'd', 'i', 's', 'e', 'm', 'b', 'a', 'r', 'k', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'e', 'm', 'b', 'o', 'd', 'i', 'e', 'd', '\n',
        'd', 'i', 's', 'e', 'm', 'b', 'o', 'd', 'i', 'm', 'e', 'n', 't', '\n',
        'd', 'i', 's', 'e', 'm', 'b', 'o', 'w', 'e', 'l', '\n',
        'd', 'i', 's', 'e', 'm', 'b', 'o', 'w', 'e', 'l', 'l', 'e', 'd', '\n',
        'd', 'i', 's', 'e', 'm', 'b', 'o', 'w', 'e', 'l', 'm', 'e', 'n', 't', '\n',
        'd', 'i', 's', 'e', 'm', 'b', 'o', 'w', 'e', 'l', 's', '\n',
        'd', 'i', 's', 'e', 'n', 'c', 'h', 'a', 'n', 't', 'e', 'd', '\n',
        'd', 'i', 's', 'e', 'n', 'c', 'h', 'a', 'n', 't', 'm', 'e', 'n', 't', '\n',
        'd', 'i', 's', 'e', 'n', 'f', 'r', 'a', 'n', 'c', 'h', 'i', 's', 'e', '\n',
        'd', 'i', 's', 'e', 'n', 'f', 'r', 'a', 'n', 'c', 'h', 'i', 's', 'e', 'd', '\n',
        'd', 'i', 's', 'e', 'n', 'f', 'r', 'a', 'n', 'c', 'h', 'i', 's', 'e', 'm', 'e', 'n', 't', '\n',
        'd', 'i', 's', 'e', 'n', 'f', 'r', 'a', 'n', 'c', 'h', 'i', 's', 'e', 's', '\n',
        'd', 'i', 's', 'e', 'n', 'f', 'r', 'a', 'n', 'c', 'h', 'i', 's', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'e', 'n', 'g', 'a', 'g', 'e', '\n',
        'd', 'i', 's', 'e', 'n', 'g', 'a', 'g', 'e', 'd', '\n',
        'd', 'i', 's', 'e', 'n', 'g', 'a', 'g', 'e', 'm', 'e', 'n', 't', '\n',
        'd', 'i', 's', 'e', 'n', 'g', 'a', 'g', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'e', 'n', 't', 'a', 'n', 'g', 'l', 'e', '\n',
        'd', 'i', 's', 'e', 'n', 't', 'a', 'n', 'g', 'l', 'e', 'd', '\n',
        'd', 'i', 's', 'e', 'n', 't', 'a', 'n', 'g', 'l', 'e', 's', '\n',
        'd', 'i', 's', 'e', 'n', 't', 'a', 'n', 'g', 'l', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'e', 'q', 'u', 'i', 'l', 'i', 'b', 'r', 'i', 'u', 'm', '\n',
        'd', 'i', 's', 'e', 's', 't', 'a', 'b', 'l', 'i', 's', 'h', '\n',
        'd', 'i', 's', 'e', 's', 't', 'a', 'b', 'l', 'i', 's', 'h', 'e', 'd', '\n',
        'd', 'i', 's', 'e', 's', 't', 'a', 'b', 'l', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'e', 's', 't', 'a', 'b', 'l', 'i', 's', 'h', 'm', 'e', 'n', 't', '\n',
        'd', 'i', 's', 'f', 'a', 'v', 'o', 'u', 'r', '\n',
        'd', 'i', 's', 'f', 'i', 'g', 'u', 'r', 'e', '\n',
        'd', 'i', 's', 'f', 'i', 'g', 'u', 'r', 'e', 'd', '\n',
        'd', 'i', 's', 'f', 'i', 'g', 'u', 'r', 'e', 'm', 'e', 'n', 't', '\n',
        'd', 'i', 's', 'f', 'i', 'g', 'u', 'r', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'd', 'i', 's', 'f', 'i', 'g', 'u', 'r', 'e', 's', '\n',
        'd', 'i', 's', 'f', 'i', 'g', 'u', 'r', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'f', 'r', 'a', 'n', 'c', 'h', 'i', 's', 'e', '\n',
        'd', 'i', 's', 'g', 'o', 'r', 'g', 'e', '\n',
        'd', 'i', 's', 'g', 'o', 'r', 'g', 'e', 'd', '\n',
        'd', 'i', 's', 'g', 'o', 'r', 'g', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'g', 'r', 'a', 'c', 'e', '\n',
        'd', 'i', 's', 'g', 'r', 'a', 'c', 'e', 'd', '\n',
        'd', 'i', 's', 'g', 'r', 'a', 'c', 'e', 'f', 'u', 'l', '\n',
        'd', 'i', 's', 'g', 'r', 'a', 'c', 'e', 'f', 'u', 'l', 'l', 'y', '\n',
        'd', 'i', 's', 'g', 'r', 'a', 'c', 'e', 's', '\n',
        'd', 'i', 's', 'g', 'r', 'a', 'c', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'g', 'r', 'u', 'n', 't', 'l', 'e', 'd', '\n',
        'd', 'i', 's', 'g', 'r', 'u', 'n', 't', 'l', 'e', 'm', 'e', 'n', 't', '\n',
        'd', 'i', 's', 'g', 'u', 'i', 's', 'e', '\n',
        'd', 'i', 's', 'g', 'u', 'i', 's', 'e', 'd', '\n',
        'd', 'i', 's', 'g', 'u', 'i', 's', 'e', 's', '\n',
        'd', 'i', 's', 'g', 'u', 'i', 's', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'g', 'u', 's', 't', '\n',
        'd', 'i', 's', 'g', 'u', 's', 't', 'e', 'd', '\n',
        'd', 'i', 's', 'g', 'u', 's', 't', 'e', 'd', 'l', 'y', '\n',
        'd', 'i', 's', 'g', 'u', 's', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'g', 'u', 's', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'd', 'i', 's', 'g', 'u', 's', 't', 's', '\n',
        'd', 'i', 's', 'h', '\n',
        'd', 'i', 's', 'h', 'a', 'r', 'm', 'o', 'n', 'i', 'o', 'u', 's', '\n',
        'd', 'i', 's', 'h', 'a', 'r', 'm', 'o', 'n', 'y', '\n',
        'd', 'i', 's', 'h', 'c', 'l', 'o', 't', 'h', '\n',
        'd', 'i', 's', 'h', 'e', 'a', 'r', 't', 'e', 'n', 'e', 'd', '\n',
        'd', 'i', 's', 'h', 'e', 'a', 'r', 't', 'e', 'n', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'h', 'e', 'd', '\n',
        'd', 'i', 's', 'h', 'e', 's', '\n',
        'd', 'i', 's', 'h', 'e', 'v', 'e', 'l', 'l', 'e', 'd', '\n',
        'd', 'i', 's', 'h', 'i', 'e', 'r', '\n',
        'd', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'h', 'o', 'n', 'e', 's', 't', '\n',
        'd', 'i', 's', 'h', 'o', 'n', 'e', 's', 't', 'l', 'y', '\n',
        'd', 'i', 's', 'h', 'o', 'n', 'e', 's', 't', 'y', '\n',
        'd', 'i', 's', 'h', 'o', 'n', 'o', 'u', 'r', '\n',
        'd', 'i', 's', 'h', 'o', 'n', 'o', 'u', 'r', 'a', 'b', 'l', 'e', '\n',
        'd', 'i', 's', 'h', 'o', 'n', 'o', 'u', 'r', 'a', 'b', 'l', 'y', '\n',
        'd', 'i', 's', 'h', 'o', 'n', 'o', 'u', 'r', 'e', 'd', '\n',
        'd', 'i', 's', 'h', 'p', 'a', 'n', '\n',
        'd', 'i', 's', 'h', 'w', 'a', 's', 'h', 'e', 'r', '\n',
        'd', 'i', 's', 'h', 'w', 'a', 's', 'h', 'e', 'r', 's', '\n',
        'd', 'i', 's', 'h', 'w', 'a', 't', 'e', 'r', '\n',
        'd', 'i', 's', 'h', 'y', '\n',
        'd', 'i', 's', 'i', 'l', 'l', 'u', 's', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 'i', 'l', 'l', 'u', 's', 'i', 'o', 'n', 'e', 'd', '\n',
        'd', 'i', 's', 'i', 'l', 'l', 'u', 's', 'i', 'o', 'n', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'i', 'l', 'l', 'u', 's', 'i', 'o', 'n', 'm', 'e', 'n', 't', '\n',
        'd', 'i', 's', 'i', 'n', 'c', 'e', 'n', 't', 'i', 'v', 'e', '\n',
        'd', 'i', 's', 'i', 'n', 'c', 'e', 'n', 't', 'i', 'v', 'e', 's', '\n',
        'd', 'i', 's', 'i', 'n', 'c', 'l', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 'i', 'n', 'c', 'l', 'i', 'n', 'e', 'd', '\n',
        'd', 'i', 's', 'i', 'n', 'f', 'e', 'c', 't', '\n',
        'd', 'i', 's', 'i', 'n', 'f', 'e', 'c', 't', 'a', 'n', 't', '\n',
        'd', 'i', 's', 'i', 'n', 'f', 'e', 'c', 't', 'a', 'n', 't', 's', '\n',
        'd', 'i', 's', 'i', 'n', 'f', 'e', 'c', 't', 'e', 'd', '\n',
        'd', 'i', 's', 'i', 'n', 'f', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'i', 'n', 'f', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 'i', 'n', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 'i', 'n', 'g', 'e', 'n', 'u', 'o', 'u', 's', '\n',
        'd', 'i', 's', 'i', 'n', 'g', 'e', 'n', 'u', 'o', 'u', 's', 'l', 'y', '\n',
        'd', 'i', 's', 'i', 'n', 'h', 'e', 'r', 'i', 't', '\n',
        'd', 'i', 's', 'i', 'n', 'h', 'e', 'r', 'i', 't', 'e', 'd', '\n',
        'd', 'i', 's', 'i', 'n', 't', 'e', 'g', 'r', 'a', 't', 'e', '\n',
        'd', 'i', 's', 'i', 'n', 't', 'e', 'g', 'r', 'a', 't', 'e', 'd', '\n',
        'd', 'i', 's', 'i', 'n', 't', 'e', 'g', 'r', 'a', 't', 'e', 's', '\n',
        'd', 'i', 's', 'i', 'n', 't', 'e', 'g', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'i', 'n', 't', 'e', 'g', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 'i', 'n', 't', 'e', 'r', '\n',
        'd', 'i', 's', 'i', 'n', 't', 'e', 'r', 'e', 's', 't', '\n',
        'd', 'i', 's', 'i', 'n', 't', 'e', 'r', 'e', 's', 't', 'e', 'd', '\n',
        'd', 'i', 's', 'i', 'n', 't', 'e', 'r', 'e', 's', 't', 'e', 'd', 'l', 'y', '\n',
        'd', 'i', 's', 'i', 'n', 't', 'e', 'r', 'e', 's', 't', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'd', 'i', 's', 'i', 'n', 't', 'e', 'r', 'r', 'e', 'd', '\n',
        'd', 'i', 's', 'i', 'n', 'v', 'e', 's', 't', '\n',
        'd', 'i', 's', 'i', 'n', 'v', 'e', 's', 't', 'm', 'e', 'n', 't', '\n',
        'd', 'i', 's', 'j', 'o', 'i', 'n', '\n',
        'd', 'i', 's', 'j', 'o', 'i', 'n', 't', '\n',
        'd', 'i', 's', 'j', 'o', 'i', 'n', 't', 'e', 'd', '\n',
        'd', 'i', 's', 'j', 'o', 'i', 'n', 't', 'e', 'd', 'l', 'y', '\n',
        'd', 'i', 's', 'j', 'o', 'i', 'n', 't', 'n', 'e', 's', 's', '\n',
        'd', 'i', 's', 'j', 'u', 'n', 'c', 't', '\n',
        'd', 'i', 's', 'j', 'u', 'n', 'c', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 'j', 'u', 'n', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'i', 's', 'j', 'u', 'n', 'c', 't', 'i', 'v', 'e', '\n',
        'd', 'i', 's', 'k', 'e', 't', 't', 'e', '\n',
        'd', 'i', 's', 'k', 'e', 't', 't', 'e', 's', '\n',
        'd', 'i', 's', 'l', 'i', 'k', 'e', '\n',
        'd', 'i', 's', 'l', 'i', 'k', 'e', 'd', '\n',
        'd', 'i', 's', 'l', 'i', 'k', 'e', 's', '\n',
        'd', 'i', 's', 'l', 'i', 'k', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'l', 'o', 'c', 'a', 't', 'e', '\n',
        'd', 'i', 's', 'l', 'o', 'c', 'a', 't', 'e', 'd', '\n',
        'd', 'i', 's', 'l', 'o', 'c', 'a', 't', 'e', 's', '\n',
        'd', 'i', 's', 'l', 'o', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'l', 'o', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 'l', 'o', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'i', 's', 'l', 'o', 'd', 'g', 'e', '\n',
        'd', 'i', 's', 'l', 'o', 'd', 'g', 'e', 'd', '\n',
        'd', 'i', 's', 'l', 'o', 'd', 'g', 'e', 's', '\n',
        'd', 'i', 's', 'l', 'o', 'd', 'g', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'l', 'o', 'y', 'a', 'l', '\n',
        'd', 'i', 's', 'l', 'o', 'y', 'a', 'l', 't', 'y', '\n',
        'd', 'i', 's', 'm', 'a', 'l', '\n',
        'd', 'i', 's', 'm', 'a', 'l', 'l', 'y', '\n',
        'd', 'i', 's', 'm', 'a', 'n', 't', 'l', 'e', '\n',
        'd', 'i', 's', 'm', 'a', 'n', 't', 'l', 'e', 'd', '\n',
        'd', 'i', 's', 'm', 'a', 'n', 't', 'l', 'e', 's', '\n',
        'd', 'i', 's', 'm', 'a', 'n', 't', 'l', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'm', 'a', 'y', '\n',
        'd', 'i', 's', 'm', 'a', 'y', 'e', 'd', '\n',
        'd', 'i', 's', 'm', 'a', 'y', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'm', 'a', 'y', 's', '\n',
        'd', 'i', 's', 'm', 'e', 'm', 'b', 'e', 'r', '\n',
        'd', 'i', 's', 'm', 'e', 'm', 'b', 'e', 'r', 'e', 'd', '\n',
        'd', 'i', 's', 'm', 'e', 'm', 'b', 'e', 'r', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'm', 'e', 'm', 'b', 'e', 'r', 'm', 'e', 'n', 't', '\n',
        'd', 'i', 's', 'm', 'e', 'm', 'b', 'e', 'r', 's', '\n',
        'd', 'i', 's', 'm', 'i', 's', 's', '\n',
        'd', 'i', 's', 'm', 'i', 's', 's', 'a', 'l', '\n',
        'd', 'i', 's', 'm', 'i', 's', 's', 'a', 'l', 's', '\n',
        'd', 'i', 's', 'm', 'i', 's', 's', 'e', 'd', '\n',
        'd', 'i', 's', 'm', 'i', 's', 's', 'e', 's', '\n',
        'd', 'i', 's', 'm', 'i', 's', 's', 'i', 'b', 'l', 'e', '\n',
        'd', 'i', 's', 'm', 'i', 's', 's', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'm', 'i', 's', 's', 'i', 'v', 'e', '\n',
        'd', 'i', 's', 'm', 'i', 's', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'd', 'i', 's', 'm', 'o', 'u', 'n', 't', '\n',
        'd', 'i', 's', 'm', 'o', 'u', 'n', 't', 'e', 'd', '\n',
        'd', 'i', 's', 'm', 'o', 'u', 'n', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'm', 'o', 'u', 'n', 't', 's', '\n',
        'd', 'i', 's', 'o', 'b', 'e', 'd', 'i', 'e', 'n', 'c', 'e', '\n',
        'd', 'i', 's', 'o', 'b', 'e', 'd', 'i', 'e', 'n', 't', '\n',
        'd', 'i', 's', 'o', 'b', 'e', 'y', '\n',
        'd', 'i', 's', 'o', 'b', 'e', 'y', 'e', 'd', '\n',
        'd', 'i', 's', 'o', 'b', 'e', 'y', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'o', 'b', 'e', 'y', 's', '\n',
        'd', 'i', 's', 'o', 'r', 'd', 'e', 'r', '\n',
        'd', 'i', 's', 'o', 'r', 'd', 'e', 'r', 'e', 'd', '\n',
        'd', 'i', 's', 'o', 'r', 'd', 'e', 'r', 'l', 'y', '\n',
        'd', 'i', 's', 'o', 'r', 'd', 'e', 'r', 's', '\n',
        'd', 'i', 's', 'o', 'r', 'g', 'a', 'n', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 'o', 'r', 'g', 'a', 'n', 'i', 's', 'e', '\n',
        'd', 'i', 's', 'o', 'r', 'g', 'a', 'n', 'i', 's', 'e', 'd', '\n',
        'd', 'i', 's', 'o', 'r', 'g', 'a', 'n', 'i', 's', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'o', 'r', 'i', 'e', 'n', 't', '\n',
        'd', 'i', 's', 'o', 'r', 'i', 'e', 'n', 't', 'a', 't', 'e', 'd', '\n',
        'd', 'i', 's', 'o', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'o', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 'o', 'r', 'i', 'e', 'n', 't', 'e', 'd', '\n',
        'd', 'i', 's', 'o', 'w', 'n', '\n',
        'd', 'i', 's', 'o', 'w', 'n', 'e', 'd', '\n',
        'd', 'i', 's', 'o', 'w', 'n', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'o', 'w', 'n', 's', '\n',
        'd', 'i', 's', 'p', 'a', 'r', 'a', 'g', 'e', '\n',
        'd', 'i', 's', 'p', 'a', 'r', 'a', 'g', 'e', 'd', '\n',
        'd', 'i', 's', 'p', 'a', 'r', 'a', 'g', 'e', 'm', 'e', 'n', 't', '\n',
        'd', 'i', 's', 'p', 'a', 'r', 'a', 'g', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'p', 'a', 'r', 'a', 'g', 'i', 'n', 'g', 'l', 'y', '\n',
        'd', 'i', 's', 'p', 'a', 'r', 'a', 't', 'e', '\n',
        'd', 'i', 's', 'p', 'a', 'r', 'i', 't', 'i', 'e', 's', '\n',
        'd', 'i', 's', 'p', 'a', 'r', 'i', 't', 'y', '\n',
        'd', 'i', 's', 'p', 'a', 's', 's', 'i', 'o', 'n', 'a', 't', 'e', '\n',
        'd', 'i', 's', 'p', 'a', 's', 's', 'i', 'o', 'n', 'a', 't', 'e', 'l', 'y', '\n',
        'd', 'i', 's', 'p', 'a', 't', 'c', 'h', '\n',
        'd', 'i', 's', 'p', 'a', 't', 'c', 'h', 'e', 'd', '\n',
        'd', 'i', 's', 'p', 'a', 't', 'c', 'h', 'e', 'r', '\n',
        'd', 'i', 's', 'p', 'a', 't', 'c', 'h', 'e', 'r', 's', '\n',
        'd', 'i', 's', 'p', 'a', 't', 'c', 'h', 'e', 's', '\n',
        'd', 'i', 's', 'p', 'a', 't', 'c', 'h', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'p', 'e', 'l', '\n',
        'd', 'i', 's', 'p', 'e', 'l', 'l', 'e', 'd', '\n',
        'd', 'i', 's', 'p', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'p', 'e', 'l', 's', '\n',
        'd', 'i', 's', 'p', 'e', 'n', 's', 'a', 'b', 'l', 'e', '\n',
        'd', 'i', 's', 'p', 'e', 'n', 's', 'a', 'r', 'i', 'e', 's', '\n',
        'd', 'i', 's', 'p', 'e', 'n', 's', 'a', 'r', 'y', '\n',
        'd', 'i', 's', 'p', 'e', 'n', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 'p', 'e', 'n', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'i', 's', 'p', 'e', 'n', 's', 'e', '\n',
        'd', 'i', 's', 'p', 'e', 'n', 's', 'e', 'd', '\n',
        'd', 'i', 's', 'p', 'e', 'n', 's', 'e', 'r', '\n',
        'd', 'i', 's', 'p', 'e', 'n', 's', 'e', 'r', 's', '\n',
        'd', 'i', 's', 'p', 'e', 'n', 's', 'e', 's', '\n',
        'd', 'i', 's', 'p', 'e', 'n', 's', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'p', 'e', 'r', 's', 'a', 'l', '\n',
        'd', 'i', 's', 'p', 'e', 'r', 's', 'a', 'n', 't', '\n',
        'd', 'i', 's', 'p', 'e', 'r', 's', 'e', '\n',
        'd', 'i', 's', 'p', 'e', 'r', 's', 'e', 'd', '\n',
        'd', 'i', 's', 'p', 'e', 'r', 's', 'e', 'r', '\n',
        'd', 'i', 's', 'p', 'e', 'r', 's', 'e', 'r', 's', '\n',
        'd', 'i', 's', 'p', 'e', 'r', 's', 'e', 's', '\n',
        'd', 'i', 's', 'p', 'e', 'r', 's', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'p', 'e', 'r', 's', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 'p', 'e', 'r', 's', 'i', 'o', 'n', 's', '\n',
        'd', 'i', 's', 'p', 'e', 'r', 's', 'i', 'v', 'e', '\n',
        'd', 'i', 's', 'p', 'e', 'r', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'd', 'i', 's', 'p', 'i', 'r', 'i', 't', 'e', 'd', '\n',
        'd', 'i', 's', 'p', 'i', 'r', 'i', 't', 'e', 'd', 'l', 'y', '\n',
        'd', 'i', 's', 'p', 'i', 'r', 'i', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'p', 'l', 'a', 'c', 'e', '\n',
        'd', 'i', 's', 'p', 'l', 'a', 'c', 'e', 'd', '\n',
        'd', 'i', 's', 'p', 'l', 'a', 'c', 'e', 'm', 'e', 'n', 't', '\n',
        'd', 'i', 's', 'p', 'l', 'a', 'c', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'd', 'i', 's', 'p', 'l', 'a', 'c', 'e', 'r', '\n',
        'd', 'i', 's', 'p', 'l', 'a', 'c', 'e', 's', '\n',
        'd', 'i', 's', 'p', 'l', 'a', 'c', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'p', 'l', 'a', 'y', '\n',
        'd', 'i', 's', 'p', 'l', 'a', 'y', 'a', 'b', 'l', 'e', '\n',
        'd', 'i', 's', 'p', 'l', 'a', 'y', 'e', 'd', '\n',
        'd', 'i', 's', 'p', 'l', 'a', 'y', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'p', 'l', 'a', 'y', 's', '\n',
        'd', 'i', 's', 'p', 'l', 'e', 'a', 's', 'e', '\n',
        'd', 'i', 's', 'p', 'l', 'e', 'a', 's', 'e', 'd', '\n',
        'd', 'i', 's', 'p', 'l', 'e', 'a', 's', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'p', 'l', 'e', 'a', 's', 'u', 'r', 'e', '\n',
        'd', 'i', 's', 'p', 'o', 'r', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'p', 'o', 's', 'a', 'b', 'l', 'e', '\n',
        'd', 'i', 's', 'p', 'o', 's', 'a', 'b', 'l', 'e', 's', '\n',
        'd', 'i', 's', 'p', 'o', 's', 'a', 'l', '\n',
        'd', 'i', 's', 'p', 'o', 's', 'a', 'l', 's', '\n',
        'd', 'i', 's', 'p', 'o', 's', 'e', '\n',
        'd', 'i', 's', 'p', 'o', 's', 'e', 'd', '\n',
        'd', 'i', 's', 'p', 'o', 's', 'e', 'r', '\n',
        'd', 'i', 's', 'p', 'o', 's', 'e', 'r', 's', '\n',
        'd', 'i', 's', 'p', 'o', 's', 'e', 's', '\n',
        'd', 'i', 's', 'p', 'o', 's', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'i', 's', 'p', 'o', 's', 's', 'e', 's', 's', '\n',
        'd', 'i', 's', 'p', 'o', 's', 's', 'e', 's', 's', 'e', 'd', '\n',
        'd', 'i', 's', 'p', 'o', 's', 's', 'e', 's', 's', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 'p', 'r', 'o', 'o', 'f', '\n',
        'd', 'i', 's', 'p', 'r', 'o', 'o', 'f', 's', '\n',
        'd', 'i', 's', 'p', 'r', 'o', 'p', 'o', 'r', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'd', 'i', 's', 'p', 'r', 'o', 'p', 'o', 'r', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'd', 'i', 's', 'p', 'r', 'o', 'p', 'o', 'r', 't', 'i', 'o', 'n', 'a', 't', 'e', '\n',
        'd', 'i', 's', 'p', 'r', 'o', 'p', 'o', 'r', 't', 'i', 'o', 'n', 'a', 't', 'e', 'l', 'y', '\n',
        'd', 'i', 's', 'p', 'r', 'o', 'v', 'a', 'b', 'l', 'e', '\n',
        'd', 'i', 's', 'p', 'r', 'o', 'v', 'e', '\n',
        'd', 'i', 's', 'p', 'r', 'o', 'v', 'e', 'd', '\n',
        'd', 'i', 's', 'p', 'r', 'o', 'v', 'e', 's', '\n',
        'd', 'i', 's', 'p', 'r', 'o', 'v', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'p', 'u', 't', 'a', 'b', 'l', 'e', '\n',
        'd', 'i', 's', 'p', 'u', 't', 'a', 'n', 't', '\n',
        'd', 'i', 's', 'p', 'u', 't', 'a', 'n', 't', 's', '\n',
        'd', 'i', 's', 'p', 'u', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 'p', 'u', 't', 'a', 't', 'i', 'o', 'u', 's', '\n',
        'd', 'i', 's', 'p', 'u', 't', 'e', '\n',
        'd', 'i', 's', 'p', 'u', 't', 'e', 'd', '\n',
        'd', 'i', 's', 'p', 'u', 't', 'e', 's', '\n',
        'd', 'i', 's', 'p', 'u', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'q', 'u', 'a', 'l', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 'q', 'u', 'a', 'l', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'i', 's', 'q', 'u', 'a', 'l', 'i', 'f', 'i', 'e', 'd', '\n',
        'd', 'i', 's', 'q', 'u', 'a', 'l', 'i', 'f', 'i', 'e', 's', '\n',
        'd', 'i', 's', 'q', 'u', 'a', 'l', 'i', 'f', 'y', '\n',
        'd', 'i', 's', 'q', 'u', 'a', 'l', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'q', 'u', 'i', 'e', 't', '\n',
        'd', 'i', 's', 'q', 'u', 'i', 'e', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'q', 'u', 'i', 'e', 't', 'u', 'd', 'e', '\n',
        'd', 'i', 's', 'q', 'u', 'i', 's', 'i', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 'q', 'u', 'i', 's', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'i', 's', 'r', 'e', 'g', 'a', 'r', 'd', '\n',
        'd', 'i', 's', 'r', 'e', 'g', 'a', 'r', 'd', 'e', 'd', '\n',
        'd', 'i', 's', 'r', 'e', 'g', 'a', 'r', 'd', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'r', 'e', 'g', 'a', 'r', 'd', 's', '\n',
        'd', 'i', 's', 'r', 'e', 'p', 'a', 'i', 'r', '\n',
        'd', 'i', 's', 'r', 'e', 'p', 'u', 't', 'a', 'b', 'l', 'e', '\n',
        'd', 'i', 's', 'r', 'e', 'p', 'u', 't', 'e', '\n',
        'd', 'i', 's', 'r', 'e', 's', 'p', 'e', 'c', 't', '\n',
        'd', 'i', 's', 'r', 'e', 's', 'p', 'e', 'c', 't', 'f', 'u', 'l', '\n',
        'd', 'i', 's', 'r', 'e', 's', 'p', 'e', 'c', 't', 'f', 'u', 'l', 'l', 'y', '\n',
        'd', 'i', 's', 'r', 'e', 's', 'p', 'e', 'c', 't', 's', '\n',
        'd', 'i', 's', 'r', 'o', 'b', 'e', '\n',
        'd', 'i', 's', 'r', 'o', 'b', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'r', 'u', 'p', 't', '\n',
        'd', 'i', 's', 'r', 'u', 'p', 't', 'e', 'd', '\n',
        'd', 'i', 's', 'r', 'u', 'p', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 'r', 'u', 'p', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 'r', 'u', 'p', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'i', 's', 'r', 'u', 'p', 't', 'i', 'v', 'e', '\n',
        'd', 'i', 's', 'r', 'u', 'p', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'd', 'i', 's', 'r', 'u', 'p', 't', 'o', 'r', '\n',
        'd', 'i', 's', 'r', 'u', 'p', 't', 's', '\n',
        'd', 'i', 's', 's', 'a', 't', 'i', 's', 'f', 'a', 'c', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 's', 'a', 't', 'i', 's', 'f', 'a', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'i', 's', 's', 'a', 't', 'i', 's', 'f', 'i', 'e', 'd', '\n',
        'd', 'i', 's', 's', 'a', 't', 'i', 's', 'f', 'i', 'e', 's', '\n',
        'd', 'i', 's', 's', 'a', 't', 'i', 's', 'f', 'y', '\n',
        'd', 'i', 's', 's', 'a', 't', 'i', 's', 'f', 'y', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 's', 'e', 'c', 't', '\n',
        'd', 'i', 's', 's', 'e', 'c', 't', 'e', 'd', '\n',
        'd', 'i', 's', 's', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 's', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 's', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'i', 's', 's', 'e', 'c', 't', 'o', 'r', '\n',
        'd', 'i', 's', 's', 'e', 'c', 't', 's', '\n',
        'd', 'i', 's', 's', 'e', 'm', 'b', 'l', 'e', '\n',
        'd', 'i', 's', 's', 'e', 'm', 'b', 'l', 'e', 'd', '\n',
        'd', 'i', 's', 's', 'e', 'm', 'b', 'l', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 's', 'e', 'm', 'i', 'n', 'a', 't', 'e', '\n',
        'd', 'i', 's', 's', 'e', 'm', 'i', 'n', 'a', 't', 'e', 'd', '\n',
        'd', 'i', 's', 's', 'e', 'm', 'i', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 's', 'e', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 's', 'e', 'n', 's', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 's', 'e', 'n', 's', 'i', 'o', 'n', 's', '\n',
        'd', 'i', 's', 's', 'e', 'n', 't', '\n',
        'd', 'i', 's', 's', 'e', 'n', 't', 'e', 'd', '\n',
        'd', 'i', 's', 's', 'e', 'n', 't', 'e', 'r', '\n',
        'd', 'i', 's', 's', 'e', 'n', 't', 'e', 'r', 's', '\n',
        'd', 'i', 's', 's', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 's', 'e', 'r', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 's', 'e', 'r', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'i', 's', 's', 'e', 'r', 'v', 'i', 'c', 'e', '\n',
        'd', 'i', 's', 's', 'i', 'd', 'e', 'n', 'c', 'e', '\n',
        'd', 'i', 's', 's', 'i', 'd', 'e', 'n', 't', '\n',
        'd', 'i', 's', 's', 'i', 'd', 'e', 'n', 't', 's', '\n',
        'd', 'i', 's', 's', 'i', 'm', 'i', 'l', 'a', 'r', '\n',
        'd', 'i', 's', 's', 'i', 'm', 'i', 'l', 'a', 'r', 'i', 't', 'i', 'e', 's', '\n',
        'd', 'i', 's', 's', 'i', 'm', 'i', 'l', 'a', 'r', 'i', 't', 'y', '\n',
        'd', 'i', 's', 's', 'i', 'm', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 's', 'i', 'p', 'a', 't', 'e', '\n',
        'd', 'i', 's', 's', 'i', 'p', 'a', 't', 'e', 'd', '\n',
        'd', 'i', 's', 's', 'i', 'p', 'a', 't', 'e', 's', '\n',
        'd', 'i', 's', 's', 'i', 'p', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 's', 'i', 'p', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 's', 'i', 'p', 'a', 't', 'i', 'v', 'e', '\n',
        'd', 'i', 's', 's', 'o', 'c', 'i', 'a', 't', 'e', '\n',
        'd', 'i', 's', 's', 'o', 'c', 'i', 'a', 't', 'e', 'd', '\n',
        'd', 'i', 's', 's', 'o', 'c', 'i', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 's', 'o', 'c', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 's', 'o', 'c', 'i', 'a', 't', 'i', 'v', 'e', '\n',
        'd', 'i', 's', 's', 'o', 'c', 'i', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'd', 'i', 's', 's', 'o', 'l', 'u', 't', 'e', '\n',
        'd', 'i', 's', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 's', 'o', 'l', 'v', 'e', '\n',
        'd', 'i', 's', 's', 'o', 'l', 'v', 'e', 'd', '\n',
        'd', 'i', 's', 's', 'o', 'l', 'v', 'e', 's', '\n',
        'd', 'i', 's', 's', 'o', 'l', 'v', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 's', 'o', 'n', 'a', 'n', 'c', 'e', '\n',
        'd', 'i', 's', 's', 'o', 'n', 'a', 'n', 'c', 'e', 's', '\n',
        'd', 'i', 's', 's', 'o', 'n', 'a', 'n', 't', '\n',
        'd', 'i', 's', 's', 'u', 'a', 'd', 'e', '\n',
        'd', 'i', 's', 's', 'u', 'a', 'd', 'e', 'd', '\n',
        'd', 'i', 's', 's', 'u', 'a', 'd', 'e', 's', '\n',
        'd', 'i', 's', 's', 'u', 'a', 'd', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 't', 'a', 'f', 'f', '\n',
        'd', 'i', 's', 't', 'a', 'l', '\n',
        'd', 'i', 's', 't', 'a', 'l', 'l', 'y', '\n',
        'd', 'i', 's', 't', 'a', 'n', 'c', 'e', '\n',
        'd', 'i', 's', 't', 'a', 'n', 'c', 'e', 'd', '\n',
        'd', 'i', 's', 't', 'a', 'n', 'c', 'e', 's', '\n',
        'd', 'i', 's', 't', 'a', 'n', 'c', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 't', 'a', 'n', 't', '\n',
        'd', 'i', 's', 't', 'a', 'n', 't', 'l', 'y', '\n',
        'd', 'i', 's', 't', 'a', 's', 't', 'e', '\n',
        'd', 'i', 's', 't', 'a', 's', 't', 'e', 'f', 'u', 'l', '\n',
        'd', 'i', 's', 't', 'a', 's', 't', 'e', 'f', 'u', 'l', 'l', 'y', '\n',
        'd', 'i', 's', 't', 'e', 'm', 'p', 'e', 'r', '\n',
        'd', 'i', 's', 't', 'e', 'm', 'p', 'e', 'r', 'e', 'd', '\n',
        'd', 'i', 's', 't', 'e', 'm', 'p', 'e', 'r', 's', '\n',
        'd', 'i', 's', 't', 'e', 'n', 'd', 'e', 'd', '\n',
        'd', 'i', 's', 't', 'e', 'n', 's', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 't', 'i', 'l', '\n',
        'd', 'i', 's', 't', 'i', 'l', 'l', 'a', 't', 'e', '\n',
        'd', 'i', 's', 't', 'i', 'l', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 't', 'i', 'l', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'i', 's', 't', 'i', 'l', 'l', 'e', 'd', '\n',
        'd', 'i', 's', 't', 'i', 'l', 'l', 'e', 'r', '\n',
        'd', 'i', 's', 't', 'i', 'l', 'l', 'e', 'r', 'i', 'e', 's', '\n',
        'd', 'i', 's', 't', 'i', 'l', 'l', 'e', 'r', 's', '\n',
        'd', 'i', 's', 't', 'i', 'l', 'l', 'e', 'r', 'y', '\n',
        'd', 'i', 's', 't', 'i', 'l', 'l', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 't', 'i', 'l', 's', '\n',
        'd', 'i', 's', 't', 'i', 'n', 'c', 't', '\n',
        'd', 'i', 's', 't', 'i', 'n', 'c', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 't', 'i', 'n', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'i', 's', 't', 'i', 'n', 'c', 't', 'i', 'v', 'e', '\n',
        'd', 'i', 's', 't', 'i', 'n', 'c', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'd', 'i', 's', 't', 'i', 'n', 'c', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'd', 'i', 's', 't', 'i', 'n', 'c', 't', 'l', 'y', '\n',
        'd', 'i', 's', 't', 'i', 'n', 'c', 't', 'n', 'e', 's', 's', '\n',
        'd', 'i', 's', 't', 'i', 'n', 'g', 'u', 'i', 's', 'h', '\n',
        'd', 'i', 's', 't', 'i', 'n', 'g', 'u', 'i', 's', 'h', 'a', 'b', 'l', 'e', '\n',
        'd', 'i', 's', 't', 'i', 'n', 'g', 'u', 'i', 's', 'h', 'a', 'b', 'l', 'y', '\n',
        'd', 'i', 's', 't', 'i', 'n', 'g', 'u', 'i', 's', 'h', 'e', 'd', '\n',
        'd', 'i', 's', 't', 'i', 'n', 'g', 'u', 'i', 's', 'h', 'e', 's', '\n',
        'd', 'i', 's', 't', 'i', 'n', 'g', 'u', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 't', 'o', 'r', 't', '\n',
        'd', 'i', 's', 't', 'o', 'r', 't', 'e', 'd', '\n',
        'd', 'i', 's', 't', 'o', 'r', 't', 'e', 'r', '\n',
        'd', 'i', 's', 't', 'o', 'r', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 't', 'o', 'r', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 't', 'o', 'r', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'i', 's', 't', 'o', 'r', 't', 's', '\n',
        'd', 'i', 's', 't', 'r', 'a', 'c', 't', '\n',
        'd', 'i', 's', 't', 'r', 'a', 'c', 't', 'e', 'd', '\n',
        'd', 'i', 's', 't', 'r', 'a', 'c', 't', 'e', 'd', 'l', 'y', '\n',
        'd', 'i', 's', 't', 'r', 'a', 'c', 't', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'd', 'i', 's', 't', 'r', 'a', 'c', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 't', 'r', 'a', 'c', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'd', 'i', 's', 't', 'r', 'a', 'c', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 't', 'r', 'a', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'i', 's', 't', 'r', 'a', 'c', 't', 's', '\n',
        'd', 'i', 's', 't', 'r', 'a', 'u', 'g', 'h', 't', '\n',
        'd', 'i', 's', 't', 'r', 'e', 's', 's', '\n',
        'd', 'i', 's', 't', 'r', 'e', 's', 's', 'e', 'd', '\n',
        'd', 'i', 's', 't', 'r', 'e', 's', 's', 'e', 's', '\n',
        'd', 'i', 's', 't', 'r', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 't', 'r', 'e', 's', 's', 'i', 'n', 'g', 'l', 'y', '\n',
        'd', 'i', 's', 't', 'r', 'i', 'b', 'u', 't', 'a', 'b', 'l', 'e', '\n',
        'd', 'i', 's', 't', 'r', 'i', 'b', 'u', 't', 'e', '\n',
        'd', 'i', 's', 't', 'r', 'i', 'b', 'u', 't', 'e', 'd', '\n',
        'd', 'i', 's', 't', 'r', 'i', 'b', 'u', 't', 'e', 's', '\n',
        'd', 'i', 's', 't', 'r', 'i', 'b', 'u', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 't', 'r', 'i', 'b', 'u', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 't', 'r', 'i', 'b', 'u', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'd', 'i', 's', 't', 'r', 'i', 'b', 'u', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'i', 's', 't', 'r', 'i', 'b', 'u', 't', 'i', 'v', 'e', '\n',
        'd', 'i', 's', 't', 'r', 'i', 'b', 'u', 't', 'i', 'v', 'i', 't', 'y', '\n',
        'd', 'i', 's', 't', 'r', 'i', 'b', 'u', 't', 'o', 'r', '\n',
        'd', 'i', 's', 't', 'r', 'i', 'b', 'u', 't', 'o', 'r', 's', '\n',
        'd', 'i', 's', 't', 'r', 'i', 'c', 't', '\n',
        'd', 'i', 's', 't', 'r', 'i', 'c', 't', 's', '\n',
        'd', 'i', 's', 't', 'r', 'u', 's', 't', '\n',
        'd', 'i', 's', 't', 'r', 'u', 's', 't', 'e', 'd', '\n',
        'd', 'i', 's', 't', 'r', 'u', 's', 't', 'f', 'u', 'l', '\n',
        'd', 'i', 's', 't', 'r', 'u', 's', 't', 'f', 'u', 'l', 'l', 'y', '\n',
        'd', 'i', 's', 't', 'r', 'u', 's', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 't', 'r', 'u', 's', 't', 's', '\n',
        'd', 'i', 's', 't', 'u', 'r', 'b', '\n',
        'd', 'i', 's', 't', 'u', 'r', 'b', 'a', 'n', 'c', 'e', '\n',
        'd', 'i', 's', 't', 'u', 'r', 'b', 'a', 'n', 'c', 'e', 's', '\n',
        'd', 'i', 's', 't', 'u', 'r', 'b', 'e', 'd', '\n',
        'd', 'i', 's', 't', 'u', 'r', 'b', 'i', 'n', 'g', '\n',
        'd', 'i', 's', 't', 'u', 'r', 'b', 'i', 'n', 'g', 'l', 'y', '\n',
        'd', 'i', 's', 't', 'u', 'r', 'b', 's', '\n',
        'd', 'i', 's', 'u', 'l', 'p', 'h', 'i', 'd', 'e', '\n',
        'd', 'i', 's', 'u', 'n', 'i', 'o', 'n', '\n',
        'd', 'i', 's', 'u', 'n', 'i', 't', 'e', '\n',
        'd', 'i', 's', 'u', 'n', 'i', 't', 'y', '\n',
        'd', 'i', 's', 'u', 's', 'e', '\n',
        'd', 'i', 's', 'u', 's', 'e', 'd', '\n',
        'd', 'i', 's', 'y', 'l', 'l', 'a', 'b', 'i', 'c', '\n',
        'd', 'i', 's', 'y', 'l', 'l', 'a', 'b', 'l', 'e', '\n',
        'd', 'i', 't', 'c', 'h', '\n',
        'd', 'i', 't', 'c', 'h', 'e', 'd', '\n',
        'd', 'i', 't', 'c', 'h', 'e', 's', '\n',
        'd', 'i', 't', 'c', 'h', 'i', 'n', 'g', '\n',
        'd', 'i', 't', 'h', 'e', 'r', '\n',
        'd', 'i', 't', 'h', 'e', 'r', 'e', 'd', '\n',
        'd', 'i', 't', 'h', 'e', 'r', 'i', 'n', 'g', '\n',
        'd', 'i', 't', 'h', 'e', 'r', 's', '\n',
        'd', 'i', 't', 't', 'i', 'e', 's', '\n',
        'd', 'i', 't', 't', 'o', '\n',
        'd', 'i', 't', 't', 'y', '\n',
        'd', 'i', 'u', 'r', 'e', 's', 'i', 's', '\n',
        'd', 'i', 'u', 'r', 'e', 't', 'i', 'c', '\n',
        'd', 'i', 'u', 'r', 'e', 't', 'i', 'c', 's', '\n',
        'd', 'i', 'u', 'r', 'n', 'a', 'l', '\n',
        'd', 'i', 'v', 'a', '\n',
        'd', 'i', 'v', 'a', 'n', '\n',
        'd', 'i', 'v', 'a', 'n', 's', '\n',
        'd', 'i', 'v', 'a', 's', '\n',
        'd', 'i', 'v', 'e', '\n',
        'd', 'i', 'v', 'e', 'b', 'o', 'm', 'b', 'i', 'n', 'g', '\n',
        'd', 'i', 'v', 'e', 'd', '\n',
        'd', 'i', 'v', 'e', 'r', '\n',
        'd', 'i', 'v', 'e', 'r', 'g', 'e', '\n',
        'd', 'i', 'v', 'e', 'r', 'g', 'e', 'd', '\n',
        'd', 'i', 'v', 'e', 'r', 'g', 'e', 'n', 'c', 'e', '\n',
        'd', 'i', 'v', 'e', 'r', 'g', 'e', 'n', 'c', 'e', 's', '\n',
        'd', 'i', 'v', 'e', 'r', 'g', 'e', 'n', 't', '\n',
        'd', 'i', 'v', 'e', 'r', 'g', 'e', 's', '\n',
        'd', 'i', 'v', 'e', 'r', 'g', 'i', 'n', 'g', '\n',
        'd', 'i', 'v', 'e', 'r', 's', '\n',
        'd', 'i', 'v', 'e', 'r', 's', 'e', '\n',
        'd', 'i', 'v', 'e', 'r', 's', 'e', 'l', 'y', '\n',
        'd', 'i', 'v', 'e', 'r', 's', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 'v', 'e', 'r', 's', 'i', 'f', 'i', 'e', 'd', '\n',
        'd', 'i', 'v', 'e', 'r', 's', 'i', 'f', 'i', 'e', 's', '\n',
        'd', 'i', 'v', 'e', 'r', 's', 'i', 'f', 'y', '\n',
        'd', 'i', 'v', 'e', 'r', 's', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'd', 'i', 'v', 'e', 'r', 's', 'i', 'o', 'n', '\n',
        'd', 'i', 'v', 'e', 'r', 's', 'i', 'o', 'n', 'a', 'r', 'y', '\n',
        'd', 'i', 'v', 'e', 'r', 's', 'i', 'o', 'n', 's', '\n',
        'd', 'i', 'v', 'e', 'r', 's', 'i', 't', 'i', 'e', 's', '\n',
        'd', 'i', 'v', 'e', 'r', 's', 'i', 't', 'y', '\n',
        'd', 'i', 'v', 'e', 'r', 't', '\n',
        'd', 'i', 'v', 'e', 'r', 't', 'e', 'd', '\n',
        'd', 'i', 'v', 'e', 'r', 't', 'i', 'c', 'u', 'l', 'a', 'r', '\n',
        'd', 'i', 'v', 'e', 'r', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 'v', 'e', 'r', 't', 's', '\n',
        'd', 'i', 'v', 'e', 's', '\n',
        'd', 'i', 'v', 'e', 's', 't', '\n',
        'd', 'i', 'v', 'e', 's', 't', 'e', 'd', '\n',
        'd', 'i', 'v', 'e', 's', 't', 'i', 'n', 'g', '\n',
        'd', 'i', 'v', 'i', 'd', 'e', '\n',
        'd', 'i', 'v', 'i', 'd', 'e', 'd', '\n',
        'd', 'i', 'v', 'i', 'd', 'e', 'n', 'd', '\n',
        'd', 'i', 'v', 'i', 'd', 'e', 'n', 'd', 's', '\n',
        'd', 'i', 'v', 'i', 'd', 'e', 'r', '\n',
        'd', 'i', 'v', 'i', 'd', 'e', 'r', 's', '\n',
        'd', 'i', 'v', 'i', 'd', 'e', 's', '\n',
        'd', 'i', 'v', 'i', 'd', 'i', 'n', 'g', '\n',
        'd', 'i', 'v', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'i', 'v', 'i', 'n', 'e', '\n',
        'd', 'i', 'v', 'i', 'n', 'e', 'd', '\n',
        'd', 'i', 'v', 'i', 'n', 'e', 'l', 'y', '\n',
        'd', 'i', 'v', 'i', 'n', 'e', 'r', '\n',
        'd', 'i', 'v', 'i', 'n', 'e', 's', '\n',
        'd', 'i', 'v', 'i', 'n', 'e', 's', 't', '\n',
        'd', 'i', 'v', 'i', 'n', 'g', '\n',
        'd', 'i', 'v', 'i', 'n', 'i', 'n', 'g', '\n',
        'd', 'i', 'v', 'i', 'n', 'i', 't', 'i', 'e', 's', '\n',
        'd', 'i', 'v', 'i', 'n', 'i', 't', 'y', '\n',
        'd', 'i', 'v', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'd', 'i', 'v', 'i', 's', 'i', 'b', 'l', 'e', '\n',
        'd', 'i', 'v', 'i', 's', 'i', 'o', 'n', '\n',
        'd', 'i', 'v', 'i', 's', 'i', 'o', 'n', 'a', 'l', '\n',
        'd', 'i', 'v', 'i', 's', 'i', 'o', 'n', 's', '\n',
        'd', 'i', 'v', 'i', 's', 'i', 'v', 'e', '\n',
        'd', 'i', 'v', 'i', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'd', 'i', 'v', 'i', 's', 'o', 'r', '\n',
        'd', 'i', 'v', 'i', 's', 'o', 'r', 's', '\n',
        'd', 'i', 'v', 'o', 'r', 'c', 'e', '\n',
        'd', 'i', 'v', 'o', 'r', 'c', 'e', 'd', '\n',
        'd', 'i', 'v', 'o', 'r', 'c', 'e', 'e', '\n',
        'd', 'i', 'v', 'o', 'r', 'c', 'e', 'e', 's', '\n',
        'd', 'i', 'v', 'o', 'r', 'c', 'e', 's', '\n',
        'd', 'i', 'v', 'o', 'r', 'c', 'i', 'n', 'g', '\n',
        'd', 'i', 'v', 'o', 't', '\n',
        'd', 'i', 'v', 'o', 't', 's', '\n',
        'd', 'i', 'v', 'u', 'l', 'g', 'e', '\n',
        'd', 'i', 'v', 'u', 'l', 'g', 'e', 'd', '\n',
        'd', 'i', 'v', 'u', 'l', 'g', 'e', 's', '\n',
        'd', 'i', 'v', 'u', 'l', 'g', 'i', 'n', 'g', '\n',
        'd', 'i', 'z', 'z', 'i', 'e', 'r', '\n',
        'd', 'i', 'z', 'z', 'i', 'e', 's', 't', '\n',
        'd', 'i', 'z', 'z', 'i', 'l', 'y', '\n',
        'd', 'i', 'z', 'z', 'i', 'n', 'e', 's', 's', '\n',
        'd', 'i', 'z', 'z', 'y', '\n',
        'd', 'i', 'z', 'z', 'y', 'i', 'n', 'g', '\n',
        'd', 'i', 'z', 'z', 'y', 'i', 'n', 'g', 'l', 'y', '\n',
        'd', 'o', '\n',
        'd', 'o', 'b', 'e', 'r', 'm', 'a', 'n', '\n',
        'd', 'o', 'c', '\n',
        'd', 'o', 'c', 'i', 'l', 'e', '\n',
        'd', 'o', 'c', 'i', 'l', 'e', 'l', 'y', '\n',
        'd', 'o', 'c', 'i', 'l', 'i', 't', 'y', '\n',
        'd', 'o', 'c', 'k', '\n',
        'd', 'o', 'c', 'k', 'a', 'g', 'e', '\n',
        'd', 'o', 'c', 'k', 'e', 'd', '\n',
        'd', 'o', 'c', 'k', 'e', 'r', '\n',
        'd', 'o', 'c', 'k', 'e', 'r', 's', '\n',
        'd', 'o', 'c', 'k', 'e', 't', '\n',
        'd', 'o', 'c', 'k', 'e', 't', 's', '\n',
        'd', 'o', 'c', 'k', 'i', 'n', 'g', '\n',
        'd', 'o', 'c', 'k', 'l', 'a', 'n', 'd', '\n',
        'd', 'o', 'c', 'k', 'l', 'a', 'n', 'd', 's', '\n',
        'd', 'o', 'c', 'k', 's', '\n',
        'd', 'o', 'c', 'k', 's', 'i', 'd', 'e', '\n',
        'd', 'o', 'c', 'k', 'y', 'a', 'r', 'd', '\n',
        'd', 'o', 'c', 'k', 'y', 'a', 'r', 'd', 's', '\n',
        'd', 'o', 'c', 's', '\n',
        'd', 'o', 'c', 't', 'o', 'r', '\n',
        'd', 'o', 'c', 't', 'o', 'r', 'a', 'l', '\n',
        'd', 'o', 'c', 't', 'o', 'r', 'a', 't', 'e', '\n',
        'd', 'o', 'c', 't', 'o', 'r', 'a', 't', 'e', 's', '\n',
        'd', 'o', 'c', 't', 'o', 'r', 'e', 'd', '\n',
        'd', 'o', 'c', 't', 'o', 'r', 'i', 'n', 'g', '\n',
        'd', 'o', 'c', 't', 'o', 'r', 's', '\n',
        'd', 'o', 'c', 't', 'r', 'i', 'n', 'a', 'i', 'r', 'e', '\n',
        'd', 'o', 'c', 't', 'r', 'i', 'n', 'a', 'l', '\n',
        'd', 'o', 'c', 't', 'r', 'i', 'n', 'a', 'l', 'l', 'y', '\n',
        'd', 'o', 'c', 't', 'r', 'i', 'n', 'e', '\n',
        'd', 'o', 'c', 't', 'r', 'i', 'n', 'e', 's', '\n',
        'd', 'o', 'c', 'u', 'm', 'e', 'n', 't', '\n',
        'd', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'a', 'r', 'i', 'e', 's', '\n',
        'd', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'a', 'r', 'y', '\n',
        'd', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'e', 'd', '\n',
        'd', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'd', 'o', 'c', 'u', 'm', 'e', 'n', 't', 's', '\n',
        'd', 'o', 'd', 'e', 'c', 'a', 'h', 'e', 'd', 'r', 'a', '\n',
        'd', 'o', 'd', 'e', 'c', 'a', 'h', 'e', 'd', 'r', 'a', 'l', '\n',
        'd', 'o', 'd', 'e', 'c', 'a', 'h', 'e', 'd', 'r', 'o', 'n', '\n',
        'd', 'o', 'd', 'g', 'e', '\n',
        'd', 'o', 'd', 'g', 'e', 'd', '\n',
        'd', 'o', 'd', 'g', 'e', 'm', '\n',
        'd', 'o', 'd', 'g', 'e', 'm', 's', '\n',
        'd', 'o', 'd', 'g', 'e', 'r', '\n',
        'd', 'o', 'd', 'g', 'e', 'r', 's', '\n',
        'd', 'o', 'd', 'g', 'e', 's', '\n',
        'd', 'o', 'd', 'g', 'i', 'e', 'r', '\n',
        'd', 'o', 'd', 'g', 'i', 'n', 'g', '\n',
        'd', 'o', 'd', 'g', 'y', '\n',
        'd', 'o', 'd', 'o', '\n',
        'd', 'o', 'e', '\n',
        'd', 'o', 'e', 'r', '\n',
        'd', 'o', 'e', 'r', 's', '\n',
        'd', 'o', 'e', 's', '\n',
        'd', 'o', 'e', 's', 'n', 't', '\n',
        'd', 'o', 'f', 'f', 'e', 'd', '\n',
        'd', 'o', 'f', 'f', 'i', 'n', 'g', '\n',
        'd', 'o', 'g', '\n',
        'd', 'o', 'g', 'd', 'a', 'y', 's', '\n',
        'd', 'o', 'g', 'e', '\n',
        'd', 'o', 'g', 'e', 'a', 'r', 'e', 'd', '\n',
        'd', 'o', 'g', 'e', 's', '\n',
        'd', 'o', 'g', 'f', 'i', 'g', 'h', 't', '\n',
        'd', 'o', 'g', 'f', 'i', 'g', 'h', 't', 's', '\n',
        'd', 'o', 'g', 'f', 'i', 's', 'h', '\n',
        'd', 'o', 'g', 'g', 'e', 'd', '\n',
        'd', 'o', 'g', 'g', 'e', 'd', 'l', 'y', '\n',
        'd', 'o', 'g', 'g', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'd', 'o', 'g', 'g', 'e', 'r', 'e', 'l', '\n',
        'd', 'o', 'g', 'g', 'i', 'n', 'g', '\n',
        'd', 'o', 'g', 'g', 'y', '\n',
        'd', 'o', 'g', 'l', 'i', 'k', 'e', '\n',
        'd', 'o', 'g', 'm', 'a', '\n',
        'd', 'o', 'g', 'm', 'a', 's', '\n',
        'd', 'o', 'g', 'm', 'a', 't', 'i', 'c', '\n',
        'd', 'o', 'g', 'm', 'a', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'd', 'o', 'g', 'm', 'a', 't', 'i', 's', 'm', '\n',
        'd', 'o', 'g', 'm', 'a', 't', 'i', 's', 't', '\n',
        'd', 'o', 'g', 'm', 'a', 't', 'i', 's', 't', 's', '\n',
        'd', 'o', 'g', 'o', 'o', 'd', '\n',
        'd', 'o', 'g', 'o', 'o', 'd', 'e', 'r', '\n',
        'd', 'o', 'g', 'o', 'o', 'd', 'e', 'r', 's', '\n',
        'd', 'o', 'g', 's', '\n',
        'd', 'o', 'g', 's', 'b', 'o', 'd', 'y', '\n',
        'd', 'o', 'g', 't', 'a', 'g', '\n',
        'd', 'o', 'g', 'y', '\n',
        'd', 'o', 'h', '\n',
        'd', 'o', 'h', 's', '\n',
        'd', 'o', 'i', 'l', 'y', '\n',
        'd', 'o', 'i', 'n', 'g', '\n',
        'd', 'o', 'i', 'n', 'g', 's', '\n',
        'd', 'o', 'i', 't', 'y', 'o', 'u', 'r', 's', 'e', 'l', 'f', '\n',
        'd', 'o', 'l', 'd', 'r', 'u', 'm', 's', '\n',
        'd', 'o', 'l', 'e', '\n',
        'd', 'o', 'l', 'e', 'd', '\n',
        'd', 'o', 'l', 'e', 'f', 'u', 'l', '\n',
        'd', 'o', 'l', 'e', 'f', 'u', 'l', 'l', 'y', '\n',
        'd', 'o', 'l', 'e', 'r', 'i', 't', 'e', '\n',
        'd', 'o', 'l', 'e', 's', '\n',
        'd', 'o', 'l', 'i', 'n', 'g', '\n',
        'd', 'o', 'l', 'l', '\n',
        'd', 'o', 'l', 'l', 'a', 'r', '\n',
        'd', 'o', 'l', 'l', 'a', 'r', 's', '\n',
        'd', 'o', 'l', 'l', 'e', 'd', '\n',
        'd', 'o', 'l', 'l', 'i', 'e', 's', '\n',
        'd', 'o', 'l', 'l', 'o', 'p', '\n',
        'd', 'o', 'l', 'l', 's', '\n',
        'd', 'o', 'l', 'l', 'y', '\n',
        'd', 'o', 'l', 'm', 'a', 'n', '\n',
        'd', 'o', 'l', 'm', 'e', 'n', '\n',
        'd', 'o', 'l', 'o', 'm', 'i', 't', 'e', '\n',
        'd', 'o', 'l', 'o', 'r', 'o', 'u', 's', '\n',
        'd', 'o', 'l', 'p', 'h', 'i', 'n', '\n',
        'd', 'o', 'l', 'p', 'h', 'i', 'n', 'a', 'r', 'i', 'u', 'm', '\n',
        'd', 'o', 'l', 'p', 'h', 'i', 'n', 's', '\n',
        'd', 'o', 'l', 't', '\n',
        'd', 'o', 'm', 'a', 'i', 'n', '\n',
        'd', 'o', 'm', 'a', 'i', 'n', 's', '\n',
        'd', 'o', 'm', 'e', '\n',
        'd', 'o', 'm', 'e', 'd', '\n',
        'd', 'o', 'm', 'e', 's', '\n',
        'd', 'o', 'm', 'e', 's', 't', 'i', 'c', '\n',
        'd', 'o', 'm', 'e', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'd', 'o', 'm', 'e', 's', 't', 'i', 'c', 'a', 't', 'e', 'd', '\n',
        'd', 'o', 'm', 'e', 's', 't', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'o', 'm', 'e', 's', 't', 'i', 'c', 'i', 't', 'y', '\n',
        'd', 'o', 'm', 'e', 's', 't', 'i', 'c', 's', '\n',
        'd', 'o', 'm', 'i', 'c', 'i', 'l', 'e', '\n',
        'd', 'o', 'm', 'i', 'c', 'i', 'l', 'e', 'd', '\n',
        'd', 'o', 'm', 'i', 'c', 'i', 'l', 'i', 'a', 'r', 'y', '\n',
        'd', 'o', 'm', 'i', 'n', 'a', 'n', 'c', 'e', '\n',
        'd', 'o', 'm', 'i', 'n', 'a', 'n', 't', '\n',
        'd', 'o', 'm', 'i', 'n', 'a', 'n', 't', 'l', 'y', '\n',
        'd', 'o', 'm', 'i', 'n', 'a', 't', 'e', '\n',
        'd', 'o', 'm', 'i', 'n', 'a', 't', 'e', 'd', '\n',
        'd', 'o', 'm', 'i', 'n', 'a', 't', 'e', 's', '\n',
        'd', 'o', 'm', 'i', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'o', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'o', 'm', 'i', 'n', 'e', 'e', 'r', '\n',
        'd', 'o', 'm', 'i', 'n', 'e', 'e', 'r', 'e', 'd', '\n',
        'd', 'o', 'm', 'i', 'n', 'e', 'e', 'r', 'i', 'n', 'g', '\n',
        'd', 'o', 'm', 'i', 'n', 'i', 'o', 'n', '\n',
        'd', 'o', 'm', 'i', 'n', 'i', 'o', 'n', 's', '\n',
        'd', 'o', 'm', 'i', 'n', 'o', '\n',
        'd', 'o', 'n', '\n',
        'd', 'o', 'n', 'a', 't', 'e', '\n',
        'd', 'o', 'n', 'a', 't', 'e', 'd', '\n',
        'd', 'o', 'n', 'a', 't', 'e', 's', '\n',
        'd', 'o', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'o', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'o', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'o', 'n', 'e', '\n',
        'd', 'o', 'n', 'g', '\n',
        'd', 'o', 'n', 'g', 'a', '\n',
        'd', 'o', 'n', 'j', 'u', 'a', 'n', '\n',
        'd', 'o', 'n', 'k', 'e', 'y', '\n',
        'd', 'o', 'n', 'k', 'e', 'y', 's', '\n',
        'd', 'o', 'n', 'n', 'e', 'd', '\n',
        'd', 'o', 'n', 'n', 'i', 'n', 'g', '\n',
        'd', 'o', 'n', 'o', 'r', '\n',
        'd', 'o', 'n', 'o', 'r', 's', '\n',
        'd', 'o', 'n', 's', '\n',
        'd', 'o', 'n', 't', '\n',
        'd', 'o', 'n', 'u', 't', '\n',
        'd', 'o', 'o', 'd', 'l', 'e', '\n',
        'd', 'o', 'o', 'd', 'l', 'e', 'd', '\n',
        'd', 'o', 'o', 'd', 'l', 'e', 's', '\n',
        'd', 'o', 'o', 'd', 'l', 'i', 'n', 'g', '\n',
        'd', 'o', 'o', 'm', '\n',
        'd', 'o', 'o', 'm', 'e', 'd', '\n',
        'd', 'o', 'o', 'm', 'i', 'n', 'g', '\n',
        'd', 'o', 'o', 'm', 's', '\n',
        'd', 'o', 'o', 'm', 's', 'd', 'a', 'y', '\n',
        'd', 'o', 'o', 'r', '\n',
        'd', 'o', 'o', 'r', 'b', 'e', 'l', 'l', '\n',
        'd', 'o', 'o', 'r', 'b', 'e', 'l', 'l', 's', '\n',
        'd', 'o', 'o', 'r', 'h', 'a', 'n', 'd', 'l', 'e', 's', '\n',
        'd', 'o', 'o', 'r', 'k', 'e', 'e', 'p', 'e', 'r', '\n',
        'd', 'o', 'o', 'r', 'k', 'e', 'e', 'p', 'e', 'r', 's', '\n',
        'd', 'o', 'o', 'r', 'k', 'n', 'o', 'b', '\n',
        'd', 'o', 'o', 'r', 'k', 'n', 'o', 'b', 's', '\n',
        'd', 'o', 'o', 'r', 'm', 'a', 'n', '\n',
        'd', 'o', 'o', 'r', 'm', 'a', 't', '\n',
        'd', 'o', 'o', 'r', 'm', 'a', 't', 's', '\n',
        'd', 'o', 'o', 'r', 'm', 'e', 'n', '\n',
        'd', 'o', 'o', 'r', 'n', 'a', 'i', 'l', '\n',
        'd', 'o', 'o', 'r', 'p', 'o', 's', 't', '\n',
        'd', 'o', 'o', 'r', 's', '\n',
        'd', 'o', 'o', 'r', 's', 't', 'e', 'p', '\n',
        'd', 'o', 'o', 'r', 's', 't', 'e', 'p', 's', '\n',
        'd', 'o', 'o', 'r', 's', 't', 'o', 'p', '\n',
        'd', 'o', 'o', 'r', 's', 't', 'o', 'p', 's', '\n',
        'd', 'o', 'o', 'r', 'w', 'a', 'y', '\n',
        'd', 'o', 'o', 'r', 'w', 'a', 'y', 's', '\n',
        'd', 'o', 'p', 'a', 'm', 'i', 'n', 'e', '\n',
        'd', 'o', 'p', 'e', '\n',
        'd', 'o', 'p', 'e', 'd', '\n',
        'd', 'o', 'p', 'e', 's', '\n',
        'd', 'o', 'p', 'e', 'y', '\n',
        'd', 'o', 'p', 'i', 'e', 'r', '\n',
        'd', 'o', 'p', 'i', 'n', 'g', '\n',
        'd', 'o', 'p', 'y', '\n',
        'd', 'o', 'r', '\n',
        'd', 'o', 'r', 'a', 'd', 'o', '\n',
        'd', 'o', 'r', 'm', 'a', 'n', 'c', 'y', '\n',
        'd', 'o', 'r', 'm', 'a', 'n', 't', '\n',
        'd', 'o', 'r', 'm', 'e', 'r', '\n',
        'd', 'o', 'r', 'm', 'e', 'r', 's', '\n',
        'd', 'o', 'r', 'm', 'i', 'c', 'e', '\n',
        'd', 'o', 'r', 'm', 'i', 't', 'o', 'r', 'i', 'e', 's', '\n',
        'd', 'o', 'r', 'm', 'i', 't', 'o', 'r', 'y', '\n',
        'd', 'o', 'r', 'm', 'o', 'u', 's', 'e', '\n',
        'd', 'o', 'r', 's', 'a', 'l', '\n',
        'd', 'o', 'r', 's', 'a', 'l', 'l', 'y', '\n',
        'd', 'o', 's', 'a', 'g', 'e', '\n',
        'd', 'o', 's', 'a', 'g', 'e', 's', '\n',
        'd', 'o', 's', 'e', '\n',
        'd', 'o', 's', 'e', 'd', '\n',
        'd', 'o', 's', 'e', 's', '\n',
        'd', 'o', 's', 'i', 'n', 'g', '\n',
        'd', 'o', 's', 's', 'i', 'e', 'r', '\n',
        'd', 'o', 's', 's', 'i', 'e', 'r', 's', '\n',
        'd', 'o', 't', '\n',
        'd', 'o', 't', 'a', 'g', 'e', '\n',
        'd', 'o', 't', 'e', '\n',
        'd', 'o', 't', 'e', 'd', '\n',
        'd', 'o', 't', 'e', 's', '\n',
        'd', 'o', 't', 'i', 'n', 'g', '\n',
        'd', 'o', 't', 's', '\n',
        'd', 'o', 't', 't', 'e', 'd', '\n',
        'd', 'o', 't', 't', 'i', 'n', 'e', 's', 's', '\n',
        'd', 'o', 't', 't', 'i', 'n', 'g', '\n',
        'd', 'o', 't', 't', 'y', '\n',
        'd', 'o', 'u', 'b', 'l', 'e', '\n',
        'd', 'o', 'u', 'b', 'l', 'e', 'b', 'a', 'r', 'r', 'e', 'l', 'l', 'e', 'd', '\n',
        'd', 'o', 'u', 'b', 'l', 'e', 'c', 'r', 'o', 's', 's', '\n',
        'd', 'o', 'u', 'b', 'l', 'e', 'c', 'r', 'o', 's', 's', 'i', 'n', 'g', '\n',
        'd', 'o', 'u', 'b', 'l', 'e', 'd', '\n',
        'd', 'o', 'u', 'b', 'l', 'e', 'd', 'e', 'a', 'l', 'i', 'n', 'g', '\n',
        'd', 'o', 'u', 'b', 'l', 'e', 'd', 'e', 'c', 'k', 'e', 'r', '\n',
        'd', 'o', 'u', 'b', 'l', 'e', 'd', 'e', 'c', 'k', 'e', 'r', 's', '\n',
        'd', 'o', 'u', 'b', 'l', 'e', 's', '\n',
        'd', 'o', 'u', 'b', 'l', 'e', 't', '\n',
        'd', 'o', 'u', 'b', 'l', 'e', 't', 'a', 'l', 'k', '\n',
        'd', 'o', 'u', 'b', 'l', 'e', 't', 's', '\n',
        'd', 'o', 'u', 'b', 'l', 'i', 'n', 'g', '\n',
        'd', 'o', 'u', 'b', 'l', 'y', '\n',
        'd', 'o', 'u', 'b', 't', '\n',
        'd', 'o', 'u', 'b', 't', 'e', 'd', '\n',
        'd', 'o', 'u', 'b', 't', 'e', 'r', '\n',
        'd', 'o', 'u', 'b', 't', 'e', 'r', 's', '\n',
        'd', 'o', 'u', 'b', 't', 'f', 'u', 'l', '\n',
        'd', 'o', 'u', 'b', 't', 'f', 'u', 'l', 'l', 'y', '\n',
        'd', 'o', 'u', 'b', 't', 'i', 'n', 'g', '\n',
        'd', 'o', 'u', 'b', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'd', 'o', 'u', 'b', 't', 'l', 'e', 's', 's', '\n',
        'd', 'o', 'u', 'b', 't', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'd', 'o', 'u', 'b', 't', 's', '\n',
        'd', 'o', 'u', 'c', 'h', 'e', '\n',
        'd', 'o', 'u', 'c', 'h', 'i', 'n', 'g', '\n',
        'd', 'o', 'u', 'g', 'h', '\n',
        'd', 'o', 'u', 'g', 'h', 'n', 'u', 't', '\n',
        'd', 'o', 'u', 'g', 'h', 'n', 'u', 't', 's', '\n',
        'd', 'o', 'u', 'g', 'h', 's', '\n',
        'd', 'o', 'u', 'g', 'h', 't', 'y', '\n',
        'd', 'o', 'u', 'r', '\n',
        'd', 'o', 'u', 'r', 'l', 'y', '\n',
        'd', 'o', 'u', 'r', 'n', 'e', 's', 's', '\n',
        'd', 'o', 'u', 's', 'e', '\n',
        'd', 'o', 'u', 's', 'e', 'd', '\n',
        'd', 'o', 'u', 's', 'i', 'n', 'g', '\n',
        'd', 'o', 'v', 'e', '\n',
        'd', 'o', 'v', 'e', 'c', 'o', 't', '\n',
        'd', 'o', 'v', 'e', 'c', 'o', 't', 'e', '\n',
        'd', 'o', 'v', 'e', 'r', '\n',
        'd', 'o', 'v', 'e', 's', '\n',
        'd', 'o', 'v', 'e', 't', 'a', 'i', 'l', '\n',
        'd', 'o', 'v', 'e', 't', 'a', 'i', 'l', 's', '\n',
        'd', 'o', 'w', 'a', 'g', 'e', 'r', '\n',
        'd', 'o', 'w', 'a', 'g', 'e', 'r', 's', '\n',
        'd', 'o', 'w', 'd', 'i', 'e', 'r', '\n',
        'd', 'o', 'w', 'd', 'i', 'e', 's', 't', '\n',
        'd', 'o', 'w', 'd', 'y', '\n',
        'd', 'o', 'w', 'e', 'l', '\n',
        'd', 'o', 'w', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'd', 'o', 'w', 'e', 'l', 's', '\n',
        'd', 'o', 'w', 'n', '\n',
        'd', 'o', 'w', 'n', 'b', 'e', 'a', 't', '\n',
        'd', 'o', 'w', 'n', 'c', 'a', 's', 't', '\n',
        'd', 'o', 'w', 'n', 'e', 'd', '\n',
        'd', 'o', 'w', 'n', 'f', 'a', 'l', 'l', '\n',
        'd', 'o', 'w', 'n', 'g', 'r', 'a', 'd', 'e', '\n',
        'd', 'o', 'w', 'n', 'g', 'r', 'a', 'd', 'e', 'd', '\n',
        'd', 'o', 'w', 'n', 'g', 'r', 'a', 'd', 'e', 's', '\n',
        'd', 'o', 'w', 'n', 'g', 'r', 'a', 'd', 'i', 'n', 'g', '\n',
        'd', 'o', 'w', 'n', 'h', 'e', 'a', 'r', 't', 'e', 'd', '\n',
        'd', 'o', 'w', 'n', 'h', 'i', 'l', 'l', '\n',
        'd', 'o', 'w', 'n', 'i', 'n', 'g', '\n',
        'd', 'o', 'w', 'n', 'l', 'a', 'n', 'd', '\n',
        'd', 'o', 'w', 'n', 'l', 'a', 'n', 'd', 's', '\n',
        'd', 'o', 'w', 'n', 'l', 'o', 'a', 'd', '\n',
        'd', 'o', 'w', 'n', 'l', 'o', 'a', 'd', 'e', 'd', '\n',
        'd', 'o', 'w', 'n', 'l', 'o', 'a', 'd', 'i', 'n', 'g', '\n',
        'd', 'o', 'w', 'n', 'l', 'o', 'a', 'd', 's', '\n',
        'd', 'o', 'w', 'n', 'p', 'i', 'p', 'e', '\n',
        'd', 'o', 'w', 'n', 'p', 'i', 'p', 'e', 's', '\n',
        'd', 'o', 'w', 'n', 'p', 'l', 'a', 'y', '\n',
        'd', 'o', 'w', 'n', 'p', 'l', 'a', 'y', 'e', 'd', '\n',
        'd', 'o', 'w', 'n', 'p', 'o', 'u', 'r', '\n',
        'd', 'o', 'w', 'n', 'p', 'o', 'u', 'r', 's', '\n',
        'd', 'o', 'w', 'n', 'r', 'i', 'g', 'h', 't', '\n',
        'd', 'o', 'w', 'n', 's', '\n',
        'd', 'o', 'w', 'n', 's', 'i', 'd', 'e', '\n',
        'd', 'o', 'w', 'n', 's', 'i', 'z', 'e', '\n',
        'd', 'o', 'w', 'n', 's', 'i', 'z', 'e', 'd', '\n',
        'd', 'o', 'w', 'n', 's', 'i', 'z', 'i', 'n', 'g', '\n',
        'd', 'o', 'w', 'n', 's', 't', 'a', 'g', 'e', '\n',
        'd', 'o', 'w', 'n', 's', 't', 'a', 'i', 'r', 's', '\n',
        'd', 'o', 'w', 'n', 's', 't', 'r', 'e', 'a', 'm', '\n',
        'd', 'o', 'w', 'n', 's', 'w', 'i', 'n', 'g', '\n',
        'd', 'o', 'w', 'n', 't', 'o', 'e', 'a', 'r', 't', 'h', '\n',
        'd', 'o', 'w', 'n', 't', 'r', 'o', 'd', 'd', 'e', 'n', '\n',
        'd', 'o', 'w', 'n', 't', 'u', 'r', 'n', '\n',
        'd', 'o', 'w', 'n', 't', 'u', 'r', 'n', 's', '\n',
        'd', 'o', 'w', 'n', 'w', 'a', 'r', 'd', '\n',
        'd', 'o', 'w', 'n', 'w', 'a', 'r', 'd', 'l', 'y', '\n',
        'd', 'o', 'w', 'n', 'w', 'a', 'r', 'd', 's', '\n',
        'd', 'o', 'w', 'n', 'w', 'i', 'n', 'd', '\n',
        'd', 'o', 'w', 'n', 'y', '\n',
        'd', 'o', 'w', 'r', 'i', 'e', 's', '\n',
        'd', 'o', 'w', 'r', 'y', '\n',
        'd', 'o', 'w', 's', 'e', '\n',
        'd', 'o', 'w', 's', 'e', 'r', '\n',
        'd', 'o', 'w', 's', 'e', 'r', 's', '\n',
        'd', 'o', 'w', 's', 'i', 'n', 'g', '\n',
        'd', 'o', 'y', 'e', 'n', '\n',
        'd', 'o', 'y', 'e', 'n', 'n', 'e', '\n',
        'd', 'o', 'y', 'e', 'n', 's', '\n',
        'd', 'o', 'z', 'e', '\n',
        'd', 'o', 'z', 'e', 'd', '\n',
        'd', 'o', 'z', 'e', 'n', '\n',
        'd', 'o', 'z', 'e', 'n', 's', '\n',
        'd', 'o', 'z', 'e', 's', '\n',
        'd', 'o', 'z', 'i', 'e', 'r', '\n',
        'd', 'o', 'z', 'i', 'n', 'g', '\n',
        'd', 'o', 'z', 'y', '\n',
        'd', 'r', '\n',
        'd', 'r', 'a', 'b', '\n',
        'd', 'r', 'a', 'b', 'n', 'e', 's', 's', '\n',
        'd', 'r', 'a', 'c', 'h', 'm', '\n',
        'd', 'r', 'a', 'c', 'h', 'm', 'a', '\n',
        'd', 'r', 'a', 'c', 'h', 'm', 'a', 's', '\n',
        'd', 'r', 'a', 'c', 'o', 'n', 'e', '\n',
        'd', 'r', 'a', 'c', 'o', 'n', 'i', 'a', 'n', '\n',
        'd', 'r', 'a', 'c', 'u', 'l', 'a', '\n',
        'd', 'r', 'a', 'f', 't', '\n',
        'd', 'r', 'a', 'f', 't', 'e', 'd', '\n',
        'd', 'r', 'a', 'f', 't', 'e', 'e', '\n',
        'd', 'r', 'a', 'f', 't', 'e', 'e', 's', '\n',
        'd', 'r', 'a', 'f', 't', 'e', 'r', '\n',
        'd', 'r', 'a', 'f', 't', 'e', 'r', 's', '\n',
        'd', 'r', 'a', 'f', 't', 'i', 'e', 'r', '\n',
        'd', 'r', 'a', 'f', 't', 'i', 'n', 'g', '\n',
        'd', 'r', 'a', 'f', 't', 's', '\n',
        'd', 'r', 'a', 'f', 't', 's', 'm', 'a', 'n', '\n',
        'd', 'r', 'a', 'f', 't', 'y', '\n',
        'd', 'r', 'a', 'g', '\n',
        'd', 'r', 'a', 'g', 'g', 'e', 'd', '\n',
        'd', 'r', 'a', 'g', 'g', 'i', 'n', 'g', '\n',
        'd', 'r', 'a', 'g', 'n', 'e', 't', '\n',
        'd', 'r', 'a', 'g', 'o', 'n', '\n',
        'd', 'r', 'a', 'g', 'o', 'n', 'f', 'l', 'i', 'e', 's', '\n',
        'd', 'r', 'a', 'g', 'o', 'n', 'f', 'l', 'y', '\n',
        'd', 'r', 'a', 'g', 'o', 'n', 's', '\n',
        'd', 'r', 'a', 'g', 'o', 'o', 'n', '\n',
        'd', 'r', 'a', 'g', 'o', 'o', 'n', 'e', 'd', '\n',
        'd', 'r', 'a', 'g', 'o', 'o', 'n', 's', '\n',
        'd', 'r', 'a', 'g', 's', '\n',
        'd', 'r', 'a', 'i', 'n', '\n',
        'd', 'r', 'a', 'i', 'n', 'a', 'g', 'e', '\n',
        'd', 'r', 'a', 'i', 'n', 'e', 'd', '\n',
        'd', 'r', 'a', 'i', 'n', 'e', 'r', '\n',
        'd', 'r', 'a', 'i', 'n', 'i', 'n', 'g', '\n',
        'd', 'r', 'a', 'i', 'n', 'p', 'i', 'p', 'e', '\n',
        'd', 'r', 'a', 'i', 'n', 'p', 'i', 'p', 'e', 's', '\n',
        'd', 'r', 'a', 'i', 'n', 's', '\n',
        'd', 'r', 'a', 'k', 'e', '\n',
        'd', 'r', 'a', 'k', 'e', 's', '\n',
        'd', 'r', 'a', 'm', '\n',
        'd', 'r', 'a', 'm', 'a', '\n',
        'd', 'r', 'a', 'm', 'a', 's', '\n',
        'd', 'r', 'a', 'm', 'a', 't', 'i', 'c', '\n',
        'd', 'r', 'a', 'm', 'a', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'd', 'r', 'a', 'm', 'a', 't', 'i', 'c', 's', '\n',
        'd', 'r', 'a', 'm', 'a', 't', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'r', 'a', 'm', 'a', 't', 'i', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'r', 'a', 'm', 'a', 't', 'i', 's', 'e', '\n',
        'd', 'r', 'a', 'm', 'a', 't', 'i', 's', 'e', 'd', '\n',
        'd', 'r', 'a', 'm', 'a', 't', 'i', 's', 'i', 'n', 'g', '\n',
        'd', 'r', 'a', 'm', 'a', 't', 'i', 's', 't', '\n',
        'd', 'r', 'a', 'm', 'a', 't', 'i', 's', 't', 's', '\n',
        'd', 'r', 'a', 'm', 'a', 't', 'u', 'r', 'g', 'i', 'c', 'a', 'l', '\n',
        'd', 'r', 'a', 'n', 'k', '\n',
        'd', 'r', 'a', 'p', 'e', '\n',
        'd', 'r', 'a', 'p', 'e', 'd', '\n',
        'd', 'r', 'a', 'p', 'e', 'r', '\n',
        'd', 'r', 'a', 'p', 'e', 'r', 'i', 'e', 's', '\n',
        'd', 'r', 'a', 'p', 'e', 'r', 's', '\n',
        'd', 'r', 'a', 'p', 'e', 'r', 'y', '\n',
        'd', 'r', 'a', 'p', 'e', 's', '\n',
        'd', 'r', 'a', 'p', 'i', 'n', 'g', '\n',
        'd', 'r', 'a', 's', 't', 'i', 'c', '\n',
        'd', 'r', 'a', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'd', 'r', 'a', 't', '\n',
        'd', 'r', 'a', 'u', 'g', 'h', 't', '\n',
        'd', 'r', 'a', 'u', 'g', 'h', 't', 'i', 'e', 'r', '\n',
        'd', 'r', 'a', 'u', 'g', 'h', 't', 'i', 'e', 's', 't', '\n',
        'd', 'r', 'a', 'u', 'g', 'h', 't', 's', '\n',
        'd', 'r', 'a', 'u', 'g', 'h', 't', 's', 'm', 'a', 'n', '\n',
        'd', 'r', 'a', 'u', 'g', 'h', 't', 's', 'm', 'a', 'n', 's', 'h', 'i', 'p', '\n',
        'd', 'r', 'a', 'u', 'g', 'h', 't', 's', 'm', 'e', 'n', '\n',
        'd', 'r', 'a', 'u', 'g', 'h', 't', 'y', '\n',
        'd', 'r', 'a', 'w', '\n',
        'd', 'r', 'a', 'w', 'a', 'b', 'l', 'e', '\n',
        'd', 'r', 'a', 'w', 'b', 'a', 'c', 'k', '\n',
        'd', 'r', 'a', 'w', 'b', 'a', 'c', 'k', 's', '\n',
        'd', 'r', 'a', 'w', 'b', 'r', 'i', 'd', 'g', 'e', '\n',
        'd', 'r', 'a', 'w', 'b', 'r', 'i', 'd', 'g', 'e', 's', '\n',
        'd', 'r', 'a', 'w', 'c', 'o', 'r', 'd', '\n',
        'd', 'r', 'a', 'w', 'e', 'e', 's', '\n',
        'd', 'r', 'a', 'w', 'e', 'r', '\n',
        'd', 'r', 'a', 'w', 'e', 'r', 's', '\n',
        'd', 'r', 'a', 'w', 'i', 'n', 'g', '\n',
        'd', 'r', 'a', 'w', 'i', 'n', 'g', 's', '\n',
        'd', 'r', 'a', 'w', 'l', '\n',
        'd', 'r', 'a', 'w', 'l', 'e', 'd', '\n',
        'd', 'r', 'a', 'w', 'l', 'i', 'n', 'g', '\n',
        'd', 'r', 'a', 'w', 'l', 's', '\n',
        'd', 'r', 'a', 'w', 'n', '\n',
        'd', 'r', 'a', 'w', 's', '\n',
        'd', 'r', 'a', 'y', '\n',
        'd', 'r', 'a', 'y', 's', '\n',
        'd', 'r', 'e', 'a', 'd', '\n',
        'd', 'r', 'e', 'a', 'd', 'e', 'd', '\n',
        'd', 'r', 'e', 'a', 'd', 'f', 'u', 'l', '\n',
        'd', 'r', 'e', 'a', 'd', 'f', 'u', 'l', 'l', 'y', '\n',
        'd', 'r', 'e', 'a', 'd', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'd', 'r', 'e', 'a', 'd', 'i', 'n', 'g', '\n',
        'd', 'r', 'e', 'a', 'd', 'l', 'o', 'c', 'k', 's', '\n',
        'd', 'r', 'e', 'a', 'd', 'n', 'o', 'u', 'g', 'h', 't', '\n',
        'd', 'r', 'e', 'a', 'd', 's', '\n',
        'd', 'r', 'e', 'a', 'm', '\n',
        'd', 'r', 'e', 'a', 'm', 'e', 'd', '\n',
        'd', 'r', 'e', 'a', 'm', 'e', 'r', '\n',
        'd', 'r', 'e', 'a', 'm', 'e', 'r', 's', '\n',
        'd', 'r', 'e', 'a', 'm', 'i', 'e', 'r', '\n',
        'd', 'r', 'e', 'a', 'm', 'i', 'e', 's', 't', '\n',
        'd', 'r', 'e', 'a', 'm', 'i', 'l', 'y', '\n',
        'd', 'r', 'e', 'a', 'm', 'i', 'n', 'g', '\n',
        'd', 'r', 'e', 'a', 'm', 'l', 'a', 'n', 'd', '\n',
        'd', 'r', 'e', 'a', 'm', 'l', 'e', 's', 's', '\n',
        'd', 'r', 'e', 'a', 'm', 'l', 'i', 'k', 'e', '\n',
        'd', 'r', 'e', 'a', 'm', 's', '\n',
        'd', 'r', 'e', 'a', 'm', 't', '\n',
        'd', 'r', 'e', 'a', 'm', 'y', '\n',
        'd', 'r', 'e', 'a', 'r', '\n',
        'd', 'r', 'e', 'a', 'r', 'i', 'e', 'r', '\n',
        'd', 'r', 'e', 'a', 'r', 'i', 'e', 's', 't', '\n',
        'd', 'r', 'e', 'a', 'r', 'i', 'l', 'y', '\n',
        'd', 'r', 'e', 'a', 'r', 'i', 'n', 'e', 's', 's', '\n',
        'd', 'r', 'e', 'a', 'r', 'y', '\n',
        'd', 'r', 'e', 'd', 'g', 'e', '\n',
        'd', 'r', 'e', 'd', 'g', 'e', 'd', '\n',
        'd', 'r', 'e', 'd', 'g', 'e', 'r', '\n',
        'd', 'r', 'e', 'd', 'g', 'e', 's', '\n',
        'd', 'r', 'e', 'd', 'g', 'i', 'n', 'g', '\n',
        'd', 'r', 'e', 'g', 's', '\n',
        'd', 'r', 'e', 'n', 'c', 'h', '\n',
        'd', 'r', 'e', 'n', 'c', 'h', 'e', 'd', '\n',
        'd', 'r', 'e', 'n', 'c', 'h', 'e', 's', '\n',
        'd', 'r', 'e', 'n', 'c', 'h', 'i', 'n', 'g', '\n',
        'd', 'r', 'e', 's', 's', '\n',
        'd', 'r', 'e', 's', 's', 'a', 'g', 'e', '\n',
        'd', 'r', 'e', 's', 's', 'e', 'd', '\n',
        'd', 'r', 'e', 's', 's', 'e', 'r', '\n',
        'd', 'r', 'e', 's', 's', 'e', 'r', 's', '\n',
        'd', 'r', 'e', 's', 's', 'e', 's', '\n',
        'd', 'r', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'd', 'r', 'e', 's', 's', 'i', 'n', 'g', 's', '\n',
        'd', 'r', 'e', 's', 's', 'm', 'a', 'k', 'e', 'r', '\n',
        'd', 'r', 'e', 's', 's', 'm', 'a', 'k', 'e', 'r', 's', '\n',
        'd', 'r', 'e', 's', 's', 'm', 'a', 'k', 'i', 'n', 'g', '\n',
        'd', 'r', 'e', 's', 's', 'y', '\n',
        'd', 'r', 'e', 'w', '\n',
        'd', 'r', 'i', 'b', 'b', 'l', 'e', '\n',
        'd', 'r', 'i', 'b', 'b', 'l', 'e', 'd', '\n',
        'd', 'r', 'i', 'b', 'b', 'l', 'e', 'r', '\n',
        'd', 'r', 'i', 'b', 'b', 'l', 'e', 's', '\n',
        'd', 'r', 'i', 'b', 'b', 'l', 'i', 'n', 'g', '\n',
        'd', 'r', 'i', 'e', 'd', '\n',
        'd', 'r', 'i', 'e', 'r', '\n',
        'd', 'r', 'i', 'e', 'r', 's', '\n',
        'd', 'r', 'i', 'e', 's', '\n',
        'd', 'r', 'i', 'e', 's', 't', '\n',
        'd', 'r', 'i', 'f', 't', '\n',
        'd', 'r', 'i', 'f', 't', 'e', 'd', '\n',
        'd', 'r', 'i', 'f', 't', 'e', 'r', '\n',
        'd', 'r', 'i', 'f', 't', 'e', 'r', 's', '\n',
        'd', 'r', 'i', 'f', 't', 'i', 'n', 'g', '\n',
        'd', 'r', 'i', 'f', 't', 's', '\n',
        'd', 'r', 'i', 'f', 't', 'w', 'o', 'o', 'd', '\n',
        'd', 'r', 'i', 'l', 'l', '\n',
        'd', 'r', 'i', 'l', 'l', 'e', 'd', '\n',
        'd', 'r', 'i', 'l', 'l', 'e', 'r', '\n',
        'd', 'r', 'i', 'l', 'l', 'i', 'n', 'g', '\n',
        'd', 'r', 'i', 'l', 'l', 's', '\n',
        'd', 'r', 'i', 'l', 'y', '\n',
        'd', 'r', 'i', 'n', 'k', '\n',
        'd', 'r', 'i', 'n', 'k', 'a', 'b', 'l', 'e', '\n',
        'd', 'r', 'i', 'n', 'k', 'e', 'r', '\n',
        'd', 'r', 'i', 'n', 'k', 'e', 'r', 's', '\n',
        'd', 'r', 'i', 'n', 'k', 'i', 'n', 'g', '\n',
        'd', 'r', 'i', 'n', 'k', 's', '\n',
        'd', 'r', 'i', 'p', '\n',
        'd', 'r', 'i', 'p', 'd', 'r', 'y', '\n',
        'd', 'r', 'i', 'p', 'p', 'e', 'd', '\n',
        'd', 'r', 'i', 'p', 'p', 'i', 'n', 'g', '\n',
        'd', 'r', 'i', 'p', 'p', 'y', '\n',
        'd', 'r', 'i', 'p', 's', '\n',
        'd', 'r', 'i', 'v', 'a', 'b', 'l', 'e', '\n',
        'd', 'r', 'i', 'v', 'e', '\n',
        'd', 'r', 'i', 'v', 'e', '\n',
        'd', 'r', 'i', 'v', 'e', 'i', 'n', '\n',
        'd', 'r', 'i', 'v', 'e', 'i', 'n', 's', '\n',
        'd', 'r', 'i', 'v', 'e', 'l', '\n',
        'd', 'r', 'i', 'v', 'e', 'l', 'l', 'e', 'd', '\n',
        'd', 'r', 'i', 'v', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'd', 'r', 'i', 'v', 'e', 'l', 's', '\n',
        'd', 'r', 'i', 'v', 'e', 'n', '\n',
        'd', 'r', 'i', 'v', 'e', 'r', '\n',
        'd', 'r', 'i', 'v', 'e', 'r', 'l', 'e', 's', 's', '\n',
        'd', 'r', 'i', 'v', 'e', 'r', 's', '\n',
        'd', 'r', 'i', 'v', 'e', 's', '\n',
        'd', 'r', 'i', 'v', 'e', 'w', 'a', 'y', '\n',
        'd', 'r', 'i', 'v', 'e', 'w', 'a', 'y', 's', '\n',
        'd', 'r', 'i', 'v', 'i', 'n', 'g', '\n',
        'd', 'r', 'i', 'z', 'z', 'l', 'e', '\n',
        'd', 'r', 'i', 'z', 'z', 'l', 'e', 'd', '\n',
        'd', 'r', 'i', 'z', 'z', 'l', 'e', 's', '\n',
        'd', 'r', 'i', 'z', 'z', 'l', 'i', 'n', 'g', '\n',
        'd', 'r', 'i', 'z', 'z', 'l', 'y', '\n',
        'd', 'r', 'o', 'l', 'l', '\n',
        'd', 'r', 'o', 'l', 'l', 'e', 'r', '\n',
        'd', 'r', 'o', 'l', 'l', 'e', 'r', 'y', '\n',
        'd', 'r', 'o', 'l', 'l', 'e', 's', 't', '\n',
        'd', 'r', 'o', 'm', 'e', 'd', 'a', 'r', 'i', 'e', 's', '\n',
        'd', 'r', 'o', 'm', 'e', 'd', 'a', 'r', 'y', '\n',
        'd', 'r', 'o', 'n', 'e', '\n',
        'd', 'r', 'o', 'n', 'e', 'd', '\n',
        'd', 'r', 'o', 'n', 'e', 's', '\n',
        'd', 'r', 'o', 'n', 'i', 'n', 'g', '\n',
        'd', 'r', 'o', 'o', 'l', '\n',
        'd', 'r', 'o', 'o', 'l', 'e', 'd', '\n',
        'd', 'r', 'o', 'o', 'l', 'i', 'n', 'g', '\n',
        'd', 'r', 'o', 'o', 'l', 's', '\n',
        'd', 'r', 'o', 'o', 'p', '\n',
        'd', 'r', 'o', 'o', 'p', 'e', 'd', '\n',
        'd', 'r', 'o', 'o', 'p', 'i', 'e', 'r', '\n',
        'd', 'r', 'o', 'o', 'p', 'i', 'e', 's', 't', '\n',
        'd', 'r', 'o', 'o', 'p', 'i', 'n', 'g', '\n',
        'd', 'r', 'o', 'o', 'p', 'i', 'n', 'g', 'l', 'y', '\n',
        'd', 'r', 'o', 'o', 'p', 's', '\n',
        'd', 'r', 'o', 'o', 'p', 'y', '\n',
        'd', 'r', 'o', 'p', '\n',
        'd', 'r', 'o', 'p', 'l', 'e', 't', '\n',
        'd', 'r', 'o', 'p', 'l', 'e', 't', 's', '\n',
        'd', 'r', 'o', 'p', 'o', 'u', 't', '\n',
        'd', 'r', 'o', 'p', 'o', 'u', 't', 's', '\n',
        'd', 'r', 'o', 'p', 'p', 'e', 'd', '\n',
        'd', 'r', 'o', 'p', 'p', 'e', 'r', '\n',
        'd', 'r', 'o', 'p', 'p', 'i', 'n', 'g', '\n',
        'd', 'r', 'o', 'p', 'p', 'i', 'n', 'g', 's', '\n',
        'd', 'r', 'o', 'p', 's', '\n',
        'd', 'r', 'o', 'p', 's', 'y', '\n',
        'd', 'r', 'o', 's', 's', '\n',
        'd', 'r', 'o', 'u', 'g', 'h', 't', '\n',
        'd', 'r', 'o', 'u', 'g', 'h', 't', 's', '\n',
        'd', 'r', 'o', 'v', 'e', '\n',
        'd', 'r', 'o', 'v', 'e', 'r', '\n',
        'd', 'r', 'o', 'v', 'e', 'r', 's', '\n',
        'd', 'r', 'o', 'v', 'e', 's', '\n',
        'd', 'r', 'o', 'v', 'i', 'n', 'g', '\n',
        'd', 'r', 'o', 'w', 'n', '\n',
        'd', 'r', 'o', 'w', 'n', 'e', 'd', '\n',
        'd', 'r', 'o', 'w', 'n', 'i', 'n', 'g', '\n',
        'd', 'r', 'o', 'w', 'n', 'i', 'n', 'g', 's', '\n',
        'd', 'r', 'o', 'w', 'n', 's', '\n',
        'd', 'r', 'o', 'w', 's', 'e', '\n',
        'd', 'r', 'o', 'w', 's', 'e', 'd', '\n',
        'd', 'r', 'o', 'w', 's', 'e', 's', '\n',
        'd', 'r', 'o', 'w', 's', 'i', 'e', 'r', '\n',
        'd', 'r', 'o', 'w', 's', 'i', 'e', 's', 't', '\n',
        'd', 'r', 'o', 'w', 's', 'i', 'l', 'y', '\n',
        'd', 'r', 'o', 'w', 's', 'i', 'n', 'e', 's', 's', '\n',
        'd', 'r', 'o', 'w', 's', 'y', '\n',
        'd', 'r', 'u', 'b', '\n',
        'd', 'r', 'u', 'b', 'b', 'e', 'd', '\n',
        'd', 'r', 'u', 'b', 'b', 'i', 'n', 'g', '\n',
        'd', 'r', 'u', 'd', 'g', 'e', '\n',
        'd', 'r', 'u', 'd', 'g', 'e', 'r', 'y', '\n',
        'd', 'r', 'u', 'd', 'g', 'e', 's', '\n',
        'd', 'r', 'u', 'g', '\n',
        'd', 'r', 'u', 'g', 'g', 'e', 'd', '\n',
        'd', 'r', 'u', 'g', 'g', 'i', 'n', 'g', '\n',
        'd', 'r', 'u', 'g', 'g', 'i', 's', 't', '\n',
        'd', 'r', 'u', 'g', 's', '\n',
        'd', 'r', 'u', 'i', 'd', '\n',
        'd', 'r', 'u', 'i', 'd', 's', '\n',
        'd', 'r', 'u', 'm', '\n',
        'd', 'r', 'u', 'm', 'b', 'e', 'a', 't', '\n',
        'd', 'r', 'u', 'm', 'b', 'e', 'a', 't', 's', '\n',
        'd', 'r', 'u', 'm', 'm', 'e', 'd', '\n',
        'd', 'r', 'u', 'm', 'm', 'e', 'r', '\n',
        'd', 'r', 'u', 'm', 'm', 'e', 'r', 's', '\n',
        'd', 'r', 'u', 'm', 'm', 'i', 'n', 'g', '\n',
        'd', 'r', 'u', 'm', 's', '\n',
        'd', 'r', 'u', 'm', 's', 't', 'i', 'c', 'k', 's', '\n',
        'd', 'r', 'u', 'n', 'k', '\n',
        'd', 'r', 'u', 'n', 'k', 'a', 'r', 'd', '\n',
        'd', 'r', 'u', 'n', 'k', 'a', 'r', 'd', 's', '\n',
        'd', 'r', 'u', 'n', 'k', 'e', 'n', '\n',
        'd', 'r', 'u', 'n', 'k', 'e', 'n', 'l', 'y', '\n',
        'd', 'r', 'u', 'n', 'k', 'e', 'n', 'n', 'e', 's', 's', '\n',
        'd', 'r', 'u', 'n', 'k', 'e', 'r', '\n',
        'd', 'r', 'u', 'n', 'k', 's', '\n',
        'd', 'r', 'y', '\n',
        'd', 'r', 'y', 'c', 'l', 'e', 'a', 'n', 'e', 'd', '\n',
        'd', 'r', 'y', 'c', 'l', 'e', 'a', 'n', 'i', 'n', 'g', '\n',
        'd', 'r', 'y', 'e', 'r', '\n',
        'd', 'r', 'y', 'e', 'r', 's', '\n',
        'd', 'r', 'y', 'e', 'y', 'e', 'd', '\n',
        'd', 'r', 'y', 'i', 'n', 'g', '\n',
        'd', 'r', 'y', 'i', 's', 'h', '\n',
        'd', 'r', 'y', 'l', 'y', '\n',
        'd', 'r', 'y', 'n', 'e', 's', 's', '\n',
        'd', 'r', 'y', 's', 't', 'o', 'n', 'e', '\n',
        'd', 'u', 'a', 'l', '\n',
        'd', 'u', 'a', 'l', 'i', 's', 'm', '\n',
        'd', 'u', 'a', 'l', 'i', 's', 'm', 's', '\n',
        'd', 'u', 'a', 'l', 'i', 's', 't', '\n',
        'd', 'u', 'a', 'l', 'i', 's', 't', 'i', 'c', '\n',
        'd', 'u', 'a', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'd', 'u', 'a', 'l', 'i', 't', 'y', '\n',
        'd', 'u', 'a', 'l', 'l', 'y', '\n',
        'd', 'u', 'a', 'l', 's', '\n',
        'd', 'u', 'b', '\n',
        'd', 'u', 'b', 'b', 'e', 'd', '\n',
        'd', 'u', 'b', 'b', 'i', 'n', 'g', '\n',
        'd', 'u', 'b', 'i', 'o', 'u', 's', '\n',
        'd', 'u', 'b', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'd', 'u', 'b', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'd', 'u', 'b', 'l', 'i', 'n', '\n',
        'd', 'u', 'b', 's', '\n',
        'd', 'u', 'c', 'e', '\n',
        'd', 'u', 'c', 'h', 'e', 's', 's', '\n',
        'd', 'u', 'c', 'h', 'e', 's', 's', 'e', 's', '\n',
        'd', 'u', 'c', 'h', 'i', 'e', 's', '\n',
        'd', 'u', 'c', 'h', 'y', '\n',
        'd', 'u', 'c', 'k', '\n',
        'd', 'u', 'c', 'k', 'b', 'i', 'l', 'l', '\n',
        'd', 'u', 'c', 'k', 'b', 'i', 'l', 'l', 'e', 'd', '\n',
        'd', 'u', 'c', 'k', 'b', 'o', 'a', 'r', 'd', 's', '\n',
        'd', 'u', 'c', 'k', 'e', 'd', '\n',
        'd', 'u', 'c', 'k', 'i', 'n', 'g', '\n',
        'd', 'u', 'c', 'k', 'i', 'n', 'g', 's', '\n',
        'd', 'u', 'c', 'k', 'l', 'i', 'n', 'g', '\n',
        'd', 'u', 'c', 'k', 'l', 'i', 'n', 'g', 's', '\n',
        'd', 'u', 'c', 'k', 'p', 'o', 'n', 'd', '\n',
        'd', 'u', 'c', 'k', 's', '\n',
        'd', 'u', 'c', 't', '\n',
        'd', 'u', 'c', 't', 'e', 'd', '\n',
        'd', 'u', 'c', 't', 'i', 'l', 'e', '\n',
        'd', 'u', 'c', 't', 'i', 'n', 'g', '\n',
        'd', 'u', 'c', 't', 's', '\n',
        'd', 'u', 'd', '\n',
        'd', 'u', 'd', 'e', '\n',
        'd', 'u', 'd', 'e', 's', '\n',
        'd', 'u', 'd', 'g', 'e', 'o', 'n', '\n',
        'd', 'u', 'd', 's', '\n',
        'd', 'u', 'e', '\n',
        'd', 'u', 'e', 'l', '\n',
        'd', 'u', 'e', 'l', 'l', 'e', 'd', '\n',
        'd', 'u', 'e', 'l', 'l', 'e', 'r', '\n',
        'd', 'u', 'e', 'l', 'l', 'e', 'r', 's', '\n',
        'd', 'u', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'd', 'u', 'e', 'l', 'l', 'i', 's', 't', '\n',
        'd', 'u', 'e', 'l', 's', '\n',
        'd', 'u', 'e', 's', '\n',
        'd', 'u', 'e', 't', '\n',
        'd', 'u', 'e', 't', 's', '\n',
        'd', 'u', 'f', 'f', '\n',
        'd', 'u', 'f', 'f', 'e', 'l', '\n',
        'd', 'u', 'g', '\n',
        'd', 'u', 'g', 'o', 'u', 't', '\n',
        'd', 'u', 'g', 'o', 'u', 't', 's', '\n',
        'd', 'u', 'i', 'k', 'e', 'r', '\n',
        'd', 'u', 'k', 'e', '\n',
        'd', 'u', 'k', 'e', 'd', 'o', 'm', '\n',
        'd', 'u', 'k', 'e', 'd', 'o', 'm', 's', '\n',
        'd', 'u', 'k', 'e', 's', '\n',
        'd', 'u', 'l', 'c', 'e', 't', '\n',
        'd', 'u', 'l', 'c', 'i', 'm', 'e', 'r', '\n',
        'd', 'u', 'l', 'l', '\n',
        'd', 'u', 'l', 'l', 'a', 'r', 'd', '\n',
        'd', 'u', 'l', 'l', 'a', 'r', 'd', 's', '\n',
        'd', 'u', 'l', 'l', 'e', 'd', '\n',
        'd', 'u', 'l', 'l', 'e', 'r', '\n',
        'd', 'u', 'l', 'l', 'e', 's', 't', '\n',
        'd', 'u', 'l', 'l', 'i', 'n', 'g', '\n',
        'd', 'u', 'l', 'l', 'n', 'e', 's', 's', '\n',
        'd', 'u', 'l', 'l', 's', '\n',
        'd', 'u', 'l', 'l', 'y', '\n',
        'd', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'd', 'u', 'l', 'y', '\n',
        'd', 'u', 'm', 'b', '\n',
        'd', 'u', 'm', 'b', 'b', 'e', 'l', 'l', '\n',
        'd', 'u', 'm', 'b', 'e', 'r', '\n',
        'd', 'u', 'm', 'b', 'e', 's', 't', '\n',
        'd', 'u', 'm', 'b', 'f', 'o', 'u', 'n', 'd', '\n',
        'd', 'u', 'm', 'b', 'f', 'o', 'u', 'n', 'd', 'e', 'd', '\n',
        'd', 'u', 'm', 'b', 'f', 'o', 'u', 'n', 'd', 'i', 'n', 'g', '\n',
        'd', 'u', 'm', 'b', 'f', 'o', 'u', 'n', 'd', 's', '\n',
        'd', 'u', 'm', 'b', 'l', 'y', '\n',
        'd', 'u', 'm', 'b', 'n', 'e', 's', 's', '\n',
        'd', 'u', 'm', 'b', 's', 't', 'r', 'u', 'c', 'k', '\n',
        'd', 'u', 'm', 'f', 'o', 'u', 'n', 'd', '\n',
        'd', 'u', 'm', 'f', 'o', 'u', 'n', 'd', 'e', 'd', '\n',
        'd', 'u', 'm', 'f', 'o', 'u', 'n', 'd', 'i', 'n', 'g', '\n',
        'd', 'u', 'm', 'f', 'o', 'u', 'n', 'd', 's', '\n',
        'd', 'u', 'm', 'm', 'i', 'e', 'd', '\n',
        'd', 'u', 'm', 'm', 'i', 'e', 's', '\n',
        'd', 'u', 'm', 'm', 'y', '\n',
        'd', 'u', 'm', 'p', '\n',
        'd', 'u', 'm', 'p', 'e', 'd', '\n',
        'd', 'u', 'm', 'p', 'e', 'r', '\n',
        'd', 'u', 'm', 'p', 'i', 'n', 'g', '\n',
        'd', 'u', 'm', 'p', 'l', 'i', 'n', 'g', '\n',
        'd', 'u', 'm', 'p', 'l', 'i', 'n', 'g', 's', '\n',
        'd', 'u', 'm', 'p', 's', '\n',
        'd', 'u', 'm', 'p', 'y', '\n',
        'd', 'u', 'n', '\n',
        'd', 'u', 'n', 'c', 'e', '\n',
        'd', 'u', 'n', 'c', 'e', 's', '\n',
        'd', 'u', 'n', 'e', '\n',
        'd', 'u', 'n', 'e', 's', '\n',
        'd', 'u', 'n', 'g', '\n',
        'd', 'u', 'n', 'g', 'a', 'r', 'e', 'e', 's', '\n',
        'd', 'u', 'n', 'g', 'b', 'e', 'e', 't', 'l', 'e', '\n',
        'd', 'u', 'n', 'g', 'e', 'o', 'n', '\n',
        'd', 'u', 'n', 'g', 'e', 'o', 'n', 's', '\n',
        'd', 'u', 'n', 'g', 'h', 'i', 'l', 'l', '\n',
        'd', 'u', 'n', 'k', 'e', 'd', '\n',
        'd', 'u', 'n', 'k', 'i', 'n', 'g', '\n',
        'd', 'u', 'n', 'k', 'i', 'r', 'k', '\n',
        'd', 'u', 'o', '\n',
        'd', 'u', 'o', 'd', 'e', 'n', 'a', 'l', '\n',
        'd', 'u', 'o', 'd', 'e', 'n', 'u', 'm', '\n',
        'd', 'u', 'o', 'l', 'o', 'g', 'u', 'e', '\n',
        'd', 'u', 'o', 'm', 'o', '\n',
        'd', 'u', 'o', 'p', 'o', 'l', 'y', '\n',
        'd', 'u', 'p', 'e', '\n',
        'd', 'u', 'p', 'e', 'd', '\n',
        'd', 'u', 'p', 'e', 's', '\n',
        'd', 'u', 'p', 'l', 'e', 'x', '\n',
        'd', 'u', 'p', 'l', 'i', 'c', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'd', 'u', 'p', 'l', 'i', 'c', 'a', 't', 'e', '\n',
        'd', 'u', 'p', 'l', 'i', 'c', 'a', 't', 'e', 'd', '\n',
        'd', 'u', 'p', 'l', 'i', 'c', 'a', 't', 'e', 's', '\n',
        'd', 'u', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'd', 'u', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'u', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'u', 'p', 'l', 'i', 'c', 'a', 't', 'o', 'r', '\n',
        'd', 'u', 'p', 'l', 'i', 'c', 'a', 't', 'o', 'r', 's', '\n',
        'd', 'u', 'p', 'l', 'i', 'c', 'i', 't', 'i', 'e', 's', '\n',
        'd', 'u', 'p', 'l', 'i', 'c', 'i', 't', 'o', 'u', 's', '\n',
        'd', 'u', 'p', 'l', 'i', 'c', 'i', 't', 'y', '\n',
        'd', 'u', 'r', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'd', 'u', 'r', 'a', 'b', 'l', 'e', '\n',
        'd', 'u', 'r', 'a', 'b', 'l', 'e', 's', '\n',
        'd', 'u', 'r', 'a', 'n', 'c', 'e', '\n',
        'd', 'u', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'd', 'u', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'u', 'r', 'b', 'a', 'n', '\n',
        'd', 'u', 'r', 'e', 's', 's', '\n',
        'd', 'u', 'r', 'i', 'n', 'g', '\n',
        'd', 'u', 's', 'k', '\n',
        'd', 'u', 's', 'k', 'i', 'e', 'r', '\n',
        'd', 'u', 's', 'k', 'y', '\n',
        'd', 'u', 's', 't', '\n',
        'd', 'u', 's', 't', 'b', 'i', 'n', '\n',
        'd', 'u', 's', 't', 'b', 'i', 'n', 's', '\n',
        'd', 'u', 's', 't', 'c', 'a', 'r', 't', '\n',
        'd', 'u', 's', 't', 'e', 'd', '\n',
        'd', 'u', 's', 't', 'e', 'r', '\n',
        'd', 'u', 's', 't', 'e', 'r', 's', '\n',
        'd', 'u', 's', 't', 'i', 'e', 'r', '\n',
        'd', 'u', 's', 't', 'i', 'l', 'y', '\n',
        'd', 'u', 's', 't', 'i', 'n', 'g', '\n',
        'd', 'u', 's', 't', 'm', 'a', 'n', '\n',
        'd', 'u', 's', 't', 'm', 'e', 'n', '\n',
        'd', 'u', 's', 't', 'p', 'a', 'n', '\n',
        'd', 'u', 's', 't', 's', '\n',
        'd', 'u', 's', 't', 'y', '\n',
        'd', 'u', 't', 'c', 'h', '\n',
        'd', 'u', 't', 'c', 'h', 'm', 'a', 'n', '\n',
        'd', 'u', 't', 'c', 'h', 'm', 'e', 'n', '\n',
        'd', 'u', 't', 'i', 'e', 's', '\n',
        'd', 'u', 't', 'i', 'f', 'u', 'l', '\n',
        'd', 'u', 't', 'i', 'f', 'u', 'l', 'l', 'y', '\n',
        'd', 'u', 't', 'i', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'd', 'u', 't', 'y', '\n',
        'd', 'u', 't', 'y', 'f', 'r', 'e', 'e', '\n',
        'd', 'u', 'v', 'e', 't', '\n',
        'd', 'u', 'v', 'e', 't', 's', '\n',
        'd', 'u', 'x', '\n',
        'd', 'w', 'a', 'r', 'f', '\n',
        'd', 'w', 'a', 'r', 'f', 'e', 'd', '\n',
        'd', 'w', 'a', 'r', 'f', 'i', 'n', 'g', '\n',
        'd', 'w', 'a', 'r', 'f', 'i', 's', 'h', '\n',
        'd', 'w', 'a', 'r', 'f', 's', '\n',
        'd', 'w', 'a', 'r', 'v', 'e', 's', '\n',
        'd', 'w', 'e', 'l', 'l', '\n',
        'd', 'w', 'e', 'l', 'l', 'e', 'd', '\n',
        'd', 'w', 'e', 'l', 'l', 'e', 'r', '\n',
        'd', 'w', 'e', 'l', 'l', 'e', 'r', 's', '\n',
        'd', 'w', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'd', 'w', 'e', 'l', 'l', 'i', 'n', 'g', 's', '\n',
        'd', 'w', 'e', 'l', 'l', 's', '\n',
        'd', 'w', 'e', 'l', 't', '\n',
        'd', 'w', 'i', 'n', 'd', 'l', 'e', '\n',
        'd', 'w', 'i', 'n', 'd', 'l', 'e', 'd', '\n',
        'd', 'w', 'i', 'n', 'd', 'l', 'e', 's', '\n',
        'd', 'w', 'i', 'n', 'd', 'l', 'i', 'n', 'g', '\n',
        'd', 'y', 'a', 'd', '\n',
        'd', 'y', 'a', 'd', 'i', 'c', '\n',
        'd', 'y', 'e', '\n',
        'd', 'y', 'e', 'd', '\n',
        'd', 'y', 'e', 'i', 'n', 'g', '\n',
        'd', 'y', 'e', 'i', 'n', 'g', 's', '\n',
        'd', 'y', 'e', 'r', '\n',
        'd', 'y', 'e', 'r', 's', '\n',
        'd', 'y', 'e', 's', '\n',
        'd', 'y', 'e', 's', 't', 'u', 'f', 'f', '\n',
        'd', 'y', 'e', 's', 't', 'u', 'f', 'f', 's', '\n',
        'd', 'y', 'i', 'n', 'g', '\n',
        'd', 'y', 'k', 'e', '\n',
        'd', 'y', 'k', 'e', 's', '\n',
        'd', 'y', 'n', 'a', 'm', 'i', 'c', '\n',
        'd', 'y', 'n', 'a', 'm', 'i', 'c', 'a', 'l', '\n',
        'd', 'y', 'n', 'a', 'm', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'd', 'y', 'n', 'a', 'm', 'i', 'c', 's', '\n',
        'd', 'y', 'n', 'a', 'm', 'i', 's', 'm', '\n',
        'd', 'y', 'n', 'a', 'm', 'i', 't', 'e', '\n',
        'd', 'y', 'n', 'a', 'm', 'i', 't', 'e', 'd', '\n',
        'd', 'y', 'n', 'a', 'm', 'o', '\n',
        'd', 'y', 'n', 'a', 's', 't', '\n',
        'd', 'y', 'n', 'a', 's', 't', 'i', 'c', '\n',
        'd', 'y', 'n', 'a', 's', 't', 'i', 'e', 's', '\n',
        'd', 'y', 'n', 'a', 's', 't', 's', '\n',
        'd', 'y', 'n', 'a', 's', 't', 'y', '\n',
        'd', 'y', 'n', 'e', '\n',
        'd', 'y', 's', 'e', 'n', 't', 'e', 'r', 'y', '\n',
        'd', 'y', 's', 'f', 'u', 'n', 'c', 't', 'i', 'o', 'n', '\n',
        'd', 'y', 's', 'f', 'u', 'n', 'c', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'd', 'y', 's', 'f', 'u', 'n', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'd', 'y', 's', 'l', 'e', 'x', 'i', 'a', '\n',
        'd', 'y', 's', 'l', 'e', 'x', 'i', 'c', '\n',
        'd', 'y', 's', 'l', 'e', 'x', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'd', 'y', 's', 'l', 'e', 'x', 'i', 'c', 's', '\n',
        'd', 'y', 's', 'p', 'e', 'p', 's', 'i', 'a', '\n',
        'd', 'y', 's', 'p', 'e', 'p', 't', 'i', 'c', '\n',
        'd', 'y', 's', 't', 'r', 'o', 'p', 'h', 'y', '\n',
        'e', 'a', 'c', 'h', '\n',
        'e', 'a', 'g', 'e', 'r', '\n',
        'e', 'a', 'g', 'e', 'r', 'l', 'y', '\n',
        'e', 'a', 'g', 'e', 'r', 'n', 'e', 's', 's', '\n',
        'e', 'a', 'g', 'l', 'e', '\n',
        'e', 'a', 'g', 'l', 'e', 's', '\n',
        'e', 'a', 'g', 'l', 'e', 't', '\n',
        'e', 'a', 'g', 'l', 'e', 't', 's', '\n',
        'e', 'a', 'r', '\n',
        'e', 'a', 'r', 'a', 'c', 'h', 'e', '\n',
        'e', 'a', 'r', 'a', 'c', 'h', 'e', 's', '\n',
        'e', 'a', 'r', 'd', 'r', 'o', 'p', '\n',
        'e', 'a', 'r', 'd', 'r', 'o', 'p', 's', '\n',
        'e', 'a', 'r', 'd', 'r', 'u', 'm', '\n',
        'e', 'a', 'r', 'd', 'r', 'u', 'm', 's', '\n',
        'e', 'a', 'r', 'e', 'd', '\n',
        'e', 'a', 'r', 'f', 'u', 'l', '\n',
        'e', 'a', 'r', 'h', 'o', 'l', 'e', 's', '\n',
        'e', 'a', 'r', 'l', '\n',
        'e', 'a', 'r', 'l', 'd', 'o', 'm', '\n',
        'e', 'a', 'r', 'l', 'd', 'o', 'm', 's', '\n',
        'e', 'a', 'r', 'l', 'i', 'e', 'r', '\n',
        'e', 'a', 'r', 'l', 'i', 'e', 's', 't', '\n',
        'e', 'a', 'r', 'l', 'o', 'b', 'e', '\n',
        'e', 'a', 'r', 'l', 'o', 'b', 'e', 's', '\n',
        'e', 'a', 'r', 'l', 's', '\n',
        'e', 'a', 'r', 'l', 'y', '\n',
        'e', 'a', 'r', 'm', 'a', 'r', 'k', '\n',
        'e', 'a', 'r', 'm', 'a', 'r', 'k', 'e', 'd', '\n',
        'e', 'a', 'r', 'm', 'a', 'r', 'k', 'i', 'n', 'g', '\n',
        'e', 'a', 'r', 'n', '\n',
        'e', 'a', 'r', 'n', 'e', 'd', '\n',
        'e', 'a', 'r', 'n', 'e', 'r', '\n',
        'e', 'a', 'r', 'n', 'e', 'r', 's', '\n',
        'e', 'a', 'r', 'n', 'e', 's', 't', '\n',
        'e', 'a', 'r', 'n', 'e', 's', 't', 'l', 'y', '\n',
        'e', 'a', 'r', 'n', 'e', 's', 't', 'n', 'e', 's', 's', '\n',
        'e', 'a', 'r', 'n', 'i', 'n', 'g', '\n',
        'e', 'a', 'r', 'n', 'i', 'n', 'g', 's', '\n',
        'e', 'a', 'r', 'n', 's', '\n',
        'e', 'a', 'r', 'p', 'h', 'o', 'n', 'e', '\n',
        'e', 'a', 'r', 'p', 'h', 'o', 'n', 'e', 's', '\n',
        'e', 'a', 'r', 'p', 'i', 'e', 'c', 'e', '\n',
        'e', 'a', 'r', 'p', 'i', 'e', 'c', 'e', 's', '\n',
        'e', 'a', 'r', 'p', 'l', 'u', 'g', '\n',
        'e', 'a', 'r', 'p', 'l', 'u', 'g', 's', '\n',
        'e', 'a', 'r', 'r', 'i', 'n', 'g', '\n',
        'e', 'a', 'r', 'r', 'i', 'n', 'g', 's', '\n',
        'e', 'a', 'r', 's', '\n',
        'e', 'a', 'r', 's', 'h', 'o', 't', '\n',
        'e', 'a', 'r', 's', 'p', 'l', 'i', 't', 't', 'i', 'n', 'g', '\n',
        'e', 'a', 'r', 't', 'h', '\n',
        'e', 'a', 'r', 't', 'h', 'b', 'o', 'u', 'n', 'd', '\n',
        'e', 'a', 'r', 't', 'h', 'e', 'd', '\n',
        'e', 'a', 'r', 't', 'h', 'e', 'n', '\n',
        'e', 'a', 'r', 't', 'h', 'e', 'n', 'w', 'a', 'r', 'e', '\n',
        'e', 'a', 'r', 't', 'h', 'i', 'n', 'e', 's', 's', '\n',
        'e', 'a', 'r', 't', 'h', 'i', 'n', 'g', '\n',
        'e', 'a', 'r', 't', 'h', 'l', 'i', 'n', 'g', '\n',
        'e', 'a', 'r', 't', 'h', 'l', 'i', 'n', 'g', 's', '\n',
        'e', 'a', 'r', 't', 'h', 'l', 'y', '\n',
        'e', 'a', 'r', 't', 'h', 'q', 'u', 'a', 'k', 'e', '\n',
        'e', 'a', 'r', 't', 'h', 'q', 'u', 'a', 'k', 'e', 's', '\n',
        'e', 'a', 'r', 't', 'h', 's', '\n',
        'e', 'a', 'r', 't', 'h', 's', 'h', 'a', 'k', 'i', 'n', 'g', '\n',
        'e', 'a', 'r', 't', 'h', 's', 'h', 'a', 't', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'e', 'a', 'r', 't', 'h', 'w', 'a', 'r', 'd', 's', '\n',
        'e', 'a', 'r', 't', 'h', 'w', 'o', 'r', 'k', '\n',
        'e', 'a', 'r', 't', 'h', 'w', 'o', 'r', 'k', 's', '\n',
        'e', 'a', 'r', 't', 'h', 'w', 'o', 'r', 'm', '\n',
        'e', 'a', 'r', 't', 'h', 'w', 'o', 'r', 'm', 's', '\n',
        'e', 'a', 'r', 't', 'h', 'y', '\n',
        'e', 'a', 'r', 'w', 'a', 'x', '\n',
        'e', 'a', 'r', 'w', 'i', 'g', '\n',
        'e', 'a', 'r', 'w', 'i', 'g', 's', '\n',
        'e', 'a', 's', 'e', '\n',
        'e', 'a', 's', 'e', 'd', '\n',
        'e', 'a', 's', 'e', 'l', '\n',
        'e', 'a', 's', 'e', 'l', 's', '\n',
        'e', 'a', 's', 'e', 'm', 'e', 'n', 't', '\n',
        'e', 'a', 's', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'e', 'a', 's', 'e', 's', '\n',
        'e', 'a', 's', 'i', 'e', 'r', '\n',
        'e', 'a', 's', 'i', 'e', 's', 't', '\n',
        'e', 'a', 's', 'i', 'l', 'y', '\n',
        'e', 'a', 's', 'i', 'n', 'e', 's', 's', '\n',
        'e', 'a', 's', 'i', 'n', 'g', '\n',
        'e', 'a', 's', 't', '\n',
        'e', 'a', 's', 't', 'b', 'o', 'u', 'n', 'd', '\n',
        'e', 'a', 's', 't', 'e', 'r', '\n',
        'e', 'a', 's', 't', 'e', 'r', 'l', 'y', '\n',
        'e', 'a', 's', 't', 'e', 'r', 'n', '\n',
        'e', 'a', 's', 't', 'e', 'r', 'n', 'e', 'r', 's', '\n',
        'e', 'a', 's', 't', 'e', 'r', 'n', 'm', 'o', 's', 't', '\n',
        'e', 'a', 's', 't', 'i', 'n', 'g', '\n',
        'e', 'a', 's', 't', 'w', 'a', 'r', 'd', '\n',
        'e', 'a', 's', 't', 'w', 'a', 'r', 'd', 's', '\n',
        'e', 'a', 's', 'y', '\n',
        'e', 'a', 's', 'y', 'g', 'o', 'i', 'n', 'g', '\n',
        'e', 'a', 't', '\n',
        'e', 'a', 't', 'a', 'b', 'l', 'e', '\n',
        'e', 'a', 't', 'a', 'g', 'e', '\n',
        'e', 'a', 't', 'e', 'n', '\n',
        'e', 'a', 't', 'e', 'r', '\n',
        'e', 'a', 't', 'e', 'r', 's', '\n',
        'e', 'a', 't', 'e', 'r', 'y', '\n',
        'e', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'a', 't', 'i', 'n', 'g', 's', '\n',
        'e', 'a', 't', 's', '\n',
        'e', 'a', 'v', 'e', 's', '\n',
        'e', 'a', 'v', 'e', 's', 'd', 'r', 'o', 'p', '\n',
        'e', 'a', 'v', 'e', 's', 'd', 'r', 'o', 'p', 'p', 'e', 'd', '\n',
        'e', 'a', 'v', 'e', 's', 'd', 'r', 'o', 'p', 'p', 'e', 'r', '\n',
        'e', 'a', 'v', 'e', 's', 'd', 'r', 'o', 'p', 'p', 'e', 'r', 's', '\n',
        'e', 'a', 'v', 'e', 's', 'd', 'r', 'o', 'p', 'p', 'i', 'n', 'g', '\n',
        'e', 'a', 'v', 'e', 's', 'd', 'r', 'o', 'p', 's', '\n',
        'e', 'b', 'b', '\n',
        'e', 'b', 'b', 'e', 'd', '\n',
        'e', 'b', 'b', 'i', 'n', 'g', '\n',
        'e', 'b', 'b', 's', '\n',
        'e', 'b', 'b', 't', 'i', 'd', 'e', '\n',
        'e', 'b', 'o', 'n', 'y', '\n',
        'e', 'b', 'u', 'l', 'l', 'i', 'e', 'n', 'c', 'e', '\n',
        'e', 'b', 'u', 'l', 'l', 'i', 'e', 'n', 't', '\n',
        'e', 'c', 'c', 'e', 'n', 't', 'r', 'i', 'c', '\n',
        'e', 'c', 'c', 'e', 'n', 't', 'r', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'e', 'c', 'c', 'e', 'n', 't', 'r', 'i', 'c', 'i', 't', 'i', 'e', 's', '\n',
        'e', 'c', 'c', 'e', 'n', 't', 'r', 'i', 'c', 'i', 't', 'y', '\n',
        'e', 'c', 'c', 'e', 'n', 't', 'r', 'i', 'c', 's', '\n',
        'e', 'c', 'c', 'l', 'e', 's', 'i', 'a', 's', 't', 'i', 'c', '\n',
        'e', 'c', 'c', 'l', 'e', 's', 'i', 'a', 's', 't', 'i', 'c', 'a', 'l', '\n',
        'e', 'c', 'c', 'l', 'e', 's', 'i', 'a', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'e', 'c', 'h', 'e', 'l', 'o', 'n', '\n',
        'e', 'c', 'h', 'e', 'l', 'o', 'n', 's', '\n',
        'e', 'c', 'h', 'i', 'd', 'n', 'a', '\n',
        'e', 'c', 'h', 'i', 'd', 'n', 'a', 's', '\n',
        'e', 'c', 'h', 'i', 'n', 'o', 'd', 'e', 'r', 'm', '\n',
        'e', 'c', 'h', 'i', 'n', 'o', 'd', 'e', 'r', 'm', 's', '\n',
        'e', 'c', 'h', 'o', '\n',
        'e', 'c', 'h', 'o', 'e', 'd', '\n',
        'e', 'c', 'h', 'o', 'i', 'c', '\n',
        'e', 'c', 'h', 'o', 'i', 'n', 'g', '\n',
        'e', 'c', 'l', 'a', 'i', 'r', '\n',
        'e', 'c', 'l', 'a', 'i', 'r', 's', '\n',
        'e', 'c', 'l', 'e', 'c', 't', 'i', 'c', '\n',
        'e', 'c', 'l', 'e', 'c', 't', 'i', 'c', 'i', 's', 'm', '\n',
        'e', 'c', 'l', 'i', 'p', 's', 'e', '\n',
        'e', 'c', 'l', 'i', 'p', 's', 'e', 'd', '\n',
        'e', 'c', 'l', 'i', 'p', 's', 'e', 's', '\n',
        'e', 'c', 'l', 'i', 'p', 's', 'i', 'n', 'g', '\n',
        'e', 'c', 'l', 'i', 'p', 't', 'i', 'c', '\n',
        'e', 'c', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'e', 'c', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'e', 'c', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'e', 'c', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'e', 'c', 'o', 'l', 'o', 'g', 'y', '\n',
        'e', 'c', 'o', 'n', 'o', 'm', 'e', 't', 'r', 'i', 'c', '\n',
        'e', 'c', 'o', 'n', 'o', 'm', 'e', 't', 'r', 'i', 'c', 's', '\n',
        'e', 'c', 'o', 'n', 'o', 'm', 'i', 'c', '\n',
        'e', 'c', 'o', 'n', 'o', 'm', 'i', 'c', 'a', 'l', '\n',
        'e', 'c', 'o', 'n', 'o', 'm', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'e', 'c', 'o', 'n', 'o', 'm', 'i', 'c', 's', '\n',
        'e', 'c', 'o', 'n', 'o', 'm', 'i', 'e', 's', '\n',
        'e', 'c', 'o', 'n', 'o', 'm', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'c', 'o', 'n', 'o', 'm', 'i', 's', 'e', '\n',
        'e', 'c', 'o', 'n', 'o', 'm', 'i', 's', 'e', 'd', '\n',
        'e', 'c', 'o', 'n', 'o', 'm', 'i', 's', 'e', 's', '\n',
        'e', 'c', 'o', 'n', 'o', 'm', 'i', 's', 'i', 'n', 'g', '\n',
        'e', 'c', 'o', 'n', 'o', 'm', 'i', 's', 't', '\n',
        'e', 'c', 'o', 'n', 'o', 'm', 'i', 's', 't', 's', '\n',
        'e', 'c', 'o', 'n', 'o', 'm', 'y', '\n',
        'e', 'c', 'o', 's', 'y', 's', 't', 'e', 'm', '\n',
        'e', 'c', 'o', 's', 'y', 's', 't', 'e', 'm', 's', '\n',
        'e', 'c', 's', 't', 'a', 's', 'i', 'e', 's', '\n',
        'e', 'c', 's', 't', 'a', 's', 'y', '\n',
        'e', 'c', 's', 't', 'a', 't', 'i', 'c', '\n',
        'e', 'c', 's', 't', 'a', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'e', 'c', 't', 'o', 'p', 'i', 'c', '\n',
        'e', 'c', 't', 'o', 'p', 'l', 'a', 's', 'm', '\n',
        'e', 'c', 'u', 'a', 'd', 'o', 'r', '\n',
        'e', 'c', 'u', 'm', 'e', 'n', 'i', 'c', 'a', 'l', '\n',
        'e', 'c', 'u', 'm', 'e', 'n', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'e', 'c', 'u', 'm', 'e', 'n', 'i', 's', 'm', '\n',
        'e', 'c', 'z', 'e', 'm', 'a', '\n',
        'e', 'd', 'd', 'i', 'e', 'd', '\n',
        'e', 'd', 'd', 'i', 'e', 's', '\n',
        'e', 'd', 'd', 'y', '\n',
        'e', 'd', 'd', 'y', 'i', 'n', 'g', '\n',
        'e', 'd', 'e', 'm', 'a', '\n',
        'e', 'd', 'e', 'n', '\n',
        'e', 'd', 'g', 'e', '\n',
        'e', 'd', 'g', 'e', 'd', '\n',
        'e', 'd', 'g', 'e', 'l', 'e', 's', 's', '\n',
        'e', 'd', 'g', 'e', 's', '\n',
        'e', 'd', 'g', 'e', 'w', 'a', 'y', 's', '\n',
        'e', 'd', 'g', 'e', 'w', 'i', 's', 'e', '\n',
        'e', 'd', 'g', 'i', 'e', 'r', '\n',
        'e', 'd', 'g', 'i', 'l', 'y', '\n',
        'e', 'd', 'g', 'i', 'n', 'e', 's', 's', '\n',
        'e', 'd', 'g', 'i', 'n', 'g', '\n',
        'e', 'd', 'g', 'i', 'n', 'g', 's', '\n',
        'e', 'd', 'g', 'y', '\n',
        'e', 'd', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'e', 'd', 'i', 'b', 'l', 'e', '\n',
        'e', 'd', 'i', 'b', 'l', 'e', 's', '\n',
        'e', 'd', 'i', 'c', 't', '\n',
        'e', 'd', 'i', 'c', 't', 's', '\n',
        'e', 'd', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'd', 'i', 'f', 'i', 'c', 'e', '\n',
        'e', 'd', 'i', 'f', 'i', 'c', 'e', 's', '\n',
        'e', 'd', 'i', 'f', 'i', 'e', 'd', '\n',
        'e', 'd', 'i', 'f', 'i', 'e', 's', '\n',
        'e', 'd', 'i', 'f', 'y', '\n',
        'e', 'd', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'e', 'd', 'i', 's', 'o', 'n', '\n',
        'e', 'd', 'i', 't', '\n',
        'e', 'd', 'i', 't', 'a', 'b', 'l', 'e', '\n',
        'e', 'd', 'i', 't', 'e', 'd', '\n',
        'e', 'd', 'i', 't', 'i', 'n', 'g', '\n',
        'e', 'd', 'i', 't', 'i', 'o', 'n', '\n',
        'e', 'd', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'd', 'i', 't', 'o', 'r', '\n',
        'e', 'd', 'i', 't', 'o', 'r', 'i', 'a', 'l', '\n',
        'e', 'd', 'i', 't', 'o', 'r', 'i', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'e', 'd', 'i', 't', 'o', 'r', 'i', 'a', 'l', 'l', 'y', '\n',
        'e', 'd', 'i', 't', 'o', 'r', 'i', 'a', 'l', 's', '\n',
        'e', 'd', 'i', 't', 'o', 'r', 's', '\n',
        'e', 'd', 'i', 't', 'o', 'r', 's', 'h', 'i', 'p', '\n',
        'e', 'd', 'i', 't', 'o', 'r', 's', 'h', 'i', 'p', 's', '\n',
        'e', 'd', 'i', 't', 's', '\n',
        'e', 'd', 'u', 'c', 'a', 't', 'e', '\n',
        'e', 'd', 'u', 'c', 'a', 't', 'e', 'd', '\n',
        'e', 'd', 'u', 'c', 'a', 't', 'e', 's', '\n',
        'e', 'd', 'u', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'd', 'u', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'd', 'u', 'c', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'e', 'd', 'u', 'c', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 't', '\n',
        'e', 'd', 'u', 'c', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 't', 's', '\n',
        'e', 'd', 'u', 'c', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'e', 'd', 'u', 'c', 'a', 't', 'i', 'o', 'n', 'i', 's', 't', '\n',
        'e', 'd', 'u', 'c', 'a', 't', 'i', 'o', 'n', 'i', 's', 't', 's', '\n',
        'e', 'd', 'u', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'd', 'u', 'c', 'a', 't', 'i', 'v', 'e', '\n',
        'e', 'd', 'u', 'c', 'a', 't', 'o', 'r', '\n',
        'e', 'd', 'u', 'c', 'a', 't', 'o', 'r', 's', '\n',
        'e', 'd', 'u', 'c', 't', 'i', 'o', 'n', '\n',
        'e', 'e', 'l', '\n',
        'e', 'e', 'l', 's', '\n',
        'e', 'e', 'l', 'w', 'o', 'r', 'm', '\n',
        'e', 'e', 'l', 'w', 'o', 'r', 'm', 's', '\n',
        'e', 'e', 'r', 'i', 'e', '\n',
        'e', 'e', 'r', 'i', 'e', 'r', '\n',
        'e', 'e', 'r', 'i', 'e', 's', 't', '\n',
        'e', 'e', 'r', 'i', 'l', 'y', '\n',
        'e', 'e', 'r', 'i', 'n', 'e', 's', 's', '\n',
        'e', 'e', 'r', 'y', '\n',
        'e', 'f', 'f', 'a', 'c', 'e', '\n',
        'e', 'f', 'f', 'a', 'c', 'e', 'd', '\n',
        'e', 'f', 'f', 'a', 'c', 'i', 'n', 'g', '\n',
        'e', 'f', 'f', 'e', 'c', 't', '\n',
        'e', 'f', 'f', 'e', 'c', 't', 'e', 'd', '\n',
        'e', 'f', 'f', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'e', 'f', 'f', 'e', 'c', 't', 'i', 'v', 'e', '\n',
        'e', 'f', 'f', 'e', 'c', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'e', 'f', 'f', 'e', 'c', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'e', 'f', 'f', 'e', 'c', 't', 'o', 'r', '\n',
        'e', 'f', 'f', 'e', 'c', 't', 'o', 'r', 's', '\n',
        'e', 'f', 'f', 'e', 'c', 't', 's', '\n',
        'e', 'f', 'f', 'e', 'c', 't', 'u', 'a', 'l', '\n',
        'e', 'f', 'f', 'e', 'c', 't', 'u', 'a', 'l', 'l', 'y', '\n',
        'e', 'f', 'f', 'e', 'm', 'i', 'n', 'a', 'c', 'y', '\n',
        'e', 'f', 'f', 'e', 'm', 'i', 'n', 'a', 't', 'e', '\n',
        'e', 'f', 'f', 'e', 'r', 'e', 'n', 't', '\n',
        'e', 'f', 'f', 'e', 'r', 'v', 'e', 's', 'c', 'e', 'n', 'c', 'e', '\n',
        'e', 'f', 'f', 'e', 'r', 'v', 'e', 's', 'c', 'e', 'n', 't', '\n',
        'e', 'f', 'f', 'e', 't', 'e', '\n',
        'e', 'f', 'f', 'i', 'c', 'a', 'c', 'i', 'o', 'u', 's', '\n',
        'e', 'f', 'f', 'i', 'c', 'a', 'c', 'y', '\n',
        'e', 'f', 'f', 'i', 'c', 'i', 'e', 'n', 'c', 'i', 'e', 's', '\n',
        'e', 'f', 'f', 'i', 'c', 'i', 'e', 'n', 'c', 'y', '\n',
        'e', 'f', 'f', 'i', 'c', 'i', 'e', 'n', 't', '\n',
        'e', 'f', 'f', 'i', 'c', 'i', 'e', 'n', 't', 'l', 'y', '\n',
        'e', 'f', 'f', 'i', 'g', 'i', 'e', 's', '\n',
        'e', 'f', 'f', 'i', 'g', 'y', '\n',
        'e', 'f', 'f', 'l', 'u', 'e', 'n', 't', '\n',
        'e', 'f', 'f', 'l', 'u', 'e', 'n', 't', 's', '\n',
        'e', 'f', 'f', 'l', 'u', 'v', 'i', 'a', '\n',
        'e', 'f', 'f', 'l', 'u', 'x', 'i', 'o', 'n', '\n',
        'e', 'f', 'f', 'o', 'r', 't', '\n',
        'e', 'f', 'f', 'o', 'r', 't', 'l', 'e', 's', 's', '\n',
        'e', 'f', 'f', 'o', 'r', 't', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'e', 'f', 'f', 'o', 'r', 't', 's', '\n',
        'e', 'f', 'f', 'r', 'o', 'n', 't', 'e', 'r', 'y', '\n',
        'e', 'f', 'f', 'u', 'l', 'g', 'e', 'n', 'c', 'e', '\n',
        'e', 'f', 'f', 'u', 'l', 'g', 'e', 'n', 't', '\n',
        'e', 'f', 'f', 'u', 's', 'i', 'o', 'n', '\n',
        'e', 'f', 'f', 'u', 's', 'i', 'o', 'n', 's', '\n',
        'e', 'f', 'f', 'u', 's', 'i', 'v', 'e', '\n',
        'e', 'f', 'f', 'u', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'e', 'g', '\n',
        'e', 'g', 'a', 'l', 'i', 't', 'a', 'r', 'i', 'a', 'n', '\n',
        'e', 'g', 'a', 'l', 'i', 't', 'a', 'r', 'i', 'a', 'n', 'i', 's', 'm', '\n',
        'e', 'g', 'a', 'l', 'i', 't', 'a', 'r', 'i', 'a', 'n', 's', '\n',
        'e', 'g', 'g', '\n',
        'e', 'g', 'g', 'e', 'd', '\n',
        'e', 'g', 'g', 'h', 'e', 'a', 'd', 's', '\n',
        'e', 'g', 'g', 'i', 'n', 'g', '\n',
        'e', 'g', 'g', 's', '\n',
        'e', 'g', 'g', 's', 'h', 'e', 'l', 'l', '\n',
        'e', 'g', 'g', 's', 'h', 'e', 'l', 'l', 's', '\n',
        'e', 'g', 'o', '\n',
        'e', 'g', 'o', 'c', 'e', 'n', 't', 'r', 'i', 'c', '\n',
        'e', 'g', 'o', 'c', 'e', 'n', 't', 'r', 'i', 'c', 'i', 't', 'y', '\n',
        'e', 'g', 'o', 'i', 's', 'm', '\n',
        'e', 'g', 'o', 'i', 's', 't', '\n',
        'e', 'g', 'o', 'i', 's', 't', 'i', 'c', '\n',
        'e', 'g', 'o', 'i', 's', 't', 's', '\n',
        'e', 'g', 'o', 'm', 'a', 'n', 'i', 'a', '\n',
        'e', 'g', 'o', 'm', 'a', 'n', 'i', 'a', 'c', '\n',
        'e', 'g', 'o', 'm', 'a', 'n', 'i', 'a', 'c', 's', '\n',
        'e', 'g', 'o', 't', 'i', 's', 'm', '\n',
        'e', 'g', 'o', 't', 'i', 's', 't', '\n',
        'e', 'g', 'o', 't', 'i', 's', 't', 'i', 'c', '\n',
        'e', 'g', 'o', 't', 'i', 's', 't', 'i', 'c', 'a', 'l', '\n',
        'e', 'g', 'o', 't', 'i', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'e', 'g', 'o', 't', 'i', 's', 't', 's', '\n',
        'e', 'g', 'r', 'e', 'g', 'i', 'o', 'u', 's', '\n',
        'e', 'g', 'r', 'e', 's', 's', '\n',
        'e', 'g', 'r', 'e', 't', '\n',
        'e', 'g', 'r', 'e', 't', 's', '\n',
        'e', 'g', 'y', 'p', 't', '\n',
        'e', 'g', 'y', 'p', 't', 'i', 'a', 'n', '\n',
        'e', 'h', '\n',
        'e', 'i', 'd', 'e', 'r', '\n',
        'e', 'i', 'd', 'e', 'r', 'd', 'o', 'w', 'n', '\n',
        'e', 'i', 'd', 'e', 't', 'i', 'c', '\n',
        'e', 'i', 'g', 'e', 'n', 'f', 'u', 'n', 'c', 't', 'i', 'o', 'n', '\n',
        'e', 'i', 'g', 'e', 'n', 'f', 'u', 'n', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'i', 'g', 'e', 'n', 's', 't', 'a', 't', 'e', '\n',
        'e', 'i', 'g', 'e', 'n', 's', 't', 'a', 't', 'e', 's', '\n',
        'e', 'i', 'g', 'e', 'n', 'v', 'a', 'l', 'u', 'e', '\n',
        'e', 'i', 'g', 'e', 'n', 'v', 'a', 'l', 'u', 'e', 's', '\n',
        'e', 'i', 'g', 'h', 't', '\n',
        'e', 'i', 'g', 'h', 't', 'e', 'e', 'n', '\n',
        'e', 'i', 'g', 'h', 't', 'e', 'e', 'n', 't', 'h', '\n',
        'e', 'i', 'g', 'h', 't', 'f', 'o', 'l', 'd', '\n',
        'e', 'i', 'g', 'h', 't', 'h', '\n',
        'e', 'i', 'g', 'h', 't', 'i', 'e', 's', '\n',
        'e', 'i', 'g', 'h', 't', 'i', 'e', 't', 'h', '\n',
        'e', 'i', 'g', 'h', 't', 'p', 'e', 'n', 'c', 'e', '\n',
        'e', 'i', 'g', 'h', 't', 's', '\n',
        'e', 'i', 'g', 'h', 't', 'y', '\n',
        'e', 'i', 'n', 's', 't', 'e', 'i', 'n', '\n',
        'e', 'i', 'r', 'e', '\n',
        'e', 'i', 's', 't', 'e', 'd', 'd', 'f', 'o', 'd', '\n',
        'e', 'i', 't', 'h', 'e', 'r', '\n',
        'e', 'j', 'e', 'c', 't', '\n',
        'e', 'j', 'e', 'c', 't', 'e', 'd', '\n',
        'e', 'j', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'e', 'j', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'e', 'j', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'j', 'e', 'c', 't', 'o', 'r', '\n',
        'e', 'j', 'e', 'c', 't', 'o', 'r', 's', '\n',
        'e', 'j', 'e', 'c', 't', 's', '\n',
        'e', 'k', 'e', '\n',
        'e', 'k', 'e', 'd', '\n',
        'e', 'k', 'i', 'n', 'g', '\n',
        'e', 'l', 'a', 'b', 'o', 'r', 'a', 't', 'e', '\n',
        'e', 'l', 'a', 'b', 'o', 'r', 'a', 't', 'e', 'd', '\n',
        'e', 'l', 'a', 'b', 'o', 'r', 'a', 't', 'e', 'l', 'y', '\n',
        'e', 'l', 'a', 'b', 'o', 'r', 'a', 't', 'e', 'n', 'e', 's', 's', '\n',
        'e', 'l', 'a', 'b', 'o', 'r', 'a', 't', 'e', 's', '\n',
        'e', 'l', 'a', 'b', 'o', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'l', 'a', 'b', 'o', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'l', 'a', 'b', 'o', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'l', 'a', 'l', '\n',
        'e', 'l', 'a', 'n', '\n',
        'e', 'l', 'a', 'n', 'd', '\n',
        'e', 'l', 'a', 'n', 'd', 's', '\n',
        'e', 'l', 'a', 'p', 's', 'e', '\n',
        'e', 'l', 'a', 'p', 's', 'e', 'd', '\n',
        'e', 'l', 'a', 'p', 's', 'e', 's', '\n',
        'e', 'l', 'a', 'p', 's', 'i', 'n', 'g', '\n',
        'e', 'l', 'a', 's', 't', 'i', 'c', '\n',
        'e', 'l', 'a', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'e', 'l', 'a', 's', 't', 'i', 'c', 'a', 't', 'e', 'd', '\n',
        'e', 'l', 'a', 's', 't', 'i', 'c', 'i', 't', 'i', 'e', 's', '\n',
        'e', 'l', 'a', 's', 't', 'i', 'c', 'i', 't', 'y', '\n',
        'e', 'l', 'a', 's', 't', 'i', 'c', 's', '\n',
        'e', 'l', 'a', 's', 't', 'i', 'n', '\n',
        'e', 'l', 'a', 's', 't', 'o', 'd', 'y', 'n', 'a', 'm', 'i', 'c', 's', '\n',
        'e', 'l', 'a', 't', 'e', '\n',
        'e', 'l', 'a', 't', 'e', 'd', '\n',
        'e', 'l', 'a', 't', 'e', 's', '\n',
        'e', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'l', 'b', 'e', '\n',
        'e', 'l', 'b', 'o', 'w', '\n',
        'e', 'l', 'b', 'o', 'w', 'e', 'd', '\n',
        'e', 'l', 'b', 'o', 'w', 'i', 'n', 'g', '\n',
        'e', 'l', 'b', 'o', 'w', 's', '\n',
        'e', 'l', 'd', 'e', 'r', '\n',
        'e', 'l', 'd', 'e', 'r', 'b', 'e', 'r', 'r', 'i', 'e', 's', '\n',
        'e', 'l', 'd', 'e', 'r', 'b', 'e', 'r', 'r', 'y', '\n',
        'e', 'l', 'd', 'e', 'r', 'f', 'l', 'o', 'w', 'e', 'r', '\n',
        'e', 'l', 'd', 'e', 'r', 'l', 'y', '\n',
        'e', 'l', 'd', 'e', 'r', 's', '\n',
        'e', 'l', 'd', 'e', 's', 't', '\n',
        'e', 'l', 'd', 'o', 'r', 'a', 'd', 'o', '\n',
        'e', 'l', 'e', 'c', 't', '\n',
        'e', 'l', 'e', 'c', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'e', 'l', 'e', 'c', 't', 'a', 'b', 'l', 'e', '\n',
        'e', 'l', 'e', 'c', 't', 'e', 'd', '\n',
        'e', 'l', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'e', 'e', 'r', 'i', 'n', 'g', '\n',
        'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'l', 'e', 'c', 't', 'i', 'v', 'e', '\n',
        'e', 'l', 'e', 'c', 't', 'o', 'r', '\n',
        'e', 'l', 'e', 'c', 't', 'o', 'r', 'a', 'l', '\n',
        'e', 'l', 'e', 'c', 't', 'o', 'r', 'a', 'l', 'l', 'y', '\n',
        'e', 'l', 'e', 'c', 't', 'o', 'r', 'a', 't', 'e', '\n',
        'e', 'l', 'e', 'c', 't', 'o', 'r', 'a', 't', 'e', 's', '\n',
        'e', 'l', 'e', 'c', 't', 'o', 'r', 's', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'i', 'c', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'i', 'c', 'a', 'l', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'i', 'c', 'i', 'a', 'n', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'i', 'c', 'i', 'a', 'n', 's', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'i', 'c', 'i', 't', 'y', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'i', 'c', 's', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'i', 'f', 'i', 'e', 'd', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'i', 'f', 'y', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'c', 'a', 'r', 'd', 'i', 'o', 'g', 'r', 'a', 'm', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'c', 'a', 'r', 'd', 'i', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'c', 'h', 'e', 'm', 'i', 'c', 'a', 'l', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'c', 'h', 'e', 'm', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'c', 'u', 't', 'e', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'c', 'u', 't', 'e', 'd', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'c', 'u', 't', 'e', 's', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'c', 'u', 't', 'i', 'n', 'g', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'c', 'u', 't', 'i', 'o', 'n', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'd', 'e', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'd', 'e', 's', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'd', 'y', 'n', 'a', 'm', 'i', 'c', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'd', 'y', 'n', 'a', 'm', 'i', 'c', 's', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'e', 'n', 'c', 'e', 'p', 'h', 'a', 'l', 'o', 'g', 'r', 'a', 'm', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'l', 'u', 'm', 'i', 'n', 'e', 's', 'c', 'e', 'n', 't', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'l', 'y', 's', 'e', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'l', 'y', 's', 'e', 'd', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'l', 'y', 's', 'i', 'n', 'g', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'l', 'y', 's', 'i', 's', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'l', 'y', 't', 'e', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'l', 'y', 't', 'e', 's', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'l', 'y', 't', 'i', 'c', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'l', 'y', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'm', 'a', 'g', 'n', 'e', 't', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'm', 'a', 'g', 'n', 'e', 't', 'i', 'c', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'm', 'a', 'g', 'n', 'e', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'm', 'a', 'g', 'n', 'e', 't', 'i', 's', 'm', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'm', 'e', 'c', 'h', 'a', 'n', 'i', 'c', 'a', 'l', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'm', 'e', 'c', 'h', 'a', 'n', 'i', 'c', 's', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'm', 'o', 't', 'i', 'v', 'e', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'n', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'n', 'e', 'g', 'a', 't', 'i', 'v', 'e', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'n', 'i', 'c', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'n', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'n', 'i', 'c', 's', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'n', 's', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 'p', 'h', 'o', 'r', 'e', 's', 'i', 's', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 's', 't', 'a', 't', 'i', 'c', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 's', 't', 'a', 't', 'i', 'c', 's', '\n',
        'e', 'l', 'e', 'c', 't', 'r', 'o', 't', 'e', 'c', 'h', 'n', 'i', 'c', 'a', 'l', '\n',
        'e', 'l', 'e', 'c', 't', 's', '\n',
        'e', 'l', 'e', 'g', 'a', 'n', 'c', 'e', '\n',
        'e', 'l', 'e', 'g', 'a', 'n', 't', '\n',
        'e', 'l', 'e', 'g', 'a', 'n', 't', 'l', 'y', '\n',
        'e', 'l', 'e', 'g', 'i', 'a', 'c', '\n',
        'e', 'l', 'e', 'g', 'i', 'e', 's', '\n',
        'e', 'l', 'e', 'g', 'y', '\n',
        'e', 'l', 'e', 'm', 'e', 'n', 't', '\n',
        'e', 'l', 'e', 'm', 'e', 'n', 't', 'a', 'l', '\n',
        'e', 'l', 'e', 'm', 'e', 'n', 't', 'a', 'l', 'l', 'y', '\n',
        'e', 'l', 'e', 'm', 'e', 'n', 't', 'a', 'r', 'i', 'l', 'y', '\n',
        'e', 'l', 'e', 'm', 'e', 'n', 't', 'a', 'r', 'y', '\n',
        'e', 'l', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'e', 'l', 'e', 'p', 'h', 'a', 'n', 't', '\n',
        'e', 'l', 'e', 'p', 'h', 'a', 'n', 't', 'i', 'a', 's', 'i', 's', '\n',
        'e', 'l', 'e', 'p', 'h', 'a', 'n', 't', 'i', 'n', 'e', '\n',
        'e', 'l', 'e', 'p', 'h', 'a', 'n', 't', 's', '\n',
        'e', 'l', 'e', 'v', 'a', 't', 'e', '\n',
        'e', 'l', 'e', 'v', 'a', 't', 'e', 'd', '\n',
        'e', 'l', 'e', 'v', 'a', 't', 'e', 's', '\n',
        'e', 'l', 'e', 'v', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'l', 'e', 'v', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'l', 'e', 'v', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'l', 'e', 'v', 'a', 't', 'o', 'r', '\n',
        'e', 'l', 'e', 'v', 'a', 't', 'o', 'r', 's', '\n',
        'e', 'l', 'e', 'v', 'e', 'n', '\n',
        'e', 'l', 'e', 'v', 'e', 'n', 't', 'h', '\n',
        'e', 'l', 'f', '\n',
        'e', 'l', 'f', 'i', 'n', '\n',
        'e', 'l', 'f', 'l', 'i', 'k', 'e', '\n',
        'e', 'l', 'g', 'r', 'e', 'c', 'o', '\n',
        'e', 'l', 'i', 'c', 'i', 't', '\n',
        'e', 'l', 'i', 'c', 'i', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'l', 'i', 'c', 'i', 't', 'e', 'd', '\n',
        'e', 'l', 'i', 'c', 'i', 't', 'i', 'n', 'g', '\n',
        'e', 'l', 'i', 'c', 'i', 't', 's', '\n',
        'e', 'l', 'i', 'd', 'e', '\n',
        'e', 'l', 'i', 'd', 'e', 'd', '\n',
        'e', 'l', 'i', 'd', 'e', 's', '\n',
        'e', 'l', 'i', 'd', 'i', 'n', 'g', '\n',
        'e', 'l', 'i', 'g', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'e', 'l', 'i', 'g', 'i', 'b', 'l', 'e', '\n',
        'e', 'l', 'i', 'g', 'i', 'b', 'l', 'y', '\n',
        'e', 'l', 'i', 'j', 'a', 'h', '\n',
        'e', 'l', 'i', 'm', 'i', 'n', 'a', 't', 'e', '\n',
        'e', 'l', 'i', 'm', 'i', 'n', 'a', 't', 'e', 'd', '\n',
        'e', 'l', 'i', 'm', 'i', 'n', 'a', 't', 'e', 's', '\n',
        'e', 'l', 'i', 'm', 'i', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'l', 'i', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'l', 'i', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'l', 'i', 'm', 'i', 'n', 'a', 't', 'o', 'r', '\n',
        'e', 'l', 'i', 's', 'i', 'o', 'n', '\n',
        'e', 'l', 'i', 's', 'i', 'o', 'n', 's', '\n',
        'e', 'l', 'i', 't', 'e', '\n',
        'e', 'l', 'i', 't', 'e', 's', '\n',
        'e', 'l', 'i', 't', 'i', 's', 'm', '\n',
        'e', 'l', 'i', 't', 'i', 's', 't', '\n',
        'e', 'l', 'i', 't', 'i', 's', 't', 's', '\n',
        'e', 'l', 'i', 'x', 'i', 'r', '\n',
        'e', 'l', 'i', 'x', 'i', 'r', 's', '\n',
        'e', 'l', 'k', '\n',
        'e', 'l', 'k', 's', '\n',
        'e', 'l', 'l', '\n',
        'e', 'l', 'l', 'i', 'p', 's', 'e', '\n',
        'e', 'l', 'l', 'i', 'p', 's', 'e', 's', '\n',
        'e', 'l', 'l', 'i', 'p', 's', 'i', 's', '\n',
        'e', 'l', 'l', 'i', 'p', 's', 'o', 'i', 'd', '\n',
        'e', 'l', 'l', 'i', 'p', 's', 'o', 'i', 'd', 'a', 'l', '\n',
        'e', 'l', 'l', 'i', 'p', 's', 'o', 'i', 'd', 's', '\n',
        'e', 'l', 'l', 'i', 'p', 't', 'i', 'c', '\n',
        'e', 'l', 'l', 'i', 'p', 't', 'i', 'c', 'a', 'l', '\n',
        'e', 'l', 'l', 'i', 'p', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'e', 'l', 'l', 's', '\n',
        'e', 'l', 'm', '\n',
        'e', 'l', 'm', 's', '\n',
        'e', 'l', 'n', 'i', 'n', 'o', '\n',
        'e', 'l', 'o', 'c', 'u', 't', 'i', 'o', 'n', '\n',
        'e', 'l', 'o', 'n', 'g', 'a', 't', 'e', '\n',
        'e', 'l', 'o', 'n', 'g', 'a', 't', 'e', 'd', '\n',
        'e', 'l', 'o', 'n', 'g', 'a', 't', 'e', 's', '\n',
        'e', 'l', 'o', 'n', 'g', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'l', 'o', 'n', 'g', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'l', 'o', 'n', 'g', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'l', 'o', 'p', 'e', '\n',
        'e', 'l', 'o', 'p', 'e', 'd', '\n',
        'e', 'l', 'o', 'p', 'e', 'm', 'e', 'n', 't', '\n',
        'e', 'l', 'o', 'p', 'e', 's', '\n',
        'e', 'l', 'o', 'p', 'i', 'n', 'g', '\n',
        'e', 'l', 'o', 'q', 'u', 'e', 'n', 'c', 'e', '\n',
        'e', 'l', 'o', 'q', 'u', 'e', 'n', 't', '\n',
        'e', 'l', 'o', 'q', 'u', 'e', 'n', 't', 'l', 'y', '\n',
        'e', 'l', 's', '\n',
        'e', 'l', 's', 'e', '\n',
        'e', 'l', 's', 'e', 'w', 'h', 'e', 'r', 'e', '\n',
        'e', 'l', 'u', 'c', 'i', 'd', 'a', 't', 'e', '\n',
        'e', 'l', 'u', 'c', 'i', 'd', 'a', 't', 'e', 'd', '\n',
        'e', 'l', 'u', 'c', 'i', 'd', 'a', 't', 'e', 's', '\n',
        'e', 'l', 'u', 'c', 'i', 'd', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'l', 'u', 'c', 'i', 'd', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'l', 'u', 'd', 'e', '\n',
        'e', 'l', 'u', 'd', 'e', 'd', '\n',
        'e', 'l', 'u', 'd', 'e', 's', '\n',
        'e', 'l', 'u', 'd', 'i', 'n', 'g', '\n',
        'e', 'l', 'u', 's', 'i', 'o', 'n', '\n',
        'e', 'l', 'u', 's', 'i', 'o', 'n', 's', '\n',
        'e', 'l', 'u', 's', 'i', 'v', 'e', '\n',
        'e', 'l', 'u', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'e', 'l', 'u', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'e', 'l', 'u', 't', 'e', 'd', '\n',
        'e', 'l', 'u', 't', 'i', 'o', 'n', '\n',
        'e', 'l', 'v', 'e', 'n', '\n',
        'e', 'l', 'v', 'e', 's', '\n',
        'e', 'l', 'v', 'i', 's', 'h', '\n',
        'e', 'l', 'y', 's', 'e', 'e', '\n',
        'e', 'm', '\n',
        'e', 'm', 'a', 'c', 'i', 'a', 't', 'e', '\n',
        'e', 'm', 'a', 'c', 'i', 'a', 't', 'e', 'd', '\n',
        'e', 'm', 'a', 'c', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'm', 'a', 'i', 'l', '\n',
        'e', 'm', 'a', 'i', 'l', 'e', 'd', '\n',
        'e', 'm', 'a', 'n', 'a', 't', 'e', '\n',
        'e', 'm', 'a', 'n', 'a', 't', 'e', 'd', '\n',
        'e', 'm', 'a', 'n', 'a', 't', 'e', 's', '\n',
        'e', 'm', 'a', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'm', 'a', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'm', 'a', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'm', 'a', 'n', 'c', 'i', 'p', 'a', 't', 'e', '\n',
        'e', 'm', 'a', 'n', 'c', 'i', 'p', 'a', 't', 'e', 'd', '\n',
        'e', 'm', 'a', 'n', 'c', 'i', 'p', 'a', 't', 'e', 's', '\n',
        'e', 'm', 'a', 'n', 'c', 'i', 'p', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'm', 'a', 'n', 'c', 'i', 'p', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'm', 'a', 'n', 'c', 'i', 'p', 'a', 't', 'o', 'r', '\n',
        'e', 'm', 'a', 'n', 'c', 'i', 'p', 'a', 't', 'o', 'r', 'y', '\n',
        'e', 'm', 'a', 's', 'c', 'u', 'l', 'a', 't', 'e', '\n',
        'e', 'm', 'a', 's', 'c', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'e', 'm', 'a', 's', 'c', 'u', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'm', 'a', 's', 'c', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'm', 'b', 'a', 'l', 'm', '\n',
        'e', 'm', 'b', 'a', 'l', 'm', 'e', 'd', '\n',
        'e', 'm', 'b', 'a', 'l', 'm', 'e', 'r', '\n',
        'e', 'm', 'b', 'a', 'l', 'm', 'e', 'r', 's', '\n',
        'e', 'm', 'b', 'a', 'l', 'm', 'i', 'n', 'g', '\n',
        'e', 'm', 'b', 'a', 'l', 'm', 's', '\n',
        'e', 'm', 'b', 'a', 'n', 'k', '\n',
        'e', 'm', 'b', 'a', 'n', 'k', 'm', 'e', 'n', 't', '\n',
        'e', 'm', 'b', 'a', 'n', 'k', 'm', 'e', 'n', 't', 's', '\n',
        'e', 'm', 'b', 'a', 'r', 'g', 'o', '\n',
        'e', 'm', 'b', 'a', 'r', 'g', 'o', 'e', 'd', '\n',
        'e', 'm', 'b', 'a', 'r', 'k', '\n',
        'e', 'm', 'b', 'a', 'r', 'k', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'm', 'b', 'a', 'r', 'k', 'e', 'd', '\n',
        'e', 'm', 'b', 'a', 'r', 'k', 'i', 'n', 'g', '\n',
        'e', 'm', 'b', 'a', 'r', 'k', 's', '\n',
        'e', 'm', 'b', 'a', 'r', 'r', 'a', 's', 's', '\n',
        'e', 'm', 'b', 'a', 'r', 'r', 'a', 's', 's', 'e', 'd', '\n',
        'e', 'm', 'b', 'a', 'r', 'r', 'a', 's', 's', 'e', 'd', 'l', 'y', '\n',
        'e', 'm', 'b', 'a', 'r', 'r', 'a', 's', 's', 'e', 's', '\n',
        'e', 'm', 'b', 'a', 'r', 'r', 'a', 's', 's', 'i', 'n', 'g', '\n',
        'e', 'm', 'b', 'a', 'r', 'r', 'a', 's', 's', 'i', 'n', 'g', 'l', 'y', '\n',
        'e', 'm', 'b', 'a', 'r', 'r', 'a', 's', 's', 'm', 'e', 'n', 't', '\n',
        'e', 'm', 'b', 'a', 'r', 'r', 'a', 's', 's', 'm', 'e', 'n', 't', 's', '\n',
        'e', 'm', 'b', 'a', 's', 's', 'i', 'e', 's', '\n',
        'e', 'm', 'b', 'a', 's', 's', 'y', '\n',
        'e', 'm', 'b', 'a', 't', 't', 'l', 'e', '\n',
        'e', 'm', 'b', 'a', 't', 't', 'l', 'e', 'd', '\n',
        'e', 'm', 'b', 'e', 'd', '\n',
        'e', 'm', 'b', 'e', 'd', 'd', 'a', 'b', 'l', 'e', '\n',
        'e', 'm', 'b', 'e', 'd', 'd', 'e', 'd', '\n',
        'e', 'm', 'b', 'e', 'd', 'd', 'i', 'n', 'g', '\n',
        'e', 'm', 'b', 'e', 'd', 'd', 'i', 'n', 'g', 's', '\n',
        'e', 'm', 'b', 'e', 'd', 's', '\n',
        'e', 'm', 'b', 'e', 'l', 'l', 'i', 's', 'h', '\n',
        'e', 'm', 'b', 'e', 'l', 'l', 'i', 's', 'h', 'e', 'd', '\n',
        'e', 'm', 'b', 'e', 'l', 'l', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'e', 'm', 'b', 'e', 'l', 'l', 'i', 's', 'h', 'm', 'e', 'n', 't', '\n',
        'e', 'm', 'b', 'e', 'l', 'l', 'i', 's', 'h', 'm', 'e', 'n', 't', 's', '\n',
        'e', 'm', 'b', 'e', 'r', '\n',
        'e', 'm', 'b', 'e', 'r', 's', '\n',
        'e', 'm', 'b', 'e', 'z', 'z', 'l', 'e', '\n',
        'e', 'm', 'b', 'e', 'z', 'z', 'l', 'e', 'd', '\n',
        'e', 'm', 'b', 'e', 'z', 'z', 'l', 'e', 'm', 'e', 'n', 't', '\n',
        'e', 'm', 'b', 'e', 'z', 'z', 'l', 'e', 'r', '\n',
        'e', 'm', 'b', 'e', 'z', 'z', 'l', 'e', 'r', 's', '\n',
        'e', 'm', 'b', 'e', 'z', 'z', 'l', 'i', 'n', 'g', '\n',
        'e', 'm', 'b', 'i', 't', 't', 'e', 'r', '\n',
        'e', 'm', 'b', 'i', 't', 't', 'e', 'r', 'e', 'd', '\n',
        'e', 'm', 'b', 'i', 't', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'e', 'm', 'b', 'i', 't', 't', 'e', 'r', 'm', 'e', 'n', 't', '\n',
        'e', 'm', 'b', 'l', 'a', 'z', 'o', 'n', 'e', 'd', '\n',
        'e', 'm', 'b', 'l', 'e', 'm', '\n',
        'e', 'm', 'b', 'l', 'e', 'm', 'a', 't', 'i', 'c', '\n',
        'e', 'm', 'b', 'l', 'e', 'm', 's', '\n',
        'e', 'm', 'b', 'o', 'd', 'i', 'e', 'd', '\n',
        'e', 'm', 'b', 'o', 'd', 'i', 'e', 's', '\n',
        'e', 'm', 'b', 'o', 'd', 'i', 'm', 'e', 'n', 't', '\n',
        'e', 'm', 'b', 'o', 'd', 'i', 'm', 'e', 'n', 't', 's', '\n',
        'e', 'm', 'b', 'o', 'd', 'y', '\n',
        'e', 'm', 'b', 'o', 'd', 'y', 'i', 'n', 'g', '\n',
        'e', 'm', 'b', 'o', 'l', 'd', 'e', 'n', '\n',
        'e', 'm', 'b', 'o', 'l', 'd', 'e', 'n', 'e', 'd', '\n',
        'e', 'm', 'b', 'o', 'l', 'd', 'e', 'n', 'i', 'n', 'g', '\n',
        'e', 'm', 'b', 'o', 'l', 'd', 'e', 'n', 's', '\n',
        'e', 'm', 'b', 'o', 'l', 'i', 's', 'm', '\n',
        'e', 'm', 'b', 'o', 's', 'o', 'm', '\n',
        'e', 'm', 'b', 'o', 's', 's', '\n',
        'e', 'm', 'b', 'o', 's', 's', 'e', 'd', '\n',
        'e', 'm', 'b', 'r', 'a', 'c', 'e', '\n',
        'e', 'm', 'b', 'r', 'a', 'c', 'e', 'd', '\n',
        'e', 'm', 'b', 'r', 'a', 'c', 'e', 's', '\n',
        'e', 'm', 'b', 'r', 'a', 'c', 'i', 'n', 'g', '\n',
        'e', 'm', 'b', 'r', 'a', 's', 'u', 'r', 'e', '\n',
        'e', 'm', 'b', 'r', 'o', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'm', 'b', 'r', 'o', 'i', 'd', 'e', 'r', '\n',
        'e', 'm', 'b', 'r', 'o', 'i', 'd', 'e', 'r', 'e', 'd', '\n',
        'e', 'm', 'b', 'r', 'o', 'i', 'd', 'e', 'r', 'e', 'r', 's', '\n',
        'e', 'm', 'b', 'r', 'o', 'i', 'd', 'e', 'r', 'i', 'e', 's', '\n',
        'e', 'm', 'b', 'r', 'o', 'i', 'd', 'e', 'r', 'i', 'n', 'g', '\n',
        'e', 'm', 'b', 'r', 'o', 'i', 'd', 'e', 'r', 'y', '\n',
        'e', 'm', 'b', 'r', 'o', 'i', 'l', '\n',
        'e', 'm', 'b', 'r', 'o', 'i', 'l', 'e', 'd', '\n',
        'e', 'm', 'b', 'r', 'o', 'i', 'l', 'i', 'n', 'g', '\n',
        'e', 'm', 'b', 'r', 'y', 'o', '\n',
        'e', 'm', 'b', 'r', 'y', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'e', 'm', 'b', 'r', 'y', 'o', 'l', 'o', 'g', 'y', '\n',
        'e', 'm', 'b', 'r', 'y', 'o', 'n', 'a', 'l', '\n',
        'e', 'm', 'b', 'r', 'y', 'o', 'n', 'i', 'c', '\n',
        'e', 'm', 'e', 'n', 'd', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'm', 'e', 'n', 'd', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'm', 'e', 'n', 'd', 'e', 'd', '\n',
        'e', 'm', 'e', 'r', 'a', 'l', 'd', '\n',
        'e', 'm', 'e', 'r', 'a', 'l', 'd', 's', '\n',
        'e', 'm', 'e', 'r', 'g', 'e', '\n',
        'e', 'm', 'e', 'r', 'g', 'e', 'd', '\n',
        'e', 'm', 'e', 'r', 'g', 'e', 'n', 'c', 'e', '\n',
        'e', 'm', 'e', 'r', 'g', 'e', 'n', 'c', 'i', 'e', 's', '\n',
        'e', 'm', 'e', 'r', 'g', 'e', 'n', 'c', 'y', '\n',
        'e', 'm', 'e', 'r', 'g', 'e', 'n', 't', '\n',
        'e', 'm', 'e', 'r', 'g', 'e', 's', '\n',
        'e', 'm', 'e', 'r', 'g', 'i', 'n', 'g', '\n',
        'e', 'm', 'e', 'r', 'i', 't', 'u', 's', '\n',
        'e', 'm', 'e', 'r', 's', 'i', 'o', 'n', '\n',
        'e', 'm', 'e', 'r', 'y', '\n',
        'e', 'm', 'e', 't', 'i', 'c', '\n',
        'e', 'm', 'i', 'g', 'r', 'a', 'n', 't', '\n',
        'e', 'm', 'i', 'g', 'r', 'a', 'n', 't', 's', '\n',
        'e', 'm', 'i', 'g', 'r', 'a', 't', 'e', '\n',
        'e', 'm', 'i', 'g', 'r', 'a', 't', 'e', 'd', '\n',
        'e', 'm', 'i', 'g', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'm', 'i', 'g', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'm', 'i', 'g', 'r', 'e', '\n',
        'e', 'm', 'i', 'g', 'r', 'e', 's', '\n',
        'e', 'm', 'i', 'n', 'e', 'n', 'c', 'e', '\n',
        'e', 'm', 'i', 'n', 'e', 'n', 'c', 'e', 's', '\n',
        'e', 'm', 'i', 'n', 'e', 'n', 't', '\n',
        'e', 'm', 'i', 'n', 'e', 'n', 't', 'l', 'y', '\n',
        'e', 'm', 'i', 'r', '\n',
        'e', 'm', 'i', 'r', 'a', 't', 'e', '\n',
        'e', 'm', 'i', 'r', 'a', 't', 'e', 's', '\n',
        'e', 'm', 'i', 'r', 's', '\n',
        'e', 'm', 'i', 's', 's', 'a', 'r', 'i', 'e', 's', '\n',
        'e', 'm', 'i', 's', 's', 'a', 'r', 'y', '\n',
        'e', 'm', 'i', 's', 's', 'i', 'o', 'n', '\n',
        'e', 'm', 'i', 's', 's', 'i', 'o', 'n', 's', '\n',
        'e', 'm', 'i', 's', 's', 'i', 'v', 'i', 't', 'i', 'e', 's', '\n',
        'e', 'm', 'i', 's', 's', 'i', 'v', 'i', 't', 'y', '\n',
        'e', 'm', 'i', 't', '\n',
        'e', 'm', 'i', 't', 's', '\n',
        'e', 'm', 'i', 't', 't', 'e', 'd', '\n',
        'e', 'm', 'i', 't', 't', 'e', 'r', '\n',
        'e', 'm', 'i', 't', 't', 'e', 'r', 's', '\n',
        'e', 'm', 'i', 't', 't', 'i', 'n', 'g', '\n',
        'e', 'm', 'o', 'l', 'l', 'i', 'e', 'n', 't', '\n',
        'e', 'm', 'o', 'l', 'u', 'm', 'e', 'n', 't', '\n',
        'e', 'm', 'o', 'l', 'u', 'm', 'e', 'n', 't', 's', '\n',
        'e', 'm', 'o', 't', 'i', 'o', 'n', '\n',
        'e', 'm', 'o', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'e', 'm', 'o', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 'm', '\n',
        'e', 'm', 'o', 't', 'i', 'o', 'n', 'a', 'l', 'i', 't', 'y', '\n',
        'e', 'm', 'o', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'e', 'm', 'o', 't', 'i', 'o', 'n', 'l', 'e', 's', 's', '\n',
        'e', 'm', 'o', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'm', 'o', 't', 'i', 'v', 'e', '\n',
        'e', 'm', 'o', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'e', 'm', 'p', 'a', 't', 'h', 'e', 't', 'i', 'c', '\n',
        'e', 'm', 'p', 'a', 't', 'h', 'e', 't', 'i', 'c', 'a', 'l', '\n',
        'e', 'm', 'p', 'a', 't', 'h', 'i', 'c', '\n',
        'e', 'm', 'p', 'a', 't', 'h', 'i', 's', 'e', '\n',
        'e', 'm', 'p', 'a', 't', 'h', 'i', 's', 'i', 'n', 'g', '\n',
        'e', 'm', 'p', 'a', 't', 'h', 'y', '\n',
        'e', 'm', 'p', 'e', 'r', 'o', 'r', '\n',
        'e', 'm', 'p', 'e', 'r', 'o', 'r', 's', '\n',
        'e', 'm', 'p', 'h', 'a', 's', 'e', 's', '\n',
        'e', 'm', 'p', 'h', 'a', 's', 'i', 's', '\n',
        'e', 'm', 'p', 'h', 'a', 's', 'i', 's', 'e', '\n',
        'e', 'm', 'p', 'h', 'a', 's', 'i', 's', 'e', 'd', '\n',
        'e', 'm', 'p', 'h', 'a', 's', 'i', 's', 'e', 's', '\n',
        'e', 'm', 'p', 'h', 'a', 's', 'i', 's', 'i', 'n', 'g', '\n',
        'e', 'm', 'p', 'h', 'a', 't', 'i', 'c', '\n',
        'e', 'm', 'p', 'h', 'a', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'e', 'm', 'p', 'h', 'y', 's', 'e', 'm', 'a', '\n',
        'e', 'm', 'p', 'i', 'r', 'e', '\n',
        'e', 'm', 'p', 'i', 'r', 'e', 's', '\n',
        'e', 'm', 'p', 'i', 'r', 'i', 'c', '\n',
        'e', 'm', 'p', 'i', 'r', 'i', 'c', 'a', 'l', '\n',
        'e', 'm', 'p', 'i', 'r', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'e', 'm', 'p', 'i', 'r', 'i', 'c', 'i', 's', 'm', '\n',
        'e', 'm', 'p', 'i', 'r', 'i', 'c', 'i', 's', 't', '\n',
        'e', 'm', 'p', 'i', 'r', 'i', 'c', 'i', 's', 't', 's', '\n',
        'e', 'm', 'p', 'l', 'a', 'c', 'e', 'm', 'e', 'n', 't', '\n',
        'e', 'm', 'p', 'l', 'a', 'c', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'e', 'm', 'p', 'l', 'o', 'y', '\n',
        'e', 'm', 'p', 'l', 'o', 'y', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'e', 'm', 'p', 'l', 'o', 'y', 'a', 'b', 'l', 'e', '\n',
        'e', 'm', 'p', 'l', 'o', 'y', 'e', 'd', '\n',
        'e', 'm', 'p', 'l', 'o', 'y', 'e', 'e', '\n',
        'e', 'm', 'p', 'l', 'o', 'y', 'e', 'e', 's', '\n',
        'e', 'm', 'p', 'l', 'o', 'y', 'e', 'r', '\n',
        'e', 'm', 'p', 'l', 'o', 'y', 'e', 'r', 's', '\n',
        'e', 'm', 'p', 'l', 'o', 'y', 'i', 'n', 'g', '\n',
        'e', 'm', 'p', 'l', 'o', 'y', 'm', 'e', 'n', 't', '\n',
        'e', 'm', 'p', 'l', 'o', 'y', 'm', 'e', 'n', 't', 's', '\n',
        'e', 'm', 'p', 'l', 'o', 'y', 's', '\n',
        'e', 'm', 'p', 'o', 'r', 'i', 'a', '\n',
        'e', 'm', 'p', 'o', 'r', 'i', 'u', 'm', '\n',
        'e', 'm', 'p', 'o', 'w', 'e', 'r', '\n',
        'e', 'm', 'p', 'o', 'w', 'e', 'r', 'e', 'd', '\n',
        'e', 'm', 'p', 'o', 'w', 'e', 'r', 'i', 'n', 'g', '\n',
        'e', 'm', 'p', 'o', 'w', 'e', 'r', 'm', 'e', 'n', 't', '\n',
        'e', 'm', 'p', 'o', 'w', 'e', 'r', 's', '\n',
        'e', 'm', 'p', 'r', 'e', 's', 's', '\n',
        'e', 'm', 'p', 't', 'i', 'e', 'd', '\n',
        'e', 'm', 'p', 't', 'i', 'e', 'r', '\n',
        'e', 'm', 'p', 't', 'i', 'e', 's', '\n',
        'e', 'm', 'p', 't', 'i', 'e', 's', 't', '\n',
        'e', 'm', 'p', 't', 'i', 'l', 'y', '\n',
        'e', 'm', 'p', 't', 'i', 'n', 'e', 's', 's', '\n',
        'e', 'm', 'p', 't', 'y', '\n',
        'e', 'm', 'p', 't', 'y', 'h', 'a', 'n', 'd', 'e', 'd', '\n',
        'e', 'm', 'p', 't', 'y', 'i', 'n', 'g', '\n',
        'e', 'm', 's', '\n',
        'e', 'm', 'u', '\n',
        'e', 'm', 'u', 'l', 'a', 't', 'e', '\n',
        'e', 'm', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'e', 'm', 'u', 'l', 'a', 't', 'e', 's', '\n',
        'e', 'm', 'u', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'm', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'm', 'u', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'm', 'u', 'l', 'a', 't', 'o', 'r', '\n',
        'e', 'm', 'u', 'l', 'a', 't', 'o', 'r', 's', '\n',
        'e', 'm', 'u', 'l', 's', 'i', 'f', 'i', 'e', 's', '\n',
        'e', 'm', 'u', 'l', 's', 'i', 'o', 'n', '\n',
        'e', 'm', 'u', 'l', 's', 'i', 'o', 'n', 's', '\n',
        'e', 'm', 'u', 's', '\n',
        'e', 'n', 'a', 'b', 'l', 'e', '\n',
        'e', 'n', 'a', 'b', 'l', 'e', 'd', '\n',
        'e', 'n', 'a', 'b', 'l', 'e', 's', '\n',
        'e', 'n', 'a', 'b', 'l', 'i', 'n', 'g', '\n',
        'e', 'n', 'a', 'c', 't', '\n',
        'e', 'n', 'a', 'c', 't', 'e', 'd', '\n',
        'e', 'n', 'a', 'c', 't', 'i', 'n', 'g', '\n',
        'e', 'n', 'a', 'c', 't', 'm', 'e', 'n', 't', '\n',
        'e', 'n', 'a', 'c', 't', 'm', 'e', 'n', 't', 's', '\n',
        'e', 'n', 'a', 'c', 't', 's', '\n',
        'e', 'n', 'a', 'm', 'e', 'l', '\n',
        'e', 'n', 'a', 'm', 'e', 'l', 'l', 'e', 'd', '\n',
        'e', 'n', 'a', 'm', 'e', 'l', 's', '\n',
        'e', 'n', 'a', 'm', 'o', 'u', 'r', 'e', 'd', '\n',
        'e', 'n', 'c', 'a', 'g', 'e', '\n',
        'e', 'n', 'c', 'a', 'm', 'p', '\n',
        'e', 'n', 'c', 'a', 'm', 'p', 'e', 'd', '\n',
        'e', 'n', 'c', 'a', 'm', 'p', 'm', 'e', 'n', 't', '\n',
        'e', 'n', 'c', 'a', 'm', 'p', 'm', 'e', 'n', 't', 's', '\n',
        'e', 'n', 'c', 'a', 'p', 's', 'u', 'l', 'a', 't', 'e', '\n',
        'e', 'n', 'c', 'a', 'p', 's', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'e', 'n', 'c', 'a', 'p', 's', 'u', 'l', 'a', 't', 'e', 's', '\n',
        'e', 'n', 'c', 'a', 'p', 's', 'u', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'n', 'c', 'a', 'p', 's', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'n', 'c', 'a', 'p', 's', 'u', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'n', 'c', 'a', 's', 'e', '\n',
        'e', 'n', 'c', 'a', 's', 'e', 'd', '\n',
        'e', 'n', 'c', 'a', 's', 'e', 's', '\n',
        'e', 'n', 'c', 'a', 's', 'h', 'm', 'e', 'n', 't', '\n',
        'e', 'n', 'c', 'a', 's', 'i', 'n', 'g', '\n',
        'e', 'n', 'c', 'e', 'p', 'h', 'a', 'l', 'i', 't', 'i', 's', '\n',
        'e', 'n', 'c', 'e', 'p', 'h', 'a', 'l', 'o', 'p', 'a', 't', 'h', 'y', '\n',
        'e', 'n', 'c', 'h', 'a', 'i', 'n', '\n',
        'e', 'n', 'c', 'h', 'a', 'n', 't', '\n',
        'e', 'n', 'c', 'h', 'a', 'n', 't', 'e', 'd', '\n',
        'e', 'n', 'c', 'h', 'a', 'n', 't', 'e', 'r', '\n',
        'e', 'n', 'c', 'h', 'a', 'n', 't', 'e', 'r', 's', '\n',
        'e', 'n', 'c', 'h', 'a', 'n', 't', 'i', 'n', 'g', '\n',
        'e', 'n', 'c', 'h', 'a', 'n', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'e', 'n', 'c', 'h', 'a', 'n', 't', 'm', 'e', 'n', 't', '\n',
        'e', 'n', 'c', 'h', 'a', 'n', 't', 'm', 'e', 'n', 't', 's', '\n',
        'e', 'n', 'c', 'h', 'a', 'n', 't', 'r', 'e', 's', 's', '\n',
        'e', 'n', 'c', 'h', 'a', 'n', 't', 's', '\n',
        'e', 'n', 'c', 'h', 'i', 'l', 'a', 'd', 'a', 's', '\n',
        'e', 'n', 'c', 'i', 'p', 'h', 'e', 'r', 'i', 'n', 'g', '\n',
        'e', 'n', 'c', 'i', 'r', 'c', 'l', 'e', '\n',
        'e', 'n', 'c', 'i', 'r', 'c', 'l', 'e', 'd', '\n',
        'e', 'n', 'c', 'i', 'r', 'c', 'l', 'e', 'm', 'e', 'n', 't', '\n',
        'e', 'n', 'c', 'i', 'r', 'c', 'l', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'e', 'n', 'c', 'i', 'r', 'c', 'l', 'e', 's', '\n',
        'e', 'n', 'c', 'i', 'r', 'c', 'l', 'i', 'n', 'g', '\n',
        'e', 'n', 'c', 'l', 'a', 's', 'p', '\n',
        'e', 'n', 'c', 'l', 'a', 'v', 'e', '\n',
        'e', 'n', 'c', 'l', 'a', 'v', 'e', 's', '\n',
        'e', 'n', 'c', 'l', 'o', 's', 'e', '\n',
        'e', 'n', 'c', 'l', 'o', 's', 'e', 'd', '\n',
        'e', 'n', 'c', 'l', 'o', 's', 'e', 's', '\n',
        'e', 'n', 'c', 'l', 'o', 's', 'i', 'n', 'g', '\n',
        'e', 'n', 'c', 'l', 'o', 's', 'u', 'r', 'e', '\n',
        'e', 'n', 'c', 'l', 'o', 's', 'u', 'r', 'e', 's', '\n',
        'e', 'n', 'c', 'o', 'd', 'e', '\n',
        'e', 'n', 'c', 'o', 'd', 'e', 'd', '\n',
        'e', 'n', 'c', 'o', 'd', 'e', 'r', '\n',
        'e', 'n', 'c', 'o', 'd', 'e', 'r', 's', '\n',
        'e', 'n', 'c', 'o', 'd', 'e', 's', '\n',
        'e', 'n', 'c', 'o', 'd', 'i', 'n', 'g', '\n',
        'e', 'n', 'c', 'o', 'm', 'i', 'u', 'm', '\n',
        'e', 'n', 'c', 'o', 'm', 'p', 'a', 's', 's', '\n',
        'e', 'n', 'c', 'o', 'm', 'p', 'a', 's', 's', 'e', 'd', '\n',
        'e', 'n', 'c', 'o', 'm', 'p', 'a', 's', 's', 'e', 's', '\n',
        'e', 'n', 'c', 'o', 'm', 'p', 'a', 's', 's', 'i', 'n', 'g', '\n',
        'e', 'n', 'c', 'o', 'r', 'e', '\n',
        'e', 'n', 'c', 'o', 'r', 'e', 'd', '\n',
        'e', 'n', 'c', 'o', 'r', 'e', 's', '\n',
        'e', 'n', 'c', 'o', 'u', 'n', 't', 'e', 'r', '\n',
        'e', 'n', 'c', 'o', 'u', 'n', 't', 'e', 'r', 'e', 'd', '\n',
        'e', 'n', 'c', 'o', 'u', 'n', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'e', 'n', 'c', 'o', 'u', 'n', 't', 'e', 'r', 's', '\n',
        'e', 'n', 'c', 'o', 'u', 'r', 'a', 'g', 'e', '\n',
        'e', 'n', 'c', 'o', 'u', 'r', 'a', 'g', 'e', 'd', '\n',
        'e', 'n', 'c', 'o', 'u', 'r', 'a', 'g', 'e', 'm', 'e', 'n', 't', '\n',
        'e', 'n', 'c', 'o', 'u', 'r', 'a', 'g', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'e', 'n', 'c', 'o', 'u', 'r', 'a', 'g', 'e', 'r', '\n',
        'e', 'n', 'c', 'o', 'u', 'r', 'a', 'g', 'e', 's', '\n',
        'e', 'n', 'c', 'o', 'u', 'r', 'a', 'g', 'i', 'n', 'g', '\n',
        'e', 'n', 'c', 'o', 'u', 'r', 'a', 'g', 'i', 'n', 'g', 'l', 'y', '\n',
        'e', 'n', 'c', 'r', 'o', 'a', 'c', 'h', '\n',
        'e', 'n', 'c', 'r', 'o', 'a', 'c', 'h', 'e', 'd', '\n',
        'e', 'n', 'c', 'r', 'o', 'a', 'c', 'h', 'e', 's', '\n',
        'e', 'n', 'c', 'r', 'o', 'a', 'c', 'h', 'i', 'n', 'g', '\n',
        'e', 'n', 'c', 'r', 'o', 'a', 'c', 'h', 'm', 'e', 'n', 't', '\n',
        'e', 'n', 'c', 'r', 'o', 'a', 'c', 'h', 'm', 'e', 'n', 't', 's', '\n',
        'e', 'n', 'c', 'r', 'u', 's', 't', '\n',
        'e', 'n', 'c', 'r', 'u', 's', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'n', 'c', 'r', 'u', 's', 't', 'e', 'd', '\n',
        'e', 'n', 'c', 'r', 'u', 's', 't', 'i', 'n', 'g', '\n',
        'e', 'n', 'c', 'r', 'y', 'p', 't', '\n',
        'e', 'n', 'c', 'r', 'y', 'p', 't', 'e', 'd', '\n',
        'e', 'n', 'c', 'r', 'y', 'p', 't', 'i', 'n', 'g', '\n',
        'e', 'n', 'c', 'r', 'y', 'p', 't', 'i', 'o', 'n', '\n',
        'e', 'n', 'c', 'r', 'y', 'p', 't', 's', '\n',
        'e', 'n', 'c', 'u', 'm', 'b', 'e', 'r', '\n',
        'e', 'n', 'c', 'u', 'm', 'b', 'e', 'r', 'e', 'd', '\n',
        'e', 'n', 'c', 'u', 'm', 'b', 'e', 'r', 'i', 'n', 'g', '\n',
        'e', 'n', 'c', 'u', 'm', 'b', 'r', 'a', 'n', 'c', 'e', '\n',
        'e', 'n', 'c', 'u', 'm', 'b', 'r', 'a', 'n', 'c', 'e', 's', '\n',
        'e', 'n', 'c', 'y', 'c', 'l', 'i', 'c', 'a', 'l', '\n',
        'e', 'n', 'c', 'y', 'c', 'l', 'o', 'p', 'a', 'e', 'd', 'i', 'a', '\n',
        'e', 'n', 'c', 'y', 'c', 'l', 'o', 'p', 'a', 'e', 'd', 'i', 'a', 's', '\n',
        'e', 'n', 'c', 'y', 'c', 'l', 'o', 'p', 'a', 'e', 'd', 'i', 'c', '\n',
        'e', 'n', 'c', 'y', 'c', 'l', 'o', 'p', 'e', 'd', 'i', 'a', '\n',
        'e', 'n', 'c', 'y', 'c', 'l', 'o', 'p', 'e', 'd', 'i', 'a', 's', '\n',
        'e', 'n', 'c', 'y', 'c', 'l', 'o', 'p', 'e', 'd', 'i', 'c', '\n',
        'e', 'n', 'd', '\n',
        'e', 'n', 'd', 'a', 'n', 'g', 'e', 'r', '\n',
        'e', 'n', 'd', 'a', 'n', 'g', 'e', 'r', 'e', 'd', '\n',
        'e', 'n', 'd', 'a', 'n', 'g', 'e', 'r', 'i', 'n', 'g', '\n',
        'e', 'n', 'd', 'a', 'n', 'g', 'e', 'r', 's', '\n',
        'e', 'n', 'd', 'e', 'a', 'r', '\n',
        'e', 'n', 'd', 'e', 'a', 'r', 'e', 'd', '\n',
        'e', 'n', 'd', 'e', 'a', 'r', 'i', 'n', 'g', '\n',
        'e', 'n', 'd', 'e', 'a', 'r', 'i', 'n', 'g', 'l', 'y', '\n',
        'e', 'n', 'd', 'e', 'a', 'r', 'm', 'e', 'n', 't', '\n',
        'e', 'n', 'd', 'e', 'a', 'r', 'm', 'e', 'n', 't', 's', '\n',
        'e', 'n', 'd', 'e', 'a', 'r', 's', '\n',
        'e', 'n', 'd', 'e', 'a', 'v', 'o', 'u', 'r', '\n',
        'e', 'n', 'd', 'e', 'a', 'v', 'o', 'u', 'r', 'e', 'd', '\n',
        'e', 'n', 'd', 'e', 'a', 'v', 'o', 'u', 'r', 'i', 'n', 'g', '\n',
        'e', 'n', 'd', 'e', 'a', 'v', 'o', 'u', 'r', 's', '\n',
        'e', 'n', 'd', 'e', 'd', '\n',
        'e', 'n', 'd', 'e', 'm', 'i', 'c', '\n',
        'e', 'n', 'd', 'e', 'm', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'e', 'n', 'd', 'g', 'a', 'm', 'e', '\n',
        'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'e', 'n', 'd', 'i', 'n', 'g', 's', '\n',
        'e', 'n', 'd', 'i', 'v', 'e', '\n',
        'e', 'n', 'd', 'l', 'e', 's', 's', '\n',
        'e', 'n', 'd', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'e', 'n', 'd', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'e', 'n', 'd', 'o', 'c', 'r', 'i', 'n', 'e', '\n',
        'e', 'n', 'd', 'o', 'g', 'e', 'n', 'o', 'u', 's', '\n',
        'e', 'n', 'd', 'o', 'g', 'e', 'n', 'o', 'u', 's', 'l', 'y', '\n',
        'e', 'n', 'd', 'o', 'm', 'e', 't', 'r', 'i', 'a', 'l', '\n',
        'e', 'n', 'd', 'o', 'm', 'e', 't', 'r', 'i', 'o', 's', 'i', 's', '\n',
        'e', 'n', 'd', 'o', 'm', 'e', 't', 'r', 'i', 'u', 'm', '\n',
        'e', 'n', 'd', 'o', 'm', 'o', 'r', 'p', 'h', 'i', 's', 'm', '\n',
        'e', 'n', 'd', 'o', 'm', 'o', 'r', 'p', 'h', 'i', 's', 'm', 's', '\n',
        'e', 'n', 'd', 'o', 'p', 'l', 'a', 's', 'm', 'i', 'c', '\n',
        'e', 'n', 'd', 'o', 'r', 'p', 'h', 'i', 'n', 's', '\n',
        'e', 'n', 'd', 'o', 'r', 's', 'e', '\n',
        'e', 'n', 'd', 'o', 'r', 's', 'e', 'd', '\n',
        'e', 'n', 'd', 'o', 'r', 's', 'e', 'm', 'e', 'n', 't', '\n',
        'e', 'n', 'd', 'o', 'r', 's', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'e', 'n', 'd', 'o', 'r', 's', 'e', 'r', '\n',
        'e', 'n', 'd', 'o', 'r', 's', 'e', 's', '\n',
        'e', 'n', 'd', 'o', 'r', 's', 'i', 'n', 'g', '\n',
        'e', 'n', 'd', 'o', 's', 'c', 'o', 'p', 'e', '\n',
        'e', 'n', 'd', 'o', 's', 'c', 'o', 'p', 'i', 'c', '\n',
        'e', 'n', 'd', 'o', 's', 'c', 'o', 'p', 'y', '\n',
        'e', 'n', 'd', 'o', 't', 'h', 'e', 'r', 'm', 'i', 'c', '\n',
        'e', 'n', 'd', 'o', 't', 'o', 'x', 'i', 'n', '\n',
        'e', 'n', 'd', 'o', 'w', '\n',
        'e', 'n', 'd', 'o', 'w', 'e', 'd', '\n',
        'e', 'n', 'd', 'o', 'w', 'i', 'n', 'g', '\n',
        'e', 'n', 'd', 'o', 'w', 'm', 'e', 'n', 't', '\n',
        'e', 'n', 'd', 'o', 'w', 'm', 'e', 'n', 't', 's', '\n',
        'e', 'n', 'd', 'o', 'w', 's', '\n',
        'e', 'n', 'd', 'p', 'a', 'p', 'e', 'r', 's', '\n',
        'e', 'n', 'd', 's', '\n',
        'e', 'n', 'd', 'u', 'e', 'd', '\n',
        'e', 'n', 'd', 'u', 'e', 's', '\n',
        'e', 'n', 'd', 'u', 'n', 'g', 'e', 'o', 'n', 'e', 'd', '\n',
        'e', 'n', 'd', 'u', 'r', 'a', 'b', 'l', 'e', '\n',
        'e', 'n', 'd', 'u', 'r', 'a', 'n', 'c', 'e', '\n',
        'e', 'n', 'd', 'u', 'r', 'e', '\n',
        'e', 'n', 'd', 'u', 'r', 'e', 'd', '\n',
        'e', 'n', 'd', 'u', 'r', 'e', 's', '\n',
        'e', 'n', 'd', 'u', 'r', 'i', 'n', 'g', '\n',
        'e', 'n', 'e', 'm', 'a', '\n',
        'e', 'n', 'e', 'm', 'a', 's', '\n',
        'e', 'n', 'e', 'm', 'i', 'e', 's', '\n',
        'e', 'n', 'e', 'm', 'y', '\n',
        'e', 'n', 'e', 'r', 'g', 'e', 't', 'i', 'c', '\n',
        'e', 'n', 'e', 'r', 'g', 'e', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'e', 'n', 'e', 'r', 'g', 'e', 't', 'i', 'c', 's', '\n',
        'e', 'n', 'e', 'r', 'g', 'i', 'e', 's', '\n',
        'e', 'n', 'e', 'r', 'g', 'i', 's', 'e', '\n',
        'e', 'n', 'e', 'r', 'g', 'i', 's', 'e', 'd', '\n',
        'e', 'n', 'e', 'r', 'g', 'i', 's', 'e', 'r', '\n',
        'e', 'n', 'e', 'r', 'g', 'i', 's', 'e', 'r', 's', '\n',
        'e', 'n', 'e', 'r', 'g', 'i', 's', 'i', 'n', 'g', '\n',
        'e', 'n', 'e', 'r', 'g', 'y', '\n',
        'e', 'n', 'e', 'r', 'v', 'a', 't', 'e', '\n',
        'e', 'n', 'e', 'r', 'v', 'a', 't', 'e', 'd', '\n',
        'e', 'n', 'e', 'r', 'v', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'n', 'f', 'e', 'e', 'b', 'l', 'e', '\n',
        'e', 'n', 'f', 'e', 'e', 'b', 'l', 'e', 'd', '\n',
        'e', 'n', 'f', 'e', 'e', 'b', 'l', 'e', 'm', 'e', 'n', 't', '\n',
        'e', 'n', 'f', 'o', 'l', 'd', '\n',
        'e', 'n', 'f', 'o', 'l', 'd', 'e', 'd', '\n',
        'e', 'n', 'f', 'o', 'l', 'd', 'i', 'n', 'g', '\n',
        'e', 'n', 'f', 'o', 'l', 'd', 's', '\n',
        'e', 'n', 'f', 'o', 'r', 'c', 'e', '\n',
        'e', 'n', 'f', 'o', 'r', 'c', 'e', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'e', 'n', 'f', 'o', 'r', 'c', 'e', 'a', 'b', 'l', 'e', '\n',
        'e', 'n', 'f', 'o', 'r', 'c', 'e', 'd', '\n',
        'e', 'n', 'f', 'o', 'r', 'c', 'e', 'm', 'e', 'n', 't', '\n',
        'e', 'n', 'f', 'o', 'r', 'c', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'e', 'n', 'f', 'o', 'r', 'c', 'e', 'r', '\n',
        'e', 'n', 'f', 'o', 'r', 'c', 'e', 'r', 's', '\n',
        'e', 'n', 'f', 'o', 'r', 'c', 'e', 's', '\n',
        'e', 'n', 'f', 'o', 'r', 'c', 'i', 'n', 'g', '\n',
        'e', 'n', 'f', 'r', 'a', 'n', 'c', 'h', 'i', 's', 'e', '\n',
        'e', 'n', 'f', 'r', 'a', 'n', 'c', 'h', 'i', 's', 'e', 'd', '\n',
        'e', 'n', 'f', 'r', 'a', 'n', 'c', 'h', 'i', 's', 'e', 'm', 'e', 'n', 't', '\n',
        'e', 'n', 'f', 'r', 'a', 'n', 'c', 'h', 'i', 's', 'e', 'r', '\n',
        'e', 'n', 'f', 'r', 'a', 'n', 'c', 'h', 'i', 's', 'i', 'n', 'g', '\n',
        'e', 'n', 'g', 'a', 'g', 'e', '\n',
        'e', 'n', 'g', 'a', 'g', 'e', 'd', '\n',
        'e', 'n', 'g', 'a', 'g', 'e', 'm', 'e', 'n', 't', '\n',
        'e', 'n', 'g', 'a', 'g', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'e', 'n', 'g', 'a', 'g', 'e', 's', '\n',
        'e', 'n', 'g', 'a', 'g', 'i', 'n', 'g', '\n',
        'e', 'n', 'g', 'a', 'g', 'i', 'n', 'g', 'l', 'y', '\n',
        'e', 'n', 'g', 'a', 'r', 'd', 'e', '\n',
        'e', 'n', 'g', 'e', 'l', 's', '\n',
        'e', 'n', 'g', 'e', 'n', 'd', 'e', 'r', '\n',
        'e', 'n', 'g', 'e', 'n', 'd', 'e', 'r', 'e', 'd', '\n',
        'e', 'n', 'g', 'e', 'n', 'd', 'e', 'r', 'i', 'n', 'g', '\n',
        'e', 'n', 'g', 'e', 'n', 'd', 'e', 'r', 's', '\n',
        'e', 'n', 'g', 'i', 'n', 'e', '\n',
        'e', 'n', 'g', 'i', 'n', 'e', 'd', '\n',
        'e', 'n', 'g', 'i', 'n', 'e', 'e', 'r', '\n',
        'e', 'n', 'g', 'i', 'n', 'e', 'e', 'r', 'e', 'd', '\n',
        'e', 'n', 'g', 'i', 'n', 'e', 'e', 'r', 'i', 'n', 'g', '\n',
        'e', 'n', 'g', 'i', 'n', 'e', 'e', 'r', 's', '\n',
        'e', 'n', 'g', 'i', 'n', 'e', 's', '\n',
        'e', 'n', 'g', 'l', 'a', 'n', 'd', '\n',
        'e', 'n', 'g', 'l', 'i', 's', 'h', '\n',
        'e', 'n', 'g', 'o', 'r', 'g', 'e', '\n',
        'e', 'n', 'g', 'o', 'r', 'g', 'e', 'd', '\n',
        'e', 'n', 'g', 'r', 'a', 'i', 'n', 'e', 'd', '\n',
        'e', 'n', 'g', 'r', 'a', 'v', 'e', '\n',
        'e', 'n', 'g', 'r', 'a', 'v', 'e', 'd', '\n',
        'e', 'n', 'g', 'r', 'a', 'v', 'e', 'r', '\n',
        'e', 'n', 'g', 'r', 'a', 'v', 'e', 'r', 's', '\n',
        'e', 'n', 'g', 'r', 'a', 'v', 'e', 's', '\n',
        'e', 'n', 'g', 'r', 'a', 'v', 'i', 'n', 'g', '\n',
        'e', 'n', 'g', 'r', 'a', 'v', 'i', 'n', 'g', 's', '\n',
        'e', 'n', 'g', 'r', 'o', 's', 's', '\n',
        'e', 'n', 'g', 'r', 'o', 's', 's', 'e', 'd', '\n',
        'e', 'n', 'g', 'r', 'o', 's', 's', 'i', 'n', 'g', '\n',
        'e', 'n', 'g', 'u', 'l', 'f', '\n',
        'e', 'n', 'g', 'u', 'l', 'f', 'e', 'd', '\n',
        'e', 'n', 'g', 'u', 'l', 'f', 'i', 'n', 'g', '\n',
        'e', 'n', 'g', 'u', 'l', 'f', 's', '\n',
        'e', 'n', 'h', 'a', 'n', 'c', 'e', '\n',
        'e', 'n', 'h', 'a', 'n', 'c', 'e', 'a', 'b', 'l', 'e', '\n',
        'e', 'n', 'h', 'a', 'n', 'c', 'e', 'd', '\n',
        'e', 'n', 'h', 'a', 'n', 'c', 'e', 'm', 'e', 'n', 't', '\n',
        'e', 'n', 'h', 'a', 'n', 'c', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'e', 'n', 'h', 'a', 'n', 'c', 'e', 'r', '\n',
        'e', 'n', 'h', 'a', 'n', 'c', 'e', 'r', 's', '\n',
        'e', 'n', 'h', 'a', 'n', 'c', 'e', 's', '\n',
        'e', 'n', 'h', 'a', 'n', 'c', 'i', 'n', 'g', '\n',
        'e', 'n', 'h', 'a', 'r', 'm', 'o', 'n', 'i', 'c', '\n',
        'e', 'n', 'i', 'g', 'm', 'a', '\n',
        'e', 'n', 'i', 'g', 'm', 'a', 's', '\n',
        'e', 'n', 'i', 'g', 'm', 'a', 't', 'i', 'c', '\n',
        'e', 'n', 'i', 'g', 'm', 'a', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'e', 'n', 'j', 'o', 'i', 'n', '\n',
        'e', 'n', 'j', 'o', 'i', 'n', 'e', 'd', '\n',
        'e', 'n', 'j', 'o', 'i', 'n', 'i', 'n', 'g', '\n',
        'e', 'n', 'j', 'o', 'i', 'n', 's', '\n',
        'e', 'n', 'j', 'o', 'y', '\n',
        'e', 'n', 'j', 'o', 'y', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'e', 'n', 'j', 'o', 'y', 'a', 'b', 'l', 'e', '\n',
        'e', 'n', 'j', 'o', 'y', 'a', 'b', 'l', 'y', '\n',
        'e', 'n', 'j', 'o', 'y', 'e', 'd', '\n',
        'e', 'n', 'j', 'o', 'y', 'e', 'r', '\n',
        'e', 'n', 'j', 'o', 'y', 'i', 'n', 'g', '\n',
        'e', 'n', 'j', 'o', 'y', 'm', 'e', 'n', 't', '\n',
        'e', 'n', 'j', 'o', 'y', 'm', 'e', 'n', 't', 's', '\n',
        'e', 'n', 'j', 'o', 'y', 's', '\n',
        'e', 'n', 'l', 'a', 'c', 'e', '\n',
        'e', 'n', 'l', 'a', 'r', 'g', 'e', '\n',
        'e', 'n', 'l', 'a', 'r', 'g', 'e', 'd', '\n',
        'e', 'n', 'l', 'a', 'r', 'g', 'e', 'm', 'e', 'n', 't', '\n',
        'e', 'n', 'l', 'a', 'r', 'g', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'e', 'n', 'l', 'a', 'r', 'g', 'e', 'r', '\n',
        'e', 'n', 'l', 'a', 'r', 'g', 'e', 's', '\n',
        'e', 'n', 'l', 'a', 'r', 'g', 'i', 'n', 'g', '\n',
        'e', 'n', 'l', 'i', 'g', 'h', 't', 'e', 'n', '\n',
        'e', 'n', 'l', 'i', 'g', 'h', 't', 'e', 'n', 'e', 'd', '\n',
        'e', 'n', 'l', 'i', 'g', 'h', 't', 'e', 'n', 'i', 'n', 'g', '\n',
        'e', 'n', 'l', 'i', 'g', 'h', 't', 'e', 'n', 'm', 'e', 'n', 't', '\n',
        'e', 'n', 'l', 'i', 'g', 'h', 't', 'e', 'n', 's', '\n',
        'e', 'n', 'l', 'i', 's', 't', '\n',
        'e', 'n', 'l', 'i', 's', 't', 'e', 'd', '\n',
        'e', 'n', 'l', 'i', 's', 't', 'i', 'n', 'g', '\n',
        'e', 'n', 'l', 'i', 's', 't', 'm', 'e', 'n', 't', '\n',
        'e', 'n', 'l', 'i', 's', 't', 's', '\n',
        'e', 'n', 'l', 'i', 'v', 'e', 'n', '\n',
        'e', 'n', 'l', 'i', 'v', 'e', 'n', 'e', 'd', '\n',
        'e', 'n', 'l', 'i', 'v', 'e', 'n', 'i', 'n', 'g', '\n',
        'e', 'n', 'l', 'i', 'v', 'e', 'n', 's', '\n',
        'e', 'n', 'm', 'a', 's', 's', 'e', '\n',
        'e', 'n', 'm', 'e', 's', 'h', 'e', 'd', '\n',
        'e', 'n', 'm', 'i', 't', 'i', 'e', 's', '\n',
        'e', 'n', 'm', 'i', 't', 'y', '\n',
        'e', 'n', 'n', 'e', 'a', 'd', 's', '\n',
        'e', 'n', 'n', 'o', 'b', 'l', 'e', '\n',
        'e', 'n', 'n', 'o', 'b', 'l', 'e', 'd', '\n',
        'e', 'n', 'n', 'o', 'b', 'l', 'e', 's', '\n',
        'e', 'n', 'n', 'o', 'b', 'l', 'i', 'n', 'g', '\n',
        'e', 'n', 'n', 'u', 'i', '\n',
        'e', 'n', 'o', 'r', 'm', 'i', 't', 'i', 'e', 's', '\n',
        'e', 'n', 'o', 'r', 'm', 'i', 't', 'y', '\n',
        'e', 'n', 'o', 'r', 'm', 'o', 'u', 's', '\n',
        'e', 'n', 'o', 'r', 'm', 'o', 'u', 's', 'l', 'y', '\n',
        'e', 'n', 'o', 'u', 'g', 'h', '\n',
        'e', 'n', 'o', 'u', 'n', 'c', 'e', 'd', '\n',
        'e', 'n', 'o', 'u', 'n', 'c', 'e', 's', '\n',
        'e', 'n', 'q', 'u', 'i', 'r', 'e', '\n',
        'e', 'n', 'q', 'u', 'i', 'r', 'e', 'd', '\n',
        'e', 'n', 'q', 'u', 'i', 'r', 'e', 'r', '\n',
        'e', 'n', 'q', 'u', 'i', 'r', 'e', 'r', 's', '\n',
        'e', 'n', 'q', 'u', 'i', 'r', 'e', 's', '\n',
        'e', 'n', 'q', 'u', 'i', 'r', 'i', 'e', 's', '\n',
        'e', 'n', 'q', 'u', 'i', 'r', 'i', 'n', 'g', '\n',
        'e', 'n', 'q', 'u', 'i', 'r', 'i', 'n', 'g', 'l', 'y', '\n',
        'e', 'n', 'q', 'u', 'i', 'r', 'y', '\n',
        'e', 'n', 'r', 'a', 'g', 'e', '\n',
        'e', 'n', 'r', 'a', 'g', 'e', 'd', '\n',
        'e', 'n', 'r', 'a', 'g', 'e', 's', '\n',
        'e', 'n', 'r', 'a', 'g', 'i', 'n', 'g', '\n',
        'e', 'n', 'r', 'a', 'p', 't', 'u', 'r', 'e', 'd', '\n',
        'e', 'n', 'r', 'i', 'c', 'h', '\n',
        'e', 'n', 'r', 'i', 'c', 'h', 'e', 'd', '\n',
        'e', 'n', 'r', 'i', 'c', 'h', 'e', 's', '\n',
        'e', 'n', 'r', 'i', 'c', 'h', 'i', 'n', 'g', '\n',
        'e', 'n', 'r', 'i', 'c', 'h', 'm', 'e', 'n', 't', '\n',
        'e', 'n', 'r', 'i', 'c', 'h', 'm', 'e', 'n', 't', 's', '\n',
        'e', 'n', 'r', 'o', 'b', 'e', '\n',
        'e', 'n', 'r', 'o', 'b', 'e', 'd', '\n',
        'e', 'n', 'r', 'o', 'l', '\n',
        'e', 'n', 'r', 'o', 'l', 'l', '\n',
        'e', 'n', 'r', 'o', 'l', 'l', 'e', 'd', '\n',
        'e', 'n', 'r', 'o', 'l', 'l', 'i', 'n', 'g', '\n',
        'e', 'n', 'r', 'o', 'l', 'l', 's', '\n',
        'e', 'n', 'r', 'o', 'l', 'm', 'e', 'n', 't', '\n',
        'e', 'n', 'r', 'o', 'l', 'm', 'e', 'n', 't', 's', '\n',
        'e', 'n', 'r', 'o', 'l', 's', '\n',
        'e', 'n', 'r', 'o', 'u', 't', 'e', '\n',
        'e', 'n', 's', 'c', 'o', 'n', 'c', 'e', '\n',
        'e', 'n', 's', 'c', 'o', 'n', 'c', 'e', 'd', '\n',
        'e', 'n', 's', 'e', 'm', 'b', 'l', 'e', '\n',
        'e', 'n', 's', 'e', 'm', 'b', 'l', 'e', 's', '\n',
        'e', 'n', 's', 'h', 'r', 'i', 'n', 'e', '\n',
        'e', 'n', 's', 'h', 'r', 'i', 'n', 'e', 'd', '\n',
        'e', 'n', 's', 'h', 'r', 'i', 'n', 'e', 's', '\n',
        'e', 'n', 's', 'h', 'r', 'i', 'n', 'i', 'n', 'g', '\n',
        'e', 'n', 's', 'h', 'r', 'o', 'u', 'd', '\n',
        'e', 'n', 's', 'h', 'r', 'o', 'u', 'd', 'e', 'd', '\n',
        'e', 'n', 's', 'i', 'g', 'n', '\n',
        'e', 'n', 's', 'i', 'g', 'n', 's', '\n',
        'e', 'n', 's', 'l', 'a', 'v', 'e', '\n',
        'e', 'n', 's', 'l', 'a', 'v', 'e', 'd', '\n',
        'e', 'n', 's', 'l', 'a', 'v', 'e', 'm', 'e', 'n', 't', '\n',
        'e', 'n', 's', 'l', 'a', 'v', 'e', 's', '\n',
        'e', 'n', 's', 'l', 'a', 'v', 'i', 'n', 'g', '\n',
        'e', 'n', 's', 'n', 'a', 'r', 'e', '\n',
        'e', 'n', 's', 'n', 'a', 'r', 'e', 'd', '\n',
        'e', 'n', 's', 'n', 'a', 'r', 'i', 'n', 'g', '\n',
        'e', 'n', 's', 'n', 'a', 'r', 'l', '\n',
        'e', 'n', 's', 'u', 'e', '\n',
        'e', 'n', 's', 'u', 'e', 'd', '\n',
        'e', 'n', 's', 'u', 'e', 's', '\n',
        'e', 'n', 's', 'u', 'i', 'n', 'g', '\n',
        'e', 'n', 's', 'u', 'r', 'e', '\n',
        'e', 'n', 's', 'u', 'r', 'e', 'd', '\n',
        'e', 'n', 's', 'u', 'r', 'e', 's', '\n',
        'e', 'n', 's', 'u', 'r', 'i', 'n', 'g', '\n',
        'e', 'n', 't', 'a', 'b', 'l', 'a', 't', 'u', 'r', 'e', '\n',
        'e', 'n', 't', 'a', 'i', 'l', '\n',
        'e', 'n', 't', 'a', 'i', 'l', 'e', 'd', '\n',
        'e', 'n', 't', 'a', 'i', 'l', 'i', 'n', 'g', '\n',
        'e', 'n', 't', 'a', 'i', 'l', 'm', 'e', 'n', 't', '\n',
        'e', 'n', 't', 'a', 'i', 'l', 's', '\n',
        'e', 'n', 't', 'a', 'n', 'g', 'l', 'e', '\n',
        'e', 'n', 't', 'a', 'n', 'g', 'l', 'e', 'd', '\n',
        'e', 'n', 't', 'a', 'n', 'g', 'l', 'e', 'm', 'e', 'n', 't', '\n',
        'e', 'n', 't', 'a', 'n', 'g', 'l', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'e', 'n', 't', 'a', 'n', 'g', 'l', 'e', 'r', '\n',
        'e', 'n', 't', 'a', 'n', 'g', 'l', 'e', 's', '\n',
        'e', 'n', 't', 'a', 'n', 'g', 'l', 'i', 'n', 'g', '\n',
        'e', 'n', 't', 'e', 'n', 't', 'e', '\n',
        'e', 'n', 't', 'e', 'r', '\n',
        'e', 'n', 't', 'e', 'r', 'e', 'd', '\n',
        'e', 'n', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'e', 'n', 't', 'e', 'r', 'i', 't', 'i', 's', '\n',
        'e', 'n', 't', 'e', 'r', 'p', 'r', 'i', 's', 'e', '\n',
        'e', 'n', 't', 'e', 'r', 'p', 'r', 'i', 's', 'e', 's', '\n',
        'e', 'n', 't', 'e', 'r', 'p', 'r', 'i', 's', 'i', 'n', 'g', '\n',
        'e', 'n', 't', 'e', 'r', 's', '\n',
        'e', 'n', 't', 'e', 'r', 't', 'a', 'i', 'n', '\n',
        'e', 'n', 't', 'e', 'r', 't', 'a', 'i', 'n', 'e', 'd', '\n',
        'e', 'n', 't', 'e', 'r', 't', 'a', 'i', 'n', 'e', 'r', '\n',
        'e', 'n', 't', 'e', 'r', 't', 'a', 'i', 'n', 'e', 'r', 's', '\n',
        'e', 'n', 't', 'e', 'r', 't', 'a', 'i', 'n', 'i', 'n', 'g', '\n',
        'e', 'n', 't', 'e', 'r', 't', 'a', 'i', 'n', 'i', 'n', 'g', 'l', 'y', '\n',
        'e', 'n', 't', 'e', 'r', 't', 'a', 'i', 'n', 'm', 'e', 'n', 't', '\n',
        'e', 'n', 't', 'e', 'r', 't', 'a', 'i', 'n', 'm', 'e', 'n', 't', 's', '\n',
        'e', 'n', 't', 'e', 'r', 't', 'a', 'i', 'n', 's', '\n',
        'e', 'n', 't', 'h', 'a', 'l', 'p', 'i', 'e', 's', '\n',
        'e', 'n', 't', 'h', 'a', 'l', 'p', 'y', '\n',
        'e', 'n', 't', 'h', 'r', 'a', 'l', 'l', 'e', 'd', '\n',
        'e', 'n', 't', 'h', 'r', 'a', 'l', 'l', 'i', 'n', 'g', '\n',
        'e', 'n', 't', 'h', 'r', 'o', 'n', 'e', '\n',
        'e', 'n', 't', 'h', 'r', 'o', 'n', 'e', 'd', '\n',
        'e', 'n', 't', 'h', 'r', 'o', 'n', 'e', 'm', 'e', 'n', 't', '\n',
        'e', 'n', 't', 'h', 'u', 's', 'e', '\n',
        'e', 'n', 't', 'h', 'u', 's', 'e', 'd', '\n',
        'e', 'n', 't', 'h', 'u', 's', 'e', 's', '\n',
        'e', 'n', 't', 'h', 'u', 's', 'i', 'a', 's', 'm', '\n',
        'e', 'n', 't', 'h', 'u', 's', 'i', 'a', 's', 'm', 's', '\n',
        'e', 'n', 't', 'h', 'u', 's', 'i', 'a', 's', 't', '\n',
        'e', 'n', 't', 'h', 'u', 's', 'i', 'a', 's', 't', 'i', 'c', '\n',
        'e', 'n', 't', 'h', 'u', 's', 'i', 'a', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'e', 'n', 't', 'h', 'u', 's', 'i', 'a', 's', 't', 's', '\n',
        'e', 'n', 't', 'h', 'u', 's', 'i', 'n', 'g', '\n',
        'e', 'n', 't', 'i', 'c', 'e', '\n',
        'e', 'n', 't', 'i', 'c', 'e', 'd', '\n',
        'e', 'n', 't', 'i', 'c', 'e', 'm', 'e', 'n', 't', '\n',
        'e', 'n', 't', 'i', 'c', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'e', 'n', 't', 'i', 'c', 'e', 's', '\n',
        'e', 'n', 't', 'i', 'c', 'i', 'n', 'g', '\n',
        'e', 'n', 't', 'i', 'c', 'i', 'n', 'g', 'l', 'y', '\n',
        'e', 'n', 't', 'i', 'r', 'e', '\n',
        'e', 'n', 't', 'i', 'r', 'e', 'l', 'y', '\n',
        'e', 'n', 't', 'i', 'r', 'e', 's', '\n',
        'e', 'n', 't', 'i', 'r', 'e', 't', 'y', '\n',
        'e', 'n', 't', 'i', 't', 'i', 'e', 's', '\n',
        'e', 'n', 't', 'i', 't', 'l', 'e', '\n',
        'e', 'n', 't', 'i', 't', 'l', 'e', 'd', '\n',
        'e', 'n', 't', 'i', 't', 'l', 'e', 'm', 'e', 'n', 't', '\n',
        'e', 'n', 't', 'i', 't', 'l', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'e', 'n', 't', 'i', 't', 'l', 'e', 's', '\n',
        'e', 'n', 't', 'i', 't', 'l', 'i', 'n', 'g', '\n',
        'e', 'n', 't', 'i', 't', 'y', '\n',
        'e', 'n', 't', 'o', 'm', 'b', '\n',
        'e', 'n', 't', 'o', 'm', 'b', 'e', 'd', '\n',
        'e', 'n', 't', 'o', 'm', 'b', 'm', 'e', 'n', 't', '\n',
        'e', 'n', 't', 'o', 'm', 'b', 's', '\n',
        'e', 'n', 't', 'o', 'm', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'e', 'n', 't', 'o', 'm', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'e', 'n', 't', 'o', 'm', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'e', 'n', 't', 'o', 'm', 'o', 'l', 'o', 'g', 'y', '\n',
        'e', 'n', 't', 'o', 'u', 'r', 'a', 'g', 'e', '\n',
        'e', 'n', 't', 'r', 'a', 'i', 'l', 's', '\n',
        'e', 'n', 't', 'r', 'a', 'i', 'n', '\n',
        'e', 'n', 't', 'r', 'a', 'i', 'n', 'e', 'd', '\n',
        'e', 'n', 't', 'r', 'a', 'i', 'n', 'm', 'e', 'n', 't', '\n',
        'e', 'n', 't', 'r', 'a', 'n', 'c', 'e', '\n',
        'e', 'n', 't', 'r', 'a', 'n', 'c', 'e', 'd', '\n',
        'e', 'n', 't', 'r', 'a', 'n', 'c', 'e', 's', '\n',
        'e', 'n', 't', 'r', 'a', 'n', 'c', 'i', 'n', 'g', '\n',
        'e', 'n', 't', 'r', 'a', 'n', 't', '\n',
        'e', 'n', 't', 'r', 'a', 'n', 't', 's', '\n',
        'e', 'n', 't', 'r', 'a', 'p', '\n',
        'e', 'n', 't', 'r', 'a', 'p', 'm', 'e', 'n', 't', '\n',
        'e', 'n', 't', 'r', 'a', 'p', 'p', 'e', 'd', '\n',
        'e', 'n', 't', 'r', 'a', 'p', 'p', 'i', 'n', 'g', '\n',
        'e', 'n', 't', 'r', 'e', 'a', 't', '\n',
        'e', 'n', 't', 'r', 'e', 'a', 't', 'e', 'd', '\n',
        'e', 'n', 't', 'r', 'e', 'a', 't', 'i', 'e', 's', '\n',
        'e', 'n', 't', 'r', 'e', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'n', 't', 'r', 'e', 'a', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'e', 'n', 't', 'r', 'e', 'a', 't', 's', '\n',
        'e', 'n', 't', 'r', 'e', 'a', 't', 'y', '\n',
        'e', 'n', 't', 'r', 'e', 'e', '\n',
        'e', 'n', 't', 'r', 'e', 'n', 'c', 'h', '\n',
        'e', 'n', 't', 'r', 'e', 'n', 'c', 'h', 'e', 'd', '\n',
        'e', 'n', 't', 'r', 'e', 'n', 'c', 'h', 'i', 'n', 'g', '\n',
        'e', 'n', 't', 'r', 'e', 'n', 'c', 'h', 'm', 'e', 'n', 't', '\n',
        'e', 'n', 't', 'r', 'e', 'p', 'r', 'e', 'n', 'e', 'u', 'r', '\n',
        'e', 'n', 't', 'r', 'e', 'p', 'r', 'e', 'n', 'e', 'u', 'r', 'i', 'a', 'l', '\n',
        'e', 'n', 't', 'r', 'e', 'p', 'r', 'e', 'n', 'e', 'u', 'r', 's', '\n',
        'e', 'n', 't', 'r', 'e', 'p', 'r', 'e', 'n', 'e', 'u', 'r', 's', 'h', 'i', 'p', '\n',
        'e', 'n', 't', 'r', 'i', 'e', 's', '\n',
        'e', 'n', 't', 'r', 'o', 'p', 'i', 'c', '\n',
        'e', 'n', 't', 'r', 'o', 'p', 'y', '\n',
        'e', 'n', 't', 'r', 'u', 's', 't', '\n',
        'e', 'n', 't', 'r', 'u', 's', 't', 'e', 'd', '\n',
        'e', 'n', 't', 'r', 'u', 's', 't', 'i', 'n', 'g', '\n',
        'e', 'n', 't', 'r', 'u', 's', 't', 's', '\n',
        'e', 'n', 't', 'r', 'y', '\n',
        'e', 'n', 't', 'w', 'i', 'n', 'e', '\n',
        'e', 'n', 't', 'w', 'i', 'n', 'e', 'd', '\n',
        'e', 'n', 't', 'w', 'i', 'n', 'e', 's', '\n',
        'e', 'n', 't', 'w', 'i', 'n', 'i', 'n', 'g', '\n',
        'e', 'n', 'u', 'm', 'e', 'r', 'a', 'b', 'l', 'e', '\n',
        'e', 'n', 'u', 'm', 'e', 'r', 'a', 't', 'e', '\n',
        'e', 'n', 'u', 'm', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'e', 'n', 'u', 'm', 'e', 'r', 'a', 't', 'e', 's', '\n',
        'e', 'n', 'u', 'm', 'e', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'n', 'u', 'm', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'n', 'u', 'm', 'e', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'n', 'u', 'm', 'e', 'r', 'a', 't', 'o', 'r', '\n',
        'e', 'n', 'u', 'm', 'e', 'r', 'a', 't', 'o', 'r', 's', '\n',
        'e', 'n', 'u', 'n', 'c', 'i', 'a', 't', 'e', '\n',
        'e', 'n', 'u', 'n', 'c', 'i', 'a', 't', 'e', 'd', '\n',
        'e', 'n', 'u', 'n', 'c', 'i', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'n', 'u', 'n', 'c', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'n', 'v', 'e', 'l', 'o', 'p', '\n',
        'e', 'n', 'v', 'e', 'l', 'o', 'p', 'e', '\n',
        'e', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'd', '\n',
        'e', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'r', '\n',
        'e', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 'r', 's', '\n',
        'e', 'n', 'v', 'e', 'l', 'o', 'p', 'e', 's', '\n',
        'e', 'n', 'v', 'e', 'l', 'o', 'p', 'i', 'n', 'g', '\n',
        'e', 'n', 'v', 'e', 'l', 'o', 'p', 's', '\n',
        'e', 'n', 'v', 'i', 'a', 'b', 'l', 'e', '\n',
        'e', 'n', 'v', 'i', 'a', 'b', 'l', 'y', '\n',
        'e', 'n', 'v', 'i', 'e', 'd', '\n',
        'e', 'n', 'v', 'i', 'e', 's', '\n',
        'e', 'n', 'v', 'i', 'o', 'u', 's', '\n',
        'e', 'n', 'v', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'e', 'n', 'v', 'i', 'r', 'o', 'n', '\n',
        'e', 'n', 'v', 'i', 'r', 'o', 'n', 'm', 'e', 'n', 't', '\n',
        'e', 'n', 'v', 'i', 'r', 'o', 'n', 'm', 'e', 'n', 't', 'a', 'l', '\n',
        'e', 'n', 'v', 'i', 'r', 'o', 'n', 'm', 'e', 'n', 't', 'a', 'l', 'i', 's', 'm', '\n',
        'e', 'n', 'v', 'i', 'r', 'o', 'n', 'm', 'e', 'n', 't', 'a', 'l', 'i', 's', 't', '\n',
        'e', 'n', 'v', 'i', 'r', 'o', 'n', 'm', 'e', 'n', 't', 'a', 'l', 'i', 's', 't', 's', '\n',
        'e', 'n', 'v', 'i', 'r', 'o', 'n', 'm', 'e', 'n', 't', 'a', 'l', 'l', 'y', '\n',
        'e', 'n', 'v', 'i', 'r', 'o', 'n', 'm', 'e', 'n', 't', 's', '\n',
        'e', 'n', 'v', 'i', 'r', 'o', 'n', 's', '\n',
        'e', 'n', 'v', 'i', 's', 'a', 'g', 'e', '\n',
        'e', 'n', 'v', 'i', 's', 'a', 'g', 'e', 'd', '\n',
        'e', 'n', 'v', 'i', 's', 'a', 'g', 'e', 's', '\n',
        'e', 'n', 'v', 'i', 's', 'a', 'g', 'i', 'n', 'g', '\n',
        'e', 'n', 'v', 'i', 's', 'i', 'o', 'n', '\n',
        'e', 'n', 'v', 'i', 's', 'i', 'o', 'n', 'e', 'd', '\n',
        'e', 'n', 'v', 'o', 'y', '\n',
        'e', 'n', 'v', 'o', 'y', 's', '\n',
        'e', 'n', 'v', 'y', '\n',
        'e', 'n', 'v', 'y', 'i', 'n', 'g', '\n',
        'e', 'n', 'w', 'r', 'a', 'p', '\n',
        'e', 'n', 'z', 'y', 'm', 'a', 't', 'i', 'c', '\n',
        'e', 'n', 'z', 'y', 'm', 'e', '\n',
        'e', 'n', 'z', 'y', 'm', 'e', 's', '\n',
        'e', 'o', 'n', '\n',
        'e', 'o', 'n', 's', '\n',
        'e', 'o', 's', 'i', 'n', '\n',
        'e', 'p', 'a', 'u', 'l', 'e', 't', 't', 'e', 's', '\n',
        'e', 'p', 'h', 'e', 'm', 'e', 'r', 'a', '\n',
        'e', 'p', 'h', 'e', 'm', 'e', 'r', 'a', 'l', '\n',
        'e', 'p', 'h', 'e', 'm', 'e', 'r', 'i', 's', '\n',
        'e', 'p', 'h', 'o', 'r', '\n',
        'e', 'p', 'i', 'c', '\n',
        'e', 'p', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'e', 'p', 'i', 'c', 'a', 'r', 'p', '\n',
        'e', 'p', 'i', 'c', 'e', 'n', 't', 'r', 'e', '\n',
        'e', 'p', 'i', 'c', 's', '\n',
        'e', 'p', 'i', 'c', 'u', 'r', 'e', '\n',
        'e', 'p', 'i', 'c', 'u', 'r', 'e', 'a', 'n', '\n',
        'e', 'p', 'i', 'c', 'y', 'c', 'l', 'e', 's', '\n',
        'e', 'p', 'i', 'c', 'y', 'c', 'l', 'o', 'i', 'd', '\n',
        'e', 'p', 'i', 'd', 'e', 'm', 'i', 'c', '\n',
        'e', 'p', 'i', 'd', 'e', 'm', 'i', 'c', 's', '\n',
        'e', 'p', 'i', 'd', 'e', 'm', 'i', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'e', 'p', 'i', 'd', 'e', 'm', 'i', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'e', 'p', 'i', 'd', 'e', 'm', 'i', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'e', 'p', 'i', 'd', 'e', 'm', 'i', 'o', 'l', 'o', 'g', 'y', '\n',
        'e', 'p', 'i', 'd', 'e', 'r', 'm', 'a', 'l', '\n',
        'e', 'p', 'i', 'd', 'e', 'r', 'm', 'i', 's', '\n',
        'e', 'p', 'i', 'd', 'u', 'r', 'a', 'l', '\n',
        'e', 'p', 'i', 'g', 'e', 'n', 'e', 't', 'i', 'c', '\n',
        'e', 'p', 'i', 'g', 'o', 'n', '\n',
        'e', 'p', 'i', 'g', 'o', 'n', 'e', 's', '\n',
        'e', 'p', 'i', 'g', 'r', 'a', 'm', '\n',
        'e', 'p', 'i', 'g', 'r', 'a', 'm', 'm', 'a', 't', 'i', 'c', '\n',
        'e', 'p', 'i', 'g', 'r', 'a', 'm', 's', '\n',
        'e', 'p', 'i', 'g', 'r', 'a', 'p', 'h', '\n',
        'e', 'p', 'i', 'g', 'r', 'a', 'p', 'h', 'i', 'c', 'a', 'l', '\n',
        'e', 'p', 'i', 'g', 'r', 'a', 'p', 'h', 'y', '\n',
        'e', 'p', 'i', 'l', 'e', 'p', 's', 'y', '\n',
        'e', 'p', 'i', 'l', 'e', 'p', 't', 'i', 'c', '\n',
        'e', 'p', 'i', 'l', 'e', 'p', 't', 'i', 'c', 's', '\n',
        'e', 'p', 'i', 'l', 'o', 'g', 'u', 'e', '\n',
        'e', 'p', 'i', 'n', 'e', 'p', 'h', 'r', 'i', 'n', 'e', '\n',
        'e', 'p', 'i', 'p', 'h', 'a', 'n', 'i', 'e', 's', '\n',
        'e', 'p', 'i', 'p', 'h', 'e', 'n', 'o', 'm', 'e', 'n', 'a', '\n',
        'e', 'p', 'i', 'p', 'h', 'e', 'n', 'o', 'm', 'e', 'n', 'o', 'n', '\n',
        'e', 'p', 'i', 's', 'c', 'o', 'p', 'a', 'c', 'y', '\n',
        'e', 'p', 'i', 's', 'c', 'o', 'p', 'a', 'l', '\n',
        'e', 'p', 'i', 's', 'c', 'o', 'p', 'a', 'l', 'i', 'a', 'n', '\n',
        'e', 'p', 'i', 's', 'c', 'o', 'p', 'a', 't', 'e', '\n',
        'e', 'p', 'i', 's', 'o', 'd', 'e', '\n',
        'e', 'p', 'i', 's', 'o', 'd', 'e', 's', '\n',
        'e', 'p', 'i', 's', 'o', 'd', 'i', 'c', '\n',
        'e', 'p', 'i', 's', 'o', 'd', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'e', 'p', 'i', 's', 't', 'e', 'm', 'i', 'c', '\n',
        'e', 'p', 'i', 's', 't', 'e', 'm', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'e', 'p', 'i', 's', 't', 'e', 'm', 'o', 'l', 'o', 'g', 'y', '\n',
        'e', 'p', 'i', 's', 't', 'l', 'e', '\n',
        'e', 'p', 'i', 's', 't', 'l', 'e', 's', '\n',
        'e', 'p', 'i', 's', 't', 'o', 'l', 'a', 'r', 'y', '\n',
        'e', 'p', 'i', 't', 'a', 'p', '\n',
        'e', 'p', 'i', 't', 'a', 'p', 'h', '\n',
        'e', 'p', 'i', 't', 'a', 'p', 'h', 's', '\n',
        'e', 'p', 'i', 't', 'a', 'x', 'i', 'a', 'l', '\n',
        'e', 'p', 'i', 't', 'a', 'x', 'y', '\n',
        'e', 'p', 'i', 't', 'h', 'e', 'l', 'i', 'a', 'l', '\n',
        'e', 'p', 'i', 't', 'h', 'e', 'l', 'i', 'u', 'm', '\n',
        'e', 'p', 'i', 't', 'h', 'e', 't', '\n',
        'e', 'p', 'i', 't', 'h', 'e', 't', 'i', 'c', '\n',
        'e', 'p', 'i', 't', 'h', 'e', 't', 's', '\n',
        'e', 'p', 'i', 't', 'o', 'm', 'e', '\n',
        'e', 'p', 'i', 't', 'o', 'm', 'i', 's', 'e', '\n',
        'e', 'p', 'i', 't', 'o', 'm', 'i', 's', 'e', 'd', '\n',
        'e', 'p', 'i', 't', 'o', 'm', 'i', 's', 'e', 's', '\n',
        'e', 'p', 'o', 'c', 'h', '\n',
        'e', 'p', 'o', 'c', 'h', 'a', 'l', '\n',
        'e', 'p', 'o', 'c', 'h', 's', '\n',
        'e', 'p', 'o', 'x', 'i', 'e', 's', '\n',
        'e', 'p', 'o', 'x', 'y', '\n',
        'e', 'p', 's', 'i', 'l', 'o', 'n', '\n',
        'e', 'q', 'u', 'a', 'b', 'l', 'e', '\n',
        'e', 'q', 'u', 'a', 'b', 'l', 'y', '\n',
        'e', 'q', 'u', 'a', 'l', '\n',
        'e', 'q', 'u', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'q', 'u', 'a', 'l', 'i', 's', 'e', '\n',
        'e', 'q', 'u', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'e', 'q', 'u', 'a', 'l', 'i', 's', 'e', 'r', '\n',
        'e', 'q', 'u', 'a', 'l', 'i', 's', 'e', 'r', 's', '\n',
        'e', 'q', 'u', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'e', 'q', 'u', 'a', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'e', 'q', 'u', 'a', 'l', 'i', 't', 'y', '\n',
        'e', 'q', 'u', 'a', 'l', 'l', 'e', 'd', '\n',
        'e', 'q', 'u', 'a', 'l', 'l', 'i', 'n', 'g', '\n',
        'e', 'q', 'u', 'a', 'l', 'l', 'y', '\n',
        'e', 'q', 'u', 'a', 'l', 's', '\n',
        'e', 'q', 'u', 'a', 'n', 'i', 'm', 'i', 't', 'y', '\n',
        'e', 'q', 'u', 'a', 't', 'e', '\n',
        'e', 'q', 'u', 'a', 't', 'e', 'd', '\n',
        'e', 'q', 'u', 'a', 't', 'e', 's', '\n',
        'e', 'q', 'u', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'q', 'u', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'q', 'u', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'q', 'u', 'a', 't', 'o', 'r', '\n',
        'e', 'q', 'u', 'a', 't', 'o', 'r', 'i', 'a', 'l', '\n',
        'e', 'q', 'u', 'e', 'r', 'r', 'y', '\n',
        'e', 'q', 'u', 'e', 's', 't', 'r', 'i', 'a', 'n', '\n',
        'e', 'q', 'u', 'e', 's', 't', 'r', 'i', 'a', 'n', 'i', 's', 'm', '\n',
        'e', 'q', 'u', 'i', 'a', 'n', 'g', 'u', 'l', 'a', 'r', '\n',
        'e', 'q', 'u', 'i', 'd', 'i', 's', 't', 'a', 'n', 't', '\n',
        'e', 'q', 'u', 'i', 'l', 'a', 't', 'e', 'r', 'a', 'l', '\n',
        'e', 'q', 'u', 'i', 'l', 'i', 'b', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'q', 'u', 'i', 'l', 'i', 'b', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'q', 'u', 'i', 'l', 'i', 'b', 'r', 'i', 'a', '\n',
        'e', 'q', 'u', 'i', 'l', 'i', 'b', 'r', 'i', 'u', 'm', '\n',
        'e', 'q', 'u', 'i', 'n', 'e', '\n',
        'e', 'q', 'u', 'i', 'n', 'o', 'c', 't', 'i', 'a', 'l', '\n',
        'e', 'q', 'u', 'i', 'n', 'o', 'x', '\n',
        'e', 'q', 'u', 'i', 'n', 'o', 'x', 'e', 's', '\n',
        'e', 'q', 'u', 'i', 'p', '\n',
        'e', 'q', 'u', 'i', 'p', 'a', 'r', 't', 'i', 't', 'i', 'o', 'n', '\n',
        'e', 'q', 'u', 'i', 'p', 'm', 'e', 'n', 't', '\n',
        'e', 'q', 'u', 'i', 'p', 'm', 'e', 'n', 't', 's', '\n',
        'e', 'q', 'u', 'i', 'p', 'p', 'e', 'd', '\n',
        'e', 'q', 'u', 'i', 'p', 'p', 'i', 'n', 'g', '\n',
        'e', 'q', 'u', 'i', 'p', 's', '\n',
        'e', 'q', 'u', 'i', 't', 'a', 'b', 'l', 'e', '\n',
        'e', 'q', 'u', 'i', 't', 'a', 'b', 'l', 'y', '\n',
        'e', 'q', 'u', 'i', 't', 'i', 'e', 's', '\n',
        'e', 'q', 'u', 'i', 't', 'y', '\n',
        'e', 'q', 'u', 'i', 'v', 'a', 'l', 'e', 'n', 'c', 'e', '\n',
        'e', 'q', 'u', 'i', 'v', 'a', 'l', 'e', 'n', 'c', 'e', 's', '\n',
        'e', 'q', 'u', 'i', 'v', 'a', 'l', 'e', 'n', 't', '\n',
        'e', 'q', 'u', 'i', 'v', 'a', 'l', 'e', 'n', 't', 'l', 'y', '\n',
        'e', 'q', 'u', 'i', 'v', 'a', 'l', 'e', 'n', 't', 's', '\n',
        'e', 'q', 'u', 'i', 'v', 'o', 'c', 'a', 'l', '\n',
        'e', 'q', 'u', 'i', 'v', 'o', 'c', 'a', 't', 'e', 'd', '\n',
        'e', 'q', 'u', 'i', 'v', 'o', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'q', 'u', 'i', 'v', 'o', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'q', 'u', 'i', 'v', 'o', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'r', 'a', '\n',
        'e', 'r', 'a', 'd', 'i', 'c', 'a', 't', 'e', '\n',
        'e', 'r', 'a', 'd', 'i', 'c', 'a', 't', 'e', 'd', '\n',
        'e', 'r', 'a', 'd', 'i', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'r', 'a', 'd', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'r', 'a', 's', '\n',
        'e', 'r', 'a', 's', 'a', 'b', 'l', 'e', '\n',
        'e', 'r', 'a', 's', 'e', '\n',
        'e', 'r', 'a', 's', 'e', 'd', '\n',
        'e', 'r', 'a', 's', 'e', 'r', '\n',
        'e', 'r', 'a', 's', 'e', 'r', 's', '\n',
        'e', 'r', 'a', 's', 'e', 's', '\n',
        'e', 'r', 'a', 's', 'i', 'n', 'g', '\n',
        'e', 'r', 'a', 's', 'u', 'r', 'e', '\n',
        'e', 'r', 'a', 's', 'u', 'r', 'e', 's', '\n',
        'e', 'r', 'b', 'i', 'u', 'm', '\n',
        'e', 'r', 'e', '\n',
        'e', 'r', 'e', 'c', 't', '\n',
        'e', 'r', 'e', 'c', 't', 'e', 'd', '\n',
        'e', 'r', 'e', 'c', 't', 'e', 'r', '\n',
        'e', 'r', 'e', 'c', 't', 'i', 'l', 'e', '\n',
        'e', 'r', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'e', 'r', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'e', 'r', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'r', 'e', 'c', 't', 'l', 'y', '\n',
        'e', 'r', 'e', 'c', 't', 's', '\n',
        'e', 'r', 'g', '\n',
        'e', 'r', 'g', 'o', '\n',
        'e', 'r', 'g', 'o', 'd', 'i', 'c', '\n',
        'e', 'r', 'g', 'o', 'n', 'o', 'm', 'i', 'c', '\n',
        'e', 'r', 'g', 'o', 'n', 'o', 'm', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'e', 'r', 'g', 'o', 'n', 'o', 'm', 'i', 'c', 's', '\n',
        'e', 'r', 'g', 'o', 'p', 'h', 'o', 'b', 'i', 'a', '\n',
        'e', 'r', 'g', 'o', 't', '\n',
        'e', 'r', 'g', 's', '\n',
        'e', 'r', 'i', 'c', 'a', '\n',
        'e', 'r', 'i', 'c', 'a', 's', '\n',
        'e', 'r', 'i', 't', 'r', 'e', 'a', '\n',
        'e', 'r', 'm', 'i', 'n', 'e', '\n',
        'e', 'r', 'o', 'd', 'e', '\n',
        'e', 'r', 'o', 'd', 'e', 'd', '\n',
        'e', 'r', 'o', 'd', 'e', 's', '\n',
        'e', 'r', 'o', 'd', 'i', 'n', 'g', '\n',
        'e', 'r', 'o', 'g', 'e', 'n', 'o', 'u', 's', '\n',
        'e', 'r', 'o', 's', '\n',
        'e', 'r', 'o', 's', 'e', '\n',
        'e', 'r', 'o', 's', 'i', 'o', 'n', '\n',
        'e', 'r', 'o', 's', 'i', 'o', 'n', 'a', 'l', '\n',
        'e', 'r', 'o', 's', 'i', 'o', 'n', 's', '\n',
        'e', 'r', 'o', 's', 'i', 'v', 'e', '\n',
        'e', 'r', 'o', 't', 'i', 'c', '\n',
        'e', 'r', 'o', 't', 'i', 'c', 'a', '\n',
        'e', 'r', 'o', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'e', 'r', 'o', 't', 'i', 'c', 'i', 's', 'm', '\n',
        'e', 'r', 'r', '\n',
        'e', 'r', 'r', 'a', 'n', 'd', '\n',
        'e', 'r', 'r', 'a', 'n', 'd', 's', '\n',
        'e', 'r', 'r', 'a', 'n', 't', '\n',
        'e', 'r', 'r', 'a', 't', 'a', '\n',
        'e', 'r', 'r', 'a', 't', 'i', 'c', '\n',
        'e', 'r', 'r', 'a', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'e', 'r', 'r', 'a', 't', 'u', 'm', '\n',
        'e', 'r', 'r', 'e', 'd', '\n',
        'e', 'r', 'r', 'i', 'n', 'g', '\n',
        'e', 'r', 'r', 'o', 'n', 'e', 'o', 'u', 's', '\n',
        'e', 'r', 'r', 'o', 'n', 'e', 'o', 'u', 's', 'l', 'y', '\n',
        'e', 'r', 'r', 'o', 'r', '\n',
        'e', 'r', 'r', 'o', 'r', 's', '\n',
        'e', 'r', 'r', 's', '\n',
        'e', 'r', 's', 'a', 't', 'z', '\n',
        'e', 'r', 's', 't', '\n',
        'e', 'r', 's', 't', 'w', 'h', 'i', 'l', 'e', '\n',
        'e', 'r', 'u', 'd', 'i', 't', 'e', '\n',
        'e', 'r', 'u', 'd', 'i', 't', 'i', 'o', 'n', '\n',
        'e', 'r', 'u', 'p', 't', '\n',
        'e', 'r', 'u', 'p', 't', 'e', 'd', '\n',
        'e', 'r', 'u', 'p', 't', 'i', 'n', 'g', '\n',
        'e', 'r', 'u', 'p', 't', 'i', 'o', 'n', '\n',
        'e', 'r', 'u', 'p', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'r', 'u', 'p', 't', 'i', 'v', 'e', '\n',
        'e', 'r', 'u', 'p', 't', 's', '\n',
        'e', 'r', 'y', 's', 'i', 'p', 'e', 'l', 'a', 's', '\n',
        'e', 's', 'a', 'u', '\n',
        'e', 's', 'c', 'a', 'l', 'a', 'd', 'e', '\n',
        'e', 's', 'c', 'a', 'l', 'a', 't', 'e', '\n',
        'e', 's', 'c', 'a', 'l', 'a', 't', 'e', 'd', '\n',
        'e', 's', 'c', 'a', 'l', 'a', 't', 'e', 's', '\n',
        'e', 's', 'c', 'a', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 's', 'c', 'a', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 's', 'c', 'a', 'l', 'a', 't', 'o', 'r', '\n',
        'e', 's', 'c', 'a', 'l', 'a', 't', 'o', 'r', 's', '\n',
        'e', 's', 'c', 'a', 'p', 'a', 'd', 'e', '\n',
        'e', 's', 'c', 'a', 'p', 'a', 'd', 'e', 's', '\n',
        'e', 's', 'c', 'a', 'p', 'e', '\n',
        'e', 's', 'c', 'a', 'p', 'e', 'd', '\n',
        'e', 's', 'c', 'a', 'p', 'e', 'e', '\n',
        'e', 's', 'c', 'a', 'p', 'e', 'e', 's', '\n',
        'e', 's', 'c', 'a', 'p', 'e', 'm', 'e', 'n', 't', '\n',
        'e', 's', 'c', 'a', 'p', 'e', 's', '\n',
        'e', 's', 'c', 'a', 'p', 'i', 'n', 'g', '\n',
        'e', 's', 'c', 'a', 'p', 'i', 's', 'm', '\n',
        'e', 's', 'c', 'a', 'p', 'i', 's', 't', '\n',
        'e', 's', 'c', 'a', 'p', 'o', 'l', 'o', 'g', 'y', '\n',
        'e', 's', 'c', 'a', 'r', 'p', '\n',
        'e', 's', 'c', 'a', 'r', 'p', 'm', 'e', 'n', 't', '\n',
        'e', 's', 'c', 'a', 'r', 'p', 'm', 'e', 'n', 't', 's', '\n',
        'e', 's', 'c', 'a', 'r', 'p', 's', '\n',
        'e', 's', 'c', 'h', 'a', 't', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'e', 's', 'c', 'h', 'a', 't', 'o', 'l', 'o', 'g', 'y', '\n',
        'e', 's', 'c', 'h', 'e', 'w', '\n',
        'e', 's', 'c', 'h', 'e', 'w', 'e', 'd', '\n',
        'e', 's', 'c', 'h', 'e', 'w', 'i', 'n', 'g', '\n',
        'e', 's', 'c', 'h', 'e', 'w', 's', '\n',
        'e', 's', 'c', 'o', 'r', 't', '\n',
        'e', 's', 'c', 'o', 'r', 't', 'e', 'd', '\n',
        'e', 's', 'c', 'o', 'r', 't', 'i', 'n', 'g', '\n',
        'e', 's', 'c', 'o', 'r', 't', 's', '\n',
        'e', 's', 'c', 'u', 'd', 'o', '\n',
        'e', 's', 'k', 'i', 'm', 'o', '\n',
        'e', 's', 'o', 't', 'e', 'r', 'i', 'c', '\n',
        'e', 's', 'o', 't', 'e', 'r', 'i', 'c', 'a', '\n',
        'e', 's', 'o', 't', 'e', 'r', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'e', 's', 'p', 'a', 'd', 'r', 'i', 'l', 'l', 'e', 's', '\n',
        'e', 's', 'p', 'e', 'c', 'i', 'a', 'l', '\n',
        'e', 's', 'p', 'e', 'c', 'i', 'a', 'l', 'l', 'y', '\n',
        'e', 's', 'p', 'i', 'e', 'd', '\n',
        'e', 's', 'p', 'i', 'o', 'n', 'a', 'g', 'e', '\n',
        'e', 's', 'p', 'l', 'a', 'n', 'a', 'd', 'e', '\n',
        'e', 's', 'p', 'o', 'u', 's', 'a', 'l', '\n',
        'e', 's', 'p', 'o', 'u', 's', 'e', '\n',
        'e', 's', 'p', 'o', 'u', 's', 'e', 'd', '\n',
        'e', 's', 'p', 'o', 'u', 's', 'e', 's', '\n',
        'e', 's', 'p', 'o', 'u', 's', 'i', 'n', 'g', '\n',
        'e', 's', 'p', 'r', 'e', 's', 's', 'o', '\n',
        'e', 's', 'p', 'r', 'i', 't', '\n',
        'e', 's', 'p', 'y', '\n',
        'e', 's', 'p', 'y', 'i', 'n', 'g', '\n',
        'e', 's', 'q', 'u', 'i', 'r', 'e', '\n',
        'e', 's', 'q', 'u', 'i', 'r', 'e', 's', '\n',
        'e', 's', 's', 'a', 'y', '\n',
        'e', 's', 's', 'a', 'y', 'e', 'd', '\n',
        'e', 's', 's', 'a', 'y', 'i', 's', 't', '\n',
        'e', 's', 's', 'a', 'y', 'i', 's', 't', 's', '\n',
        'e', 's', 's', 'a', 'y', 's', '\n',
        'e', 's', 's', 'e', 'n', '\n',
        'e', 's', 's', 'e', 'n', 'c', 'e', '\n',
        'e', 's', 's', 'e', 'n', 'c', 'e', 's', '\n',
        'e', 's', 's', 'e', 'n', 't', 'i', 'a', 'l', '\n',
        'e', 's', 's', 'e', 'n', 't', 'i', 'a', 'l', 'i', 's', 'm', '\n',
        'e', 's', 's', 'e', 'n', 't', 'i', 'a', 'l', 'i', 's', 't', '\n',
        'e', 's', 's', 'e', 'n', 't', 'i', 'a', 'l', 'l', 'y', '\n',
        'e', 's', 's', 'e', 'n', 't', 'i', 'a', 'l', 's', '\n',
        'e', 's', 't', '\n',
        'e', 's', 't', 'a', 'b', 'l', 'i', 's', 'h', '\n',
        'e', 's', 't', 'a', 'b', 'l', 'i', 's', 'h', 'e', 'd', '\n',
        'e', 's', 't', 'a', 'b', 'l', 'i', 's', 'h', 'e', 's', '\n',
        'e', 's', 't', 'a', 'b', 'l', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'e', 's', 't', 'a', 'b', 'l', 'i', 's', 'h', 'm', 'e', 'n', 't', '\n',
        'e', 's', 't', 'a', 'b', 'l', 'i', 's', 'h', 'm', 'e', 'n', 't', 's', '\n',
        'e', 's', 't', 'a', 't', 'e', '\n',
        'e', 's', 't', 'a', 't', 'e', 's', '\n',
        'e', 's', 't', 'e', 'e', 'm', '\n',
        'e', 's', 't', 'e', 'e', 'm', 'e', 'd', '\n',
        'e', 's', 't', 'e', 'e', 'm', 's', '\n',
        'e', 's', 't', 'e', 'r', '\n',
        'e', 's', 't', 'e', 'r', 's', '\n',
        'e', 's', 't', 'h', 'e', 't', 'e', '\n',
        'e', 's', 't', 'h', 'e', 't', 'i', 'c', '\n',
        'e', 's', 't', 'i', 'm', 'a', 'b', 'l', 'e', '\n',
        'e', 's', 't', 'i', 'm', 'a', 't', 'e', '\n',
        'e', 's', 't', 'i', 'm', 'a', 't', 'e', 'd', '\n',
        'e', 's', 't', 'i', 'm', 'a', 't', 'e', 's', '\n',
        'e', 's', 't', 'i', 'm', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 's', 't', 'i', 'm', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 's', 't', 'i', 'm', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'e', 's', 't', 'i', 'm', 'a', 't', 'o', 'r', '\n',
        'e', 's', 't', 'i', 'm', 'a', 't', 'o', 'r', 's', '\n',
        'e', 's', 't', 'o', 'n', 'i', 'a', '\n',
        'e', 's', 't', 'r', 'a', 'n', 'g', 'e', 'd', '\n',
        'e', 's', 't', 'r', 'a', 'n', 'g', 'e', 'm', 'e', 'n', 't', '\n',
        'e', 's', 't', 'r', 'a', 'n', 'g', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'e', 's', 't', 'u', 'a', 'r', 'i', 'e', 's', '\n',
        'e', 's', 't', 'u', 'a', 'r', 'i', 'n', 'e', '\n',
        'e', 's', 't', 'u', 'a', 'r', 'y', '\n',
        'e', 't', 'a', '\n',
        'e', 't', 'a', 'l', '\n',
        'e', 't', 'c', 'e', 't', 'e', 'r', 'a', '\n',
        'e', 't', 'c', 'h', '\n',
        'e', 't', 'c', 'h', 'e', 'd', '\n',
        'e', 't', 'c', 'h', 'e', 'r', '\n',
        'e', 't', 'c', 'h', 'e', 'r', 's', '\n',
        'e', 't', 'c', 'h', 'e', 's', '\n',
        'e', 't', 'c', 'h', 'i', 'n', 'g', '\n',
        'e', 't', 'c', 'h', 'i', 'n', 'g', 's', '\n',
        'e', 't', 'e', 'r', 'n', 'a', 'l', '\n',
        'e', 't', 'e', 'r', 'n', 'a', 'l', 'l', 'y', '\n',
        'e', 't', 'e', 'r', 'n', 'i', 't', 'y', '\n',
        'e', 't', 'h', 'a', 'n', 'e', '\n',
        'e', 't', 'h', 'a', 'n', 'o', 'l', '\n',
        'e', 't', 'h', 'e', 'r', '\n',
        'e', 't', 'h', 'e', 'r', 'e', 'a', 'l', '\n',
        'e', 't', 'h', 'e', 'r', 'e', 'a', 'l', 'l', 'y', '\n',
        'e', 't', 'h', 'e', 'r', 'i', 's', 'e', 'd', '\n',
        'e', 't', 'h', 'i', 'c', '\n',
        'e', 't', 'h', 'i', 'c', 'a', 'l', '\n',
        'e', 't', 'h', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'e', 't', 'h', 'i', 'c', 'i', 's', 't', '\n',
        'e', 't', 'h', 'i', 'c', 's', '\n',
        'e', 't', 'h', 'i', 'o', 'p', 'i', 'a', '\n',
        'e', 't', 'h', 'n', 'i', 'c', '\n',
        'e', 't', 'h', 'n', 'i', 'c', 'a', 'l', '\n',
        'e', 't', 'h', 'n', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'e', 't', 'h', 'n', 'i', 'c', 'i', 't', 'y', '\n',
        'e', 't', 'h', 'n', 'o', 'c', 'e', 'n', 't', 'r', 'i', 'c', '\n',
        'e', 't', 'h', 'n', 'o', 'g', 'r', 'a', 'p', 'h', 'e', 'r', '\n',
        'e', 't', 'h', 'n', 'o', 'g', 'r', 'a', 'p', 'h', 'e', 'r', 's', '\n',
        'e', 't', 'h', 'n', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', '\n',
        'e', 't', 'h', 'n', 'o', 'g', 'r', 'a', 'p', 'h', 'y', '\n',
        'e', 't', 'h', 'n', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'e', 't', 'h', 'n', 'o', 'l', 'o', 'g', 'y', '\n',
        'e', 't', 'h', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'e', 't', 'h', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'e', 't', 'h', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'e', 't', 'h', 'o', 'l', 'o', 'g', 'y', '\n',
        'e', 't', 'h', 'o', 's', '\n',
        'e', 't', 'h', 'y', 'l', '\n',
        'e', 't', 'h', 'y', 'l', 'e', 'n', 'e', '\n',
        'e', 't', 'i', 'q', 'u', 'e', 't', 't', 'e', '\n',
        'e', 't', 'n', 'a', '\n',
        'e', 't', 'u', 'd', 'e', 's', '\n',
        'e', 't', 'u', 'i', '\n',
        'e', 't', 'y', 'm', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'e', 't', 'y', 'm', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'e', 't', 'y', 'm', 'o', 'l', 'o', 'g', 'i', 'e', 's', '\n',
        'e', 't', 'y', 'm', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'e', 't', 'y', 'm', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'e', 't', 'y', 'm', 'o', 'l', 'o', 'g', 'y', '\n',
        'e', 'u', 'c', 'a', 'l', 'y', 'p', 't', 'u', 's', '\n',
        'e', 'u', 'g', 'e', 'n', 'i', 'c', '\n',
        'e', 'u', 'g', 'e', 'n', 'i', 'c', 's', '\n',
        'e', 'u', 'k', 'a', 'r', 'y', 'o', 't', 'e', '\n',
        'e', 'u', 'k', 'a', 'r', 'y', 'o', 't', 'e', 's', '\n',
        'e', 'u', 'k', 'a', 'r', 'y', 'o', 't', 'i', 'c', '\n',
        'e', 'u', 'l', 'o', 'g', 'i', 'e', 's', '\n',
        'e', 'u', 'l', 'o', 'g', 'i', 's', 'e', '\n',
        'e', 'u', 'l', 'o', 'g', 'i', 's', 'e', 's', '\n',
        'e', 'u', 'l', 'o', 'g', 'i', 's', 'i', 'n', 'g', '\n',
        'e', 'u', 'l', 'o', 'g', 'i', 's', 't', 'i', 'c', '\n',
        'e', 'u', 'l', 'o', 'g', 'y', '\n',
        'e', 'u', 'n', 'u', 'c', 'h', '\n',
        'e', 'u', 'n', 'u', 'c', 'h', 's', '\n',
        'e', 'u', 'p', 'h', 'e', 'm', 'i', 's', 'm', '\n',
        'e', 'u', 'p', 'h', 'e', 'm', 'i', 's', 'm', 's', '\n',
        'e', 'u', 'p', 'h', 'e', 'm', 'i', 's', 't', 'i', 'c', '\n',
        'e', 'u', 'p', 'h', 'e', 'm', 'i', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'e', 'u', 'p', 'h', 'o', 'n', 'i', 'o', 'u', 's', '\n',
        'e', 'u', 'p', 'h', 'o', 'n', 'i', 'u', 'm', '\n',
        'e', 'u', 'p', 'h', 'o', 'n', 'i', 'u', 'm', 's', '\n',
        'e', 'u', 'p', 'h', 'o', 'n', 'y', '\n',
        'e', 'u', 'p', 'h', 'o', 'r', 'i', 'a', '\n',
        'e', 'u', 'p', 'h', 'o', 'r', 'i', 'c', '\n',
        'e', 'u', 'r', 'a', 's', 'i', 'a', '\n',
        'e', 'u', 'r', 'a', 's', 'i', 'a', 'n', '\n',
        'e', 'u', 'r', 'e', 'k', 'a', '\n',
        'e', 'u', 'r', 'e', 'k', 'a', 's', '\n',
        'e', 'u', 'r', 'o', '\n',
        'e', 'u', 'r', 'o', 'p', 'e', '\n',
        'e', 'u', 'r', 'o', 'p', 'e', 'a', 'n', '\n',
        'e', 'u', 'r', 'y', 'd', 'i', 'c', 'e', '\n',
        'e', 'u', 't', 'e', 'c', 't', 'i', 'c', '\n',
        'e', 'u', 't', 'h', 'a', 'n', 'a', 's', 'i', 'a', '\n',
        'e', 'v', 'a', 'c', 'u', 'a', 't', 'e', '\n',
        'e', 'v', 'a', 'c', 'u', 'a', 't', 'e', 'd', '\n',
        'e', 'v', 'a', 'c', 'u', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'v', 'a', 'c', 'u', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'v', 'a', 'c', 'u', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'v', 'a', 'c', 'u', 'e', 'e', '\n',
        'e', 'v', 'a', 'c', 'u', 'e', 'e', 's', '\n',
        'e', 'v', 'a', 'd', 'a', 'b', 'l', 'e', '\n',
        'e', 'v', 'a', 'd', 'e', '\n',
        'e', 'v', 'a', 'd', 'e', 'd', '\n',
        'e', 'v', 'a', 'd', 'e', 'r', '\n',
        'e', 'v', 'a', 'd', 'e', 'r', 's', '\n',
        'e', 'v', 'a', 'd', 'e', 's', '\n',
        'e', 'v', 'a', 'd', 'i', 'n', 'g', '\n',
        'e', 'v', 'a', 'l', 'u', 'a', 'b', 'l', 'e', '\n',
        'e', 'v', 'a', 'l', 'u', 'a', 't', 'e', '\n',
        'e', 'v', 'a', 'l', 'u', 'a', 't', 'e', 'd', '\n',
        'e', 'v', 'a', 'l', 'u', 'a', 't', 'e', 's', '\n',
        'e', 'v', 'a', 'l', 'u', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'v', 'a', 'l', 'u', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'v', 'a', 'l', 'u', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'e', 'v', 'a', 'l', 'u', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'v', 'a', 'l', 'u', 'a', 't', 'i', 'v', 'e', '\n',
        'e', 'v', 'a', 'l', 'u', 'a', 't', 'o', 'r', '\n',
        'e', 'v', 'a', 'l', 'u', 'a', 't', 'o', 'r', 's', '\n',
        'e', 'v', 'a', 'n', 'e', 's', 'c', 'e', 'n', 't', '\n',
        'e', 'v', 'a', 'n', 'g', 'e', 'l', 'i', 'c', 'a', 'l', '\n',
        'e', 'v', 'a', 'n', 'g', 'e', 'l', 'i', 'c', 'a', 'l', 'i', 's', 'm', '\n',
        'e', 'v', 'a', 'n', 'g', 'e', 'l', 'i', 'c', 'a', 'l', 's', '\n',
        'e', 'v', 'a', 'n', 'g', 'e', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'v', 'a', 'n', 'g', 'e', 'l', 'i', 's', 'e', '\n',
        'e', 'v', 'a', 'n', 'g', 'e', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'e', 'v', 'a', 'n', 'g', 'e', 'l', 'i', 's', 'm', '\n',
        'e', 'v', 'a', 'n', 'g', 'e', 'l', 'i', 's', 't', '\n',
        'e', 'v', 'a', 'n', 'g', 'e', 'l', 'i', 's', 't', 'i', 'c', '\n',
        'e', 'v', 'a', 'n', 'g', 'e', 'l', 'i', 's', 't', 's', '\n',
        'e', 'v', 'a', 'p', 'o', 'r', 'a', 't', 'e', '\n',
        'e', 'v', 'a', 'p', 'o', 'r', 'a', 't', 'e', 'd', '\n',
        'e', 'v', 'a', 'p', 'o', 'r', 'a', 't', 'e', 's', '\n',
        'e', 'v', 'a', 'p', 'o', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'v', 'a', 'p', 'o', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'v', 'a', 'p', 'o', 'r', 'a', 't', 'o', 'r', '\n',
        'e', 'v', 'a', 's', 'i', 'o', 'n', '\n',
        'e', 'v', 'a', 's', 'i', 'o', 'n', 's', '\n',
        'e', 'v', 'a', 's', 'i', 'v', 'e', '\n',
        'e', 'v', 'a', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'e', 'v', 'a', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'e', 'v', 'e', '\n',
        'e', 'v', 'e', 'n', '\n',
        'e', 'v', 'e', 'n', 'e', 'd', '\n',
        'e', 'v', 'e', 'n', 'e', 'r', '\n',
        'e', 'v', 'e', 'n', 'h', 'a', 'n', 'd', 'e', 'd', '\n',
        'e', 'v', 'e', 'n', 'i', 'n', 'g', '\n',
        'e', 'v', 'e', 'n', 'i', 'n', 'g', 's', '\n',
        'e', 'v', 'e', 'n', 'l', 'y', '\n',
        'e', 'v', 'e', 'n', 'n', 'e', 's', 's', '\n',
        'e', 'v', 'e', 'n', 's', '\n',
        'e', 'v', 'e', 'n', 's', 'o', 'n', 'g', '\n',
        'e', 'v', 'e', 'n', 't', '\n',
        'e', 'v', 'e', 'n', 't', 'f', 'u', 'l', '\n',
        'e', 'v', 'e', 'n', 't', 'i', 'd', 'e', '\n',
        'e', 'v', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'e', 'v', 'e', 'n', 't', 's', '\n',
        'e', 'v', 'e', 'n', 't', 'u', 'a', 'l', '\n',
        'e', 'v', 'e', 'n', 't', 'u', 'a', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'e', 'v', 'e', 'n', 't', 'u', 'a', 'l', 'i', 't', 'y', '\n',
        'e', 'v', 'e', 'n', 't', 'u', 'a', 'l', 'l', 'y', '\n',
        'e', 'v', 'e', 'r', '\n',
        'e', 'v', 'e', 'r', 'c', 'h', 'a', 'n', 'g', 'i', 'n', 'g', '\n',
        'e', 'v', 'e', 'r', 'e', 's', 't', '\n',
        'e', 'v', 'e', 'r', 'g', 'r', 'e', 'e', 'n', '\n',
        'e', 'v', 'e', 'r', 'g', 'r', 'e', 'e', 'n', 's', '\n',
        'e', 'v', 'e', 'r', 'i', 'n', 'c', 'r', 'e', 'a', 's', 'i', 'n', 'g', '\n',
        'e', 'v', 'e', 'r', 'l', 'a', 's', 't', 'i', 'n', 'g', '\n',
        'e', 'v', 'e', 'r', 'l', 'a', 's', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'e', 'v', 'e', 'r', 'l', 'i', 'v', 'i', 'n', 'g', '\n',
        'e', 'v', 'e', 'r', 'm', 'o', 'r', 'e', '\n',
        'e', 'v', 'e', 'r', 'p', 'r', 'e', 's', 'e', 'n', 't', '\n',
        'e', 'v', 'e', 'r', 's', 'i', 'o', 'n', '\n',
        'e', 'v', 'e', 'r', 't', 'i', 'n', 'g', '\n',
        'e', 'v', 'e', 'r', 'y', '\n',
        'e', 'v', 'e', 'r', 'y', 'b', 'o', 'd', 'y', '\n',
        'e', 'v', 'e', 'r', 'y', 'd', 'a', 'y', '\n',
        'e', 'v', 'e', 'r', 'y', 'o', 'n', 'e', '\n',
        'e', 'v', 'e', 'r', 'y', 't', 'h', 'i', 'n', 'g', '\n',
        'e', 'v', 'e', 'r', 'y', 'w', 'h', 'e', 'r', 'e', '\n',
        'e', 'v', 'e', 's', '\n',
        'e', 'v', 'i', 'c', 't', '\n',
        'e', 'v', 'i', 'c', 't', 'e', 'd', '\n',
        'e', 'v', 'i', 'c', 't', 'i', 'n', 'g', '\n',
        'e', 'v', 'i', 'c', 't', 'i', 'o', 'n', '\n',
        'e', 'v', 'i', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'v', 'i', 'c', 't', 's', '\n',
        'e', 'v', 'i', 'd', 'e', 'n', 'c', 'e', '\n',
        'e', 'v', 'i', 'd', 'e', 'n', 'c', 'e', 'd', '\n',
        'e', 'v', 'i', 'd', 'e', 'n', 'c', 'e', 's', '\n',
        'e', 'v', 'i', 'd', 'e', 'n', 't', '\n',
        'e', 'v', 'i', 'd', 'e', 'n', 't', 'i', 'a', 'l', '\n',
        'e', 'v', 'i', 'd', 'e', 'n', 't', 'l', 'y', '\n',
        'e', 'v', 'i', 'l', '\n',
        'e', 'v', 'i', 'l', 'd', 'o', 'e', 'r', '\n',
        'e', 'v', 'i', 'l', 'l', 'y', '\n',
        'e', 'v', 'i', 'l', 'n', 'e', 's', 's', '\n',
        'e', 'v', 'i', 'l', 's', '\n',
        'e', 'v', 'i', 'n', 'c', 'e', '\n',
        'e', 'v', 'i', 'n', 'c', 'e', 'd', '\n',
        'e', 'v', 'i', 'n', 'c', 'e', 's', '\n',
        'e', 'v', 'i', 'n', 'c', 'i', 'n', 'g', '\n',
        'e', 'v', 'i', 's', 'c', 'e', 'r', 'a', 't', 'e', '\n',
        'e', 'v', 'o', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'v', 'o', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'v', 'o', 'c', 'a', 't', 'i', 'v', 'e', '\n',
        'e', 'v', 'o', 'c', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'e', 'v', 'o', 'k', 'e', '\n',
        'e', 'v', 'o', 'k', 'e', 'd', '\n',
        'e', 'v', 'o', 'k', 'e', 's', '\n',
        'e', 'v', 'o', 'k', 'i', 'n', 'g', '\n',
        'e', 'v', 'o', 'l', 'u', 't', 'e', '\n',
        'e', 'v', 'o', 'l', 'u', 't', 'i', 'o', 'n', '\n',
        'e', 'v', 'o', 'l', 'u', 't', 'i', 'o', 'n', 'a', 'r', 'i', 'l', 'y', '\n',
        'e', 'v', 'o', 'l', 'u', 't', 'i', 'o', 'n', 'a', 'r', 'y', '\n',
        'e', 'v', 'o', 'l', 'u', 't', 'i', 'o', 'n', 'i', 's', 'm', '\n',
        'e', 'v', 'o', 'l', 'u', 't', 'i', 'o', 'n', 'i', 's', 't', '\n',
        'e', 'v', 'o', 'l', 'u', 't', 'i', 'o', 'n', 'i', 's', 't', 's', '\n',
        'e', 'v', 'o', 'l', 'u', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'v', 'o', 'l', 'v', 'e', '\n',
        'e', 'v', 'o', 'l', 'v', 'e', 'd', '\n',
        'e', 'v', 'o', 'l', 'v', 'e', 's', '\n',
        'e', 'v', 'o', 'l', 'v', 'i', 'n', 'g', '\n',
        'e', 'w', 'e', '\n',
        'e', 'w', 'e', 's', '\n',
        'e', 'x', 'a', 'c', 'e', 'r', 'b', 'a', 't', 'e', '\n',
        'e', 'x', 'a', 'c', 'e', 'r', 'b', 'a', 't', 'e', 'd', '\n',
        'e', 'x', 'a', 'c', 'e', 'r', 'b', 'a', 't', 'e', 's', '\n',
        'e', 'x', 'a', 'c', 'e', 'r', 'b', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'x', 'a', 'c', 'e', 'r', 'b', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'a', 'c', 't', '\n',
        'e', 'x', 'a', 'c', 't', 'e', 'd', '\n',
        'e', 'x', 'a', 'c', 't', 'i', 'n', 'g', '\n',
        'e', 'x', 'a', 'c', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'a', 'c', 't', 'i', 't', 'u', 'd', 'e', '\n',
        'e', 'x', 'a', 'c', 't', 'l', 'y', '\n',
        'e', 'x', 'a', 'c', 't', 'n', 'e', 's', 's', '\n',
        'e', 'x', 'a', 'c', 't', 's', '\n',
        'e', 'x', 'a', 'g', 'g', 'e', 'r', 'a', 't', 'e', '\n',
        'e', 'x', 'a', 'g', 'g', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'e', 'x', 'a', 'g', 'g', 'e', 'r', 'a', 't', 'e', 'd', 'l', 'y', '\n',
        'e', 'x', 'a', 'g', 'g', 'e', 'r', 'a', 't', 'e', 's', '\n',
        'e', 'x', 'a', 'g', 'g', 'e', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'x', 'a', 'g', 'g', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'a', 'g', 'g', 'e', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'x', 'a', 'l', 't', '\n',
        'e', 'x', 'a', 'l', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'a', 'l', 't', 'e', 'd', '\n',
        'e', 'x', 'a', 'l', 't', 'i', 'n', 'g', '\n',
        'e', 'x', 'a', 'l', 't', 's', '\n',
        'e', 'x', 'a', 'm', '\n',
        'e', 'x', 'a', 'm', 'i', 'n', 'a', 'b', 'l', 'e', '\n',
        'e', 'x', 'a', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'a', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'x', 'a', 'm', 'i', 'n', 'e', '\n',
        'e', 'x', 'a', 'm', 'i', 'n', 'e', 'd', '\n',
        'e', 'x', 'a', 'm', 'i', 'n', 'e', 'e', 's', '\n',
        'e', 'x', 'a', 'm', 'i', 'n', 'e', 'r', '\n',
        'e', 'x', 'a', 'm', 'i', 'n', 'e', 'r', 's', '\n',
        'e', 'x', 'a', 'm', 'i', 'n', 'e', 's', '\n',
        'e', 'x', 'a', 'm', 'i', 'n', 'i', 'n', 'g', '\n',
        'e', 'x', 'a', 'm', 'p', 'l', 'e', '\n',
        'e', 'x', 'a', 'm', 'p', 'l', 'e', 's', '\n',
        'e', 'x', 'a', 'm', 's', '\n',
        'e', 'x', 'a', 's', 'p', 'e', 'r', 'a', 't', 'e', '\n',
        'e', 'x', 'a', 's', 'p', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'e', 'x', 'a', 's', 'p', 'e', 'r', 'a', 't', 'e', 'd', 'l', 'y', '\n',
        'e', 'x', 'a', 's', 'p', 'e', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'x', 'a', 's', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'c', 'a', 'v', 'a', 't', 'e', '\n',
        'e', 'x', 'c', 'a', 'v', 'a', 't', 'e', 'd', '\n',
        'e', 'x', 'c', 'a', 'v', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'x', 'c', 'a', 'v', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'c', 'a', 'v', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'x', 'c', 'a', 'v', 'a', 't', 'o', 'r', '\n',
        'e', 'x', 'c', 'a', 'v', 'a', 't', 'o', 'r', 's', '\n',
        'e', 'x', 'c', 'e', 'e', 'd', '\n',
        'e', 'x', 'c', 'e', 'e', 'd', 'e', 'd', '\n',
        'e', 'x', 'c', 'e', 'e', 'd', 'i', 'n', 'g', '\n',
        'e', 'x', 'c', 'e', 'e', 'd', 'i', 'n', 'g', 'l', 'y', '\n',
        'e', 'x', 'c', 'e', 'e', 'd', 's', '\n',
        'e', 'x', 'c', 'e', 'l', '\n',
        'e', 'x', 'c', 'e', 'l', 'l', 'e', 'd', '\n',
        'e', 'x', 'c', 'e', 'l', 'l', 'e', 'n', 'c', 'e', '\n',
        'e', 'x', 'c', 'e', 'l', 'l', 'e', 'n', 'c', 'i', 'e', 's', '\n',
        'e', 'x', 'c', 'e', 'l', 'l', 'e', 'n', 'c', 'y', '\n',
        'e', 'x', 'c', 'e', 'l', 'l', 'e', 'n', 't', '\n',
        'e', 'x', 'c', 'e', 'l', 'l', 'e', 'n', 't', 'l', 'y', '\n',
        'e', 'x', 'c', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'e', 'x', 'c', 'e', 'l', 's', '\n',
        'e', 'x', 'c', 'e', 'l', 's', 'i', 'o', 'r', '\n',
        'e', 'x', 'c', 'e', 'p', 't', '\n',
        'e', 'x', 'c', 'e', 'p', 't', 'e', 'd', '\n',
        'e', 'x', 'c', 'e', 'p', 't', 'i', 'n', 'g', '\n',
        'e', 'x', 'c', 'e', 'p', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'c', 'e', 'p', 't', 'i', 'o', 'n', 'a', 'b', 'l', 'e', '\n',
        'e', 'x', 'c', 'e', 'p', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'e', 'x', 'c', 'e', 'p', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'e', 'x', 'c', 'e', 'p', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'x', 'c', 'e', 'p', 't', 's', '\n',
        'e', 'x', 'c', 'e', 'r', 'p', 't', '\n',
        'e', 'x', 'c', 'e', 'r', 'p', 't', 'e', 'd', '\n',
        'e', 'x', 'c', 'e', 'r', 'p', 't', 's', '\n',
        'e', 'x', 'c', 'e', 's', 's', '\n',
        'e', 'x', 'c', 'e', 's', 's', 'e', 's', '\n',
        'e', 'x', 'c', 'e', 's', 's', 'i', 'v', 'e', '\n',
        'e', 'x', 'c', 'e', 's', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'e', 'x', 'c', 'h', 'a', 'n', 'g', 'e', '\n',
        'e', 'x', 'c', 'h', 'a', 'n', 'g', 'e', 'a', 'b', 'l', 'e', '\n',
        'e', 'x', 'c', 'h', 'a', 'n', 'g', 'e', 'd', '\n',
        'e', 'x', 'c', 'h', 'a', 'n', 'g', 'e', 'r', '\n',
        'e', 'x', 'c', 'h', 'a', 'n', 'g', 'e', 'r', 's', '\n',
        'e', 'x', 'c', 'h', 'a', 'n', 'g', 'e', 's', '\n',
        'e', 'x', 'c', 'h', 'a', 'n', 'g', 'i', 'n', 'g', '\n',
        'e', 'x', 'c', 'h', 'e', 'q', 'u', 'e', 'r', '\n',
        'e', 'x', 'c', 'i', 's', 'e', '\n',
        'e', 'x', 'c', 'i', 's', 'e', 'd', '\n',
        'e', 'x', 'c', 'i', 's', 'i', 'n', 'g', '\n',
        'e', 'x', 'c', 'i', 's', 'i', 'o', 'n', '\n',
        'e', 'x', 'c', 'i', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'e', 'x', 'c', 'i', 't', 'a', 'b', 'l', 'e', '\n',
        'e', 'x', 'c', 'i', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'c', 'i', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'x', 'c', 'i', 't', 'e', '\n',
        'e', 'x', 'c', 'i', 't', 'e', 'd', '\n',
        'e', 'x', 'c', 'i', 't', 'e', 'd', 'l', 'y', '\n',
        'e', 'x', 'c', 'i', 't', 'e', 'm', 'e', 'n', 't', '\n',
        'e', 'x', 'c', 'i', 't', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'e', 'x', 'c', 'i', 't', 'e', 's', '\n',
        'e', 'x', 'c', 'i', 't', 'i', 'n', 'g', '\n',
        'e', 'x', 'c', 'i', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'e', 'x', 'c', 'i', 't', 'o', 'n', '\n',
        'e', 'x', 'c', 'l', 'a', 'i', 'm', '\n',
        'e', 'x', 'c', 'l', 'a', 'i', 'm', 'e', 'd', '\n',
        'e', 'x', 'c', 'l', 'a', 'i', 'm', 'i', 'n', 'g', '\n',
        'e', 'x', 'c', 'l', 'a', 'i', 'm', 's', '\n',
        'e', 'x', 'c', 'l', 'a', 'm', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'c', 'l', 'a', 'm', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'x', 'c', 'l', 'a', 'm', 'a', 't', 'o', 'r', 'y', '\n',
        'e', 'x', 'c', 'l', 'u', 'd', 'e', '\n',
        'e', 'x', 'c', 'l', 'u', 'd', 'e', 'd', '\n',
        'e', 'x', 'c', 'l', 'u', 'd', 'e', 's', '\n',
        'e', 'x', 'c', 'l', 'u', 'd', 'i', 'n', 'g', '\n',
        'e', 'x', 'c', 'l', 'u', 's', 'i', 'o', 'n', '\n',
        'e', 'x', 'c', 'l', 'u', 's', 'i', 'o', 'n', 'a', 'r', 'y', '\n',
        'e', 'x', 'c', 'l', 'u', 's', 'i', 'o', 'n', 's', '\n',
        'e', 'x', 'c', 'l', 'u', 's', 'i', 'v', 'e', '\n',
        'e', 'x', 'c', 'l', 'u', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'e', 'x', 'c', 'l', 'u', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'e', 'x', 'c', 'l', 'u', 's', 'i', 'v', 'i', 's', 't', '\n',
        'e', 'x', 'c', 'l', 'u', 's', 'i', 'v', 'i', 't', 'y', '\n',
        'e', 'x', 'c', 'o', 'm', 'm', 'u', 'n', 'i', 'c', 'a', 't', 'e', '\n',
        'e', 'x', 'c', 'o', 'm', 'm', 'u', 'n', 'i', 'c', 'a', 't', 'e', 'd', '\n',
        'e', 'x', 'c', 'o', 'm', 'm', 'u', 'n', 'i', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'x', 'c', 'o', 'm', 'm', 'u', 'n', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'c', 'r', 'e', 't', 'e', '\n',
        'e', 'x', 'c', 'r', 'u', 'c', 'i', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'x', 'c', 'r', 'u', 'c', 'i', 'a', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'e', 'x', 'c', 'r', 'u', 'c', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'c', 'u', 'r', 's', 'i', 'o', 'n', '\n',
        'e', 'x', 'c', 'u', 'r', 's', 'i', 'o', 'n', 'i', 's', 't', 's', '\n',
        'e', 'x', 'c', 'u', 'r', 's', 'i', 'o', 'n', 's', '\n',
        'e', 'x', 'c', 'u', 'r', 's', 'u', 's', '\n',
        'e', 'x', 'c', 'u', 's', 'a', 'b', 'l', 'e', '\n',
        'e', 'x', 'c', 'u', 's', 'e', '\n',
        'e', 'x', 'c', 'u', 's', 'e', 'd', '\n',
        'e', 'x', 'c', 'u', 's', 'e', 's', '\n',
        'e', 'x', 'c', 'u', 's', 'i', 'n', 'g', '\n',
        'e', 'x', 'e', 'c', 'u', 't', 'a', 'b', 'l', 'e', '\n',
        'e', 'x', 'e', 'c', 'u', 't', 'e', '\n',
        'e', 'x', 'e', 'c', 'u', 't', 'e', 'd', '\n',
        'e', 'x', 'e', 'c', 'u', 't', 'e', 's', '\n',
        'e', 'x', 'e', 'c', 'u', 't', 'i', 'n', 'g', '\n',
        'e', 'x', 'e', 'c', 'u', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'e', 'c', 'u', 't', 'i', 'o', 'n', 'e', 'r', '\n',
        'e', 'x', 'e', 'c', 'u', 't', 'i', 'o', 'n', 'e', 'r', 's', '\n',
        'e', 'x', 'e', 'c', 'u', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'x', 'e', 'c', 'u', 't', 'i', 'v', 'e', '\n',
        'e', 'x', 'e', 'c', 'u', 't', 'i', 'v', 'e', 's', '\n',
        'e', 'x', 'e', 'c', 'u', 't', 'o', 'r', '\n',
        'e', 'x', 'e', 'c', 'u', 't', 'o', 'r', 's', '\n',
        'e', 'x', 'e', 'g', 'e', 's', 'i', 's', '\n',
        'e', 'x', 'e', 'g', 'e', 't', 'i', 'c', 'a', 'l', '\n',
        'e', 'x', 'e', 'm', 'p', 'l', 'a', 'r', '\n',
        'e', 'x', 'e', 'm', 'p', 'l', 'a', 'r', 's', '\n',
        'e', 'x', 'e', 'm', 'p', 'l', 'a', 'r', 'y', '\n',
        'e', 'x', 'e', 'm', 'p', 'l', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'e', 'm', 'p', 'l', 'i', 'f', 'i', 'e', 'd', '\n',
        'e', 'x', 'e', 'm', 'p', 'l', 'i', 'f', 'i', 'e', 's', '\n',
        'e', 'x', 'e', 'm', 'p', 'l', 'i', 'f', 'y', '\n',
        'e', 'x', 'e', 'm', 'p', 'l', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'e', 'x', 'e', 'm', 'p', 't', '\n',
        'e', 'x', 'e', 'm', 'p', 't', 'e', 'd', '\n',
        'e', 'x', 'e', 'm', 'p', 't', 'i', 'n', 'g', '\n',
        'e', 'x', 'e', 'm', 'p', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'e', 'm', 'p', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'x', 'e', 'm', 'p', 't', 's', '\n',
        'e', 'x', 'e', 'r', 'c', 'i', 's', 'a', 'b', 'l', 'e', '\n',
        'e', 'x', 'e', 'r', 'c', 'i', 's', 'e', '\n',
        'e', 'x', 'e', 'r', 'c', 'i', 's', 'e', 'd', '\n',
        'e', 'x', 'e', 'r', 'c', 'i', 's', 'e', 'r', '\n',
        'e', 'x', 'e', 'r', 'c', 'i', 's', 'e', 's', '\n',
        'e', 'x', 'e', 'r', 'c', 'i', 's', 'i', 'n', 'g', '\n',
        'e', 'x', 'e', 'r', 't', '\n',
        'e', 'x', 'e', 'r', 't', 'e', 'd', '\n',
        'e', 'x', 'e', 'r', 't', 'i', 'n', 'g', '\n',
        'e', 'x', 'e', 'r', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'e', 'r', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'x', 'e', 'r', 't', 's', '\n',
        'e', 'x', 'e', 's', '\n',
        'e', 'x', 'e', 'u', 'n', 't', '\n',
        'e', 'x', 'f', 'o', 'l', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'h', 'a', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'h', 'a', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'x', 'h', 'a', 'l', 'e', '\n',
        'e', 'x', 'h', 'a', 'l', 'e', 'd', '\n',
        'e', 'x', 'h', 'a', 'l', 'e', 's', '\n',
        'e', 'x', 'h', 'a', 'l', 'i', 'n', 'g', '\n',
        'e', 'x', 'h', 'a', 'u', 's', 't', '\n',
        'e', 'x', 'h', 'a', 'u', 's', 't', 'e', 'd', '\n',
        'e', 'x', 'h', 'a', 'u', 's', 't', 'i', 'b', 'l', 'e', '\n',
        'e', 'x', 'h', 'a', 'u', 's', 't', 'i', 'n', 'g', '\n',
        'e', 'x', 'h', 'a', 'u', 's', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'h', 'a', 'u', 's', 't', 'i', 'v', 'e', '\n',
        'e', 'x', 'h', 'a', 'u', 's', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'e', 'x', 'h', 'a', 'u', 's', 't', 's', '\n',
        'e', 'x', 'h', 'i', 'b', 'i', 't', '\n',
        'e', 'x', 'h', 'i', 'b', 'i', 't', 'e', 'd', '\n',
        'e', 'x', 'h', 'i', 'b', 'i', 't', 'i', 'n', 'g', '\n',
        'e', 'x', 'h', 'i', 'b', 'i', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'h', 'i', 'b', 'i', 't', 'i', 'o', 'n', 'e', 'r', '\n',
        'e', 'x', 'h', 'i', 'b', 'i', 't', 'i', 'o', 'n', 'e', 'r', 's', '\n',
        'e', 'x', 'h', 'i', 'b', 'i', 't', 'i', 'o', 'n', 'i', 's', 'm', '\n',
        'e', 'x', 'h', 'i', 'b', 'i', 't', 'i', 'o', 'n', 'i', 's', 't', '\n',
        'e', 'x', 'h', 'i', 'b', 'i', 't', 'i', 'o', 'n', 'i', 's', 't', 's', '\n',
        'e', 'x', 'h', 'i', 'b', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'x', 'h', 'i', 'b', 'i', 't', 'o', 'r', '\n',
        'e', 'x', 'h', 'i', 'b', 'i', 't', 'o', 'r', 's', '\n',
        'e', 'x', 'h', 'i', 'b', 'i', 't', 's', '\n',
        'e', 'x', 'h', 'i', 'l', 'a', 'r', 'a', 't', 'e', '\n',
        'e', 'x', 'h', 'i', 'l', 'a', 'r', 'a', 't', 'e', 'd', '\n',
        'e', 'x', 'h', 'i', 'l', 'a', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'x', 'h', 'i', 'l', 'a', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'h', 'o', 'r', 't', '\n',
        'e', 'x', 'h', 'o', 'r', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'h', 'o', 'r', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'x', 'h', 'o', 'r', 't', 'e', 'd', '\n',
        'e', 'x', 'h', 'o', 'r', 't', 'i', 'n', 'g', '\n',
        'e', 'x', 'h', 'o', 'r', 't', 's', '\n',
        'e', 'x', 'h', 'u', 'm', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'h', 'u', 'm', 'e', '\n',
        'e', 'x', 'h', 'u', 'm', 'e', 'd', '\n',
        'e', 'x', 'h', 'u', 'm', 'e', 's', '\n',
        'e', 'x', 'h', 'u', 'm', 'i', 'n', 'g', '\n',
        'e', 'x', 'h', 'u', 's', 'b', 'a', 'n', 'd', '\n',
        'e', 'x', 'i', 'g', 'e', 'n', 'c', 'i', 'e', 's', '\n',
        'e', 'x', 'i', 'g', 'e', 'n', 'c', 'y', '\n',
        'e', 'x', 'i', 'g', 'e', 'n', 't', '\n',
        'e', 'x', 'i', 'g', 'u', 'o', 'u', 's', '\n',
        'e', 'x', 'i', 'l', 'e', '\n',
        'e', 'x', 'i', 'l', 'e', 'd', '\n',
        'e', 'x', 'i', 'l', 'e', 's', '\n',
        'e', 'x', 'i', 'l', 'i', 'n', 'g', '\n',
        'e', 'x', 'i', 's', 't', '\n',
        'e', 'x', 'i', 's', 't', 'e', 'd', '\n',
        'e', 'x', 'i', 's', 't', 'e', 'n', 'c', 'e', '\n',
        'e', 'x', 'i', 's', 't', 'e', 'n', 'c', 'e', 's', '\n',
        'e', 'x', 'i', 's', 't', 'e', 'n', 't', '\n',
        'e', 'x', 'i', 's', 't', 'e', 'n', 't', 'i', 'a', 'l', '\n',
        'e', 'x', 'i', 's', 't', 'e', 'n', 't', 'i', 'a', 'l', 'i', 's', 'm', '\n',
        'e', 'x', 'i', 's', 't', 'e', 'n', 't', 'i', 'a', 'l', 'i', 's', 't', '\n',
        'e', 'x', 'i', 's', 't', 'e', 'n', 't', 'i', 'a', 'l', 'i', 's', 't', 'i', 'c', '\n',
        'e', 'x', 'i', 's', 't', 'e', 'n', 't', 'i', 'a', 'l', 'l', 'y', '\n',
        'e', 'x', 'i', 's', 't', 'i', 'n', 'g', '\n',
        'e', 'x', 'i', 's', 't', 's', '\n',
        'e', 'x', 'i', 't', '\n',
        'e', 'x', 'i', 't', 'e', 'd', '\n',
        'e', 'x', 'i', 't', 'i', 'n', 'g', '\n',
        'e', 'x', 'i', 't', 's', '\n',
        'e', 'x', 'm', 'e', 'm', 'b', 'e', 'r', '\n',
        'e', 'x', 'm', 'e', 'm', 'b', 'e', 'r', 's', '\n',
        'e', 'x', 'o', 'c', 'r', 'i', 'n', 'e', '\n',
        'e', 'x', 'o', 'd', 'e', 'r', 'm', '\n',
        'e', 'x', 'o', 'd', 'u', 's', '\n',
        'e', 'x', 'o', 'g', 'e', 'n', 'o', 'u', 's', '\n',
        'e', 'x', 'o', 'g', 'e', 'n', 'o', 'u', 's', 'l', 'y', '\n',
        'e', 'x', 'o', 'n', 'e', 'r', 'a', 't', 'e', '\n',
        'e', 'x', 'o', 'n', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'e', 'x', 'o', 'n', 'e', 'r', 'a', 't', 'e', 's', '\n',
        'e', 'x', 'o', 'n', 'e', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'x', 'o', 'n', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'o', 'r', 'b', 'i', 't', 'a', 'n', 't', '\n',
        'e', 'x', 'o', 'r', 'b', 'i', 't', 'a', 'n', 't', 'l', 'y', '\n',
        'e', 'x', 'o', 'r', 'c', 'i', 's', 'e', '\n',
        'e', 'x', 'o', 'r', 'c', 'i', 's', 'e', 'd', '\n',
        'e', 'x', 'o', 'r', 'c', 'i', 's', 'i', 'n', 'g', '\n',
        'e', 'x', 'o', 'r', 'c', 'i', 's', 'm', '\n',
        'e', 'x', 'o', 'r', 'c', 'i', 's', 'm', 's', '\n',
        'e', 'x', 'o', 'r', 'c', 'i', 's', 't', '\n',
        'e', 'x', 'o', 's', 'k', 'e', 'l', 'e', 't', 'o', 'n', '\n',
        'e', 'x', 'o', 't', 'h', 'e', 'r', 'm', 'i', 'c', '\n',
        'e', 'x', 'o', 't', 'h', 'e', 'r', 'm', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'e', 'x', 'o', 't', 'i', 'c', '\n',
        'e', 'x', 'o', 't', 'i', 'c', 'a', '\n',
        'e', 'x', 'o', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'e', 'x', 'o', 't', 'i', 'c', 'i', 's', 'm', '\n',
        'e', 'x', 'p', 'a', 'n', 'd', '\n',
        'e', 'x', 'p', 'a', 'n', 'd', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'e', 'x', 'p', 'a', 'n', 'd', 'a', 'b', 'l', 'e', '\n',
        'e', 'x', 'p', 'a', 'n', 'd', 'e', 'd', '\n',
        'e', 'x', 'p', 'a', 'n', 'd', 'e', 'r', '\n',
        'e', 'x', 'p', 'a', 'n', 'd', 'i', 'n', 'g', '\n',
        'e', 'x', 'p', 'a', 'n', 'd', 's', '\n',
        'e', 'x', 'p', 'a', 'n', 's', 'e', '\n',
        'e', 'x', 'p', 'a', 'n', 's', 'e', 's', '\n',
        'e', 'x', 'p', 'a', 'n', 's', 'i', 'b', 'l', 'e', '\n',
        'e', 'x', 'p', 'a', 'n', 's', 'i', 'o', 'n', '\n',
        'e', 'x', 'p', 'a', 'n', 's', 'i', 'o', 'n', 'a', 'r', 'y', '\n',
        'e', 'x', 'p', 'a', 'n', 's', 'i', 'o', 'n', 'i', 's', 'm', '\n',
        'e', 'x', 'p', 'a', 'n', 's', 'i', 'o', 'n', 'i', 's', 't', '\n',
        'e', 'x', 'p', 'a', 'n', 's', 'i', 'o', 'n', 's', '\n',
        'e', 'x', 'p', 'a', 'n', 's', 'i', 'v', 'e', '\n',
        'e', 'x', 'p', 'a', 'n', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'e', 'x', 'p', 'a', 'n', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'e', 'x', 'p', 'a', 't', 'r', 'i', 'a', 't', 'e', '\n',
        'e', 'x', 'p', 'a', 't', 'r', 'i', 'a', 't', 'e', 'd', '\n',
        'e', 'x', 'p', 'a', 't', 'r', 'i', 'a', 't', 'e', 's', '\n',
        'e', 'x', 'p', 'e', 'c', 't', '\n',
        'e', 'x', 'p', 'e', 'c', 't', 'a', 'n', 'c', 'i', 'e', 's', '\n',
        'e', 'x', 'p', 'e', 'c', 't', 'a', 'n', 'c', 'y', '\n',
        'e', 'x', 'p', 'e', 'c', 't', 'a', 'n', 't', '\n',
        'e', 'x', 'p', 'e', 'c', 't', 'a', 'n', 't', 'l', 'y', '\n',
        'e', 'x', 'p', 'e', 'c', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'p', 'e', 'c', 't', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'e', 'x', 'p', 'e', 'c', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'x', 'p', 'e', 'c', 't', 'e', 'd', '\n',
        'e', 'x', 'p', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'e', 'x', 'p', 'e', 'c', 't', 'o', 'r', 'a', 't', 'e', '\n',
        'e', 'x', 'p', 'e', 'c', 't', 'o', 'r', 'a', 't', 'e', 'd', '\n',
        'e', 'x', 'p', 'e', 'c', 't', 'o', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'p', 'e', 'c', 't', 's', '\n',
        'e', 'x', 'p', 'e', 'd', 'i', 'e', 'n', 'c', 'e', '\n',
        'e', 'x', 'p', 'e', 'd', 'i', 'e', 'n', 'c', 'y', '\n',
        'e', 'x', 'p', 'e', 'd', 'i', 'e', 'n', 't', '\n',
        'e', 'x', 'p', 'e', 'd', 'i', 'e', 'n', 't', 's', '\n',
        'e', 'x', 'p', 'e', 'd', 'i', 't', 'e', '\n',
        'e', 'x', 'p', 'e', 'd', 'i', 't', 'e', 'd', '\n',
        'e', 'x', 'p', 'e', 'd', 'i', 't', 'e', 's', '\n',
        'e', 'x', 'p', 'e', 'd', 'i', 't', 'i', 'n', 'g', '\n',
        'e', 'x', 'p', 'e', 'd', 'i', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'p', 'e', 'd', 'i', 't', 'i', 'o', 'n', 'a', 'r', 'y', '\n',
        'e', 'x', 'p', 'e', 'd', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'x', 'p', 'e', 'd', 'i', 't', 'i', 'o', 'u', 's', '\n',
        'e', 'x', 'p', 'e', 'd', 'i', 't', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'e', 'x', 'p', 'e', 'l', '\n',
        'e', 'x', 'p', 'e', 'l', 'l', 'e', 'd', '\n',
        'e', 'x', 'p', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'e', 'x', 'p', 'e', 'l', 's', '\n',
        'e', 'x', 'p', 'e', 'n', 'd', '\n',
        'e', 'x', 'p', 'e', 'n', 'd', 'a', 'b', 'l', 'e', '\n',
        'e', 'x', 'p', 'e', 'n', 'd', 'e', 'd', '\n',
        'e', 'x', 'p', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'e', 'x', 'p', 'e', 'n', 'd', 'i', 't', 'u', 'r', 'e', '\n',
        'e', 'x', 'p', 'e', 'n', 'd', 'i', 't', 'u', 'r', 'e', 's', '\n',
        'e', 'x', 'p', 'e', 'n', 'd', 's', '\n',
        'e', 'x', 'p', 'e', 'n', 's', 'e', '\n',
        'e', 'x', 'p', 'e', 'n', 's', 'e', 's', '\n',
        'e', 'x', 'p', 'e', 'n', 's', 'i', 'v', 'e', '\n',
        'e', 'x', 'p', 'e', 'n', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'e', 'x', 'p', 'e', 'r', 'i', 'e', 'n', 'c', 'e', '\n',
        'e', 'x', 'p', 'e', 'r', 'i', 'e', 'n', 'c', 'e', 'd', '\n',
        'e', 'x', 'p', 'e', 'r', 'i', 'e', 'n', 'c', 'e', 's', '\n',
        'e', 'x', 'p', 'e', 'r', 'i', 'e', 'n', 'c', 'i', 'n', 'g', '\n',
        'e', 'x', 'p', 'e', 'r', 'i', 'e', 'n', 't', 'i', 'a', 'l', '\n',
        'e', 'x', 'p', 'e', 'r', 'i', 'm', 'e', 'n', 't', '\n',
        'e', 'x', 'p', 'e', 'r', 'i', 'm', 'e', 'n', 't', 'a', 'l', '\n',
        'e', 'x', 'p', 'e', 'r', 'i', 'm', 'e', 'n', 't', 'a', 'l', 'i', 's', 't', '\n',
        'e', 'x', 'p', 'e', 'r', 'i', 'm', 'e', 'n', 't', 'a', 'l', 'i', 's', 't', 's', '\n',
        'e', 'x', 'p', 'e', 'r', 'i', 'm', 'e', 'n', 't', 'a', 'l', 'l', 'y', '\n',
        'e', 'x', 'p', 'e', 'r', 'i', 'm', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'p', 'e', 'r', 'i', 'm', 'e', 'n', 't', 'e', 'd', '\n',
        'e', 'x', 'p', 'e', 'r', 'i', 'm', 'e', 'n', 't', 'e', 'r', '\n',
        'e', 'x', 'p', 'e', 'r', 'i', 'm', 'e', 'n', 't', 'e', 'r', 's', '\n',
        'e', 'x', 'p', 'e', 'r', 'i', 'm', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'e', 'x', 'p', 'e', 'r', 'i', 'm', 'e', 'n', 't', 's', '\n',
        'e', 'x', 'p', 'e', 'r', 't', '\n',
        'e', 'x', 'p', 'e', 'r', 't', 'i', 's', 'e', '\n',
        'e', 'x', 'p', 'e', 'r', 't', 'l', 'y', '\n',
        'e', 'x', 'p', 'e', 'r', 't', 'n', 'e', 's', 's', '\n',
        'e', 'x', 'p', 'e', 'r', 't', 's', '\n',
        'e', 'x', 'p', 'i', 'a', 't', 'e', '\n',
        'e', 'x', 'p', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'p', 'i', 'a', 't', 'o', 'r', 'y', '\n',
        'e', 'x', 'p', 'i', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'p', 'i', 'r', 'a', 't', 'o', 'r', 'y', '\n',
        'e', 'x', 'p', 'i', 'r', 'e', '\n',
        'e', 'x', 'p', 'i', 'r', 'e', 'd', '\n',
        'e', 'x', 'p', 'i', 'r', 'e', 's', '\n',
        'e', 'x', 'p', 'i', 'r', 'i', 'n', 'g', '\n',
        'e', 'x', 'p', 'i', 'r', 'y', '\n',
        'e', 'x', 'p', 'l', 'a', 'i', 'n', '\n',
        'e', 'x', 'p', 'l', 'a', 'i', 'n', 'a', 'b', 'l', 'e', '\n',
        'e', 'x', 'p', 'l', 'a', 'i', 'n', 'e', 'd', '\n',
        'e', 'x', 'p', 'l', 'a', 'i', 'n', 'i', 'n', 'g', '\n',
        'e', 'x', 'p', 'l', 'a', 'i', 'n', 's', '\n',
        'e', 'x', 'p', 'l', 'a', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'p', 'l', 'a', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'x', 'p', 'l', 'a', 'n', 'a', 't', 'o', 'r', 'y', '\n',
        'e', 'x', 'p', 'l', 'e', 't', 'i', 'v', 'e', '\n',
        'e', 'x', 'p', 'l', 'e', 't', 'i', 'v', 'e', 's', '\n',
        'e', 'x', 'p', 'l', 'i', 'c', 'a', 'b', 'l', 'e', '\n',
        'e', 'x', 'p', 'l', 'i', 'c', 'a', 't', 'e', '\n',
        'e', 'x', 'p', 'l', 'i', 'c', 'a', 't', 'e', 'd', '\n',
        'e', 'x', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'v', 'e', '\n',
        'e', 'x', 'p', 'l', 'i', 'c', 'i', 't', '\n',
        'e', 'x', 'p', 'l', 'i', 'c', 'i', 't', 'l', 'y', '\n',
        'e', 'x', 'p', 'l', 'i', 'c', 'i', 't', 'n', 'e', 's', 's', '\n',
        'e', 'x', 'p', 'l', 'o', 'd', 'e', '\n',
        'e', 'x', 'p', 'l', 'o', 'd', 'e', 'd', '\n',
        'e', 'x', 'p', 'l', 'o', 'd', 'e', 'r', '\n',
        'e', 'x', 'p', 'l', 'o', 'd', 'e', 'r', 's', '\n',
        'e', 'x', 'p', 'l', 'o', 'd', 'e', 's', '\n',
        'e', 'x', 'p', 'l', 'o', 'd', 'i', 'n', 'g', '\n',
        'e', 'x', 'p', 'l', 'o', 'i', 't', '\n',
        'e', 'x', 'p', 'l', 'o', 'i', 't', 'a', 'b', 'l', 'e', '\n',
        'e', 'x', 'p', 'l', 'o', 'i', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'p', 'l', 'o', 'i', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'x', 'p', 'l', 'o', 'i', 't', 'a', 't', 'i', 'v', 'e', '\n',
        'e', 'x', 'p', 'l', 'o', 'i', 't', 'e', 'd', '\n',
        'e', 'x', 'p', 'l', 'o', 'i', 't', 'e', 'r', '\n',
        'e', 'x', 'p', 'l', 'o', 'i', 't', 'e', 'r', 's', '\n',
        'e', 'x', 'p', 'l', 'o', 'i', 't', 'i', 'n', 'g', '\n',
        'e', 'x', 'p', 'l', 'o', 'i', 't', 's', '\n',
        'e', 'x', 'p', 'l', 'o', 'r', 'a', 'b', 'l', 'e', '\n',
        'e', 'x', 'p', 'l', 'o', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'p', 'l', 'o', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'x', 'p', 'l', 'o', 'r', 'a', 't', 'o', 'r', 'y', '\n',
        'e', 'x', 'p', 'l', 'o', 'r', 'e', '\n',
        'e', 'x', 'p', 'l', 'o', 'r', 'e', 'd', '\n',
        'e', 'x', 'p', 'l', 'o', 'r', 'e', 'r', '\n',
        'e', 'x', 'p', 'l', 'o', 'r', 'e', 'r', 's', '\n',
        'e', 'x', 'p', 'l', 'o', 'r', 'e', 's', '\n',
        'e', 'x', 'p', 'l', 'o', 'r', 'i', 'n', 'g', '\n',
        'e', 'x', 'p', 'l', 'o', 's', 'i', 'o', 'n', '\n',
        'e', 'x', 'p', 'l', 'o', 's', 'i', 'o', 'n', 's', '\n',
        'e', 'x', 'p', 'l', 'o', 's', 'i', 'v', 'e', '\n',
        'e', 'x', 'p', 'l', 'o', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'e', 'x', 'p', 'l', 'o', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'e', 'x', 'p', 'l', 'o', 's', 'i', 'v', 'e', 's', '\n',
        'e', 'x', 'p', 'o', '\n',
        'e', 'x', 'p', 'o', 'n', 'e', 'n', 't', '\n',
        'e', 'x', 'p', 'o', 'n', 'e', 'n', 't', 'i', 'a', 'l', '\n',
        'e', 'x', 'p', 'o', 'n', 'e', 'n', 't', 'i', 'a', 'l', 'l', 'y', '\n',
        'e', 'x', 'p', 'o', 'n', 'e', 'n', 't', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'p', 'o', 'n', 'e', 'n', 't', 's', '\n',
        'e', 'x', 'p', 'o', 'r', 't', '\n',
        'e', 'x', 'p', 'o', 'r', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'e', 'x', 'p', 'o', 'r', 't', 'a', 'b', 'l', 'e', '\n',
        'e', 'x', 'p', 'o', 'r', 't', 'e', 'd', '\n',
        'e', 'x', 'p', 'o', 'r', 't', 'e', 'r', '\n',
        'e', 'x', 'p', 'o', 'r', 't', 'e', 'r', 's', '\n',
        'e', 'x', 'p', 'o', 'r', 't', 'i', 'n', 'g', '\n',
        'e', 'x', 'p', 'o', 'r', 't', 's', '\n',
        'e', 'x', 'p', 'o', 's', 'e', '\n',
        'e', 'x', 'p', 'o', 's', 'e', 'd', '\n',
        'e', 'x', 'p', 'o', 's', 'e', 's', '\n',
        'e', 'x', 'p', 'o', 's', 'i', 'n', 'g', '\n',
        'e', 'x', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'x', 'p', 'o', 's', 'i', 't', 'o', 'r', 'y', '\n',
        'e', 'x', 'p', 'o', 's', 't', 'u', 'l', 'a', 't', 'e', '\n',
        'e', 'x', 'p', 'o', 's', 't', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'e', 'x', 'p', 'o', 's', 't', 'u', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'x', 'p', 'o', 's', 't', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'p', 'o', 's', 't', 'u', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'x', 'p', 'o', 's', 'u', 'r', 'e', '\n',
        'e', 'x', 'p', 'o', 's', 'u', 'r', 'e', 's', '\n',
        'e', 'x', 'p', 'o', 'u', 'n', 'd', '\n',
        'e', 'x', 'p', 'o', 'u', 'n', 'd', 'e', 'd', '\n',
        'e', 'x', 'p', 'o', 'u', 'n', 'd', 'i', 'n', 'g', '\n',
        'e', 'x', 'p', 'o', 'u', 'n', 'd', 's', '\n',
        'e', 'x', 'p', 'r', 'e', 's', 's', '\n',
        'e', 'x', 'p', 'r', 'e', 's', 's', 'e', 'd', '\n',
        'e', 'x', 'p', 'r', 'e', 's', 's', 'e', 's', '\n',
        'e', 'x', 'p', 'r', 'e', 's', 's', 'i', 'b', 'l', 'e', '\n',
        'e', 'x', 'p', 'r', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'e', 'x', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', '\n',
        'e', 'x', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 'i', 's', 'm', '\n',
        'e', 'x', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 'i', 's', 't', '\n',
        'e', 'x', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 'i', 's', 't', 'i', 'c', '\n',
        'e', 'x', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 'i', 's', 't', 's', '\n',
        'e', 'x', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 'l', 'e', 's', 's', '\n',
        'e', 'x', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'e', 'x', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 's', '\n',
        'e', 'x', 'p', 'r', 'e', 's', 's', 'i', 'v', 'e', '\n',
        'e', 'x', 'p', 'r', 'e', 's', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'e', 'x', 'p', 'r', 'e', 's', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'e', 'x', 'p', 'r', 'e', 's', 's', 'l', 'y', '\n',
        'e', 'x', 'p', 'r', 'o', 'p', 'r', 'i', 'a', 't', 'e', '\n',
        'e', 'x', 'p', 'r', 'o', 'p', 'r', 'i', 'a', 't', 'e', 'd', '\n',
        'e', 'x', 'p', 'r', 'o', 'p', 'r', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'p', 'r', 'o', 'p', 'r', 'i', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'x', 'p', 'u', 'l', 's', 'i', 'o', 'n', '\n',
        'e', 'x', 'p', 'u', 'l', 's', 'i', 'o', 'n', 's', '\n',
        'e', 'x', 'p', 'u', 'n', 'g', 'e', '\n',
        'e', 'x', 'p', 'u', 'n', 'g', 'e', 'd', '\n',
        'e', 'x', 'p', 'u', 'n', 'g', 'e', 's', '\n',
        'e', 'x', 'p', 'u', 'n', 'g', 'i', 'n', 'g', '\n',
        'e', 'x', 'p', 'u', 'r', 'g', 'a', 't', 'e', '\n',
        'e', 'x', 'p', 'u', 'r', 'g', 'a', 't', 'e', 'd', '\n',
        'e', 'x', 'p', 'u', 'r', 'g', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'x', 'q', 'u', 'i', 's', 'i', 't', 'e', '\n',
        'e', 'x', 'q', 'u', 'i', 's', 'i', 't', 'e', 'l', 'y', '\n',
        'e', 'x', 'q', 'u', 'i', 's', 'i', 't', 'e', 'n', 'e', 's', 's', '\n',
        'e', 'x', 't', '\n',
        'e', 'x', 't', 'e', 'n', 'd', '\n',
        'e', 'x', 't', 'e', 'n', 'd', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'e', 'x', 't', 'e', 'n', 'd', 'a', 'b', 'l', 'e', '\n',
        'e', 'x', 't', 'e', 'n', 'd', 'e', 'd', '\n',
        'e', 'x', 't', 'e', 'n', 'd', 'e', 'r', '\n',
        'e', 'x', 't', 'e', 'n', 'd', 'e', 'r', 's', '\n',
        'e', 'x', 't', 'e', 'n', 'd', 'i', 'b', 'l', 'e', '\n',
        'e', 'x', 't', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'e', 'x', 't', 'e', 'n', 'd', 's', '\n',
        'e', 'x', 't', 'e', 'n', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'e', 'x', 't', 'e', 'n', 's', 'i', 'b', 'l', 'e', '\n',
        'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', '\n',
        'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 'a', 'l', '\n',
        'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'e', 'x', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', '\n',
        'e', 'x', 't', 'e', 'n', 's', 'i', 'v', 'e', '\n',
        'e', 'x', 't', 'e', 'n', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'e', 'x', 't', 'e', 'n', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'e', 'x', 't', 'e', 'n', 's', 'o', 'r', 's', '\n',
        'e', 'x', 't', 'e', 'n', 't', '\n',
        'e', 'x', 't', 'e', 'n', 't', 's', '\n',
        'e', 'x', 't', 'e', 'n', 'u', 'a', 't', 'e', '\n',
        'e', 'x', 't', 'e', 'n', 'u', 'a', 't', 'e', 'd', '\n',
        'e', 'x', 't', 'e', 'n', 'u', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'x', 't', 'e', 'n', 'u', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 't', 'e', 'r', 'i', 'o', 'r', '\n',
        'e', 'x', 't', 'e', 'r', 'i', 'o', 'r', 's', '\n',
        'e', 'x', 't', 'e', 'r', 'm', 'i', 'n', 'a', 't', 'e', '\n',
        'e', 'x', 't', 'e', 'r', 'm', 'i', 'n', 'a', 't', 'e', 'd', '\n',
        'e', 'x', 't', 'e', 'r', 'm', 'i', 'n', 'a', 't', 'e', 's', '\n',
        'e', 'x', 't', 'e', 'r', 'm', 'i', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'x', 't', 'e', 'r', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 't', 'e', 'r', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'x', 't', 'e', 'r', 'm', 'i', 'n', 'a', 't', 'o', 'r', '\n',
        'e', 'x', 't', 'e', 'r', 'm', 'i', 'n', 'a', 't', 'o', 'r', 's', '\n',
        'e', 'x', 't', 'e', 'r', 'n', '\n',
        'e', 'x', 't', 'e', 'r', 'n', 'a', 'l', '\n',
        'e', 'x', 't', 'e', 'r', 'n', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'e', 'x', 't', 'e', 'r', 'n', 'a', 'l', 'l', 'y', '\n',
        'e', 'x', 't', 'e', 'r', 'n', 'a', 'l', 's', '\n',
        'e', 'x', 't', 'e', 'r', 'n', 's', '\n',
        'e', 'x', 't', 'i', 'n', 'c', 't', '\n',
        'e', 'x', 't', 'i', 'n', 'c', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 't', 'i', 'n', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'x', 't', 'i', 'n', 'g', 'u', 'i', 's', 'h', '\n',
        'e', 'x', 't', 'i', 'n', 'g', 'u', 'i', 's', 'h', 'e', 'd', '\n',
        'e', 'x', 't', 'i', 'n', 'g', 'u', 'i', 's', 'h', 'e', 'r', '\n',
        'e', 'x', 't', 'i', 'n', 'g', 'u', 'i', 's', 'h', 'e', 'r', 's', '\n',
        'e', 'x', 't', 'i', 'n', 'g', 'u', 'i', 's', 'h', 'e', 's', '\n',
        'e', 'x', 't', 'i', 'n', 'g', 'u', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'e', 'x', 't', 'i', 'n', 'g', 'u', 'i', 's', 'h', 'm', 'e', 'n', 't', '\n',
        'e', 'x', 't', 'i', 'r', 'p', 'a', 't', 'e', '\n',
        'e', 'x', 't', 'i', 'r', 'p', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 't', 'o', 'l', '\n',
        'e', 'x', 't', 'o', 'l', 'l', 'e', 'd', '\n',
        'e', 'x', 't', 'o', 'l', 'l', 'i', 'n', 'g', '\n',
        'e', 'x', 't', 'o', 'l', 's', '\n',
        'e', 'x', 't', 'o', 'r', 't', '\n',
        'e', 'x', 't', 'o', 'r', 't', 'e', 'd', '\n',
        'e', 'x', 't', 'o', 'r', 't', 'i', 'n', 'g', '\n',
        'e', 'x', 't', 'o', 'r', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 't', 'o', 'r', 't', 'i', 'o', 'n', 'a', 't', 'e', '\n',
        'e', 'x', 't', 'o', 'r', 't', 'i', 'o', 'n', 'a', 't', 'e', 'l', 'y', '\n',
        'e', 'x', 't', 'o', 'r', 't', 'i', 'o', 'n', 'i', 's', 't', 's', '\n',
        'e', 'x', 't', 'o', 'r', 't', 's', '\n',
        'e', 'x', 't', 'r', 'a', '\n',
        'e', 'x', 't', 'r', 'a', 'c', 'e', 'l', 'l', 'u', 'l', 'a', 'r', '\n',
        'e', 'x', 't', 'r', 'a', 'c', 't', '\n',
        'e', 'x', 't', 'r', 'a', 'c', 't', 'a', 'b', 'l', 'e', '\n',
        'e', 'x', 't', 'r', 'a', 'c', 't', 'e', 'd', '\n',
        'e', 'x', 't', 'r', 'a', 'c', 't', 'i', 'n', 'g', '\n',
        'e', 'x', 't', 'r', 'a', 'c', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 't', 'r', 'a', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'x', 't', 'r', 'a', 'c', 't', 'i', 'v', 'e', '\n',
        'e', 'x', 't', 'r', 'a', 'c', 't', 'o', 'r', '\n',
        'e', 'x', 't', 'r', 'a', 'c', 't', 's', '\n',
        'e', 'x', 't', 'r', 'a', 'd', 'i', 't', 'a', 'b', 'l', 'e', '\n',
        'e', 'x', 't', 'r', 'a', 'd', 'i', 't', 'e', '\n',
        'e', 'x', 't', 'r', 'a', 'd', 'i', 't', 'e', 'd', '\n',
        'e', 'x', 't', 'r', 'a', 'd', 'i', 't', 'i', 'n', 'g', '\n',
        'e', 'x', 't', 'r', 'a', 'd', 'i', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 't', 'r', 'a', 'g', 'a', 'l', 'a', 'c', 't', 'i', 'c', '\n',
        'e', 'x', 't', 'r', 'a', 'j', 'u', 'd', 'i', 'c', 'i', 'a', 'l', '\n',
        'e', 'x', 't', 'r', 'a', 'l', 'i', 'n', 'g', 'u', 'i', 's', 't', 'i', 'c', '\n',
        'e', 'x', 't', 'r', 'a', 'm', 'a', 'r', 'i', 't', 'a', 'l', '\n',
        'e', 'x', 't', 'r', 'a', 'm', 'u', 'r', 'a', 'l', '\n',
        'e', 'x', 't', 'r', 'a', 'n', 'e', 'o', 'u', 's', '\n',
        'e', 'x', 't', 'r', 'a', 'o', 'r', 'd', 'i', 'n', 'a', 'r', 'i', 'l', 'y', '\n',
        'e', 'x', 't', 'r', 'a', 'o', 'r', 'd', 'i', 'n', 'a', 'r', 'y', '\n',
        'e', 'x', 't', 'r', 'a', 'p', 'o', 'l', 'a', 't', 'e', '\n',
        'e', 'x', 't', 'r', 'a', 'p', 'o', 'l', 'a', 't', 'e', 'd', '\n',
        'e', 'x', 't', 'r', 'a', 'p', 'o', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'x', 't', 'r', 'a', 'p', 'o', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 't', 'r', 'a', 'p', 'o', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'e', 'x', 't', 'r', 'a', 's', '\n',
        'e', 'x', 't', 'r', 'a', 's', 'o', 'l', 'a', 'r', '\n',
        'e', 'x', 't', 'r', 'a', 't', 'e', 'r', 'r', 'e', 's', 't', 'r', 'i', 'a', 'l', '\n',
        'e', 'x', 't', 'r', 'a', 't', 'e', 'r', 'r', 'e', 's', 't', 'r', 'i', 'a', 'l', 's', '\n',
        'e', 'x', 't', 'r', 'a', 't', 'e', 'r', 'r', 'i', 't', 'o', 'r', 'i', 'a', 'l', '\n',
        'e', 'x', 't', 'r', 'a', 'v', 'a', 'g', 'a', 'n', 'c', 'e', '\n',
        'e', 'x', 't', 'r', 'a', 'v', 'a', 'g', 'a', 'n', 'c', 'e', 's', '\n',
        'e', 'x', 't', 'r', 'a', 'v', 'a', 'g', 'a', 'n', 't', '\n',
        'e', 'x', 't', 'r', 'a', 'v', 'a', 'g', 'a', 'n', 't', 'l', 'y', '\n',
        'e', 'x', 't', 'r', 'a', 'v', 'a', 'g', 'a', 'n', 'z', 'a', '\n',
        'e', 'x', 't', 'r', 'a', 'v', 'a', 'g', 'a', 'n', 'z', 'a', 's', '\n',
        'e', 'x', 't', 'r', 'e', 'm', 'a', '\n',
        'e', 'x', 't', 'r', 'e', 'm', 'a', 'l', '\n',
        'e', 'x', 't', 'r', 'e', 'm', 'e', '\n',
        'e', 'x', 't', 'r', 'e', 'm', 'e', 'l', 'y', '\n',
        'e', 'x', 't', 'r', 'e', 'm', 'e', 's', '\n',
        'e', 'x', 't', 'r', 'e', 'm', 'e', 's', 't', '\n',
        'e', 'x', 't', 'r', 'e', 'm', 'i', 's', 'm', '\n',
        'e', 'x', 't', 'r', 'e', 'm', 'i', 's', 't', '\n',
        'e', 'x', 't', 'r', 'e', 'm', 'i', 's', 't', 's', '\n',
        'e', 'x', 't', 'r', 'e', 'm', 'i', 't', 'i', 'e', 's', '\n',
        'e', 'x', 't', 'r', 'e', 'm', 'i', 't', 'y', '\n',
        'e', 'x', 't', 'r', 'i', 'c', 'a', 't', 'e', '\n',
        'e', 'x', 't', 'r', 'i', 'c', 'a', 't', 'e', 'd', '\n',
        'e', 'x', 't', 'r', 'i', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'e', 'x', 't', 'r', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 't', 'r', 'i', 'n', 's', 'i', 'c', '\n',
        'e', 'x', 't', 'r', 'i', 'n', 's', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'e', 'x', 't', 'r', 'o', 'v', 'e', 'r', 's', 'i', 'o', 'n', '\n',
        'e', 'x', 't', 'r', 'o', 'v', 'e', 'r', 't', '\n',
        'e', 'x', 't', 'r', 'o', 'v', 'e', 'r', 't', 's', '\n',
        'e', 'x', 't', 'r', 'u', 'd', 'e', '\n',
        'e', 'x', 't', 'r', 'u', 'd', 'e', 'd', '\n',
        'e', 'x', 't', 'r', 'u', 's', 'i', 'o', 'n', '\n',
        'e', 'x', 't', 'r', 'u', 's', 'i', 'o', 'n', 's', '\n',
        'e', 'x', 'u', 'b', 'e', 'r', 'a', 'n', 'c', 'e', '\n',
        'e', 'x', 'u', 'b', 'e', 'r', 'a', 'n', 't', '\n',
        'e', 'x', 'u', 'b', 'e', 'r', 'a', 'n', 't', 'l', 'y', '\n',
        'e', 'x', 'u', 'd', 'a', 't', 'e', '\n',
        'e', 'x', 'u', 'd', 'e', '\n',
        'e', 'x', 'u', 'd', 'e', 'd', '\n',
        'e', 'x', 'u', 'd', 'e', 's', '\n',
        'e', 'x', 'u', 'd', 'i', 'n', 'g', '\n',
        'e', 'x', 'u', 'l', 't', '\n',
        'e', 'x', 'u', 'l', 't', 'a', 'n', 't', '\n',
        'e', 'x', 'u', 'l', 't', 'a', 'n', 't', 'l', 'y', '\n',
        'e', 'x', 'u', 'l', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'e', 'x', 'u', 'l', 't', 'e', 'd', '\n',
        'e', 'x', 'u', 'l', 't', 'i', 'n', 'g', '\n',
        'e', 'x', 'u', 'l', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'e', 'x', 'u', 'l', 't', 's', '\n',
        'e', 'x', 'w', 'i', 'f', 'e', '\n',
        'e', 'x', 'w', 'i', 'v', 'e', 's', '\n',
        'e', 'y', 'e', '\n',
        'e', 'y', 'e', 'b', 'a', 'l', 'l', '\n',
        'e', 'y', 'e', 'b', 'a', 'l', 'l', 's', '\n',
        'e', 'y', 'e', 'b', 'r', 'o', 'w', '\n',
        'e', 'y', 'e', 'b', 'r', 'o', 'w', 's', '\n',
        'e', 'y', 'e', 'c', 'a', 't', 'c', 'h', 'i', 'n', 'g', '\n',
        'e', 'y', 'e', 'd', '\n',
        'e', 'y', 'e', 'f', 'u', 'l', '\n',
        'e', 'y', 'e', 'g', 'l', 'a', 's', 's', '\n',
        'e', 'y', 'e', 'g', 'l', 'a', 's', 's', 'e', 's', '\n',
        'e', 'y', 'e', 'i', 'n', 'g', '\n',
        'e', 'y', 'e', 'l', 'a', 's', 'h', '\n',
        'e', 'y', 'e', 'l', 'a', 's', 'h', 'e', 's', '\n',
        'e', 'y', 'e', 'l', 'e', 's', 's', '\n',
        'e', 'y', 'e', 'l', 'e', 't', '\n',
        'e', 'y', 'e', 'l', 'e', 't', 's', '\n',
        'e', 'y', 'e', 'l', 'e', 'v', 'e', 'l', '\n',
        'e', 'y', 'e', 'l', 'i', 'd', '\n',
        'e', 'y', 'e', 'l', 'i', 'd', 's', '\n',
        'e', 'y', 'e', 'l', 'i', 'k', 'e', '\n',
        'e', 'y', 'e', 'l', 'i', 'n', 'e', 'r', '\n',
        'e', 'y', 'e', 'p', 'a', 't', 'c', 'h', '\n',
        'e', 'y', 'e', 'p', 'i', 'e', 'c', 'e', '\n',
        'e', 'y', 'e', 's', '\n',
        'e', 'y', 'e', 's', 'h', 'a', 'd', 'o', 'w', '\n',
        'e', 'y', 'e', 's', 'i', 'g', 'h', 't', '\n',
        'e', 'y', 'e', 's', 'o', 'r', 'e', '\n',
        'e', 'y', 'e', 's', 'o', 'r', 'e', 's', '\n',
        'e', 'y', 'e', 't', 'e', 'e', 't', 'h', '\n',
        'e', 'y', 'e', 't', 'o', 'o', 't', 'h', '\n',
        'e', 'y', 'e', 'w', 'a', 's', 'h', '\n',
        'e', 'y', 'e', 'w', 'i', 't', 'n', 'e', 's', 's', '\n',
        'e', 'y', 'e', 'w', 'i', 't', 'n', 'e', 's', 's', 'e', 's', '\n',
        'f', 'a', 'b', '\n',
        'f', 'a', 'b', 'l', 'e', '\n',
        'f', 'a', 'b', 'l', 'e', 'd', '\n',
        'f', 'a', 'b', 'l', 'e', 's', '\n',
        'f', 'a', 'b', 'r', 'i', 'c', '\n',
        'f', 'a', 'b', 'r', 'i', 'c', 'a', 't', 'e', '\n',
        'f', 'a', 'b', 'r', 'i', 'c', 'a', 't', 'e', 'd', '\n',
        'f', 'a', 'b', 'r', 'i', 'c', 'a', 't', 'e', 's', '\n',
        'f', 'a', 'b', 'r', 'i', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'f', 'a', 'b', 'r', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'f', 'a', 'b', 'r', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'f', 'a', 'b', 'r', 'i', 'c', 'a', 't', 'o', 'r', '\n',
        'f', 'a', 'b', 'r', 'i', 'c', 's', '\n',
        'f', 'a', 'b', 'u', 'l', 'i', 's', 't', 's', '\n',
        'f', 'a', 'b', 'u', 'l', 'o', 'u', 's', '\n',
        'f', 'a', 'b', 'u', 'l', 'o', 'u', 's', 'l', 'y', '\n',
        'f', 'a', 'c', 'a', 'd', 'e', '\n',
        'f', 'a', 'c', 'a', 'd', 'e', 's', '\n',
        'f', 'a', 'c', 'e', '\n',
        'f', 'a', 'c', 'e', 'd', '\n',
        'f', 'a', 'c', 'e', 'l', 'e', 's', 's', '\n',
        'f', 'a', 'c', 'e', 'l', 'i', 'f', 't', '\n',
        'f', 'a', 'c', 'e', 'p', 'l', 'a', 't', 'e', '\n',
        'f', 'a', 'c', 'e', 'r', '\n',
        'f', 'a', 'c', 'e', 'r', 's', '\n',
        'f', 'a', 'c', 'e', 's', '\n',
        'f', 'a', 'c', 'e', 't', '\n',
        'f', 'a', 'c', 'e', 't', 'e', 'd', '\n',
        'f', 'a', 'c', 'e', 't', 'i', 'n', 'g', '\n',
        'f', 'a', 'c', 'e', 't', 'i', 'o', 'u', 's', '\n',
        'f', 'a', 'c', 'e', 't', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'f', 'a', 'c', 'e', 't', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'f', 'a', 'c', 'e', 't', 's', '\n',
        'f', 'a', 'c', 'i', 'a', '\n',
        'f', 'a', 'c', 'i', 'a', 'l', '\n',
        'f', 'a', 'c', 'i', 'a', 'l', 's', '\n',
        'f', 'a', 'c', 'i', 'l', 'e', '\n',
        'f', 'a', 'c', 'i', 'l', 'i', 't', 'a', 't', 'e', '\n',
        'f', 'a', 'c', 'i', 'l', 'i', 't', 'a', 't', 'e', 'd', '\n',
        'f', 'a', 'c', 'i', 'l', 'i', 't', 'a', 't', 'e', 's', '\n',
        'f', 'a', 'c', 'i', 'l', 'i', 't', 'a', 't', 'i', 'n', 'g', '\n',
        'f', 'a', 'c', 'i', 'l', 'i', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'f', 'a', 'c', 'i', 'l', 'i', 't', 'a', 't', 'i', 'v', 'e', '\n',
        'f', 'a', 'c', 'i', 'l', 'i', 't', 'a', 't', 'o', 'r', '\n',
        'f', 'a', 'c', 'i', 'l', 'i', 't', 'a', 't', 'o', 'r', 's', '\n',
        'f', 'a', 'c', 'i', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'f', 'a', 'c', 'i', 'l', 'i', 't', 'y', '\n',
        'f', 'a', 'c', 'i', 'n', 'g', '\n',
        'f', 'a', 'c', 'i', 'n', 'g', 's', '\n',
        'f', 'a', 'c', 's', 'i', 'm', 'i', 'l', 'e', '\n',
        'f', 'a', 'c', 's', 'i', 'm', 'i', 'l', 'e', 's', '\n',
        'f', 'a', 'c', 't', '\n',
        'f', 'a', 'c', 't', 'i', 'o', 'n', '\n',
        'f', 'a', 'c', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'f', 'a', 'c', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 'm', '\n',
        'f', 'a', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'f', 'a', 'c', 't', 'i', 'o', 'u', 's', '\n',
        'f', 'a', 'c', 't', 'i', 't', 'i', 'o', 'u', 's', '\n',
        'f', 'a', 'c', 't', 'o', 'r', '\n',
        'f', 'a', 'c', 't', 'o', 'r', 'e', 'd', '\n',
        'f', 'a', 'c', 't', 'o', 'r', 'i', 'a', 'l', '\n',
        'f', 'a', 'c', 't', 'o', 'r', 'i', 'a', 'l', 's', '\n',
        'f', 'a', 'c', 't', 'o', 'r', 'i', 'e', 's', '\n',
        'f', 'a', 'c', 't', 'o', 'r', 'i', 'n', 'g', '\n',
        'f', 'a', 'c', 't', 'o', 'r', 'i', 's', 'a', 'b', 'l', 'e', '\n',
        'f', 'a', 'c', 't', 'o', 'r', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'f', 'a', 'c', 't', 'o', 'r', 'i', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'f', 'a', 'c', 't', 'o', 'r', 'i', 's', 'e', '\n',
        'f', 'a', 'c', 't', 'o', 'r', 'i', 's', 'e', 'd', '\n',
        'f', 'a', 'c', 't', 'o', 'r', 'i', 's', 'e', 's', '\n',
        'f', 'a', 'c', 't', 'o', 'r', 'i', 's', 'i', 'n', 'g', '\n',
        'f', 'a', 'c', 't', 'o', 'r', 's', '\n',
        'f', 'a', 'c', 't', 'o', 'r', 'y', '\n',
        'f', 'a', 'c', 't', 'o', 't', 'u', 'm', '\n',
        'f', 'a', 'c', 't', 's', '\n',
        'f', 'a', 'c', 't', 'u', 'a', 'l', '\n',
        'f', 'a', 'c', 't', 'u', 'a', 'l', 'l', 'y', '\n',
        'f', 'a', 'c', 'u', 'l', 't', 'i', 'e', 's', '\n',
        'f', 'a', 'c', 'u', 'l', 't', 'y', '\n',
        'f', 'a', 'd', '\n',
        'f', 'a', 'd', 'e', '\n',
        'f', 'a', 'd', 'e', 'd', '\n',
        'f', 'a', 'd', 'e', 'o', 'u', 't', '\n',
        'f', 'a', 'd', 'e', 's', '\n',
        'f', 'a', 'd', 'i', 'n', 'g', '\n',
        'f', 'a', 'd', 's', '\n',
        'f', 'a', 'e', 'c', 'a', 'l', '\n',
        'f', 'a', 'e', 'c', 'e', 's', '\n',
        'f', 'a', 'g', '\n',
        'f', 'a', 'g', 'g', 'o', 't', '\n',
        'f', 'a', 'g', 'g', 'o', 't', 's', '\n',
        'f', 'a', 'g', 'o', 't', '\n',
        'f', 'a', 'g', 's', '\n',
        'f', 'a', 'i', 'l', '\n',
        'f', 'a', 'i', 'l', 'e', 'd', '\n',
        'f', 'a', 'i', 'l', 'i', 'n', 'g', '\n',
        'f', 'a', 'i', 'l', 'i', 'n', 'g', 's', '\n',
        'f', 'a', 'i', 'l', 's', '\n',
        'f', 'a', 'i', 'l', 'u', 'r', 'e', '\n',
        'f', 'a', 'i', 'l', 'u', 'r', 'e', 's', '\n',
        'f', 'a', 'i', 'n', 't', '\n',
        'f', 'a', 'i', 'n', 't', 'e', 'd', '\n',
        'f', 'a', 'i', 'n', 't', 'e', 'r', '\n',
        'f', 'a', 'i', 'n', 't', 'e', 's', 't', '\n',
        'f', 'a', 'i', 'n', 't', 'h', 'e', 'a', 'r', 't', 'e', 'd', '\n',
        'f', 'a', 'i', 'n', 't', 'i', 'n', 'g', '\n',
        'f', 'a', 'i', 'n', 't', 'l', 'y', '\n',
        'f', 'a', 'i', 'n', 't', 'n', 'e', 's', 's', '\n',
        'f', 'a', 'i', 'n', 't', 's', '\n',
        'f', 'a', 'i', 'r', '\n',
        'f', 'a', 'i', 'r', 'e', 'r', '\n',
        'f', 'a', 'i', 'r', 'e', 's', 't', '\n',
        'f', 'a', 'i', 'r', 'g', 'r', 'o', 'u', 'n', 'd', '\n',
        'f', 'a', 'i', 'r', 'g', 'r', 'o', 'u', 'n', 'd', 's', '\n',
        'f', 'a', 'i', 'r', 'i', 'e', 's', '\n',
        'f', 'a', 'i', 'r', 'i', 'n', 'g', '\n',
        'f', 'a', 'i', 'r', 'i', 's', 'h', '\n',
        'f', 'a', 'i', 'r', 'l', 'y', '\n',
        'f', 'a', 'i', 'r', 'n', 'e', 's', 's', '\n',
        'f', 'a', 'i', 'r', 's', '\n',
        'f', 'a', 'i', 'r', 's', 'e', 'x', '\n',
        'f', 'a', 'i', 'r', 'w', 'a', 'y', '\n',
        'f', 'a', 'i', 'r', 'w', 'a', 'y', 's', '\n',
        'f', 'a', 'i', 'r', 'y', '\n',
        'f', 'a', 'i', 'r', 'y', 't', 'a', 'l', 'e', '\n',
        'f', 'a', 'i', 't', 'h', '\n',
        'f', 'a', 'i', 't', 'h', 'f', 'u', 'l', '\n',
        'f', 'a', 'i', 't', 'h', 'f', 'u', 'l', 'l', 'y', '\n',
        'f', 'a', 'i', 't', 'h', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'f', 'a', 'i', 't', 'h', 'l', 'e', 's', 's', '\n',
        'f', 'a', 'i', 't', 'h', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'f', 'a', 'i', 't', 'h', 's', '\n',
        'f', 'a', 'k', 'e', '\n',
        'f', 'a', 'k', 'e', 'd', '\n',
        'f', 'a', 'k', 'e', 'r', 's', '\n',
        'f', 'a', 'k', 'e', 'r', 'y', '\n',
        'f', 'a', 'k', 'e', 's', '\n',
        'f', 'a', 'k', 'i', 'n', 'g', '\n',
        'f', 'a', 'l', 'c', 'o', 'n', '\n',
        'f', 'a', 'l', 'c', 'o', 'n', 'e', 'r', '\n',
        'f', 'a', 'l', 'c', 'o', 'n', 'r', 'y', '\n',
        'f', 'a', 'l', 'c', 'o', 'n', 's', '\n',
        'f', 'a', 'l', 'l', '\n',
        'f', 'a', 'l', 'l', 'a', 'c', 'i', 'e', 's', '\n',
        'f', 'a', 'l', 'l', 'a', 'c', 'i', 'o', 'u', 's', '\n',
        'f', 'a', 'l', 'l', 'a', 'c', 'y', '\n',
        'f', 'a', 'l', 'l', 'e', 'n', '\n',
        'f', 'a', 'l', 'l', 'e', 'r', '\n',
        'f', 'a', 'l', 'l', 'e', 'r', 's', '\n',
        'f', 'a', 'l', 'l', 'g', 'u', 'y', '\n',
        'f', 'a', 'l', 'l', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'f', 'a', 'l', 'l', 'i', 'b', 'l', 'e', '\n',
        'f', 'a', 'l', 'l', 'i', 'n', 'g', '\n',
        'f', 'a', 'l', 'l', 'o', 'p', 'i', 'a', 'n', '\n',
        'f', 'a', 'l', 'l', 'o', 'u', 't', '\n',
        'f', 'a', 'l', 'l', 'o', 'w', '\n',
        'f', 'a', 'l', 'l', 's', '\n',
        'f', 'a', 'l', 's', 'e', '\n',
        'f', 'a', 'l', 's', 'e', 'b', 'a', 'y', '\n',
        'f', 'a', 'l', 's', 'e', 'h', 'o', 'o', 'd', '\n',
        'f', 'a', 'l', 's', 'e', 'h', 'o', 'o', 'd', 's', '\n',
        'f', 'a', 'l', 's', 'e', 'l', 'y', '\n',
        'f', 'a', 'l', 's', 'e', 'n', 'e', 's', 's', '\n',
        'f', 'a', 'l', 's', 'e', 'r', '\n',
        'f', 'a', 'l', 's', 'e', 't', 't', 'o', '\n',
        'f', 'a', 'l', 's', 'i', 'f', 'i', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'f', 'a', 'l', 's', 'i', 'f', 'i', 'a', 'b', 'l', 'e', '\n',
        'f', 'a', 'l', 's', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'f', 'a', 'l', 's', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'f', 'a', 'l', 's', 'i', 'f', 'i', 'e', 'd', '\n',
        'f', 'a', 'l', 's', 'i', 'f', 'i', 'e', 'r', '\n',
        'f', 'a', 'l', 's', 'i', 'f', 'i', 'e', 'r', 's', '\n',
        'f', 'a', 'l', 's', 'i', 'f', 'i', 'e', 's', '\n',
        'f', 'a', 'l', 's', 'i', 'f', 'y', '\n',
        'f', 'a', 'l', 's', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'f', 'a', 'l', 's', 'i', 't', 'i', 'e', 's', '\n',
        'f', 'a', 'l', 's', 'i', 't', 'y', '\n',
        'f', 'a', 'l', 't', 'e', 'r', '\n',
        'f', 'a', 'l', 't', 'e', 'r', 'e', 'd', '\n',
        'f', 'a', 'l', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'f', 'a', 'l', 't', 'e', 'r', 'i', 'n', 'g', 'l', 'y', '\n',
        'f', 'a', 'l', 't', 'e', 'r', 's', '\n',
        'f', 'a', 'm', 'e', '\n',
        'f', 'a', 'm', 'e', 'd', '\n',
        'f', 'a', 'm', 'i', 'l', 'i', 'a', 'l', '\n',
        'f', 'a', 'm', 'i', 'l', 'i', 'a', 'r', '\n',
        'f', 'a', 'm', 'i', 'l', 'i', 'a', 'r', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'f', 'a', 'm', 'i', 'l', 'i', 'a', 'r', 'i', 's', 'e', '\n',
        'f', 'a', 'm', 'i', 'l', 'i', 'a', 'r', 'i', 's', 'e', 'd', '\n',
        'f', 'a', 'm', 'i', 'l', 'i', 'a', 'r', 'i', 's', 'i', 'n', 'g', '\n',
        'f', 'a', 'm', 'i', 'l', 'i', 'a', 'r', 'i', 't', 'i', 'e', 's', '\n',
        'f', 'a', 'm', 'i', 'l', 'i', 'a', 'r', 'i', 't', 'y', '\n',
        'f', 'a', 'm', 'i', 'l', 'i', 'a', 'r', 'l', 'y', '\n',
        'f', 'a', 'm', 'i', 'l', 'i', 'e', 's', '\n',
        'f', 'a', 'm', 'i', 'l', 'y', '\n',
        'f', 'a', 'm', 'i', 'n', 'e', '\n',
        'f', 'a', 'm', 'i', 'n', 'e', 's', '\n',
        'f', 'a', 'm', 'i', 's', 'h', '\n',
        'f', 'a', 'm', 'i', 's', 'h', 'e', 'd', '\n',
        'f', 'a', 'm', 'o', 'u', 's', '\n',
        'f', 'a', 'm', 'o', 'u', 's', 'l', 'y', '\n',
        'f', 'a', 'n', '\n',
        'f', 'a', 'n', 'a', 't', 'i', 'c', '\n',
        'f', 'a', 'n', 'a', 't', 'i', 'c', 'a', 'l', '\n',
        'f', 'a', 'n', 'a', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'f', 'a', 'n', 'a', 't', 'i', 'c', 'i', 's', 'm', '\n',
        'f', 'a', 'n', 'a', 't', 'i', 'c', 's', '\n',
        'f', 'a', 'n', 'b', 'e', 'l', 't', '\n',
        'f', 'a', 'n', 'c', 'i', 'a', 'b', 'l', 'e', '\n',
        'f', 'a', 'n', 'c', 'i', 'e', 'd', '\n',
        'f', 'a', 'n', 'c', 'i', 'e', 'r', '\n',
        'f', 'a', 'n', 'c', 'i', 'e', 'r', 's', '\n',
        'f', 'a', 'n', 'c', 'i', 'e', 's', '\n',
        'f', 'a', 'n', 'c', 'i', 'e', 's', 't', '\n',
        'f', 'a', 'n', 'c', 'i', 'f', 'u', 'l', '\n',
        'f', 'a', 'n', 'c', 'i', 'f', 'u', 'l', 'l', 'y', '\n',
        'f', 'a', 'n', 'c', 'y', '\n',
        'f', 'a', 'n', 'c', 'y', 'i', 'n', 'g', '\n',
        'f', 'a', 'n', 'd', 'a', 'n', 'g', 'o', '\n',
        'f', 'a', 'n', 'f', 'a', 'r', 'e', '\n',
        'f', 'a', 'n', 'f', 'a', 'r', 'e', 's', '\n',
        'f', 'a', 'n', 'g', '\n',
        'f', 'a', 'n', 'g', 's', '\n',
        'f', 'a', 'n', 'l', 'i', 'g', 'h', 't', '\n',
        'f', 'a', 'n', 'n', 'e', 'd', '\n',
        'f', 'a', 'n', 'n', 'i', 'n', 'g', '\n',
        'f', 'a', 'n', 'n', 'y', '\n',
        'f', 'a', 'n', 's', '\n',
        'f', 'a', 'n', 't', 'a', 'i', 'l', '\n',
        'f', 'a', 'n', 't', 'a', 'i', 'l', 's', '\n',
        'f', 'a', 'n', 't', 'a', 's', 'i', 'a', '\n',
        'f', 'a', 'n', 't', 'a', 's', 't', 'i', 'c', '\n',
        'f', 'a', 'r', '\n',
        'f', 'a', 'r', 'a', 'd', '\n',
        'f', 'a', 'r', 'a', 'd', 'a', 'y', '\n',
        'f', 'a', 'r', 'a', 'w', 'a', 'y', '\n',
        'f', 'a', 'r', 'c', 'e', '\n',
        'f', 'a', 'r', 'c', 'e', 's', '\n',
        'f', 'a', 'r', 'c', 'i', 'c', 'a', 'l', '\n',
        'f', 'a', 'r', 'e', '\n',
        'f', 'a', 'r', 'e', 'd', '\n',
        'f', 'a', 'r', 'e', 's', '\n',
        'f', 'a', 'r', 'e', 'w', 'e', 'l', 'l', '\n',
        'f', 'a', 'r', 'e', 'w', 'e', 'l', 'l', 's', '\n',
        'f', 'a', 'r', 'f', 'e', 't', 'c', 'h', 'e', 'd', '\n',
        'f', 'a', 'r', 'f', 'l', 'u', 'n', 'g', '\n',
        'f', 'a', 'r', 'i', 'n', 'g', '\n',
        'f', 'a', 'r', 'm', '\n',
        'f', 'a', 'r', 'm', 'e', 'd', '\n',
        'f', 'a', 'r', 'm', 'e', 'r', '\n',
        'f', 'a', 'r', 'm', 'e', 'r', 's', '\n',
        'f', 'a', 'r', 'm', 'h', 'o', 'u', 's', 'e', '\n',
        'f', 'a', 'r', 'm', 'h', 'o', 'u', 's', 'e', 's', '\n',
        'f', 'a', 'r', 'm', 'i', 'n', 'g', '\n',
        'f', 'a', 'r', 'm', 'i', 'n', 'g', 's', '\n',
        'f', 'a', 'r', 'm', 'l', 'a', 'n', 'd', '\n',
        'f', 'a', 'r', 'm', 's', '\n',
        'f', 'a', 'r', 'm', 's', 't', 'e', 'a', 'd', '\n',
        'f', 'a', 'r', 'm', 's', 't', 'e', 'a', 'd', 's', '\n',
        'f', 'a', 'r', 'm', 'y', 'a', 'r', 'd', '\n',
        'f', 'a', 'r', 'm', 'y', 'a', 'r', 'd', 's', '\n',
        'f', 'a', 'r', 'o', 'f', 'f', '\n',
        'f', 'a', 'r', 'o', 'u', 't', '\n',
        'f', 'a', 'r', 'r', 'a', 'g', 'o', '\n',
        'f', 'a', 'r', 'r', 'e', 'a', 'c', 'h', 'i', 'n', 'g', '\n',
        'f', 'a', 'r', 'r', 'i', 'e', 'r', '\n',
        'f', 'a', 'r', 'r', 'i', 'e', 'r', 's', '\n',
        'f', 'a', 'r', 'r', 'o', 'w', '\n',
        'f', 'a', 'r', 's', 'e', 'e', 'i', 'n', 'g', '\n',
        'f', 'a', 'r', 's', 'i', 'g', 'h', 't', 'e', 'd', '\n',
        'f', 'a', 'r', 't', 'h', 'e', 'r', '\n',
        'f', 'a', 'r', 't', 'h', 'e', 's', 't', '\n',
        'f', 'a', 'r', 't', 'h', 'i', 'n', 'g', '\n',
        'f', 'a', 'r', 't', 'h', 'i', 'n', 'g', 's', '\n',
        'f', 'a', 's', 'c', 'i', 'a', '\n',
        'f', 'a', 's', 'c', 'i', 'a', 's', '\n',
        'f', 'a', 's', 'c', 'i', 'n', 'a', 't', 'e', '\n',
        'f', 'a', 's', 'c', 'i', 'n', 'a', 't', 'e', 'd', '\n',
        'f', 'a', 's', 'c', 'i', 'n', 'a', 't', 'e', 's', '\n',
        'f', 'a', 's', 'c', 'i', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'f', 'a', 's', 'c', 'i', 'n', 'a', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'f', 'a', 's', 'c', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'f', 'a', 's', 'c', 'i', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'f', 'a', 's', 'c', 'i', 's', 'm', '\n',
        'f', 'a', 's', 'c', 'i', 's', 't', '\n',
        'f', 'a', 's', 'c', 'i', 's', 't', 's', '\n',
        'f', 'a', 's', 'h', 'i', 'o', 'n', '\n',
        'f', 'a', 's', 'h', 'i', 'o', 'n', 'a', 'b', 'l', 'e', '\n',
        'f', 'a', 's', 'h', 'i', 'o', 'n', 'a', 'b', 'l', 'y', '\n',
        'f', 'a', 's', 'h', 'i', 'o', 'n', 'e', 'd', '\n',
        'f', 'a', 's', 'h', 'i', 'o', 'n', 'i', 'n', 'g', '\n',
        'f', 'a', 's', 'h', 'i', 'o', 'n', 's', '\n',
        'f', 'a', 's', 't', '\n',
        'f', 'a', 's', 't', 'e', 'd', '\n',
        'f', 'a', 's', 't', 'e', 'n', '\n',
        'f', 'a', 's', 't', 'e', 'n', 'e', 'd', '\n',
        'f', 'a', 's', 't', 'e', 'n', 'e', 'r', '\n',
        'f', 'a', 's', 't', 'e', 'n', 'e', 'r', 's', '\n',
        'f', 'a', 's', 't', 'e', 'n', 'i', 'n', 'g', '\n',
        'f', 'a', 's', 't', 'e', 'n', 'i', 'n', 'g', 's', '\n',
        'f', 'a', 's', 't', 'e', 'n', 's', '\n',
        'f', 'a', 's', 't', 'e', 'r', '\n',
        'f', 'a', 's', 't', 'e', 's', 't', '\n',
        'f', 'a', 's', 't', 'i', 'd', 'i', 'o', 'u', 's', '\n',
        'f', 'a', 's', 't', 'i', 'd', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'f', 'a', 's', 't', 'i', 'd', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'f', 'a', 's', 't', 'i', 'n', 'g', '\n',
        'f', 'a', 's', 't', 'i', 'n', 'g', 's', '\n',
        'f', 'a', 's', 't', 'n', 'e', 's', 's', '\n',
        'f', 'a', 's', 't', 'n', 'e', 's', 's', 'e', 's', '\n',
        'f', 'a', 's', 't', 's', '\n',
        'f', 'a', 't', '\n',
        'f', 'a', 't', 'a', 'l', '\n',
        'f', 'a', 't', 'a', 'l', 'i', 's', 'm', '\n',
        'f', 'a', 't', 'a', 'l', 'i', 's', 't', '\n',
        'f', 'a', 't', 'a', 'l', 'i', 's', 't', 'i', 'c', '\n',
        'f', 'a', 't', 'a', 'l', 'i', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'f', 'a', 't', 'a', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'f', 'a', 't', 'a', 'l', 'i', 't', 'y', '\n',
        'f', 'a', 't', 'a', 'l', 'l', 'y', '\n',
        'f', 'a', 't', 'c', 'a', 't', '\n',
        'f', 'a', 't', 'e', '\n',
        'f', 'a', 't', 'e', 'd', '\n',
        'f', 'a', 't', 'e', 'f', 'u', 'l', '\n',
        'f', 'a', 't', 'e', 's', '\n',
        'f', 'a', 't', 'h', 'e', 'a', 'd', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'f', 'a', 't', 'h', 'e', 'r', '\n',
        'f', 'a', 't', 'h', 'e', 'r', 'e', 'd', '\n',
        'f', 'a', 't', 'h', 'e', 'r', 'h', 'o', 'o', 'd', '\n',
        'f', 'a', 't', 'h', 'e', 'r', 'i', 'n', 'g', '\n',
        'f', 'a', 't', 'h', 'e', 'r', 'i', 'n', 'l', 'a', 'w', '\n',
        'f', 'a', 't', 'h', 'e', 'r', 'l', 'a', 'n', 'd', '\n',
        'f', 'a', 't', 'h', 'e', 'r', 'l', 'e', 's', 's', '\n',
        'f', 'a', 't', 'h', 'e', 'r', 'l', 'y', '\n',
        'f', 'a', 't', 'h', 'e', 'r', 's', '\n',
        'f', 'a', 't', 'h', 'e', 'r', 's', 'i', 'n', 'l', 'a', 'w', '\n',
        'f', 'a', 't', 'h', 'o', 'm', '\n',
        'f', 'a', 't', 'h', 'o', 'm', 'e', 'd', '\n',
        'f', 'a', 't', 'h', 'o', 'm', 'i', 'n', 'g', '\n',
        'f', 'a', 't', 'h', 'o', 'm', 'l', 'e', 's', 's', '\n',
        'f', 'a', 't', 'h', 'o', 'm', 's', '\n',
        'f', 'a', 't', 'i', 'g', 'u', 'e', '\n',
        'f', 'a', 't', 'i', 'g', 'u', 'e', 'd', '\n',
        'f', 'a', 't', 'i', 'g', 'u', 'e', 's', '\n',
        'f', 'a', 't', 'i', 'g', 'u', 'i', 'n', 'g', '\n',
        'f', 'a', 't', 'l', 'e', 's', 's', '\n',
        'f', 'a', 't', 'n', 'e', 's', 's', '\n',
        'f', 'a', 't', 's', '\n',
        'f', 'a', 't', 't', 'e', 'd', '\n',
        'f', 'a', 't', 't', 'e', 'n', '\n',
        'f', 'a', 't', 't', 'e', 'n', 'e', 'd', '\n',
        'f', 'a', 't', 't', 'e', 'n', 'i', 'n', 'g', '\n',
        'f', 'a', 't', 't', 'e', 'n', 's', '\n',
        'f', 'a', 't', 't', 'e', 'r', '\n',
        'f', 'a', 't', 't', 'e', 's', 't', '\n',
        'f', 'a', 't', 't', 'i', 'e', 'r', '\n',
        'f', 'a', 't', 't', 'i', 'e', 's', 't', '\n',
        'f', 'a', 't', 't', 'y', '\n',
        'f', 'a', 't', 'u', 'i', 't', 'y', '\n',
        'f', 'a', 't', 'u', 'o', 'u', 's', '\n',
        'f', 'a', 't', 'u', 'o', 'u', 's', 'l', 'y', '\n',
        'f', 'a', 't', 'w', 'a', '\n',
        'f', 'a', 'u', 'c', 'e', 't', '\n',
        'f', 'a', 'u', 'c', 'e', 't', 's', '\n',
        'f', 'a', 'u', 'l', 't', '\n',
        'f', 'a', 'u', 'l', 't', 'e', 'd', '\n',
        'f', 'a', 'u', 'l', 't', 'i', 'n', 'g', '\n',
        'f', 'a', 'u', 'l', 't', 'l', 'e', 's', 's', '\n',
        'f', 'a', 'u', 'l', 't', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'f', 'a', 'u', 'l', 't', 's', '\n',
        'f', 'a', 'u', 'l', 't', 'y', '\n',
        'f', 'a', 'u', 'n', '\n',
        'f', 'a', 'u', 'n', 'a', '\n',
        'f', 'a', 'u', 'n', 'a', 'l', '\n',
        'f', 'a', 'u', 'n', 'a', 's', '\n',
        'f', 'a', 'u', 'n', 's', '\n',
        'f', 'a', 'u', 's', 't', '\n',
        'f', 'a', 'u', 's', 't', 'u', 's', '\n',
        'f', 'a', 'v', 'o', 'u', 'r', '\n',
        'f', 'a', 'v', 'o', 'u', 'r', 'a', 'b', 'l', 'e', '\n',
        'f', 'a', 'v', 'o', 'u', 'r', 'a', 'b', 'l', 'y', '\n',
        'f', 'a', 'v', 'o', 'u', 'r', 'e', 'd', '\n',
        'f', 'a', 'v', 'o', 'u', 'r', 'i', 'n', 'g', '\n',
        'f', 'a', 'v', 'o', 'u', 'r', 'i', 't', 'e', '\n',
        'f', 'a', 'v', 'o', 'u', 'r', 'i', 't', 'e', 's', '\n',
        'f', 'a', 'v', 'o', 'u', 'r', 'i', 't', 'i', 's', 'm', '\n',
        'f', 'a', 'v', 'o', 'u', 'r', 's', '\n',
        'f', 'a', 'w', 'n', '\n',
        'f', 'a', 'w', 'n', 'e', 'd', '\n',
        'f', 'a', 'w', 'n', 'i', 'n', 'g', '\n',
        'f', 'a', 'w', 'n', 'i', 'n', 'g', 'l', 'y', '\n',
        'f', 'a', 'w', 'n', 's', '\n',
        'f', 'a', 'x', '\n',
        'f', 'a', 'x', 'e', 'd', '\n',
        'f', 'a', 'x', 'e', 's', '\n',
        'f', 'a', 'x', 'i', 'n', 'g', '\n',
        'f', 'e', 'a', 'l', 't', 'y', '\n',
        'f', 'e', 'a', 'r', '\n',
        'f', 'e', 'a', 'r', 'e', 'd', '\n',
        'f', 'e', 'a', 'r', 'f', 'u', 'l', '\n',
        'f', 'e', 'a', 'r', 'f', 'u', 'l', 'l', 'y', '\n',
        'f', 'e', 'a', 'r', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'f', 'e', 'a', 'r', 'i', 'n', 'g', '\n',
        'f', 'e', 'a', 'r', 'l', 'e', 's', 's', '\n',
        'f', 'e', 'a', 'r', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'f', 'e', 'a', 'r', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'f', 'e', 'a', 'r', 's', '\n',
        'f', 'e', 'a', 'r', 's', 'o', 'm', 'e', '\n',
        'f', 'e', 'a', 'r', 's', 'o', 'm', 'e', 'l', 'y', '\n',
        'f', 'e', 'a', 'r', 's', 'o', 'm', 'e', 'n', 'e', 's', 's', '\n',
        'f', 'e', 'a', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'f', 'e', 'a', 's', 'i', 'b', 'l', 'e', '\n',
        'f', 'e', 'a', 's', 'i', 'b', 'l', 'y', '\n',
        'f', 'e', 'a', 's', 't', '\n',
        'f', 'e', 'a', 's', 't', 'e', 'd', '\n',
        'f', 'e', 'a', 's', 't', 'i', 'n', 'g', '\n',
        'f', 'e', 'a', 's', 't', 's', '\n',
        'f', 'e', 'a', 't', '\n',
        'f', 'e', 'a', 't', 'h', 'e', 'r', '\n',
        'f', 'e', 'a', 't', 'h', 'e', 'r', 'e', 'd', '\n',
        'f', 'e', 'a', 't', 'h', 'e', 'r', 'i', 'n', 'g', '\n',
        'f', 'e', 'a', 't', 'h', 'e', 'r', 'l', 'i', 'g', 'h', 't', '\n',
        'f', 'e', 'a', 't', 'h', 'e', 'r', 's', '\n',
        'f', 'e', 'a', 't', 'h', 'e', 'r', 'w', 'e', 'i', 'g', 'h', 't', '\n',
        'f', 'e', 'a', 't', 'h', 'e', 'r', 'y', '\n',
        'f', 'e', 'a', 't', 's', '\n',
        'f', 'e', 'a', 't', 'u', 'r', 'e', '\n',
        'f', 'e', 'a', 't', 'u', 'r', 'e', 'd', '\n',
        'f', 'e', 'a', 't', 'u', 'r', 'e', 'l', 'e', 's', 's', '\n',
        'f', 'e', 'a', 't', 'u', 'r', 'e', 's', '\n',
        'f', 'e', 'a', 't', 'u', 'r', 'i', 'n', 'g', '\n',
        'f', 'e', 'b', 'r', 'i', 'l', 'e', '\n',
        'f', 'e', 'b', 'r', 'u', 'a', 'r', 'y', '\n',
        'f', 'e', 'c', 'k', 'l', 'e', 's', 's', '\n',
        'f', 'e', 'c', 'k', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'f', 'e', 'c', 'u', 'n', 'd', '\n',
        'f', 'e', 'c', 'u', 'n', 'd', 'i', 't', 'y', '\n',
        'f', 'e', 'd', '\n',
        'f', 'e', 'd', 'e', 'r', 'a', 'l', '\n',
        'f', 'e', 'd', 'e', 'r', 'a', 'l', 'i', 's', 'm', '\n',
        'f', 'e', 'd', 'e', 'r', 'a', 'l', 'i', 's', 't', '\n',
        'f', 'e', 'd', 'e', 'r', 'a', 'l', 'i', 's', 't', 's', '\n',
        'f', 'e', 'd', 'e', 'r', 'a', 'l', 'l', 'y', '\n',
        'f', 'e', 'd', 'e', 'r', 'a', 't', 'e', '\n',
        'f', 'e', 'd', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'f', 'e', 'd', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'f', 'e', 'd', 'e', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'f', 'e', 'd', 'o', 'r', 'a', '\n',
        'f', 'e', 'd', 's', '\n',
        'f', 'e', 'd', 'u', 'p', '\n',
        'f', 'e', 'e', '\n',
        'f', 'e', 'e', 'b', 'l', 'e', '\n',
        'f', 'e', 'e', 'b', 'l', 'e', 'm', 'i', 'n', 'd', 'e', 'd', '\n',
        'f', 'e', 'e', 'b', 'l', 'e', 'n', 'e', 's', 's', '\n',
        'f', 'e', 'e', 'b', 'l', 'e', 'r', '\n',
        'f', 'e', 'e', 'b', 'l', 'e', 's', 't', '\n',
        'f', 'e', 'e', 'b', 'l', 'y', '\n',
        'f', 'e', 'e', 'd', '\n',
        'f', 'e', 'e', 'd', 'b', 'a', 'c', 'k', '\n',
        'f', 'e', 'e', 'd', 'e', 'r', '\n',
        'f', 'e', 'e', 'd', 'e', 'r', 's', '\n',
        'f', 'e', 'e', 'd', 'i', 'n', 'g', '\n',
        'f', 'e', 'e', 'd', 'i', 'n', 'g', 's', '\n',
        'f', 'e', 'e', 'd', 's', '\n',
        'f', 'e', 'e', 'd', 's', 't', 'o', 'c', 'k', '\n',
        'f', 'e', 'e', 'd', 's', 't', 'u', 'f', 'f', 's', '\n',
        'f', 'e', 'e', 'l', '\n',
        'f', 'e', 'e', 'l', 'e', 'r', '\n',
        'f', 'e', 'e', 'l', 'e', 'r', 's', '\n',
        'f', 'e', 'e', 'l', 'i', 'n', 'g', '\n',
        'f', 'e', 'e', 'l', 'i', 'n', 'g', 'l', 'y', '\n',
        'f', 'e', 'e', 'l', 'i', 'n', 'g', 's', '\n',
        'f', 'e', 'e', 'l', 's', '\n',
        'f', 'e', 'e', 's', '\n',
        'f', 'e', 'e', 't', '\n',
        'f', 'e', 'i', 'g', 'n', '\n',
        'f', 'e', 'i', 'g', 'n', 'e', 'd', '\n',
        'f', 'e', 'i', 'g', 'n', 'i', 'n', 'g', '\n',
        'f', 'e', 'i', 'g', 'n', 's', '\n',
        'f', 'e', 'i', 'n', 't', '\n',
        'f', 'e', 'i', 'n', 't', 'e', 'd', '\n',
        'f', 'e', 'i', 'n', 't', 'i', 'n', 'g', '\n',
        'f', 'e', 'i', 'n', 't', 's', '\n',
        'f', 'e', 'l', 'd', 's', 'p', 'a', 'r', '\n',
        'f', 'e', 'l', 'd', 's', 'p', 'a', 'r', 's', '\n',
        'f', 'e', 'l', 'i', 'c', 'i', 'a', '\n',
        'f', 'e', 'l', 'i', 'c', 'i', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'f', 'e', 'l', 'i', 'c', 'i', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'f', 'e', 'l', 'i', 'c', 'i', 't', 'i', 'e', 's', '\n',
        'f', 'e', 'l', 'i', 'c', 'i', 't', 'o', 'u', 's', '\n',
        'f', 'e', 'l', 'i', 'c', 'i', 't', 'y', '\n',
        'f', 'e', 'l', 'i', 'n', 'e', '\n',
        'f', 'e', 'l', 'i', 'n', 'e', 's', '\n',
        'f', 'e', 'l', 'l', '\n',
        'f', 'e', 'l', 'l', 'a', 't', 'i', 'o', '\n',
        'f', 'e', 'l', 'l', 'e', 'd', '\n',
        'f', 'e', 'l', 'l', 'e', 'r', '\n',
        'f', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'f', 'e', 'l', 'l', 'o', 'w', '\n',
        'f', 'e', 'l', 'l', 'o', 'w', 's', '\n',
        'f', 'e', 'l', 'l', 'o', 'w', 's', 'h', 'i', 'p', '\n',
        'f', 'e', 'l', 'l', 'o', 'w', 's', 'h', 'i', 'p', 's', '\n',
        'f', 'e', 'l', 'l', 's', '\n',
        'f', 'e', 'l', 'o', 'n', '\n',
        'f', 'e', 'l', 'o', 'n', 'i', 'o', 'u', 's', '\n',
        'f', 'e', 'l', 'o', 'n', 's', '\n',
        'f', 'e', 'l', 'o', 'n', 'y', '\n',
        'f', 'e', 'l', 't', '\n',
        'f', 'e', 'l', 't', 'p', 'e', 'n', '\n',
        'f', 'e', 'm', 'a', 'l', 'e', '\n',
        'f', 'e', 'm', 'a', 'l', 'e', 'n', 'e', 's', 's', '\n',
        'f', 'e', 'm', 'a', 'l', 'e', 's', '\n',
        'f', 'e', 'm', 'i', 'n', 'i', 'n', 'e', '\n',
        'f', 'e', 'm', 'i', 'n', 'i', 'n', 'e', 'l', 'y', '\n',
        'f', 'e', 'm', 'i', 'n', 'i', 'n', 'i', 't', 'y', '\n',
        'f', 'e', 'm', 'i', 'n', 'i', 's', 'm', '\n',
        'f', 'e', 'm', 'i', 'n', 'i', 's', 't', '\n',
        'f', 'e', 'm', 'i', 'n', 'i', 's', 't', 's', '\n',
        'f', 'e', 'm', 'u', 'r', '\n',
        'f', 'e', 'm', 'u', 'r', 's', '\n',
        'f', 'e', 'n', '\n',
        'f', 'e', 'n', 'c', 'e', '\n',
        'f', 'e', 'n', 'c', 'e', 'd', '\n',
        'f', 'e', 'n', 'c', 'e', 'p', 'o', 's', 't', '\n',
        'f', 'e', 'n', 'c', 'e', 'r', '\n',
        'f', 'e', 'n', 'c', 'e', 'r', 's', '\n',
        'f', 'e', 'n', 'c', 'e', 's', '\n',
        'f', 'e', 'n', 'c', 'i', 'n', 'g', '\n',
        'f', 'e', 'n', 'c', 'i', 'n', 'g', 's', '\n',
        'f', 'e', 'n', 'd', '\n',
        'f', 'e', 'n', 'd', 'e', 'd', '\n',
        'f', 'e', 'n', 'd', 'e', 'r', '\n',
        'f', 'e', 'n', 'd', 'e', 'r', 's', '\n',
        'f', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'f', 'e', 'n', 'd', 's', '\n',
        'f', 'e', 'n', 'l', 'a', 'n', 'd', '\n',
        'f', 'e', 'n', 'n', 'e', 'l', '\n',
        'f', 'e', 'n', 's', '\n',
        'f', 'e', 'r', 'a', 'l', '\n',
        'f', 'e', 'r', 'm', 'e', 'n', 't', '\n',
        'f', 'e', 'r', 'm', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'f', 'e', 'r', 'm', 'e', 'n', 't', 'e', 'd', '\n',
        'f', 'e', 'r', 'm', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'f', 'e', 'r', 'm', 'e', 'n', 't', 's', '\n',
        'f', 'e', 'r', 'm', 'i', 'o', 'n', '\n',
        'f', 'e', 'r', 'm', 'i', 'o', 'n', 's', '\n',
        'f', 'e', 'r', 'n', '\n',
        'f', 'e', 'r', 'n', 's', '\n',
        'f', 'e', 'r', 'n', 'y', '\n',
        'f', 'e', 'r', 'o', 'c', 'i', 'o', 'u', 's', '\n',
        'f', 'e', 'r', 'o', 'c', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'f', 'e', 'r', 'o', 'c', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'f', 'e', 'r', 'o', 'c', 'i', 't', 'y', '\n',
        'f', 'e', 'r', 'r', 'e', 't', '\n',
        'f', 'e', 'r', 'r', 'e', 't', 'e', 'd', '\n',
        'f', 'e', 'r', 'r', 'e', 't', 'i', 'n', 'g', '\n',
        'f', 'e', 'r', 'r', 'e', 't', 's', '\n',
        'f', 'e', 'r', 'r', 'i', 'c', '\n',
        'f', 'e', 'r', 'r', 'i', 'e', 'd', '\n',
        'f', 'e', 'r', 'r', 'i', 'e', 's', '\n',
        'f', 'e', 'r', 'r', 'i', 't', 'e', '\n',
        'f', 'e', 'r', 'r', 'o', 'm', 'a', 'g', 'n', 'e', 't', 'i', 'c', '\n',
        'f', 'e', 'r', 'r', 'o', 'u', 's', '\n',
        'f', 'e', 'r', 'r', 'u', 'l', 'e', '\n',
        'f', 'e', 'r', 'r', 'y', '\n',
        'f', 'e', 'r', 'r', 'y', 'i', 'n', 'g', '\n',
        'f', 'e', 'r', 'r', 'y', 'm', 'a', 'n', '\n',
        'f', 'e', 'r', 't', 'i', 'l', 'e', '\n',
        'f', 'e', 'r', 't', 'i', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'f', 'e', 'r', 't', 'i', 'l', 'i', 's', 'e', '\n',
        'f', 'e', 'r', 't', 'i', 'l', 'i', 's', 'e', 'd', '\n',
        'f', 'e', 'r', 't', 'i', 'l', 'i', 's', 'e', 'r', '\n',
        'f', 'e', 'r', 't', 'i', 'l', 'i', 's', 'e', 'r', 's', '\n',
        'f', 'e', 'r', 't', 'i', 'l', 'i', 's', 'e', 's', '\n',
        'f', 'e', 'r', 't', 'i', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'f', 'e', 'r', 't', 'i', 'l', 'i', 't', 'y', '\n',
        'f', 'e', 'r', 'v', 'e', 'n', 't', '\n',
        'f', 'e', 'r', 'v', 'e', 'n', 't', 'l', 'y', '\n',
        'f', 'e', 'r', 'v', 'i', 'd', '\n',
        'f', 'e', 'r', 'v', 'i', 'd', 'l', 'y', '\n',
        'f', 'e', 'r', 'v', 'o', 'u', 'r', '\n',
        'f', 'e', 's', 'c', 'u', 'e', '\n',
        'f', 'e', 's', 't', '\n',
        'f', 'e', 's', 't', 'a', 'l', '\n',
        'f', 'e', 's', 't', 'e', 'r', '\n',
        'f', 'e', 's', 't', 'e', 'r', 'e', 'd', '\n',
        'f', 'e', 's', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'f', 'e', 's', 't', 'e', 'r', 's', '\n',
        'f', 'e', 's', 't', 'i', 'v', 'a', 'l', '\n',
        'f', 'e', 's', 't', 'i', 'v', 'a', 'l', 's', '\n',
        'f', 'e', 's', 't', 'i', 'v', 'e', '\n',
        'f', 'e', 's', 't', 'i', 'v', 'i', 't', 'i', 'e', 's', '\n',
        'f', 'e', 's', 't', 'i', 'v', 'i', 't', 'y', '\n',
        'f', 'e', 's', 't', 'o', 'o', 'n', '\n',
        'f', 'e', 's', 't', 'o', 'o', 'n', 'e', 'd', '\n',
        'f', 'e', 's', 't', 'o', 'o', 'n', 'i', 'n', 'g', '\n',
        'f', 'e', 's', 't', 'o', 'o', 'n', 's', '\n',
        'f', 'e', 't', 'a', 'l', '\n',
        'f', 'e', 't', 'c', 'h', '\n',
        'f', 'e', 't', 'c', 'h', 'e', 'd', '\n',
        'f', 'e', 't', 'c', 'h', 'e', 's', '\n',
        'f', 'e', 't', 'c', 'h', 'i', 'n', 'g', '\n',
        'f', 'e', 't', 'e', '\n',
        'f', 'e', 't', 'e', 'd', '\n',
        'f', 'e', 't', 'e', 's', '\n',
        'f', 'e', 't', 'i', 'd', '\n',
        'f', 'e', 't', 'i', 's', 'h', '\n',
        'f', 'e', 't', 'i', 's', 'h', 'e', 's', '\n',
        'f', 'e', 't', 'i', 's', 'h', 'i', 's', 'm', '\n',
        'f', 'e', 't', 'i', 's', 'h', 'i', 's', 't', '\n',
        'f', 'e', 't', 'i', 's', 'h', 'i', 's', 't', 'i', 'c', '\n',
        'f', 'e', 't', 'i', 's', 'h', 'i', 's', 't', 's', '\n',
        'f', 'e', 't', 'l', 'o', 'c', 'k', '\n',
        'f', 'e', 't', 'l', 'o', 'c', 'k', 's', '\n',
        'f', 'e', 't', 't', 'e', 'r', '\n',
        'f', 'e', 't', 't', 'e', 'r', 'e', 'd', '\n',
        'f', 'e', 't', 't', 'e', 'r', 's', '\n',
        'f', 'e', 't', 't', 'l', 'e', '\n',
        'f', 'e', 't', 'u', 's', '\n',
        'f', 'e', 'u', 'd', '\n',
        'f', 'e', 'u', 'd', 'a', 'l', '\n',
        'f', 'e', 'u', 'd', 'a', 'l', 'i', 's', 'm', '\n',
        'f', 'e', 'u', 'd', 'e', 'd', '\n',
        'f', 'e', 'u', 'd', 'i', 'n', 'g', '\n',
        'f', 'e', 'u', 'd', 'i', 's', 't', '\n',
        'f', 'e', 'u', 'd', 's', '\n',
        'f', 'e', 'v', 'e', 'r', '\n',
        'f', 'e', 'v', 'e', 'r', 'e', 'd', '\n',
        'f', 'e', 'v', 'e', 'r', 'i', 's', 'h', '\n',
        'f', 'e', 'v', 'e', 'r', 'i', 's', 'h', 'l', 'y', '\n',
        'f', 'e', 'v', 'e', 'r', 's', '\n',
        'f', 'e', 'w', '\n',
        'f', 'e', 'w', 'e', 'r', '\n',
        'f', 'e', 'w', 'e', 's', 't', '\n',
        'f', 'e', 'w', 'n', 'e', 's', 's', '\n',
        'f', 'e', 'z', '\n',
        'f', 'i', 'a', 'n', 'c', 'e', '\n',
        'f', 'i', 'a', 'n', 'c', 'e', 'e', '\n',
        'f', 'i', 'a', 's', 'c', 'o', '\n',
        'f', 'i', 'a', 't', '\n',
        'f', 'i', 'b', '\n',
        'f', 'i', 'b', 'b', 'e', 'd', '\n',
        'f', 'i', 'b', 'b', 'e', 'r', '\n',
        'f', 'i', 'b', 'b', 'e', 'r', 's', '\n',
        'f', 'i', 'b', 'b', 'i', 'n', 'g', '\n',
        'f', 'i', 'b', 'e', 'r', 's', '\n',
        'f', 'i', 'b', 'r', 'e', '\n',
        'f', 'i', 'b', 'r', 'e', 'b', 'o', 'a', 'r', 'd', '\n',
        'f', 'i', 'b', 'r', 'e', 'd', '\n',
        'f', 'i', 'b', 'r', 'e', 'g', 'l', 'a', 's', 's', '\n',
        'f', 'i', 'b', 'r', 'e', 's', '\n',
        'f', 'i', 'b', 'r', 'i', 'l', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'f', 'i', 'b', 'r', 'i', 'l', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'f', 'i', 'b', 'r', 'o', 'b', 'l', 'a', 's', 't', '\n',
        'f', 'i', 'b', 'r', 'o', 'b', 'l', 'a', 's', 't', 's', '\n',
        'f', 'i', 'b', 'r', 'o', 's', 'i', 's', '\n',
        'f', 'i', 'b', 'r', 'o', 'u', 's', '\n',
        'f', 'i', 'b', 's', '\n',
        'f', 'i', 'b', 'u', 'l', 'a', '\n',
        'f', 'i', 'c', 'h', 'e', '\n',
        'f', 'i', 'c', 'h', 'e', 's', '\n',
        'f', 'i', 'c', 'k', 'l', 'e', '\n',
        'f', 'i', 'c', 'k', 'l', 'e', 'n', 'e', 's', 's', '\n',
        'f', 'i', 'c', 't', 'i', 'o', 'n', '\n',
        'f', 'i', 'c', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'f', 'i', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'f', 'i', 'c', 't', 'i', 't', 'i', 'o', 'u', 's', '\n',
        'f', 'i', 'c', 't', 'i', 'v', 'e', '\n',
        'f', 'i', 'c', 'u', 's', '\n',
        'f', 'i', 'd', 'd', 'l', 'e', '\n',
        'f', 'i', 'd', 'd', 'l', 'e', 'd', '\n',
        'f', 'i', 'd', 'd', 'l', 'e', 'r', '\n',
        'f', 'i', 'd', 'd', 'l', 'e', 'r', 's', '\n',
        'f', 'i', 'd', 'd', 'l', 'e', 's', '\n',
        'f', 'i', 'd', 'd', 'l', 'e', 's', 't', 'i', 'c', 'k', 's', '\n',
        'f', 'i', 'd', 'd', 'l', 'i', 'n', 'g', '\n',
        'f', 'i', 'd', 'd', 'l', 'i', 'n', 'g', 's', '\n',
        'f', 'i', 'd', 'd', 'l', 'y', '\n',
        'f', 'i', 'd', 'e', 'l', 'i', 't', 'y', '\n',
        'f', 'i', 'd', 'g', 'e', 't', '\n',
        'f', 'i', 'd', 'g', 'e', 't', 'e', 'd', '\n',
        'f', 'i', 'd', 'g', 'e', 't', 'i', 'n', 'g', '\n',
        'f', 'i', 'd', 'g', 'e', 't', 's', '\n',
        'f', 'i', 'd', 'g', 'e', 't', 'y', '\n',
        'f', 'i', 'd', 'u', 'c', 'i', 'a', 'r', 'y', '\n',
        'f', 'i', 'e', 'f', '\n',
        'f', 'i', 'e', 'f', 'd', 'o', 'm', '\n',
        'f', 'i', 'e', 'f', 'd', 'o', 'm', 's', '\n',
        'f', 'i', 'e', 'f', 's', '\n',
        'f', 'i', 'e', 'l', 'd', '\n',
        'f', 'i', 'e', 'l', 'd', 'e', 'd', '\n',
        'f', 'i', 'e', 'l', 'd', 'e', 'r', '\n',
        'f', 'i', 'e', 'l', 'd', 'e', 'r', 's', '\n',
        'f', 'i', 'e', 'l', 'd', 'i', 'n', 'g', '\n',
        'f', 'i', 'e', 'l', 'd', 's', '\n',
        'f', 'i', 'e', 'l', 'd', 'w', 'o', 'r', 'k', '\n',
        'f', 'i', 'e', 'l', 'd', 'w', 'o', 'r', 'k', 'e', 'r', '\n',
        'f', 'i', 'e', 'l', 'd', 'w', 'o', 'r', 'k', 'e', 'r', 's', '\n',
        'f', 'i', 'e', 'n', 'd', '\n',
        'f', 'i', 'e', 'n', 'd', 'i', 's', 'h', '\n',
        'f', 'i', 'e', 'n', 'd', 'i', 's', 'h', 'l', 'y', '\n',
        'f', 'i', 'e', 'n', 'd', 's', '\n',
        'f', 'i', 'e', 'r', 'c', 'e', '\n',
        'f', 'i', 'e', 'r', 'c', 'e', 'l', 'y', '\n',
        'f', 'i', 'e', 'r', 'c', 'e', 'n', 'e', 's', 's', '\n',
        'f', 'i', 'e', 'r', 'c', 'e', 'r', '\n',
        'f', 'i', 'e', 'r', 'c', 'e', 's', 't', '\n',
        'f', 'i', 'e', 'r', 'i', 'e', 'r', '\n',
        'f', 'i', 'e', 'r', 'i', 'e', 's', 't', '\n',
        'f', 'i', 'e', 'r', 'i', 'l', 'y', '\n',
        'f', 'i', 'e', 'r', 'y', '\n',
        'f', 'i', 'e', 's', 't', 'a', '\n',
        'f', 'i', 'e', 's', 't', 'a', 's', '\n',
        'f', 'i', 'f', 'e', '\n',
        'f', 'i', 'f', 'e', 's', '\n',
        'f', 'i', 'f', 't', 'e', 'e', 'n', '\n',
        'f', 'i', 'f', 't', 'e', 'e', 'n', 't', 'h', '\n',
        'f', 'i', 'f', 't', 'h', '\n',
        'f', 'i', 'f', 't', 'h', 'l', 'y', '\n',
        'f', 'i', 'f', 't', 'h', 's', '\n',
        'f', 'i', 'f', 't', 'i', 'e', 's', '\n',
        'f', 'i', 'f', 't', 'i', 'e', 't', 'h', '\n',
        'f', 'i', 'f', 't', 'y', '\n',
        'f', 'i', 'g', '\n',
        'f', 'i', 'g', 'h', 't', '\n',
        'f', 'i', 'g', 'h', 't', 'b', 'a', 'c', 'k', '\n',
        'f', 'i', 'g', 'h', 't', 'e', 'r', '\n',
        'f', 'i', 'g', 'h', 't', 'e', 'r', 's', '\n',
        'f', 'i', 'g', 'h', 't', 'i', 'n', 'g', '\n',
        'f', 'i', 'g', 'h', 't', 's', '\n',
        'f', 'i', 'g', 'l', 'e', 'a', 'f', '\n',
        'f', 'i', 'g', 'm', 'e', 'n', 't', '\n',
        'f', 'i', 'g', 'm', 'e', 'n', 't', 's', '\n',
        'f', 'i', 'g', 's', '\n',
        'f', 'i', 'g', 't', 'r', 'e', 'e', '\n',
        'f', 'i', 'g', 'u', 'r', 'a', 'l', '\n',
        'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'v', 'e', '\n',
        'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'f', 'i', 'g', 'u', 'r', 'e', '\n',
        'f', 'i', 'g', 'u', 'r', 'e', 'd', '\n',
        'f', 'i', 'g', 'u', 'r', 'e', 'h', 'e', 'a', 'd', '\n',
        'f', 'i', 'g', 'u', 'r', 'e', 'h', 'e', 'a', 'd', 's', '\n',
        'f', 'i', 'g', 'u', 'r', 'e', 'r', '\n',
        'f', 'i', 'g', 'u', 'r', 'e', 's', '\n',
        'f', 'i', 'g', 'u', 'r', 'i', 'n', 'e', '\n',
        'f', 'i', 'g', 'u', 'r', 'i', 'n', 'e', 's', '\n',
        'f', 'i', 'g', 'u', 'r', 'i', 'n', 'g', '\n',
        'f', 'i', 'j', 'i', '\n',
        'f', 'i', 'j', 'i', 'a', 'n', 's', '\n',
        'f', 'i', 'l', 'a', 'm', 'e', 'n', 't', '\n',
        'f', 'i', 'l', 'a', 'm', 'e', 'n', 't', 'a', 'r', 'y', '\n',
        'f', 'i', 'l', 'a', 'm', 'e', 'n', 't', 'o', 'u', 's', '\n',
        'f', 'i', 'l', 'a', 'm', 'e', 'n', 't', 's', '\n',
        'f', 'i', 'l', 'c', 'h', '\n',
        'f', 'i', 'l', 'c', 'h', 'e', 'd', '\n',
        'f', 'i', 'l', 'e', '\n',
        'f', 'i', 'l', 'e', 'd', '\n',
        'f', 'i', 'l', 'e', 'r', '\n',
        'f', 'i', 'l', 'e', 'r', 's', '\n',
        'f', 'i', 'l', 'e', 's', '\n',
        'f', 'i', 'l', 'e', 't', '\n',
        'f', 'i', 'l', 'i', 'a', 'l', '\n',
        'f', 'i', 'l', 'i', 'b', 'u', 's', 't', 'e', 'r', '\n',
        'f', 'i', 'l', 'i', 'g', 'r', 'e', 'e', '\n',
        'f', 'i', 'l', 'i', 'n', 'g', '\n',
        'f', 'i', 'l', 'i', 'n', 'g', 's', '\n',
        'f', 'i', 'l', 'l', '\n',
        'f', 'i', 'l', 'l', 'e', 'd', '\n',
        'f', 'i', 'l', 'l', 'e', 'r', '\n',
        'f', 'i', 'l', 'l', 'e', 'r', 's', '\n',
        'f', 'i', 'l', 'l', 'e', 't', '\n',
        'f', 'i', 'l', 'l', 'e', 't', 's', '\n',
        'f', 'i', 'l', 'l', 'i', 'e', 's', '\n',
        'f', 'i', 'l', 'l', 'i', 'n', 'g', '\n',
        'f', 'i', 'l', 'l', 'i', 'n', 'g', 's', '\n',
        'f', 'i', 'l', 'l', 'i', 'p', '\n',
        'f', 'i', 'l', 'l', 's', '\n',
        'f', 'i', 'l', 'l', 'y', '\n',
        'f', 'i', 'l', 'm', '\n',
        'f', 'i', 'l', 'm', 'e', 'd', '\n',
        'f', 'i', 'l', 'm', 'i', 'c', '\n',
        'f', 'i', 'l', 'm', 'i', 'n', 'g', '\n',
        'f', 'i', 'l', 'm', 'm', 'a', 'k', 'e', 'r', 's', '\n',
        'f', 'i', 'l', 'm', 's', '\n',
        'f', 'i', 'l', 'm', 's', 'e', 't', '\n',
        'f', 'i', 'l', 'm', 'y', '\n',
        'f', 'i', 'l', 't', 'e', 'r', '\n',
        'f', 'i', 'l', 't', 'e', 'r', 'e', 'd', '\n',
        'f', 'i', 'l', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'f', 'i', 'l', 't', 'e', 'r', 's', '\n',
        'f', 'i', 'l', 't', 'h', '\n',
        'f', 'i', 'l', 't', 'h', 'i', 'e', 'r', '\n',
        'f', 'i', 'l', 't', 'h', 'i', 'e', 's', 't', '\n',
        'f', 'i', 'l', 't', 'h', 'i', 'l', 'y', '\n',
        'f', 'i', 'l', 't', 'h', 'y', '\n',
        'f', 'i', 'l', 't', 'r', 'a', 't', 'e', '\n',
        'f', 'i', 'l', 't', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'f', 'i', 'n', '\n',
        'f', 'i', 'n', 'a', 'l', '\n',
        'f', 'i', 'n', 'a', 'l', 'e', '\n',
        'f', 'i', 'n', 'a', 'l', 'e', 's', '\n',
        'f', 'i', 'n', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'f', 'i', 'n', 'a', 'l', 'i', 's', 'e', '\n',
        'f', 'i', 'n', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'f', 'i', 'n', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'f', 'i', 'n', 'a', 'l', 'i', 's', 't', '\n',
        'f', 'i', 'n', 'a', 'l', 'i', 's', 't', 's', '\n',
        'f', 'i', 'n', 'a', 'l', 'i', 't', 'y', '\n',
        'f', 'i', 'n', 'a', 'l', 'l', 'y', '\n',
        'f', 'i', 'n', 'a', 'l', 's', '\n',
        'f', 'i', 'n', 'a', 'n', 'c', 'e', '\n',
        'f', 'i', 'n', 'a', 'n', 'c', 'e', 'd', '\n',
        'f', 'i', 'n', 'a', 'n', 'c', 'e', 's', '\n',
        'f', 'i', 'n', 'a', 'n', 'c', 'i', 'a', 'l', '\n',
        'f', 'i', 'n', 'a', 'n', 'c', 'i', 'a', 'l', 'l', 'y', '\n',
        'f', 'i', 'n', 'a', 'n', 'c', 'i', 'e', 'r', '\n',
        'f', 'i', 'n', 'a', 'n', 'c', 'i', 'e', 'r', 's', '\n',
        'f', 'i', 'n', 'a', 'n', 'c', 'i', 'n', 'g', '\n',
        'f', 'i', 'n', 'c', 'h', '\n',
        'f', 'i', 'n', 'c', 'h', 'e', 's', '\n',
        'f', 'i', 'n', 'd', '\n',
        'f', 'i', 'n', 'd', 'a', 'b', 'l', 'e', '\n',
        'f', 'i', 'n', 'd', 'e', 'r', '\n',
        'f', 'i', 'n', 'd', 'e', 'r', 's', '\n',
        'f', 'i', 'n', 'd', 'i', 'n', 'g', '\n',
        'f', 'i', 'n', 'd', 'i', 'n', 'g', 's', '\n',
        'f', 'i', 'n', 'd', 's', '\n',
        'f', 'i', 'n', 'e', '\n',
        'f', 'i', 'n', 'e', 'd', '\n',
        'f', 'i', 'n', 'e', 'l', 'y', '\n',
        'f', 'i', 'n', 'e', 'n', 'e', 's', 's', '\n',
        'f', 'i', 'n', 'e', 'r', '\n',
        'f', 'i', 'n', 'e', 'r', 'y', '\n',
        'f', 'i', 'n', 'e', 's', '\n',
        'f', 'i', 'n', 'e', 's', 's', 'e', '\n',
        'f', 'i', 'n', 'e', 's', 't', '\n',
        'f', 'i', 'n', 'e', 't', 'u', 'n', 'e', '\n',
        'f', 'i', 'n', 'e', 't', 'u', 'n', 'e', 'd', '\n',
        'f', 'i', 'n', 'e', 't', 'u', 'n', 'e', 's', '\n',
        'f', 'i', 'n', 'e', 't', 'u', 'n', 'i', 'n', 'g', '\n',
        'f', 'i', 'n', 'g', 'e', 'r', '\n',
        'f', 'i', 'n', 'g', 'e', 'r', 'b', 'o', 'a', 'r', 'd', '\n',
        'f', 'i', 'n', 'g', 'e', 'r', 'e', 'd', '\n',
        'f', 'i', 'n', 'g', 'e', 'r', 'i', 'n', 'g', '\n',
        'f', 'i', 'n', 'g', 'e', 'r', 'i', 'n', 'g', 's', '\n',
        'f', 'i', 'n', 'g', 'e', 'r', 'l', 'e', 's', 's', '\n',
        'f', 'i', 'n', 'g', 'e', 'r', 'm', 'a', 'r', 'k', 's', '\n',
        'f', 'i', 'n', 'g', 'e', 'r', 'n', 'a', 'i', 'l', '\n',
        'f', 'i', 'n', 'g', 'e', 'r', 'n', 'a', 'i', 'l', 's', '\n',
        'f', 'i', 'n', 'g', 'e', 'r', 'p', 'r', 'i', 'n', 't', '\n',
        'f', 'i', 'n', 'g', 'e', 'r', 'p', 'r', 'i', 'n', 't', 'e', 'd', '\n',
        'f', 'i', 'n', 'g', 'e', 'r', 'p', 'r', 'i', 'n', 't', 'i', 'n', 'g', '\n',
        'f', 'i', 'n', 'g', 'e', 'r', 'p', 'r', 'i', 'n', 't', 's', '\n',
        'f', 'i', 'n', 'g', 'e', 'r', 's', '\n',
        'f', 'i', 'n', 'g', 'e', 'r', 't', 'i', 'p', '\n',
        'f', 'i', 'n', 'g', 'e', 'r', 't', 'i', 'p', 's', '\n',
        'f', 'i', 'n', 'i', 'a', 'l', '\n',
        'f', 'i', 'n', 'i', 'c', 'k', 'y', '\n',
        'f', 'i', 'n', 'i', 'n', 'g', '\n',
        'f', 'i', 'n', 'i', 's', '\n',
        'f', 'i', 'n', 'i', 's', 'h', '\n',
        'f', 'i', 'n', 'i', 's', 'h', 'e', 'd', '\n',
        'f', 'i', 'n', 'i', 's', 'h', 'e', 'r', '\n',
        'f', 'i', 'n', 'i', 's', 'h', 'e', 'r', 's', '\n',
        'f', 'i', 'n', 'i', 's', 'h', 'e', 's', '\n',
        'f', 'i', 'n', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'f', 'i', 'n', 'i', 't', 'e', '\n',
        'f', 'i', 'n', 'i', 't', 'e', 'l', 'y', '\n',
        'f', 'i', 'n', 'i', 't', 'e', 'n', 'e', 's', 's', '\n',
        'f', 'i', 'n', 'l', 'a', 'n', 'd', '\n',
        'f', 'i', 'n', 'n', '\n',
        'f', 'i', 'n', 'n', 'e', 'd', '\n',
        'f', 'i', 'n', 'n', 'i', 's', 'h', '\n',
        'f', 'i', 'n', 's', '\n',
        'f', 'i', 'o', 'r', 'd', '\n',
        'f', 'i', 'o', 'r', 'd', 's', '\n',
        'f', 'i', 'r', '\n',
        'f', 'i', 'r', 'e', '\n',
        'f', 'i', 'r', 'e', 'a', 'r', 'm', '\n',
        'f', 'i', 'r', 'e', 'a', 'r', 'm', 's', '\n',
        'f', 'i', 'r', 'e', 'b', 'a', 'l', 'l', '\n',
        'f', 'i', 'r', 'e', 'b', 'a', 'l', 'l', 's', '\n',
        'f', 'i', 'r', 'e', 'b', 'o', 'm', 'b', '\n',
        'f', 'i', 'r', 'e', 'b', 'o', 'm', 'b', 'e', 'd', '\n',
        'f', 'i', 'r', 'e', 'b', 'o', 'm', 'b', 'i', 'n', 'g', '\n',
        'f', 'i', 'r', 'e', 'b', 'o', 'm', 'b', 's', '\n',
        'f', 'i', 'r', 'e', 'b', 'o', 'x', '\n',
        'f', 'i', 'r', 'e', 'b', 'r', 'a', 'n', 'd', '\n',
        'f', 'i', 'r', 'e', 'c', 'o', 'n', 't', 'r', 'o', 'l', '\n',
        'f', 'i', 'r', 'e', 'd', '\n',
        'f', 'i', 'r', 'e', 'f', 'i', 'g', 'h', 't', '\n',
        'f', 'i', 'r', 'e', 'f', 'i', 'g', 'h', 't', 'e', 'r', '\n',
        'f', 'i', 'r', 'e', 'f', 'i', 'g', 'h', 't', 'e', 'r', 's', '\n',
        'f', 'i', 'r', 'e', 'f', 'i', 'g', 'h', 't', 'i', 'n', 'g', '\n',
        'f', 'i', 'r', 'e', 'f', 'l', 'i', 'e', 's', '\n',
        'f', 'i', 'r', 'e', 'f', 'l', 'y', '\n',
        'f', 'i', 'r', 'e', 'g', 'u', 'a', 'r', 'd', '\n',
        'f', 'i', 'r', 'e', 'l', 'i', 'g', 'h', 't', '\n',
        'f', 'i', 'r', 'e', 'l', 'i', 'g', 'h', 't', 'e', 'r', 's', '\n',
        'f', 'i', 'r', 'e', 'm', 'a', 'n', '\n',
        'f', 'i', 'r', 'e', 'm', 'e', 'n', '\n',
        'f', 'i', 'r', 'e', 'p', 'l', 'a', 'c', 'e', '\n',
        'f', 'i', 'r', 'e', 'p', 'l', 'a', 'c', 'e', 's', '\n',
        'f', 'i', 'r', 'e', 'p', 'o', 'w', 'e', 'r', '\n',
        'f', 'i', 'r', 'e', 'p', 'r', 'o', 'o', 'f', '\n',
        'f', 'i', 'r', 'e', 'p', 'r', 'o', 'o', 'f', 'e', 'd', '\n',
        'f', 'i', 'r', 'e', 'r', '\n',
        'f', 'i', 'r', 'e', 's', '\n',
        'f', 'i', 'r', 'e', 's', 'i', 'd', 'e', '\n',
        'f', 'i', 'r', 'e', 's', 'i', 'd', 'e', 's', '\n',
        'f', 'i', 'r', 'e', 'w', 'o', 'o', 'd', '\n',
        'f', 'i', 'r', 'e', 'w', 'o', 'r', 'k', '\n',
        'f', 'i', 'r', 'e', 'w', 'o', 'r', 'k', 's', '\n',
        'f', 'i', 'r', 'i', 'n', 'g', '\n',
        'f', 'i', 'r', 'i', 'n', 'g', 's', '\n',
        'f', 'i', 'r', 'k', 'i', 'n', '\n',
        'f', 'i', 'r', 'm', '\n',
        'f', 'i', 'r', 'm', 'a', 'm', 'e', 'n', 't', '\n',
        'f', 'i', 'r', 'm', 'e', 'd', '\n',
        'f', 'i', 'r', 'm', 'e', 'r', '\n',
        'f', 'i', 'r', 'm', 'e', 's', 't', '\n',
        'f', 'i', 'r', 'm', 'i', 'n', 'g', '\n',
        'f', 'i', 'r', 'm', 'l', 'y', '\n',
        'f', 'i', 'r', 'm', 'n', 'e', 's', 's', '\n',
        'f', 'i', 'r', 'm', 's', '\n',
        'f', 'i', 'r', 'm', 'w', 'a', 'r', 'e', '\n',
        'f', 'i', 'r', 's', '\n',
        'f', 'i', 'r', 's', 't', '\n',
        'f', 'i', 'r', 's', 't', 'a', 'i', 'd', '\n',
        'f', 'i', 'r', 's', 't', 'b', 'o', 'r', 'n', '\n',
        'f', 'i', 'r', 's', 't', 'b', 'o', 'r', 'n', 's', '\n',
        'f', 'i', 'r', 's', 't', 'h', 'a', 'n', 'd', '\n',
        'f', 'i', 'r', 's', 't', 'l', 'y', '\n',
        'f', 'i', 'r', 's', 't', 's', '\n',
        'f', 'i', 'r', 't', 'h', '\n',
        'f', 'i', 's', 'c', 'a', 'l', '\n',
        'f', 'i', 's', 'c', 'a', 'l', 'l', 'y', '\n',
        'f', 'i', 's', 'h', '\n',
        'f', 'i', 's', 'h', 'e', 'd', '\n',
        'f', 'i', 's', 'h', 'e', 'r', '\n',
        'f', 'i', 's', 'h', 'e', 'r', 'i', 'e', 's', '\n',
        'f', 'i', 's', 'h', 'e', 'r', 'm', 'a', 'n', '\n',
        'f', 'i', 's', 'h', 'e', 'r', 'm', 'e', 'n', '\n',
        'f', 'i', 's', 'h', 'e', 'r', 's', '\n',
        'f', 'i', 's', 'h', 'e', 'r', 'y', '\n',
        'f', 'i', 's', 'h', 'e', 's', '\n',
        'f', 'i', 's', 'h', 'h', 'o', 'o', 'k', '\n',
        'f', 'i', 's', 'h', 'h', 'o', 'o', 'k', 's', '\n',
        'f', 'i', 's', 'h', 'i', 'e', 'r', '\n',
        'f', 'i', 's', 'h', 'i', 'e', 's', 't', '\n',
        'f', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'f', 'i', 's', 'h', 'i', 'n', 'g', 's', '\n',
        'f', 'i', 's', 'h', 'l', 'i', 'k', 'e', '\n',
        'f', 'i', 's', 'h', 'm', 'o', 'n', 'g', 'e', 'r', '\n',
        'f', 'i', 's', 'h', 'm', 'o', 'n', 'g', 'e', 'r', 's', '\n',
        'f', 'i', 's', 'h', 'n', 'e', 't', '\n',
        'f', 'i', 's', 'h', 'w', 'i', 'f', 'e', '\n',
        'f', 'i', 's', 'h', 'y', '\n',
        'f', 'i', 's', 's', 'i', 'l', 'e', '\n',
        'f', 'i', 's', 's', 'i', 'o', 'n', '\n',
        'f', 'i', 's', 's', 'i', 'o', 'n', 's', '\n',
        'f', 'i', 's', 's', 'u', 'r', 'e', '\n',
        'f', 'i', 's', 's', 'u', 'r', 'e', 'd', '\n',
        'f', 'i', 's', 's', 'u', 'r', 'e', 's', '\n',
        'f', 'i', 's', 't', '\n',
        'f', 'i', 's', 't', 'e', 'd', '\n',
        'f', 'i', 's', 't', 'f', 'u', 'l', '\n',
        'f', 'i', 's', 't', 'i', 'c', 'u', 'f', 'f', 's', '\n',
        'f', 'i', 's', 't', 's', '\n',
        'f', 'i', 's', 't', 'u', 'l', 'a', '\n',
        'f', 'i', 't', '\n',
        'f', 'i', 't', 'f', 'u', 'l', '\n',
        'f', 'i', 't', 'f', 'u', 'l', 'l', 'y', '\n',
        'f', 'i', 't', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'f', 'i', 't', 'l', 'y', '\n',
        'f', 'i', 't', 'm', 'e', 'n', 't', '\n',
        'f', 'i', 't', 'm', 'e', 'n', 't', 's', '\n',
        'f', 'i', 't', 'n', 'e', 's', 's', '\n',
        'f', 'i', 't', 's', '\n',
        'f', 'i', 't', 't', 'e', 'd', '\n',
        'f', 'i', 't', 't', 'e', 'r', '\n',
        'f', 'i', 't', 't', 'e', 'r', 's', '\n',
        'f', 'i', 't', 't', 'e', 's', 't', '\n',
        'f', 'i', 't', 't', 'i', 'n', 'g', '\n',
        'f', 'i', 't', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'f', 'i', 't', 't', 'i', 'n', 'g', 's', '\n',
        'f', 'i', 'v', 'e', '\n',
        'f', 'i', 'v', 'e', 'f', 'o', 'l', 'd', '\n',
        'f', 'i', 'v', 'e', 'r', '\n',
        'f', 'i', 'v', 'e', 'r', 's', '\n',
        'f', 'i', 'v', 'e', 's', '\n',
        'f', 'i', 'x', '\n',
        'f', 'i', 'x', 'a', 'b', 'l', 'e', '\n',
        'f', 'i', 'x', 'a', 't', 'e', '\n',
        'f', 'i', 'x', 'a', 't', 'e', 'd', '\n',
        'f', 'i', 'x', 'a', 't', 'e', 's', '\n',
        'f', 'i', 'x', 'a', 't', 'i', 'o', 'n', '\n',
        'f', 'i', 'x', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'f', 'i', 'x', 'a', 't', 'i', 'v', 'e', '\n',
        'f', 'i', 'x', 'e', 'd', '\n',
        'f', 'i', 'x', 'e', 'd', 'l', 'y', '\n',
        'f', 'i', 'x', 'e', 'r', '\n',
        'f', 'i', 'x', 'e', 'r', 's', '\n',
        'f', 'i', 'x', 'e', 's', '\n',
        'f', 'i', 'x', 'i', 'n', 'g', '\n',
        'f', 'i', 'x', 'i', 'n', 'g', 's', '\n',
        'f', 'i', 'x', 't', 'u', 'r', 'e', '\n',
        'f', 'i', 'x', 't', 'u', 'r', 'e', 's', '\n',
        'f', 'i', 'z', 'z', '\n',
        'f', 'i', 'z', 'z', 'e', 'd', '\n',
        'f', 'i', 'z', 'z', 'e', 's', '\n',
        'f', 'i', 'z', 'z', 'i', 'e', 'r', '\n',
        'f', 'i', 'z', 'z', 'i', 'e', 's', 't', '\n',
        'f', 'i', 'z', 'z', 'i', 'n', 'g', '\n',
        'f', 'i', 'z', 'z', 'l', 'e', '\n',
        'f', 'i', 'z', 'z', 'l', 'e', 'd', '\n',
        'f', 'i', 'z', 'z', 'l', 'e', 's', '\n',
        'f', 'i', 'z', 'z', 'y', '\n',
        'f', 'j', 'o', 'r', 'd', '\n',
        'f', 'j', 'o', 'r', 'd', 's', '\n',
        'f', 'l', 'a', 'b', '\n',
        'f', 'l', 'a', 'b', 'b', 'e', 'r', 'g', 'a', 's', 't', 'e', 'd', '\n',
        'f', 'l', 'a', 'b', 'b', 'i', 'e', 'r', '\n',
        'f', 'l', 'a', 'b', 'b', 'i', 'e', 's', 't', '\n',
        'f', 'l', 'a', 'b', 'b', 'y', '\n',
        'f', 'l', 'a', 'b', 's', '\n',
        'f', 'l', 'a', 'c', 'c', 'i', 'd', '\n',
        'f', 'l', 'a', 'c', 'c', 'i', 'd', 'i', 't', 'y', '\n',
        'f', 'l', 'a', 'c', 'k', '\n',
        'f', 'l', 'a', 'g', '\n',
        'f', 'l', 'a', 'g', 'e', 'l', 'l', 'a', '\n',
        'f', 'l', 'a', 'g', 'e', 'l', 'l', 'a', 't', 'e', '\n',
        'f', 'l', 'a', 'g', 'e', 'l', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'f', 'l', 'a', 'g', 'g', 'e', 'd', '\n',
        'f', 'l', 'a', 'g', 'g', 'i', 'n', 'g', '\n',
        'f', 'l', 'a', 'g', 'o', 'n', '\n',
        'f', 'l', 'a', 'g', 'o', 'n', 's', '\n',
        'f', 'l', 'a', 'g', 'p', 'o', 'l', 'e', '\n',
        'f', 'l', 'a', 'g', 'r', 'a', 'n', 't', '\n',
        'f', 'l', 'a', 'g', 'r', 'a', 'n', 't', 'l', 'y', '\n',
        'f', 'l', 'a', 'g', 's', '\n',
        'f', 'l', 'a', 'g', 's', 'h', 'i', 'p', '\n',
        'f', 'l', 'a', 'g', 's', 'h', 'i', 'p', 's', '\n',
        'f', 'l', 'a', 'i', 'r', '\n',
        'f', 'l', 'a', 'k', '\n',
        'f', 'l', 'a', 'k', 'e', '\n',
        'f', 'l', 'a', 'k', 'e', 'd', '\n',
        'f', 'l', 'a', 'k', 'e', 's', '\n',
        'f', 'l', 'a', 'k', 'i', 'e', 's', 't', '\n',
        'f', 'l', 'a', 'k', 'i', 'n', 'g', '\n',
        'f', 'l', 'a', 'k', 'y', '\n',
        'f', 'l', 'a', 'm', 'b', 'o', 'y', 'a', 'n', 'c', 'e', '\n',
        'f', 'l', 'a', 'm', 'b', 'o', 'y', 'a', 'n', 't', '\n',
        'f', 'l', 'a', 'm', 'b', 'o', 'y', 'a', 'n', 't', 'l', 'y', '\n',
        'f', 'l', 'a', 'm', 'e', '\n',
        'f', 'l', 'a', 'm', 'e', 'd', '\n',
        'f', 'l', 'a', 'm', 'e', 'n', 'c', 'o', '\n',
        'f', 'l', 'a', 'm', 'e', 'p', 'r', 'o', 'o', 'f', '\n',
        'f', 'l', 'a', 'm', 'e', 's', '\n',
        'f', 'l', 'a', 'm', 'i', 'n', 'g', '\n',
        'f', 'l', 'a', 'm', 'i', 'n', 'g', 'o', '\n',
        'f', 'l', 'a', 'm', 'm', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'f', 'l', 'a', 'm', 'm', 'a', 'b', 'l', 'e', '\n',
        'f', 'l', 'a', 'n', '\n',
        'f', 'l', 'a', 'n', 'g', 'e', '\n',
        'f', 'l', 'a', 'n', 'g', 'e', 'd', '\n',
        'f', 'l', 'a', 'n', 'g', 'e', 's', '\n',
        'f', 'l', 'a', 'n', 'k', '\n',
        'f', 'l', 'a', 'n', 'k', 'e', 'd', '\n',
        'f', 'l', 'a', 'n', 'k', 'e', 'r', '\n',
        'f', 'l', 'a', 'n', 'k', 'i', 'n', 'g', '\n',
        'f', 'l', 'a', 'n', 'k', 's', '\n',
        'f', 'l', 'a', 'n', 'n', 'e', 'l', '\n',
        'f', 'l', 'a', 'n', 'n', 'e', 'l', 'e', 't', 't', 'e', '\n',
        'f', 'l', 'a', 'n', 'n', 'e', 'l', 's', '\n',
        'f', 'l', 'a', 'n', 's', '\n',
        'f', 'l', 'a', 'p', '\n',
        'f', 'l', 'a', 'p', 'j', 'a', 'c', 'k', '\n',
        'f', 'l', 'a', 'p', 'p', 'e', 'd', '\n',
        'f', 'l', 'a', 'p', 'p', 'e', 'r', '\n',
        'f', 'l', 'a', 'p', 'p', 'e', 'r', 's', '\n',
        'f', 'l', 'a', 'p', 'p', 'i', 'n', 'g', '\n',
        'f', 'l', 'a', 'p', 's', '\n',
        'f', 'l', 'a', 'r', 'e', '\n',
        'f', 'l', 'a', 'r', 'e', 'd', '\n',
        'f', 'l', 'a', 'r', 'e', 's', '\n',
        'f', 'l', 'a', 'r', 'e', 'u', 'p', '\n',
        'f', 'l', 'a', 'r', 'e', 'u', 'p', 's', '\n',
        'f', 'l', 'a', 'r', 'i', 'n', 'g', '\n',
        'f', 'l', 'a', 's', 'h', '\n',
        'f', 'l', 'a', 's', 'h', 'b', 'a', 'c', 'k', '\n',
        'f', 'l', 'a', 's', 'h', 'b', 'a', 'c', 'k', 's', '\n',
        'f', 'l', 'a', 's', 'h', 'b', 'u', 'l', 'b', '\n',
        'f', 'l', 'a', 's', 'h', 'e', 'd', '\n',
        'f', 'l', 'a', 's', 'h', 'e', 'r', '\n',
        'f', 'l', 'a', 's', 'h', 'e', 's', '\n',
        'f', 'l', 'a', 's', 'h', 'i', 'e', 'r', '\n',
        'f', 'l', 'a', 's', 'h', 'i', 'e', 's', 't', '\n',
        'f', 'l', 'a', 's', 'h', 'i', 'l', 'y', '\n',
        'f', 'l', 'a', 's', 'h', 'i', 'n', 'g', '\n',
        'f', 'l', 'a', 's', 'h', 'l', 'i', 'g', 'h', 't', '\n',
        'f', 'l', 'a', 's', 'h', 'l', 'i', 'g', 'h', 't', 's', '\n',
        'f', 'l', 'a', 's', 'h', 'p', 'o', 'i', 'n', 't', '\n',
        'f', 'l', 'a', 's', 'h', 'p', 'o', 'i', 'n', 't', 's', '\n',
        'f', 'l', 'a', 's', 'h', 'y', '\n',
        'f', 'l', 'a', 's', 'k', '\n',
        'f', 'l', 'a', 's', 'k', 's', '\n',
        'f', 'l', 'a', 't', '\n',
        'f', 'l', 'a', 't', 'f', 'i', 's', 'h', '\n',
        'f', 'l', 'a', 't', 'l', 'y', '\n',
        'f', 'l', 'a', 't', 'm', 'a', 't', 'e', '\n',
        'f', 'l', 'a', 't', 'm', 'a', 't', 'e', 's', '\n',
        'f', 'l', 'a', 't', 'n', 'e', 's', 's', '\n',
        'f', 'l', 'a', 't', 's', '\n',
        'f', 'l', 'a', 't', 't', 'e', 'n', '\n',
        'f', 'l', 'a', 't', 't', 'e', 'n', 'e', 'd', '\n',
        'f', 'l', 'a', 't', 't', 'e', 'n', 'i', 'n', 'g', '\n',
        'f', 'l', 'a', 't', 't', 'e', 'n', 's', '\n',
        'f', 'l', 'a', 't', 't', 'e', 'r', '\n',
        'f', 'l', 'a', 't', 't', 'e', 'r', 'e', 'd', '\n',
        'f', 'l', 'a', 't', 't', 'e', 'r', 'e', 'r', '\n',
        'f', 'l', 'a', 't', 't', 'e', 'r', 'e', 'r', 's', '\n',
        'f', 'l', 'a', 't', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'f', 'l', 'a', 't', 't', 'e', 'r', 'i', 'n', 'g', 'l', 'y', '\n',
        'f', 'l', 'a', 't', 't', 'e', 'r', 's', '\n',
        'f', 'l', 'a', 't', 't', 'e', 'r', 'y', '\n',
        'f', 'l', 'a', 't', 't', 'e', 's', 't', '\n',
        'f', 'l', 'a', 't', 't', 'i', 's', 'h', '\n',
        'f', 'l', 'a', 't', 'u', 'l', 'e', 'n', 'c', 'e', '\n',
        'f', 'l', 'a', 't', 'u', 'l', 'e', 'n', 't', '\n',
        'f', 'l', 'a', 't', 'u', 's', '\n',
        'f', 'l', 'a', 't', 'w', 'o', 'r', 'm', 's', '\n',
        'f', 'l', 'a', 'u', 'n', 't', '\n',
        'f', 'l', 'a', 'u', 'n', 't', 'e', 'd', '\n',
        'f', 'l', 'a', 'u', 'n', 't', 'i', 'n', 'g', '\n',
        'f', 'l', 'a', 'u', 'n', 't', 's', '\n',
        'f', 'l', 'a', 'u', 't', 'i', 's', 't', '\n',
        'f', 'l', 'a', 'v', 'o', 'u', 'r', '\n',
        'f', 'l', 'a', 'v', 'o', 'u', 'r', 'e', 'd', '\n',
        'f', 'l', 'a', 'v', 'o', 'u', 'r', 'i', 'n', 'g', '\n',
        'f', 'l', 'a', 'v', 'o', 'u', 'r', 'i', 'n', 'g', 's', '\n',
        'f', 'l', 'a', 'v', 'o', 'u', 'r', 's', '\n',
        'f', 'l', 'a', 'w', '\n',
        'f', 'l', 'a', 'w', 'e', 'd', '\n',
        'f', 'l', 'a', 'w', 'l', 'e', 's', 's', '\n',
        'f', 'l', 'a', 'w', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'f', 'l', 'a', 'w', 's', '\n',
        'f', 'l', 'a', 'x', '\n',
        'f', 'l', 'a', 'x', 'e', 'n', '\n',
        'f', 'l', 'a', 'y', '\n',
        'f', 'l', 'a', 'y', 'e', 'd', '\n',
        'f', 'l', 'a', 'y', 'e', 'r', '\n',
        'f', 'l', 'a', 'y', 'e', 'r', 's', '\n',
        'f', 'l', 'a', 'y', 'i', 'n', 'g', '\n',
        'f', 'l', 'e', 'a', '\n',
        'f', 'l', 'e', 'a', 'b', 'i', 't', 'e', 's', '\n',
        'f', 'l', 'e', 'a', 's', '\n',
        'f', 'l', 'e', 'c', 'k', '\n',
        'f', 'l', 'e', 'c', 'k', 'e', 'd', '\n',
        'f', 'l', 'e', 'c', 'k', 's', '\n',
        'f', 'l', 'e', 'd', '\n',
        'f', 'l', 'e', 'd', 'g', 'e', '\n',
        'f', 'l', 'e', 'd', 'g', 'e', 'd', '\n',
        'f', 'l', 'e', 'd', 'g', 'e', 'l', 'i', 'n', 'g', '\n',
        'f', 'l', 'e', 'd', 'g', 'e', 's', '\n',
        'f', 'l', 'e', 'd', 'g', 'l', 'i', 'n', 'g', '\n',
        'f', 'l', 'e', 'd', 'g', 'l', 'i', 'n', 'g', 's', '\n',
        'f', 'l', 'e', 'e', '\n',
        'f', 'l', 'e', 'e', 'c', 'e', '\n',
        'f', 'l', 'e', 'e', 'c', 'e', 'd', '\n',
        'f', 'l', 'e', 'e', 'c', 'e', 's', '\n',
        'f', 'l', 'e', 'e', 'c', 'i', 'n', 'g', '\n',
        'f', 'l', 'e', 'e', 'c', 'y', '\n',
        'f', 'l', 'e', 'e', 'i', 'n', 'g', '\n',
        'f', 'l', 'e', 'e', 's', '\n',
        'f', 'l', 'e', 'e', 't', '\n',
        'f', 'l', 'e', 'e', 't', 'e', 'd', '\n',
        'f', 'l', 'e', 'e', 't', 'e', 'r', '\n',
        'f', 'l', 'e', 'e', 't', 'i', 'n', 'g', '\n',
        'f', 'l', 'e', 'e', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'f', 'l', 'e', 'e', 't', 'l', 'y', '\n',
        'f', 'l', 'e', 'e', 't', 's', '\n',
        'f', 'l', 'e', 'm', 'i', 's', 'h', '\n',
        'f', 'l', 'e', 's', 'h', '\n',
        'f', 'l', 'e', 's', 'h', 'e', 'd', '\n',
        'f', 'l', 'e', 's', 'h', 'e', 'r', '\n',
        'f', 'l', 'e', 's', 'h', 'e', 's', '\n',
        'f', 'l', 'e', 's', 'h', 'i', 'e', 'r', '\n',
        'f', 'l', 'e', 's', 'h', 'i', 'e', 's', 't', '\n',
        'f', 'l', 'e', 's', 'h', 'i', 'n', 'g', '\n',
        'f', 'l', 'e', 's', 'h', 'l', 'e', 's', 's', '\n',
        'f', 'l', 'e', 's', 'h', 'l', 'y', '\n',
        'f', 'l', 'e', 's', 'h', 'p', 'o', 't', 's', '\n',
        'f', 'l', 'e', 's', 'h', 'y', '\n',
        'f', 'l', 'e', 'w', '\n',
        'f', 'l', 'e', 'x', '\n',
        'f', 'l', 'e', 'x', 'e', 'd', '\n',
        'f', 'l', 'e', 'x', 'e', 's', '\n',
        'f', 'l', 'e', 'x', 'i', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'f', 'l', 'e', 'x', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'f', 'l', 'e', 'x', 'i', 'b', 'l', 'e', '\n',
        'f', 'l', 'e', 'x', 'i', 'b', 'l', 'y', '\n',
        'f', 'l', 'e', 'x', 'i', 'l', 'e', '\n',
        'f', 'l', 'e', 'x', 'i', 'n', 'g', '\n',
        'f', 'l', 'e', 'x', 'i', 'o', 'n', '\n',
        'f', 'l', 'e', 'x', 'o', 'r', '\n',
        'f', 'l', 'i', 'c', 'k', '\n',
        'f', 'l', 'i', 'c', 'k', 'e', 'd', '\n',
        'f', 'l', 'i', 'c', 'k', 'e', 'r', '\n',
        'f', 'l', 'i', 'c', 'k', 'e', 'r', 'e', 'd', '\n',
        'f', 'l', 'i', 'c', 'k', 'e', 'r', 'i', 'n', 'g', '\n',
        'f', 'l', 'i', 'c', 'k', 'e', 'r', 's', '\n',
        'f', 'l', 'i', 'c', 'k', 'e', 'r', 'y', '\n',
        'f', 'l', 'i', 'c', 'k', 'i', 'n', 'g', '\n',
        'f', 'l', 'i', 'c', 'k', 's', '\n',
        'f', 'l', 'i', 'e', 'r', '\n',
        'f', 'l', 'i', 'e', 'r', 's', '\n',
        'f', 'l', 'i', 'e', 's', '\n',
        'f', 'l', 'i', 'g', 'h', 't', '\n',
        'f', 'l', 'i', 'g', 'h', 't', 'e', 'd', '\n',
        'f', 'l', 'i', 'g', 'h', 't', 'l', 'e', 's', 's', '\n',
        'f', 'l', 'i', 'g', 'h', 't', 'p', 'a', 't', 'h', '\n',
        'f', 'l', 'i', 'g', 'h', 't', 's', '\n',
        'f', 'l', 'i', 'g', 'h', 't', 'y', '\n',
        'f', 'l', 'i', 'm', 's', 'i', 'e', 'r', '\n',
        'f', 'l', 'i', 'm', 's', 'i', 'e', 's', 't', '\n',
        'f', 'l', 'i', 'm', 's', 'i', 'l', 'y', '\n',
        'f', 'l', 'i', 'm', 's', 'i', 'n', 'e', 's', 's', '\n',
        'f', 'l', 'i', 'm', 's', 'y', '\n',
        'f', 'l', 'i', 'n', 'c', 'h', '\n',
        'f', 'l', 'i', 'n', 'c', 'h', 'e', 'd', '\n',
        'f', 'l', 'i', 'n', 'c', 'h', 'i', 'n', 'g', '\n',
        'f', 'l', 'i', 'n', 'g', '\n',
        'f', 'l', 'i', 'n', 'g', 'i', 'n', 'g', '\n',
        'f', 'l', 'i', 'n', 'g', 's', '\n',
        'f', 'l', 'i', 'n', 't', '\n',
        'f', 'l', 'i', 'n', 't', 'l', 'o', 'c', 'k', '\n',
        'f', 'l', 'i', 'n', 't', 'l', 'o', 'c', 'k', 's', '\n',
        'f', 'l', 'i', 'n', 't', 's', '\n',
        'f', 'l', 'i', 'n', 't', 'y', '\n',
        'f', 'l', 'i', 'p', '\n',
        'f', 'l', 'i', 'p', 'f', 'l', 'o', 'p', '\n',
        'f', 'l', 'i', 'p', 'f', 'l', 'o', 'p', 's', '\n',
        'f', 'l', 'i', 'p', 'p', 'a', 'b', 'l', 'e', '\n',
        'f', 'l', 'i', 'p', 'p', 'a', 'n', 'c', 'y', '\n',
        'f', 'l', 'i', 'p', 'p', 'a', 'n', 't', '\n',
        'f', 'l', 'i', 'p', 'p', 'a', 'n', 't', 'l', 'y', '\n',
        'f', 'l', 'i', 'p', 'p', 'e', 'd', '\n',
        'f', 'l', 'i', 'p', 'p', 'e', 'r', '\n',
        'f', 'l', 'i', 'p', 'p', 'e', 'r', 's', '\n',
        'f', 'l', 'i', 'p', 'p', 'i', 'n', 'g', '\n',
        'f', 'l', 'i', 'p', 's', '\n',
        'f', 'l', 'i', 'r', 't', '\n',
        'f', 'l', 'i', 'r', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'f', 'l', 'i', 'r', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'f', 'l', 'i', 'r', 't', 'a', 't', 'i', 'o', 'u', 's', '\n',
        'f', 'l', 'i', 'r', 't', 'a', 't', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'f', 'l', 'i', 'r', 't', 'e', 'd', '\n',
        'f', 'l', 'i', 'r', 't', 'i', 'n', 'g', '\n',
        'f', 'l', 'i', 'r', 't', 's', '\n',
        'f', 'l', 'i', 't', '\n',
        'f', 'l', 'i', 't', 'i', 'n', 'g', '\n',
        'f', 'l', 'i', 't', 's', '\n',
        'f', 'l', 'i', 't', 't', 'e', 'd', '\n',
        'f', 'l', 'i', 't', 't', 'i', 'n', 'g', '\n',
        'f', 'l', 'o', 'a', 't', '\n',
        'f', 'l', 'o', 'a', 't', 'e', 'd', '\n',
        'f', 'l', 'o', 'a', 't', 'e', 'r', '\n',
        'f', 'l', 'o', 'a', 't', 'e', 'r', 's', '\n',
        'f', 'l', 'o', 'a', 't', 'i', 'n', 'g', '\n',
        'f', 'l', 'o', 'a', 't', 's', '\n',
        'f', 'l', 'o', 'a', 't', 'y', '\n',
        'f', 'l', 'o', 'c', 'k', '\n',
        'f', 'l', 'o', 'c', 'k', 'e', 'd', '\n',
        'f', 'l', 'o', 'c', 'k', 'i', 'n', 'g', '\n',
        'f', 'l', 'o', 'c', 'k', 's', '\n',
        'f', 'l', 'o', 'e', '\n',
        'f', 'l', 'o', 'g', '\n',
        'f', 'l', 'o', 'g', 'g', 'e', 'd', '\n',
        'f', 'l', 'o', 'g', 'g', 'e', 'r', '\n',
        'f', 'l', 'o', 'g', 'g', 'e', 'r', 's', '\n',
        'f', 'l', 'o', 'g', 'g', 'i', 'n', 'g', '\n',
        'f', 'l', 'o', 'g', 'g', 'i', 'n', 'g', 's', '\n',
        'f', 'l', 'o', 'g', 's', '\n',
        'f', 'l', 'o', 'o', 'd', '\n',
        'f', 'l', 'o', 'o', 'd', 'e', 'd', '\n',
        'f', 'l', 'o', 'o', 'd', 'g', 'a', 't', 'e', 's', '\n',
        'f', 'l', 'o', 'o', 'd', 'i', 'n', 'g', '\n',
        'f', 'l', 'o', 'o', 'd', 'l', 'i', 'g', 'h', 't', '\n',
        'f', 'l', 'o', 'o', 'd', 'l', 'i', 'g', 'h', 't', 'i', 'n', 'g', '\n',
        'f', 'l', 'o', 'o', 'd', 'l', 'i', 'g', 'h', 't', 's', '\n',
        'f', 'l', 'o', 'o', 'd', 'l', 'i', 't', '\n',
        'f', 'l', 'o', 'o', 'd', 's', '\n',
        'f', 'l', 'o', 'o', 'r', '\n',
        'f', 'l', 'o', 'o', 'r', 'b', 'o', 'a', 'r', 'd', '\n',
        'f', 'l', 'o', 'o', 'r', 'b', 'o', 'a', 'r', 'd', 's', '\n',
        'f', 'l', 'o', 'o', 'r', 'e', 'd', '\n',
        'f', 'l', 'o', 'o', 'r', 'i', 'n', 'g', '\n',
        'f', 'l', 'o', 'o', 'r', 's', '\n',
        'f', 'l', 'o', 'o', 'r', 's', 'p', 'a', 'c', 'e', '\n',
        'f', 'l', 'o', 'o', 'z', 'i', 'e', '\n',
        'f', 'l', 'o', 'o', 'z', 'i', 'e', 's', '\n',
        'f', 'l', 'o', 'o', 'z', 'y', '\n',
        'f', 'l', 'o', 'p', '\n',
        'f', 'l', 'o', 'p', 'p', 'e', 'd', '\n',
        'f', 'l', 'o', 'p', 'p', 'e', 'r', '\n',
        'f', 'l', 'o', 'p', 'p', 'i', 'e', 'r', '\n',
        'f', 'l', 'o', 'p', 'p', 'i', 'e', 's', '\n',
        'f', 'l', 'o', 'p', 'p', 'i', 'e', 's', 't', '\n',
        'f', 'l', 'o', 'p', 'p', 'i', 'n', 'g', '\n',
        'f', 'l', 'o', 'p', 'p', 'y', '\n',
        'f', 'l', 'o', 'p', 's', '\n',
        'f', 'l', 'o', 'r', 'a', '\n',
        'f', 'l', 'o', 'r', 'a', 'l', '\n',
        'f', 'l', 'o', 'r', 'a', 's', '\n',
        'f', 'l', 'o', 'r', 'e', 'a', 't', '\n',
        'f', 'l', 'o', 'r', 'e', 'n', 'c', 'e', '\n',
        'f', 'l', 'o', 'r', 'e', 't', '\n',
        'f', 'l', 'o', 'r', 'i', 'd', '\n',
        'f', 'l', 'o', 'r', 'i', 'd', 'a', '\n',
        'f', 'l', 'o', 'r', 'i', 'd', 'l', 'y', '\n',
        'f', 'l', 'o', 'r', 'i', 'n', '\n',
        'f', 'l', 'o', 'r', 'i', 'n', 's', '\n',
        'f', 'l', 'o', 'r', 'i', 's', 't', '\n',
        'f', 'l', 'o', 'r', 'i', 's', 't', 's', '\n',
        'f', 'l', 'o', 's', 's', '\n',
        'f', 'l', 'o', 's', 's', 'e', 's', '\n',
        'f', 'l', 'o', 's', 's', 'i', 'n', 'g', '\n',
        'f', 'l', 'o', 's', 's', 'y', '\n',
        'f', 'l', 'o', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'f', 'l', 'o', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'f', 'l', 'o', 't', 'i', 'l', 'l', 'a', '\n',
        'f', 'l', 'o', 't', 'i', 'l', 'l', 'a', 's', '\n',
        'f', 'l', 'o', 't', 's', 'a', 'm', '\n',
        'f', 'l', 'o', 'u', 'n', 'c', 'e', '\n',
        'f', 'l', 'o', 'u', 'n', 'c', 'e', 'd', '\n',
        'f', 'l', 'o', 'u', 'n', 'c', 'e', 's', '\n',
        'f', 'l', 'o', 'u', 'n', 'c', 'i', 'n', 'g', '\n',
        'f', 'l', 'o', 'u', 'n', 'd', 'e', 'r', '\n',
        'f', 'l', 'o', 'u', 'n', 'd', 'e', 'r', 'e', 'd', '\n',
        'f', 'l', 'o', 'u', 'n', 'd', 'e', 'r', 'i', 'n', 'g', '\n',
        'f', 'l', 'o', 'u', 'n', 'd', 'e', 'r', 's', '\n',
        'f', 'l', 'o', 'u', 'r', '\n',
        'f', 'l', 'o', 'u', 'r', 'e', 'd', '\n',
        'f', 'l', 'o', 'u', 'r', 'i', 's', 'h', '\n',
        'f', 'l', 'o', 'u', 'r', 'i', 's', 'h', 'e', 'd', '\n',
        'f', 'l', 'o', 'u', 'r', 'i', 's', 'h', 'e', 's', '\n',
        'f', 'l', 'o', 'u', 'r', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'f', 'l', 'o', 'u', 'r', 's', '\n',
        'f', 'l', 'o', 'u', 'r', 'y', '\n',
        'f', 'l', 'o', 'u', 't', '\n',
        'f', 'l', 'o', 'u', 't', 'e', 'd', '\n',
        'f', 'l', 'o', 'u', 't', 'i', 'n', 'g', '\n',
        'f', 'l', 'o', 'u', 't', 's', '\n',
        'f', 'l', 'o', 'w', '\n',
        'f', 'l', 'o', 'w', 'e', 'd', '\n',
        'f', 'l', 'o', 'w', 'e', 'r', '\n',
        'f', 'l', 'o', 'w', 'e', 'r', 'e', 'd', '\n',
        'f', 'l', 'o', 'w', 'e', 'r', 'i', 'n', 'g', '\n',
        'f', 'l', 'o', 'w', 'e', 'r', 'l', 'e', 's', 's', '\n',
        'f', 'l', 'o', 'w', 'e', 'r', 'p', 'o', 't', '\n',
        'f', 'l', 'o', 'w', 'e', 'r', 'p', 'o', 't', 's', '\n',
        'f', 'l', 'o', 'w', 'e', 'r', 's', '\n',
        'f', 'l', 'o', 'w', 'e', 'r', 'y', '\n',
        'f', 'l', 'o', 'w', 'i', 'n', 'g', '\n',
        'f', 'l', 'o', 'w', 'n', '\n',
        'f', 'l', 'o', 'w', 's', '\n',
        'f', 'l', 'u', 'b', '\n',
        'f', 'l', 'u', 'b', 'b', 'e', 'd', '\n',
        'f', 'l', 'u', 'c', 't', 'u', 'a', 't', 'e', '\n',
        'f', 'l', 'u', 'c', 't', 'u', 'a', 't', 'e', 'd', '\n',
        'f', 'l', 'u', 'c', 't', 'u', 'a', 't', 'e', 's', '\n',
        'f', 'l', 'u', 'c', 't', 'u', 'a', 't', 'i', 'n', 'g', '\n',
        'f', 'l', 'u', 'c', 't', 'u', 'a', 't', 'i', 'o', 'n', '\n',
        'f', 'l', 'u', 'c', 't', 'u', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'f', 'l', 'u', 'e', '\n',
        'f', 'l', 'u', 'e', 'n', 'c', 'y', '\n',
        'f', 'l', 'u', 'e', 'n', 't', '\n',
        'f', 'l', 'u', 'e', 'n', 't', 'l', 'y', '\n',
        'f', 'l', 'u', 'e', 's', '\n',
        'f', 'l', 'u', 'f', 'f', '\n',
        'f', 'l', 'u', 'f', 'f', 'e', 'd', '\n',
        'f', 'l', 'u', 'f', 'f', 'i', 'e', 'r', '\n',
        'f', 'l', 'u', 'f', 'f', 'i', 'e', 's', 't', '\n',
        'f', 'l', 'u', 'f', 'f', 'i', 'n', 'g', '\n',
        'f', 'l', 'u', 'f', 'f', 's', '\n',
        'f', 'l', 'u', 'f', 'f', 'y', '\n',
        'f', 'l', 'u', 'i', 'd', '\n',
        'f', 'l', 'u', 'i', 'd', 'i', 's', 'e', 'd', '\n',
        'f', 'l', 'u', 'i', 'd', 'i', 't', 'y', '\n',
        'f', 'l', 'u', 'i', 'd', 'l', 'y', '\n',
        'f', 'l', 'u', 'i', 'd', 's', '\n',
        'f', 'l', 'u', 'k', 'e', '\n',
        'f', 'l', 'u', 'k', 'e', 's', '\n',
        'f', 'l', 'u', 'k', 'e', 'y', '\n',
        'f', 'l', 'u', 'k', 'i', 'e', 'r', '\n',
        'f', 'l', 'u', 'k', 'i', 'e', 's', 't', '\n',
        'f', 'l', 'u', 'm', 'e', 's', '\n',
        'f', 'l', 'u', 'm', 'p', 'e', 'd', '\n',
        'f', 'l', 'u', 'n', 'g', '\n',
        'f', 'l', 'u', 'n', 'k', 'e', 'd', '\n',
        'f', 'l', 'u', 'o', 'r', '\n',
        'f', 'l', 'u', 'o', 'r', 'e', 's', 'c', 'e', '\n',
        'f', 'l', 'u', 'o', 'r', 'e', 's', 'c', 'e', 'n', 'c', 'e', '\n',
        'f', 'l', 'u', 'o', 'r', 'e', 's', 'c', 'e', 'n', 't', '\n',
        'f', 'l', 'u', 'o', 'r', 'e', 's', 'c', 'e', 's', '\n',
        'f', 'l', 'u', 'o', 'r', 'e', 's', 'c', 'i', 'n', 'g', '\n',
        'f', 'l', 'u', 'o', 'r', 'i', 'd', 'a', 't', 'i', 'o', 'n', '\n',
        'f', 'l', 'u', 'o', 'r', 'i', 'd', 'e', '\n',
        'f', 'l', 'u', 'o', 'r', 'i', 'n', 'e', '\n',
        'f', 'l', 'u', 'o', 'r', 'o', 'c', 'a', 'r', 'b', 'o', 'n', '\n',
        'f', 'l', 'u', 'o', 'r', 'o', 'c', 'a', 'r', 'b', 'o', 'n', 's', '\n',
        'f', 'l', 'u', 'r', 'r', 'i', 'e', 'd', '\n',
        'f', 'l', 'u', 'r', 'r', 'i', 'e', 's', '\n',
        'f', 'l', 'u', 'r', 'r', 'y', '\n',
        'f', 'l', 'u', 's', 'h', '\n',
        'f', 'l', 'u', 's', 'h', 'e', 'd', '\n',
        'f', 'l', 'u', 's', 'h', 'e', 'r', '\n',
        'f', 'l', 'u', 's', 'h', 'e', 's', '\n',
        'f', 'l', 'u', 's', 'h', 'i', 'n', 'g', '\n',
        'f', 'l', 'u', 's', 't', 'e', 'r', '\n',
        'f', 'l', 'u', 's', 't', 'e', 'r', 'e', 'd', '\n',
        'f', 'l', 'u', 't', 'e', '\n',
        'f', 'l', 'u', 't', 'e', 'd', '\n',
        'f', 'l', 'u', 't', 'e', 's', '\n',
        'f', 'l', 'u', 't', 'i', 'n', 'g', '\n',
        'f', 'l', 'u', 't', 'i', 's', 't', '\n',
        'f', 'l', 'u', 't', 't', 'e', 'r', '\n',
        'f', 'l', 'u', 't', 't', 'e', 'r', 'e', 'd', '\n',
        'f', 'l', 'u', 't', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'f', 'l', 'u', 't', 't', 'e', 'r', 's', '\n',
        'f', 'l', 'u', 't', 't', 'e', 'r', 'y', '\n',
        'f', 'l', 'u', 'v', 'i', 'a', 'l', '\n',
        'f', 'l', 'u', 'x', '\n',
        'f', 'l', 'u', 'x', 'e', 's', '\n',
        'f', 'l', 'y', '\n',
        'f', 'l', 'y', 'a', 'w', 'a', 'y', '\n',
        'f', 'l', 'y', 'e', 'r', '\n',
        'f', 'l', 'y', 'e', 'r', 's', '\n',
        'f', 'l', 'y', 'h', 'a', 'l', 'f', '\n',
        'f', 'l', 'y', 'i', 'n', 'g', '\n',
        'f', 'l', 'y', 'o', 'v', 'e', 'r', '\n',
        'f', 'l', 'y', 'o', 'v', 'e', 'r', 's', '\n',
        'f', 'l', 'y', 'p', 'a', 'p', 'e', 'r', '\n',
        'f', 'l', 'y', 'p', 'a', 's', 't', '\n',
        'f', 'l', 'y', 'w', 'a', 'y', '\n',
        'f', 'l', 'y', 'w', 'a', 'y', 's', '\n',
        'f', 'l', 'y', 'w', 'e', 'i', 'g', 'h', 't', '\n',
        'f', 'l', 'y', 'w', 'h', 'e', 'e', 'l', '\n',
        'f', 'o', 'a', 'l', '\n',
        'f', 'o', 'a', 'l', 'e', 'd', '\n',
        'f', 'o', 'a', 'l', 'i', 'n', 'g', '\n',
        'f', 'o', 'a', 'l', 's', '\n',
        'f', 'o', 'a', 'm', '\n',
        'f', 'o', 'a', 'm', 'e', 'd', '\n',
        'f', 'o', 'a', 'm', 'i', 'e', 'r', '\n',
        'f', 'o', 'a', 'm', 'i', 'e', 's', 't', '\n',
        'f', 'o', 'a', 'm', 'i', 'n', 'g', '\n',
        'f', 'o', 'a', 'm', 's', '\n',
        'f', 'o', 'a', 'm', 'y', '\n',
        'f', 'o', 'b', '\n',
        'f', 'o', 'b', 'b', 'e', 'd', '\n',
        'f', 'o', 'b', 'b', 'i', 'n', 'g', '\n',
        'f', 'o', 'b', 's', '\n',
        'f', 'o', 'c', 'a', 'l', '\n',
        'f', 'o', 'c', 'a', 'l', 'l', 'y', '\n',
        'f', 'o', 'c', 'i', '\n',
        'f', 'o', 'c', 'u', 's', '\n',
        'f', 'o', 'c', 'u', 's', 'e', 'd', '\n',
        'f', 'o', 'c', 'u', 's', 'e', 's', '\n',
        'f', 'o', 'c', 'u', 's', 'i', 'n', 'g', '\n',
        'f', 'o', 'c', 'u', 's', 's', 'e', 'd', '\n',
        'f', 'o', 'c', 'u', 's', 's', 'e', 's', '\n',
        'f', 'o', 'c', 'u', 's', 's', 'i', 'n', 'g', '\n',
        'f', 'o', 'd', 'd', 'e', 'r', '\n',
        'f', 'o', 'd', 'd', 'e', 'r', 's', '\n',
        'f', 'o', 'e', '\n',
        'f', 'o', 'e', 'h', 'n', 's', '\n',
        'f', 'o', 'e', 's', '\n',
        'f', 'o', 'e', 't', 'a', 'l', '\n',
        'f', 'o', 'e', 't', 'i', 'd', '\n',
        'f', 'o', 'e', 't', 'u', 's', '\n',
        'f', 'o', 'e', 't', 'u', 's', 'e', 's', '\n',
        'f', 'o', 'g', '\n',
        'f', 'o', 'g', 'b', 'a', 'n', 'k', '\n',
        'f', 'o', 'g', 'e', 'y', '\n',
        'f', 'o', 'g', 'g', 'e', 'd', '\n',
        'f', 'o', 'g', 'g', 'i', 'e', 'r', '\n',
        'f', 'o', 'g', 'g', 'i', 'e', 's', 't', '\n',
        'f', 'o', 'g', 'g', 'i', 'n', 'g', '\n',
        'f', 'o', 'g', 'g', 'y', '\n',
        'f', 'o', 'g', 'h', 'o', 'r', 'n', '\n',
        'f', 'o', 'g', 'h', 'o', 'r', 'n', 's', '\n',
        'f', 'o', 'g', 's', '\n',
        'f', 'o', 'g', 'y', '\n',
        'f', 'o', 'i', 'b', 'l', 'e', '\n',
        'f', 'o', 'i', 'b', 'l', 'e', 's', '\n',
        'f', 'o', 'i', 'l', '\n',
        'f', 'o', 'i', 'l', 'e', 'd', '\n',
        'f', 'o', 'i', 'l', 'i', 'n', 'g', '\n',
        'f', 'o', 'i', 'l', 's', '\n',
        'f', 'o', 'i', 's', 't', '\n',
        'f', 'o', 'i', 's', 't', 'e', 'd', '\n',
        'f', 'o', 'i', 's', 't', 'i', 'n', 'g', '\n',
        'f', 'o', 'l', 'd', '\n',
        'f', 'o', 'l', 'd', 'e', 'd', '\n',
        'f', 'o', 'l', 'd', 'e', 'r', '\n',
        'f', 'o', 'l', 'd', 'e', 'r', 's', '\n',
        'f', 'o', 'l', 'd', 'i', 'n', 'g', '\n',
        'f', 'o', 'l', 'd', 's', '\n',
        'f', 'o', 'l', 'i', 'a', 'g', 'e', '\n',
        'f', 'o', 'l', 'i', 'a', 't', 'e', '\n',
        'f', 'o', 'l', 'i', 'a', 't', 'e', 'd', '\n',
        'f', 'o', 'l', 'i', 'o', '\n',
        'f', 'o', 'l', 'k', '\n',
        'f', 'o', 'l', 'k', 'a', 'r', 't', '\n',
        'f', 'o', 'l', 'k', 'i', 's', 'h', '\n',
        'f', 'o', 'l', 'k', 'l', 'o', 'r', 'e', '\n',
        'f', 'o', 'l', 'k', 'l', 'o', 'r', 'i', 's', 't', '\n',
        'f', 'o', 'l', 'k', 'l', 'o', 'r', 'i', 's', 't', 's', '\n',
        'f', 'o', 'l', 'k', 's', '\n',
        'f', 'o', 'l', 'k', 't', 'a', 'l', 'e', '\n',
        'f', 'o', 'l', 'l', 'i', 'c', 'l', 'e', '\n',
        'f', 'o', 'l', 'l', 'i', 'c', 'l', 'e', 's', '\n',
        'f', 'o', 'l', 'l', 'i', 'c', 'u', 'l', 'a', 'r', '\n',
        'f', 'o', 'l', 'l', 'i', 'e', 's', '\n',
        'f', 'o', 'l', 'l', 'o', 'w', '\n',
        'f', 'o', 'l', 'l', 'o', 'w', 'a', 'b', 'l', 'e', '\n',
        'f', 'o', 'l', 'l', 'o', 'w', 'e', 'd', '\n',
        'f', 'o', 'l', 'l', 'o', 'w', 'e', 'r', '\n',
        'f', 'o', 'l', 'l', 'o', 'w', 'e', 'r', 's', '\n',
        'f', 'o', 'l', 'l', 'o', 'w', 'i', 'n', 'g', '\n',
        'f', 'o', 'l', 'l', 'o', 'w', 'i', 'n', 'g', 's', '\n',
        'f', 'o', 'l', 'l', 'o', 'w', 's', '\n',
        'f', 'o', 'l', 'l', 'y', '\n',
        'f', 'o', 'm', 'e', 'n', 't', '\n',
        'f', 'o', 'm', 'e', 'n', 't', 'e', 'd', '\n',
        'f', 'o', 'm', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'f', 'o', 'n', 'd', '\n',
        'f', 'o', 'n', 'd', 'a', 'n', 't', '\n',
        'f', 'o', 'n', 'd', 'e', 'r', '\n',
        'f', 'o', 'n', 'd', 'e', 's', 't', '\n',
        'f', 'o', 'n', 'd', 'l', 'e', '\n',
        'f', 'o', 'n', 'd', 'l', 'e', 'd', '\n',
        'f', 'o', 'n', 'd', 'l', 'e', 's', '\n',
        'f', 'o', 'n', 'd', 'l', 'i', 'n', 'g', '\n',
        'f', 'o', 'n', 'd', 'l', 'y', '\n',
        'f', 'o', 'n', 'd', 'n', 'e', 's', 's', '\n',
        'f', 'o', 'n', 'd', 'u', 'e', '\n',
        'f', 'o', 'n', 'd', 'u', 'e', 's', '\n',
        'f', 'o', 'n', 't', '\n',
        'f', 'o', 'n', 't', 'a', 'n', 'e', 'l', '\n',
        'f', 'o', 'n', 't', 's', '\n',
        'f', 'o', 'o', 'd', '\n',
        'f', 'o', 'o', 'd', 'l', 'e', 's', 's', '\n',
        'f', 'o', 'o', 'd', 's', '\n',
        'f', 'o', 'o', 'd', 's', 't', 'u', 'f', 'f', '\n',
        'f', 'o', 'o', 'd', 's', 't', 'u', 'f', 'f', 's', '\n',
        'f', 'o', 'o', 'l', '\n',
        'f', 'o', 'o', 'l', 'e', 'd', '\n',
        'f', 'o', 'o', 'l', 'e', 'r', 'y', '\n',
        'f', 'o', 'o', 'l', 'h', 'a', 'r', 'd', 'i', 'l', 'y', '\n',
        'f', 'o', 'o', 'l', 'h', 'a', 'r', 'd', 'i', 'n', 'e', 's', 's', '\n',
        'f', 'o', 'o', 'l', 'h', 'a', 'r', 'd', 'y', '\n',
        'f', 'o', 'o', 'l', 'i', 'n', 'g', '\n',
        'f', 'o', 'o', 'l', 'i', 's', 'h', '\n',
        'f', 'o', 'o', 'l', 'i', 's', 'h', 'l', 'y', '\n',
        'f', 'o', 'o', 'l', 'i', 's', 'h', 'n', 'e', 's', 's', '\n',
        'f', 'o', 'o', 'l', 'p', 'r', 'o', 'o', 'f', '\n',
        'f', 'o', 'o', 'l', 's', '\n',
        'f', 'o', 'o', 'l', 's', 'c', 'a', 'p', '\n',
        'f', 'o', 'o', 't', '\n',
        'f', 'o', 'o', 't', 'a', 'g', 'e', '\n',
        'f', 'o', 'o', 't', 'a', 'g', 'e', 's', '\n',
        'f', 'o', 'o', 't', 'b', 'a', 'l', 'l', '\n',
        'f', 'o', 'o', 't', 'b', 'a', 'l', 'l', 'e', 'r', '\n',
        'f', 'o', 'o', 't', 'b', 'a', 'l', 'l', 'e', 'r', 's', '\n',
        'f', 'o', 'o', 't', 'b', 'a', 'l', 'l', 'i', 'n', 'g', '\n',
        'f', 'o', 'o', 't', 'b', 'a', 'l', 'l', 's', '\n',
        'f', 'o', 'o', 't', 'b', 'a', 't', 'h', '\n',
        'f', 'o', 'o', 't', 'b', 'r', 'i', 'd', 'g', 'e', '\n',
        'f', 'o', 'o', 't', 'e', 'd', '\n',
        'f', 'o', 'o', 't', 'f', 'a', 'l', 'l', '\n',
        'f', 'o', 'o', 't', 'f', 'a', 'l', 'l', 's', '\n',
        'f', 'o', 'o', 't', 'g', 'e', 'a', 'r', '\n',
        'f', 'o', 'o', 't', 'h', 'i', 'l', 'l', '\n',
        'f', 'o', 'o', 't', 'h', 'i', 'l', 'l', 's', '\n',
        'f', 'o', 'o', 't', 'h', 'o', 'l', 'd', '\n',
        'f', 'o', 'o', 't', 'h', 'o', 'l', 'd', 's', '\n',
        'f', 'o', 'o', 't', 'i', 'n', 'g', '\n',
        'f', 'o', 'o', 't', 'i', 'n', 'g', 's', '\n',
        'f', 'o', 'o', 't', 'l', 'e', 's', 's', '\n',
        'f', 'o', 'o', 't', 'l', 'i', 'g', 'h', 't', 's', '\n',
        'f', 'o', 'o', 't', 'l', 'o', 'o', 's', 'e', '\n',
        'f', 'o', 'o', 't', 'm', 'a', 'n', '\n',
        'f', 'o', 'o', 't', 'm', 'a', 'r', 'k', 's', '\n',
        'f', 'o', 'o', 't', 'm', 'e', 'n', '\n',
        'f', 'o', 'o', 't', 'n', 'o', 't', 'e', '\n',
        'f', 'o', 'o', 't', 'n', 'o', 't', 'e', 's', '\n',
        'f', 'o', 'o', 't', 'p', 'a', 'd', 's', '\n',
        'f', 'o', 'o', 't', 'p', 'a', 't', 'h', '\n',
        'f', 'o', 'o', 't', 'p', 'a', 't', 'h', 's', '\n',
        'f', 'o', 'o', 't', 'p', 'l', 'a', 't', 'e', '\n',
        'f', 'o', 'o', 't', 'p', 'r', 'i', 'n', 't', '\n',
        'f', 'o', 'o', 't', 'p', 'r', 'i', 'n', 't', 's', '\n',
        'f', 'o', 'o', 't', 'r', 'e', 's', 't', '\n',
        'f', 'o', 'o', 't', 's', '\n',
        'f', 'o', 'o', 't', 's', 'i', 'e', '\n',
        'f', 'o', 'o', 't', 's', 'o', 'r', 'e', '\n',
        'f', 'o', 'o', 't', 's', 't', 'e', 'p', '\n',
        'f', 'o', 'o', 't', 's', 't', 'e', 'p', 's', '\n',
        'f', 'o', 'o', 't', 's', 't', 'o', 'o', 'l', '\n',
        'f', 'o', 'o', 't', 's', 't', 'o', 'o', 'l', 's', '\n',
        'f', 'o', 'o', 't', 'w', 'a', 'y', '\n',
        'f', 'o', 'o', 't', 'w', 'e', 'a', 'r', '\n',
        'f', 'o', 'o', 't', 'w', 'o', 'r', 'k', '\n',
        'f', 'o', 'p', '\n',
        'f', 'o', 'p', 's', '\n',
        'f', 'o', 'r', '\n',
        'f', 'o', 'r', 'a', 'g', 'e', '\n',
        'f', 'o', 'r', 'a', 'g', 'e', 'd', '\n',
        'f', 'o', 'r', 'a', 'g', 'e', 'r', 's', '\n',
        'f', 'o', 'r', 'a', 'g', 'e', 's', '\n',
        'f', 'o', 'r', 'a', 'g', 'i', 'n', 'g', '\n',
        'f', 'o', 'r', 'a', 'm', 'e', 'n', '\n',
        'f', 'o', 'r', 'a', 'y', '\n',
        'f', 'o', 'r', 'a', 'y', 's', '\n',
        'f', 'o', 'r', 'b', 'a', 'd', '\n',
        'f', 'o', 'r', 'b', 'a', 'd', 'e', '\n',
        'f', 'o', 'r', 'b', 'e', 'a', 'r', '\n',
        'f', 'o', 'r', 'b', 'e', 'a', 'r', 'a', 'n', 'c', 'e', '\n',
        'f', 'o', 'r', 'b', 'e', 'a', 'r', 'i', 'n', 'g', '\n',
        'f', 'o', 'r', 'b', 'e', 'a', 'r', 's', '\n',
        'f', 'o', 'r', 'b', 'i', 'd', '\n',
        'f', 'o', 'r', 'b', 'i', 'd', 'd', 'e', 'n', '\n',
        'f', 'o', 'r', 'b', 'i', 'd', 'd', 'i', 'n', 'g', '\n',
        'f', 'o', 'r', 'b', 'i', 'd', 'd', 'i', 'n', 'g', 'l', 'y', '\n',
        'f', 'o', 'r', 'b', 'i', 'd', 's', '\n',
        'f', 'o', 'r', 'b', 'o', 'r', 'e', '\n',
        'f', 'o', 'r', 'c', 'e', '\n',
        'f', 'o', 'r', 'c', 'e', 'd', '\n',
        'f', 'o', 'r', 'c', 'e', 'f', 'e', 'e', 'd', '\n',
        'f', 'o', 'r', 'c', 'e', 'f', 'e', 'e', 'd', 'i', 'n', 'g', '\n',
        'f', 'o', 'r', 'c', 'e', 'f', 'u', 'l', '\n',
        'f', 'o', 'r', 'c', 'e', 'f', 'u', 'l', 'l', 'y', '\n',
        'f', 'o', 'r', 'c', 'e', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'f', 'o', 'r', 'c', 'e', 'p', 's', '\n',
        'f', 'o', 'r', 'c', 'e', 's', '\n',
        'f', 'o', 'r', 'c', 'i', 'b', 'l', 'e', '\n',
        'f', 'o', 'r', 'c', 'i', 'b', 'l', 'y', '\n',
        'f', 'o', 'r', 'c', 'i', 'n', 'g', '\n',
        'f', 'o', 'r', 'd', '\n',
        'f', 'o', 'r', 'd', 'e', 'd', '\n',
        'f', 'o', 'r', 'd', 'i', 'n', 'g', '\n',
        'f', 'o', 'r', 'd', 's', '\n',
        'f', 'o', 'r', 'e', '\n',
        'f', 'o', 'r', 'e', 'a', 'r', 'm', '\n',
        'f', 'o', 'r', 'e', 'a', 'r', 'm', 'e', 'd', '\n',
        'f', 'o', 'r', 'e', 'a', 'r', 'm', 's', '\n',
        'f', 'o', 'r', 'e', 'b', 'e', 'a', 'r', '\n',
        'f', 'o', 'r', 'e', 'b', 'e', 'a', 'r', 's', '\n',
        'f', 'o', 'r', 'e', 'b', 'o', 'd', 'e', 'd', '\n',
        'f', 'o', 'r', 'e', 'b', 'o', 'd', 'i', 'n', 'g', '\n',
        'f', 'o', 'r', 'e', 'b', 'o', 'd', 'i', 'n', 'g', 's', '\n',
        'f', 'o', 'r', 'e', 'b', 'r', 'a', 'i', 'n', '\n',
        'f', 'o', 'r', 'e', 'c', 'a', 's', 't', '\n',
        'f', 'o', 'r', 'e', 'c', 'a', 's', 't', 'e', 'r', '\n',
        'f', 'o', 'r', 'e', 'c', 'a', 's', 't', 'e', 'r', 's', '\n',
        'f', 'o', 'r', 'e', 'c', 'a', 's', 't', 'i', 'n', 'g', '\n',
        'f', 'o', 'r', 'e', 'c', 'a', 's', 't', 's', '\n',
        'f', 'o', 'r', 'e', 'c', 'l', 'o', 's', 'e', '\n',
        'f', 'o', 'r', 'e', 'c', 'l', 'o', 's', 'e', 'd', '\n',
        'f', 'o', 'r', 'e', 'c', 'l', 'o', 's', 'u', 'r', 'e', '\n',
        'f', 'o', 'r', 'e', 'c', 'o', 'u', 'r', 't', '\n',
        'f', 'o', 'r', 'e', 'c', 'o', 'u', 'r', 't', 's', '\n',
        'f', 'o', 'r', 'e', 'd', 'e', 'c', 'k', '\n',
        'f', 'o', 'r', 'e', 'f', 'a', 't', 'h', 'e', 'r', '\n',
        'f', 'o', 'r', 'e', 'f', 'a', 't', 'h', 'e', 'r', 's', '\n',
        'f', 'o', 'r', 'e', 'f', 'i', 'n', 'g', 'e', 'r', '\n',
        'f', 'o', 'r', 'e', 'f', 'i', 'n', 'g', 'e', 'r', 's', '\n',
        'f', 'o', 'r', 'e', 'f', 'r', 'o', 'n', 't', '\n',
        'f', 'o', 'r', 'e', 'g', 'a', 't', 'h', 'e', 'r', '\n',
        'f', 'o', 'r', 'e', 'g', 'a', 't', 'h', 'e', 'r', 'e', 'd', '\n',
        'f', 'o', 'r', 'e', 'g', 'o', '\n',
        'f', 'o', 'r', 'e', 'g', 'o', 'i', 'n', 'g', '\n',
        'f', 'o', 'r', 'e', 'g', 'o', 'n', 'e', '\n',
        'f', 'o', 'r', 'e', 'g', 'r', 'o', 'u', 'n', 'd', '\n',
        'f', 'o', 'r', 'e', 'g', 'r', 'o', 'u', 'n', 'd', 'e', 'd', '\n',
        'f', 'o', 'r', 'e', 'g', 'r', 'o', 'u', 'n', 'd', 'i', 'n', 'g', '\n',
        'f', 'o', 'r', 'e', 'g', 'r', 'o', 'u', 'n', 'd', 's', '\n',
        'f', 'o', 'r', 'e', 'h', 'a', 'n', 'd', '\n',
        'f', 'o', 'r', 'e', 'h', 'e', 'a', 'd', '\n',
        'f', 'o', 'r', 'e', 'h', 'e', 'a', 'd', 's', '\n',
        'f', 'o', 'r', 'e', 'i', 'g', 'n', '\n',
        'f', 'o', 'r', 'e', 'i', 'g', 'n', 'e', 'r', '\n',
        'f', 'o', 'r', 'e', 'i', 'g', 'n', 'e', 'r', 's', '\n',
        'f', 'o', 'r', 'e', 'i', 'g', 'n', 'n', 'e', 's', 's', '\n',
        'f', 'o', 'r', 'e', 'k', 'n', 'o', 'w', 'l', 'e', 'd', 'g', 'e', '\n',
        'f', 'o', 'r', 'e', 'l', 'a', 'n', 'd', '\n',
        'f', 'o', 'r', 'e', 'l', 'e', 'g', '\n',
        'f', 'o', 'r', 'e', 'l', 'e', 'g', 's', '\n',
        'f', 'o', 'r', 'e', 'l', 'i', 'm', 'b', 's', '\n',
        'f', 'o', 'r', 'e', 'l', 'o', 'c', 'k', '\n',
        'f', 'o', 'r', 'e', 'm', 'a', 'n', '\n',
        'f', 'o', 'r', 'e', 'm', 'e', 'n', '\n',
        'f', 'o', 'r', 'e', 'm', 'o', 's', 't', '\n',
        'f', 'o', 'r', 'e', 'n', 'a', 'm', 'e', '\n',
        'f', 'o', 'r', 'e', 'n', 'a', 'm', 'e', 's', '\n',
        'f', 'o', 'r', 'e', 'n', 's', 'i', 'c', '\n',
        'f', 'o', 'r', 'e', 'n', 's', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'f', 'o', 'r', 'e', 'p', 'a', 'w', '\n',
        'f', 'o', 'r', 'e', 'p', 'a', 'w', 's', '\n',
        'f', 'o', 'r', 'e', 'p', 'l', 'a', 'y', '\n',
        'f', 'o', 'r', 'e', 'r', 'u', 'n', 'n', 'e', 'r', '\n',
        'f', 'o', 'r', 'e', 'r', 'u', 'n', 'n', 'e', 'r', 's', '\n',
        'f', 'o', 'r', 'e', 's', 'a', 'i', 'l', '\n',
        'f', 'o', 'r', 'e', 's', 'a', 'w', '\n',
        'f', 'o', 'r', 'e', 's', 'e', 'e', '\n',
        'f', 'o', 'r', 'e', 's', 'e', 'e', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'f', 'o', 'r', 'e', 's', 'e', 'e', 'a', 'b', 'l', 'e', '\n',
        'f', 'o', 'r', 'e', 's', 'e', 'e', 'i', 'n', 'g', '\n',
        'f', 'o', 'r', 'e', 's', 'e', 'e', 'n', '\n',
        'f', 'o', 'r', 'e', 's', 'e', 'e', 's', '\n',
        'f', 'o', 'r', 'e', 's', 'h', 'a', 'd', 'o', 'w', '\n',
        'f', 'o', 'r', 'e', 's', 'h', 'a', 'd', 'o', 'w', 'e', 'd', '\n',
        'f', 'o', 'r', 'e', 's', 'h', 'a', 'd', 'o', 'w', 'i', 'n', 'g', '\n',
        'f', 'o', 'r', 'e', 's', 'h', 'a', 'd', 'o', 'w', 's', '\n',
        'f', 'o', 'r', 'e', 's', 'h', 'o', 'r', 'e', '\n',
        'f', 'o', 'r', 'e', 's', 'h', 'o', 'r', 'e', 's', '\n',
        'f', 'o', 'r', 'e', 's', 'h', 'o', 'r', 't', 'e', 'n', 'e', 'd', '\n',
        'f', 'o', 'r', 'e', 's', 'h', 'o', 'r', 't', 'e', 'n', 'i', 'n', 'g', '\n',
        'f', 'o', 'r', 'e', 's', 'i', 'g', 'h', 't', '\n',
        'f', 'o', 'r', 'e', 's', 'k', 'i', 'n', '\n',
        'f', 'o', 'r', 'e', 's', 'k', 'i', 'n', 's', '\n',
        'f', 'o', 'r', 'e', 's', 't', '\n',
        'f', 'o', 'r', 'e', 's', 't', 'a', 'l', 'l', '\n',
        'f', 'o', 'r', 'e', 's', 't', 'a', 'l', 'l', 'e', 'd', '\n',
        'f', 'o', 'r', 'e', 's', 't', 'a', 'l', 'l', 'i', 'n', 'g', '\n',
        'f', 'o', 'r', 'e', 's', 't', 'a', 'l', 'l', 's', '\n',
        'f', 'o', 'r', 'e', 's', 't', 'e', 'd', '\n',
        'f', 'o', 'r', 'e', 's', 't', 'e', 'r', '\n',
        'f', 'o', 'r', 'e', 's', 't', 'e', 'r', 's', '\n',
        'f', 'o', 'r', 'e', 's', 't', 'r', 'y', '\n',
        'f', 'o', 'r', 'e', 's', 't', 's', '\n',
        'f', 'o', 'r', 'e', 't', 'a', 's', 't', 'e', '\n',
        'f', 'o', 'r', 'e', 't', 'a', 's', 't', 'e', 's', '\n',
        'f', 'o', 'r', 'e', 't', 'e', 'l', 'l', '\n',
        'f', 'o', 'r', 'e', 't', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'f', 'o', 'r', 'e', 't', 'h', 'o', 'u', 'g', 'h', 't', '\n',
        'f', 'o', 'r', 'e', 't', 'o', 'l', 'd', '\n',
        'f', 'o', 'r', 'e', 'v', 'e', 'r', '\n',
        'f', 'o', 'r', 'e', 'w', 'a', 'r', 'n', '\n',
        'f', 'o', 'r', 'e', 'w', 'a', 'r', 'n', 'e', 'd', '\n',
        'f', 'o', 'r', 'e', 'w', 'a', 'r', 'n', 'i', 'n', 'g', '\n',
        'f', 'o', 'r', 'e', 'w', 'o', 'r', 'd', '\n',
        'f', 'o', 'r', 'e', 'w', 'o', 'r', 'd', 's', '\n',
        'f', 'o', 'r', 'f', 'e', 'i', 't', '\n',
        'f', 'o', 'r', 'f', 'e', 'i', 't', 'e', 'd', '\n',
        'f', 'o', 'r', 'f', 'e', 'i', 't', 'i', 'n', 'g', '\n',
        'f', 'o', 'r', 'f', 'e', 'i', 't', 's', '\n',
        'f', 'o', 'r', 'f', 'e', 'i', 't', 'u', 'r', 'e', '\n',
        'f', 'o', 'r', 'g', 'a', 'v', 'e', '\n',
        'f', 'o', 'r', 'g', 'e', '\n',
        'f', 'o', 'r', 'g', 'e', 'd', '\n',
        'f', 'o', 'r', 'g', 'e', 'r', '\n',
        'f', 'o', 'r', 'g', 'e', 'r', 'i', 'e', 's', '\n',
        'f', 'o', 'r', 'g', 'e', 'r', 's', '\n',
        'f', 'o', 'r', 'g', 'e', 'r', 'y', '\n',
        'f', 'o', 'r', 'g', 'e', 's', '\n',
        'f', 'o', 'r', 'g', 'e', 't', '\n',
        'f', 'o', 'r', 'g', 'e', 't', 'f', 'u', 'l', '\n',
        'f', 'o', 'r', 'g', 'e', 't', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'f', 'o', 'r', 'g', 'e', 't', 'm', 'e', 'n', 'o', 't', '\n',
        'f', 'o', 'r', 'g', 'e', 't', 'm', 'e', 'n', 'o', 't', 's', '\n',
        'f', 'o', 'r', 'g', 'e', 't', 's', '\n',
        'f', 'o', 'r', 'g', 'e', 't', 't', 'a', 'b', 'l', 'e', '\n',
        'f', 'o', 'r', 'g', 'e', 't', 't', 'i', 'n', 'g', '\n',
        'f', 'o', 'r', 'g', 'i', 'n', 'g', '\n',
        'f', 'o', 'r', 'g', 'i', 'n', 'g', 's', '\n',
        'f', 'o', 'r', 'g', 'i', 'v', 'a', 'b', 'l', 'e', '\n',
        'f', 'o', 'r', 'g', 'i', 'v', 'e', '\n',
        'f', 'o', 'r', 'g', 'i', 'v', 'e', 'n', '\n',
        'f', 'o', 'r', 'g', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'f', 'o', 'r', 'g', 'i', 'v', 'e', 's', '\n',
        'f', 'o', 'r', 'g', 'i', 'v', 'i', 'n', 'g', '\n',
        'f', 'o', 'r', 'g', 'o', '\n',
        'f', 'o', 'r', 'g', 'o', 'i', 'n', 'g', '\n',
        'f', 'o', 'r', 'g', 'o', 'n', 'e', '\n',
        'f', 'o', 'r', 'g', 'o', 't', '\n',
        'f', 'o', 'r', 'g', 'o', 't', 't', 'e', 'n', '\n',
        'f', 'o', 'r', 'k', '\n',
        'f', 'o', 'r', 'k', 'e', 'd', '\n',
        'f', 'o', 'r', 'k', 'i', 'n', 'g', '\n',
        'f', 'o', 'r', 'k', 's', '\n',
        'f', 'o', 'r', 'l', 'o', 'r', 'n', '\n',
        'f', 'o', 'r', 'l', 'o', 'r', 'n', 'l', 'y', '\n',
        'f', 'o', 'r', 'l', 'o', 'r', 'n', 'n', 'e', 's', 's', '\n',
        'f', 'o', 'r', 'm', '\n',
        'f', 'o', 'r', 'm', 'a', 'l', '\n',
        'f', 'o', 'r', 'm', 'a', 'l', 'd', 'e', 'h', 'y', 'd', 'e', '\n',
        'f', 'o', 'r', 'm', 'a', 'l', 'i', 'n', '\n',
        'f', 'o', 'r', 'm', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'f', 'o', 'r', 'm', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'f', 'o', 'r', 'm', 'a', 'l', 'i', 's', 'e', '\n',
        'f', 'o', 'r', 'm', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'f', 'o', 'r', 'm', 'a', 'l', 'i', 's', 'e', 's', '\n',
        'f', 'o', 'r', 'm', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'f', 'o', 'r', 'm', 'a', 'l', 'i', 's', 'm', '\n',
        'f', 'o', 'r', 'm', 'a', 'l', 'i', 's', 'm', 's', '\n',
        'f', 'o', 'r', 'm', 'a', 'l', 'i', 's', 't', '\n',
        'f', 'o', 'r', 'm', 'a', 'l', 'i', 's', 't', 'i', 'c', '\n',
        'f', 'o', 'r', 'm', 'a', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'f', 'o', 'r', 'm', 'a', 'l', 'i', 't', 'y', '\n',
        'f', 'o', 'r', 'm', 'a', 'l', 'l', 'y', '\n',
        'f', 'o', 'r', 'm', 'a', 'n', 't', '\n',
        'f', 'o', 'r', 'm', 'a', 't', '\n',
        'f', 'o', 'r', 'm', 'a', 't', 'e', 'd', '\n',
        'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', '\n',
        'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'f', 'o', 'r', 'm', 'a', 't', 'i', 'v', 'e', '\n',
        'f', 'o', 'r', 'm', 'a', 't', 's', '\n',
        'f', 'o', 'r', 'm', 'a', 't', 't', 'e', 'd', '\n',
        'f', 'o', 'r', 'm', 'a', 't', 't', 'i', 'n', 'g', '\n',
        'f', 'o', 'r', 'm', 'e', 'd', '\n',
        'f', 'o', 'r', 'm', 'e', 'r', '\n',
        'f', 'o', 'r', 'm', 'e', 'r', 'l', 'y', '\n',
        'f', 'o', 'r', 'm', 'e', 'r', 's', '\n',
        'f', 'o', 'r', 'm', 'i', 'c', '\n',
        'f', 'o', 'r', 'm', 'i', 'd', 'a', 'b', 'l', 'e', '\n',
        'f', 'o', 'r', 'm', 'i', 'd', 'a', 'b', 'l', 'y', '\n',
        'f', 'o', 'r', 'm', 'i', 'n', 'g', '\n',
        'f', 'o', 'r', 'm', 'l', 'e', 's', 's', '\n',
        'f', 'o', 'r', 'm', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'f', 'o', 'r', 'm', 'o', 's', 'a', '\n',
        'f', 'o', 'r', 'm', 's', '\n',
        'f', 'o', 'r', 'm', 'u', 'l', 'a', '\n',
        'f', 'o', 'r', 'm', 'u', 'l', 'a', 'e', '\n',
        'f', 'o', 'r', 'm', 'u', 'l', 'a', 'i', 'c', '\n',
        'f', 'o', 'r', 'm', 'u', 'l', 'a', 'r', 'y', '\n',
        'f', 'o', 'r', 'm', 'u', 'l', 'a', 's', '\n',
        'f', 'o', 'r', 'm', 'u', 'l', 'a', 't', 'e', '\n',
        'f', 'o', 'r', 'm', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'f', 'o', 'r', 'm', 'u', 'l', 'a', 't', 'e', 's', '\n',
        'f', 'o', 'r', 'm', 'u', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'f', 'o', 'r', 'm', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'f', 'o', 'r', 'm', 'u', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'f', 'o', 'r', 'm', 'u', 'l', 'a', 't', 'o', 'r', '\n',
        'f', 'o', 'r', 'n', 'i', 'c', 'a', 't', 'e', '\n',
        'f', 'o', 'r', 'n', 'i', 'c', 'a', 't', 'e', 'd', '\n',
        'f', 'o', 'r', 'n', 'i', 'c', 'a', 't', 'e', 's', '\n',
        'f', 'o', 'r', 'n', 'i', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'f', 'o', 'r', 'n', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'f', 'o', 'r', 'n', 'i', 'c', 'a', 't', 'o', 'r', '\n',
        'f', 'o', 'r', 'n', 'i', 'c', 'a', 't', 'o', 'r', 's', '\n',
        'f', 'o', 'r', 's', 'a', 'k', 'e', '\n',
        'f', 'o', 'r', 's', 'a', 'k', 'e', 'n', '\n',
        'f', 'o', 'r', 's', 'a', 'k', 'e', 's', '\n',
        'f', 'o', 'r', 's', 'a', 'k', 'i', 'n', 'g', '\n',
        'f', 'o', 'r', 's', 'o', 'o', 'k', '\n',
        'f', 'o', 'r', 's', 'w', 'e', 'a', 'r', '\n',
        'f', 'o', 'r', 's', 'w', 'e', 'a', 'r', 'i', 'n', 'g', '\n',
        'f', 'o', 'r', 's', 'w', 'o', 'r', 'e', '\n',
        'f', 'o', 'r', 's', 'w', 'o', 'r', 'n', '\n',
        'f', 'o', 'r', 's', 'y', 't', 'h', 'i', 'a', '\n',
        'f', 'o', 'r', 't', '\n',
        'f', 'o', 'r', 't', 'e', '\n',
        'f', 'o', 'r', 't', 'h', '\n',
        'f', 'o', 'r', 't', 'h', 'c', 'o', 'm', 'i', 'n', 'g', '\n',
        'f', 'o', 'r', 't', 'h', 'r', 'i', 'g', 'h', 't', '\n',
        'f', 'o', 'r', 't', 'h', 'r', 'i', 'g', 'h', 't', 'l', 'y', '\n',
        'f', 'o', 'r', 't', 'h', 'r', 'i', 'g', 'h', 't', 'n', 'e', 's', 's', '\n',
        'f', 'o', 'r', 't', 'h', 'w', 'i', 't', 'h', '\n',
        'f', 'o', 'r', 't', 'i', 'e', 's', '\n',
        'f', 'o', 'r', 't', 'i', 'e', 't', 'h', '\n',
        'f', 'o', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'f', 'o', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'f', 'o', 'r', 't', 'i', 'f', 'i', 'e', 'd', '\n',
        'f', 'o', 'r', 't', 'i', 'f', 'y', '\n',
        'f', 'o', 'r', 't', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'f', 'o', 'r', 't', 'i', 's', 's', 'i', 'm', 'o', '\n',
        'f', 'o', 'r', 't', 'i', 't', 'u', 'd', 'e', '\n',
        'f', 'o', 'r', 't', 'k', 'n', 'o', 'x', '\n',
        'f', 'o', 'r', 't', 'n', 'i', 'g', 'h', 't', '\n',
        'f', 'o', 'r', 't', 'n', 'i', 'g', 'h', 't', 'l', 'y', '\n',
        'f', 'o', 'r', 't', 'n', 'i', 'g', 'h', 't', 's', '\n',
        'f', 'o', 'r', 't', 'r', 'e', 's', 's', '\n',
        'f', 'o', 'r', 't', 'r', 'e', 's', 's', 'e', 's', '\n',
        'f', 'o', 'r', 't', 's', '\n',
        'f', 'o', 'r', 't', 'u', 'i', 't', 'o', 'u', 's', '\n',
        'f', 'o', 'r', 't', 'u', 'i', 't', 'o', 'u', 's', 'l', 'y', '\n',
        'f', 'o', 'r', 't', 'u', 'n', 'a', 't', 'e', '\n',
        'f', 'o', 'r', 't', 'u', 'n', 'a', 't', 'e', 'l', 'y', '\n',
        'f', 'o', 'r', 't', 'u', 'n', 'e', '\n',
        'f', 'o', 'r', 't', 'u', 'n', 'e', 's', '\n',
        'f', 'o', 'r', 't', 'u', 'n', 'e', 't', 'e', 'l', 'l', 'e', 'r', '\n',
        'f', 'o', 'r', 't', 'u', 'n', 'e', 't', 'e', 'l', 'l', 'e', 'r', 's', '\n',
        'f', 'o', 'r', 't', 'u', 'n', 'e', 't', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'f', 'o', 'r', 't', 'y', '\n',
        'f', 'o', 'r', 'u', 'm', '\n',
        'f', 'o', 'r', 'u', 'm', 's', '\n',
        'f', 'o', 'r', 'w', 'a', 'r', 'd', '\n',
        'f', 'o', 'r', 'w', 'a', 'r', 'd', 'e', 'd', '\n',
        'f', 'o', 'r', 'w', 'a', 'r', 'd', 'e', 'r', '\n',
        'f', 'o', 'r', 'w', 'a', 'r', 'd', 'i', 'n', 'g', '\n',
        'f', 'o', 'r', 'w', 'a', 'r', 'd', 'l', 'o', 'o', 'k', 'i', 'n', 'g', '\n',
        'f', 'o', 'r', 'w', 'a', 'r', 'd', 'l', 'y', '\n',
        'f', 'o', 'r', 'w', 'a', 'r', 'd', 'n', 'e', 's', 's', '\n',
        'f', 'o', 'r', 'w', 'a', 'r', 'd', 's', '\n',
        'f', 'o', 's', 's', 'a', '\n',
        'f', 'o', 's', 's', 'i', 'l', '\n',
        'f', 'o', 's', 's', 'i', 'l', 'i', 'f', 'e', 'r', 'o', 'u', 's', '\n',
        'f', 'o', 's', 's', 'i', 'l', 'i', 's', 'e', '\n',
        'f', 'o', 's', 's', 'i', 'l', 'i', 's', 'e', 'd', '\n',
        'f', 'o', 's', 's', 'i', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'f', 'o', 's', 's', 'i', 'l', 's', '\n',
        'f', 'o', 's', 't', 'e', 'r', '\n',
        'f', 'o', 's', 't', 'e', 'r', 'e', 'd', '\n',
        'f', 'o', 's', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'f', 'o', 's', 't', 'e', 'r', 's', '\n',
        'f', 'o', 'u', 'g', 'h', 't', '\n',
        'f', 'o', 'u', 'l', '\n',
        'f', 'o', 'u', 'l', 'e', 'd', '\n',
        'f', 'o', 'u', 'l', 'e', 'r', '\n',
        'f', 'o', 'u', 'l', 'e', 's', 't', '\n',
        'f', 'o', 'u', 'l', 'i', 'n', 'g', '\n',
        'f', 'o', 'u', 'l', 'l', 'y', '\n',
        'f', 'o', 'u', 'l', 'm', 'o', 'u', 't', 'h', 'e', 'd', '\n',
        'f', 'o', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'f', 'o', 'u', 'l', 's', '\n',
        'f', 'o', 'u', 'l', 'u', 'p', '\n',
        'f', 'o', 'u', 'l', 'u', 'p', 's', '\n',
        'f', 'o', 'u', 'n', 'd', '\n',
        'f', 'o', 'u', 'n', 'd', 'a', 't', 'i', 'o', 'n', '\n',
        'f', 'o', 'u', 'n', 'd', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'f', 'o', 'u', 'n', 'd', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'f', 'o', 'u', 'n', 'd', 'e', 'd', '\n',
        'f', 'o', 'u', 'n', 'd', 'e', 'r', '\n',
        'f', 'o', 'u', 'n', 'd', 'e', 'r', 'e', 'd', '\n',
        'f', 'o', 'u', 'n', 'd', 'e', 'r', 'i', 'n', 'g', '\n',
        'f', 'o', 'u', 'n', 'd', 'e', 'r', 's', '\n',
        'f', 'o', 'u', 'n', 'd', 'i', 'n', 'g', '\n',
        'f', 'o', 'u', 'n', 'd', 'l', 'i', 'n', 'g', '\n',
        'f', 'o', 'u', 'n', 'd', 'r', 'i', 'e', 's', '\n',
        'f', 'o', 'u', 'n', 'd', 'r', 'y', '\n',
        'f', 'o', 'u', 'n', 'd', 's', '\n',
        'f', 'o', 'u', 'n', 't', '\n',
        'f', 'o', 'u', 'n', 't', 'a', 'i', 'n', '\n',
        'f', 'o', 'u', 'n', 't', 'a', 'i', 'n', 's', '\n',
        'f', 'o', 'u', 'n', 't', 's', '\n',
        'f', 'o', 'u', 'r', '\n',
        'f', 'o', 'u', 'r', 'f', 'o', 'l', 'd', '\n',
        'f', 'o', 'u', 'r', 's', '\n',
        'f', 'o', 'u', 'r', 's', 'o', 'm', 'e', '\n',
        'f', 'o', 'u', 'r', 't', 'e', 'e', 'n', '\n',
        'f', 'o', 'u', 'r', 't', 'e', 'e', 'n', 't', 'h', '\n',
        'f', 'o', 'u', 'r', 't', 'h', '\n',
        'f', 'o', 'u', 'r', 't', 'h', 'l', 'y', '\n',
        'f', 'o', 'u', 'r', 't', 'h', 's', '\n',
        'f', 'o', 'w', 'l', '\n',
        'f', 'o', 'w', 'l', 's', '\n',
        'f', 'o', 'x', '\n',
        'f', 'o', 'x', 'e', 'd', '\n',
        'f', 'o', 'x', 'e', 's', '\n',
        'f', 'o', 'x', 'h', 'o', 'l', 'e', '\n',
        'f', 'o', 'x', 'h', 'o', 'l', 'e', 's', '\n',
        'f', 'o', 'x', 'h', 'o', 'u', 'n', 'd', 's', '\n',
        'f', 'o', 'x', 'h', 'u', 'n', 't', '\n',
        'f', 'o', 'x', 'h', 'u', 'n', 't', 'i', 'n', 'g', '\n',
        'f', 'o', 'x', 'h', 'u', 'n', 't', 's', '\n',
        'f', 'o', 'x', 'i', 'e', 'r', '\n',
        'f', 'o', 'x', 'i', 'e', 's', 't', '\n',
        'f', 'o', 'x', 'i', 'l', 'y', '\n',
        'f', 'o', 'x', 'i', 'n', 'e', 's', 's', '\n',
        'f', 'o', 'x', 'i', 'n', 'g', '\n',
        'f', 'o', 'x', 't', 'r', 'o', 't', '\n',
        'f', 'o', 'x', 't', 'r', 'o', 't', 's', '\n',
        'f', 'o', 'x', 'y', '\n',
        'f', 'o', 'y', 'e', 'r', '\n',
        'f', 'o', 'y', 'e', 'r', 's', '\n',
        'f', 'r', 'a', 'c', 'a', 's', '\n',
        'f', 'r', 'a', 'c', 't', 'a', 'l', '\n',
        'f', 'r', 'a', 'c', 't', 'a', 'l', 's', '\n',
        'f', 'r', 'a', 'c', 't', 'i', 'o', 'n', '\n',
        'f', 'r', 'a', 'c', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'f', 'r', 'a', 'c', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'f', 'r', 'a', 'c', 't', 'i', 'o', 'n', 'a', 't', 'e', '\n',
        'f', 'r', 'a', 'c', 't', 'i', 'o', 'n', 'a', 't', 'e', 'd', '\n',
        'f', 'r', 'a', 'c', 't', 'i', 'o', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'f', 'r', 'a', 'c', 't', 'i', 'o', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'f', 'r', 'a', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'f', 'r', 'a', 'c', 't', 'i', 'o', 'u', 's', '\n',
        'f', 'r', 'a', 'c', 't', 'u', 'r', 'e', '\n',
        'f', 'r', 'a', 'c', 't', 'u', 'r', 'e', 'd', '\n',
        'f', 'r', 'a', 'c', 't', 'u', 'r', 'e', 's', '\n',
        'f', 'r', 'a', 'c', 't', 'u', 'r', 'i', 'n', 'g', '\n',
        'f', 'r', 'a', 'g', 'i', 'l', 'e', '\n',
        'f', 'r', 'a', 'g', 'i', 'l', 'i', 't', 'y', '\n',
        'f', 'r', 'a', 'g', 'm', 'e', 'n', 't', '\n',
        'f', 'r', 'a', 'g', 'm', 'e', 'n', 't', 'a', 'r', 'y', '\n',
        'f', 'r', 'a', 'g', 'm', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'f', 'r', 'a', 'g', 'm', 'e', 'n', 't', 'e', 'd', '\n',
        'f', 'r', 'a', 'g', 'm', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'f', 'r', 'a', 'g', 'm', 'e', 'n', 't', 's', '\n',
        'f', 'r', 'a', 'g', 'r', 'a', 'n', 'c', 'e', '\n',
        'f', 'r', 'a', 'g', 'r', 'a', 'n', 'c', 'e', 's', '\n',
        'f', 'r', 'a', 'g', 'r', 'a', 'n', 't', '\n',
        'f', 'r', 'a', 'i', 'l', '\n',
        'f', 'r', 'a', 'i', 'l', 'e', 'r', '\n',
        'f', 'r', 'a', 'i', 'l', 'e', 's', 't', '\n',
        'f', 'r', 'a', 'i', 'l', 'l', 'y', '\n',
        'f', 'r', 'a', 'i', 'l', 't', 'i', 'e', 's', '\n',
        'f', 'r', 'a', 'i', 'l', 't', 'y', '\n',
        'f', 'r', 'a', 'm', 'e', '\n',
        'f', 'r', 'a', 'm', 'e', 'd', '\n',
        'f', 'r', 'a', 'm', 'e', 'r', '\n',
        'f', 'r', 'a', 'm', 'e', 'r', 's', '\n',
        'f', 'r', 'a', 'm', 'e', 's', '\n',
        'f', 'r', 'a', 'm', 'e', 'u', 'p', '\n',
        'f', 'r', 'a', 'm', 'e', 'w', 'o', 'r', 'k', '\n',
        'f', 'r', 'a', 'm', 'e', 'w', 'o', 'r', 'k', 's', '\n',
        'f', 'r', 'a', 'm', 'i', 'n', 'g', '\n',
        'f', 'r', 'a', 'n', 'c', '\n',
        'f', 'r', 'a', 'n', 'c', 'e', '\n',
        'f', 'r', 'a', 'n', 'c', 'h', 'i', 's', 'e', '\n',
        'f', 'r', 'a', 'n', 'c', 'h', 'i', 's', 'e', 'd', '\n',
        'f', 'r', 'a', 'n', 'c', 'h', 'i', 's', 'e', 'e', '\n',
        'f', 'r', 'a', 'n', 'c', 'h', 'i', 's', 'e', 'e', 's', '\n',
        'f', 'r', 'a', 'n', 'c', 'h', 'i', 's', 'e', 's', '\n',
        'f', 'r', 'a', 'n', 'c', 'h', 'i', 's', 'i', 'n', 'g', '\n',
        'f', 'r', 'a', 'n', 'c', 'h', 'i', 's', 'o', 'r', '\n',
        'f', 'r', 'a', 'n', 'c', 'o', 'p', 'h', 'o', 'n', 'e', '\n',
        'f', 'r', 'a', 'n', 'c', 's', '\n',
        'f', 'r', 'a', 'n', 'g', 'i', 'p', 'a', 'n', 'i', '\n',
        'f', 'r', 'a', 'n', 'k', '\n',
        'f', 'r', 'a', 'n', 'k', 'e', 'd', '\n',
        'f', 'r', 'a', 'n', 'k', 'e', 'r', '\n',
        'f', 'r', 'a', 'n', 'k', 'e', 's', 't', '\n',
        'f', 'r', 'a', 'n', 'k', 'f', 'u', 'r', 't', 'e', 'r', '\n',
        'f', 'r', 'a', 'n', 'k', 'i', 'n', 'c', 'e', 'n', 's', 'e', '\n',
        'f', 'r', 'a', 'n', 'k', 'i', 'n', 'g', '\n',
        'f', 'r', 'a', 'n', 'k', 'l', 'y', '\n',
        'f', 'r', 'a', 'n', 'k', 'n', 'e', 's', 's', '\n',
        'f', 'r', 'a', 'n', 'k', 's', '\n',
        'f', 'r', 'a', 'n', 't', 'i', 'c', '\n',
        'f', 'r', 'a', 'n', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'f', 'r', 'a', 't', 'e', 'r', 'n', 'a', 'l', '\n',
        'f', 'r', 'a', 't', 'e', 'r', 'n', 'i', 's', 'e', '\n',
        'f', 'r', 'a', 't', 'e', 'r', 'n', 'i', 's', 'i', 'n', 'g', '\n',
        'f', 'r', 'a', 't', 'e', 'r', 'n', 'i', 't', 'i', 'e', 's', '\n',
        'f', 'r', 'a', 't', 'e', 'r', 'n', 'i', 't', 'y', '\n',
        'f', 'r', 'a', 't', 'r', 'i', 'c', 'i', 'd', 'a', 'l', '\n',
        'f', 'r', 'a', 't', 'r', 'i', 'c', 'i', 'd', 'e', '\n',
        'f', 'r', 'a', 'u', 'd', '\n',
        'f', 'r', 'a', 'u', 'd', 's', '\n',
        'f', 'r', 'a', 'u', 'd', 's', 't', 'e', 'r', '\n',
        'f', 'r', 'a', 'u', 'd', 's', 't', 'e', 'r', 's', '\n',
        'f', 'r', 'a', 'u', 'd', 'u', 'l', 'e', 'n', 't', '\n',
        'f', 'r', 'a', 'u', 'd', 'u', 'l', 'e', 'n', 't', 'l', 'y', '\n',
        'f', 'r', 'a', 'u', 'g', 'h', 't', '\n',
        'f', 'r', 'a', 'y', '\n',
        'f', 'r', 'a', 'y', 'e', 'd', '\n',
        'f', 'r', 'a', 'y', 'i', 'n', 'g', '\n',
        'f', 'r', 'a', 'y', 's', '\n',
        'f', 'r', 'a', 'z', 'z', 'l', 'e', '\n',
        'f', 'r', 'a', 'z', 'z', 'l', 'e', 'd', '\n',
        'f', 'r', 'e', 'a', 'k', '\n',
        'f', 'r', 'e', 'a', 'k', 'e', 'd', '\n',
        'f', 'r', 'e', 'a', 'k', 'i', 's', 'h', '\n',
        'f', 'r', 'e', 'a', 'k', 's', '\n',
        'f', 'r', 'e', 'a', 'k', 'y', '\n',
        'f', 'r', 'e', 'c', 'k', 'l', 'e', '\n',
        'f', 'r', 'e', 'c', 'k', 'l', 'e', 'd', '\n',
        'f', 'r', 'e', 'c', 'k', 'l', 'e', 's', '\n',
        'f', 'r', 'e', 'e', '\n',
        'f', 'r', 'e', 'e', 'b', 'i', 'e', '\n',
        'f', 'r', 'e', 'e', 'b', 'o', 'o', 't', 'e', 'r', 's', '\n',
        'f', 'r', 'e', 'e', 'd', '\n',
        'f', 'r', 'e', 'e', 'd', 'o', 'm', '\n',
        'f', 'r', 'e', 'e', 'd', 'o', 'm', 's', '\n',
        'f', 'r', 'e', 'e', 'f', 'a', 'l', 'l', '\n',
        'f', 'r', 'e', 'e', 'f', 'a', 'l', 'l', 'i', 'n', 'g', '\n',
        'f', 'r', 'e', 'e', 'f', 'o', 'r', 'a', 'l', 'l', '\n',
        'f', 'r', 'e', 'e', 'h', 'a', 'n', 'd', '\n',
        'f', 'r', 'e', 'e', 'h', 'o', 'l', 'd', '\n',
        'f', 'r', 'e', 'e', 'h', 'o', 'l', 'd', 'e', 'r', '\n',
        'f', 'r', 'e', 'e', 'h', 'o', 'l', 'd', 'e', 'r', 's', '\n',
        'f', 'r', 'e', 'e', 'h', 'o', 'l', 'd', 's', '\n',
        'f', 'r', 'e', 'e', 'i', 'n', 'g', '\n',
        'f', 'r', 'e', 'e', 'l', 'a', 'n', 'c', 'e', '\n',
        'f', 'r', 'e', 'e', 'l', 'a', 'n', 'c', 'e', 'r', '\n',
        'f', 'r', 'e', 'e', 'l', 'a', 'n', 'c', 'e', 'r', 's', '\n',
        'f', 'r', 'e', 'e', 'l', 'a', 'n', 'c', 'e', 's', '\n',
        'f', 'r', 'e', 'e', 'l', 'a', 'n', 'c', 'i', 'n', 'g', '\n',
        'f', 'r', 'e', 'e', 'l', 'y', '\n',
        'f', 'r', 'e', 'e', 'm', 'a', 'n', '\n',
        'f', 'r', 'e', 'e', 'm', 'a', 's', 'o', 'n', 'r', 'y', '\n',
        'f', 'r', 'e', 'e', 'm', 'e', 'n', '\n',
        'f', 'r', 'e', 'e', 'r', '\n',
        'f', 'r', 'e', 'e', 'r', 'a', 'n', 'g', 'e', '\n',
        'f', 'r', 'e', 'e', 's', '\n',
        'f', 'r', 'e', 'e', 's', 'i', 'a', '\n',
        'f', 'r', 'e', 'e', 's', 'i', 'a', 's', '\n',
        'f', 'r', 'e', 'e', 's', 't', 'a', 'n', 'd', 'i', 'n', 'g', '\n',
        'f', 'r', 'e', 'e', 's', 't', 'y', 'l', 'e', '\n',
        'f', 'r', 'e', 'e', 'w', 'a', 'y', '\n',
        'f', 'r', 'e', 'e', 'w', 'h', 'e', 'e', 'l', 'i', 'n', 'g', '\n',
        'f', 'r', 'e', 'e', 'w', 'h', 'e', 'e', 'l', 's', '\n',
        'f', 'r', 'e', 'e', 'z', 'e', '\n',
        'f', 'r', 'e', 'e', 'z', 'e', 'r', '\n',
        'f', 'r', 'e', 'e', 'z', 'e', 'r', 's', '\n',
        'f', 'r', 'e', 'e', 'z', 'e', 's', '\n',
        'f', 'r', 'e', 'e', 'z', 'i', 'n', 'g', '\n',
        'f', 'r', 'e', 'i', 'g', 'h', 't', '\n',
        'f', 'r', 'e', 'i', 'g', 'h', 't', 'e', 'd', '\n',
        'f', 'r', 'e', 'i', 'g', 'h', 't', 'e', 'r', '\n',
        'f', 'r', 'e', 'i', 'g', 'h', 't', 'e', 'r', 's', '\n',
        'f', 'r', 'e', 'i', 'g', 'h', 't', 's', '\n',
        'f', 'r', 'e', 'n', 'c', 'h', '\n',
        'f', 'r', 'e', 'n', 'e', 't', 'i', 'c', '\n',
        'f', 'r', 'e', 'n', 'e', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'f', 'r', 'e', 'n', 'z', 'i', 'e', 'd', '\n',
        'f', 'r', 'e', 'n', 'z', 'i', 'e', 'd', 'l', 'y', '\n',
        'f', 'r', 'e', 'n', 'z', 'i', 'e', 's', '\n',
        'f', 'r', 'e', 'n', 'z', 'y', '\n',
        'f', 'r', 'e', 'o', 'n', '\n',
        'f', 'r', 'e', 'o', 'n', 's', '\n',
        'f', 'r', 'e', 'q', 'u', 'e', 'n', 'c', 'i', 'e', 's', '\n',
        'f', 'r', 'e', 'q', 'u', 'e', 'n', 'c', 'y', '\n',
        'f', 'r', 'e', 'q', 'u', 'e', 'n', 't', '\n',
        'f', 'r', 'e', 'q', 'u', 'e', 'n', 't', 'e', 'd', '\n',
        'f', 'r', 'e', 'q', 'u', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'f', 'r', 'e', 'q', 'u', 'e', 'n', 't', 'l', 'y', '\n',
        'f', 'r', 'e', 'q', 'u', 'e', 'n', 't', 's', '\n',
        'f', 'r', 'e', 's', 'c', 'o', '\n',
        'f', 'r', 'e', 's', 'h', '\n',
        'f', 'r', 'e', 's', 'h', 'e', 'n', '\n',
        'f', 'r', 'e', 's', 'h', 'e', 'n', 'e', 'd', '\n',
        'f', 'r', 'e', 's', 'h', 'e', 'n', 'e', 'r', '\n',
        'f', 'r', 'e', 's', 'h', 'e', 'n', 'e', 'r', 's', '\n',
        'f', 'r', 'e', 's', 'h', 'e', 'n', 'i', 'n', 'g', '\n',
        'f', 'r', 'e', 's', 'h', 'e', 'n', 's', '\n',
        'f', 'r', 'e', 's', 'h', 'e', 'r', '\n',
        'f', 'r', 'e', 's', 'h', 'e', 'r', 's', '\n',
        'f', 'r', 'e', 's', 'h', 'e', 's', 't', '\n',
        'f', 'r', 'e', 's', 'h', 'l', 'y', '\n',
        'f', 'r', 'e', 's', 'h', 'm', 'a', 'n', '\n',
        'f', 'r', 'e', 's', 'h', 'm', 'e', 'n', '\n',
        'f', 'r', 'e', 's', 'h', 'n', 'e', 's', 's', '\n',
        'f', 'r', 'e', 's', 'h', 'w', 'a', 't', 'e', 'r', '\n',
        'f', 'r', 'e', 't', '\n',
        'f', 'r', 'e', 't', 'b', 'o', 'a', 'r', 'd', '\n',
        'f', 'r', 'e', 't', 'f', 'u', 'l', '\n',
        'f', 'r', 'e', 't', 'f', 'u', 'l', 'l', 'y', '\n',
        'f', 'r', 'e', 't', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'f', 'r', 'e', 't', 'l', 'e', 's', 's', '\n',
        'f', 'r', 'e', 't', 's', '\n',
        'f', 'r', 'e', 't', 's', 'a', 'w', '\n',
        'f', 'r', 'e', 't', 's', 'a', 'w', 's', '\n',
        'f', 'r', 'e', 't', 't', 'e', 'd', '\n',
        'f', 'r', 'e', 't', 't', 'i', 'n', 'g', '\n',
        'f', 'r', 'e', 't', 'w', 'o', 'r', 'k', '\n',
        'f', 'r', 'e', 'u', 'd', '\n',
        'f', 'r', 'e', 'y', 'a', '\n',
        'f', 'r', 'i', 'a', 'b', 'l', 'e', '\n',
        'f', 'r', 'i', 'a', 'r', '\n',
        'f', 'r', 'i', 'a', 'r', 's', '\n',
        'f', 'r', 'i', 'a', 'r', 'y', '\n',
        'f', 'r', 'i', 'c', 'a', 't', 'i', 'v', 'e', '\n',
        'f', 'r', 'i', 'c', 'a', 't', 'i', 'v', 'e', 's', '\n',
        'f', 'r', 'i', 'c', 't', 'i', 'o', 'n', '\n',
        'f', 'r', 'i', 'c', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'f', 'r', 'i', 'c', 't', 'i', 'o', 'n', 'l', 'e', 's', 's', '\n',
        'f', 'r', 'i', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'f', 'r', 'i', 'd', 'a', 'y', '\n',
        'f', 'r', 'i', 'd', 'a', 'y', 's', '\n',
        'f', 'r', 'i', 'd', 'g', 'e', '\n',
        'f', 'r', 'i', 'd', 'g', 'e', 's', '\n',
        'f', 'r', 'i', 'e', 'd', '\n',
        'f', 'r', 'i', 'e', 'n', 'd', '\n',
        'f', 'r', 'i', 'e', 'n', 'd', 'l', 'e', 's', 's', '\n',
        'f', 'r', 'i', 'e', 'n', 'd', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'f', 'r', 'i', 'e', 'n', 'd', 'l', 'i', 'e', 'r', '\n',
        'f', 'r', 'i', 'e', 'n', 'd', 'l', 'i', 'e', 's', '\n',
        'f', 'r', 'i', 'e', 'n', 'd', 'l', 'i', 'e', 's', 't', '\n',
        'f', 'r', 'i', 'e', 'n', 'd', 'l', 'i', 'l', 'y', '\n',
        'f', 'r', 'i', 'e', 'n', 'd', 'l', 'i', 'n', 'e', 's', 's', '\n',
        'f', 'r', 'i', 'e', 'n', 'd', 'l', 'y', '\n',
        'f', 'r', 'i', 'e', 'n', 'd', 's', '\n',
        'f', 'r', 'i', 'e', 'n', 'd', 's', 'h', 'i', 'p', '\n',
        'f', 'r', 'i', 'e', 'n', 'd', 's', 'h', 'i', 'p', 's', '\n',
        'f', 'r', 'i', 'e', 'r', 's', '\n',
        'f', 'r', 'i', 'e', 's', '\n',
        'f', 'r', 'i', 'e', 'z', 'e', '\n',
        'f', 'r', 'i', 'e', 'z', 'e', 's', '\n',
        'f', 'r', 'i', 'g', 'a', 't', 'e', '\n',
        'f', 'r', 'i', 'g', 'a', 't', 'e', 's', '\n',
        'f', 'r', 'i', 'g', 'h', 't', '\n',
        'f', 'r', 'i', 'g', 'h', 't', 'e', 'd', '\n',
        'f', 'r', 'i', 'g', 'h', 't', 'e', 'n', '\n',
        'f', 'r', 'i', 'g', 'h', 't', 'e', 'n', 'e', 'd', '\n',
        'f', 'r', 'i', 'g', 'h', 't', 'e', 'n', 'e', 'r', 's', '\n',
        'f', 'r', 'i', 'g', 'h', 't', 'e', 'n', 'i', 'n', 'g', '\n',
        'f', 'r', 'i', 'g', 'h', 't', 'e', 'n', 'i', 'n', 'g', 'l', 'y', '\n',
        'f', 'r', 'i', 'g', 'h', 't', 'e', 'n', 's', '\n',
        'f', 'r', 'i', 'g', 'h', 't', 'f', 'u', 'l', '\n',
        'f', 'r', 'i', 'g', 'h', 't', 'f', 'u', 'l', 'l', 'y', '\n',
        'f', 'r', 'i', 'g', 'h', 't', 's', '\n',
        'f', 'r', 'i', 'g', 'i', 'd', '\n',
        'f', 'r', 'i', 'g', 'i', 'd', 'i', 't', 'y', '\n',
        'f', 'r', 'i', 'g', 'i', 'd', 'l', 'y', '\n',
        'f', 'r', 'i', 'j', 'o', 'l', 'e', '\n',
        'f', 'r', 'i', 'l', 'l', '\n',
        'f', 'r', 'i', 'l', 'l', 'e', 'd', '\n',
        'f', 'r', 'i', 'l', 'l', 'i', 'e', 'r', '\n',
        'f', 'r', 'i', 'l', 'l', 'i', 'e', 's', 't', '\n',
        'f', 'r', 'i', 'l', 'l', 's', '\n',
        'f', 'r', 'i', 'l', 'l', 'y', '\n',
        'f', 'r', 'i', 'n', 'g', 'e', '\n',
        'f', 'r', 'i', 'n', 'g', 'e', 'd', '\n',
        'f', 'r', 'i', 'n', 'g', 'e', 's', '\n',
        'f', 'r', 'i', 'n', 'g', 'i', 'n', 'g', '\n',
        'f', 'r', 'i', 'n', 'g', 'y', '\n',
        'f', 'r', 'i', 'p', 'p', 'e', 'r', 'y', '\n',
        'f', 'r', 'i', 's', 'k', '\n',
        'f', 'r', 'i', 's', 'k', 'e', 'd', '\n',
        'f', 'r', 'i', 's', 'k', 'i', 'e', 'r', '\n',
        'f', 'r', 'i', 's', 'k', 'i', 'e', 's', 't', '\n',
        'f', 'r', 'i', 's', 'k', 'i', 'l', 'y', '\n',
        'f', 'r', 'i', 's', 'k', 'i', 'n', 'g', '\n',
        'f', 'r', 'i', 's', 'k', 's', '\n',
        'f', 'r', 'i', 's', 'k', 'y', '\n',
        'f', 'r', 'i', 's', 's', 'o', 'n', '\n',
        'f', 'r', 'i', 't', 't', 'e', 'r', '\n',
        'f', 'r', 'i', 't', 't', 'e', 'r', 'e', 'd', '\n',
        'f', 'r', 'i', 't', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'f', 'r', 'i', 't', 't', 'e', 'r', 's', '\n',
        'f', 'r', 'i', 'v', 'o', 'l', '\n',
        'f', 'r', 'i', 'v', 'o', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'f', 'r', 'i', 'v', 'o', 'l', 'i', 't', 'y', '\n',
        'f', 'r', 'i', 'v', 'o', 'l', 'o', 'u', 's', '\n',
        'f', 'r', 'i', 'v', 'o', 'l', 'o', 'u', 's', 'l', 'y', '\n',
        'f', 'r', 'i', 'v', 'o', 'l', 's', '\n',
        'f', 'r', 'i', 'z', 'z', 'l', 'e', '\n',
        'f', 'r', 'i', 'z', 'z', 'l', 'e', 's', '\n',
        'f', 'r', 'i', 'z', 'z', 'y', '\n',
        'f', 'r', 'o', '\n',
        'f', 'r', 'o', 'c', 'k', '\n',
        'f', 'r', 'o', 'c', 'k', 's', '\n',
        'f', 'r', 'o', 'g', '\n',
        'f', 'r', 'o', 'g', 'g', 'y', '\n',
        'f', 'r', 'o', 'g', 'm', 'a', 'n', '\n',
        'f', 'r', 'o', 'g', 'm', 'a', 'r', 'c', 'h', 'e', 'd', '\n',
        'f', 'r', 'o', 'g', 'm', 'e', 'n', '\n',
        'f', 'r', 'o', 'g', 's', '\n',
        'f', 'r', 'o', 'l', 'i', 'c', '\n',
        'f', 'r', 'o', 'l', 'i', 'c', 'k', 'e', 'd', '\n',
        'f', 'r', 'o', 'l', 'i', 'c', 'k', 'i', 'n', 'g', '\n',
        'f', 'r', 'o', 'l', 'i', 'c', 's', '\n',
        'f', 'r', 'o', 'l', 'i', 'c', 's', 'o', 'm', 'e', '\n',
        'f', 'r', 'o', 'm', '\n',
        'f', 'r', 'o', 'n', 'd', '\n',
        'f', 'r', 'o', 'n', 'd', 's', '\n',
        'f', 'r', 'o', 'n', 't', '\n',
        'f', 'r', 'o', 'n', 't', 'a', 'g', 'e', '\n',
        'f', 'r', 'o', 'n', 't', 'a', 'g', 'e', 's', '\n',
        'f', 'r', 'o', 'n', 't', 'a', 'l', '\n',
        'f', 'r', 'o', 'n', 't', 'a', 'l', 'l', 'y', '\n',
        'f', 'r', 'o', 'n', 't', 'a', 'l', 's', '\n',
        'f', 'r', 'o', 'n', 't', 'e', 'd', '\n',
        'f', 'r', 'o', 'n', 't', 'i', 'e', 'r', '\n',
        'f', 'r', 'o', 'n', 't', 'i', 'e', 'r', 's', '\n',
        'f', 'r', 'o', 'n', 't', 'i', 'n', 'g', '\n',
        'f', 'r', 'o', 'n', 't', 'i', 's', 'p', 'i', 'e', 'c', 'e', '\n',
        'f', 'r', 'o', 'n', 't', 'i', 's', 'p', 'i', 'e', 'c', 'e', 's', '\n',
        'f', 'r', 'o', 'n', 't', 'l', 'i', 'n', 'e', '\n',
        'f', 'r', 'o', 'n', 't', 'p', 'a', 'g', 'e', '\n',
        'f', 'r', 'o', 'n', 't', 's', '\n',
        'f', 'r', 'o', 's', 't', '\n',
        'f', 'r', 'o', 's', 't', 'b', 'i', 't', 'e', '\n',
        'f', 'r', 'o', 's', 't', 'b', 'i', 't', 't', 'e', 'n', '\n',
        'f', 'r', 'o', 's', 't', 'e', 'd', '\n',
        'f', 'r', 'o', 's', 't', 'i', 'e', 'r', '\n',
        'f', 'r', 'o', 's', 't', 'i', 'e', 's', 't', '\n',
        'f', 'r', 'o', 's', 't', 'i', 'l', 'y', '\n',
        'f', 'r', 'o', 's', 't', 'i', 'n', 'g', '\n',
        'f', 'r', 'o', 's', 't', 's', '\n',
        'f', 'r', 'o', 's', 't', 'y', '\n',
        'f', 'r', 'o', 't', 'h', '\n',
        'f', 'r', 'o', 't', 'h', 'e', 'd', '\n',
        'f', 'r', 'o', 't', 'h', 'i', 'e', 'r', '\n',
        'f', 'r', 'o', 't', 'h', 'i', 'e', 's', 't', '\n',
        'f', 'r', 'o', 't', 'h', 'i', 'n', 'g', '\n',
        'f', 'r', 'o', 't', 'h', 's', '\n',
        'f', 'r', 'o', 't', 'h', 'y', '\n',
        'f', 'r', 'o', 'w', 'a', 'r', 'd', '\n',
        'f', 'r', 'o', 'w', 'n', '\n',
        'f', 'r', 'o', 'w', 'n', 'e', 'd', '\n',
        'f', 'r', 'o', 'w', 'n', 'i', 'n', 'g', '\n',
        'f', 'r', 'o', 'w', 'n', 'i', 'n', 'g', 'l', 'y', '\n',
        'f', 'r', 'o', 'w', 'n', 's', '\n',
        'f', 'r', 'o', 'z', 'e', '\n',
        'f', 'r', 'o', 'z', 'e', 'n', '\n',
        'f', 'r', 'u', 'c', 't', 'o', 's', 'e', '\n',
        'f', 'r', 'u', 'g', 'a', 'l', '\n',
        'f', 'r', 'u', 'g', 'a', 'l', 'i', 't', 'y', '\n',
        'f', 'r', 'u', 'g', 'a', 'l', 'l', 'y', '\n',
        'f', 'r', 'u', 'i', 't', '\n',
        'f', 'r', 'u', 'i', 't', 'c', 'a', 'k', 'e', '\n',
        'f', 'r', 'u', 'i', 't', 'c', 'a', 'k', 'e', 's', '\n',
        'f', 'r', 'u', 'i', 't', 'e', 'd', '\n',
        'f', 'r', 'u', 'i', 't', 'e', 'r', '\n',
        'f', 'r', 'u', 'i', 't', 'f', 'u', 'l', '\n',
        'f', 'r', 'u', 'i', 't', 'f', 'u', 'l', 'l', 'y', '\n',
        'f', 'r', 'u', 'i', 't', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'f', 'r', 'u', 'i', 't', 'i', 'e', 'r', '\n',
        'f', 'r', 'u', 'i', 't', 'i', 'e', 's', 't', '\n',
        'f', 'r', 'u', 'i', 't', 'i', 'n', 'e', 's', 's', '\n',
        'f', 'r', 'u', 'i', 't', 'i', 'n', 'g', '\n',
        'f', 'r', 'u', 'i', 't', 'i', 'o', 'n', '\n',
        'f', 'r', 'u', 'i', 't', 'l', 'e', 's', 's', '\n',
        'f', 'r', 'u', 'i', 't', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'f', 'r', 'u', 'i', 't', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'f', 'r', 'u', 'i', 't', 's', '\n',
        'f', 'r', 'u', 'i', 't', 'y', '\n',
        'f', 'r', 'u', 'm', 'p', 's', '\n',
        'f', 'r', 'u', 'm', 'p', 'y', '\n',
        'f', 'r', 'u', 's', 't', 'r', 'a', 't', 'e', '\n',
        'f', 'r', 'u', 's', 't', 'r', 'a', 't', 'e', 'd', '\n',
        'f', 'r', 'u', 's', 't', 'r', 'a', 't', 'e', 'd', 'l', 'y', '\n',
        'f', 'r', 'u', 's', 't', 'r', 'a', 't', 'e', 's', '\n',
        'f', 'r', 'u', 's', 't', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'f', 'r', 'u', 's', 't', 'r', 'a', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'f', 'r', 'u', 's', 't', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'f', 'r', 'u', 's', 't', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'f', 'r', 'u', 's', 't', 'u', 'm', '\n',
        'f', 'r', 'y', '\n',
        'f', 'r', 'y', 'e', 'r', '\n',
        'f', 'r', 'y', 'e', 'r', 's', '\n',
        'f', 'r', 'y', 'i', 'n', 'g', '\n',
        'f', 'r', 'y', 'i', 'n', 'g', 's', '\n',
        'f', 'u', 'c', 'h', 's', 'i', 'a', '\n',
        'f', 'u', 'c', 'h', 's', 'i', 'a', 's', '\n',
        'f', 'u', 'd', 'd', 'l', 'e', '\n',
        'f', 'u', 'd', 'd', 'l', 'e', 'd', '\n',
        'f', 'u', 'd', 'd', 'l', 'e', 's', '\n',
        'f', 'u', 'd', 'g', 'e', '\n',
        'f', 'u', 'd', 'g', 'e', 'd', '\n',
        'f', 'u', 'd', 'g', 'e', 's', '\n',
        'f', 'u', 'd', 'g', 'i', 'n', 'g', '\n',
        'f', 'u', 'e', 'l', '\n',
        'f', 'u', 'e', 'l', 'l', 'e', 'd', '\n',
        'f', 'u', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'f', 'u', 'e', 'l', 's', '\n',
        'f', 'u', 'g', '\n',
        'f', 'u', 'g', 'a', 'l', '\n',
        'f', 'u', 'g', 'i', 't', 'i', 'v', 'e', '\n',
        'f', 'u', 'g', 'i', 't', 'i', 'v', 'e', 's', '\n',
        'f', 'u', 'g', 'u', 'e', '\n',
        'f', 'u', 'g', 'u', 'e', 's', '\n',
        'f', 'u', 'h', 'r', 'e', 'r', '\n',
        'f', 'u', 'l', 'c', 'r', 'u', 'm', '\n',
        'f', 'u', 'l', 'f', 'i', 'l', '\n',
        'f', 'u', 'l', 'f', 'i', 'l', 'l', 'e', 'd', '\n',
        'f', 'u', 'l', 'f', 'i', 'l', 'l', 'i', 'n', 'g', '\n',
        'f', 'u', 'l', 'f', 'i', 'l', 'm', 'e', 'n', 't', '\n',
        'f', 'u', 'l', 'f', 'i', 'l', 's', '\n',
        'f', 'u', 'l', 'l', '\n',
        'f', 'u', 'l', 'l', 'b', 'a', 'c', 'k', '\n',
        'f', 'u', 'l', 'l', 'b', 'a', 'c', 'k', 's', '\n',
        'f', 'u', 'l', 'l', 'b', 'l', 'o', 'o', 'd', 'e', 'd', '\n',
        'f', 'u', 'l', 'l', 'b', 'l', 'o', 'w', 'n', '\n',
        'f', 'u', 'l', 'l', 'b', 'o', 'd', 'i', 'e', 'd', '\n',
        'f', 'u', 'l', 'l', 'c', 'o', 'l', 'o', 'u', 'r', '\n',
        'f', 'u', 'l', 'l', 'e', 'r', '\n',
        'f', 'u', 'l', 'l', 'e', 's', 't', '\n',
        'f', 'u', 'l', 'l', 'g', 'r', 'o', 'w', 'n', '\n',
        'f', 'u', 'l', 'l', 'i', 'n', 'g', '\n',
        'f', 'u', 'l', 'l', 'i', 's', 'h', '\n',
        'f', 'u', 'l', 'l', 'l', 'e', 'n', 'g', 't', 'h', '\n',
        'f', 'u', 'l', 'l', 'm', 'o', 'o', 'n', '\n',
        'f', 'u', 'l', 'l', 'n', 'e', 's', 's', '\n',
        'f', 'u', 'l', 'l', 'p', 'a', 'g', 'e', '\n',
        'f', 'u', 'l', 'l', 's', 'c', 'a', 'l', 'e', '\n',
        'f', 'u', 'l', 'l', 's', 't', 'o', 'p', '\n',
        'f', 'u', 'l', 'l', 's', 't', 'o', 'p', 's', '\n',
        'f', 'u', 'l', 'l', 't', 'i', 'm', 'e', '\n',
        'f', 'u', 'l', 'l', 't', 'i', 'm', 'e', 'r', '\n',
        'f', 'u', 'l', 'l', 't', 'i', 'm', 'e', 'r', 's', '\n',
        'f', 'u', 'l', 'l', 'y', '\n',
        'f', 'u', 'l', 'm', 'i', 'n', 'a', 'n', 't', '\n',
        'f', 'u', 'l', 'm', 'i', 'n', 'a', 't', 'e', '\n',
        'f', 'u', 'l', 'm', 'i', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'f', 'u', 'l', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'f', 'u', 'l', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'f', 'u', 'l', 's', 'o', 'm', 'e', '\n',
        'f', 'u', 'l', 's', 'o', 'm', 'e', 'l', 'y', '\n',
        'f', 'u', 'm', 'a', 'r', 'o', 'l', 'e', '\n',
        'f', 'u', 'm', 'a', 'r', 'o', 'l', 'e', 's', '\n',
        'f', 'u', 'm', 'b', 'l', 'e', '\n',
        'f', 'u', 'm', 'b', 'l', 'e', 'd', '\n',
        'f', 'u', 'm', 'b', 'l', 'e', 's', '\n',
        'f', 'u', 'm', 'b', 'l', 'i', 'n', 'g', '\n',
        'f', 'u', 'm', 'e', '\n',
        'f', 'u', 'm', 'e', 'd', '\n',
        'f', 'u', 'm', 'e', 's', '\n',
        'f', 'u', 'm', 'i', 'g', 'a', 't', 'e', '\n',
        'f', 'u', 'm', 'i', 'g', 'a', 't', 'i', 'n', 'g', '\n',
        'f', 'u', 'm', 'i', 'g', 'a', 't', 'i', 'o', 'n', '\n',
        'f', 'u', 'm', 'i', 'n', 'g', '\n',
        'f', 'u', 'm', 'i', 'n', 'g', 'l', 'y', '\n',
        'f', 'u', 'n', '\n',
        'f', 'u', 'n', 'c', 't', 'i', 'o', 'n', '\n',
        'f', 'u', 'n', 'c', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'f', 'u', 'n', 'c', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 'm', '\n',
        'f', 'u', 'n', 'c', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 't', '\n',
        'f', 'u', 'n', 'c', 't', 'i', 'o', 'n', 'a', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'f', 'u', 'n', 'c', 't', 'i', 'o', 'n', 'a', 'l', 'i', 't', 'y', '\n',
        'f', 'u', 'n', 'c', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'f', 'u', 'n', 'c', 't', 'i', 'o', 'n', 'a', 'r', 'i', 'e', 's', '\n',
        'f', 'u', 'n', 'c', 't', 'i', 'o', 'n', 'a', 'r', 'y', '\n',
        'f', 'u', 'n', 'c', 't', 'i', 'o', 'n', 'e', 'd', '\n',
        'f', 'u', 'n', 'c', 't', 'i', 'o', 'n', 'i', 'n', 'g', '\n',
        'f', 'u', 'n', 'c', 't', 'i', 'o', 'n', 'l', 'e', 's', 's', '\n',
        'f', 'u', 'n', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'f', 'u', 'n', 'd', '\n',
        'f', 'u', 'n', 'd', 'a', 'm', 'e', 'n', 't', 'a', 'l', '\n',
        'f', 'u', 'n', 'd', 'a', 'm', 'e', 'n', 't', 'a', 'l', 'i', 's', 'm', '\n',
        'f', 'u', 'n', 'd', 'a', 'm', 'e', 'n', 't', 'a', 'l', 'i', 's', 't', '\n',
        'f', 'u', 'n', 'd', 'a', 'm', 'e', 'n', 't', 'a', 'l', 'i', 's', 't', 's', '\n',
        'f', 'u', 'n', 'd', 'a', 'm', 'e', 'n', 't', 'a', 'l', 'l', 'y', '\n',
        'f', 'u', 'n', 'd', 'a', 'm', 'e', 'n', 't', 'a', 'l', 's', '\n',
        'f', 'u', 'n', 'd', 'e', 'd', '\n',
        'f', 'u', 'n', 'd', 'h', 'o', 'l', 'd', 'e', 'r', 's', '\n',
        'f', 'u', 'n', 'd', 'h', 'o', 'l', 'd', 'i', 'n', 'g', '\n',
        'f', 'u', 'n', 'd', 'i', 'n', 'g', '\n',
        'f', 'u', 'n', 'd', 'i', 'n', 'g', 's', '\n',
        'f', 'u', 'n', 'd', 'r', 'a', 'i', 's', 'e', 'r', '\n',
        'f', 'u', 'n', 'd', 'r', 'a', 'i', 's', 'e', 'r', 's', '\n',
        'f', 'u', 'n', 'd', 'r', 'a', 'i', 's', 'i', 'n', 'g', '\n',
        'f', 'u', 'n', 'd', 's', '\n',
        'f', 'u', 'n', 'e', 'r', 'a', 'l', '\n',
        'f', 'u', 'n', 'e', 'r', 'a', 'l', 's', '\n',
        'f', 'u', 'n', 'e', 'r', 'a', 'r', 'y', '\n',
        'f', 'u', 'n', 'e', 'r', 'e', 'a', 'l', '\n',
        'f', 'u', 'n', 'f', 'a', 'i', 'r', '\n',
        'f', 'u', 'n', 'g', 'a', 'l', '\n',
        'f', 'u', 'n', 'g', 'i', '\n',
        'f', 'u', 'n', 'g', 'i', 'c', 'i', 'd', 'a', 'l', '\n',
        'f', 'u', 'n', 'g', 'i', 'c', 'i', 'd', 'e', '\n',
        'f', 'u', 'n', 'g', 'i', 'c', 'i', 'd', 'e', 's', '\n',
        'f', 'u', 'n', 'g', 'o', 'i', 'd', '\n',
        'f', 'u', 'n', 'g', 'o', 'u', 's', '\n',
        'f', 'u', 'n', 'g', 'u', 's', '\n',
        'f', 'u', 'n', 'g', 'u', 's', 'e', 's', '\n',
        'f', 'u', 'n', 'i', 'c', 'u', 'l', 'a', 'r', '\n',
        'f', 'u', 'n', 'k', '\n',
        'f', 'u', 'n', 'k', 'e', 'd', '\n',
        'f', 'u', 'n', 'k', 'i', 'e', 'r', '\n',
        'f', 'u', 'n', 'k', 'y', '\n',
        'f', 'u', 'n', 'n', 'e', 'l', '\n',
        'f', 'u', 'n', 'n', 'e', 'l', 'l', 'e', 'd', '\n',
        'f', 'u', 'n', 'n', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'f', 'u', 'n', 'n', 'e', 'l', 's', '\n',
        'f', 'u', 'n', 'n', 'i', 'e', 'r', '\n',
        'f', 'u', 'n', 'n', 'i', 'e', 's', '\n',
        'f', 'u', 'n', 'n', 'i', 'e', 's', 't', '\n',
        'f', 'u', 'n', 'n', 'i', 'l', 'y', '\n',
        'f', 'u', 'n', 'n', 'y', '\n',
        'f', 'u', 'r', '\n',
        'f', 'u', 'r', 'b', 'i', 's', 'h', 'e', 'd', '\n',
        'f', 'u', 'r', 'b', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'f', 'u', 'r', 'i', 'e', 's', '\n',
        'f', 'u', 'r', 'i', 'o', 'u', 's', '\n',
        'f', 'u', 'r', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'f', 'u', 'r', 'l', 'e', 'd', '\n',
        'f', 'u', 'r', 'l', 'i', 'n', 'g', '\n',
        'f', 'u', 'r', 'l', 'o', 'n', 'g', '\n',
        'f', 'u', 'r', 'l', 'o', 'n', 'g', 's', '\n',
        'f', 'u', 'r', 'l', 'o', 'u', 'g', 'h', '\n',
        'f', 'u', 'r', 'l', 's', '\n',
        'f', 'u', 'r', 'n', 'a', 'c', 'e', '\n',
        'f', 'u', 'r', 'n', 'a', 'c', 'e', 's', '\n',
        'f', 'u', 'r', 'n', 'i', 's', 'h', '\n',
        'f', 'u', 'r', 'n', 'i', 's', 'h', 'e', 'd', '\n',
        'f', 'u', 'r', 'n', 'i', 's', 'h', 'e', 'r', 's', '\n',
        'f', 'u', 'r', 'n', 'i', 's', 'h', 'e', 's', '\n',
        'f', 'u', 'r', 'n', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'f', 'u', 'r', 'n', 'i', 's', 'h', 'i', 'n', 'g', 's', '\n',
        'f', 'u', 'r', 'n', 'i', 't', 'u', 'r', 'e', '\n',
        'f', 'u', 'r', 'o', 'r', 'e', '\n',
        'f', 'u', 'r', 'o', 'r', 'e', 's', '\n',
        'f', 'u', 'r', 'r', 'e', 'd', '\n',
        'f', 'u', 'r', 'r', 'i', 'e', 'r', '\n',
        'f', 'u', 'r', 'r', 'i', 'e', 'r', 's', '\n',
        'f', 'u', 'r', 'r', 'i', 'e', 's', 't', '\n',
        'f', 'u', 'r', 'r', 'i', 'n', 'e', 's', 's', '\n',
        'f', 'u', 'r', 'r', 'i', 'n', 'g', '\n',
        'f', 'u', 'r', 'r', 'o', 'w', '\n',
        'f', 'u', 'r', 'r', 'o', 'w', 'e', 'd', '\n',
        'f', 'u', 'r', 'r', 'o', 'w', 's', '\n',
        'f', 'u', 'r', 'r', 'y', '\n',
        'f', 'u', 'r', 's', '\n',
        'f', 'u', 'r', 't', 'h', 'e', 'r', '\n',
        'f', 'u', 'r', 't', 'h', 'e', 'r', 'a', 'n', 'c', 'e', '\n',
        'f', 'u', 'r', 't', 'h', 'e', 'r', 'e', 'd', '\n',
        'f', 'u', 'r', 't', 'h', 'e', 'r', 'i', 'n', 'g', '\n',
        'f', 'u', 'r', 't', 'h', 'e', 'r', 'm', 'o', 'r', 'e', '\n',
        'f', 'u', 'r', 't', 'h', 'e', 'r', 's', '\n',
        'f', 'u', 'r', 't', 'h', 'e', 's', 't', '\n',
        'f', 'u', 'r', 't', 'i', 'v', 'e', '\n',
        'f', 'u', 'r', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'f', 'u', 'r', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'f', 'u', 'r', 'y', '\n',
        'f', 'u', 'r', 'z', 'e', '\n',
        'f', 'u', 's', 'e', '\n',
        'f', 'u', 's', 'e', 'd', '\n',
        'f', 'u', 's', 'e', 'l', 'a', 'g', 'e', '\n',
        'f', 'u', 's', 'e', 's', '\n',
        'f', 'u', 's', 'i', 'b', 'l', 'e', '\n',
        'f', 'u', 's', 'i', 'l', 'i', 'e', 'r', '\n',
        'f', 'u', 's', 'i', 'l', 'i', 'e', 'r', 's', '\n',
        'f', 'u', 's', 'i', 'l', 'l', 'a', 'd', 'e', '\n',
        'f', 'u', 's', 'i', 'n', 'g', '\n',
        'f', 'u', 's', 'i', 'o', 'n', '\n',
        'f', 'u', 's', 'i', 'o', 'n', 's', '\n',
        'f', 'u', 's', 's', '\n',
        'f', 'u', 's', 's', 'e', 'd', '\n',
        'f', 'u', 's', 's', 'e', 's', '\n',
        'f', 'u', 's', 's', 'i', 'e', 'r', '\n',
        'f', 'u', 's', 's', 'i', 'e', 's', 't', '\n',
        'f', 'u', 's', 's', 'i', 'l', 'y', '\n',
        'f', 'u', 's', 's', 'i', 'n', 'e', 's', 's', '\n',
        'f', 'u', 's', 's', 'i', 'n', 'g', '\n',
        'f', 'u', 's', 's', 'y', '\n',
        'f', 'u', 's', 't', 'i', 'a', 'n', '\n',
        'f', 'u', 's', 't', 'y', '\n',
        'f', 'u', 't', 'i', 'l', 'e', '\n',
        'f', 'u', 't', 'i', 'l', 'e', 'l', 'y', '\n',
        'f', 'u', 't', 'i', 'l', 'i', 't', 'y', '\n',
        'f', 'u', 't', 'o', 'n', '\n',
        'f', 'u', 't', 'u', 'r', 'e', '\n',
        'f', 'u', 't', 'u', 'r', 'e', 's', '\n',
        'f', 'u', 't', 'u', 'r', 'i', 's', 'm', '\n',
        'f', 'u', 't', 'u', 'r', 'i', 's', 't', '\n',
        'f', 'u', 't', 'u', 'r', 'i', 's', 't', 'i', 'c', '\n',
        'f', 'u', 't', 'u', 'r', 'i', 's', 't', 's', '\n',
        'f', 'u', 't', 'u', 'r', 'i', 't', 'y', '\n',
        'f', 'u', 't', 'u', 'r', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'f', 'u', 'z', 'z', '\n',
        'f', 'u', 'z', 'z', 'e', 'd', '\n',
        'f', 'u', 'z', 'z', 'e', 's', '\n',
        'f', 'u', 'z', 'z', 'i', 'e', 'r', '\n',
        'f', 'u', 'z', 'z', 'i', 'e', 's', 't', '\n',
        'f', 'u', 'z', 'z', 'i', 'l', 'y', '\n',
        'f', 'u', 'z', 'z', 'i', 'n', 'e', 's', 's', '\n',
        'f', 'u', 'z', 'z', 'y', '\n',
        'g', 'a', 'b', '\n',
        'g', 'a', 'b', 'b', 'l', 'e', '\n',
        'g', 'a', 'b', 'b', 'l', 'e', 'd', '\n',
        'g', 'a', 'b', 'b', 'l', 'e', 's', '\n',
        'g', 'a', 'b', 'b', 'l', 'i', 'n', 'g', '\n',
        'g', 'a', 'b', 'e', 'r', 'd', 'i', 'n', 'e', '\n',
        'g', 'a', 'b', 'l', 'e', '\n',
        'g', 'a', 'b', 'l', 'e', 'd', '\n',
        'g', 'a', 'b', 'l', 'e', 's', '\n',
        'g', 'a', 'b', 'o', 'n', '\n',
        'g', 'a', 'd', '\n',
        'g', 'a', 'd', 'd', 'e', 'd', '\n',
        'g', 'a', 'd', 'd', 'i', 'n', 'g', '\n',
        'g', 'a', 'd', 'f', 'l', 'y', '\n',
        'g', 'a', 'd', 'g', 'e', 't', '\n',
        'g', 'a', 'd', 'g', 'e', 't', 'r', 'y', '\n',
        'g', 'a', 'd', 'g', 'e', 't', 's', '\n',
        'g', 'a', 'f', 'f', '\n',
        'g', 'a', 'f', 'f', 'e', '\n',
        'g', 'a', 'f', 'f', 'e', 's', '\n',
        'g', 'a', 'g', '\n',
        'g', 'a', 'g', 'a', '\n',
        'g', 'a', 'g', 'e', '\n',
        'g', 'a', 'g', 'g', 'e', 'd', '\n',
        'g', 'a', 'g', 'g', 'i', 'n', 'g', '\n',
        'g', 'a', 'g', 'g', 'l', 'e', '\n',
        'g', 'a', 'g', 'g', 'l', 'e', 'd', '\n',
        'g', 'a', 'g', 'i', 'n', 'g', '\n',
        'g', 'a', 'g', 's', '\n',
        'g', 'a', 'g', 's', 't', 'e', 'r', '\n',
        'g', 'a', 'i', 'e', 't', 'y', '\n',
        'g', 'a', 'i', 'j', 'i', 'n', '\n',
        'g', 'a', 'i', 'l', 'y', '\n',
        'g', 'a', 'i', 'n', '\n',
        'g', 'a', 'i', 'n', 'e', 'd', '\n',
        'g', 'a', 'i', 'n', 'e', 'r', '\n',
        'g', 'a', 'i', 'n', 'e', 'r', 's', '\n',
        'g', 'a', 'i', 'n', 'f', 'u', 'l', '\n',
        'g', 'a', 'i', 'n', 'f', 'u', 'l', 'l', 'y', '\n',
        'g', 'a', 'i', 'n', 'i', 'n', 'g', '\n',
        'g', 'a', 'i', 'n', 'l', 'y', '\n',
        'g', 'a', 'i', 'n', 's', '\n',
        'g', 'a', 'i', 'n', 's', 'a', 'y', '\n',
        'g', 'a', 'i', 'n', 's', 'a', 'y', 'i', 'n', 'g', '\n',
        'g', 'a', 'i', 't', '\n',
        'g', 'a', 'i', 't', 'e', 'r', '\n',
        'g', 'a', 'i', 't', 'e', 'r', 's', '\n',
        'g', 'a', 'i', 't', 's', '\n',
        'g', 'a', 'l', '\n',
        'g', 'a', 'l', 'a', '\n',
        'g', 'a', 'l', 'a', 'c', 't', 'i', 'c', '\n',
        'g', 'a', 'l', 'a', 's', '\n',
        'g', 'a', 'l', 'a', 'x', 'i', 'e', 's', '\n',
        'g', 'a', 'l', 'a', 'x', 'y', '\n',
        'g', 'a', 'l', 'e', '\n',
        'g', 'a', 'l', 'e', 'n', 'a', '\n',
        'g', 'a', 'l', 'e', 's', '\n',
        'g', 'a', 'l', 'i', 'l', 'e', 'a', 'n', '\n',
        'g', 'a', 'l', 'i', 'l', 'e', 'o', '\n',
        'g', 'a', 'l', 'l', '\n',
        'g', 'a', 'l', 'l', 'a', 'n', 't', '\n',
        'g', 'a', 'l', 'l', 'a', 'n', 't', 'l', 'y', '\n',
        'g', 'a', 'l', 'l', 'a', 'n', 't', 'r', 'i', 'e', 's', '\n',
        'g', 'a', 'l', 'l', 'a', 'n', 't', 'r', 'y', '\n',
        'g', 'a', 'l', 'l', 'a', 'n', 't', 's', '\n',
        'g', 'a', 'l', 'l', 'e', 'd', '\n',
        'g', 'a', 'l', 'l', 'e', 'o', 'n', '\n',
        'g', 'a', 'l', 'l', 'e', 'o', 'n', 's', '\n',
        'g', 'a', 'l', 'l', 'e', 'r', 'i', 'e', 'd', '\n',
        'g', 'a', 'l', 'l', 'e', 'r', 'i', 'e', 's', '\n',
        'g', 'a', 'l', 'l', 'e', 'r', 'y', '\n',
        'g', 'a', 'l', 'l', 'e', 'y', '\n',
        'g', 'a', 'l', 'l', 'e', 'y', 's', '\n',
        'g', 'a', 'l', 'l', 'i', 'c', '\n',
        'g', 'a', 'l', 'l', 'i', 'n', 'g', '\n',
        'g', 'a', 'l', 'l', 'i', 'u', 'm', '\n',
        'g', 'a', 'l', 'l', 'i', 'v', 'a', 'n', 't', 'e', 'd', '\n',
        'g', 'a', 'l', 'l', 'i', 'v', 'a', 'n', 't', 'i', 'n', 'g', '\n',
        'g', 'a', 'l', 'l', 'o', 'n', '\n',
        'g', 'a', 'l', 'l', 'o', 'n', 's', '\n',
        'g', 'a', 'l', 'l', 'o', 'p', '\n',
        'g', 'a', 'l', 'l', 'o', 'p', 'e', 'd', '\n',
        'g', 'a', 'l', 'l', 'o', 'p', 'i', 'n', 'g', '\n',
        'g', 'a', 'l', 'l', 'o', 'p', 's', '\n',
        'g', 'a', 'l', 'l', 'o', 'w', 's', '\n',
        'g', 'a', 'l', 'l', 's', '\n',
        'g', 'a', 'l', 'l', 's', 't', 'o', 'n', 'e', 's', '\n',
        'g', 'a', 'l', 'o', 'p', '\n',
        'g', 'a', 'l', 'o', 'r', 'e', '\n',
        'g', 'a', 'l', 'o', 's', 'h', 'e', 's', '\n',
        'g', 'a', 'l', 's', '\n',
        'g', 'a', 'l', 'v', 'a', 'n', 'i', 'c', '\n',
        'g', 'a', 'l', 'v', 'a', 'n', 'i', 's', 'e', '\n',
        'g', 'a', 'l', 'v', 'a', 'n', 'i', 's', 'e', 'd', '\n',
        'g', 'a', 'l', 'v', 'a', 'n', 'i', 's', 'i', 'n', 'g', '\n',
        'g', 'a', 'l', 'v', 'a', 'n', 'o', 'm', 'e', 't', 'e', 'r', '\n',
        'g', 'a', 'l', 'v', 'a', 'n', 'o', 'm', 'e', 't', 'r', 'i', 'c', '\n',
        'g', 'a', 'm', 'b', 'i', 'a', '\n',
        'g', 'a', 'm', 'b', 'i', 'a', 'n', '\n',
        'g', 'a', 'm', 'b', 'i', 't', '\n',
        'g', 'a', 'm', 'b', 'i', 't', 's', '\n',
        'g', 'a', 'm', 'b', 'l', 'e', '\n',
        'g', 'a', 'm', 'b', 'l', 'e', 'd', '\n',
        'g', 'a', 'm', 'b', 'l', 'e', 'r', '\n',
        'g', 'a', 'm', 'b', 'l', 'e', 'r', 's', '\n',
        'g', 'a', 'm', 'b', 'l', 'e', 's', '\n',
        'g', 'a', 'm', 'b', 'l', 'i', 'n', 'g', '\n',
        'g', 'a', 'm', 'b', 'o', 'l', '\n',
        'g', 'a', 'm', 'b', 'o', 'l', 'l', 'i', 'n', 'g', '\n',
        'g', 'a', 'm', 'b', 'o', 'l', 's', '\n',
        'g', 'a', 'm', 'e', '\n',
        'g', 'a', 'm', 'e', 'd', '\n',
        'g', 'a', 'm', 'e', 'k', 'e', 'e', 'p', 'e', 'r', '\n',
        'g', 'a', 'm', 'e', 'k', 'e', 'e', 'p', 'e', 'r', 's', '\n',
        'g', 'a', 'm', 'e', 'l', 'y', '\n',
        'g', 'a', 'm', 'e', 'r', 's', '\n',
        'g', 'a', 'm', 'e', 's', '\n',
        'g', 'a', 'm', 'e', 's', 'm', 'a', 'n', 's', 'h', 'i', 'p', '\n',
        'g', 'a', 'm', 'e', 's', 'm', 'e', 'n', '\n',
        'g', 'a', 'm', 'e', 't', 'e', '\n',
        'g', 'a', 'm', 'e', 't', 'e', 's', '\n',
        'g', 'a', 'm', 'i', 'n', 'g', '\n',
        'g', 'a', 'm', 'm', 'a', '\n',
        'g', 'a', 'm', 'm', 'o', 'n', '\n',
        'g', 'a', 'm', 'u', 't', '\n',
        'g', 'a', 'm', 'y', '\n',
        'g', 'a', 'n', 'd', 'e', 'r', '\n',
        'g', 'a', 'n', 'd', 'e', 'r', 's', '\n',
        'g', 'a', 'n', 'd', 'h', 'i', '\n',
        'g', 'a', 'n', 'g', '\n',
        'g', 'a', 'n', 'g', 'e', 'd', '\n',
        'g', 'a', 'n', 'g', 'e', 'r', '\n',
        'g', 'a', 'n', 'g', 'e', 'r', 's', '\n',
        'g', 'a', 'n', 'g', 'e', 's', '\n',
        'g', 'a', 'n', 'g', 'i', 'n', 'g', '\n',
        'g', 'a', 'n', 'g', 'l', 'a', 'n', 'd', '\n',
        'g', 'a', 'n', 'g', 'l', 'i', 'a', '\n',
        'g', 'a', 'n', 'g', 'l', 'i', 'n', 'g', '\n',
        'g', 'a', 'n', 'g', 'l', 'i', 'o', 'n', '\n',
        'g', 'a', 'n', 'g', 'l', 'i', 'o', 'n', 'i', 'c', '\n',
        'g', 'a', 'n', 'g', 'l', 'y', '\n',
        'g', 'a', 'n', 'g', 'p', 'l', 'a', 'n', 'k', '\n',
        'g', 'a', 'n', 'g', 'r', 'e', 'n', 'e', '\n',
        'g', 'a', 'n', 'g', 'r', 'e', 'n', 'o', 'u', 's', '\n',
        'g', 'a', 'n', 'g', 's', '\n',
        'g', 'a', 'n', 'g', 's', 't', 'e', 'r', '\n',
        'g', 'a', 'n', 'g', 's', 't', 'e', 'r', 'i', 's', 'm', '\n',
        'g', 'a', 'n', 'g', 's', 't', 'e', 'r', 's', '\n',
        'g', 'a', 'n', 'g', 'w', 'a', 'y', '\n',
        'g', 'a', 'n', 'g', 'w', 'a', 'y', 's', '\n',
        'g', 'a', 'n', 'n', 'e', 't', '\n',
        'g', 'a', 'n', 'n', 'e', 't', 's', '\n',
        'g', 'a', 'n', 't', 'r', 'i', 'e', 's', '\n',
        'g', 'a', 'n', 't', 'r', 'y', '\n',
        'g', 'a', 'o', 'l', '\n',
        'g', 'a', 'o', 'l', 'e', 'd', '\n',
        'g', 'a', 'o', 'l', 'e', 'r', '\n',
        'g', 'a', 'o', 'l', 'e', 'r', 's', '\n',
        'g', 'a', 'o', 'l', 's', '\n',
        'g', 'a', 'p', '\n',
        'g', 'a', 'p', 'e', '\n',
        'g', 'a', 'p', 'e', 'd', '\n',
        'g', 'a', 'p', 'e', 's', '\n',
        'g', 'a', 'p', 'i', 'n', 'g', '\n',
        'g', 'a', 'p', 'i', 'n', 'g', 'l', 'y', '\n',
        'g', 'a', 'p', 's', '\n',
        'g', 'a', 'r', 'a', 'g', 'e', '\n',
        'g', 'a', 'r', 'a', 'g', 'e', 'd', '\n',
        'g', 'a', 'r', 'a', 'g', 'e', 's', '\n',
        'g', 'a', 'r', 'b', '\n',
        'g', 'a', 'r', 'b', 'a', 'g', 'e', '\n',
        'g', 'a', 'r', 'b', 'e', 'd', '\n',
        'g', 'a', 'r', 'b', 'l', 'e', '\n',
        'g', 'a', 'r', 'b', 'l', 'e', 'd', '\n',
        'g', 'a', 'r', 'b', 'l', 'e', 's', '\n',
        'g', 'a', 'r', 'b', 'l', 'i', 'n', 'g', '\n',
        'g', 'a', 'r', 'b', 's', '\n',
        'g', 'a', 'r', 'd', 'e', 'n', '\n',
        'g', 'a', 'r', 'd', 'e', 'n', 'e', 'r', '\n',
        'g', 'a', 'r', 'd', 'e', 'n', 'e', 'r', 's', '\n',
        'g', 'a', 'r', 'd', 'e', 'n', 'i', 'n', 'g', '\n',
        'g', 'a', 'r', 'd', 'e', 'n', 's', '\n',
        'g', 'a', 'r', 'g', 'a', 'n', 't', 'u', 'a', 'n', '\n',
        'g', 'a', 'r', 'g', 'l', 'e', '\n',
        'g', 'a', 'r', 'g', 'l', 'e', 'd', '\n',
        'g', 'a', 'r', 'g', 'l', 'e', 's', '\n',
        'g', 'a', 'r', 'g', 'l', 'i', 'n', 'g', '\n',
        'g', 'a', 'r', 'g', 'o', 'y', 'l', 'e', '\n',
        'g', 'a', 'r', 'g', 'o', 'y', 'l', 'e', 's', '\n',
        'g', 'a', 'r', 'i', 's', 'h', '\n',
        'g', 'a', 'r', 'i', 's', 'h', 'l', 'y', '\n',
        'g', 'a', 'r', 'l', 'a', 'n', 'd', '\n',
        'g', 'a', 'r', 'l', 'a', 'n', 'd', 'e', 'd', '\n',
        'g', 'a', 'r', 'l', 'a', 'n', 'd', 's', '\n',
        'g', 'a', 'r', 'l', 'i', 'c', '\n',
        'g', 'a', 'r', 'm', 'e', 'n', 't', '\n',
        'g', 'a', 'r', 'm', 'e', 'n', 't', 's', '\n',
        'g', 'a', 'r', 'n', 'e', 'r', '\n',
        'g', 'a', 'r', 'n', 'e', 'r', 'e', 'd', '\n',
        'g', 'a', 'r', 'n', 'e', 'r', 'i', 'n', 'g', '\n',
        'g', 'a', 'r', 'n', 'e', 't', '\n',
        'g', 'a', 'r', 'n', 'e', 't', 's', '\n',
        'g', 'a', 'r', 'n', 'i', 's', 'h', '\n',
        'g', 'a', 'r', 'n', 'i', 's', 'h', 'e', 'd', '\n',
        'g', 'a', 'r', 'n', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'g', 'a', 'r', 'o', 't', 't', 'e', '\n',
        'g', 'a', 'r', 'o', 't', 't', 'e', 'd', '\n',
        'g', 'a', 'r', 'o', 't', 't', 'e', 's', '\n',
        'g', 'a', 'r', 'o', 't', 't', 'i', 'n', 'g', '\n',
        'g', 'a', 'r', 'r', 'e', 't', '\n',
        'g', 'a', 'r', 'r', 'e', 't', 's', '\n',
        'g', 'a', 'r', 'r', 'i', 's', 'o', 'n', '\n',
        'g', 'a', 'r', 'r', 'i', 's', 'o', 'n', 'e', 'd', '\n',
        'g', 'a', 'r', 'r', 'i', 's', 'o', 'n', 's', '\n',
        'g', 'a', 'r', 'r', 'o', 't', 't', 'e', '\n',
        'g', 'a', 'r', 'r', 'o', 't', 't', 'e', 'd', '\n',
        'g', 'a', 'r', 'r', 'o', 't', 't', 'e', 's', '\n',
        'g', 'a', 'r', 'r', 'o', 't', 't', 'i', 'n', 'g', '\n',
        'g', 'a', 'r', 'r', 'u', 'l', 'o', 'u', 's', '\n',
        'g', 'a', 'r', 't', 'e', 'r', '\n',
        'g', 'a', 'r', 't', 'e', 'r', 's', '\n',
        'g', 'a', 's', '\n',
        'g', 'a', 's', 'e', 'o', 'u', 's', '\n',
        'g', 'a', 's', 'e', 's', '\n',
        'g', 'a', 's', 'h', '\n',
        'g', 'a', 's', 'h', 'e', 'd', '\n',
        'g', 'a', 's', 'h', 'e', 's', '\n',
        'g', 'a', 's', 'h', 'i', 'n', 'g', '\n',
        'g', 'a', 's', 'h', 'o', 'l', 'd', 'e', 'r', '\n',
        'g', 'a', 's', 'i', 'f', 'y', '\n',
        'g', 'a', 's', 'k', 'e', 't', '\n',
        'g', 'a', 's', 'k', 'e', 't', 's', '\n',
        'g', 'a', 's', 'l', 'i', 'g', 'h', 't', '\n',
        'g', 'a', 's', 'o', 'm', 'e', 't', 'e', 'r', '\n',
        'g', 'a', 's', 'p', '\n',
        'g', 'a', 's', 'p', 'e', 'd', '\n',
        'g', 'a', 's', 'p', 'e', 'r', '\n',
        'g', 'a', 's', 'p', 'i', 'n', 'g', '\n',
        'g', 'a', 's', 'p', 's', '\n',
        'g', 'a', 's', 's', 'e', 'd', '\n',
        'g', 'a', 's', 's', 'e', 's', '\n',
        'g', 'a', 's', 's', 'i', 'e', 'r', '\n',
        'g', 'a', 's', 's', 'i', 'e', 's', 't', '\n',
        'g', 'a', 's', 's', 'i', 'n', 'g', '\n',
        'g', 'a', 's', 's', 'y', '\n',
        'g', 'a', 's', 't', 'r', 'e', 'c', 't', 'o', 'm', 'y', '\n',
        'g', 'a', 's', 't', 'r', 'i', 'c', '\n',
        'g', 'a', 's', 't', 'r', 'i', 't', 'i', 's', '\n',
        'g', 'a', 's', 't', 'r', 'o', 'e', 'n', 't', 'e', 'r', 'i', 't', 'i', 's', '\n',
        'g', 'a', 's', 't', 'r', 'o', 'i', 'n', 't', 'e', 's', 't', 'i', 'n', 'a', 'l', '\n',
        'g', 'a', 's', 't', 'r', 'o', 'n', 'o', 'm', 'i', 'c', '\n',
        'g', 'a', 's', 't', 'r', 'o', 'n', 'o', 'm', 'y', '\n',
        'g', 'a', 's', 't', 'r', 'o', 'p', 'o', 'd', '\n',
        'g', 'a', 's', 't', 'r', 'o', 'p', 'o', 'd', 's', '\n',
        'g', 'a', 's', 'w', 'o', 'r', 'k', 's', '\n',
        'g', 'a', 't', 'e', '\n',
        'g', 'a', 't', 'e', 'a', 'u', '\n',
        'g', 'a', 't', 'e', 'a', 'u', 's', '\n',
        'g', 'a', 't', 'e', 'a', 'u', 'x', '\n',
        'g', 'a', 't', 'e', 'c', 'r', 'a', 's', 'h', '\n',
        'g', 'a', 't', 'e', 'c', 'r', 'a', 's', 'h', 'e', 'd', '\n',
        'g', 'a', 't', 'e', 'c', 'r', 'a', 's', 'h', 'e', 'r', '\n',
        'g', 'a', 't', 'e', 'c', 'r', 'a', 's', 'h', 'e', 'r', 's', '\n',
        'g', 'a', 't', 'e', 'c', 'r', 'a', 's', 'h', 'i', 'n', 'g', '\n',
        'g', 'a', 't', 'e', 'd', '\n',
        'g', 'a', 't', 'e', 'h', 'o', 'u', 's', 'e', '\n',
        'g', 'a', 't', 'e', 'h', 'o', 'u', 's', 'e', 's', '\n',
        'g', 'a', 't', 'e', 'k', 'e', 'e', 'p', 'e', 'r', '\n',
        'g', 'a', 't', 'e', 'k', 'e', 'e', 'p', 'e', 'r', 's', '\n',
        'g', 'a', 't', 'e', 'p', 'o', 's', 't', '\n',
        'g', 'a', 't', 'e', 'p', 'o', 's', 't', 's', '\n',
        'g', 'a', 't', 'e', 's', '\n',
        'g', 'a', 't', 'e', 'w', 'a', 'y', '\n',
        'g', 'a', 't', 'e', 'w', 'a', 'y', 's', '\n',
        'g', 'a', 't', 'h', 'e', 'r', '\n',
        'g', 'a', 't', 'h', 'e', 'r', 'e', 'd', '\n',
        'g', 'a', 't', 'h', 'e', 'r', 'e', 'r', '\n',
        'g', 'a', 't', 'h', 'e', 'r', 'e', 'r', 's', '\n',
        'g', 'a', 't', 'h', 'e', 'r', 'i', 'n', 'g', '\n',
        'g', 'a', 't', 'h', 'e', 'r', 'i', 'n', 'g', 's', '\n',
        'g', 'a', 't', 'h', 'e', 'r', 's', '\n',
        'g', 'a', 't', 'i', 'n', 'g', '\n',
        'g', 'a', 'u', 'c', 'h', 'e', '\n',
        'g', 'a', 'u', 'c', 'h', 'e', 'n', 'e', 's', 's', '\n',
        'g', 'a', 'u', 'c', 'h', 'e', 'r', 'i', 'e', '\n',
        'g', 'a', 'u', 'd', '\n',
        'g', 'a', 'u', 'd', 'i', 'e', 's', 't', '\n',
        'g', 'a', 'u', 'd', 'i', 'l', 'y', '\n',
        'g', 'a', 'u', 'd', 'i', 'n', 'e', 's', 's', '\n',
        'g', 'a', 'u', 'd', 'y', '\n',
        'g', 'a', 'u', 'g', 'e', '\n',
        'g', 'a', 'u', 'g', 'e', 'd', '\n',
        'g', 'a', 'u', 'g', 'e', 's', '\n',
        'g', 'a', 'u', 'g', 'i', 'n', 'g', '\n',
        'g', 'a', 'u', 'l', '\n',
        'g', 'a', 'u', 'l', 's', '\n',
        'g', 'a', 'u', 'n', 't', '\n',
        'g', 'a', 'u', 'n', 't', 'e', 'r', '\n',
        'g', 'a', 'u', 'n', 't', 'l', 'e', 't', '\n',
        'g', 'a', 'u', 'n', 't', 'l', 'e', 't', 's', '\n',
        'g', 'a', 'u', 'n', 't', 'l', 'y', '\n',
        'g', 'a', 'u', 'z', 'e', '\n',
        'g', 'a', 'v', 'e', '\n',
        'g', 'a', 'v', 'e', 'l', '\n',
        'g', 'a', 'v', 'i', 'a', 'l', '\n',
        'g', 'a', 'v', 'i', 'a', 'l', 's', '\n',
        'g', 'a', 'v', 'o', 't', 't', 'e', '\n',
        'g', 'a', 'w', 'k', '\n',
        'g', 'a', 'w', 'k', 'i', 'n', 'g', '\n',
        'g', 'a', 'w', 'k', 'y', '\n',
        'g', 'a', 'w', 'p', 'i', 'n', '\n',
        'g', 'a', 'y', '\n',
        'g', 'a', 'y', 'e', 's', 't', '\n',
        'g', 'a', 'y', 's', '\n',
        'g', 'a', 'z', 'e', '\n',
        'g', 'a', 'z', 'e', 'b', 'o', '\n',
        'g', 'a', 'z', 'e', 'd', '\n',
        'g', 'a', 'z', 'e', 'l', 'l', 'e', '\n',
        'g', 'a', 'z', 'e', 'l', 'l', 'e', 's', '\n',
        'g', 'a', 'z', 'e', 's', '\n',
        'g', 'a', 'z', 'e', 't', 't', 'e', '\n',
        'g', 'a', 'z', 'e', 't', 't', 'e', 'e', 'r', '\n',
        'g', 'a', 'z', 'e', 't', 't', 'e', 's', '\n',
        'g', 'a', 'z', 'i', 'n', 'g', '\n',
        'g', 'd', 'a', 'n', 's', 'k', '\n',
        'g', 'e', 'a', 'r', '\n',
        'g', 'e', 'a', 'r', 'b', 'o', 'x', '\n',
        'g', 'e', 'a', 'r', 'b', 'o', 'x', 'e', 's', '\n',
        'g', 'e', 'a', 'r', 'e', 'd', '\n',
        'g', 'e', 'a', 'r', 'i', 'n', 'g', '\n',
        'g', 'e', 'a', 'r', 's', '\n',
        'g', 'e', 'a', 'r', 's', 't', 'i', 'c', 'k', '\n',
        'g', 'e', 'c', 'k', 'o', '\n',
        'g', 'e', 'e', 'k', '\n',
        'g', 'e', 'e', 'k', 's', '\n',
        'g', 'e', 'e', 's', 'e', '\n',
        'g', 'e', 'e', 'z', 'e', 'r', '\n',
        'g', 'e', 'i', 'g', 'e', 'r', '\n',
        'g', 'e', 'i', 's', 'h', 'a', '\n',
        'g', 'e', 'i', 's', 'h', 'a', 's', '\n',
        'g', 'e', 'l', '\n',
        'g', 'e', 'l', 'a', 't', 'i', 'n', '\n',
        'g', 'e', 'l', 'a', 't', 'i', 'n', 'e', '\n',
        'g', 'e', 'l', 'a', 't', 'i', 'n', 'o', 'u', 's', '\n',
        'g', 'e', 'l', 'd', 'i', 'n', 'g', '\n',
        'g', 'e', 'l', 'd', 'i', 'n', 'g', 's', '\n',
        'g', 'e', 'l', 'i', 'g', 'n', 'i', 't', 'e', '\n',
        'g', 'e', 'l', 'l', 'e', 'd', '\n',
        'g', 'e', 'l', 's', '\n',
        'g', 'e', 'm', '\n',
        'g', 'e', 'm', 'i', 'n', 'i', '\n',
        'g', 'e', 'm', 'm', 'e', 'd', '\n',
        'g', 'e', 'm', 's', '\n',
        'g', 'e', 'm', 's', 'b', 'o', 'k', '\n',
        'g', 'e', 'm', 's', 't', 'o', 'n', 'e', '\n',
        'g', 'e', 'm', 's', 't', 'o', 'n', 'e', 's', '\n',
        'g', 'e', 'n', '\n',
        'g', 'e', 'n', 'd', 'e', 'r', '\n',
        'g', 'e', 'n', 'd', 'e', 'r', 'e', 'd', '\n',
        'g', 'e', 'n', 'd', 'e', 'r', 'l', 'e', 's', 's', '\n',
        'g', 'e', 'n', 'd', 'e', 'r', 's', '\n',
        'g', 'e', 'n', 'e', '\n',
        'g', 'e', 'n', 'e', 'a', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'g', 'e', 'n', 'e', 'a', 'l', 'o', 'g', 'i', 'e', 's', '\n',
        'g', 'e', 'n', 'e', 'a', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'g', 'e', 'n', 'e', 'a', 'l', 'o', 'g', 'y', '\n',
        'g', 'e', 'n', 'e', 'r', 'a', '\n',
        'g', 'e', 'n', 'e', 'r', 'a', 'l', '\n',
        'g', 'e', 'n', 'e', 'r', 'a', 'l', 'i', 's', 'a', 'b', 'l', 'e', '\n',
        'g', 'e', 'n', 'e', 'r', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'g', 'e', 'n', 'e', 'r', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'g', 'e', 'n', 'e', 'r', 'a', 'l', 'i', 's', 'e', '\n',
        'g', 'e', 'n', 'e', 'r', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'g', 'e', 'n', 'e', 'r', 'a', 'l', 'i', 's', 'e', 's', '\n',
        'g', 'e', 'n', 'e', 'r', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'g', 'e', 'n', 'e', 'r', 'a', 'l', 'i', 's', 't', '\n',
        'g', 'e', 'n', 'e', 'r', 'a', 'l', 'i', 's', 't', 's', '\n',
        'g', 'e', 'n', 'e', 'r', 'a', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'g', 'e', 'n', 'e', 'r', 'a', 'l', 'i', 't', 'y', '\n',
        'g', 'e', 'n', 'e', 'r', 'a', 'l', 'l', 'y', '\n',
        'g', 'e', 'n', 'e', 'r', 'a', 'l', 's', '\n',
        'g', 'e', 'n', 'e', 'r', 'a', 'l', 's', 'h', 'i', 'p', '\n',
        'g', 'e', 'n', 'e', 'r', 'a', 't', 'e', '\n',
        'g', 'e', 'n', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'g', 'e', 'n', 'e', 'r', 'a', 't', 'e', 's', '\n',
        'g', 'e', 'n', 'e', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'g', 'e', 'n', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'g', 'e', 'n', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'g', 'e', 'n', 'e', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'g', 'e', 'n', 'e', 'r', 'a', 't', 'i', 'v', 'e', '\n',
        'g', 'e', 'n', 'e', 'r', 'a', 't', 'o', 'r', '\n',
        'g', 'e', 'n', 'e', 'r', 'a', 't', 'o', 'r', 's', '\n',
        'g', 'e', 'n', 'e', 'r', 'i', 'c', '\n',
        'g', 'e', 'n', 'e', 'r', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'g', 'e', 'n', 'e', 'r', 'o', 's', 'i', 't', 'i', 'e', 's', '\n',
        'g', 'e', 'n', 'e', 'r', 'o', 's', 'i', 't', 'y', '\n',
        'g', 'e', 'n', 'e', 'r', 'o', 'u', 's', '\n',
        'g', 'e', 'n', 'e', 'r', 'o', 'u', 's', 'l', 'y', '\n',
        'g', 'e', 'n', 'e', 's', '\n',
        'g', 'e', 'n', 'e', 's', 'i', 's', '\n',
        'g', 'e', 'n', 'e', 't', 'i', 'c', '\n',
        'g', 'e', 'n', 'e', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'g', 'e', 'n', 'e', 't', 'i', 'c', 'i', 's', 't', '\n',
        'g', 'e', 'n', 'e', 't', 'i', 'c', 'i', 's', 't', 's', '\n',
        'g', 'e', 'n', 'e', 't', 'i', 'c', 's', '\n',
        'g', 'e', 'n', 'e', 't', 's', '\n',
        'g', 'e', 'n', 'e', 'v', 'a', '\n',
        'g', 'e', 'n', 'i', 'a', 'l', '\n',
        'g', 'e', 'n', 'i', 'a', 'l', 'i', 't', 'y', '\n',
        'g', 'e', 'n', 'i', 'a', 'l', 'l', 'y', '\n',
        'g', 'e', 'n', 'i', 'e', '\n',
        'g', 'e', 'n', 'i', 'i', '\n',
        'g', 'e', 'n', 'i', 't', 'a', 'l', '\n',
        'g', 'e', 'n', 'i', 't', 'a', 'l', 'i', 'a', '\n',
        'g', 'e', 'n', 'i', 't', 'a', 'l', 's', '\n',
        'g', 'e', 'n', 'i', 't', 'i', 'v', 'e', '\n',
        'g', 'e', 'n', 'i', 't', 'i', 'v', 'e', 's', '\n',
        'g', 'e', 'n', 'i', 'u', 's', '\n',
        'g', 'e', 'n', 'i', 'u', 's', 'e', 's', '\n',
        'g', 'e', 'n', 'o', 'a', '\n',
        'g', 'e', 'n', 'o', 'c', 'i', 'd', 'a', 'l', '\n',
        'g', 'e', 'n', 'o', 'c', 'i', 'd', 'e', '\n',
        'g', 'e', 'n', 'o', 'm', 'e', '\n',
        'g', 'e', 'n', 'o', 'm', 'e', 's', '\n',
        'g', 'e', 'n', 'o', 'm', 'i', 'c', '\n',
        'g', 'e', 'n', 'o', 't', 'y', 'p', 'e', '\n',
        'g', 'e', 'n', 'o', 't', 'y', 'p', 'e', 's', '\n',
        'g', 'e', 'n', 'r', 'e', '\n',
        'g', 'e', 'n', 'r', 'e', 's', '\n',
        'g', 'e', 'n', 't', '\n',
        'g', 'e', 'n', 't', 'e', 'e', 'l', '\n',
        'g', 'e', 'n', 't', 'e', 'e', 'l', 'e', 's', 't', '\n',
        'g', 'e', 'n', 't', 'e', 'e', 'l', 'l', 'y', '\n',
        'g', 'e', 'n', 't', 'i', 'a', 'n', 's', '\n',
        'g', 'e', 'n', 't', 'i', 'l', 'e', '\n',
        'g', 'e', 'n', 't', 'i', 'l', 'e', 's', '\n',
        'g', 'e', 'n', 't', 'i', 'l', 'i', 't', 'y', '\n',
        'g', 'e', 'n', 't', 'l', 'e', '\n',
        'g', 'e', 'n', 't', 'l', 'e', 'f', 'o', 'l', 'k', '\n',
        'g', 'e', 'n', 't', 'l', 'e', 'm', 'a', 'n', '\n',
        'g', 'e', 'n', 't', 'l', 'e', 'm', 'a', 'n', 'l', 'y', '\n',
        'g', 'e', 'n', 't', 'l', 'e', 'm', 'e', 'n', '\n',
        'g', 'e', 'n', 't', 'l', 'e', 'n', 'e', 's', 's', '\n',
        'g', 'e', 'n', 't', 'l', 'e', 'r', '\n',
        'g', 'e', 'n', 't', 'l', 'e', 's', 't', '\n',
        'g', 'e', 'n', 't', 'l', 'i', 'n', 'g', '\n',
        'g', 'e', 'n', 't', 'l', 'y', '\n',
        'g', 'e', 'n', 't', 'r', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'g', 'e', 'n', 't', 'r', 'i', 'f', 'i', 'e', 'd', '\n',
        'g', 'e', 'n', 't', 'r', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'g', 'e', 'n', 't', 'r', 'y', '\n',
        'g', 'e', 'n', 't', 's', '\n',
        'g', 'e', 'n', 'u', 'f', 'l', 'e', 'c', 't', '\n',
        'g', 'e', 'n', 'u', 'f', 'l', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'g', 'e', 'n', 'u', 'i', 'n', 'e', '\n',
        'g', 'e', 'n', 'u', 'i', 'n', 'e', 'l', 'y', '\n',
        'g', 'e', 'n', 'u', 'i', 'n', 'e', 'n', 'e', 's', 's', '\n',
        'g', 'e', 'n', 'u', 's', '\n',
        'g', 'e', 'o', 'c', 'e', 'n', 't', 'r', 'i', 'c', '\n',
        'g', 'e', 'o', 'c', 'h', 'e', 'm', 'i', 'c', 'a', 'l', '\n',
        'g', 'e', 'o', 'c', 'h', 'e', 'm', 'i', 's', 't', 'r', 'y', '\n',
        'g', 'e', 'o', 'd', 'e', 's', 'i', 'c', '\n',
        'g', 'e', 'o', 'd', 'e', 's', 'i', 'c', 's', '\n',
        'g', 'e', 'o', 'g', 'r', 'a', 'p', 'h', 'e', 'r', '\n',
        'g', 'e', 'o', 'g', 'r', 'a', 'p', 'h', 'e', 'r', 's', '\n',
        'g', 'e', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', '\n',
        'g', 'e', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', 'a', 'l', '\n',
        'g', 'e', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'g', 'e', 'o', 'g', 'r', 'a', 'p', 'h', 'y', '\n',
        'g', 'e', 'o', 'l', 'o', 'g', 'i', 'c', '\n',
        'g', 'e', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'g', 'e', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'g', 'e', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'g', 'e', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'g', 'e', 'o', 'l', 'o', 'g', 'y', '\n',
        'g', 'e', 'o', 'm', 'a', 'g', 'n', 'e', 't', 'i', 'c', '\n',
        'g', 'e', 'o', 'm', 'a', 'g', 'n', 'e', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'g', 'e', 'o', 'm', 'a', 'g', 'n', 'e', 't', 'i', 's', 'm', '\n',
        'g', 'e', 'o', 'm', 'e', 't', 'e', 'r', '\n',
        'g', 'e', 'o', 'm', 'e', 't', 'e', 'r', 's', '\n',
        'g', 'e', 'o', 'm', 'e', 't', 'r', 'i', 'c', '\n',
        'g', 'e', 'o', 'm', 'e', 't', 'r', 'i', 'c', 'a', 'l', '\n',
        'g', 'e', 'o', 'm', 'e', 't', 'r', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'g', 'e', 'o', 'm', 'e', 't', 'r', 'i', 'e', 's', '\n',
        'g', 'e', 'o', 'm', 'e', 't', 'r', 'y', '\n',
        'g', 'e', 'o', 'm', 'o', 'r', 'p', 'h', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'g', 'e', 'o', 'm', 'o', 'r', 'p', 'h', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'g', 'e', 'o', 'm', 'o', 'r', 'p', 'h', 'o', 'l', 'o', 'g', 'y', '\n',
        'g', 'e', 'o', 'p', 'h', 'y', 's', 'i', 'c', 'a', 'l', '\n',
        'g', 'e', 'o', 'p', 'h', 'y', 's', 'i', 'c', 'i', 's', 't', '\n',
        'g', 'e', 'o', 'p', 'h', 'y', 's', 'i', 'c', 'i', 's', 't', 's', '\n',
        'g', 'e', 'o', 'p', 'h', 'y', 's', 'i', 'c', 's', '\n',
        'g', 'e', 'o', 'p', 'o', 'l', 'i', 't', 'i', 'c', 'a', 'l', '\n',
        'g', 'e', 'o', 'r', 'g', 'e', '\n',
        'g', 'e', 'o', 'r', 'g', 'i', 'a', '\n',
        'g', 'e', 'o', 's', 'c', 'i', 'e', 'n', 't', 'i', 'f', 'i', 'c', '\n',
        'g', 'e', 'o', 's', 't', 'a', 't', 'i', 'o', 'n', 'a', 'r', 'y', '\n',
        'g', 'e', 'o', 's', 'y', 'n', 'c', 'h', 'r', 'o', 'n', 'o', 'u', 's', '\n',
        'g', 'e', 'o', 't', 'h', 'e', 'r', 'm', 'a', 'l', '\n',
        'g', 'e', 'r', 'a', 'n', 'i', 'u', 'm', '\n',
        'g', 'e', 'r', 'a', 'n', 'i', 'u', 'm', 's', '\n',
        'g', 'e', 'r', 'b', 'i', 'l', '\n',
        'g', 'e', 'r', 'b', 'i', 'l', 's', '\n',
        'g', 'e', 'r', 'i', 'a', 't', 'r', 'i', 'c', '\n',
        'g', 'e', 'r', 'i', 'a', 't', 'r', 'i', 'c', 's', '\n',
        'g', 'e', 'r', 'm', '\n',
        'g', 'e', 'r', 'm', 'a', 'n', '\n',
        'g', 'e', 'r', 'm', 'a', 'n', 'e', '\n',
        'g', 'e', 'r', 'm', 'a', 'n', 'i', 'c', '\n',
        'g', 'e', 'r', 'm', 'a', 'n', 'i', 'u', 'm', '\n',
        'g', 'e', 'r', 'm', 'a', 'n', 's', '\n',
        'g', 'e', 'r', 'm', 'a', 'n', 'y', '\n',
        'g', 'e', 'r', 'm', 'i', 'c', 'i', 'd', 'a', 'l', '\n',
        'g', 'e', 'r', 'm', 'i', 'c', 'i', 'd', 'e', 's', '\n',
        'g', 'e', 'r', 'm', 'i', 'n', 'a', 'l', '\n',
        'g', 'e', 'r', 'm', 'i', 'n', 'a', 't', 'e', '\n',
        'g', 'e', 'r', 'm', 'i', 'n', 'a', 't', 'e', 'd', '\n',
        'g', 'e', 'r', 'm', 'i', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'g', 'e', 'r', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'g', 'e', 'r', 'm', 's', '\n',
        'g', 'e', 'r', 'o', 'n', 't', 'o', 'c', 'r', 'a', 'c', 'y', '\n',
        'g', 'e', 'r', 'o', 'n', 't', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'g', 'e', 'r', 'o', 'n', 't', 'o', 'l', 'o', 'g', 'y', '\n',
        'g', 'e', 'r', 'r', 'y', 'm', 'a', 'n', 'd', 'e', 'r', '\n',
        'g', 'e', 'r', 'r', 'y', 'm', 'a', 'n', 'd', 'e', 'r', 'e', 'd', '\n',
        'g', 'e', 'r', 'u', 'n', 'd', '\n',
        'g', 'e', 'r', 'u', 'n', 'd', 'i', 'v', 'e', '\n',
        'g', 'e', 's', 't', 'a', 'l', 't', '\n',
        'g', 'e', 's', 't', 'a', 'p', 'o', '\n',
        'g', 'e', 's', 't', 'a', 't', 'e', '\n',
        'g', 'e', 's', 't', 'a', 't', 'i', 'n', 'g', '\n',
        'g', 'e', 's', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'g', 'e', 's', 't', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'g', 'e', 's', 't', 'i', 'c', 'u', 'l', 'a', 't', 'e', '\n',
        'g', 'e', 's', 't', 'i', 'c', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'g', 'e', 's', 't', 'i', 'c', 'u', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'g', 'e', 's', 't', 'i', 'c', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'g', 'e', 's', 't', 'i', 'c', 'u', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'g', 'e', 's', 't', 'u', 'r', 'a', 'l', '\n',
        'g', 'e', 's', 't', 'u', 'r', 'e', '\n',
        'g', 'e', 's', 't', 'u', 'r', 'e', 'd', '\n',
        'g', 'e', 's', 't', 'u', 'r', 'e', 's', '\n',
        'g', 'e', 's', 't', 'u', 'r', 'i', 'n', 'g', '\n',
        'g', 'e', 't', '\n',
        'g', 'e', 't', 'a', 'b', 'l', 'e', '\n',
        'g', 'e', 't', 'a', 'w', 'a', 'y', '\n',
        'g', 'e', 't', 'r', 'i', 'c', 'h', 'q', 'u', 'i', 'c', 'k', '\n',
        'g', 'e', 't', 's', '\n',
        'g', 'e', 't', 't', 'a', 'b', 'l', 'e', '\n',
        'g', 'e', 't', 't', 'e', 'r', '\n',
        'g', 'e', 't', 't', 'i', 'n', 'g', '\n',
        'g', 'e', 'y', 's', 'e', 'r', '\n',
        'g', 'e', 'y', 's', 'e', 'r', 's', '\n',
        'g', 'h', 'a', 'n', 'a', '\n',
        'g', 'h', 'a', 'n', 'i', 'a', 'n', '\n',
        'g', 'h', 'a', 's', 't', 'l', 'i', 'e', 'r', '\n',
        'g', 'h', 'a', 's', 't', 'l', 'i', 'e', 's', 't', '\n',
        'g', 'h', 'a', 's', 't', 'l', 'i', 'n', 'e', 's', 's', '\n',
        'g', 'h', 'a', 's', 't', 'l', 'y', '\n',
        'g', 'h', 'e', 'r', 'k', 'i', 'n', '\n',
        'g', 'h', 'e', 'r', 'k', 'i', 'n', 's', '\n',
        'g', 'h', 'e', 't', 't', 'o', '\n',
        'g', 'h', 'o', 's', 't', '\n',
        'g', 'h', 'o', 's', 't', 'e', 'd', '\n',
        'g', 'h', 'o', 's', 't', 'i', 'n', 'g', '\n',
        'g', 'h', 'o', 's', 't', 'l', 'i', 'e', 'r', '\n',
        'g', 'h', 'o', 's', 't', 'l', 'i', 'e', 's', 't', '\n',
        'g', 'h', 'o', 's', 't', 'l', 'i', 'k', 'e', '\n',
        'g', 'h', 'o', 's', 't', 'l', 'y', '\n',
        'g', 'h', 'o', 's', 't', 's', '\n',
        'g', 'h', 'o', 'u', 'l', '\n',
        'g', 'h', 'o', 'u', 'l', 'i', 's', 'h', '\n',
        'g', 'h', 'o', 'u', 'l', 's', '\n',
        'g', 'i', 'a', 'n', 't', '\n',
        'g', 'i', 'a', 'n', 't', 'e', 's', 's', '\n',
        'g', 'i', 'a', 'n', 't', 'i', 's', 'm', '\n',
        'g', 'i', 'a', 'n', 't', 'k', 'i', 'l', 'l', 'e', 'r', '\n',
        'g', 'i', 'a', 'n', 't', 'k', 'i', 'l', 'l', 'e', 'r', 's', '\n',
        'g', 'i', 'a', 'n', 't', 's', '\n',
        'g', 'i', 'b', 'b', 'e', 'r', '\n',
        'g', 'i', 'b', 'b', 'e', 'r', 'e', 'd', '\n',
        'g', 'i', 'b', 'b', 'e', 'r', 'i', 'n', 'g', '\n',
        'g', 'i', 'b', 'b', 'e', 'r', 'i', 's', 'h', '\n',
        'g', 'i', 'b', 'b', 'e', 't', '\n',
        'g', 'i', 'b', 'b', 'e', 't', 's', '\n',
        'g', 'i', 'b', 'b', 'o', 'n', '\n',
        'g', 'i', 'b', 'b', 'o', 'n', 's', '\n',
        'g', 'i', 'b', 'b', 'o', 'u', 's', '\n',
        'g', 'i', 'b', 'e', 'd', '\n',
        'g', 'i', 'b', 'e', 's', '\n',
        'g', 'i', 'b', 'l', 'e', 't', 's', '\n',
        'g', 'i', 'd', 'd', 'i', 'e', 'r', '\n',
        'g', 'i', 'd', 'd', 'i', 'e', 's', 't', '\n',
        'g', 'i', 'd', 'd', 'i', 'l', 'y', '\n',
        'g', 'i', 'd', 'd', 'i', 'n', 'e', 's', 's', '\n',
        'g', 'i', 'd', 'd', 'y', '\n',
        'g', 'i', 'f', 't', '\n',
        'g', 'i', 'f', 't', 'e', 'd', '\n',
        'g', 'i', 'f', 't', 'i', 'n', 'g', '\n',
        'g', 'i', 'f', 't', 's', '\n',
        'g', 'i', 'f', 't', 'w', 'a', 'r', 'e', '\n',
        'g', 'i', 'g', '\n',
        'g', 'i', 'g', 'a', 'b', 'y', 't', 'e', 's', '\n',
        'g', 'i', 'g', 'a', 'n', 't', 'i', 'c', '\n',
        'g', 'i', 'g', 'a', 'n', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'g', 'i', 'g', 'a', 'v', 'o', 'l', 't', '\n',
        'g', 'i', 'g', 'g', 'l', 'e', '\n',
        'g', 'i', 'g', 'g', 'l', 'e', 'd', '\n',
        'g', 'i', 'g', 'g', 'l', 'e', 's', '\n',
        'g', 'i', 'g', 'g', 'l', 'i', 'n', 'g', '\n',
        'g', 'i', 'g', 'g', 'l', 'y', '\n',
        'g', 'i', 'g', 'o', 'l', 'o', '\n',
        'g', 'i', 'l', 'd', 'e', 'd', '\n',
        'g', 'i', 'l', 'd', 'e', 'r', 's', '\n',
        'g', 'i', 'l', 'd', 'i', 'n', 'g', '\n',
        'g', 'i', 'l', 'd', 's', '\n',
        'g', 'i', 'l', 'l', '\n',
        'g', 'i', 'l', 'l', 'i', 'e', '\n',
        'g', 'i', 'l', 'l', 's', '\n',
        'g', 'i', 'l', 't', '\n',
        'g', 'i', 'l', 't', 'e', 'd', 'g', 'e', 'd', '\n',
        'g', 'i', 'l', 't', 's', '\n',
        'g', 'i', 'm', 'c', 'r', 'a', 'c', 'k', '\n',
        'g', 'i', 'm', 'l', 'e', 't', '\n',
        'g', 'i', 'm', 'l', 'e', 't', 's', '\n',
        'g', 'i', 'm', 'm', 'i', 'c', 'k', '\n',
        'g', 'i', 'm', 'm', 'i', 'c', 'k', 'r', 'y', '\n',
        'g', 'i', 'm', 'm', 'i', 'c', 'k', 's', '\n',
        'g', 'i', 'm', 'm', 'i', 'c', 'k', 'y', '\n',
        'g', 'i', 'n', '\n',
        'g', 'i', 'n', 'g', 'e', 'r', '\n',
        'g', 'i', 'n', 'g', 'e', 'r', 'b', 'r', 'e', 'a', 'd', '\n',
        'g', 'i', 'n', 'g', 'e', 'r', 'l', 'y', '\n',
        'g', 'i', 'n', 'g', 'e', 'r', 's', '\n',
        'g', 'i', 'n', 'g', 'e', 'r', 'y', '\n',
        'g', 'i', 'n', 'g', 'h', 'a', 'm', '\n',
        'g', 'i', 'n', 'g', 'i', 'v', 'i', 't', 'i', 's', '\n',
        'g', 'i', 'n', 's', '\n',
        'g', 'i', 'n', 's', 'e', 'n', 'g', '\n',
        'g', 'i', 'p', 's', 'i', 'e', 's', '\n',
        'g', 'i', 'p', 's', 'y', '\n',
        'g', 'i', 'r', 'a', 'f', 'f', 'e', '\n',
        'g', 'i', 'r', 'a', 'f', 'f', 'e', 's', '\n',
        'g', 'i', 'r', 'd', '\n',
        'g', 'i', 'r', 'd', 'e', 'd', '\n',
        'g', 'i', 'r', 'd', 'e', 'r', '\n',
        'g', 'i', 'r', 'd', 'e', 'r', 's', '\n',
        'g', 'i', 'r', 'd', 'i', 'n', 'g', '\n',
        'g', 'i', 'r', 'd', 'l', 'e', '\n',
        'g', 'i', 'r', 'd', 'l', 'e', 'd', '\n',
        'g', 'i', 'r', 'd', 'l', 'e', 's', '\n',
        'g', 'i', 'r', 'd', 'l', 'i', 'n', 'g', '\n',
        'g', 'i', 'r', 'l', '\n',
        'g', 'i', 'r', 'l', 'f', 'r', 'i', 'e', 'n', 'd', '\n',
        'g', 'i', 'r', 'l', 'f', 'r', 'i', 'e', 'n', 'd', 's', '\n',
        'g', 'i', 'r', 'l', 'h', 'o', 'o', 'd', '\n',
        'g', 'i', 'r', 'l', 'i', 'e', '\n',
        'g', 'i', 'r', 'l', 'i', 's', 'h', '\n',
        'g', 'i', 'r', 'l', 'i', 's', 'h', 'l', 'y', '\n',
        'g', 'i', 'r', 'l', 'i', 's', 'h', 'n', 'e', 's', 's', '\n',
        'g', 'i', 'r', 'l', 's', '\n',
        'g', 'i', 'r', 'o', '\n',
        'g', 'i', 'r', 't', '\n',
        'g', 'i', 'r', 't', 'h', '\n',
        'g', 'i', 'r', 't', 'h', 's', '\n',
        'g', 'i', 's', 't', '\n',
        'g', 'i', 'v', 'e', '\n',
        'g', 'i', 'v', 'e', 'a', 'w', 'a', 'y', '\n',
        'g', 'i', 'v', 'e', 'n', '\n',
        'g', 'i', 'v', 'e', 'r', '\n',
        'g', 'i', 'v', 'e', 'r', 's', '\n',
        'g', 'i', 'v', 'e', 's', '\n',
        'g', 'i', 'v', 'i', 'n', 'g', '\n',
        'g', 'i', 'v', 'i', 'n', 'g', 's', '\n',
        'g', 'i', 'z', 'z', 'a', 'r', 'd', '\n',
        'g', 'l', 'a', 'c', 'e', '\n',
        'g', 'l', 'a', 'c', 'i', 'a', 'l', '\n',
        'g', 'l', 'a', 'c', 'i', 'a', 'l', 'l', 'y', '\n',
        'g', 'l', 'a', 'c', 'i', 'a', 't', 'e', 'd', '\n',
        'g', 'l', 'a', 'c', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'g', 'l', 'a', 'c', 'i', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'g', 'l', 'a', 'c', 'i', 'e', 'r', '\n',
        'g', 'l', 'a', 'c', 'i', 'e', 'r', 's', '\n',
        'g', 'l', 'a', 'c', 'i', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'g', 'l', 'a', 'c', 'i', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'g', 'l', 'a', 'c', 'i', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'g', 'l', 'a', 'c', 'i', 'o', 'l', 'o', 'g', 'y', '\n',
        'g', 'l', 'a', 'd', '\n',
        'g', 'l', 'a', 'd', 'd', 'e', 'n', '\n',
        'g', 'l', 'a', 'd', 'd', 'e', 'n', 'e', 'd', '\n',
        'g', 'l', 'a', 'd', 'd', 'e', 'n', 'i', 'n', 'g', '\n',
        'g', 'l', 'a', 'd', 'd', 'e', 'n', 's', '\n',
        'g', 'l', 'a', 'd', 'd', 'e', 'r', '\n',
        'g', 'l', 'a', 'd', 'd', 'e', 's', 't', '\n',
        'g', 'l', 'a', 'd', 'e', '\n',
        'g', 'l', 'a', 'd', 'e', 's', '\n',
        'g', 'l', 'a', 'd', 'i', 'a', 't', 'o', 'r', '\n',
        'g', 'l', 'a', 'd', 'i', 'a', 't', 'o', 'r', 'i', 'a', 'l', '\n',
        'g', 'l', 'a', 'd', 'i', 'a', 't', 'o', 'r', 's', '\n',
        'g', 'l', 'a', 'd', 'i', 'o', 'l', 'i', '\n',
        'g', 'l', 'a', 'd', 'i', 'o', 'l', 'u', 's', '\n',
        'g', 'l', 'a', 'd', 'l', 'y', '\n',
        'g', 'l', 'a', 'd', 'n', 'e', 's', 's', '\n',
        'g', 'l', 'a', 'm', 'o', 'r', 'o', 'u', 's', '\n',
        'g', 'l', 'a', 'm', 'o', 'u', 'r', '\n',
        'g', 'l', 'a', 'n', 'c', 'e', '\n',
        'g', 'l', 'a', 'n', 'c', 'e', 'd', '\n',
        'g', 'l', 'a', 'n', 'c', 'e', 's', '\n',
        'g', 'l', 'a', 'n', 'c', 'i', 'n', 'g', '\n',
        'g', 'l', 'a', 'n', 'd', '\n',
        'g', 'l', 'a', 'n', 'd', 's', '\n',
        'g', 'l', 'a', 'n', 'd', 'u', 'l', 'a', 'r', '\n',
        'g', 'l', 'a', 'n', 's', '\n',
        'g', 'l', 'a', 'r', 'e', '\n',
        'g', 'l', 'a', 'r', 'e', 'd', '\n',
        'g', 'l', 'a', 'r', 'e', 's', '\n',
        'g', 'l', 'a', 'r', 'i', 'n', 'g', '\n',
        'g', 'l', 'a', 'r', 'i', 'n', 'g', 'l', 'y', '\n',
        'g', 'l', 'a', 's', 'g', 'o', 'w', '\n',
        'g', 'l', 'a', 's', 'n', 'o', 's', 't', '\n',
        'g', 'l', 'a', 's', 's', '\n',
        'g', 'l', 'a', 's', 's', 'e', 'd', '\n',
        'g', 'l', 'a', 's', 's', 'e', 's', '\n',
        'g', 'l', 'a', 's', 's', 'f', 'u', 'l', '\n',
        'g', 'l', 'a', 's', 's', 'h', 'o', 'u', 's', 'e', '\n',
        'g', 'l', 'a', 's', 's', 'h', 'o', 'u', 's', 'e', 's', '\n',
        'g', 'l', 'a', 's', 's', 'i', 'e', 'r', '\n',
        'g', 'l', 'a', 's', 's', 'i', 'e', 's', 't', '\n',
        'g', 'l', 'a', 's', 's', 'l', 'e', 's', 's', '\n',
        'g', 'l', 'a', 's', 's', 'w', 'a', 'r', 'e', '\n',
        'g', 'l', 'a', 's', 's', 'y', '\n',
        'g', 'l', 'a', 'u', 'c', 'o', 'm', 'a', '\n',
        'g', 'l', 'a', 'u', 'c', 'o', 'u', 's', '\n',
        'g', 'l', 'a', 'z', 'e', '\n',
        'g', 'l', 'a', 'z', 'e', 'd', '\n',
        'g', 'l', 'a', 'z', 'e', 'r', '\n',
        'g', 'l', 'a', 'z', 'e', 's', '\n',
        'g', 'l', 'a', 'z', 'i', 'e', 'r', '\n',
        'g', 'l', 'a', 'z', 'i', 'e', 'r', 's', '\n',
        'g', 'l', 'a', 'z', 'i', 'n', 'g', '\n',
        'g', 'l', 'e', 'a', 'm', '\n',
        'g', 'l', 'e', 'a', 'm', 'e', 'd', '\n',
        'g', 'l', 'e', 'a', 'm', 'i', 'n', 'g', '\n',
        'g', 'l', 'e', 'a', 'm', 's', '\n',
        'g', 'l', 'e', 'a', 'n', '\n',
        'g', 'l', 'e', 'a', 'n', 'e', 'd', '\n',
        'g', 'l', 'e', 'a', 'n', 'i', 'n', 'g', '\n',
        'g', 'l', 'e', 'a', 'n', 'i', 'n', 'g', 's', '\n',
        'g', 'l', 'e', 'a', 'n', 's', '\n',
        'g', 'l', 'e', 'b', 'e', '\n',
        'g', 'l', 'e', 'e', '\n',
        'g', 'l', 'e', 'e', 'f', 'u', 'l', '\n',
        'g', 'l', 'e', 'e', 'f', 'u', 'l', 'l', 'y', '\n',
        'g', 'l', 'e', 'e', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'g', 'l', 'e', 'n', '\n',
        'g', 'l', 'e', 'n', 'n', '\n',
        'g', 'l', 'e', 'n', 's', '\n',
        'g', 'l', 'i', 'a', '\n',
        'g', 'l', 'i', 'b', '\n',
        'g', 'l', 'i', 'b', 'l', 'y', '\n',
        'g', 'l', 'i', 'b', 'n', 'e', 's', 's', '\n',
        'g', 'l', 'i', 'd', 'e', '\n',
        'g', 'l', 'i', 'd', 'e', 'd', '\n',
        'g', 'l', 'i', 'd', 'e', 'r', '\n',
        'g', 'l', 'i', 'd', 'e', 'r', 's', '\n',
        'g', 'l', 'i', 'd', 'e', 's', '\n',
        'g', 'l', 'i', 'd', 'i', 'n', 'g', '\n',
        'g', 'l', 'i', 'm', '\n',
        'g', 'l', 'i', 'm', 'm', 'e', 'r', '\n',
        'g', 'l', 'i', 'm', 'm', 'e', 'r', 'e', 'd', '\n',
        'g', 'l', 'i', 'm', 'm', 'e', 'r', 'i', 'n', 'g', '\n',
        'g', 'l', 'i', 'm', 'm', 'e', 'r', 'i', 'n', 'g', 's', '\n',
        'g', 'l', 'i', 'm', 'm', 'e', 'r', 's', '\n',
        'g', 'l', 'i', 'm', 'p', 's', 'e', '\n',
        'g', 'l', 'i', 'm', 'p', 's', 'e', 'd', '\n',
        'g', 'l', 'i', 'm', 'p', 's', 'e', 's', '\n',
        'g', 'l', 'i', 'm', 'p', 's', 'i', 'n', 'g', '\n',
        'g', 'l', 'i', 'n', 't', '\n',
        'g', 'l', 'i', 'n', 't', 'e', 'd', '\n',
        'g', 'l', 'i', 'n', 't', 'i', 'n', 'g', '\n',
        'g', 'l', 'i', 'n', 't', 's', '\n',
        'g', 'l', 'i', 's', 't', 'e', 'n', '\n',
        'g', 'l', 'i', 's', 't', 'e', 'n', 'e', 'd', '\n',
        'g', 'l', 'i', 's', 't', 'e', 'n', 'i', 'n', 'g', '\n',
        'g', 'l', 'i', 's', 't', 'e', 'n', 's', '\n',
        'g', 'l', 'i', 't', 't', 'e', 'r', '\n',
        'g', 'l', 'i', 't', 't', 'e', 'r', 'e', 'd', '\n',
        'g', 'l', 'i', 't', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'g', 'l', 'i', 't', 't', 'e', 'r', 's', '\n',
        'g', 'l', 'i', 't', 't', 'e', 'r', 'y', '\n',
        'g', 'l', 'i', 't', 'z', 'y', '\n',
        'g', 'l', 'o', 'a', 'm', 'i', 'n', 'g', '\n',
        'g', 'l', 'o', 'a', 't', '\n',
        'g', 'l', 'o', 'a', 't', 'e', 'd', '\n',
        'g', 'l', 'o', 'a', 't', 'i', 'n', 'g', '\n',
        'g', 'l', 'o', 'b', '\n',
        'g', 'l', 'o', 'b', 'a', 'l', '\n',
        'g', 'l', 'o', 'b', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'g', 'l', 'o', 'b', 'a', 'l', 'l', 'y', '\n',
        'g', 'l', 'o', 'b', 'e', '\n',
        'g', 'l', 'o', 'b', 'e', 'd', '\n',
        'g', 'l', 'o', 'b', 'e', 's', '\n',
        'g', 'l', 'o', 'b', 'e', 't', 'r', 'o', 't', 't', 'e', 'r', 's', '\n',
        'g', 'l', 'o', 'b', 'e', 't', 'r', 'o', 't', 't', 'i', 'n', 'g', '\n',
        'g', 'l', 'o', 'b', 'o', 's', 'e', '\n',
        'g', 'l', 'o', 'b', 'u', 'l', 'a', 'r', '\n',
        'g', 'l', 'o', 'b', 'u', 'l', 'e', '\n',
        'g', 'l', 'o', 'b', 'u', 'l', 'e', 's', '\n',
        'g', 'l', 'o', 'o', 'm', '\n',
        'g', 'l', 'o', 'o', 'm', 'f', 'u', 'l', '\n',
        'g', 'l', 'o', 'o', 'm', 'i', 'e', 'r', '\n',
        'g', 'l', 'o', 'o', 'm', 'i', 'e', 's', 't', '\n',
        'g', 'l', 'o', 'o', 'm', 'i', 'l', 'y', '\n',
        'g', 'l', 'o', 'o', 'm', 'i', 'n', 'e', 's', 's', '\n',
        'g', 'l', 'o', 'o', 'm', 's', '\n',
        'g', 'l', 'o', 'o', 'm', 'y', '\n',
        'g', 'l', 'o', 'r', 'i', 'e', 'd', '\n',
        'g', 'l', 'o', 'r', 'i', 'e', 's', '\n',
        'g', 'l', 'o', 'r', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'g', 'l', 'o', 'r', 'i', 'f', 'i', 'e', 'd', '\n',
        'g', 'l', 'o', 'r', 'i', 'f', 'i', 'e', 's', '\n',
        'g', 'l', 'o', 'r', 'i', 'f', 'y', '\n',
        'g', 'l', 'o', 'r', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'g', 'l', 'o', 'r', 'i', 'o', 'u', 's', '\n',
        'g', 'l', 'o', 'r', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'g', 'l', 'o', 'r', 'y', '\n',
        'g', 'l', 'o', 'r', 'y', 'i', 'n', 'g', '\n',
        'g', 'l', 'o', 's', 's', '\n',
        'g', 'l', 'o', 's', 's', 'a', 'r', 'i', 'e', 's', '\n',
        'g', 'l', 'o', 's', 's', 'a', 'r', 'y', '\n',
        'g', 'l', 'o', 's', 's', 'e', 'd', '\n',
        'g', 'l', 'o', 's', 's', 'e', 's', '\n',
        'g', 'l', 'o', 's', 's', 'i', 'e', 'r', '\n',
        'g', 'l', 'o', 's', 's', 'i', 'e', 's', 't', '\n',
        'g', 'l', 'o', 's', 's', 'i', 'l', 'y', '\n',
        'g', 'l', 'o', 's', 's', 'i', 'n', 'g', '\n',
        'g', 'l', 'o', 's', 's', 'y', '\n',
        'g', 'l', 'o', 't', 't', 'a', 'l', '\n',
        'g', 'l', 'o', 'v', 'e', '\n',
        'g', 'l', 'o', 'v', 'e', 'd', '\n',
        'g', 'l', 'o', 'v', 'e', 's', '\n',
        'g', 'l', 'o', 'w', '\n',
        'g', 'l', 'o', 'w', 'e', 'd', '\n',
        'g', 'l', 'o', 'w', 'e', 'r', '\n',
        'g', 'l', 'o', 'w', 'e', 'r', 'e', 'd', '\n',
        'g', 'l', 'o', 'w', 'e', 'r', 'i', 'n', 'g', '\n',
        'g', 'l', 'o', 'w', 'e', 'r', 's', '\n',
        'g', 'l', 'o', 'w', 'i', 'n', 'g', '\n',
        'g', 'l', 'o', 'w', 'i', 'n', 'g', 'l', 'y', '\n',
        'g', 'l', 'o', 'w', 's', '\n',
        'g', 'l', 'o', 'w', 'w', 'o', 'r', 'm', '\n',
        'g', 'l', 'o', 'w', 'w', 'o', 'r', 'm', 's', '\n',
        'g', 'l', 'u', 'c', 'o', 's', 'e', '\n',
        'g', 'l', 'u', 'e', '\n',
        'g', 'l', 'u', 'e', 'd', '\n',
        'g', 'l', 'u', 'e', 'i', 'n', 'g', '\n',
        'g', 'l', 'u', 'e', 's', '\n',
        'g', 'l', 'u', 'e', 'y', '\n',
        'g', 'l', 'u', 'i', 'n', 'g', '\n',
        'g', 'l', 'u', 'm', '\n',
        'g', 'l', 'u', 'm', 'l', 'y', '\n',
        'g', 'l', 'u', 'o', 'n', '\n',
        'g', 'l', 'u', 't', '\n',
        'g', 'l', 'u', 't', 'a', 'm', 'a', 't', 'e', '\n',
        'g', 'l', 'u', 't', 'e', 'n', '\n',
        'g', 'l', 'u', 't', 'i', 'n', 'o', 'u', 's', '\n',
        'g', 'l', 'u', 't', 't', 'e', 'd', '\n',
        'g', 'l', 'u', 't', 't', 'o', 'n', '\n',
        'g', 'l', 'u', 't', 't', 'o', 'n', 'o', 'u', 's', '\n',
        'g', 'l', 'u', 't', 't', 'o', 'n', 's', '\n',
        'g', 'l', 'u', 't', 't', 'o', 'n', 'y', '\n',
        'g', 'l', 'y', 'c', 'e', 'r', 'i', 'n', 'e', '\n',
        'g', 'l', 'y', 'c', 'e', 'r', 'o', 'l', '\n',
        'g', 'l', 'y', 'c', 'i', 'n', 'e', '\n',
        'g', 'l', 'y', 'c', 'o', 'l', '\n',
        'g', 'l', 'y', 'p', 'h', '\n',
        'g', 'l', 'y', 'p', 'h', 's', '\n',
        'g', 'n', 'a', 'r', 'l', '\n',
        'g', 'n', 'a', 'r', 'l', 'e', 'd', '\n',
        'g', 'n', 'a', 'r', 'l', 'i', 'n', 'g', '\n',
        'g', 'n', 'a', 'r', 'l', 's', '\n',
        'g', 'n', 'a', 's', 'h', '\n',
        'g', 'n', 'a', 's', 'h', 'e', 'd', '\n',
        'g', 'n', 'a', 's', 'h', 'e', 's', '\n',
        'g', 'n', 'a', 's', 'h', 'i', 'n', 'g', '\n',
        'g', 'n', 'a', 't', '\n',
        'g', 'n', 'a', 't', 's', '\n',
        'g', 'n', 'a', 'w', '\n',
        'g', 'n', 'a', 'w', 'e', 'd', '\n',
        'g', 'n', 'a', 'w', 'e', 'r', '\n',
        'g', 'n', 'a', 'w', 'e', 'r', 's', '\n',
        'g', 'n', 'a', 'w', 'i', 'n', 'g', '\n',
        'g', 'n', 'a', 'w', 's', '\n',
        'g', 'n', 'e', 'i', 's', 's', '\n',
        'g', 'n', 'o', 'm', 'e', '\n',
        'g', 'n', 'o', 'm', 'e', 's', '\n',
        'g', 'n', 'o', 'm', 'i', 'c', '\n',
        'g', 'n', 'o', 's', 't', 'i', 'c', '\n',
        'g', 'n', 'o', 's', 't', 'i', 'c', 'i', 's', 'm', '\n',
        'g', 'n', 'u', '\n',
        'g', 'n', 'u', 's', '\n',
        'g', 'o', '\n',
        'g', 'o', 'a', 'd', '\n',
        'g', 'o', 'a', 'd', 'e', 'd', '\n',
        'g', 'o', 'a', 'd', 'i', 'n', 'g', '\n',
        'g', 'o', 'a', 'd', 's', '\n',
        'g', 'o', 'a', 'h', 'e', 'a', 'd', '\n',
        'g', 'o', 'a', 'l', '\n',
        'g', 'o', 'a', 'l', 'i', 'e', 's', '\n',
        'g', 'o', 'a', 'l', 'k', 'e', 'e', 'p', 'e', 'r', '\n',
        'g', 'o', 'a', 'l', 'k', 'e', 'e', 'p', 'e', 'r', 's', '\n',
        'g', 'o', 'a', 'l', 'k', 'e', 'e', 'p', 'i', 'n', 'g', '\n',
        'g', 'o', 'a', 'l', 'l', 'e', 's', 's', '\n',
        'g', 'o', 'a', 'l', 'm', 'o', 'u', 't', 'h', '\n',
        'g', 'o', 'a', 'l', 'p', 'o', 's', 't', '\n',
        'g', 'o', 'a', 'l', 'p', 'o', 's', 't', 's', '\n',
        'g', 'o', 'a', 'l', 's', '\n',
        'g', 'o', 'a', 'l', 's', 'c', 'o', 'r', 'e', 'r', '\n',
        'g', 'o', 'a', 'l', 's', 'c', 'o', 'r', 'e', 'r', 's', '\n',
        'g', 'o', 'a', 'l', 's', 'c', 'o', 'r', 'i', 'n', 'g', '\n',
        'g', 'o', 'a', 't', '\n',
        'g', 'o', 'a', 't', 'e', 'e', '\n',
        'g', 'o', 'a', 't', 'e', 'e', 's', '\n',
        'g', 'o', 'a', 't', 's', '\n',
        'g', 'o', 'a', 't', 's', 'k', 'i', 'n', '\n',
        'g', 'o', 'b', 'b', 'e', 't', '\n',
        'g', 'o', 'b', 'b', 'e', 't', 's', '\n',
        'g', 'o', 'b', 'b', 'l', 'e', '\n',
        'g', 'o', 'b', 'b', 'l', 'e', 'd', '\n',
        'g', 'o', 'b', 'b', 'l', 'e', 'd', 'e', 'g', 'o', 'o', 'k', '\n',
        'g', 'o', 'b', 'b', 'l', 'e', 'd', 'y', 'g', 'o', 'o', 'k', '\n',
        'g', 'o', 'b', 'b', 'l', 'e', 'r', '\n',
        'g', 'o', 'b', 'b', 'l', 'e', 's', '\n',
        'g', 'o', 'b', 'b', 'l', 'i', 'n', 'g', '\n',
        'g', 'o', 'b', 'e', 't', 'w', 'e', 'e', 'n', '\n',
        'g', 'o', 'b', 'i', '\n',
        'g', 'o', 'b', 'i', 'e', 's', '\n',
        'g', 'o', 'b', 'l', 'e', 't', '\n',
        'g', 'o', 'b', 'l', 'e', 't', 's', '\n',
        'g', 'o', 'b', 'l', 'i', 'n', '\n',
        'g', 'o', 'b', 'l', 'i', 'n', 's', '\n',
        'g', 'o', 'd', '\n',
        'g', 'o', 'd', 'c', 'h', 'i', 'l', 'd', '\n',
        'g', 'o', 'd', 'd', 'e', 's', 's', '\n',
        'g', 'o', 'd', 'd', 'e', 's', 's', 'e', 's', '\n',
        'g', 'o', 'd', 'f', 'a', 't', 'h', 'e', 'r', '\n',
        'g', 'o', 'd', 'f', 'a', 't', 'h', 'e', 'r', 's', '\n',
        'g', 'o', 'd', 'f', 'o', 'r', 's', 'a', 'k', 'e', 'n', '\n',
        'g', 'o', 'd', 'h', 'e', 'a', 'd', '\n',
        'g', 'o', 'd', 'l', 'e', 's', 's', '\n',
        'g', 'o', 'd', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'g', 'o', 'd', 'l', 'i', 'e', 'r', '\n',
        'g', 'o', 'd', 'l', 'i', 'k', 'e', '\n',
        'g', 'o', 'd', 'l', 'i', 'n', 'e', 's', 's', '\n',
        'g', 'o', 'd', 'l', 'y', '\n',
        'g', 'o', 'd', 'm', 'o', 't', 'h', 'e', 'r', '\n',
        'g', 'o', 'd', 'm', 'o', 't', 'h', 'e', 'r', 's', '\n',
        'g', 'o', 'd', 'p', 'a', 'r', 'e', 'n', 't', 's', '\n',
        'g', 'o', 'd', 's', '\n',
        'g', 'o', 'd', 's', 'e', 'n', 'd', '\n',
        'g', 'o', 'd', 's', 'o', 'n', '\n',
        'g', 'o', 'd', 's', 'o', 'n', 's', '\n',
        'g', 'o', 'e', 'r', '\n',
        'g', 'o', 'e', 'r', 's', '\n',
        'g', 'o', 'e', 's', '\n',
        'g', 'o', 'e', 't', 'h', 'e', '\n',
        'g', 'o', 'f', 'e', 'r', '\n',
        'g', 'o', 'g', 'g', 'l', 'e', 'd', '\n',
        'g', 'o', 'g', 'g', 'l', 'e', 's', '\n',
        'g', 'o', 'g', 'g', 'l', 'i', 'n', 'g', '\n',
        'g', 'o', 'i', 'n', 'g', '\n',
        'g', 'o', 'i', 'n', 'g', 's', '\n',
        'g', 'o', 'i', 't', 'r', 'e', '\n',
        'g', 'o', 'i', 't', 'r', 'e', 's', '\n',
        'g', 'o', 'l', 'd', '\n',
        'g', 'o', 'l', 'd', 'e', 'n', '\n',
        'g', 'o', 'l', 'd', 'f', 'i', 's', 'h', '\n',
        'g', 'o', 'l', 'd', 's', '\n',
        'g', 'o', 'l', 'd', 's', 'm', 'i', 't', 'h', '\n',
        'g', 'o', 'l', 'd', 's', 'm', 'i', 't', 'h', 's', '\n',
        'g', 'o', 'l', 'f', '\n',
        'g', 'o', 'l', 'f', 'e', 'r', '\n',
        'g', 'o', 'l', 'f', 'e', 'r', 's', '\n',
        'g', 'o', 'l', 'f', 'i', 'n', 'g', '\n',
        'g', 'o', 'l', 'g', 'o', 't', 'h', 'a', '\n',
        'g', 'o', 'l', 'i', 'a', 't', 'h', '\n',
        'g', 'o', 'l', 'l', 'i', 'w', 'o', 'g', '\n',
        'g', 'o', 'l', 'l', 'y', '\n',
        'g', 'o', 'n', 'a', 'd', '\n',
        'g', 'o', 'n', 'a', 'd', 's', '\n',
        'g', 'o', 'n', 'd', 'o', 'l', 'a', '\n',
        'g', 'o', 'n', 'd', 'o', 'l', 'a', 's', '\n',
        'g', 'o', 'n', 'd', 'o', 'l', 'i', 'e', 'r', '\n',
        'g', 'o', 'n', 'd', 'o', 'l', 'i', 'e', 'r', 's', '\n',
        'g', 'o', 'n', 'e', '\n',
        'g', 'o', 'n', 'g', '\n',
        'g', 'o', 'n', 'g', 's', '\n',
        'g', 'o', 'n', 'o', 'r', 'r', 'h', 'o', 'e', 'a', '\n',
        'g', 'o', 'o', '\n',
        'g', 'o', 'o', 'd', '\n',
        'g', 'o', 'o', 'd', 'b', 'y', 'e', '\n',
        'g', 'o', 'o', 'd', 'b', 'y', 'e', 's', '\n',
        'g', 'o', 'o', 'd', 'f', 'o', 'r', 'n', 'o', 't', 'h', 'i', 'n', 'g', '\n',
        'g', 'o', 'o', 'd', 'f', 'o', 'r', 'n', 'o', 't', 'h', 'i', 'n', 'g', 's', '\n',
        'g', 'o', 'o', 'd', 'h', 'o', 'p', 'e', '\n',
        'g', 'o', 'o', 'd', 'h', 'u', 'm', 'o', 'u', 'r', 'e', 'd', '\n',
        'g', 'o', 'o', 'd', 'h', 'u', 'm', 'o', 'u', 'r', 'e', 'd', 'l', 'y', '\n',
        'g', 'o', 'o', 'd', 'i', 'e', 's', '\n',
        'g', 'o', 'o', 'd', 'i', 's', 'h', '\n',
        'g', 'o', 'o', 'd', 'l', 'o', 'o', 'k', 'i', 'n', 'g', '\n',
        'g', 'o', 'o', 'd', 'l', 'y', '\n',
        'g', 'o', 'o', 'd', 'n', 'a', 't', 'u', 'r', 'e', 'd', '\n',
        'g', 'o', 'o', 'd', 'n', 'a', 't', 'u', 'r', 'e', 'd', 'l', 'y', '\n',
        'g', 'o', 'o', 'd', 'n', 'e', 's', 's', '\n',
        'g', 'o', 'o', 'd', 'n', 'i', 'g', 'h', 't', '\n',
        'g', 'o', 'o', 'd', 's', '\n',
        'g', 'o', 'o', 'd', 't', 'e', 'm', 'p', 'e', 'r', 'e', 'd', '\n',
        'g', 'o', 'o', 'd', 'w', 'i', 'l', 'l', '\n',
        'g', 'o', 'o', 'd', 'y', '\n',
        'g', 'o', 'o', 'e', 'y', '\n',
        'g', 'o', 'o', 'f', '\n',
        'g', 'o', 'o', 'f', 'e', 'd', '\n',
        'g', 'o', 'o', 'f', 'i', 'n', 'g', '\n',
        'g', 'o', 'o', 'f', 's', '\n',
        'g', 'o', 'o', 'f', 'y', '\n',
        'g', 'o', 'o', 'g', 'l', 'i', 'e', 's', '\n',
        'g', 'o', 'o', 'g', 'l', 'y', '\n',
        'g', 'o', 'o', 'n', '\n',
        'g', 'o', 'o', 'n', 's', '\n',
        'g', 'o', 'o', 's', 'e', '\n',
        'g', 'o', 'o', 's', 'e', 'b', 'e', 'r', 'r', 'i', 'e', 's', '\n',
        'g', 'o', 'o', 's', 'e', 'b', 'e', 'r', 'r', 'y', '\n',
        'g', 'o', 'o', 's', 'e', 's', 't', 'e', 'p', '\n',
        'g', 'o', 'o', 's', 'e', 's', 't', 'e', 'p', 'p', 'i', 'n', 'g', '\n',
        'g', 'o', 'p', 'h', 'e', 'r', '\n',
        'g', 'o', 'p', 'h', 'e', 'r', 's', '\n',
        'g', 'o', 'r', 'd', 'i', 'a', 'n', '\n',
        'g', 'o', 'r', 'e', '\n',
        'g', 'o', 'r', 'e', 'd', '\n',
        'g', 'o', 'r', 'e', 's', '\n',
        'g', 'o', 'r', 'g', 'e', '\n',
        'g', 'o', 'r', 'g', 'e', 'd', '\n',
        'g', 'o', 'r', 'g', 'e', 'o', 'u', 's', '\n',
        'g', 'o', 'r', 'g', 'e', 'o', 'u', 's', 'l', 'y', '\n',
        'g', 'o', 'r', 'g', 'e', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'g', 'o', 'r', 'g', 'e', 's', '\n',
        'g', 'o', 'r', 'g', 'i', 'n', 'g', '\n',
        'g', 'o', 'r', 'g', 'o', 'n', '\n',
        'g', 'o', 'r', 'g', 'o', 'n', 's', '\n',
        'g', 'o', 'r', 'i', 'e', 'r', '\n',
        'g', 'o', 'r', 'i', 'e', 's', 't', '\n',
        'g', 'o', 'r', 'i', 'l', 'l', 'a', '\n',
        'g', 'o', 'r', 'i', 'l', 'l', 'a', 's', '\n',
        'g', 'o', 'r', 'i', 'n', 'g', '\n',
        'g', 'o', 'r', 'm', 'l', 'e', 's', 's', '\n',
        'g', 'o', 'r', 's', 'e', '\n',
        'g', 'o', 'r', 'y', '\n',
        'g', 'o', 's', 'h', '\n',
        'g', 'o', 's', 'l', 'i', 'n', 'g', '\n',
        'g', 'o', 's', 'l', 'i', 'n', 'g', 's', '\n',
        'g', 'o', 's', 'l', 'o', 'w', '\n',
        'g', 'o', 's', 'l', 'o', 'w', 's', '\n',
        'g', 'o', 's', 'p', 'e', 'l', '\n',
        'g', 'o', 's', 'p', 'e', 'l', 's', '\n',
        'g', 'o', 's', 's', 'a', 'm', 'e', 'r', '\n',
        'g', 'o', 's', 's', 'i', 'p', '\n',
        'g', 'o', 's', 's', 'i', 'p', 'e', 'd', '\n',
        'g', 'o', 's', 's', 'i', 'p', 'i', 'n', 'g', '\n',
        'g', 'o', 's', 's', 'i', 'p', 's', '\n',
        'g', 'o', 's', 's', 'i', 'p', 'y', '\n',
        'g', 'o', 't', '\n',
        'g', 'o', 't', 'h', '\n',
        'g', 'o', 't', 'h', 'i', 'c', '\n',
        'g', 'o', 't', 'h', 's', '\n',
        'g', 'o', 't', 't', 'e', 'n', '\n',
        'g', 'o', 'u', 'd', 'a', '\n',
        'g', 'o', 'u', 'g', 'e', '\n',
        'g', 'o', 'u', 'g', 'e', 'd', '\n',
        'g', 'o', 'u', 'g', 'e', 's', '\n',
        'g', 'o', 'u', 'g', 'i', 'n', 'g', '\n',
        'g', 'o', 'u', 'l', 'a', 's', 'h', '\n',
        'g', 'o', 'u', 'r', 'd', '\n',
        'g', 'o', 'u', 'r', 'd', 's', '\n',
        'g', 'o', 'u', 'r', 'm', 'a', 'n', 'd', '\n',
        'g', 'o', 'u', 'r', 'm', 'e', 't', '\n',
        'g', 'o', 'u', 'r', 'm', 'e', 't', 's', '\n',
        'g', 'o', 'u', 't', '\n',
        'g', 'o', 'v', 'e', 'r', 'n', '\n',
        'g', 'o', 'v', 'e', 'r', 'n', 'a', 'n', 'c', 'e', '\n',
        'g', 'o', 'v', 'e', 'r', 'n', 'e', 'd', '\n',
        'g', 'o', 'v', 'e', 'r', 'n', 'e', 's', 's', '\n',
        'g', 'o', 'v', 'e', 'r', 'n', 'e', 's', 's', 'e', 's', '\n',
        'g', 'o', 'v', 'e', 'r', 'n', 'i', 'n', 'g', '\n',
        'g', 'o', 'v', 'e', 'r', 'n', 'm', 'e', 'n', 't', '\n',
        'g', 'o', 'v', 'e', 'r', 'n', 'm', 'e', 'n', 't', 'a', 'l', '\n',
        'g', 'o', 'v', 'e', 'r', 'n', 'm', 'e', 'n', 't', 's', '\n',
        'g', 'o', 'v', 'e', 'r', 'n', 'o', 'r', '\n',
        'g', 'o', 'v', 'e', 'r', 'n', 'o', 'r', 's', '\n',
        'g', 'o', 'v', 'e', 'r', 'n', 'o', 'r', 's', 'h', 'i', 'p', '\n',
        'g', 'o', 'v', 'e', 'r', 'n', 'o', 'r', 's', 'h', 'i', 'p', 's', '\n',
        'g', 'o', 'v', 'e', 'r', 'n', 's', '\n',
        'g', 'o', 'w', 'n', '\n',
        'g', 'o', 'w', 'n', 'e', 'd', '\n',
        'g', 'o', 'w', 'n', 's', '\n',
        'g', 'r', 'a', 'b', '\n',
        'g', 'r', 'a', 'b', 'b', 'e', 'd', '\n',
        'g', 'r', 'a', 'b', 'b', 'e', 'r', '\n',
        'g', 'r', 'a', 'b', 'b', 'e', 'r', 's', '\n',
        'g', 'r', 'a', 'b', 'b', 'i', 'n', 'g', '\n',
        'g', 'r', 'a', 'b', 's', '\n',
        'g', 'r', 'a', 'c', 'e', '\n',
        'g', 'r', 'a', 'c', 'e', 'd', '\n',
        'g', 'r', 'a', 'c', 'e', 'f', 'u', 'l', '\n',
        'g', 'r', 'a', 'c', 'e', 'f', 'u', 'l', 'l', 'y', '\n',
        'g', 'r', 'a', 'c', 'e', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'g', 'r', 'a', 'c', 'e', 'l', 'e', 's', 's', '\n',
        'g', 'r', 'a', 'c', 'e', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'g', 'r', 'a', 'c', 'e', 's', '\n',
        'g', 'r', 'a', 'c', 'i', 'n', 'g', '\n',
        'g', 'r', 'a', 'c', 'i', 'o', 'u', 's', '\n',
        'g', 'r', 'a', 'c', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'g', 'r', 'a', 'c', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'g', 'r', 'a', 'd', 'a', 't', 'i', 'o', 'n', '\n',
        'g', 'r', 'a', 'd', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'g', 'r', 'a', 'd', 'e', '\n',
        'g', 'r', 'a', 'd', 'e', 'd', '\n',
        'g', 'r', 'a', 'd', 'e', 'r', '\n',
        'g', 'r', 'a', 'd', 'e', 'r', 's', '\n',
        'g', 'r', 'a', 'd', 'e', 's', '\n',
        'g', 'r', 'a', 'd', 'i', 'e', 'n', 't', '\n',
        'g', 'r', 'a', 'd', 'i', 'e', 'n', 't', 's', '\n',
        'g', 'r', 'a', 'd', 'i', 'n', 'g', '\n',
        'g', 'r', 'a', 'd', 'i', 'n', 'g', 's', '\n',
        'g', 'r', 'a', 'd', 'u', 'a', 'l', '\n',
        'g', 'r', 'a', 'd', 'u', 'a', 'l', 'i', 's', 'm', '\n',
        'g', 'r', 'a', 'd', 'u', 'a', 'l', 'i', 's', 't', '\n',
        'g', 'r', 'a', 'd', 'u', 'a', 'l', 'l', 'y', '\n',
        'g', 'r', 'a', 'd', 'u', 'a', 'n', 'd', '\n',
        'g', 'r', 'a', 'd', 'u', 'a', 'n', 'd', 's', '\n',
        'g', 'r', 'a', 'd', 'u', 'a', 't', 'e', '\n',
        'g', 'r', 'a', 'd', 'u', 'a', 't', 'e', 'd', '\n',
        'g', 'r', 'a', 'd', 'u', 'a', 't', 'e', 's', '\n',
        'g', 'r', 'a', 'd', 'u', 'a', 't', 'i', 'n', 'g', '\n',
        'g', 'r', 'a', 'd', 'u', 'a', 't', 'i', 'o', 'n', '\n',
        'g', 'r', 'a', 'd', 'u', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'g', 'r', 'a', 'f', 'f', 'i', 't', 'i', '\n',
        'g', 'r', 'a', 'f', 'f', 'i', 't', 'o', '\n',
        'g', 'r', 'a', 'f', 't', '\n',
        'g', 'r', 'a', 'f', 't', 'e', 'd', '\n',
        'g', 'r', 'a', 'f', 't', 'i', 'n', 'g', '\n',
        'g', 'r', 'a', 'f', 't', 's', '\n',
        'g', 'r', 'a', 'h', 'a', 'm', '\n',
        'g', 'r', 'a', 'i', 'l', '\n',
        'g', 'r', 'a', 'i', 'l', 's', '\n',
        'g', 'r', 'a', 'i', 'n', '\n',
        'g', 'r', 'a', 'i', 'n', 'e', 'd', '\n',
        'g', 'r', 'a', 'i', 'n', 'i', 'e', 'r', '\n',
        'g', 'r', 'a', 'i', 'n', 'i', 'e', 's', 't', '\n',
        'g', 'r', 'a', 'i', 'n', 'i', 'n', 'e', 's', 's', '\n',
        'g', 'r', 'a', 'i', 'n', 's', '\n',
        'g', 'r', 'a', 'i', 'n', 'y', '\n',
        'g', 'r', 'a', 'm', '\n',
        'g', 'r', 'a', 'm', 'm', 'a', 'r', '\n',
        'g', 'r', 'a', 'm', 'm', 'a', 'r', 'i', 'a', 'n', '\n',
        'g', 'r', 'a', 'm', 'm', 'a', 'r', 'i', 'a', 'n', 's', '\n',
        'g', 'r', 'a', 'm', 'm', 'a', 'r', 's', '\n',
        'g', 'r', 'a', 'm', 'm', 'a', 't', 'i', 'c', 'a', 'l', '\n',
        'g', 'r', 'a', 'm', 'm', 'a', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'g', 'r', 'a', 'm', 'm', 'e', '\n',
        'g', 'r', 'a', 'm', 'm', 'e', 's', '\n',
        'g', 'r', 'a', 'm', 'o', 'p', 'h', 'o', 'n', 'e', '\n',
        'g', 'r', 'a', 'm', 'o', 'p', 'h', 'o', 'n', 'e', 's', '\n',
        'g', 'r', 'a', 'm', 's', '\n',
        'g', 'r', 'a', 'n', 'a', 'r', 'i', 'e', 's', '\n',
        'g', 'r', 'a', 'n', 'a', 'r', 'y', '\n',
        'g', 'r', 'a', 'n', 'd', '\n',
        'g', 'r', 'a', 'n', 'd', 'a', 'd', 's', '\n',
        'g', 'r', 'a', 'n', 'd', 'c', 'h', 'i', 'l', 'd', '\n',
        'g', 'r', 'a', 'n', 'd', 'c', 'h', 'i', 'l', 'd', 'r', 'e', 'n', '\n',
        'g', 'r', 'a', 'n', 'd', 'd', 'a', 'd', '\n',
        'g', 'r', 'a', 'n', 'd', 'd', 'a', 'u', 'g', 'h', 't', 'e', 'r', '\n',
        'g', 'r', 'a', 'n', 'd', 'd', 'a', 'u', 'g', 'h', 't', 'e', 'r', 's', '\n',
        'g', 'r', 'a', 'n', 'd', 'e', 'e', '\n',
        'g', 'r', 'a', 'n', 'd', 'e', 'e', 's', '\n',
        'g', 'r', 'a', 'n', 'd', 'e', 'r', '\n',
        'g', 'r', 'a', 'n', 'd', 'e', 's', 't', '\n',
        'g', 'r', 'a', 'n', 'd', 'e', 'u', 'r', '\n',
        'g', 'r', 'a', 'n', 'd', 'f', 'a', 't', 'h', 'e', 'r', '\n',
        'g', 'r', 'a', 'n', 'd', 'f', 'a', 't', 'h', 'e', 'r', 's', '\n',
        'g', 'r', 'a', 'n', 'd', 'i', 'l', 'o', 'q', 'u', 'e', 'n', 't', '\n',
        'g', 'r', 'a', 'n', 'd', 'i', 'o', 's', 'e', '\n',
        'g', 'r', 'a', 'n', 'd', 'i', 'o', 's', 'i', 't', 'y', '\n',
        'g', 'r', 'a', 'n', 'd', 'l', 'y', '\n',
        'g', 'r', 'a', 'n', 'd', 'm', 'a', '\n',
        'g', 'r', 'a', 'n', 'd', 'm', 'a', 's', '\n',
        'g', 'r', 'a', 'n', 'd', 'm', 'a', 's', 't', 'e', 'r', '\n',
        'g', 'r', 'a', 'n', 'd', 'm', 'a', 's', 't', 'e', 'r', 's', '\n',
        'g', 'r', 'a', 'n', 'd', 'm', 'o', 't', 'h', 'e', 'r', '\n',
        'g', 'r', 'a', 'n', 'd', 'm', 'o', 't', 'h', 'e', 'r', 's', '\n',
        'g', 'r', 'a', 'n', 'd', 'p', 'a', '\n',
        'g', 'r', 'a', 'n', 'd', 'p', 'a', 'r', 'e', 'n', 't', '\n',
        'g', 'r', 'a', 'n', 'd', 'p', 'a', 'r', 'e', 'n', 't', 's', '\n',
        'g', 'r', 'a', 'n', 'd', 'p', 'a', 's', '\n',
        'g', 'r', 'a', 'n', 'd', 's', '\n',
        'g', 'r', 'a', 'n', 'd', 's', 'o', 'n', '\n',
        'g', 'r', 'a', 'n', 'd', 's', 'o', 'n', 's', '\n',
        'g', 'r', 'a', 'n', 'd', 's', 't', 'a', 'n', 'd', '\n',
        'g', 'r', 'a', 'n', 'g', 'e', '\n',
        'g', 'r', 'a', 'n', 'i', 't', 'e', '\n',
        'g', 'r', 'a', 'n', 'i', 't', 'e', 's', '\n',
        'g', 'r', 'a', 'n', 'i', 't', 'i', 'c', '\n',
        'g', 'r', 'a', 'n', 'n', 'i', 'e', '\n',
        'g', 'r', 'a', 'n', 'n', 'i', 'e', 's', '\n',
        'g', 'r', 'a', 'n', 'n', 'y', '\n',
        'g', 'r', 'a', 'n', 't', '\n',
        'g', 'r', 'a', 'n', 't', 'e', 'd', '\n',
        'g', 'r', 'a', 'n', 't', 'e', 'e', '\n',
        'g', 'r', 'a', 'n', 't', 'i', 'n', 'g', '\n',
        'g', 'r', 'a', 'n', 't', 's', '\n',
        'g', 'r', 'a', 'n', 'u', 'l', 'a', 'r', '\n',
        'g', 'r', 'a', 'n', 'u', 'l', 'a', 'r', 'i', 't', 'y', '\n',
        'g', 'r', 'a', 'n', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'g', 'r', 'a', 'n', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'g', 'r', 'a', 'n', 'u', 'l', 'e', '\n',
        'g', 'r', 'a', 'n', 'u', 'l', 'e', 's', '\n',
        'g', 'r', 'a', 'n', 'u', 'l', 'o', 'c', 'y', 't', 'e', '\n',
        'g', 'r', 'a', 'p', 'e', '\n',
        'g', 'r', 'a', 'p', 'e', 'f', 'r', 'u', 'i', 't', '\n',
        'g', 'r', 'a', 'p', 'e', 's', '\n',
        'g', 'r', 'a', 'p', 'e', 's', 'h', 'o', 't', '\n',
        'g', 'r', 'a', 'p', 'e', 'v', 'i', 'n', 'e', '\n',
        'g', 'r', 'a', 'p', 'h', '\n',
        'g', 'r', 'a', 'p', 'h', 'e', 'd', '\n',
        'g', 'r', 'a', 'p', 'h', 'i', 'c', '\n',
        'g', 'r', 'a', 'p', 'h', 'i', 'c', 'a', 'l', '\n',
        'g', 'r', 'a', 'p', 'h', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'g', 'r', 'a', 'p', 'h', 'i', 'c', 's', '\n',
        'g', 'r', 'a', 'p', 'h', 'i', 't', 'e', '\n',
        'g', 'r', 'a', 'p', 'h', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'g', 'r', 'a', 'p', 'h', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'g', 'r', 'a', 'p', 'h', 'o', 'l', 'o', 'g', 'y', '\n',
        'g', 'r', 'a', 'p', 'h', 's', '\n',
        'g', 'r', 'a', 'p', 'n', 'e', 'l', '\n',
        'g', 'r', 'a', 'p', 'p', 'l', 'e', '\n',
        'g', 'r', 'a', 'p', 'p', 'l', 'e', 'd', '\n',
        'g', 'r', 'a', 'p', 'p', 'l', 'e', 's', '\n',
        'g', 'r', 'a', 'p', 'p', 'l', 'i', 'n', 'g', '\n',
        'g', 'r', 'a', 'p', 't', 'o', 'l', 'i', 't', 'e', 's', '\n',
        'g', 'r', 'a', 's', 'p', '\n',
        'g', 'r', 'a', 's', 'p', 'e', 'd', '\n',
        'g', 'r', 'a', 's', 'p', 'e', 'r', '\n',
        'g', 'r', 'a', 's', 'p', 'i', 'n', 'g', '\n',
        'g', 'r', 'a', 's', 'p', 's', '\n',
        'g', 'r', 'a', 's', 's', '\n',
        'g', 'r', 'a', 's', 's', 'e', 'd', '\n',
        'g', 'r', 'a', 's', 's', 'e', 's', '\n',
        'g', 'r', 'a', 's', 's', 'h', 'o', 'p', 'p', 'e', 'r', '\n',
        'g', 'r', 'a', 's', 's', 'h', 'o', 'p', 'p', 'e', 'r', 's', '\n',
        'g', 'r', 'a', 's', 's', 'i', 'e', 'r', '\n',
        'g', 'r', 'a', 's', 's', 'i', 'e', 's', 't', '\n',
        'g', 'r', 'a', 's', 's', 'l', 'a', 'n', 'd', '\n',
        'g', 'r', 'a', 's', 's', 'l', 'a', 'n', 'd', 's', '\n',
        'g', 'r', 'a', 's', 's', 'r', 'o', 'o', 't', 's', '\n',
        'g', 'r', 'a', 's', 's', 'y', '\n',
        'g', 'r', 'a', 't', 'e', '\n',
        'g', 'r', 'a', 't', 'e', 'd', '\n',
        'g', 'r', 'a', 't', 'e', 'f', 'u', 'l', '\n',
        'g', 'r', 'a', 't', 'e', 'f', 'u', 'l', 'l', 'y', '\n',
        'g', 'r', 'a', 't', 'e', 'r', '\n',
        'g', 'r', 'a', 't', 'e', 'r', 's', '\n',
        'g', 'r', 'a', 't', 'e', 's', '\n',
        'g', 'r', 'a', 't', 'i', 'c', 'u', 'l', 'e', '\n',
        'g', 'r', 'a', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'g', 'r', 'a', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'g', 'r', 'a', 't', 'i', 'f', 'i', 'e', 'd', '\n',
        'g', 'r', 'a', 't', 'i', 'f', 'i', 'e', 's', '\n',
        'g', 'r', 'a', 't', 'i', 'f', 'y', '\n',
        'g', 'r', 'a', 't', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'g', 'r', 'a', 't', 'i', 'f', 'y', 'i', 'n', 'g', 'l', 'y', '\n',
        'g', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'g', 'r', 'a', 't', 'i', 'n', 'g', 's', '\n',
        'g', 'r', 'a', 't', 'i', 's', '\n',
        'g', 'r', 'a', 't', 'i', 't', 'u', 'd', 'e', '\n',
        'g', 'r', 'a', 't', 'u', 'i', 't', 'i', 'e', 's', '\n',
        'g', 'r', 'a', 't', 'u', 'i', 't', 'o', 'u', 's', '\n',
        'g', 'r', 'a', 't', 'u', 'i', 't', 'o', 'u', 's', 'l', 'y', '\n',
        'g', 'r', 'a', 't', 'u', 'i', 't', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'g', 'r', 'a', 't', 'u', 'i', 't', 'y', '\n',
        'g', 'r', 'a', 'v', 'e', '\n',
        'g', 'r', 'a', 'v', 'e', 'd', 'i', 'g', 'g', 'e', 'r', '\n',
        'g', 'r', 'a', 'v', 'e', 'd', 'i', 'g', 'g', 'e', 'r', 's', '\n',
        'g', 'r', 'a', 'v', 'e', 'l', '\n',
        'g', 'r', 'a', 'v', 'e', 'l', 'l', 'e', 'd', '\n',
        'g', 'r', 'a', 'v', 'e', 'l', 'l', 'y', '\n',
        'g', 'r', 'a', 'v', 'e', 'l', 's', '\n',
        'g', 'r', 'a', 'v', 'e', 'l', 'y', '\n',
        'g', 'r', 'a', 'v', 'e', 'n', '\n',
        'g', 'r', 'a', 'v', 'e', 'r', '\n',
        'g', 'r', 'a', 'v', 'e', 's', '\n',
        'g', 'r', 'a', 'v', 'e', 's', 'i', 'd', 'e', '\n',
        'g', 'r', 'a', 'v', 'e', 's', 't', '\n',
        'g', 'r', 'a', 'v', 'e', 's', 't', 'o', 'n', 'e', '\n',
        'g', 'r', 'a', 'v', 'e', 's', 't', 'o', 'n', 'e', 's', '\n',
        'g', 'r', 'a', 'v', 'e', 'y', 'a', 'r', 'd', '\n',
        'g', 'r', 'a', 'v', 'e', 'y', 'a', 'r', 'd', 's', '\n',
        'g', 'r', 'a', 'v', 'i', 'e', 's', '\n',
        'g', 'r', 'a', 'v', 'i', 't', 'a', 's', '\n',
        'g', 'r', 'a', 'v', 'i', 't', 'a', 't', 'e', '\n',
        'g', 'r', 'a', 'v', 'i', 't', 'a', 't', 'e', 'd', '\n',
        'g', 'r', 'a', 'v', 'i', 't', 'a', 't', 'i', 'n', 'g', '\n',
        'g', 'r', 'a', 'v', 'i', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'g', 'r', 'a', 'v', 'i', 't', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'g', 'r', 'a', 'v', 'i', 't', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'g', 'r', 'a', 'v', 'i', 't', 'i', 'e', 's', '\n',
        'g', 'r', 'a', 'v', 'i', 't', 'o', 'n', '\n',
        'g', 'r', 'a', 'v', 'i', 't', 'o', 'n', 's', '\n',
        'g', 'r', 'a', 'v', 'i', 't', 'y', '\n',
        'g', 'r', 'a', 'v', 'u', 'r', 'e', 's', '\n',
        'g', 'r', 'a', 'v', 'y', '\n',
        'g', 'r', 'a', 'z', 'e', '\n',
        'g', 'r', 'a', 'z', 'e', 'd', '\n',
        'g', 'r', 'a', 'z', 'e', 'r', '\n',
        'g', 'r', 'a', 'z', 'e', 's', '\n',
        'g', 'r', 'a', 'z', 'i', 'n', 'g', '\n',
        'g', 'r', 'e', 'a', 's', 'e', '\n',
        'g', 'r', 'e', 'a', 's', 'e', 'd', '\n',
        'g', 'r', 'e', 'a', 's', 'e', 'p', 'a', 'i', 'n', 't', '\n',
        'g', 'r', 'e', 'a', 's', 'e', 'p', 'r', 'o', 'o', 'f', '\n',
        'g', 'r', 'e', 'a', 's', 'e', 'r', 's', '\n',
        'g', 'r', 'e', 'a', 's', 'e', 's', '\n',
        'g', 'r', 'e', 'a', 's', 'i', 'e', 'r', '\n',
        'g', 'r', 'e', 'a', 's', 'i', 'e', 's', 't', '\n',
        'g', 'r', 'e', 'a', 's', 'i', 'n', 'g', '\n',
        'g', 'r', 'e', 'a', 's', 'y', '\n',
        'g', 'r', 'e', 'a', 't', '\n',
        'g', 'r', 'e', 'a', 't', 'a', 'u', 'n', 't', '\n',
        'g', 'r', 'e', 'a', 't', 'a', 'u', 'n', 't', 's', '\n',
        'g', 'r', 'e', 'a', 't', 'c', 'o', 'a', 't', '\n',
        'g', 'r', 'e', 'a', 't', 'c', 'o', 'a', 't', 's', '\n',
        'g', 'r', 'e', 'a', 't', 'e', 'r', '\n',
        'g', 'r', 'e', 'a', 't', 'e', 's', 't', '\n',
        'g', 'r', 'e', 'a', 't', 'g', 'r', 'a', 'n', 'd', 'c', 'h', 'i', 'l', 'd', 'r', 'e', 'n', '\n',
        'g', 'r', 'e', 'a', 't', 'g', 'r', 'a', 'n', 'd', 'd', 'a', 'u', 'g', 'h', 't', 'e', 'r', '\n',
        'g', 'r', 'e', 'a', 't', 'g', 'r', 'a', 'n', 'd', 'f', 'a', 't', 'h', 'e', 'r', '\n',
        'g', 'r', 'e', 'a', 't', 'g', 'r', 'a', 'n', 'd', 'm', 'o', 't', 'h', 'e', 'r', '\n',
        'g', 'r', 'e', 'a', 't', 'g', 'r', 'a', 'n', 'd', 'm', 'o', 't', 'h', 'e', 'r', 's', '\n',
        'g', 'r', 'e', 'a', 't', 'g', 'r', 'a', 'n', 'd', 's', 'o', 'n', '\n',
        'g', 'r', 'e', 'a', 't', 'l', 'y', '\n',
        'g', 'r', 'e', 'a', 't', 'n', 'e', 's', 's', '\n',
        'g', 'r', 'e', 'c', 'i', 'a', 'n', '\n',
        'g', 'r', 'e', 'e', 'c', 'e', '\n',
        'g', 'r', 'e', 'e', 'd', '\n',
        'g', 'r', 'e', 'e', 'd', 'i', 'e', 'r', '\n',
        'g', 'r', 'e', 'e', 'd', 'i', 'e', 's', 't', '\n',
        'g', 'r', 'e', 'e', 'd', 'i', 'l', 'y', '\n',
        'g', 'r', 'e', 'e', 'd', 'i', 'n', 'e', 's', 's', '\n',
        'g', 'r', 'e', 'e', 'd', 's', '\n',
        'g', 'r', 'e', 'e', 'd', 'y', '\n',
        'g', 'r', 'e', 'e', 'k', '\n',
        'g', 'r', 'e', 'e', 'k', 's', '\n',
        'g', 'r', 'e', 'e', 'n', '\n',
        'g', 'r', 'e', 'e', 'n', 'e', 'd', '\n',
        'g', 'r', 'e', 'e', 'n', 'e', 'r', '\n',
        'g', 'r', 'e', 'e', 'n', 'e', 'r', 'y', '\n',
        'g', 'r', 'e', 'e', 'n', 'e', 's', 't', '\n',
        'g', 'r', 'e', 'e', 'n', 'e', 'y', 'e', 'd', '\n',
        'g', 'r', 'e', 'e', 'n', 'f', 'i', 'e', 'l', 'd', '\n',
        'g', 'r', 'e', 'e', 'n', 'f', 'l', 'y', '\n',
        'g', 'r', 'e', 'e', 'n', 'g', 'a', 'g', 'e', 's', '\n',
        'g', 'r', 'e', 'e', 'n', 'g', 'r', 'o', 'c', 'e', 'r', '\n',
        'g', 'r', 'e', 'e', 'n', 'g', 'r', 'o', 'c', 'e', 'r', 's', '\n',
        'g', 'r', 'e', 'e', 'n', 'g', 'r', 'o', 'c', 'e', 'r', 'y', '\n',
        'g', 'r', 'e', 'e', 'n', 'h', 'o', 'r', 'n', '\n',
        'g', 'r', 'e', 'e', 'n', 'h', 'o', 'r', 'n', 's', '\n',
        'g', 'r', 'e', 'e', 'n', 'h', 'o', 'u', 's', 'e', '\n',
        'g', 'r', 'e', 'e', 'n', 'h', 'o', 'u', 's', 'e', 's', '\n',
        'g', 'r', 'e', 'e', 'n', 'i', 'e', '\n',
        'g', 'r', 'e', 'e', 'n', 'i', 'n', 'g', '\n',
        'g', 'r', 'e', 'e', 'n', 'i', 's', 'h', '\n',
        'g', 'r', 'e', 'e', 'n', 'l', 'y', '\n',
        'g', 'r', 'e', 'e', 'n', 'n', 'e', 's', 's', '\n',
        'g', 'r', 'e', 'e', 'n', 's', '\n',
        'g', 'r', 'e', 'e', 'n', 's', 't', 'o', 'n', 'e', '\n',
        'g', 'r', 'e', 'e', 'n', 's', 'w', 'a', 'r', 'd', '\n',
        'g', 'r', 'e', 'e', 'n', 'w', 'i', 'c', 'h', '\n',
        'g', 'r', 'e', 'e', 't', '\n',
        'g', 'r', 'e', 'e', 't', 'e', 'd', '\n',
        'g', 'r', 'e', 'e', 't', 'i', 'n', 'g', '\n',
        'g', 'r', 'e', 'e', 't', 'i', 'n', 'g', 's', '\n',
        'g', 'r', 'e', 'e', 't', 's', '\n',
        'g', 'r', 'e', 'g', 'a', 'r', 'i', 'o', 'u', 's', '\n',
        'g', 'r', 'e', 'g', 'a', 'r', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'g', 'r', 'e', 'g', 'a', 'r', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'g', 'r', 'e', 'm', 'l', 'i', 'n', '\n',
        'g', 'r', 'e', 'm', 'l', 'i', 'n', 's', '\n',
        'g', 'r', 'e', 'n', 'a', 'd', 'e', '\n',
        'g', 'r', 'e', 'n', 'a', 'd', 'e', 's', '\n',
        'g', 'r', 'e', 'n', 'a', 'd', 'i', 'e', 'r', '\n',
        'g', 'r', 'e', 'n', 'a', 'd', 'i', 'e', 'r', 's', '\n',
        'g', 'r', 'e', 'w', '\n',
        'g', 'r', 'e', 'y', '\n',
        'g', 'r', 'e', 'y', 'b', 'e', 'a', 'r', 'd', '\n',
        'g', 'r', 'e', 'y', 'e', 'd', '\n',
        'g', 'r', 'e', 'y', 'e', 'r', '\n',
        'g', 'r', 'e', 'y', 'e', 's', 't', '\n',
        'g', 'r', 'e', 'y', 'h', 'o', 'u', 'n', 'd', '\n',
        'g', 'r', 'e', 'y', 'h', 'o', 'u', 'n', 'd', 's', '\n',
        'g', 'r', 'e', 'y', 'i', 'n', 'g', '\n',
        'g', 'r', 'e', 'y', 'i', 's', 'h', '\n',
        'g', 'r', 'e', 'y', 'n', 'e', 's', 's', '\n',
        'g', 'r', 'e', 'y', 's', '\n',
        'g', 'r', 'i', 'd', '\n',
        'g', 'r', 'i', 'd', 'd', 'e', 'd', '\n',
        'g', 'r', 'i', 'd', 'i', 'r', 'o', 'n', '\n',
        'g', 'r', 'i', 'd', 'l', 'o', 'c', 'k', '\n',
        'g', 'r', 'i', 'd', 's', '\n',
        'g', 'r', 'i', 'e', 'f', '\n',
        'g', 'r', 'i', 'e', 'f', 's', '\n',
        'g', 'r', 'i', 'e', 'v', 'a', 'n', 'c', 'e', '\n',
        'g', 'r', 'i', 'e', 'v', 'a', 'n', 'c', 'e', 's', '\n',
        'g', 'r', 'i', 'e', 'v', 'e', '\n',
        'g', 'r', 'i', 'e', 'v', 'e', 'd', '\n',
        'g', 'r', 'i', 'e', 'v', 'e', 'r', '\n',
        'g', 'r', 'i', 'e', 'v', 'e', 'r', 's', '\n',
        'g', 'r', 'i', 'e', 'v', 'e', 's', '\n',
        'g', 'r', 'i', 'e', 'v', 'i', 'n', 'g', '\n',
        'g', 'r', 'i', 'e', 'v', 'o', 'u', 's', '\n',
        'g', 'r', 'i', 'e', 'v', 'o', 'u', 's', 'l', 'y', '\n',
        'g', 'r', 'i', 'f', 'f', 'i', 'n', '\n',
        'g', 'r', 'i', 'f', 'f', 'i', 'n', 's', '\n',
        'g', 'r', 'i', 'f', 'f', 'o', 'n', '\n',
        'g', 'r', 'i', 'l', 'l', '\n',
        'g', 'r', 'i', 'l', 'l', 'e', '\n',
        'g', 'r', 'i', 'l', 'l', 'e', 'd', '\n',
        'g', 'r', 'i', 'l', 'l', 'e', 's', '\n',
        'g', 'r', 'i', 'l', 'l', 'i', 'n', 'g', '\n',
        'g', 'r', 'i', 'l', 'l', 's', '\n',
        'g', 'r', 'i', 'm', '\n',
        'g', 'r', 'i', 'm', 'a', 'c', 'e', '\n',
        'g', 'r', 'i', 'm', 'a', 'c', 'e', 'd', '\n',
        'g', 'r', 'i', 'm', 'a', 'c', 'e', 's', '\n',
        'g', 'r', 'i', 'm', 'a', 'c', 'i', 'n', 'g', '\n',
        'g', 'r', 'i', 'm', 'e', '\n',
        'g', 'r', 'i', 'm', 'i', 'e', 's', 't', '\n',
        'g', 'r', 'i', 'm', 'l', 'y', '\n',
        'g', 'r', 'i', 'm', 'm', '\n',
        'g', 'r', 'i', 'm', 'm', 'e', 'r', '\n',
        'g', 'r', 'i', 'm', 'm', 'e', 's', 't', '\n',
        'g', 'r', 'i', 'm', 'n', 'e', 's', 's', '\n',
        'g', 'r', 'i', 'm', 'y', '\n',
        'g', 'r', 'i', 'n', '\n',
        'g', 'r', 'i', 'n', 'd', '\n',
        'g', 'r', 'i', 'n', 'd', 'e', 'd', '\n',
        'g', 'r', 'i', 'n', 'd', 'e', 'r', '\n',
        'g', 'r', 'i', 'n', 'd', 'e', 'r', 's', '\n',
        'g', 'r', 'i', 'n', 'd', 'i', 'n', 'g', '\n',
        'g', 'r', 'i', 'n', 'd', 's', '\n',
        'g', 'r', 'i', 'n', 'd', 's', 't', 'o', 'n', 'e', '\n',
        'g', 'r', 'i', 'n', 'n', 'e', 'd', '\n',
        'g', 'r', 'i', 'n', 'n', 'e', 'r', '\n',
        'g', 'r', 'i', 'n', 'n', 'i', 'n', 'g', '\n',
        'g', 'r', 'i', 'n', 's', '\n',
        'g', 'r', 'i', 'p', '\n',
        'g', 'r', 'i', 'p', 'e', '\n',
        'g', 'r', 'i', 'p', 'e', 'd', '\n',
        'g', 'r', 'i', 'p', 'e', 's', '\n',
        'g', 'r', 'i', 'p', 'i', 'n', 'g', '\n',
        'g', 'r', 'i', 'p', 'p', 'e', 'd', '\n',
        'g', 'r', 'i', 'p', 'p', 'e', 'r', '\n',
        'g', 'r', 'i', 'p', 'p', 'e', 'r', 's', '\n',
        'g', 'r', 'i', 'p', 'p', 'i', 'n', 'g', '\n',
        'g', 'r', 'i', 'p', 's', '\n',
        'g', 'r', 'i', 's', 'l', 'i', 'e', 'r', '\n',
        'g', 'r', 'i', 's', 'l', 'i', 'e', 's', 't', '\n',
        'g', 'r', 'i', 's', 'l', 'y', '\n',
        'g', 'r', 'i', 's', 't', '\n',
        'g', 'r', 'i', 's', 't', 'l', 'e', '\n',
        'g', 'r', 'i', 't', '\n',
        'g', 'r', 'i', 't', 's', '\n',
        'g', 'r', 'i', 't', 't', 'e', 'd', '\n',
        'g', 'r', 'i', 't', 't', 'i', 'e', 'r', '\n',
        'g', 'r', 'i', 't', 't', 'i', 'e', 's', 't', '\n',
        'g', 'r', 'i', 't', 't', 'i', 'n', 'g', '\n',
        'g', 'r', 'i', 't', 't', 'y', '\n',
        'g', 'r', 'i', 'z', 'z', 'l', 'e', 'd', '\n',
        'g', 'r', 'i', 'z', 'z', 'l', 'i', 'e', 'r', '\n',
        'g', 'r', 'i', 'z', 'z', 'l', 'i', 'e', 's', 't', '\n',
        'g', 'r', 'i', 'z', 'z', 'l', 'y', '\n',
        'g', 'r', 'o', 'a', 'n', '\n',
        'g', 'r', 'o', 'a', 'n', 'e', 'd', '\n',
        'g', 'r', 'o', 'a', 'n', 'e', 'r', '\n',
        'g', 'r', 'o', 'a', 'n', 'e', 'r', 's', '\n',
        'g', 'r', 'o', 'a', 'n', 'i', 'n', 'g', '\n',
        'g', 'r', 'o', 'a', 'n', 's', '\n',
        'g', 'r', 'o', 'a', 't', '\n',
        'g', 'r', 'o', 'a', 't', 's', '\n',
        'g', 'r', 'o', 'c', 'e', 'r', '\n',
        'g', 'r', 'o', 'c', 'e', 'r', 'i', 'e', 's', '\n',
        'g', 'r', 'o', 'c', 'e', 'r', 's', '\n',
        'g', 'r', 'o', 'c', 'e', 'r', 'y', '\n',
        'g', 'r', 'o', 'g', '\n',
        'g', 'r', 'o', 'g', 'g', 'i', 'e', 's', 't', '\n',
        'g', 'r', 'o', 'g', 'g', 'i', 'l', 'y', '\n',
        'g', 'r', 'o', 'g', 'g', 'y', '\n',
        'g', 'r', 'o', 'i', 'n', '\n',
        'g', 'r', 'o', 'i', 'n', 's', '\n',
        'g', 'r', 'o', 'm', 'm', 'e', 't', '\n',
        'g', 'r', 'o', 'm', 'm', 'e', 't', 's', '\n',
        'g', 'r', 'o', 'o', 'm', '\n',
        'g', 'r', 'o', 'o', 'm', 'e', 'd', '\n',
        'g', 'r', 'o', 'o', 'm', 'e', 'r', '\n',
        'g', 'r', 'o', 'o', 'm', 'e', 'r', 's', '\n',
        'g', 'r', 'o', 'o', 'm', 'i', 'n', 'g', '\n',
        'g', 'r', 'o', 'o', 'm', 's', '\n',
        'g', 'r', 'o', 'o', 'v', 'e', '\n',
        'g', 'r', 'o', 'o', 'v', 'e', 'd', '\n',
        'g', 'r', 'o', 'o', 'v', 'e', 's', '\n',
        'g', 'r', 'o', 'o', 'v', 'i', 'e', 'r', '\n',
        'g', 'r', 'o', 'o', 'v', 'i', 'n', 'g', '\n',
        'g', 'r', 'o', 'o', 'v', 'y', '\n',
        'g', 'r', 'o', 'p', 'e', '\n',
        'g', 'r', 'o', 'p', 'e', 'd', '\n',
        'g', 'r', 'o', 'p', 'e', 'r', '\n',
        'g', 'r', 'o', 'p', 'e', 'r', 's', '\n',
        'g', 'r', 'o', 'p', 'e', 's', '\n',
        'g', 'r', 'o', 'p', 'i', 'n', 'g', '\n',
        'g', 'r', 'o', 'p', 'i', 'n', 'g', 'l', 'y', '\n',
        'g', 'r', 'o', 'p', 'i', 'n', 'g', 's', '\n',
        'g', 'r', 'o', 's', 's', '\n',
        'g', 'r', 'o', 's', 's', 'e', 'd', '\n',
        'g', 'r', 'o', 's', 's', 'e', 'r', '\n',
        'g', 'r', 'o', 's', 's', 'e', 's', 't', '\n',
        'g', 'r', 'o', 's', 's', 'l', 'y', '\n',
        'g', 'r', 'o', 's', 's', 'n', 'e', 's', 's', '\n',
        'g', 'r', 'o', 't', 'e', 's', 'q', 'u', 'e', '\n',
        'g', 'r', 'o', 't', 'e', 's', 'q', 'u', 'e', 'l', 'y', '\n',
        'g', 'r', 'o', 't', 'e', 's', 'q', 'u', 'e', 'n', 'e', 's', 's', '\n',
        'g', 'r', 'o', 't', 't', 'o', '\n',
        'g', 'r', 'o', 'u', 'c', 'h', '\n',
        'g', 'r', 'o', 'u', 'c', 'h', 'y', '\n',
        'g', 'r', 'o', 'u', 'n', 'd', '\n',
        'g', 'r', 'o', 'u', 'n', 'd', 'e', 'd', '\n',
        'g', 'r', 'o', 'u', 'n', 'd', 'i', 'n', 'g', '\n',
        'g', 'r', 'o', 'u', 'n', 'd', 'l', 'e', 's', 's', '\n',
        'g', 'r', 'o', 'u', 'n', 'd', 'n', 'u', 't', '\n',
        'g', 'r', 'o', 'u', 'n', 'd', 'n', 'u', 't', 's', '\n',
        'g', 'r', 'o', 'u', 'n', 'd', 's', '\n',
        'g', 'r', 'o', 'u', 'n', 'd', 's', 'h', 'e', 'e', 't', '\n',
        'g', 'r', 'o', 'u', 'n', 'd', 's', 'm', 'a', 'n', '\n',
        'g', 'r', 'o', 'u', 'n', 'd', 's', 'w', 'e', 'l', 'l', '\n',
        'g', 'r', 'o', 'u', 'n', 'd', 'w', 'a', 't', 'e', 'r', '\n',
        'g', 'r', 'o', 'u', 'n', 'd', 'w', 'o', 'r', 'k', '\n',
        'g', 'r', 'o', 'u', 'p', '\n',
        'g', 'r', 'o', 'u', 'p', 'e', 'd', '\n',
        'g', 'r', 'o', 'u', 'p', 'e', 'r', '\n',
        'g', 'r', 'o', 'u', 'p', 'i', 'e', '\n',
        'g', 'r', 'o', 'u', 'p', 'i', 'e', 's', '\n',
        'g', 'r', 'o', 'u', 'p', 'i', 'n', 'g', '\n',
        'g', 'r', 'o', 'u', 'p', 'i', 'n', 'g', 's', '\n',
        'g', 'r', 'o', 'u', 'p', 's', '\n',
        'g', 'r', 'o', 'u', 's', 'e', '\n',
        'g', 'r', 'o', 'u', 's', 'e', 's', '\n',
        'g', 'r', 'o', 'u', 't', '\n',
        'g', 'r', 'o', 'u', 't', 'i', 'n', 'g', '\n',
        'g', 'r', 'o', 'v', 'e', '\n',
        'g', 'r', 'o', 'v', 'e', 'l', '\n',
        'g', 'r', 'o', 'v', 'e', 'l', 'l', 'e', 'd', '\n',
        'g', 'r', 'o', 'v', 'e', 'l', 'l', 'e', 'r', '\n',
        'g', 'r', 'o', 'v', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'g', 'r', 'o', 'v', 'e', 'l', 's', '\n',
        'g', 'r', 'o', 'v', 'e', 's', '\n',
        'g', 'r', 'o', 'w', '\n',
        'g', 'r', 'o', 'w', 'e', 'r', '\n',
        'g', 'r', 'o', 'w', 'e', 'r', 's', '\n',
        'g', 'r', 'o', 'w', 'i', 'n', 'g', '\n',
        'g', 'r', 'o', 'w', 'l', '\n',
        'g', 'r', 'o', 'w', 'l', 'e', 'd', '\n',
        'g', 'r', 'o', 'w', 'l', 'e', 'r', '\n',
        'g', 'r', 'o', 'w', 'l', 'i', 'n', 'g', '\n',
        'g', 'r', 'o', 'w', 'l', 's', '\n',
        'g', 'r', 'o', 'w', 'n', '\n',
        'g', 'r', 'o', 'w', 'n', 'u', 'p', '\n',
        'g', 'r', 'o', 'w', 'n', 'u', 'p', 's', '\n',
        'g', 'r', 'o', 'w', 's', '\n',
        'g', 'r', 'o', 'w', 't', 'h', '\n',
        'g', 'r', 'o', 'w', 't', 'h', 's', '\n',
        'g', 'r', 'u', 'b', '\n',
        'g', 'r', 'u', 'b', 'b', 'e', 'd', '\n',
        'g', 'r', 'u', 'b', 'b', 'i', 'e', 'r', '\n',
        'g', 'r', 'u', 'b', 'b', 'i', 'e', 's', 't', '\n',
        'g', 'r', 'u', 'b', 'b', 'i', 'n', 'g', '\n',
        'g', 'r', 'u', 'b', 'b', 'y', '\n',
        'g', 'r', 'u', 'b', 's', '\n',
        'g', 'r', 'u', 'd', 'g', 'e', '\n',
        'g', 'r', 'u', 'd', 'g', 'e', 's', '\n',
        'g', 'r', 'u', 'd', 'g', 'i', 'n', 'g', '\n',
        'g', 'r', 'u', 'd', 'g', 'i', 'n', 'g', 'l', 'y', '\n',
        'g', 'r', 'u', 'e', 'l', '\n',
        'g', 'r', 'u', 'e', 'l', 'i', 'n', 'g', '\n',
        'g', 'r', 'u', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'g', 'r', 'u', 'e', 's', 'o', 'm', 'e', '\n',
        'g', 'r', 'u', 'e', 's', 'o', 'm', 'e', 'l', 'y', '\n',
        'g', 'r', 'u', 'e', 's', 'o', 'm', 'e', 'n', 'e', 's', 's', '\n',
        'g', 'r', 'u', 'f', 'f', '\n',
        'g', 'r', 'u', 'f', 'f', 'l', 'y', '\n',
        'g', 'r', 'u', 'f', 'f', 'n', 'e', 's', 's', '\n',
        'g', 'r', 'u', 'm', 'b', 'l', 'e', '\n',
        'g', 'r', 'u', 'm', 'b', 'l', 'e', 'd', '\n',
        'g', 'r', 'u', 'm', 'b', 'l', 'e', 'r', '\n',
        'g', 'r', 'u', 'm', 'b', 'l', 'e', 's', '\n',
        'g', 'r', 'u', 'm', 'b', 'l', 'i', 'n', 'g', '\n',
        'g', 'r', 'u', 'm', 'b', 'l', 'i', 'n', 'g', 's', '\n',
        'g', 'r', 'u', 'm', 'p', 'i', 'e', 'r', '\n',
        'g', 'r', 'u', 'm', 'p', 'i', 'e', 's', 't', '\n',
        'g', 'r', 'u', 'm', 'p', 'i', 'l', 'y', '\n',
        'g', 'r', 'u', 'm', 'p', 's', '\n',
        'g', 'r', 'u', 'm', 'p', 'y', '\n',
        'g', 'r', 'u', 'n', 'g', 'e', '\n',
        'g', 'r', 'u', 'n', 't', '\n',
        'g', 'r', 'u', 'n', 't', 'e', 'd', '\n',
        'g', 'r', 'u', 'n', 't', 'e', 'r', '\n',
        'g', 'r', 'u', 'n', 't', 'i', 'n', 'g', '\n',
        'g', 'r', 'u', 'n', 't', 's', '\n',
        'g', 'u', 'a', 'c', 'a', 'm', 'o', 'l', 'e', '\n',
        'g', 'u', 'a', 'n', 'a', 'c', 'o', '\n',
        'g', 'u', 'a', 'n', 'i', 'n', 'e', '\n',
        'g', 'u', 'a', 'n', 'o', '\n',
        'g', 'u', 'a', 'r', 'a', 'n', 't', 'e', 'e', '\n',
        'g', 'u', 'a', 'r', 'a', 'n', 't', 'e', 'e', 'd', '\n',
        'g', 'u', 'a', 'r', 'a', 'n', 't', 'e', 'e', 'i', 'n', 'g', '\n',
        'g', 'u', 'a', 'r', 'a', 'n', 't', 'e', 'e', 's', '\n',
        'g', 'u', 'a', 'r', 'a', 'n', 't', 'o', 'r', '\n',
        'g', 'u', 'a', 'r', 'a', 'n', 't', 'o', 'r', 's', '\n',
        'g', 'u', 'a', 'r', 'd', '\n',
        'g', 'u', 'a', 'r', 'd', 'e', 'd', '\n',
        'g', 'u', 'a', 'r', 'd', 'e', 'd', 'l', 'y', '\n',
        'g', 'u', 'a', 'r', 'd', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'g', 'u', 'a', 'r', 'd', 'h', 'o', 'u', 's', 'e', '\n',
        'g', 'u', 'a', 'r', 'd', 'i', 'a', 'n', '\n',
        'g', 'u', 'a', 'r', 'd', 'i', 'a', 'n', 's', '\n',
        'g', 'u', 'a', 'r', 'd', 'i', 'a', 'n', 's', 'h', 'i', 'p', '\n',
        'g', 'u', 'a', 'r', 'd', 'i', 'n', 'g', '\n',
        'g', 'u', 'a', 'r', 'd', 'r', 'o', 'o', 'm', '\n',
        'g', 'u', 'a', 'r', 'd', 's', '\n',
        'g', 'u', 'a', 'r', 'd', 's', 'm', 'a', 'n', '\n',
        'g', 'u', 'a', 'r', 'd', 's', 'm', 'e', 'n', '\n',
        'g', 'u', 'a', 'v', 'a', '\n',
        'g', 'u', 'a', 'v', 'a', 's', '\n',
        'g', 'u', 'b', 'e', 'r', 'n', 'a', 't', 'o', 'r', 'i', 'a', 'l', '\n',
        'g', 'u', 'd', 'g', 'e', 'o', 'n', '\n',
        'g', 'u', 'e', 'r', 'i', 'l', 'l', 'a', '\n',
        'g', 'u', 'e', 'r', 'i', 'l', 'l', 'a', 's', '\n',
        'g', 'u', 'e', 'r', 'r', 'i', 'l', 'l', 'a', '\n',
        'g', 'u', 'e', 'r', 'r', 'i', 'l', 'l', 'a', 's', '\n',
        'g', 'u', 'e', 's', 's', '\n',
        'g', 'u', 'e', 's', 's', 'a', 'b', 'l', 'e', '\n',
        'g', 'u', 'e', 's', 's', 'e', 'd', '\n',
        'g', 'u', 'e', 's', 's', 'e', 's', '\n',
        'g', 'u', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'g', 'u', 'e', 's', 's', 'w', 'o', 'r', 'k', '\n',
        'g', 'u', 'e', 's', 't', '\n',
        'g', 'u', 'e', 's', 't', 'i', 'n', 'g', '\n',
        'g', 'u', 'e', 's', 't', 's', '\n',
        'g', 'u', 'f', 'f', 'a', 'w', '\n',
        'g', 'u', 'f', 'f', 'a', 'w', 'e', 'd', '\n',
        'g', 'u', 'f', 'f', 'a', 'w', 's', '\n',
        'g', 'u', 'i', 'd', 'a', 'n', 'c', 'e', '\n',
        'g', 'u', 'i', 'd', 'e', '\n',
        'g', 'u', 'i', 'd', 'e', 'b', 'o', 'o', 'k', '\n',
        'g', 'u', 'i', 'd', 'e', 'b', 'o', 'o', 'k', 's', '\n',
        'g', 'u', 'i', 'd', 'e', 'd', '\n',
        'g', 'u', 'i', 'd', 'e', 'l', 'i', 'n', 'e', '\n',
        'g', 'u', 'i', 'd', 'e', 'l', 'i', 'n', 'e', 's', '\n',
        'g', 'u', 'i', 'd', 'e', 'r', '\n',
        'g', 'u', 'i', 'd', 'e', 'r', 's', '\n',
        'g', 'u', 'i', 'd', 'e', 's', '\n',
        'g', 'u', 'i', 'd', 'i', 'n', 'g', '\n',
        'g', 'u', 'i', 'd', 'i', 'n', 'g', 's', '\n',
        'g', 'u', 'i', 'l', 'd', '\n',
        'g', 'u', 'i', 'l', 'd', 'e', 'r', '\n',
        'g', 'u', 'i', 'l', 'd', 'e', 'r', 's', '\n',
        'g', 'u', 'i', 'l', 'd', 's', '\n',
        'g', 'u', 'i', 'l', 'e', '\n',
        'g', 'u', 'i', 'l', 'e', 'l', 'e', 's', 's', '\n',
        'g', 'u', 'i', 'l', 'e', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'g', 'u', 'i', 'l', 'l', 'e', 'm', 'o', 't', '\n',
        'g', 'u', 'i', 'l', 'l', 'e', 'm', 'o', 't', 's', '\n',
        'g', 'u', 'i', 'l', 'l', 'o', 't', 'i', 'n', 'e', '\n',
        'g', 'u', 'i', 'l', 'l', 'o', 't', 'i', 'n', 'e', 'd', '\n',
        'g', 'u', 'i', 'l', 'l', 'o', 't', 'i', 'n', 'e', 's', '\n',
        'g', 'u', 'i', 'l', 'l', 'o', 't', 'i', 'n', 'i', 'n', 'g', '\n',
        'g', 'u', 'i', 'l', 't', '\n',
        'g', 'u', 'i', 'l', 't', 'i', 'e', 'r', '\n',
        'g', 'u', 'i', 'l', 't', 'i', 'e', 's', 't', '\n',
        'g', 'u', 'i', 'l', 't', 'i', 'l', 'y', '\n',
        'g', 'u', 'i', 'l', 't', 'i', 'n', 'e', 's', 's', '\n',
        'g', 'u', 'i', 'l', 't', 'l', 'e', 's', 's', '\n',
        'g', 'u', 'i', 'l', 't', 's', '\n',
        'g', 'u', 'i', 'l', 't', 'y', '\n',
        'g', 'u', 'i', 'n', 'e', 'a', '\n',
        'g', 'u', 'i', 'n', 'e', 'a', 's', '\n',
        'g', 'u', 'i', 's', 'e', '\n',
        'g', 'u', 'i', 's', 'e', 's', '\n',
        'g', 'u', 'i', 't', 'a', 'r', '\n',
        'g', 'u', 'i', 't', 'a', 'r', 'i', 's', 't', '\n',
        'g', 'u', 'i', 't', 'a', 'r', 'i', 's', 't', 's', '\n',
        'g', 'u', 'i', 't', 'a', 'r', 's', '\n',
        'g', 'u', 'l', 'f', '\n',
        'g', 'u', 'l', 'f', 's', '\n',
        'g', 'u', 'l', 'f', 'w', 'a', 'r', '\n',
        'g', 'u', 'l', 'l', '\n',
        'g', 'u', 'l', 'l', 'e', 't', '\n',
        'g', 'u', 'l', 'l', 'e', 't', 's', '\n',
        'g', 'u', 'l', 'l', 'e', 'y', '\n',
        'g', 'u', 'l', 'l', 'e', 'y', 's', '\n',
        'g', 'u', 'l', 'l', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'g', 'u', 'l', 'l', 'i', 'b', 'l', 'e', '\n',
        'g', 'u', 'l', 'l', 'i', 'e', 's', '\n',
        'g', 'u', 'l', 'l', 's', '\n',
        'g', 'u', 'l', 'l', 'y', '\n',
        'g', 'u', 'l', 'p', '\n',
        'g', 'u', 'l', 'p', 'e', 'd', '\n',
        'g', 'u', 'l', 'p', 'i', 'n', 'g', '\n',
        'g', 'u', 'l', 'p', 's', '\n',
        'g', 'u', 'm', '\n',
        'g', 'u', 'm', 'b', 'o', 'i', 'l', '\n',
        'g', 'u', 'm', 'b', 'o', 'i', 'l', 's', '\n',
        'g', 'u', 'm', 'b', 'o', 'o', 't', 's', '\n',
        'g', 'u', 'm', 'd', 'r', 'o', 'p', '\n',
        'g', 'u', 'm', 'd', 'r', 'o', 'p', 's', '\n',
        'g', 'u', 'm', 'm', 'e', 'd', '\n',
        'g', 'u', 'm', 'm', 'i', 'n', 'g', '\n',
        'g', 'u', 'm', 's', '\n',
        'g', 'u', 'm', 's', 'h', 'o', 'e', '\n',
        'g', 'u', 'm', 't', 'r', 'e', 'e', '\n',
        'g', 'u', 'm', 't', 'r', 'e', 'e', 's', '\n',
        'g', 'u', 'n', '\n',
        'g', 'u', 'n', 'b', 'o', 'a', 't', '\n',
        'g', 'u', 'n', 'b', 'o', 'a', 't', 's', '\n',
        'g', 'u', 'n', 'f', 'i', 'g', 'h', 't', '\n',
        'g', 'u', 'n', 'f', 'i', 'r', 'e', '\n',
        'g', 'u', 'n', 'f', 'i', 'r', 'e', 's', '\n',
        'g', 'u', 'n', 'i', 't', 'e', '\n',
        'g', 'u', 'n', 'k', '\n',
        'g', 'u', 'n', 'm', 'a', 'n', '\n',
        'g', 'u', 'n', 'm', 'e', 'n', '\n',
        'g', 'u', 'n', 'm', 'e', 't', 'a', 'l', '\n',
        'g', 'u', 'n', 'n', 'e', 'd', '\n',
        'g', 'u', 'n', 'n', 'e', 'r', '\n',
        'g', 'u', 'n', 'n', 'e', 'r', 's', '\n',
        'g', 'u', 'n', 'n', 'e', 'r', 'y', '\n',
        'g', 'u', 'n', 'n', 'i', 'n', 'g', '\n',
        'g', 'u', 'n', 'p', 'o', 'i', 'n', 't', '\n',
        'g', 'u', 'n', 'p', 'o', 'w', 'd', 'e', 'r', '\n',
        'g', 'u', 'n', 's', '\n',
        'g', 'u', 'n', 's', 'h', 'i', 'p', '\n',
        'g', 'u', 'n', 's', 'h', 'i', 'p', 's', '\n',
        'g', 'u', 'n', 's', 'h', 'o', 't', '\n',
        'g', 'u', 'n', 's', 'h', 'o', 't', 's', '\n',
        'g', 'u', 'n', 's', 'i', 'g', 'h', 't', '\n',
        'g', 'u', 'n', 's', 'm', 'i', 't', 'h', '\n',
        'g', 'u', 'n', 's', 'm', 'i', 't', 'h', 's', '\n',
        'g', 'u', 'n', 'w', 'a', 'l', 'e', '\n',
        'g', 'u', 'n', 'w', 'a', 'l', 'e', 's', '\n',
        'g', 'u', 'p', 'p', 'i', 'e', 's', '\n',
        'g', 'u', 'p', 'p', 'y', '\n',
        'g', 'u', 'r', 'g', 'l', 'e', '\n',
        'g', 'u', 'r', 'g', 'l', 'e', 'd', '\n',
        'g', 'u', 'r', 'g', 'l', 'e', 's', '\n',
        'g', 'u', 'r', 'g', 'l', 'i', 'n', 'g', '\n',
        'g', 'u', 'r', 'u', '\n',
        'g', 'u', 'r', 'u', 's', '\n',
        'g', 'u', 's', 'h', '\n',
        'g', 'u', 's', 'h', 'e', 'd', '\n',
        'g', 'u', 's', 'h', 'e', 'r', '\n',
        'g', 'u', 's', 'h', 'e', 's', '\n',
        'g', 'u', 's', 'h', 'i', 'n', 'g', '\n',
        'g', 'u', 's', 's', 'e', 't', '\n',
        'g', 'u', 's', 't', '\n',
        'g', 'u', 's', 't', 'e', 'd', '\n',
        'g', 'u', 's', 't', 'i', 'e', 'r', '\n',
        'g', 'u', 's', 't', 'i', 'e', 's', 't', '\n',
        'g', 'u', 's', 't', 'i', 'n', 'g', '\n',
        'g', 'u', 's', 't', 'o', '\n',
        'g', 'u', 's', 't', 's', '\n',
        'g', 'u', 's', 't', 'y', '\n',
        'g', 'u', 't', '\n',
        'g', 'u', 't', 'l', 'e', 's', 's', '\n',
        'g', 'u', 't', 's', '\n',
        'g', 'u', 't', 's', 'i', 'e', 'r', '\n',
        'g', 'u', 't', 's', 'y', '\n',
        'g', 'u', 't', 't', 'e', 'd', '\n',
        'g', 'u', 't', 't', 'e', 'r', '\n',
        'g', 'u', 't', 't', 'e', 'r', 'e', 'd', '\n',
        'g', 'u', 't', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'g', 'u', 't', 't', 'e', 'r', 's', '\n',
        'g', 'u', 't', 't', 'e', 'r', 's', 'n', 'i', 'p', 'e', '\n',
        'g', 'u', 't', 't', 'e', 'r', 's', 'n', 'i', 'p', 'e', 's', '\n',
        'g', 'u', 't', 't', 'i', 'n', 'g', '\n',
        'g', 'u', 't', 't', 'u', 'r', 'a', 'l', '\n',
        'g', 'u', 't', 't', 'u', 'r', 'a', 'l', 'l', 'y', '\n',
        'g', 'u', 'y', '\n',
        'g', 'u', 'y', 's', '\n',
        'g', 'u', 'z', 'z', 'l', 'e', '\n',
        'g', 'u', 'z', 'z', 'l', 'e', 'd', '\n',
        'g', 'u', 'z', 'z', 'l', 'e', 'r', '\n',
        'g', 'u', 'z', 'z', 'l', 'e', 'r', 's', '\n',
        'g', 'u', 'z', 'z', 'l', 'i', 'n', 'g', '\n',
        'g', 'y', 'm', '\n',
        'g', 'y', 'm', 'k', 'h', 'a', 'n', 'a', '\n',
        'g', 'y', 'm', 'n', 'a', 's', 'i', 'a', '\n',
        'g', 'y', 'm', 'n', 'a', 's', 'i', 'u', 'm', '\n',
        'g', 'y', 'm', 'n', 'a', 's', 'i', 'u', 'm', 's', '\n',
        'g', 'y', 'm', 'n', 'a', 's', 't', '\n',
        'g', 'y', 'm', 'n', 'a', 's', 't', 'i', 'c', '\n',
        'g', 'y', 'm', 'n', 'a', 's', 't', 'i', 'c', 's', '\n',
        'g', 'y', 'm', 'n', 'a', 's', 't', 's', '\n',
        'g', 'y', 'm', 's', '\n',
        'g', 'y', 'n', 'a', 'e', 'c', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'g', 'y', 'n', 'a', 'e', 'c', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'g', 'y', 'n', 'a', 'e', 'c', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'g', 'y', 'n', 'a', 'e', 'c', 'o', 'l', 'o', 'g', 'y', '\n',
        'g', 'y', 'p', 's', 'i', 'e', 's', '\n',
        'g', 'y', 'p', 's', 'u', 'm', '\n',
        'g', 'y', 'p', 's', 'y', '\n',
        'g', 'y', 'r', 'a', 't', 'e', '\n',
        'g', 'y', 'r', 'a', 't', 'e', 'd', '\n',
        'g', 'y', 'r', 'a', 't', 'e', 's', '\n',
        'g', 'y', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'g', 'y', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'g', 'y', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'g', 'y', 'r', 'o', '\n',
        'g', 'y', 'r', 'o', 'm', 'a', 'g', 'n', 'e', 't', 'i', 'c', '\n',
        'g', 'y', 'r', 'o', 's', 'c', 'o', 'p', 'e', '\n',
        'g', 'y', 'r', 'o', 's', 'c', 'o', 'p', 'e', 's', '\n',
        'g', 'y', 'r', 'o', 's', 'c', 'o', 'p', 'i', 'c', '\n',
        'h', 'a', '\n',
        'h', 'a', 'b', 'e', 'r', 'd', 'a', 's', 'h', 'e', 'r', '\n',
        'h', 'a', 'b', 'e', 'r', 'd', 'a', 's', 'h', 'e', 'r', 's', '\n',
        'h', 'a', 'b', 'e', 'r', 'd', 'a', 's', 'h', 'e', 'r', 'y', '\n',
        'h', 'a', 'b', 'i', 't', '\n',
        'h', 'a', 'b', 'i', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'h', 'a', 'b', 'i', 't', 'a', 'b', 'l', 'e', '\n',
        'h', 'a', 'b', 'i', 't', 'a', 't', '\n',
        'h', 'a', 'b', 'i', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'h', 'a', 'b', 'i', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'h', 'a', 'b', 'i', 't', 'a', 't', 's', '\n',
        'h', 'a', 'b', 'i', 't', 'f', 'o', 'r', 'm', 'i', 'n', 'g', '\n',
        'h', 'a', 'b', 'i', 't', 's', '\n',
        'h', 'a', 'b', 'i', 't', 'u', 'a', 'l', '\n',
        'h', 'a', 'b', 'i', 't', 'u', 'a', 'l', 'l', 'y', '\n',
        'h', 'a', 'b', 'i', 't', 'u', 'a', 't', 'e', '\n',
        'h', 'a', 'b', 'i', 't', 'u', 'a', 't', 'e', 'd', '\n',
        'h', 'a', 'b', 'i', 't', 'u', 'a', 't', 'i', 'o', 'n', '\n',
        'h', 'a', 'c', 'i', 'e', 'n', 'd', 'a', '\n',
        'h', 'a', 'c', 'k', '\n',
        'h', 'a', 'c', 'k', 'a', 'b', 'l', 'e', '\n',
        'h', 'a', 'c', 'k', 'e', 'd', '\n',
        'h', 'a', 'c', 'k', 'e', 'r', '\n',
        'h', 'a', 'c', 'k', 'e', 'r', 's', '\n',
        'h', 'a', 'c', 'k', 'i', 'n', 'g', '\n',
        'h', 'a', 'c', 'k', 'l', 'e', '\n',
        'h', 'a', 'c', 'k', 'l', 'e', 's', '\n',
        'h', 'a', 'c', 'k', 'l', 'i', 'n', 'g', '\n',
        'h', 'a', 'c', 'k', 'n', 'e', 'y', '\n',
        'h', 'a', 'c', 'k', 'n', 'e', 'y', 'e', 'd', '\n',
        'h', 'a', 'c', 'k', 's', '\n',
        'h', 'a', 'c', 'k', 's', 'a', 'w', '\n',
        'h', 'a', 'd', '\n',
        'h', 'a', 'd', 'd', 'o', 'c', 'k', '\n',
        'h', 'a', 'd', 'd', 'o', 'c', 'k', 's', '\n',
        'h', 'a', 'd', 'e', 's', '\n',
        'h', 'a', 'd', 'n', 't', '\n',
        'h', 'a', 'd', 'r', 'o', 'n', '\n',
        'h', 'a', 'd', 'r', 'o', 'n', 's', '\n',
        'h', 'a', 'e', 'm', 'a', 't', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'h', 'a', 'e', 'm', 'a', 't', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'h', 'a', 'e', 'm', 'a', 't', 'o', 'l', 'o', 'g', 'y', '\n',
        'h', 'a', 'e', 'm', 'a', 't', 'o', 'm', 'a', '\n',
        'h', 'a', 'e', 'm', 'a', 't', 'u', 'r', 'i', 'a', '\n',
        'h', 'a', 'e', 'm', 'o', 'g', 'l', 'o', 'b', 'i', 'n', '\n',
        'h', 'a', 'e', 'm', 'o', 'l', 'y', 't', 'i', 'c', '\n',
        'h', 'a', 'e', 'm', 'o', 'p', 'h', 'i', 'l', 'i', 'a', '\n',
        'h', 'a', 'e', 'm', 'o', 'p', 'h', 'i', 'l', 'i', 'a', 'c', '\n',
        'h', 'a', 'e', 'm', 'o', 'p', 'h', 'i', 'l', 'i', 'a', 'c', 's', '\n',
        'h', 'a', 'e', 'm', 'o', 'r', 'r', 'h', 'a', 'g', 'e', '\n',
        'h', 'a', 'e', 'm', 'o', 'r', 'r', 'h', 'a', 'g', 'e', 's', '\n',
        'h', 'a', 'e', 'm', 'o', 'r', 'r', 'h', 'a', 'g', 'i', 'c', '\n',
        'h', 'a', 'e', 'm', 'o', 'r', 'r', 'h', 'a', 'g', 'i', 'n', 'g', '\n',
        'h', 'a', 'e', 'm', 'o', 'r', 'r', 'h', 'o', 'i', 'd', '\n',
        'h', 'a', 'e', 'm', 'o', 'r', 'r', 'h', 'o', 'i', 'd', 's', '\n',
        'h', 'a', 'f', 't', '\n',
        'h', 'a', 'f', 't', 's', '\n',
        'h', 'a', 'g', '\n',
        'h', 'a', 'g', 'g', 'a', 'r', 'd', '\n',
        'h', 'a', 'g', 'g', 'a', 'r', 'd', 'n', 'e', 's', 's', '\n',
        'h', 'a', 'g', 'g', 'i', 's', '\n',
        'h', 'a', 'g', 'g', 'l', 'e', '\n',
        'h', 'a', 'g', 'g', 'l', 'e', 'd', '\n',
        'h', 'a', 'g', 'g', 'l', 'e', 'r', '\n',
        'h', 'a', 'g', 'g', 'l', 'i', 'n', 'g', '\n',
        'h', 'a', 'g', 'i', 'o', 'g', 'r', 'a', 'p', 'h', 'y', '\n',
        'h', 'a', 'g', 's', '\n',
        'h', 'a', 'h', 'a', '\n',
        'h', 'a', 'i', 'k', 'u', '\n',
        'h', 'a', 'i', 'l', '\n',
        'h', 'a', 'i', 'l', 'e', 'd', '\n',
        'h', 'a', 'i', 'l', 'i', 'n', 'g', '\n',
        'h', 'a', 'i', 'l', 's', '\n',
        'h', 'a', 'i', 'l', 's', 't', 'o', 'n', 'e', '\n',
        'h', 'a', 'i', 'l', 's', 't', 'o', 'n', 'e', 's', '\n',
        'h', 'a', 'i', 'l', 's', 't', 'o', 'r', 'm', '\n',
        'h', 'a', 'i', 'l', 's', 't', 'o', 'r', 'm', 's', '\n',
        'h', 'a', 'i', 'r', '\n',
        'h', 'a', 'i', 'r', 'b', 'r', 'u', 's', 'h', '\n',
        'h', 'a', 'i', 'r', 'c', 'a', 'r', 'e', '\n',
        'h', 'a', 'i', 'r', 'c', 'u', 't', '\n',
        'h', 'a', 'i', 'r', 'c', 'u', 't', 's', '\n',
        'h', 'a', 'i', 'r', 'd', 'o', '\n',
        'h', 'a', 'i', 'r', 'd', 'r', 'e', 's', 's', 'e', 'r', '\n',
        'h', 'a', 'i', 'r', 'd', 'r', 'e', 's', 's', 'e', 'r', 's', '\n',
        'h', 'a', 'i', 'r', 'd', 'r', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'h', 'a', 'i', 'r', 'e', 'd', '\n',
        'h', 'a', 'i', 'r', 'i', 'e', 'r', '\n',
        'h', 'a', 'i', 'r', 'i', 'e', 's', 't', '\n',
        'h', 'a', 'i', 'r', 'i', 'n', 'e', 's', 's', '\n',
        'h', 'a', 'i', 'r', 'l', 'e', 's', 's', '\n',
        'h', 'a', 'i', 'r', 'l', 'i', 'n', 'e', '\n',
        'h', 'a', 'i', 'r', 'n', 'e', 't', '\n',
        'h', 'a', 'i', 'r', 'p', 'i', 'e', 'c', 'e', '\n',
        'h', 'a', 'i', 'r', 'p', 'i', 'n', '\n',
        'h', 'a', 'i', 'r', 'p', 'i', 'n', 's', '\n',
        'h', 'a', 'i', 'r', 'r', 'a', 'i', 's', 'i', 'n', 'g', '\n',
        'h', 'a', 'i', 'r', 's', '\n',
        'h', 'a', 'i', 'r', 's', 'p', 'l', 'i', 't', 't', 'i', 'n', 'g', '\n',
        'h', 'a', 'i', 'r', 's', 'p', 'r', 'a', 'y', '\n',
        'h', 'a', 'i', 'r', 's', 'p', 'r', 'a', 'y', 's', '\n',
        'h', 'a', 'i', 'r', 's', 't', 'y', 'l', 'e', '\n',
        'h', 'a', 'i', 'r', 's', 't', 'y', 'l', 'e', 's', '\n',
        'h', 'a', 'i', 'r', 's', 't', 'y', 'l', 'i', 'n', 'g', '\n',
        'h', 'a', 'i', 'r', 'y', '\n',
        'h', 'a', 'i', 't', 'i', '\n',
        'h', 'a', 'i', 't', 'i', 'a', 'n', '\n',
        'h', 'a', 'k', 'e', '\n',
        'h', 'a', 'k', 'e', 'a', '\n',
        'h', 'a', 'l', 'e', '\n',
        'h', 'a', 'l', 'f', '\n',
        'h', 'a', 'l', 'f', 'h', 'e', 'a', 'r', 't', 'e', 'd', '\n',
        'h', 'a', 'l', 'f', 'h', 'e', 'a', 'r', 't', 'e', 'd', 'l', 'y', '\n',
        'h', 'a', 'l', 'f', 'h', 'e', 'a', 'r', 't', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'h', 'a', 'l', 'f', 'h', 'o', 'u', 'r', '\n',
        'h', 'a', 'l', 'f', 'h', 'o', 'u', 'r', 'l', 'y', '\n',
        'h', 'a', 'l', 'f', 'h', 'o', 'u', 'r', 's', '\n',
        'h', 'a', 'l', 'f', 's', 'i', 's', 't', 'e', 'r', '\n',
        'h', 'a', 'l', 'f', 't', 'r', 'u', 't', 'h', '\n',
        'h', 'a', 'l', 'f', 't', 'r', 'u', 't', 'h', 's', '\n',
        'h', 'a', 'l', 'f', 'w', 'a', 'y', '\n',
        'h', 'a', 'l', 'i', 'b', 'u', 't', '\n',
        'h', 'a', 'l', 'i', 'f', 'a', 'x', '\n',
        'h', 'a', 'l', 'i', 't', 'e', '\n',
        'h', 'a', 'l', 'i', 't', 'o', 's', 'i', 's', '\n',
        'h', 'a', 'l', 'l', '\n',
        'h', 'a', 'l', 'l', 'e', 'l', 'u', 'j', 'a', 'h', '\n',
        'h', 'a', 'l', 'l', 'm', 'a', 'r', 'k', '\n',
        'h', 'a', 'l', 'l', 'm', 'a', 'r', 'k', 's', '\n',
        'h', 'a', 'l', 'l', 'o', '\n',
        'h', 'a', 'l', 'l', 'o', 'w', '\n',
        'h', 'a', 'l', 'l', 'o', 'w', 'e', 'd', '\n',
        'h', 'a', 'l', 'l', 'o', 'w', 's', '\n',
        'h', 'a', 'l', 'l', 's', '\n',
        'h', 'a', 'l', 'l', 'u', 'c', 'i', 'n', 'a', 't', 'e', '\n',
        'h', 'a', 'l', 'l', 'u', 'c', 'i', 'n', 'a', 't', 'e', 'd', '\n',
        'h', 'a', 'l', 'l', 'u', 'c', 'i', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'h', 'a', 'l', 'l', 'u', 'c', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'h', 'a', 'l', 'l', 'u', 'c', 'i', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'h', 'a', 'l', 'l', 'u', 'c', 'i', 'n', 'a', 't', 'o', 'r', 'y', '\n',
        'h', 'a', 'l', 'l', 'w', 'a', 'y', '\n',
        'h', 'a', 'l', 'l', 'w', 'a', 'y', 's', '\n',
        'h', 'a', 'l', 'o', '\n',
        'h', 'a', 'l', 'o', 'e', 'd', '\n',
        'h', 'a', 'l', 'o', 'g', 'e', 'n', '\n',
        'h', 'a', 'l', 'o', 'g', 'e', 'n', 'a', 't', 'e', 'd', '\n',
        'h', 'a', 'l', 'o', 'g', 'e', 'n', 's', '\n',
        'h', 'a', 'l', 'o', 'n', '\n',
        'h', 'a', 'l', 'o', 'n', 's', '\n',
        'h', 'a', 'l', 't', '\n',
        'h', 'a', 'l', 't', 'e', 'd', '\n',
        'h', 'a', 'l', 't', 'e', 'r', '\n',
        'h', 'a', 'l', 't', 'e', 'r', 'e', 'd', '\n',
        'h', 'a', 'l', 't', 'e', 'r', 's', '\n',
        'h', 'a', 'l', 't', 'i', 'n', 'g', '\n',
        'h', 'a', 'l', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'h', 'a', 'l', 't', 's', '\n',
        'h', 'a', 'l', 'v', 'e', '\n',
        'h', 'a', 'l', 'v', 'e', 'd', '\n',
        'h', 'a', 'l', 'v', 'e', 's', '\n',
        'h', 'a', 'l', 'v', 'i', 'n', 'g', '\n',
        'h', 'a', 'm', '\n',
        'h', 'a', 'm', 'b', 'u', 'r', 'g', '\n',
        'h', 'a', 'm', 'b', 'u', 'r', 'g', 'e', 'r', '\n',
        'h', 'a', 'm', 'b', 'u', 'r', 'g', 'e', 'r', 's', '\n',
        'h', 'a', 'm', 'i', 't', 'i', 'c', '\n',
        'h', 'a', 'm', 'l', 'e', 't', '\n',
        'h', 'a', 'm', 'l', 'e', 't', 's', '\n',
        'h', 'a', 'm', 'm', 'e', 'r', '\n',
        'h', 'a', 'm', 'm', 'e', 'r', 'e', 'd', '\n',
        'h', 'a', 'm', 'm', 'e', 'r', 'h', 'e', 'a', 'd', '\n',
        'h', 'a', 'm', 'm', 'e', 'r', 'i', 'n', 'g', '\n',
        'h', 'a', 'm', 'm', 'e', 'r', 's', '\n',
        'h', 'a', 'm', 'm', 'o', 'c', 'k', '\n',
        'h', 'a', 'm', 'm', 'o', 'c', 'k', 's', '\n',
        'h', 'a', 'm', 'p', 'e', 'r', '\n',
        'h', 'a', 'm', 'p', 'e', 'r', 'e', 'd', '\n',
        'h', 'a', 'm', 'p', 'e', 'r', 'i', 'n', 'g', '\n',
        'h', 'a', 'm', 'p', 'e', 'r', 's', '\n',
        'h', 'a', 'm', 's', '\n',
        'h', 'a', 'm', 's', 't', 'e', 'r', '\n',
        'h', 'a', 'm', 's', 't', 'e', 'r', 's', '\n',
        'h', 'a', 'm', 's', 't', 'r', 'i', 'n', 'g', '\n',
        'h', 'a', 'm', 's', 't', 'r', 'i', 'n', 'g', 's', '\n',
        'h', 'a', 'm', 's', 't', 'r', 'u', 'n', 'g', '\n',
        'h', 'a', 'n', 'd', '\n',
        'h', 'a', 'n', 'd', 'b', 'a', 'g', '\n',
        'h', 'a', 'n', 'd', 'b', 'a', 'g', 's', '\n',
        'h', 'a', 'n', 'd', 'b', 'a', 'l', 'l', '\n',
        'h', 'a', 'n', 'd', 'b', 'a', 's', 'i', 'n', '\n',
        'h', 'a', 'n', 'd', 'b', 'e', 'l', 'l', '\n',
        'h', 'a', 'n', 'd', 'b', 'i', 'l', 'l', '\n',
        'h', 'a', 'n', 'd', 'b', 'i', 'l', 'l', 's', '\n',
        'h', 'a', 'n', 'd', 'b', 'o', 'o', 'k', '\n',
        'h', 'a', 'n', 'd', 'b', 'o', 'o', 'k', 's', '\n',
        'h', 'a', 'n', 'd', 'b', 'r', 'a', 'k', 'e', '\n',
        'h', 'a', 'n', 'd', 'b', 'r', 'a', 'k', 'e', 's', '\n',
        'h', 'a', 'n', 'd', 'c', 'a', 'r', '\n',
        'h', 'a', 'n', 'd', 'c', 'a', 'r', 't', '\n',
        'h', 'a', 'n', 'd', 'c', 'u', 'f', 'f', '\n',
        'h', 'a', 'n', 'd', 'c', 'u', 'f', 'f', 'e', 'd', '\n',
        'h', 'a', 'n', 'd', 'c', 'u', 'f', 'f', 'i', 'n', 'g', '\n',
        'h', 'a', 'n', 'd', 'c', 'u', 'f', 'f', 's', '\n',
        'h', 'a', 'n', 'd', 'e', 'd', '\n',
        'h', 'a', 'n', 'd', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'h', 'a', 'n', 'd', 'e', 'l', '\n',
        'h', 'a', 'n', 'd', 'f', 'u', 'l', '\n',
        'h', 'a', 'n', 'd', 'f', 'u', 'l', 's', '\n',
        'h', 'a', 'n', 'd', 'g', 'u', 'n', '\n',
        'h', 'a', 'n', 'd', 'g', 'u', 'n', 's', '\n',
        'h', 'a', 'n', 'd', 'h', 'o', 'l', 'd', '\n',
        'h', 'a', 'n', 'd', 'h', 'o', 'l', 'd', 's', '\n',
        'h', 'a', 'n', 'd', 'i', 'c', 'a', 'p', '\n',
        'h', 'a', 'n', 'd', 'i', 'c', 'a', 'p', 'p', 'e', 'd', '\n',
        'h', 'a', 'n', 'd', 'i', 'c', 'a', 'p', 'p', 'i', 'n', 'g', '\n',
        'h', 'a', 'n', 'd', 'i', 'c', 'a', 'p', 's', '\n',
        'h', 'a', 'n', 'd', 'i', 'c', 'r', 'a', 'f', 't', '\n',
        'h', 'a', 'n', 'd', 'i', 'c', 'r', 'a', 'f', 't', 's', '\n',
        'h', 'a', 'n', 'd', 'i', 'e', 'r', '\n',
        'h', 'a', 'n', 'd', 'i', 'e', 's', 't', '\n',
        'h', 'a', 'n', 'd', 'i', 'l', 'y', '\n',
        'h', 'a', 'n', 'd', 'i', 'n', 'g', '\n',
        'h', 'a', 'n', 'd', 'i', 'w', 'o', 'r', 'k', '\n',
        'h', 'a', 'n', 'd', 'k', 'e', 'r', 'c', 'h', 'i', 'e', 'f', '\n',
        'h', 'a', 'n', 'd', 'k', 'e', 'r', 'c', 'h', 'i', 'e', 'f', 's', '\n',
        'h', 'a', 'n', 'd', 'l', 'e', '\n',
        'h', 'a', 'n', 'd', 'l', 'e', 'b', 'a', 'r', '\n',
        'h', 'a', 'n', 'd', 'l', 'e', 'b', 'a', 'r', 's', '\n',
        'h', 'a', 'n', 'd', 'l', 'e', 'd', '\n',
        'h', 'a', 'n', 'd', 'l', 'e', 'r', '\n',
        'h', 'a', 'n', 'd', 'l', 'e', 'r', 's', '\n',
        'h', 'a', 'n', 'd', 'l', 'e', 's', '\n',
        'h', 'a', 'n', 'd', 'l', 'i', 'n', 'g', '\n',
        'h', 'a', 'n', 'd', 'm', 'a', 'd', 'e', '\n',
        'h', 'a', 'n', 'd', 'm', 'a', 'i', 'd', 'e', 'n', '\n',
        'h', 'a', 'n', 'd', 'm', 'a', 'i', 'd', 'e', 'n', 's', '\n',
        'h', 'a', 'n', 'd', 'o', 'u', 't', '\n',
        'h', 'a', 'n', 'd', 'o', 'u', 't', 's', '\n',
        'h', 'a', 'n', 'd', 'o', 'v', 'e', 'r', '\n',
        'h', 'a', 'n', 'd', 'o', 'v', 'e', 'r', 's', '\n',
        'h', 'a', 'n', 'd', 'p', 'i', 'c', 'k', 'e', 'd', '\n',
        'h', 'a', 'n', 'd', 'r', 'a', 'i', 'l', '\n',
        'h', 'a', 'n', 'd', 'r', 'a', 'i', 'l', 's', '\n',
        'h', 'a', 'n', 'd', 's', '\n',
        'h', 'a', 'n', 'd', 's', 'e', 't', '\n',
        'h', 'a', 'n', 'd', 's', 'e', 't', 's', '\n',
        'h', 'a', 'n', 'd', 's', 'h', 'a', 'k', 'e', '\n',
        'h', 'a', 'n', 'd', 's', 'h', 'a', 'k', 'e', 's', '\n',
        'h', 'a', 'n', 'd', 's', 'h', 'a', 'k', 'i', 'n', 'g', '\n',
        'h', 'a', 'n', 'd', 's', 'o', 'm', 'e', '\n',
        'h', 'a', 'n', 'd', 's', 'o', 'm', 'e', 'l', 'y', '\n',
        'h', 'a', 'n', 'd', 's', 'o', 'm', 'e', 'n', 'e', 's', 's', '\n',
        'h', 'a', 'n', 'd', 's', 'o', 'm', 'e', 'r', '\n',
        'h', 'a', 'n', 'd', 's', 'o', 'm', 'e', 's', 't', '\n',
        'h', 'a', 'n', 'd', 's', 't', 'a', 'n', 'd', '\n',
        'h', 'a', 'n', 'd', 's', 't', 'a', 'n', 'd', 's', '\n',
        'h', 'a', 'n', 'd', 'w', 'r', 'i', 't', 'i', 'n', 'g', '\n',
        'h', 'a', 'n', 'd', 'w', 'r', 'i', 't', 't', 'e', 'n', '\n',
        'h', 'a', 'n', 'd', 'y', '\n',
        'h', 'a', 'n', 'd', 'y', 'm', 'a', 'n', '\n',
        'h', 'a', 'n', 'd', 'y', 'm', 'e', 'n', '\n',
        'h', 'a', 'n', 'g', '\n',
        'h', 'a', 'n', 'g', 'a', 'r', '\n',
        'h', 'a', 'n', 'g', 'a', 'r', 's', '\n',
        'h', 'a', 'n', 'g', 'd', 'o', 'g', '\n',
        'h', 'a', 'n', 'g', 'e', 'd', '\n',
        'h', 'a', 'n', 'g', 'e', 'r', '\n',
        'h', 'a', 'n', 'g', 'e', 'r', 's', '\n',
        'h', 'a', 'n', 'g', 'g', 'l', 'i', 'd', 'e', '\n',
        'h', 'a', 'n', 'g', 'g', 'l', 'i', 'd', 'e', 'd', '\n',
        'h', 'a', 'n', 'g', 'g', 'l', 'i', 'd', 'e', 'r', '\n',
        'h', 'a', 'n', 'g', 'g', 'l', 'i', 'd', 'e', 'r', 's', '\n',
        'h', 'a', 'n', 'g', 'g', 'l', 'i', 'd', 'e', 's', '\n',
        'h', 'a', 'n', 'g', 'g', 'l', 'i', 'd', 'i', 'n', 'g', '\n',
        'h', 'a', 'n', 'g', 'i', 'n', 'g', '\n',
        'h', 'a', 'n', 'g', 'i', 'n', 'g', 's', '\n',
        'h', 'a', 'n', 'g', 'm', 'a', 'n', '\n',
        'h', 'a', 'n', 'g', 'm', 'e', 'n', '\n',
        'h', 'a', 'n', 'g', 'o', 'u', 't', 's', '\n',
        'h', 'a', 'n', 'g', 'o', 'v', 'e', 'r', '\n',
        'h', 'a', 'n', 'g', 'o', 'v', 'e', 'r', 's', '\n',
        'h', 'a', 'n', 'g', 's', '\n',
        'h', 'a', 'n', 'g', 'u', 'p', '\n',
        'h', 'a', 'n', 'k', 'e', 'r', '\n',
        'h', 'a', 'n', 'k', 'e', 'r', 'e', 'd', '\n',
        'h', 'a', 'n', 'k', 'e', 'r', 'i', 'n', 'g', '\n',
        'h', 'a', 'n', 'k', 'e', 'r', 's', '\n',
        'h', 'a', 'n', 'k', 'i', 'e', '\n',
        'h', 'a', 'n', 'k', 'i', 'e', 's', '\n',
        'h', 'a', 'n', 'o', 'i', '\n',
        'h', 'a', 'n', 'o', 'v', 'e', 'r', '\n',
        'h', 'a', 'n', 's', 'a', 'r', 'd', '\n',
        'h', 'a', 'n', 's', 'o', 'm', '\n',
        'h', 'a', 'p', 'h', 'a', 'z', 'a', 'r', 'd', '\n',
        'h', 'a', 'p', 'h', 'a', 'z', 'a', 'r', 'd', 'l', 'y', '\n',
        'h', 'a', 'p', 'l', 'e', 's', 's', '\n',
        'h', 'a', 'p', 'p', 'e', 'n', '\n',
        'h', 'a', 'p', 'p', 'e', 'n', 'e', 'd', '\n',
        'h', 'a', 'p', 'p', 'e', 'n', 'i', 'n', 'g', '\n',
        'h', 'a', 'p', 'p', 'e', 'n', 'i', 'n', 'g', 's', '\n',
        'h', 'a', 'p', 'p', 'e', 'n', 's', '\n',
        'h', 'a', 'p', 'p', 'i', 'e', 'r', '\n',
        'h', 'a', 'p', 'p', 'i', 'e', 's', 't', '\n',
        'h', 'a', 'p', 'p', 'i', 'l', 'y', '\n',
        'h', 'a', 'p', 'p', 'i', 'n', 'e', 's', 's', '\n',
        'h', 'a', 'p', 'p', 'y', '\n',
        'h', 'a', 'p', 'p', 'y', 'g', 'o', 'l', 'u', 'c', 'k', 'y', '\n',
        'h', 'a', 'r', 'a', 'n', 'g', 'u', 'e', '\n',
        'h', 'a', 'r', 'a', 'n', 'g', 'u', 'e', 'd', '\n',
        'h', 'a', 'r', 'a', 'n', 'g', 'u', 'e', 's', '\n',
        'h', 'a', 'r', 'a', 'n', 'g', 'u', 'i', 'n', 'g', '\n',
        'h', 'a', 'r', 'a', 'r', 'e', '\n',
        'h', 'a', 'r', 'a', 's', 's', '\n',
        'h', 'a', 'r', 'a', 's', 's', 'e', 'd', '\n',
        'h', 'a', 'r', 'a', 's', 's', 'e', 'r', 's', '\n',
        'h', 'a', 'r', 'a', 's', 's', 'e', 's', '\n',
        'h', 'a', 'r', 'a', 's', 's', 'i', 'n', 'g', '\n',
        'h', 'a', 'r', 'a', 's', 's', 'm', 'e', 'n', 't', '\n',
        'h', 'a', 'r', 'b', 'i', 'n', 'g', 'e', 'r', '\n',
        'h', 'a', 'r', 'b', 'i', 'n', 'g', 'e', 'r', 's', '\n',
        'h', 'a', 'r', 'b', 'o', 'u', 'r', '\n',
        'h', 'a', 'r', 'b', 'o', 'u', 'r', 'e', 'd', '\n',
        'h', 'a', 'r', 'b', 'o', 'u', 'r', 'i', 'n', 'g', '\n',
        'h', 'a', 'r', 'b', 'o', 'u', 'r', 's', '\n',
        'h', 'a', 'r', 'd', '\n',
        'h', 'a', 'r', 'd', 'b', 'a', 'c', 'k', '\n',
        'h', 'a', 'r', 'd', 'b', 'a', 'c', 'k', 's', '\n',
        'h', 'a', 'r', 'd', 'b', 'o', 'a', 'r', 'd', '\n',
        'h', 'a', 'r', 'd', 'b', 'o', 'i', 'l', 'e', 'd', '\n',
        'h', 'a', 'r', 'd', 'c', 'o', 'r', 'e', '\n',
        'h', 'a', 'r', 'd', 'e', 'a', 'r', 'n', 'e', 'd', '\n',
        'h', 'a', 'r', 'd', 'e', 'n', '\n',
        'h', 'a', 'r', 'd', 'e', 'n', 'e', 'd', '\n',
        'h', 'a', 'r', 'd', 'e', 'n', 'e', 'r', '\n',
        'h', 'a', 'r', 'd', 'e', 'n', 'e', 'r', 's', '\n',
        'h', 'a', 'r', 'd', 'e', 'n', 'i', 'n', 'g', '\n',
        'h', 'a', 'r', 'd', 'e', 'n', 's', '\n',
        'h', 'a', 'r', 'd', 'e', 'r', '\n',
        'h', 'a', 'r', 'd', 'e', 's', 't', '\n',
        'h', 'a', 'r', 'd', 'h', 'e', 'a', 'd', 'e', 'd', '\n',
        'h', 'a', 'r', 'd', 'h', 'e', 'a', 'r', 't', 'e', 'd', '\n',
        'h', 'a', 'r', 'd', 'h', 'e', 'a', 'r', 't', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'h', 'a', 'r', 'd', 'h', 'i', 't', '\n',
        'h', 'a', 'r', 'd', 'h', 'i', 't', 't', 'i', 'n', 'g', '\n',
        'h', 'a', 'r', 'd', 'i', 'e', 'r', '\n',
        'h', 'a', 'r', 'd', 'i', 'e', 's', 't', '\n',
        'h', 'a', 'r', 'd', 'i', 'l', 'y', '\n',
        'h', 'a', 'r', 'd', 'i', 'n', 'e', 's', 's', '\n',
        'h', 'a', 'r', 'd', 'l', 'i', 'n', 'e', '\n',
        'h', 'a', 'r', 'd', 'l', 'i', 'n', 'e', 'r', '\n',
        'h', 'a', 'r', 'd', 'l', 'i', 'n', 'e', 'r', 's', '\n',
        'h', 'a', 'r', 'd', 'l', 'y', '\n',
        'h', 'a', 'r', 'd', 'n', 'e', 's', 's', '\n',
        'h', 'a', 'r', 'd', 'p', 'r', 'e', 's', 's', 'e', 'd', '\n',
        'h', 'a', 'r', 'd', 's', 'h', 'i', 'p', '\n',
        'h', 'a', 'r', 'd', 's', 'h', 'i', 'p', 's', '\n',
        'h', 'a', 'r', 'd', 'u', 'p', '\n',
        'h', 'a', 'r', 'd', 'w', 'a', 'r', 'e', '\n',
        'h', 'a', 'r', 'd', 'w', 'o', 'o', 'd', '\n',
        'h', 'a', 'r', 'd', 'w', 'o', 'o', 'd', 's', '\n',
        'h', 'a', 'r', 'd', 'w', 'o', 'r', 'k', 'i', 'n', 'g', '\n',
        'h', 'a', 'r', 'd', 'y', '\n',
        'h', 'a', 'r', 'e', '\n',
        'h', 'a', 'r', 'e', 'b', 'e', 'l', 'l', '\n',
        'h', 'a', 'r', 'e', 'b', 'e', 'l', 'l', 's', '\n',
        'h', 'a', 'r', 'e', 'b', 'r', 'a', 'i', 'n', 'e', 'd', '\n',
        'h', 'a', 'r', 'e', 'd', '\n',
        'h', 'a', 'r', 'e', 'm', '\n',
        'h', 'a', 'r', 'e', 'm', 's', '\n',
        'h', 'a', 'r', 'e', 's', '\n',
        'h', 'a', 'r', 'k', '\n',
        'h', 'a', 'r', 'k', 'e', 'd', '\n',
        'h', 'a', 'r', 'k', 'e', 'n', '\n',
        'h', 'a', 'r', 'k', 'e', 'n', 'e', 'd', '\n',
        'h', 'a', 'r', 'k', 'e', 'n', 's', '\n',
        'h', 'a', 'r', 'k', 'i', 'n', 'g', '\n',
        'h', 'a', 'r', 'k', 's', '\n',
        'h', 'a', 'r', 'l', 'e', 'q', 'u', 'i', 'n', '\n',
        'h', 'a', 'r', 'l', 'e', 'q', 'u', 'i', 'n', 's', '\n',
        'h', 'a', 'r', 'l', 'o', 't', '\n',
        'h', 'a', 'r', 'l', 'o', 't', 's', '\n',
        'h', 'a', 'r', 'm', '\n',
        'h', 'a', 'r', 'm', 'e', 'd', '\n',
        'h', 'a', 'r', 'm', 'e', 'r', '\n',
        'h', 'a', 'r', 'm', 'f', 'u', 'l', '\n',
        'h', 'a', 'r', 'm', 'f', 'u', 'l', 'l', 'y', '\n',
        'h', 'a', 'r', 'm', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'h', 'a', 'r', 'm', 'i', 'n', 'g', '\n',
        'h', 'a', 'r', 'm', 'l', 'e', 's', 's', '\n',
        'h', 'a', 'r', 'm', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'h', 'a', 'r', 'm', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'h', 'a', 'r', 'm', 'o', 'n', 'i', 'c', '\n',
        'h', 'a', 'r', 'm', 'o', 'n', 'i', 'c', 'a', '\n',
        'h', 'a', 'r', 'm', 'o', 'n', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'h', 'a', 'r', 'm', 'o', 'n', 'i', 'c', 's', '\n',
        'h', 'a', 'r', 'm', 'o', 'n', 'i', 'e', 's', '\n',
        'h', 'a', 'r', 'm', 'o', 'n', 'i', 'o', 'u', 's', '\n',
        'h', 'a', 'r', 'm', 'o', 'n', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'h', 'a', 'r', 'm', 'o', 'n', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'h', 'a', 'r', 'm', 'o', 'n', 'i', 's', 'e', '\n',
        'h', 'a', 'r', 'm', 'o', 'n', 'i', 's', 'e', 'd', '\n',
        'h', 'a', 'r', 'm', 'o', 'n', 'i', 's', 'i', 'n', 'g', '\n',
        'h', 'a', 'r', 'm', 'o', 'n', 'i', 'u', 'm', '\n',
        'h', 'a', 'r', 'm', 'o', 'n', 'y', '\n',
        'h', 'a', 'r', 'm', 's', '\n',
        'h', 'a', 'r', 'n', 'e', 's', 's', '\n',
        'h', 'a', 'r', 'n', 'e', 's', 's', 'e', 'd', '\n',
        'h', 'a', 'r', 'n', 'e', 's', 's', 'e', 's', '\n',
        'h', 'a', 'r', 'n', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'h', 'a', 'r', 'p', '\n',
        'h', 'a', 'r', 'p', 'e', 'd', '\n',
        'h', 'a', 'r', 'p', 'i', 'n', 'g', '\n',
        'h', 'a', 'r', 'p', 'i', 's', 't', '\n',
        'h', 'a', 'r', 'p', 'i', 's', 't', 's', '\n',
        'h', 'a', 'r', 'p', 'o', 'o', 'n', '\n',
        'h', 'a', 'r', 'p', 'o', 'o', 'n', 's', '\n',
        'h', 'a', 'r', 'p', 's', '\n',
        'h', 'a', 'r', 'p', 's', 'i', 'c', 'h', 'o', 'r', 'd', '\n',
        'h', 'a', 'r', 'p', 's', 'i', 'c', 'h', 'o', 'r', 'd', 's', '\n',
        'h', 'a', 'r', 'r', 'i', 'd', 'a', 'n', '\n',
        'h', 'a', 'r', 'r', 'i', 'e', 'd', '\n',
        'h', 'a', 'r', 'r', 'i', 'e', 'r', '\n',
        'h', 'a', 'r', 'r', 'i', 'e', 'r', 's', '\n',
        'h', 'a', 'r', 'r', 'o', 'w', '\n',
        'h', 'a', 'r', 'r', 'o', 'w', 'e', 'd', '\n',
        'h', 'a', 'r', 'r', 'o', 'w', 'i', 'n', 'g', '\n',
        'h', 'a', 'r', 'r', 'o', 'w', 's', '\n',
        'h', 'a', 'r', 'r', 'y', '\n',
        'h', 'a', 'r', 'r', 'y', 'i', 'n', 'g', '\n',
        'h', 'a', 'r', 's', 'h', '\n',
        'h', 'a', 'r', 's', 'h', 'e', 'n', '\n',
        'h', 'a', 'r', 's', 'h', 'e', 'n', 's', '\n',
        'h', 'a', 'r', 's', 'h', 'e', 'r', '\n',
        'h', 'a', 'r', 's', 'h', 'e', 's', 't', '\n',
        'h', 'a', 'r', 's', 'h', 'l', 'y', '\n',
        'h', 'a', 'r', 's', 'h', 'n', 'e', 's', 's', '\n',
        'h', 'a', 'r', 't', '\n',
        'h', 'a', 'r', 't', 's', '\n',
        'h', 'a', 'r', 'v', 'a', 'r', 'd', '\n',
        'h', 'a', 'r', 'v', 'e', 's', 't', '\n',
        'h', 'a', 'r', 'v', 'e', 's', 't', 'e', 'd', '\n',
        'h', 'a', 'r', 'v', 'e', 's', 't', 'e', 'r', '\n',
        'h', 'a', 'r', 'v', 'e', 's', 't', 'e', 'r', 's', '\n',
        'h', 'a', 'r', 'v', 'e', 's', 't', 'i', 'n', 'g', '\n',
        'h', 'a', 'r', 'v', 'e', 's', 't', 's', '\n',
        'h', 'a', 's', '\n',
        'h', 'a', 's', 'b', 'e', 'e', 'n', '\n',
        'h', 'a', 's', 'b', 'e', 'e', 'n', 's', '\n',
        'h', 'a', 's', 'h', '\n',
        'h', 'a', 's', 'h', 'e', 'd', '\n',
        'h', 'a', 's', 'h', 'e', 's', '\n',
        'h', 'a', 's', 'h', 'i', 'n', 'g', '\n',
        'h', 'a', 's', 'h', 'i', 's', 'h', '\n',
        'h', 'a', 's', 'n', 't', '\n',
        'h', 'a', 's', 'p', '\n',
        'h', 'a', 's', 's', 'l', 'e', '\n',
        'h', 'a', 's', 't', 'e', '\n',
        'h', 'a', 's', 't', 'e', 'd', '\n',
        'h', 'a', 's', 't', 'e', 'n', '\n',
        'h', 'a', 's', 't', 'e', 'n', 'e', 'd', '\n',
        'h', 'a', 's', 't', 'e', 'n', 'i', 'n', 'g', '\n',
        'h', 'a', 's', 't', 'e', 'n', 's', '\n',
        'h', 'a', 's', 't', 'e', 's', '\n',
        'h', 'a', 's', 't', 'i', 'e', 'r', '\n',
        'h', 'a', 's', 't', 'i', 'e', 's', 't', '\n',
        'h', 'a', 's', 't', 'i', 'l', 'y', '\n',
        'h', 'a', 's', 't', 'i', 'n', 'e', 's', 's', '\n',
        'h', 'a', 's', 't', 'y', '\n',
        'h', 'a', 't', '\n',
        'h', 'a', 't', 'c', 'h', '\n',
        'h', 'a', 't', 'c', 'h', 'b', 'a', 'c', 'k', '\n',
        'h', 'a', 't', 'c', 'h', 'b', 'a', 'c', 'k', 's', '\n',
        'h', 'a', 't', 'c', 'h', 'e', 'd', '\n',
        'h', 'a', 't', 'c', 'h', 'e', 'r', 'i', 'e', 's', '\n',
        'h', 'a', 't', 'c', 'h', 'e', 'r', 'y', '\n',
        'h', 'a', 't', 'c', 'h', 'e', 's', '\n',
        'h', 'a', 't', 'c', 'h', 'e', 't', '\n',
        'h', 'a', 't', 'c', 'h', 'e', 't', 's', '\n',
        'h', 'a', 't', 'c', 'h', 'i', 'n', 'g', '\n',
        'h', 'a', 't', 'c', 'h', 'w', 'a', 'y', '\n',
        'h', 'a', 't', 'e', '\n',
        'h', 'a', 't', 'e', 'd', '\n',
        'h', 'a', 't', 'e', 'f', 'u', 'l', '\n',
        'h', 'a', 't', 'e', 'f', 'u', 'l', 'l', 'y', '\n',
        'h', 'a', 't', 'e', 'r', '\n',
        'h', 'a', 't', 'e', 'r', 's', '\n',
        'h', 'a', 't', 'e', 's', '\n',
        'h', 'a', 't', 'f', 'u', 'l', '\n',
        'h', 'a', 't', 'i', 'n', 'g', '\n',
        'h', 'a', 't', 'l', 'e', 's', 's', '\n',
        'h', 'a', 't', 'r', 'a', 'c', 'k', '\n',
        'h', 'a', 't', 'r', 'a', 'c', 'k', 's', '\n',
        'h', 'a', 't', 'r', 'e', 'd', '\n',
        'h', 'a', 't', 'r', 'e', 'd', 's', '\n',
        'h', 'a', 't', 's', '\n',
        'h', 'a', 't', 's', 't', 'a', 'n', 'd', 's', '\n',
        'h', 'a', 't', 't', 'e', 'd', '\n',
        'h', 'a', 't', 't', 'e', 'r', '\n',
        'h', 'a', 't', 't', 'e', 'r', 's', '\n',
        'h', 'a', 't', 't', 'r', 'i', 'c', 'k', '\n',
        'h', 'a', 't', 't', 'r', 'i', 'c', 'k', 's', '\n',
        'h', 'a', 'u', 'g', 'h', 't', 'i', 'e', 'r', '\n',
        'h', 'a', 'u', 'g', 'h', 't', 'i', 'e', 's', 't', '\n',
        'h', 'a', 'u', 'g', 'h', 't', 'i', 'l', 'y', '\n',
        'h', 'a', 'u', 'g', 'h', 't', 'i', 'n', 'e', 's', 's', '\n',
        'h', 'a', 'u', 'g', 'h', 't', 'y', '\n',
        'h', 'a', 'u', 'l', '\n',
        'h', 'a', 'u', 'l', 'a', 'g', 'e', '\n',
        'h', 'a', 'u', 'l', 'a', 'g', 'e', 's', '\n',
        'h', 'a', 'u', 'l', 'e', 'd', '\n',
        'h', 'a', 'u', 'l', 'e', 'r', '\n',
        'h', 'a', 'u', 'l', 'e', 'r', 's', '\n',
        'h', 'a', 'u', 'l', 'i', 'e', 'r', '\n',
        'h', 'a', 'u', 'l', 'i', 'e', 'r', 's', '\n',
        'h', 'a', 'u', 'l', 'i', 'n', 'g', '\n',
        'h', 'a', 'u', 'l', 'm', 's', '\n',
        'h', 'a', 'u', 'l', 's', '\n',
        'h', 'a', 'u', 'n', 'c', 'h', '\n',
        'h', 'a', 'u', 'n', 'c', 'h', 'e', 's', '\n',
        'h', 'a', 'u', 'n', 't', '\n',
        'h', 'a', 'u', 'n', 't', 'e', 'd', '\n',
        'h', 'a', 'u', 'n', 't', 'i', 'n', 'g', '\n',
        'h', 'a', 'u', 'n', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'h', 'a', 'u', 'n', 't', 's', '\n',
        'h', 'a', 'u', 't', 'e', 'u', 'r', '\n',
        'h', 'a', 'v', 'a', 'n', 'a', '\n',
        'h', 'a', 'v', 'e', '\n',
        'h', 'a', 'v', 'e', 'n', '\n',
        'h', 'a', 'v', 'e', 'n', 'o', 't', 's', '\n',
        'h', 'a', 'v', 'e', 'n', 's', '\n',
        'h', 'a', 'v', 'e', 'n', 't', '\n',
        'h', 'a', 'v', 'e', 'r', 'i', 'n', 'g', '\n',
        'h', 'a', 'v', 'e', 'r', 's', 'a', 'c', 'k', '\n',
        'h', 'a', 'v', 'e', 's', '\n',
        'h', 'a', 'v', 'i', 'n', 'g', '\n',
        'h', 'a', 'v', 'o', 'c', '\n',
        'h', 'a', 'w', 'a', 'i', 'i', '\n',
        'h', 'a', 'w', 'a', 'i', 'i', 'a', 'n', '\n',
        'h', 'a', 'w', 'k', '\n',
        'h', 'a', 'w', 'k', 'e', 'd', '\n',
        'h', 'a', 'w', 'k', 'e', 'r', '\n',
        'h', 'a', 'w', 'k', 'e', 'r', 's', '\n',
        'h', 'a', 'w', 'k', 'i', 'n', 'g', '\n',
        'h', 'a', 'w', 'k', 'i', 's', 'h', '\n',
        'h', 'a', 'w', 'k', 's', '\n',
        'h', 'a', 'w', 's', 'e', 'r', '\n',
        'h', 'a', 'w', 's', 'e', 'r', 's', '\n',
        'h', 'a', 'w', 't', 'h', 'o', 'r', 'n', '\n',
        'h', 'a', 'w', 't', 'h', 'o', 'r', 'n', 's', '\n',
        'h', 'a', 'y', '\n',
        'h', 'a', 'y', 'd', 'n', '\n',
        'h', 'a', 'y', 'f', 'e', 'v', 'e', 'r', '\n',
        'h', 'a', 'y', 'f', 'i', 'e', 'l', 'd', '\n',
        'h', 'a', 'y', 'l', 'o', 'f', 't', '\n',
        'h', 'a', 'y', 's', 't', 'a', 'c', 'k', '\n',
        'h', 'a', 'y', 's', 't', 'a', 'c', 'k', 's', '\n',
        'h', 'a', 'y', 'w', 'a', 'i', 'n', '\n',
        'h', 'a', 'y', 'w', 'i', 'r', 'e', '\n',
        'h', 'a', 'z', 'a', 'r', 'd', '\n',
        'h', 'a', 'z', 'a', 'r', 'd', 'e', 'd', '\n',
        'h', 'a', 'z', 'a', 'r', 'd', 'i', 'n', 'g', '\n',
        'h', 'a', 'z', 'a', 'r', 'd', 'o', 'u', 's', '\n',
        'h', 'a', 'z', 'a', 'r', 'd', 's', '\n',
        'h', 'a', 'z', 'e', '\n',
        'h', 'a', 'z', 'e', 'l', '\n',
        'h', 'a', 'z', 'e', 'l', 'n', 'u', 't', '\n',
        'h', 'a', 'z', 'e', 'l', 'n', 'u', 't', 's', '\n',
        'h', 'a', 'z', 'i', 'e', 'r', '\n',
        'h', 'a', 'z', 'i', 'e', 's', 't', '\n',
        'h', 'a', 'z', 'i', 'l', 'y', '\n',
        'h', 'a', 'z', 'i', 'n', 'e', 's', 's', '\n',
        'h', 'a', 'z', 'y', '\n',
        'h', 'e', '\n',
        'h', 'e', 'a', 'd', '\n',
        'h', 'e', 'a', 'd', 'a', 'c', 'h', 'e', '\n',
        'h', 'e', 'a', 'd', 'a', 'c', 'h', 'e', 's', '\n',
        'h', 'e', 'a', 'd', 'b', 'a', 'n', 'd', '\n',
        'h', 'e', 'a', 'd', 'b', 'a', 'n', 'd', 's', '\n',
        'h', 'e', 'a', 'd', 'b', 'o', 'a', 'r', 'd', '\n',
        'h', 'e', 'a', 'd', 'b', 'o', 'a', 'r', 'd', 's', '\n',
        'h', 'e', 'a', 'd', 'c', 'o', 'u', 'n', 't', '\n',
        'h', 'e', 'a', 'd', 'd', 'r', 'e', 's', 's', '\n',
        'h', 'e', 'a', 'd', 'd', 'r', 'e', 's', 's', 'e', 's', '\n',
        'h', 'e', 'a', 'd', 'e', 'd', '\n',
        'h', 'e', 'a', 'd', 'e', 'r', '\n',
        'h', 'e', 'a', 'd', 'e', 'r', 's', '\n',
        'h', 'e', 'a', 'd', 'f', 'a', 's', 't', '\n',
        'h', 'e', 'a', 'd', 'g', 'e', 'a', 'r', '\n',
        'h', 'e', 'a', 'd', 'h', 'u', 'n', 't', 'e', 'd', '\n',
        'h', 'e', 'a', 'd', 'h', 'u', 'n', 't', 'e', 'r', 's', '\n',
        'h', 'e', 'a', 'd', 'i', 'e', 'r', '\n',
        'h', 'e', 'a', 'd', 'i', 'e', 's', 't', '\n',
        'h', 'e', 'a', 'd', 'i', 'n', 'g', '\n',
        'h', 'e', 'a', 'd', 'i', 'n', 'g', 's', '\n',
        'h', 'e', 'a', 'd', 'l', 'a', 'm', 'p', '\n',
        'h', 'e', 'a', 'd', 'l', 'a', 'm', 'p', 's', '\n',
        'h', 'e', 'a', 'd', 'l', 'a', 'n', 'd', '\n',
        'h', 'e', 'a', 'd', 'l', 'a', 'n', 'd', 's', '\n',
        'h', 'e', 'a', 'd', 'l', 'e', 's', 's', '\n',
        'h', 'e', 'a', 'd', 'l', 'i', 'g', 'h', 't', '\n',
        'h', 'e', 'a', 'd', 'l', 'i', 'g', 'h', 't', 's', '\n',
        'h', 'e', 'a', 'd', 'l', 'i', 'n', 'e', '\n',
        'h', 'e', 'a', 'd', 'l', 'i', 'n', 'e', 'd', '\n',
        'h', 'e', 'a', 'd', 'l', 'i', 'n', 'e', 's', '\n',
        'h', 'e', 'a', 'd', 'l', 'i', 'n', 'i', 'n', 'g', '\n',
        'h', 'e', 'a', 'd', 'l', 'o', 'c', 'k', '\n',
        'h', 'e', 'a', 'd', 'l', 'o', 'n', 'g', '\n',
        'h', 'e', 'a', 'd', 'm', 'a', 'n', '\n',
        'h', 'e', 'a', 'd', 'm', 'a', 's', 't', 'e', 'r', '\n',
        'h', 'e', 'a', 'd', 'm', 'a', 's', 't', 'e', 'r', 's', '\n',
        'h', 'e', 'a', 'd', 'm', 'a', 's', 't', 'e', 'r', 's', 'h', 'i', 'p', '\n',
        'h', 'e', 'a', 'd', 'm', 'e', 'n', '\n',
        'h', 'e', 'a', 'd', 'm', 'i', 's', 't', 'r', 'e', 's', 's', '\n',
        'h', 'e', 'a', 'd', 'm', 'i', 's', 't', 'r', 'e', 's', 's', 'e', 's', '\n',
        'h', 'e', 'a', 'd', 'n', 'o', 't', 'e', '\n',
        'h', 'e', 'a', 'd', 'o', 'n', '\n',
        'h', 'e', 'a', 'd', 'p', 'h', 'o', 'n', 'e', '\n',
        'h', 'e', 'a', 'd', 'p', 'h', 'o', 'n', 'e', 's', '\n',
        'h', 'e', 'a', 'd', 'p', 'i', 'e', 'c', 'e', '\n',
        'h', 'e', 'a', 'd', 'q', 'u', 'a', 'r', 't', 'e', 'r', 's', '\n',
        'h', 'e', 'a', 'd', 'r', 'e', 's', 't', '\n',
        'h', 'e', 'a', 'd', 'r', 'o', 'o', 'm', '\n',
        'h', 'e', 'a', 'd', 's', '\n',
        'h', 'e', 'a', 'd', 's', 'c', 'a', 'r', 'f', '\n',
        'h', 'e', 'a', 'd', 's', 'c', 'a', 'r', 'v', 'e', 's', '\n',
        'h', 'e', 'a', 'd', 's', 'e', 't', '\n',
        'h', 'e', 'a', 'd', 's', 'e', 't', 's', '\n',
        'h', 'e', 'a', 'd', 's', 'h', 'i', 'p', '\n',
        'h', 'e', 'a', 'd', 's', 't', 'a', 'n', 'd', '\n',
        'h', 'e', 'a', 'd', 's', 't', 'o', 'c', 'k', '\n',
        'h', 'e', 'a', 'd', 's', 't', 'o', 'n', 'e', '\n',
        'h', 'e', 'a', 'd', 's', 't', 'o', 'n', 'e', 's', '\n',
        'h', 'e', 'a', 'd', 's', 't', 'r', 'o', 'n', 'g', '\n',
        'h', 'e', 'a', 'd', 'w', 'a', 't', 'e', 'r', 's', '\n',
        'h', 'e', 'a', 'd', 'w', 'a', 'y', '\n',
        'h', 'e', 'a', 'd', 'w', 'i', 'n', 'd', '\n',
        'h', 'e', 'a', 'd', 'w', 'i', 'n', 'd', 's', '\n',
        'h', 'e', 'a', 'd', 'w', 'o', 'r', 'd', '\n',
        'h', 'e', 'a', 'd', 'w', 'o', 'r', 'd', 's', '\n',
        'h', 'e', 'a', 'd', 'w', 'o', 'r', 'k', '\n',
        'h', 'e', 'a', 'd', 'y', '\n',
        'h', 'e', 'a', 'l', '\n',
        'h', 'e', 'a', 'l', 'e', 'd', '\n',
        'h', 'e', 'a', 'l', 'e', 'r', '\n',
        'h', 'e', 'a', 'l', 'e', 'r', 's', '\n',
        'h', 'e', 'a', 'l', 'i', 'n', 'g', '\n',
        'h', 'e', 'a', 'l', 's', '\n',
        'h', 'e', 'a', 'l', 't', 'h', '\n',
        'h', 'e', 'a', 'l', 't', 'h', 'f', 'u', 'l', '\n',
        'h', 'e', 'a', 'l', 't', 'h', 'i', 'e', 'r', '\n',
        'h', 'e', 'a', 'l', 't', 'h', 'i', 'e', 's', 't', '\n',
        'h', 'e', 'a', 'l', 't', 'h', 'i', 'l', 'y', '\n',
        'h', 'e', 'a', 'l', 't', 'h', 'i', 'n', 'e', 's', 's', '\n',
        'h', 'e', 'a', 'l', 't', 'h', 's', '\n',
        'h', 'e', 'a', 'l', 't', 'h', 'y', '\n',
        'h', 'e', 'a', 'p', '\n',
        'h', 'e', 'a', 'p', 'e', 'd', '\n',
        'h', 'e', 'a', 'p', 'i', 'n', 'g', '\n',
        'h', 'e', 'a', 'p', 's', '\n',
        'h', 'e', 'a', 'r', '\n',
        'h', 'e', 'a', 'r', 'a', 'b', 'l', 'e', '\n',
        'h', 'e', 'a', 'r', 'd', '\n',
        'h', 'e', 'a', 'r', 'e', 'r', '\n',
        'h', 'e', 'a', 'r', 'e', 'r', 's', '\n',
        'h', 'e', 'a', 'r', 'i', 'n', 'g', '\n',
        'h', 'e', 'a', 'r', 'i', 'n', 'g', 's', '\n',
        'h', 'e', 'a', 'r', 'k', 'e', 'n', '\n',
        'h', 'e', 'a', 'r', 'k', 'e', 'n', 'e', 'd', '\n',
        'h', 'e', 'a', 'r', 'k', 'e', 'n', 'i', 'n', 'g', '\n',
        'h', 'e', 'a', 'r', 'k', 'e', 'n', 's', '\n',
        'h', 'e', 'a', 'r', 's', '\n',
        'h', 'e', 'a', 'r', 's', 'a', 'y', '\n',
        'h', 'e', 'a', 'r', 's', 'e', '\n',
        'h', 'e', 'a', 'r', 's', 'e', 's', '\n',
        'h', 'e', 'a', 'r', 't', '\n',
        'h', 'e', 'a', 'r', 't', 'a', 'c', 'h', 'e', '\n',
        'h', 'e', 'a', 'r', 't', 'b', 'e', 'a', 't', '\n',
        'h', 'e', 'a', 'r', 't', 'b', 'e', 'a', 't', 's', '\n',
        'h', 'e', 'a', 'r', 't', 'b', 'r', 'e', 'a', 'k', '\n',
        'h', 'e', 'a', 'r', 't', 'b', 'r', 'e', 'a', 'k', 'i', 'n', 'g', '\n',
        'h', 'e', 'a', 'r', 't', 'b', 'r', 'e', 'a', 'k', 's', '\n',
        'h', 'e', 'a', 'r', 't', 'b', 'r', 'o', 'k', 'e', 'n', '\n',
        'h', 'e', 'a', 'r', 't', 'b', 'u', 'r', 'n', '\n',
        'h', 'e', 'a', 'r', 't', 'e', 'n', '\n',
        'h', 'e', 'a', 'r', 't', 'e', 'n', 'e', 'd', '\n',
        'h', 'e', 'a', 'r', 't', 'e', 'n', 'i', 'n', 'g', '\n',
        'h', 'e', 'a', 'r', 't', 'f', 'e', 'l', 't', '\n',
        'h', 'e', 'a', 'r', 't', 'h', '\n',
        'h', 'e', 'a', 'r', 't', 'h', 'r', 'u', 'g', '\n',
        'h', 'e', 'a', 'r', 't', 'h', 's', '\n',
        'h', 'e', 'a', 'r', 't', 'i', 'e', 's', '\n',
        'h', 'e', 'a', 'r', 't', 'i', 'e', 's', 't', '\n',
        'h', 'e', 'a', 'r', 't', 'i', 'l', 'y', '\n',
        'h', 'e', 'a', 'r', 't', 'i', 'n', 'e', 's', 's', '\n',
        'h', 'e', 'a', 'r', 't', 'l', 'a', 'n', 'd', '\n',
        'h', 'e', 'a', 'r', 't', 'l', 'a', 'n', 'd', 's', '\n',
        'h', 'e', 'a', 'r', 't', 'l', 'e', 's', 's', '\n',
        'h', 'e', 'a', 'r', 't', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'h', 'e', 'a', 'r', 't', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'h', 'e', 'a', 'r', 't', 'r', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'h', 'e', 'a', 'r', 't', 's', '\n',
        'h', 'e', 'a', 'r', 't', 's', 'e', 'a', 'r', 'c', 'h', 'i', 'n', 'g', '\n',
        'h', 'e', 'a', 'r', 't', 's', 't', 'r', 'i', 'n', 'g', 's', '\n',
        'h', 'e', 'a', 'r', 't', 't', 'o', 'h', 'e', 'a', 'r', 't', '\n',
        'h', 'e', 'a', 'r', 't', 'w', 'a', 'r', 'm', 'i', 'n', 'g', '\n',
        'h', 'e', 'a', 'r', 't', 'w', 'o', 'o', 'd', '\n',
        'h', 'e', 'a', 'r', 't', 'y', '\n',
        'h', 'e', 'a', 't', '\n',
        'h', 'e', 'a', 't', 'e', 'd', '\n',
        'h', 'e', 'a', 't', 'e', 'd', 'l', 'y', '\n',
        'h', 'e', 'a', 't', 'e', 'r', '\n',
        'h', 'e', 'a', 't', 'e', 'r', 's', '\n',
        'h', 'e', 'a', 't', 'h', '\n',
        'h', 'e', 'a', 't', 'h', 'e', 'n', '\n',
        'h', 'e', 'a', 't', 'h', 'e', 'n', 'i', 's', 'h', '\n',
        'h', 'e', 'a', 't', 'h', 'e', 'n', 'i', 's', 'm', '\n',
        'h', 'e', 'a', 't', 'h', 'e', 'n', 's', '\n',
        'h', 'e', 'a', 't', 'h', 'e', 'r', '\n',
        'h', 'e', 'a', 't', 'h', 'e', 'r', 's', '\n',
        'h', 'e', 'a', 't', 'h', 'e', 'r', 'y', '\n',
        'h', 'e', 'a', 't', 'h', 'l', 'a', 'n', 'd', '\n',
        'h', 'e', 'a', 't', 'h', 's', '\n',
        'h', 'e', 'a', 't', 'i', 'n', 'g', '\n',
        'h', 'e', 'a', 't', 'r', 'e', 's', 'i', 's', 't', 'a', 'n', 't', '\n',
        'h', 'e', 'a', 't', 's', '\n',
        'h', 'e', 'a', 't', 'w', 'a', 'v', 'e', '\n',
        'h', 'e', 'a', 'v', 'e', '\n',
        'h', 'e', 'a', 'v', 'e', 'd', '\n',
        'h', 'e', 'a', 'v', 'e', 'h', 'o', '\n',
        'h', 'e', 'a', 'v', 'e', 'n', '\n',
        'h', 'e', 'a', 'v', 'e', 'n', 'l', 'y', '\n',
        'h', 'e', 'a', 'v', 'e', 'n', 's', '\n',
        'h', 'e', 'a', 'v', 'e', 'n', 's', 'e', 'n', 't', '\n',
        'h', 'e', 'a', 'v', 'e', 'n', 'w', 'a', 'r', 'd', '\n',
        'h', 'e', 'a', 'v', 'e', 'n', 'w', 'a', 'r', 'd', 's', '\n',
        'h', 'e', 'a', 'v', 'e', 's', '\n',
        'h', 'e', 'a', 'v', 'i', 'e', 'r', '\n',
        'h', 'e', 'a', 'v', 'i', 'e', 's', '\n',
        'h', 'e', 'a', 'v', 'i', 'e', 's', 't', '\n',
        'h', 'e', 'a', 'v', 'i', 'l', 'y', '\n',
        'h', 'e', 'a', 'v', 'i', 'n', 'e', 's', 's', '\n',
        'h', 'e', 'a', 'v', 'i', 'n', 'g', '\n',
        'h', 'e', 'a', 'v', 'i', 'n', 'g', 's', '\n',
        'h', 'e', 'a', 'v', 'y', '\n',
        'h', 'e', 'a', 'v', 'y', 'd', 'u', 't', 'y', '\n',
        'h', 'e', 'a', 'v', 'y', 'w', 'e', 'i', 'g', 'h', 't', '\n',
        'h', 'e', 'a', 'v', 'y', 'w', 'e', 'i', 'g', 'h', 't', 's', '\n',
        'h', 'e', 'b', 'r', 'e', 'w', '\n',
        'h', 'e', 'b', 'r', 'e', 'w', 's', '\n',
        'h', 'e', 'c', 'k', '\n',
        'h', 'e', 'c', 'k', 'l', 'e', '\n',
        'h', 'e', 'c', 'k', 'l', 'e', 'd', '\n',
        'h', 'e', 'c', 'k', 'l', 'e', 'r', '\n',
        'h', 'e', 'c', 'k', 'l', 'e', 'r', 's', '\n',
        'h', 'e', 'c', 'k', 'l', 'e', 's', '\n',
        'h', 'e', 'c', 'k', 'l', 'i', 'n', 'g', '\n',
        'h', 'e', 'c', 't', 'a', 'r', 'e', '\n',
        'h', 'e', 'c', 't', 'a', 'r', 'e', 's', '\n',
        'h', 'e', 'c', 't', 'i', 'c', '\n',
        'h', 'e', 'c', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'h', 'e', 'c', 't', 'o', 'l', 'i', 't', 'r', 'e', 's', '\n',
        'h', 'e', 'c', 't', 'o', 'r', '\n',
        'h', 'e', 'c', 't', 'o', 'r', 'i', 'n', 'g', '\n',
        'h', 'e', 'd', 'g', 'e', '\n',
        'h', 'e', 'd', 'g', 'e', 'd', '\n',
        'h', 'e', 'd', 'g', 'e', 'h', 'o', 'g', '\n',
        'h', 'e', 'd', 'g', 'e', 'h', 'o', 'g', 's', '\n',
        'h', 'e', 'd', 'g', 'e', 'r', 'o', 'w', '\n',
        'h', 'e', 'd', 'g', 'e', 'r', 'o', 'w', 's', '\n',
        'h', 'e', 'd', 'g', 'e', 's', '\n',
        'h', 'e', 'd', 'g', 'i', 'n', 'g', '\n',
        'h', 'e', 'd', 'o', 'n', 'i', 's', 'm', '\n',
        'h', 'e', 'd', 'o', 'n', 'i', 's', 't', '\n',
        'h', 'e', 'd', 'o', 'n', 'i', 's', 't', 'i', 'c', '\n',
        'h', 'e', 'd', 'o', 'n', 'i', 's', 't', 's', '\n',
        'h', 'e', 'e', 'd', '\n',
        'h', 'e', 'e', 'd', 'e', 'd', '\n',
        'h', 'e', 'e', 'd', 'f', 'u', 'l', '\n',
        'h', 'e', 'e', 'd', 'i', 'n', 'g', '\n',
        'h', 'e', 'e', 'd', 'l', 'e', 's', 's', '\n',
        'h', 'e', 'e', 'd', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'h', 'e', 'e', 'd', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'h', 'e', 'e', 'd', 's', '\n',
        'h', 'e', 'e', 'l', '\n',
        'h', 'e', 'e', 'l', 'e', 'd', '\n',
        'h', 'e', 'e', 'l', 's', '\n',
        'h', 'e', 'f', 't', '\n',
        'h', 'e', 'f', 't', 'e', 'd', '\n',
        'h', 'e', 'f', 't', 'i', 'e', 'r', '\n',
        'h', 'e', 'f', 't', 'i', 'n', 'g', '\n',
        'h', 'e', 'f', 't', 'y', '\n',
        'h', 'e', 'g', 'e', 'm', 'o', 'n', 'i', 'c', '\n',
        'h', 'e', 'g', 'e', 'm', 'o', 'n', 'y', '\n',
        'h', 'e', 'i', 'f', 'e', 'r', '\n',
        'h', 'e', 'i', 'f', 'e', 'r', 's', '\n',
        'h', 'e', 'i', 'g', 'h', 't', '\n',
        'h', 'e', 'i', 'g', 'h', 't', 'e', 'n', '\n',
        'h', 'e', 'i', 'g', 'h', 't', 'e', 'n', 'e', 'd', '\n',
        'h', 'e', 'i', 'g', 'h', 't', 'e', 'n', 'i', 'n', 'g', '\n',
        'h', 'e', 'i', 'g', 'h', 't', 'e', 'n', 's', '\n',
        'h', 'e', 'i', 'g', 'h', 't', 's', '\n',
        'h', 'e', 'i', 'n', 'o', 'u', 's', '\n',
        'h', 'e', 'i', 'r', '\n',
        'h', 'e', 'i', 'r', 'e', 's', 's', '\n',
        'h', 'e', 'i', 'r', 'e', 's', 's', 'e', 's', '\n',
        'h', 'e', 'i', 'r', 'l', 'o', 'o', 'm', '\n',
        'h', 'e', 'i', 'r', 'l', 'o', 'o', 'm', 's', '\n',
        'h', 'e', 'i', 'r', 's', '\n',
        'h', 'e', 'i', 's', 't', '\n',
        'h', 'e', 'i', 's', 't', 's', '\n',
        'h', 'e', 'l', 'd', '\n',
        'h', 'e', 'l', 'e', 'n', '\n',
        'h', 'e', 'l', 'i', 'c', 'a', 'l', '\n',
        'h', 'e', 'l', 'i', 'c', 'e', 's', '\n',
        'h', 'e', 'l', 'i', 'c', 'o', 'p', 't', 'e', 'r', '\n',
        'h', 'e', 'l', 'i', 'c', 'o', 'p', 't', 'e', 'r', 's', '\n',
        'h', 'e', 'l', 'i', 'o', 'c', 'e', 'n', 't', 'r', 'i', 'c', '\n',
        'h', 'e', 'l', 'i', 'o', 'g', 'r', 'a', 'p', 'h', 'y', '\n',
        'h', 'e', 'l', 'i', 'o', 's', 'p', 'h', 'e', 'r', 'e', '\n',
        'h', 'e', 'l', 'i', 'o', 't', 'r', 'o', 'p', 'e', '\n',
        'h', 'e', 'l', 'i', 'p', 'a', 'd', '\n',
        'h', 'e', 'l', 'i', 'u', 'm', '\n',
        'h', 'e', 'l', 'i', 'x', '\n',
        'h', 'e', 'l', 'i', 'x', 'e', 's', '\n',
        'h', 'e', 'l', 'l', '\n',
        'h', 'e', 'l', 'l', 'e', 'n', 'i', 'c', '\n',
        'h', 'e', 'l', 'l', 'f', 'i', 'r', 'e', '\n',
        'h', 'e', 'l', 'l', 'i', 's', 'h', '\n',
        'h', 'e', 'l', 'l', 'i', 's', 'h', 'l', 'y', '\n',
        'h', 'e', 'l', 'l', 'o', '\n',
        'h', 'e', 'l', 'l', 'r', 'a', 'i', 's', 'e', 'r', '\n',
        'h', 'e', 'l', 'l', 's', '\n',
        'h', 'e', 'l', 'm', '\n',
        'h', 'e', 'l', 'm', 'e', 't', '\n',
        'h', 'e', 'l', 'm', 'e', 't', 'e', 'd', '\n',
        'h', 'e', 'l', 'm', 'e', 't', 's', '\n',
        'h', 'e', 'l', 'm', 's', '\n',
        'h', 'e', 'l', 'm', 's', 'm', 'a', 'n', '\n',
        'h', 'e', 'l', 'o', 't', 's', '\n',
        'h', 'e', 'l', 'p', '\n',
        'h', 'e', 'l', 'p', 'e', 'd', '\n',
        'h', 'e', 'l', 'p', 'e', 'r', '\n',
        'h', 'e', 'l', 'p', 'e', 'r', 's', '\n',
        'h', 'e', 'l', 'p', 'f', 'u', 'l', '\n',
        'h', 'e', 'l', 'p', 'f', 'u', 'l', 'l', 'y', '\n',
        'h', 'e', 'l', 'p', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'h', 'e', 'l', 'p', 'i', 'n', 'g', '\n',
        'h', 'e', 'l', 'p', 'i', 'n', 'g', 's', '\n',
        'h', 'e', 'l', 'p', 'l', 'e', 's', 's', '\n',
        'h', 'e', 'l', 'p', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'h', 'e', 'l', 'p', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'h', 'e', 'l', 'p', 'l', 'i', 'n', 'e', '\n',
        'h', 'e', 'l', 'p', 'l', 'i', 'n', 'e', 's', '\n',
        'h', 'e', 'l', 'p', 'm', 'a', 't', 'e', '\n',
        'h', 'e', 'l', 'p', 'm', 'a', 't', 'e', 's', '\n',
        'h', 'e', 'l', 'p', 's', '\n',
        'h', 'e', 'l', 's', 'i', 'n', 'k', 'i', '\n',
        'h', 'e', 'l', 't', 'e', 'r', 's', 'k', 'e', 'l', 't', 'e', 'r', '\n',
        'h', 'e', 'm', '\n',
        'h', 'e', 'm', 'a', 'n', '\n',
        'h', 'e', 'm', 'e', 'n', '\n',
        'h', 'e', 'm', 'i', 's', 'p', 'h', 'e', 'r', 'e', '\n',
        'h', 'e', 'm', 'i', 's', 'p', 'h', 'e', 'r', 'e', 's', '\n',
        'h', 'e', 'm', 'i', 's', 'p', 'h', 'e', 'r', 'i', 'c', '\n',
        'h', 'e', 'm', 'i', 's', 'p', 'h', 'e', 'r', 'i', 'c', 'a', 'l', '\n',
        'h', 'e', 'm', 'l', 'i', 'n', 'e', '\n',
        'h', 'e', 'm', 'l', 'i', 'n', 'e', 's', '\n',
        'h', 'e', 'm', 'l', 'o', 'c', 'k', '\n',
        'h', 'e', 'm', 'm', 'e', 'd', '\n',
        'h', 'e', 'm', 'm', 'i', 'n', 'g', '\n',
        'h', 'e', 'm', 'p', '\n',
        'h', 'e', 'm', 's', '\n',
        'h', 'e', 'n', '\n',
        'h', 'e', 'n', 'c', 'e', '\n',
        'h', 'e', 'n', 'c', 'e', 'f', 'o', 'r', 't', 'h', '\n',
        'h', 'e', 'n', 'c', 'e', 'f', 'o', 'r', 'w', 'a', 'r', 'd', '\n',
        'h', 'e', 'n', 'c', 'h', 'm', 'a', 'n', '\n',
        'h', 'e', 'n', 'c', 'h', 'm', 'e', 'n', '\n',
        'h', 'e', 'n', 'g', 'e', '\n',
        'h', 'e', 'n', 'n', 'a', '\n',
        'h', 'e', 'n', 'p', 'e', 'c', 'k', '\n',
        'h', 'e', 'n', 'r', 'y', '\n',
        'h', 'e', 'n', 's', '\n',
        'h', 'e', 'p', 'a', 't', 'i', 'c', '\n',
        'h', 'e', 'p', 'a', 't', 'i', 't', 'i', 's', '\n',
        'h', 'e', 'p', 't', 'a', 'g', 'o', 'n', '\n',
        'h', 'e', 'p', 't', 'a', 'g', 'o', 'n', 'a', 'l', '\n',
        'h', 'e', 'p', 't', 'a', 'g', 'o', 'n', 's', '\n',
        'h', 'e', 'p', 't', 'a', 'n', 'e', '\n',
        'h', 'e', 'r', '\n',
        'h', 'e', 'r', 'a', 'l', 'd', '\n',
        'h', 'e', 'r', 'a', 'l', 'd', 'e', 'd', '\n',
        'h', 'e', 'r', 'a', 'l', 'd', 'i', 'c', '\n',
        'h', 'e', 'r', 'a', 'l', 'd', 'i', 'n', 'g', '\n',
        'h', 'e', 'r', 'a', 'l', 'd', 'r', 'y', '\n',
        'h', 'e', 'r', 'a', 'l', 'd', 's', '\n',
        'h', 'e', 'r', 'b', '\n',
        'h', 'e', 'r', 'b', 'a', 'c', 'e', 'o', 'u', 's', '\n',
        'h', 'e', 'r', 'b', 'a', 'g', 'e', '\n',
        'h', 'e', 'r', 'b', 'a', 'l', '\n',
        'h', 'e', 'r', 'b', 'a', 'l', 'i', 's', 'm', '\n',
        'h', 'e', 'r', 'b', 'a', 'l', 'i', 's', 't', '\n',
        'h', 'e', 'r', 'b', 'a', 'l', 'i', 's', 't', 's', '\n',
        'h', 'e', 'r', 'b', 'i', 'c', 'i', 'd', 'e', '\n',
        'h', 'e', 'r', 'b', 'i', 'c', 'i', 'd', 'e', 's', '\n',
        'h', 'e', 'r', 'b', 'i', 'v', 'o', 'r', 'e', '\n',
        'h', 'e', 'r', 'b', 'i', 'v', 'o', 'r', 'e', 's', '\n',
        'h', 'e', 'r', 'b', 'i', 'v', 'o', 'r', 'o', 'u', 's', '\n',
        'h', 'e', 'r', 'b', 's', '\n',
        'h', 'e', 'r', 'd', '\n',
        'h', 'e', 'r', 'd', 'e', 'd', '\n',
        'h', 'e', 'r', 'd', 'i', 'n', 'g', '\n',
        'h', 'e', 'r', 'd', 's', '\n',
        'h', 'e', 'r', 'd', 's', 'm', 'a', 'n', '\n',
        'h', 'e', 'r', 'd', 's', 'm', 'e', 'n', '\n',
        'h', 'e', 'r', 'e', '\n',
        'h', 'e', 'r', 'e', 'a', 'b', 'o', 'u', 't', 's', '\n',
        'h', 'e', 'r', 'e', 'a', 'f', 't', 'e', 'r', '\n',
        'h', 'e', 'r', 'e', 'b', 'y', '\n',
        'h', 'e', 'r', 'e', 'd', 'i', 't', 'a', 'r', 'y', '\n',
        'h', 'e', 'r', 'e', 'd', 'i', 't', 'y', '\n',
        'h', 'e', 'r', 'e', 'i', 'n', '\n',
        'h', 'e', 'r', 'e', 'i', 'n', 'a', 'f', 't', 'e', 'r', '\n',
        'h', 'e', 'r', 'e', 'o', 'f', '\n',
        'h', 'e', 'r', 'e', 's', 'i', 'e', 's', '\n',
        'h', 'e', 'r', 'e', 's', 'y', '\n',
        'h', 'e', 'r', 'e', 't', 'i', 'c', '\n',
        'h', 'e', 'r', 'e', 't', 'i', 'c', 'a', 'l', '\n',
        'h', 'e', 'r', 'e', 't', 'i', 'c', 's', '\n',
        'h', 'e', 'r', 'e', 't', 'o', '\n',
        'h', 'e', 'r', 'e', 't', 'o', 'f', 'o', 'r', 'e', '\n',
        'h', 'e', 'r', 'e', 'u', 'n', 'd', 'e', 'r', '\n',
        'h', 'e', 'r', 'e', 'u', 'p', 'o', 'n', '\n',
        'h', 'e', 'r', 'e', 'w', 'i', 't', 'h', '\n',
        'h', 'e', 'r', 'i', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'h', 'e', 'r', 'i', 't', 'a', 'b', 'l', 'e', '\n',
        'h', 'e', 'r', 'i', 't', 'a', 'g', 'e', '\n',
        'h', 'e', 'r', 'i', 't', 'o', 'r', 's', '\n',
        'h', 'e', 'r', 'm', '\n',
        'h', 'e', 'r', 'm', 'a', 'p', 'h', 'r', 'o', 'd', 'i', 't', 'e', '\n',
        'h', 'e', 'r', 'm', 'a', 'p', 'h', 'r', 'o', 'd', 'i', 't', 'e', 's', '\n',
        'h', 'e', 'r', 'm', 'a', 'p', 'h', 'r', 'o', 'd', 'i', 't', 'i', 'c', '\n',
        'h', 'e', 'r', 'm', 'e', 'n', 'e', 'u', 't', 'i', 'c', '\n',
        'h', 'e', 'r', 'm', 'e', 'n', 'e', 'u', 't', 'i', 'c', 's', '\n',
        'h', 'e', 'r', 'm', 'e', 't', 'i', 'c', '\n',
        'h', 'e', 'r', 'm', 'e', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'h', 'e', 'r', 'm', 'i', 't', '\n',
        'h', 'e', 'r', 'm', 'i', 't', 'a', 'g', 'e', '\n',
        'h', 'e', 'r', 'm', 'i', 't', 's', '\n',
        'h', 'e', 'r', 'n', 'i', 'a', '\n',
        'h', 'e', 'r', 'n', 'i', 'a', 's', '\n',
        'h', 'e', 'r', 'o', '\n',
        'h', 'e', 'r', 'o', 'd', '\n',
        'h', 'e', 'r', 'o', 'i', 'c', '\n',
        'h', 'e', 'r', 'o', 'i', 'c', 'a', 'l', '\n',
        'h', 'e', 'r', 'o', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'h', 'e', 'r', 'o', 'i', 'c', 's', '\n',
        'h', 'e', 'r', 'o', 'i', 'n', '\n',
        'h', 'e', 'r', 'o', 'i', 'n', 'e', '\n',
        'h', 'e', 'r', 'o', 'i', 'n', 'e', 's', '\n',
        'h', 'e', 'r', 'o', 'i', 's', 'm', '\n',
        'h', 'e', 'r', 'o', 'n', '\n',
        'h', 'e', 'r', 'o', 'n', 'r', 'y', '\n',
        'h', 'e', 'r', 'o', 'n', 's', '\n',
        'h', 'e', 'r', 'p', 'e', 's', '\n',
        'h', 'e', 'r', 'r', 'i', 'n', 'g', '\n',
        'h', 'e', 'r', 'r', 'i', 'n', 'g', 'b', 'o', 'n', 'e', '\n',
        'h', 'e', 'r', 'r', 'i', 'n', 'g', 's', '\n',
        'h', 'e', 'r', 's', '\n',
        'h', 'e', 'r', 's', 'e', 'l', 'f', '\n',
        'h', 'e', 'r', 't', 'z', '\n',
        'h', 'e', 's', 'i', 't', 'a', 'n', 'c', 'y', '\n',
        'h', 'e', 's', 'i', 't', 'a', 'n', 't', '\n',
        'h', 'e', 's', 'i', 't', 'a', 'n', 't', 'l', 'y', '\n',
        'h', 'e', 's', 'i', 't', 'a', 't', 'e', '\n',
        'h', 'e', 's', 'i', 't', 'a', 't', 'e', 'd', '\n',
        'h', 'e', 's', 'i', 't', 'a', 't', 'e', 's', '\n',
        'h', 'e', 's', 'i', 't', 'a', 't', 'i', 'n', 'g', '\n',
        'h', 'e', 's', 'i', 't', 'a', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'h', 'e', 's', 'i', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'h', 'e', 's', 'i', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'h', 'e', 't', 'e', 'r', 'o', 'd', 'o', 'x', '\n',
        'h', 'e', 't', 'e', 'r', 'o', 'd', 'o', 'x', 'y', '\n',
        'h', 'e', 't', 'e', 'r', 'o', 'g', 'e', 'n', 'e', 'i', 't', 'y', '\n',
        'h', 'e', 't', 'e', 'r', 'o', 'g', 'e', 'n', 'e', 'o', 'u', 's', '\n',
        'h', 'e', 't', 'e', 'r', 'o', 'l', 'o', 'g', 'o', 'u', 's', '\n',
        'h', 'e', 't', 'e', 'r', 'o', 's', 'e', 'x', 'i', 's', 't', '\n',
        'h', 'e', 't', 'e', 'r', 'o', 's', 'e', 'x', 'u', 'a', 'l', '\n',
        'h', 'e', 't', 'e', 'r', 'o', 's', 'e', 'x', 'u', 'a', 'l', 'i', 't', 'y', '\n',
        'h', 'e', 't', 'e', 'r', 'o', 's', 'e', 'x', 'u', 'a', 'l', 'l', 'y', '\n',
        'h', 'e', 't', 'e', 'r', 'o', 's', 'e', 'x', 'u', 'a', 'l', 's', '\n',
        'h', 'e', 't', 'e', 'r', 'o', 'z', 'y', 'g', 'o', 'u', 's', '\n',
        'h', 'e', 'u', 'r', 'i', 's', 't', 'i', 'c', '\n',
        'h', 'e', 'u', 'r', 'i', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'h', 'e', 'u', 'r', 'i', 's', 't', 'i', 'c', 's', '\n',
        'h', 'e', 'w', '\n',
        'h', 'e', 'w', 'e', 'd', '\n',
        'h', 'e', 'w', 'e', 'r', '\n',
        'h', 'e', 'w', 'i', 'n', 'g', '\n',
        'h', 'e', 'w', 'n', '\n',
        'h', 'e', 'x', '\n',
        'h', 'e', 'x', 'a', 'd', 'e', 'c', 'i', 'm', 'a', 'l', '\n',
        'h', 'e', 'x', 'a', 'g', 'o', 'n', '\n',
        'h', 'e', 'x', 'a', 'g', 'o', 'n', 'a', 'l', '\n',
        'h', 'e', 'x', 'a', 'g', 'o', 'n', 's', '\n',
        'h', 'e', 'x', 'a', 'g', 'r', 'a', 'm', '\n',
        'h', 'e', 'x', 'a', 'g', 'r', 'a', 'm', 's', '\n',
        'h', 'e', 'x', 'a', 'm', 'e', 't', 'e', 'r', '\n',
        'h', 'e', 'x', 'a', 'n', 'e', '\n',
        'h', 'e', 'x', 'e', 'd', '\n',
        'h', 'e', 'y', '\n',
        'h', 'e', 'y', 'd', 'a', 'y', '\n',
        'h', 'e', 'y', 'd', 'a', 'y', 's', '\n',
        'h', 'i', '\n',
        'h', 'i', 'a', 't', 'u', 's', '\n',
        'h', 'i', 'a', 't', 'u', 's', 'e', 's', '\n',
        'h', 'i', 'b', 'e', 'r', 'n', 'a', 'l', '\n',
        'h', 'i', 'b', 'e', 'r', 'n', 'a', 't', 'e', '\n',
        'h', 'i', 'b', 'e', 'r', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'h', 'i', 'b', 'e', 'r', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'h', 'i', 'b', 'i', 's', 'c', 'u', 's', '\n',
        'h', 'i', 'c', '\n',
        'h', 'i', 'c', 'c', 'o', 'u', 'g', 'h', '\n',
        'h', 'i', 'c', 'c', 'u', 'p', '\n',
        'h', 'i', 'c', 'c', 'u', 'p', 's', '\n',
        'h', 'i', 'c', 'k', 'o', 'r', 'y', '\n',
        'h', 'i', 'd', '\n',
        'h', 'i', 'd', 'd', 'e', 'n', '\n',
        'h', 'i', 'd', 'e', '\n',
        'h', 'i', 'd', 'e', 'a', 'n', 'd', 's', 'e', 'e', 'k', '\n',
        'h', 'i', 'd', 'e', 'a', 'w', 'a', 'y', '\n',
        'h', 'i', 'd', 'e', 'a', 'w', 'a', 'y', 's', '\n',
        'h', 'i', 'd', 'e', 'b', 'o', 'u', 'n', 'd', '\n',
        'h', 'i', 'd', 'e', 'o', 'u', 's', '\n',
        'h', 'i', 'd', 'e', 'o', 'u', 's', 'l', 'y', '\n',
        'h', 'i', 'd', 'e', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'h', 'i', 'd', 'e', 'o', 'u', 't', '\n',
        'h', 'i', 'd', 'e', 'o', 'u', 't', 's', '\n',
        'h', 'i', 'd', 'e', 'r', '\n',
        'h', 'i', 'd', 'e', 's', '\n',
        'h', 'i', 'd', 'i', 'n', 'g', '\n',
        'h', 'i', 'd', 'i', 'n', 'g', 's', '\n',
        'h', 'i', 'e', 'r', 'a', 'r', 'c', 'h', '\n',
        'h', 'i', 'e', 'r', 'a', 'r', 'c', 'h', 'i', 'c', '\n',
        'h', 'i', 'e', 'r', 'a', 'r', 'c', 'h', 'i', 'c', 'a', 'l', '\n',
        'h', 'i', 'e', 'r', 'a', 'r', 'c', 'h', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'h', 'i', 'e', 'r', 'a', 'r', 'c', 'h', 'i', 'e', 's', '\n',
        'h', 'i', 'e', 'r', 'a', 'r', 'c', 'h', 'y', '\n',
        'h', 'i', 'e', 'r', 'a', 't', 'i', 'c', '\n',
        'h', 'i', 'e', 'r', 'o', 'g', 'l', 'y', 'p', 'h', '\n',
        'h', 'i', 'e', 'r', 'o', 'g', 'l', 'y', 'p', 'h', 'i', 'c', '\n',
        'h', 'i', 'e', 'r', 'o', 'g', 'l', 'y', 'p', 'h', 'i', 'c', 's', '\n',
        'h', 'i', 'e', 'r', 'o', 'g', 'l', 'y', 'p', 'h', 's', '\n',
        'h', 'i', 'g', 'g', 'l', 'e', 'd', 'y', 'p', 'i', 'g', 'g', 'l', 'e', 'd', 'y', '\n',
        'h', 'i', 'g', 'h', '\n',
        'h', 'i', 'g', 'h', 'b', 'r', 'o', 'w', '\n',
        'h', 'i', 'g', 'h', 'e', 'r', '\n',
        'h', 'i', 'g', 'h', 'e', 's', 't', '\n',
        'h', 'i', 'g', 'h', 'h', 'a', 'n', 'd', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'h', 'i', 'g', 'h', 'h', 'e', 'e', 'l', 'e', 'd', '\n',
        'h', 'i', 'g', 'h', 'i', 's', 'h', '\n',
        'h', 'i', 'g', 'h', 'j', 'a', 'c', 'k', '\n',
        'h', 'i', 'g', 'h', 'l', 'a', 'n', 'd', '\n',
        'h', 'i', 'g', 'h', 'l', 'a', 'n', 'd', 'e', 'r', '\n',
        'h', 'i', 'g', 'h', 'l', 'a', 'n', 'd', 'e', 'r', 's', '\n',
        'h', 'i', 'g', 'h', 'l', 'a', 'n', 'd', 's', '\n',
        'h', 'i', 'g', 'h', 'l', 'i', 'g', 'h', 't', '\n',
        'h', 'i', 'g', 'h', 'l', 'i', 'g', 'h', 't', 'e', 'd', '\n',
        'h', 'i', 'g', 'h', 'l', 'i', 'g', 'h', 't', 'e', 'r', '\n',
        'h', 'i', 'g', 'h', 'l', 'i', 'g', 'h', 't', 'i', 'n', 'g', '\n',
        'h', 'i', 'g', 'h', 'l', 'i', 'g', 'h', 't', 's', '\n',
        'h', 'i', 'g', 'h', 'l', 'y', '\n',
        'h', 'i', 'g', 'h', 'n', 'e', 's', 's', '\n',
        'h', 'i', 'g', 'h', 'p', 'i', 't', 'c', 'h', 'e', 'd', '\n',
        'h', 'i', 'g', 'h', 'p', 'o', 'i', 'n', 't', '\n',
        'h', 'i', 'g', 'h', 'r', 'a', 'n', 'k', 'i', 'n', 'g', '\n',
        'h', 'i', 'g', 'h', 's', '\n',
        'h', 'i', 'g', 'h', 's', 'p', 'i', 'r', 'i', 't', 'e', 'd', '\n',
        'h', 'i', 'g', 'h', 't', '\n',
        'h', 'i', 'g', 'h', 'w', 'a', 'y', '\n',
        'h', 'i', 'g', 'h', 'w', 'a', 'y', 'm', 'a', 'n', '\n',
        'h', 'i', 'g', 'h', 'w', 'a', 'y', 'm', 'e', 'n', '\n',
        'h', 'i', 'g', 'h', 'w', 'a', 'y', 's', '\n',
        'h', 'i', 'j', 'a', 'c', 'k', '\n',
        'h', 'i', 'j', 'a', 'c', 'k', 'e', 'd', '\n',
        'h', 'i', 'j', 'a', 'c', 'k', 'e', 'r', '\n',
        'h', 'i', 'j', 'a', 'c', 'k', 'e', 'r', 's', '\n',
        'h', 'i', 'j', 'a', 'c', 'k', 'i', 'n', 'g', '\n',
        'h', 'i', 'j', 'a', 'c', 'k', 'i', 'n', 'g', 's', '\n',
        'h', 'i', 'j', 'a', 'c', 'k', 's', '\n',
        'h', 'i', 'k', 'e', '\n',
        'h', 'i', 'k', 'e', 'd', '\n',
        'h', 'i', 'k', 'e', 'r', '\n',
        'h', 'i', 'k', 'e', 'r', 's', '\n',
        'h', 'i', 'k', 'e', 's', '\n',
        'h', 'i', 'k', 'i', 'n', 'g', '\n',
        'h', 'i', 'l', 'a', 'r', 'i', 'o', 'u', 's', '\n',
        'h', 'i', 'l', 'a', 'r', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'h', 'i', 'l', 'a', 'r', 'i', 't', 'y', '\n',
        'h', 'i', 'l', 'l', '\n',
        'h', 'i', 'l', 'l', 'e', 'd', '\n',
        'h', 'i', 'l', 'l', 'i', 'e', 'r', '\n',
        'h', 'i', 'l', 'l', 'i', 'e', 's', 't', '\n',
        'h', 'i', 'l', 'l', 'm', 'a', 'n', '\n',
        'h', 'i', 'l', 'l', 'o', 'c', 'k', '\n',
        'h', 'i', 'l', 'l', 'o', 'c', 'k', 's', '\n',
        'h', 'i', 'l', 'l', 'o', 'c', 'k', 'y', '\n',
        'h', 'i', 'l', 'l', 's', '\n',
        'h', 'i', 'l', 'l', 's', 'i', 'd', 'e', '\n',
        'h', 'i', 'l', 'l', 's', 'i', 'd', 'e', 's', '\n',
        'h', 'i', 'l', 'l', 't', 'o', 'p', '\n',
        'h', 'i', 'l', 'l', 't', 'o', 'p', 's', '\n',
        'h', 'i', 'l', 'l', 'w', 'a', 'l', 'k', 'i', 'n', 'g', '\n',
        'h', 'i', 'l', 'l', 'y', '\n',
        'h', 'i', 'l', 't', '\n',
        'h', 'i', 'l', 't', 's', '\n',
        'h', 'i', 'm', '\n',
        'h', 'i', 'm', 's', 'e', 'l', 'f', '\n',
        'h', 'i', 'n', 'd', '\n',
        'h', 'i', 'n', 'd', 'b', 'r', 'a', 'i', 'n', '\n',
        'h', 'i', 'n', 'd', 'e', 'r', '\n',
        'h', 'i', 'n', 'd', 'e', 'r', 'e', 'd', '\n',
        'h', 'i', 'n', 'd', 'e', 'r', 'e', 'r', '\n',
        'h', 'i', 'n', 'd', 'e', 'r', 'i', 'n', 'g', '\n',
        'h', 'i', 'n', 'd', 'e', 'r', 's', '\n',
        'h', 'i', 'n', 'd', 'm', 'o', 's', 't', '\n',
        'h', 'i', 'n', 'd', 'q', 'u', 'a', 'r', 't', 'e', 'r', 's', '\n',
        'h', 'i', 'n', 'd', 'r', 'a', 'n', 'c', 'e', '\n',
        'h', 'i', 'n', 'd', 'r', 'a', 'n', 'c', 'e', 's', '\n',
        'h', 'i', 'n', 'd', 's', 'i', 'g', 'h', 't', '\n',
        'h', 'i', 'n', 'd', 'u', '\n',
        'h', 'i', 'n', 'd', 'u', 'i', 's', 'm', '\n',
        'h', 'i', 'n', 'g', 'e', '\n',
        'h', 'i', 'n', 'g', 'e', 'd', '\n',
        'h', 'i', 'n', 'g', 'e', 's', '\n',
        'h', 'i', 'n', 'n', 'i', 'e', 's', '\n',
        'h', 'i', 'n', 'n', 'y', '\n',
        'h', 'i', 'n', 't', '\n',
        'h', 'i', 'n', 't', 'e', 'd', '\n',
        'h', 'i', 'n', 't', 'e', 'r', 'l', 'a', 'n', 'd', '\n',
        'h', 'i', 'n', 't', 'e', 'r', 'l', 'a', 'n', 'd', 's', '\n',
        'h', 'i', 'n', 't', 'i', 'n', 'g', '\n',
        'h', 'i', 'n', 't', 's', '\n',
        'h', 'i', 'p', '\n',
        'h', 'i', 'p', 'b', 'o', 'n', 'e', '\n',
        'h', 'i', 'p', 'p', 'i', 'e', '\n',
        'h', 'i', 'p', 'p', 'i', 'e', 's', '\n',
        'h', 'i', 'p', 'p', 'o', '\n',
        'h', 'i', 'p', 'p', 'o', 'c', 'a', 'm', 'p', 'u', 's', '\n',
        'h', 'i', 'p', 'p', 'o', 'd', 'r', 'o', 'm', 'e', '\n',
        'h', 'i', 'p', 'p', 'o', 'p', 'o', 't', 'a', 'm', 'u', 's', '\n',
        'h', 'i', 'p', 'p', 'y', '\n',
        'h', 'i', 'p', 's', '\n',
        'h', 'i', 'p', 's', 't', 'e', 'r', '\n',
        'h', 'i', 'p', 's', 't', 'e', 'r', 's', '\n',
        'h', 'i', 'r', 'e', '\n',
        'h', 'i', 'r', 'e', 'd', '\n',
        'h', 'i', 'r', 'e', 'l', 'i', 'n', 'g', '\n',
        'h', 'i', 'r', 'e', 'r', '\n',
        'h', 'i', 'r', 'e', 's', '\n',
        'h', 'i', 'r', 'i', 'n', 'g', '\n',
        'h', 'i', 'r', 'i', 'n', 'g', 's', '\n',
        'h', 'i', 'r', 's', 'u', 't', 'e', '\n',
        'h', 'i', 'r', 's', 'u', 't', 'e', 'n', 'e', 's', 's', '\n',
        'h', 'i', 's', '\n',
        'h', 'i', 's', 'p', 'a', 'n', 'i', 'c', '\n',
        'h', 'i', 's', 's', '\n',
        'h', 'i', 's', 's', 'e', 'd', '\n',
        'h', 'i', 's', 's', 'e', 's', '\n',
        'h', 'i', 's', 's', 'i', 'n', 'g', '\n',
        'h', 'i', 's', 's', 'i', 'n', 'g', 's', '\n',
        'h', 'i', 's', 't', 'a', 'm', 'i', 'n', 'e', '\n',
        'h', 'i', 's', 't', 'o', 'g', 'r', 'a', 'm', '\n',
        'h', 'i', 's', 't', 'o', 'g', 'r', 'a', 'm', 's', '\n',
        'h', 'i', 's', 't', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'h', 'i', 's', 't', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'h', 'i', 's', 't', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'h', 'i', 's', 't', 'o', 'l', 'o', 'g', 'y', '\n',
        'h', 'i', 's', 't', 'o', 'r', 'i', 'a', 'n', '\n',
        'h', 'i', 's', 't', 'o', 'r', 'i', 'a', 'n', 's', '\n',
        'h', 'i', 's', 't', 'o', 'r', 'i', 'c', '\n',
        'h', 'i', 's', 't', 'o', 'r', 'i', 'c', 'a', 'l', '\n',
        'h', 'i', 's', 't', 'o', 'r', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'h', 'i', 's', 't', 'o', 'r', 'i', 'c', 'i', 's', 't', '\n',
        'h', 'i', 's', 't', 'o', 'r', 'i', 'e', 's', '\n',
        'h', 'i', 's', 't', 'o', 'r', 'i', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', 'a', 'l', '\n',
        'h', 'i', 's', 't', 'o', 'r', 'i', 'o', 'g', 'r', 'a', 'p', 'h', 'y', '\n',
        'h', 'i', 's', 't', 'o', 'r', 'y', '\n',
        'h', 'i', 's', 't', 'r', 'i', 'o', 'n', 'i', 'c', '\n',
        'h', 'i', 's', 't', 'r', 'i', 'o', 'n', 'i', 'c', 's', '\n',
        'h', 'i', 't', '\n',
        'h', 'i', 't', 'a', 'n', 'd', 'r', 'u', 'n', '\n',
        'h', 'i', 't', 'c', 'h', '\n',
        'h', 'i', 't', 'c', 'h', 'e', 'd', '\n',
        'h', 'i', 't', 'c', 'h', 'e', 'r', '\n',
        'h', 'i', 't', 'c', 'h', 'e', 's', '\n',
        'h', 'i', 't', 'c', 'h', 'h', 'i', 'k', 'e', '\n',
        'h', 'i', 't', 'c', 'h', 'h', 'i', 'k', 'e', 'd', '\n',
        'h', 'i', 't', 'c', 'h', 'h', 'i', 'k', 'e', 'r', '\n',
        'h', 'i', 't', 'c', 'h', 'h', 'i', 'k', 'e', 'r', 's', '\n',
        'h', 'i', 't', 'c', 'h', 'h', 'i', 'k', 'i', 'n', 'g', '\n',
        'h', 'i', 't', 'c', 'h', 'i', 'n', 'g', '\n',
        'h', 'i', 't', 'h', 'e', 'r', '\n',
        'h', 'i', 't', 'h', 'e', 'r', 't', 'o', '\n',
        'h', 'i', 't', 'l', 'e', 'r', '\n',
        'h', 'i', 't', 's', '\n',
        'h', 'i', 't', 't', 'a', 'b', 'l', 'e', '\n',
        'h', 'i', 't', 't', 'e', 'r', 's', '\n',
        'h', 'i', 't', 't', 'i', 'n', 'g', '\n',
        'h', 'i', 'v', 'e', '\n',
        'h', 'i', 'v', 'e', 'd', '\n',
        'h', 'i', 'v', 'e', 's', '\n',
        'h', 'i', 'v', 'i', 'n', 'g', '\n',
        'h', 'm', 'm', '\n',
        'h', 'o', '\n',
        'h', 'o', 'a', 'r', '\n',
        'h', 'o', 'a', 'r', 'd', '\n',
        'h', 'o', 'a', 'r', 'd', 'e', 'd', '\n',
        'h', 'o', 'a', 'r', 'd', 'e', 'r', '\n',
        'h', 'o', 'a', 'r', 'd', 'e', 'r', 's', '\n',
        'h', 'o', 'a', 'r', 'd', 'i', 'n', 'g', '\n',
        'h', 'o', 'a', 'r', 'd', 'i', 'n', 'g', 's', '\n',
        'h', 'o', 'a', 'r', 'd', 's', '\n',
        'h', 'o', 'a', 'r', 'f', 'r', 'o', 's', 't', '\n',
        'h', 'o', 'a', 'r', 's', 'e', '\n',
        'h', 'o', 'a', 'r', 's', 'e', 'l', 'y', '\n',
        'h', 'o', 'a', 'r', 's', 'e', 'n', 'e', 's', 's', '\n',
        'h', 'o', 'a', 'r', 's', 'e', 'r', '\n',
        'h', 'o', 'a', 'r', 'y', '\n',
        'h', 'o', 'a', 'x', '\n',
        'h', 'o', 'a', 'x', 'e', 'd', '\n',
        'h', 'o', 'a', 'x', 'e', 'r', '\n',
        'h', 'o', 'a', 'x', 'e', 'r', 's', '\n',
        'h', 'o', 'a', 'x', 'e', 's', '\n',
        'h', 'o', 'a', 'x', 'i', 'n', 'g', '\n',
        'h', 'o', 'b', '\n',
        'h', 'o', 'b', 'b', 'i', 'e', 's', '\n',
        'h', 'o', 'b', 'b', 'i', 't', '\n',
        'h', 'o', 'b', 'b', 'l', 'e', '\n',
        'h', 'o', 'b', 'b', 'l', 'e', 'd', '\n',
        'h', 'o', 'b', 'b', 'l', 'e', 's', '\n',
        'h', 'o', 'b', 'b', 'l', 'i', 'n', 'g', '\n',
        'h', 'o', 'b', 'b', 'y', '\n',
        'h', 'o', 'b', 'b', 'y', 'i', 's', 't', '\n',
        'h', 'o', 'b', 'b', 'y', 'i', 's', 't', 's', '\n',
        'h', 'o', 'b', 'g', 'o', 'b', 'l', 'i', 'n', '\n',
        'h', 'o', 'b', 'g', 'o', 'b', 'l', 'i', 'n', 's', '\n',
        'h', 'o', 'b', 'n', 'a', 'i', 'l', 'e', 'd', '\n',
        'h', 'o', 'b', 'n', 'a', 'i', 'l', 's', '\n',
        'h', 'o', 'b', 'o', '\n',
        'h', 'o', 'b', 's', '\n',
        'h', 'o', 'c', 'k', '\n',
        'h', 'o', 'c', 'k', 'e', 'y', '\n',
        'h', 'o', 'c', 'k', 's', '\n',
        'h', 'o', 'c', 'u', 's', '\n',
        'h', 'o', 'c', 'u', 's', 'p', 'o', 'c', 'u', 's', '\n',
        'h', 'o', 'd', '\n',
        'h', 'o', 'e', '\n',
        'h', 'o', 'e', 'd', '\n',
        'h', 'o', 'e', 'i', 'n', 'g', '\n',
        'h', 'o', 'e', 's', '\n',
        'h', 'o', 'g', '\n',
        'h', 'o', 'g', 'g', '\n',
        'h', 'o', 'g', 'g', 'e', 'd', '\n',
        'h', 'o', 'g', 'g', 'e', 'r', '\n',
        'h', 'o', 'g', 'g', 'i', 'n', 'g', '\n',
        'h', 'o', 'g', 'g', 's', '\n',
        'h', 'o', 'g', 's', '\n',
        'h', 'o', 'g', 'w', 'a', 's', 'h', '\n',
        'h', 'o', 'i', 's', 't', '\n',
        'h', 'o', 'i', 's', 't', 'e', 'd', '\n',
        'h', 'o', 'i', 's', 't', 'i', 'n', 'g', '\n',
        'h', 'o', 'i', 's', 't', 's', '\n',
        'h', 'o', 'l', 'd', '\n',
        'h', 'o', 'l', 'd', 'a', 'b', 'l', 'e', '\n',
        'h', 'o', 'l', 'd', 'a', 'l', 'l', '\n',
        'h', 'o', 'l', 'd', 'a', 'l', 'l', 's', '\n',
        'h', 'o', 'l', 'd', 'e', 'r', '\n',
        'h', 'o', 'l', 'd', 'e', 'r', 's', '\n',
        'h', 'o', 'l', 'd', 'i', 'n', 'g', '\n',
        'h', 'o', 'l', 'd', 'i', 'n', 'g', 's', '\n',
        'h', 'o', 'l', 'd', 'o', 'u', 't', '\n',
        'h', 'o', 'l', 'd', 's', '\n',
        'h', 'o', 'l', 'd', 'u', 'p', '\n',
        'h', 'o', 'l', 'd', 'u', 'p', 's', '\n',
        'h', 'o', 'l', 'e', '\n',
        'h', 'o', 'l', 'e', 'd', '\n',
        'h', 'o', 'l', 'e', 'i', 'n', 'o', 'n', 'e', '\n',
        'h', 'o', 'l', 'e', 's', '\n',
        'h', 'o', 'l', 'i', 'd', 'a', 'y', '\n',
        'h', 'o', 'l', 'i', 'd', 'a', 'y', 'i', 'n', 'g', '\n',
        'h', 'o', 'l', 'i', 'd', 'a', 'y', 'm', 'a', 'k', 'e', 'r', '\n',
        'h', 'o', 'l', 'i', 'd', 'a', 'y', 'm', 'a', 'k', 'e', 'r', 's', '\n',
        'h', 'o', 'l', 'i', 'd', 'a', 'y', 's', '\n',
        'h', 'o', 'l', 'i', 'e', 'r', '\n',
        'h', 'o', 'l', 'i', 'e', 's', '\n',
        'h', 'o', 'l', 'i', 'e', 's', 't', '\n',
        'h', 'o', 'l', 'i', 'l', 'y', '\n',
        'h', 'o', 'l', 'i', 'n', 'e', 's', 's', '\n',
        'h', 'o', 'l', 'i', 'n', 'g', '\n',
        'h', 'o', 'l', 'i', 's', 'm', '\n',
        'h', 'o', 'l', 'i', 's', 't', 'i', 'c', '\n',
        'h', 'o', 'l', 'i', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'h', 'o', 'l', 'l', 'a', 'n', 'd', '\n',
        'h', 'o', 'l', 'l', 'e', 'r', '\n',
        'h', 'o', 'l', 'l', 'e', 'r', 'e', 'd', '\n',
        'h', 'o', 'l', 'l', 'i', 'e', 's', '\n',
        'h', 'o', 'l', 'l', 'o', 'w', '\n',
        'h', 'o', 'l', 'l', 'o', 'w', 'e', 'd', '\n',
        'h', 'o', 'l', 'l', 'o', 'w', 'l', 'y', '\n',
        'h', 'o', 'l', 'l', 'o', 'w', 'n', 'e', 's', 's', '\n',
        'h', 'o', 'l', 'l', 'o', 'w', 's', '\n',
        'h', 'o', 'l', 'l', 'y', '\n',
        'h', 'o', 'l', 'l', 'y', 'h', 'o', 'c', 'k', 's', '\n',
        'h', 'o', 'l', 'm', 'e', 's', '\n',
        'h', 'o', 'l', 'o', 'c', 'a', 'u', 's', 't', '\n',
        'h', 'o', 'l', 'o', 'c', 'a', 'u', 's', 't', 's', '\n',
        'h', 'o', 'l', 'o', 'g', 'r', 'a', 'm', '\n',
        'h', 'o', 'l', 'o', 'g', 'r', 'a', 'm', 's', '\n',
        'h', 'o', 'l', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', '\n',
        'h', 'o', 'l', 'o', 'g', 'r', 'a', 'p', 'h', 'y', '\n',
        'h', 'o', 'l', 's', 't', 'e', 'r', '\n',
        'h', 'o', 'l', 's', 't', 'e', 'r', 's', '\n',
        'h', 'o', 'l', 'y', '\n',
        'h', 'o', 'm', 'a', 'g', 'e', '\n',
        'h', 'o', 'm', 'a', 'g', 'e', 's', '\n',
        'h', 'o', 'm', 'b', 'r', 'e', '\n',
        'h', 'o', 'm', 'e', '\n',
        'h', 'o', 'm', 'e', 'c', 'o', 'm', 'i', 'n', 'g', '\n',
        'h', 'o', 'm', 'e', 'c', 'o', 'm', 'i', 'n', 'g', 's', '\n',
        'h', 'o', 'm', 'e', 'd', '\n',
        'h', 'o', 'm', 'e', 'l', 'a', 'n', 'd', '\n',
        'h', 'o', 'm', 'e', 'l', 'a', 'n', 'd', 's', '\n',
        'h', 'o', 'm', 'e', 'l', 'e', 's', 's', '\n',
        'h', 'o', 'm', 'e', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'h', 'o', 'm', 'e', 'l', 'i', 'e', 'r', '\n',
        'h', 'o', 'm', 'e', 'l', 'i', 'n', 'e', 's', 's', '\n',
        'h', 'o', 'm', 'e', 'l', 'y', '\n',
        'h', 'o', 'm', 'e', 'm', 'a', 'd', 'e', '\n',
        'h', 'o', 'm', 'e', 'o', 'w', 'n', 'e', 'r', '\n',
        'h', 'o', 'm', 'e', 'o', 'w', 'n', 'e', 'r', 's', '\n',
        'h', 'o', 'm', 'e', 's', '\n',
        'h', 'o', 'm', 'e', 's', 'i', 'c', 'k', '\n',
        'h', 'o', 'm', 'e', 's', 'i', 'c', 'k', 'n', 'e', 's', 's', '\n',
        'h', 'o', 'm', 'e', 's', 'p', 'u', 'n', '\n',
        'h', 'o', 'm', 'e', 's', 't', 'e', 'a', 'd', '\n',
        'h', 'o', 'm', 'e', 's', 't', 'e', 'a', 'd', 's', '\n',
        'h', 'o', 'm', 'e', 'w', 'a', 'r', 'd', '\n',
        'h', 'o', 'm', 'e', 'w', 'a', 'r', 'd', 'b', 'o', 'u', 'n', 'd', '\n',
        'h', 'o', 'm', 'e', 'w', 'a', 'r', 'd', 's', '\n',
        'h', 'o', 'm', 'e', 'w', 'o', 'r', 'k', '\n',
        'h', 'o', 'm', 'i', 'c', 'i', 'd', 'a', 'l', '\n',
        'h', 'o', 'm', 'i', 'c', 'i', 'd', 'e', '\n',
        'h', 'o', 'm', 'i', 'c', 'i', 'd', 'e', 's', '\n',
        'h', 'o', 'm', 'i', 'e', 's', 't', '\n',
        'h', 'o', 'm', 'i', 'l', 'i', 'e', 's', '\n',
        'h', 'o', 'm', 'i', 'l', 'y', '\n',
        'h', 'o', 'm', 'i', 'n', 'g', '\n',
        'h', 'o', 'm', 'i', 'n', 'i', 'd', '\n',
        'h', 'o', 'm', 'i', 'n', 'i', 'd', 's', '\n',
        'h', 'o', 'm', 'o', 'e', 'o', 'p', 'a', 't', 'h', 'i', 'c', '\n',
        'h', 'o', 'm', 'o', 'e', 'o', 'p', 'a', 't', 'h', 'y', '\n',
        'h', 'o', 'm', 'o', 'g', 'e', 'n', 'a', 't', 'e', 's', '\n',
        'h', 'o', 'm', 'o', 'g', 'e', 'n', 'e', 'i', 't', 'y', '\n',
        'h', 'o', 'm', 'o', 'g', 'e', 'n', 'e', 'o', 'u', 's', '\n',
        'h', 'o', 'm', 'o', 'g', 'e', 'n', 'e', 'o', 'u', 's', 'l', 'y', '\n',
        'h', 'o', 'm', 'o', 'g', 'e', 'n', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'h', 'o', 'm', 'o', 'g', 'e', 'n', 'i', 's', 'e', '\n',
        'h', 'o', 'm', 'o', 'g', 'e', 'n', 'i', 's', 'e', 'd', '\n',
        'h', 'o', 'm', 'o', 'g', 'e', 'n', 'i', 's', 'i', 'n', 'g', '\n',
        'h', 'o', 'm', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'h', 'o', 'm', 'o', 'l', 'o', 'g', 'i', 'e', 's', '\n',
        'h', 'o', 'm', 'o', 'l', 'o', 'g', 'o', 'u', 's', '\n',
        'h', 'o', 'm', 'o', 'l', 'o', 'g', 'u', 'e', '\n',
        'h', 'o', 'm', 'o', 'l', 'o', 'g', 'u', 'e', 's', '\n',
        'h', 'o', 'm', 'o', 'l', 'o', 'g', 'y', '\n',
        'h', 'o', 'm', 'o', 'm', 'o', 'r', 'p', 'h', 'i', 's', 'm', '\n',
        'h', 'o', 'm', 'o', 'm', 'o', 'r', 'p', 'h', 'i', 's', 'm', 's', '\n',
        'h', 'o', 'm', 'o', 'n', 'y', 'm', '\n',
        'h', 'o', 'm', 'o', 'n', 'y', 'm', 's', '\n',
        'h', 'o', 'm', 'o', 'p', 'h', 'o', 'b', 'e', 's', '\n',
        'h', 'o', 'm', 'o', 'p', 'h', 'o', 'b', 'i', 'a', '\n',
        'h', 'o', 'm', 'o', 'p', 'h', 'o', 'b', 'i', 'c', '\n',
        'h', 'o', 'm', 'o', 'p', 'h', 'o', 'n', 'e', 's', '\n',
        'h', 'o', 'm', 'o', 'p', 'h', 'o', 'n', 'y', '\n',
        'h', 'o', 'm', 'o', 's', 'e', 'x', 'u', 'a', 'l', '\n',
        'h', 'o', 'm', 'o', 's', 'e', 'x', 'u', 'a', 'l', 'i', 't', 'y', '\n',
        'h', 'o', 'm', 'o', 's', 'e', 'x', 'u', 'a', 'l', 'l', 'y', '\n',
        'h', 'o', 'm', 'o', 's', 'e', 'x', 'u', 'a', 'l', 's', '\n',
        'h', 'o', 'm', 'o', 't', 'o', 'p', 'y', '\n',
        'h', 'o', 'm', 'o', 'z', 'y', 'g', 'o', 'u', 's', '\n',
        'h', 'o', 'm', 'u', 'n', 'c', 'u', 'l', 'u', 's', '\n',
        'h', 'o', 'm', 'y', '\n',
        'h', 'o', 'n', 'e', '\n',
        'h', 'o', 'n', 'e', 'd', '\n',
        'h', 'o', 'n', 'e', 's', '\n',
        'h', 'o', 'n', 'e', 's', 't', '\n',
        'h', 'o', 'n', 'e', 's', 't', 'l', 'y', '\n',
        'h', 'o', 'n', 'e', 's', 't', 'y', '\n',
        'h', 'o', 'n', 'e', 'y', '\n',
        'h', 'o', 'n', 'e', 'y', 'b', 'e', 'e', '\n',
        'h', 'o', 'n', 'e', 'y', 'c', 'o', 'm', 'b', '\n',
        'h', 'o', 'n', 'e', 'y', 'c', 'o', 'm', 'b', 'e', 'd', '\n',
        'h', 'o', 'n', 'e', 'y', 'c', 'o', 'm', 'b', 'i', 'n', 'g', '\n',
        'h', 'o', 'n', 'e', 'y', 'd', 'e', 'w', '\n',
        'h', 'o', 'n', 'e', 'y', 'e', 'd', '\n',
        'h', 'o', 'n', 'e', 'y', 'm', 'o', 'o', 'n', '\n',
        'h', 'o', 'n', 'e', 'y', 'm', 'o', 'o', 'n', 'e', 'r', 's', '\n',
        'h', 'o', 'n', 'e', 'y', 'm', 'o', 'o', 'n', 's', '\n',
        'h', 'o', 'n', 'e', 'y', 's', 'u', 'c', 'k', 'l', 'e', '\n',
        'h', 'o', 'n', 'e', 'y', 's', 'u', 'c', 'k', 'l', 'e', 's', '\n',
        'h', 'o', 'n', 'i', 'n', 'g', '\n',
        'h', 'o', 'n', 'k', '\n',
        'h', 'o', 'n', 'k', 'i', 'n', 'g', '\n',
        'h', 'o', 'n', 'k', 's', '\n',
        'h', 'o', 'n', 'o', 'r', 'a', 'r', 'i', 'u', 'm', '\n',
        'h', 'o', 'n', 'o', 'r', 'a', 'r', 'y', '\n',
        'h', 'o', 'n', 'o', 'r', 'i', 'f', 'i', 'c', '\n',
        'h', 'o', 'n', 'o', 'r', 's', '\n',
        'h', 'o', 'n', 'o', 'u', 'r', '\n',
        'h', 'o', 'n', 'o', 'u', 'r', 'a', 'b', 'l', 'e', '\n',
        'h', 'o', 'n', 'o', 'u', 'r', 'a', 'b', 'l', 'y', '\n',
        'h', 'o', 'n', 'o', 'u', 'r', 'e', 'd', '\n',
        'h', 'o', 'n', 'o', 'u', 'r', 'i', 'n', 'g', '\n',
        'h', 'o', 'n', 'o', 'u', 'r', 's', '\n',
        'h', 'o', 'n', 's', 'h', 'u', '\n',
        'h', 'o', 'o', 'd', '\n',
        'h', 'o', 'o', 'd', 'e', 'd', '\n',
        'h', 'o', 'o', 'd', 'l', 'u', 'm', '\n',
        'h', 'o', 'o', 'd', 'l', 'u', 'm', 's', '\n',
        'h', 'o', 'o', 'd', 's', '\n',
        'h', 'o', 'o', 'd', 'w', 'i', 'n', 'k', '\n',
        'h', 'o', 'o', 'd', 'w', 'i', 'n', 'k', 'e', 'd', '\n',
        'h', 'o', 'o', 'd', 'w', 'i', 'n', 'k', 'i', 'n', 'g', '\n',
        'h', 'o', 'o', 'f', '\n',
        'h', 'o', 'o', 'f', 's', '\n',
        'h', 'o', 'o', 'k', '\n',
        'h', 'o', 'o', 'k', 'a', 'h', '\n',
        'h', 'o', 'o', 'k', 'e', 'd', '\n',
        'h', 'o', 'o', 'k', 'e', 'r', '\n',
        'h', 'o', 'o', 'k', 'e', 'r', 's', '\n',
        'h', 'o', 'o', 'k', 'i', 'n', 'g', '\n',
        'h', 'o', 'o', 'k', 'n', 'o', 's', 'e', 'd', '\n',
        'h', 'o', 'o', 'k', 's', '\n',
        'h', 'o', 'o', 'k', 'y', '\n',
        'h', 'o', 'o', 'l', 'i', 'g', 'a', 'n', '\n',
        'h', 'o', 'o', 'l', 'i', 'g', 'a', 'n', 'i', 's', 'm', '\n',
        'h', 'o', 'o', 'l', 'i', 'g', 'a', 'n', 's', '\n',
        'h', 'o', 'o', 'p', '\n',
        'h', 'o', 'o', 'p', 'e', 'd', '\n',
        'h', 'o', 'o', 'p', 's', '\n',
        'h', 'o', 'o', 'r', 'a', 'y', '\n',
        'h', 'o', 'o', 't', '\n',
        'h', 'o', 'o', 't', 'e', 'd', '\n',
        'h', 'o', 'o', 't', 'e', 'r', '\n',
        'h', 'o', 'o', 't', 'e', 'r', 's', '\n',
        'h', 'o', 'o', 't', 'i', 'n', 'g', '\n',
        'h', 'o', 'o', 't', 's', '\n',
        'h', 'o', 'o', 'v', 'e', 'r', '\n',
        'h', 'o', 'o', 'v', 'e', 'r', 'e', 'd', '\n',
        'h', 'o', 'o', 'v', 'e', 'r', 'i', 'n', 'g', '\n',
        'h', 'o', 'o', 'v', 'e', 's', '\n',
        'h', 'o', 'p', '\n',
        'h', 'o', 'p', 'e', '\n',
        'h', 'o', 'p', 'e', 'd', '\n',
        'h', 'o', 'p', 'e', 'f', 'u', 'l', '\n',
        'h', 'o', 'p', 'e', 'f', 'u', 'l', 'l', 'y', '\n',
        'h', 'o', 'p', 'e', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'h', 'o', 'p', 'e', 'f', 'u', 'l', 's', '\n',
        'h', 'o', 'p', 'e', 'l', 'e', 's', 's', '\n',
        'h', 'o', 'p', 'e', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'h', 'o', 'p', 'e', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'h', 'o', 'p', 'e', 's', '\n',
        'h', 'o', 'p', 'i', 'n', 'g', '\n',
        'h', 'o', 'p', 'p', 'e', 'd', '\n',
        'h', 'o', 'p', 'p', 'e', 'r', '\n',
        'h', 'o', 'p', 'p', 'e', 'r', 's', '\n',
        'h', 'o', 'p', 'p', 'i', 'n', 'g', '\n',
        'h', 'o', 'p', 's', '\n',
        'h', 'o', 'r', 'd', 'e', '\n',
        'h', 'o', 'r', 'd', 'e', 's', '\n',
        'h', 'o', 'r', 'i', 'z', 'o', 'n', '\n',
        'h', 'o', 'r', 'i', 'z', 'o', 'n', 's', '\n',
        'h', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', '\n',
        'h', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 'l', 'y', '\n',
        'h', 'o', 'r', 'i', 'z', 'o', 'n', 't', 'a', 'l', 's', '\n',
        'h', 'o', 'r', 'm', 'o', 'n', 'a', 'l', '\n',
        'h', 'o', 'r', 'm', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'h', 'o', 'r', 'm', 'o', 'n', 'e', '\n',
        'h', 'o', 'r', 'm', 'o', 'n', 'e', 's', '\n',
        'h', 'o', 'r', 'n', '\n',
        'h', 'o', 'r', 'n', 'b', 'e', 'a', 'm', '\n',
        'h', 'o', 'r', 'n', 'b', 'i', 'l', 'l', 's', '\n',
        'h', 'o', 'r', 'n', 'e', 'd', '\n',
        'h', 'o', 'r', 'n', 'e', 't', '\n',
        'h', 'o', 'r', 'n', 'e', 't', 's', '\n',
        'h', 'o', 'r', 'n', 'p', 'i', 'p', 'e', '\n',
        'h', 'o', 'r', 'n', 'p', 'i', 'p', 'e', 's', '\n',
        'h', 'o', 'r', 'n', 's', '\n',
        'h', 'o', 'r', 'n', 'y', '\n',
        'h', 'o', 'r', 'o', 's', 'c', 'o', 'p', 'e', '\n',
        'h', 'o', 'r', 'o', 's', 'c', 'o', 'p', 'e', 's', '\n',
        'h', 'o', 'r', 'r', 'e', 'n', 'd', 'o', 'u', 's', '\n',
        'h', 'o', 'r', 'r', 'e', 'n', 'd', 'o', 'u', 's', 'l', 'y', '\n',
        'h', 'o', 'r', 'r', 'i', 'b', 'l', 'e', '\n',
        'h', 'o', 'r', 'r', 'i', 'b', 'l', 'y', '\n',
        'h', 'o', 'r', 'r', 'i', 'd', '\n',
        'h', 'o', 'r', 'r', 'i', 'd', 'l', 'y', '\n',
        'h', 'o', 'r', 'r', 'i', 'f', 'i', 'c', '\n',
        'h', 'o', 'r', 'r', 'i', 'f', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'h', 'o', 'r', 'r', 'i', 'f', 'i', 'e', 'd', '\n',
        'h', 'o', 'r', 'r', 'i', 'f', 'i', 'e', 's', '\n',
        'h', 'o', 'r', 'r', 'i', 'f', 'y', '\n',
        'h', 'o', 'r', 'r', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'h', 'o', 'r', 'r', 'i', 'f', 'y', 'i', 'n', 'g', 'l', 'y', '\n',
        'h', 'o', 'r', 'r', 'o', 'r', '\n',
        'h', 'o', 'r', 'r', 'o', 'r', 's', '\n',
        'h', 'o', 'r', 'r', 'o', 'r', 's', 't', 'r', 'i', 'c', 'k', 'e', 'n', '\n',
        'h', 'o', 'r', 's', 'e', '\n',
        'h', 'o', 'r', 's', 'e', 'b', 'a', 'c', 'k', '\n',
        'h', 'o', 'r', 's', 'e', 'b', 'o', 'x', '\n',
        'h', 'o', 'r', 's', 'e', 'f', 'l', 'e', 's', 'h', '\n',
        'h', 'o', 'r', 's', 'e', 'f', 'l', 'y', '\n',
        'h', 'o', 'r', 's', 'e', 'h', 'a', 'i', 'r', '\n',
        'h', 'o', 'r', 's', 'e', 'l', 'e', 's', 's', '\n',
        'h', 'o', 'r', 's', 'e', 'm', 'a', 'n', '\n',
        'h', 'o', 'r', 's', 'e', 'm', 'e', 'n', '\n',
        'h', 'o', 'r', 's', 'e', 'p', 'l', 'a', 'y', '\n',
        'h', 'o', 'r', 's', 'e', 'p', 'o', 'w', 'e', 'r', '\n',
        'h', 'o', 'r', 's', 'e', 'r', 'a', 'd', 'i', 's', 'h', '\n',
        'h', 'o', 'r', 's', 'e', 's', '\n',
        'h', 'o', 'r', 's', 'e', 's', 'h', 'o', 'e', '\n',
        'h', 'o', 'r', 's', 'e', 's', 'h', 'o', 'e', 's', '\n',
        'h', 'o', 'r', 's', 'e', 'w', 'h', 'i', 'p', '\n',
        'h', 'o', 'r', 's', 'e', 'w', 'h', 'i', 'p', 'p', 'e', 'd', '\n',
        'h', 'o', 'r', 's', 'e', 'y', '\n',
        'h', 'o', 'r', 's', 'i', 'n', 'g', '\n',
        'h', 'o', 'r', 't', 'i', 'c', 'u', 'l', 't', 'u', 'r', 'a', 'l', '\n',
        'h', 'o', 'r', 't', 'i', 'c', 'u', 'l', 't', 'u', 'r', 'e', '\n',
        'h', 'o', 'r', 't', 'i', 'c', 'u', 'l', 't', 'u', 'r', 'i', 's', 't', '\n',
        'h', 'o', 'r', 't', 'i', 'c', 'u', 'l', 't', 'u', 'r', 'i', 's', 't', 's', '\n',
        'h', 'o', 's', 'a', 'n', 'n', 'a', '\n',
        'h', 'o', 's', 'a', 'n', 'n', 'a', 's', '\n',
        'h', 'o', 's', 'e', '\n',
        'h', 'o', 's', 'e', 'd', '\n',
        'h', 'o', 's', 'e', 'p', 'i', 'p', 'e', '\n',
        'h', 'o', 's', 'e', 's', '\n',
        'h', 'o', 's', 'i', 'e', 'r', '\n',
        'h', 'o', 's', 'i', 'e', 'r', 'y', '\n',
        'h', 'o', 's', 'i', 'n', 'g', '\n',
        'h', 'o', 's', 'p', 'i', 'c', 'e', '\n',
        'h', 'o', 's', 'p', 'i', 'c', 'e', 's', '\n',
        'h', 'o', 's', 'p', 'i', 't', 'a', 'b', 'l', 'e', '\n',
        'h', 'o', 's', 'p', 'i', 't', 'a', 'b', 'l', 'y', '\n',
        'h', 'o', 's', 'p', 'i', 't', 'a', 'l', '\n',
        'h', 'o', 's', 'p', 'i', 't', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'h', 'o', 's', 'p', 'i', 't', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'h', 'o', 's', 'p', 'i', 't', 'a', 'l', 'i', 't', 'y', '\n',
        'h', 'o', 's', 'p', 'i', 't', 'a', 'l', 's', '\n',
        'h', 'o', 's', 't', '\n',
        'h', 'o', 's', 't', 'a', '\n',
        'h', 'o', 's', 't', 'a', 'g', 'e', '\n',
        'h', 'o', 's', 't', 'a', 'g', 'e', 's', '\n',
        'h', 'o', 's', 't', 'e', 'd', '\n',
        'h', 'o', 's', 't', 'e', 'l', '\n',
        'h', 'o', 's', 't', 'e', 'l', 'r', 'i', 'e', 's', '\n',
        'h', 'o', 's', 't', 'e', 'l', 'r', 'y', '\n',
        'h', 'o', 's', 't', 'e', 'l', 's', '\n',
        'h', 'o', 's', 't', 'e', 's', 's', '\n',
        'h', 'o', 's', 't', 'e', 's', 's', 'e', 's', '\n',
        'h', 'o', 's', 't', 'i', 'l', 'e', '\n',
        'h', 'o', 's', 't', 'i', 'l', 'e', 'l', 'y', '\n',
        'h', 'o', 's', 't', 'i', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'h', 'o', 's', 't', 'i', 'l', 'i', 't', 'y', '\n',
        'h', 'o', 's', 't', 'i', 'n', 'g', '\n',
        'h', 'o', 's', 't', 'l', 'e', 'r', '\n',
        'h', 'o', 's', 't', 's', '\n',
        'h', 'o', 't', '\n',
        'h', 'o', 't', 'a', 'i', 'r', '\n',
        'h', 'o', 't', 'b', 'e', 'd', '\n',
        'h', 'o', 't', 'b', 'e', 'd', 's', '\n',
        'h', 'o', 't', 'b', 'l', 'o', 'o', 'd', 'e', 'd', '\n',
        'h', 'o', 't', 'c', 'h', 'p', 'o', 't', 'c', 'h', '\n',
        'h', 'o', 't', 'd', 'o', 'g', '\n',
        'h', 'o', 't', 'd', 'o', 'g', 's', '\n',
        'h', 'o', 't', 'e', 'l', '\n',
        'h', 'o', 't', 'e', 'l', 'i', 'e', 'r', '\n',
        'h', 'o', 't', 'e', 'l', 'i', 'e', 'r', 's', '\n',
        'h', 'o', 't', 'e', 'l', 's', '\n',
        'h', 'o', 't', 'h', 'e', 'a', 'd', 'e', 'd', '\n',
        'h', 'o', 't', 'h', 'e', 'a', 'd', 's', '\n',
        'h', 'o', 't', 'h', 'o', 'u', 's', 'e', '\n',
        'h', 'o', 't', 'h', 'o', 'u', 's', 'e', 's', '\n',
        'h', 'o', 't', 'l', 'i', 'n', 'e', '\n',
        'h', 'o', 't', 'l', 'y', '\n',
        'h', 'o', 't', 'n', 'e', 's', 's', '\n',
        'h', 'o', 't', 'p', 'l', 'a', 't', 'e', '\n',
        'h', 'o', 't', 'p', 'l', 'a', 't', 'e', 's', '\n',
        'h', 'o', 't', 'p', 'o', 't', '\n',
        'h', 'o', 't', 'r', 'o', 'd', '\n',
        'h', 'o', 't', 's', 'p', 'o', 't', '\n',
        'h', 'o', 't', 's', 'p', 'o', 't', 's', '\n',
        'h', 'o', 't', 't', 'e', 'm', 'p', 'e', 'r', 'e', 'd', '\n',
        'h', 'o', 't', 't', 'e', 'r', '\n',
        'h', 'o', 't', 't', 'e', 's', 't', '\n',
        'h', 'o', 't', 't', 'i', 'n', 'g', '\n',
        'h', 'o', 'u', 'n', 'd', '\n',
        'h', 'o', 'u', 'n', 'd', 'e', 'd', '\n',
        'h', 'o', 'u', 'n', 'd', 'i', 'n', 'g', '\n',
        'h', 'o', 'u', 'n', 'd', 's', '\n',
        'h', 'o', 'u', 'r', '\n',
        'h', 'o', 'u', 'r', 'g', 'l', 'a', 's', 's', '\n',
        'h', 'o', 'u', 'r', 'l', 'y', '\n',
        'h', 'o', 'u', 'r', 's', '\n',
        'h', 'o', 'u', 's', 'e', '\n',
        'h', 'o', 'u', 's', 'e', 'b', 'o', 'a', 't', '\n',
        'h', 'o', 'u', 's', 'e', 'b', 'o', 'a', 't', 's', '\n',
        'h', 'o', 'u', 's', 'e', 'b', 'o', 'u', 'n', 'd', '\n',
        'h', 'o', 'u', 's', 'e', 'b', 'r', 'e', 'a', 'k', 'e', 'r', '\n',
        'h', 'o', 'u', 's', 'e', 'b', 'r', 'e', 'a', 'k', 'e', 'r', 's', '\n',
        'h', 'o', 'u', 's', 'e', 'b', 'r', 'e', 'a', 'k', 'i', 'n', 'g', '\n',
        'h', 'o', 'u', 's', 'e', 'b', 'u', 'i', 'l', 'd', 'e', 'r', '\n',
        'h', 'o', 'u', 's', 'e', 'b', 'u', 'i', 'l', 'd', 'e', 'r', 's', '\n',
        'h', 'o', 'u', 's', 'e', 'b', 'u', 'i', 'l', 'd', 'i', 'n', 'g', '\n',
        'h', 'o', 'u', 's', 'e', 'b', 'u', 'y', 'e', 'r', 's', '\n',
        'h', 'o', 'u', 's', 'e', 'd', '\n',
        'h', 'o', 'u', 's', 'e', 'f', 'l', 'i', 'e', 's', '\n',
        'h', 'o', 'u', 's', 'e', 'f', 'u', 'l', '\n',
        'h', 'o', 'u', 's', 'e', 'h', 'o', 'l', 'd', '\n',
        'h', 'o', 'u', 's', 'e', 'h', 'o', 'l', 'd', 'e', 'r', '\n',
        'h', 'o', 'u', 's', 'e', 'h', 'o', 'l', 'd', 'e', 'r', 's', '\n',
        'h', 'o', 'u', 's', 'e', 'h', 'o', 'l', 'd', 's', '\n',
        'h', 'o', 'u', 's', 'e', 'h', 'u', 'n', 't', 'i', 'n', 'g', '\n',
        'h', 'o', 'u', 's', 'e', 'k', 'e', 'e', 'p', 'e', 'r', '\n',
        'h', 'o', 'u', 's', 'e', 'k', 'e', 'e', 'p', 'e', 'r', 's', '\n',
        'h', 'o', 'u', 's', 'e', 'k', 'e', 'e', 'p', 'i', 'n', 'g', '\n',
        'h', 'o', 'u', 's', 'e', 'm', 'a', 'i', 'd', '\n',
        'h', 'o', 'u', 's', 'e', 'm', 'a', 'i', 'd', 's', '\n',
        'h', 'o', 'u', 's', 'e', 'r', 'o', 'o', 'm', '\n',
        'h', 'o', 'u', 's', 'e', 's', '\n',
        'h', 'o', 'u', 's', 'e', 'w', 'i', 'f', 'e', '\n',
        'h', 'o', 'u', 's', 'e', 'w', 'i', 'v', 'e', 's', '\n',
        'h', 'o', 'u', 's', 'e', 'w', 'o', 'r', 'k', '\n',
        'h', 'o', 'u', 's', 'i', 'n', 'g', '\n',
        'h', 'o', 'u', 's', 'i', 'n', 'g', 's', '\n',
        'h', 'o', 'u', 's', 't', 'o', 'n', '\n',
        'h', 'o', 'v', 'e', '\n',
        'h', 'o', 'v', 'e', 'l', '\n',
        'h', 'o', 'v', 'e', 'l', 's', '\n',
        'h', 'o', 'v', 'e', 'r', '\n',
        'h', 'o', 'v', 'e', 'r', 'c', 'r', 'a', 'f', 't', '\n',
        'h', 'o', 'v', 'e', 'r', 'e', 'd', '\n',
        'h', 'o', 'v', 'e', 'r', 'e', 'r', '\n',
        'h', 'o', 'v', 'e', 'r', 'i', 'n', 'g', '\n',
        'h', 'o', 'v', 'e', 'r', 's', '\n',
        'h', 'o', 'w', '\n',
        'h', 'o', 'w', 'd', 'y', '\n',
        'h', 'o', 'w', 'e', 'v', 'e', 'r', '\n',
        'h', 'o', 'w', 'i', 't', 'z', 'e', 'r', '\n',
        'h', 'o', 'w', 'i', 't', 'z', 'e', 'r', 's', '\n',
        'h', 'o', 'w', 'l', '\n',
        'h', 'o', 'w', 'l', 'e', 'd', '\n',
        'h', 'o', 'w', 'l', 'e', 'r', '\n',
        'h', 'o', 'w', 'l', 'e', 'r', 's', '\n',
        'h', 'o', 'w', 'l', 'i', 'n', 'g', '\n',
        'h', 'o', 'w', 'l', 'i', 'n', 'g', 's', '\n',
        'h', 'o', 'w', 'l', 's', '\n',
        'h', 'o', 'w', 's', 'o', 'e', 'v', 'e', 'r', '\n',
        'h', 'u', 'b', '\n',
        'h', 'u', 'b', 'b', 'i', 'e', 's', '\n',
        'h', 'u', 'b', 'b', 'u', 'b', '\n',
        'h', 'u', 'b', 'b', 'y', '\n',
        'h', 'u', 'b', 'c', 'a', 'p', '\n',
        'h', 'u', 'b', 'c', 'a', 'p', 's', '\n',
        'h', 'u', 'b', 'r', 'i', 's', '\n',
        'h', 'u', 'b', 'r', 'i', 's', 't', 'i', 'c', '\n',
        'h', 'u', 'b', 's', '\n',
        'h', 'u', 'c', 'k', 'l', 'e', 'b', 'e', 'r', 'r', 'y', '\n',
        'h', 'u', 'd', 'd', 'l', 'e', '\n',
        'h', 'u', 'd', 'd', 'l', 'e', 'd', '\n',
        'h', 'u', 'd', 'd', 'l', 'e', 's', '\n',
        'h', 'u', 'd', 'd', 'l', 'i', 'n', 'g', '\n',
        'h', 'u', 'e', '\n',
        'h', 'u', 'e', 's', '\n',
        'h', 'u', 'f', 'f', '\n',
        'h', 'u', 'f', 'f', 'e', 'd', '\n',
        'h', 'u', 'f', 'f', 'i', 'l', 'y', '\n',
        'h', 'u', 'f', 'f', 'i', 'n', 'g', '\n',
        'h', 'u', 'f', 'f', 'y', '\n',
        'h', 'u', 'g', '\n',
        'h', 'u', 'g', 'e', '\n',
        'h', 'u', 'g', 'e', 'l', 'y', '\n',
        'h', 'u', 'g', 'e', 'n', 'e', 's', 's', '\n',
        'h', 'u', 'g', 'g', 'e', 'd', '\n',
        'h', 'u', 'g', 'g', 'i', 'n', 'g', '\n',
        'h', 'u', 'g', 's', '\n',
        'h', 'u', 'g', 'u', 'e', 'n', 'o', 't', '\n',
        'h', 'u', 'h', '\n',
        'h', 'u', 'l', 'k', '\n',
        'h', 'u', 'l', 'k', 'i', 'n', 'g', '\n',
        'h', 'u', 'l', 'k', 's', '\n',
        'h', 'u', 'l', 'l', '\n',
        'h', 'u', 'l', 'l', 'a', 'b', 'a', 'l', 'o', 'o', '\n',
        'h', 'u', 'l', 'l', 'e', 'd', '\n',
        'h', 'u', 'l', 'l', 'o', '\n',
        'h', 'u', 'l', 'l', 's', '\n',
        'h', 'u', 'm', '\n',
        'h', 'u', 'm', 'a', 'n', '\n',
        'h', 'u', 'm', 'a', 'n', 'e', '\n',
        'h', 'u', 'm', 'a', 'n', 'e', 'l', 'y', '\n',
        'h', 'u', 'm', 'a', 'n', 'e', 'r', '\n',
        'h', 'u', 'm', 'a', 'n', 'i', 's', 'e', '\n',
        'h', 'u', 'm', 'a', 'n', 'i', 's', 'e', 'd', '\n',
        'h', 'u', 'm', 'a', 'n', 'i', 's', 'i', 'n', 'g', '\n',
        'h', 'u', 'm', 'a', 'n', 'i', 's', 'm', '\n',
        'h', 'u', 'm', 'a', 'n', 'i', 's', 't', '\n',
        'h', 'u', 'm', 'a', 'n', 'i', 's', 't', 'i', 'c', '\n',
        'h', 'u', 'm', 'a', 'n', 'i', 's', 't', 's', '\n',
        'h', 'u', 'm', 'a', 'n', 'i', 't', 'a', 'r', 'i', 'a', 'n', '\n',
        'h', 'u', 'm', 'a', 'n', 'i', 't', 'a', 'r', 'i', 'a', 'n', 'i', 's', 'm', '\n',
        'h', 'u', 'm', 'a', 'n', 'i', 't', 'i', 'e', 's', '\n',
        'h', 'u', 'm', 'a', 'n', 'i', 't', 'y', '\n',
        'h', 'u', 'm', 'a', 'n', 'k', 'i', 'n', 'd', '\n',
        'h', 'u', 'm', 'a', 'n', 'l', 'y', '\n',
        'h', 'u', 'm', 'a', 'n', 'n', 'e', 's', 's', '\n',
        'h', 'u', 'm', 'a', 'n', 'o', 'i', 'd', '\n',
        'h', 'u', 'm', 'a', 'n', 'o', 'i', 'd', 's', '\n',
        'h', 'u', 'm', 'a', 'n', 's', '\n',
        'h', 'u', 'm', 'b', 'l', 'e', '\n',
        'h', 'u', 'm', 'b', 'l', 'e', 'd', '\n',
        'h', 'u', 'm', 'b', 'l', 'e', 'n', 'e', 's', 's', '\n',
        'h', 'u', 'm', 'b', 'l', 'e', 'r', '\n',
        'h', 'u', 'm', 'b', 'l', 'e', 's', '\n',
        'h', 'u', 'm', 'b', 'l', 'e', 's', 't', '\n',
        'h', 'u', 'm', 'b', 'l', 'i', 'n', 'g', '\n',
        'h', 'u', 'm', 'b', 'l', 'y', '\n',
        'h', 'u', 'm', 'b', 'u', 'g', '\n',
        'h', 'u', 'm', 'b', 'u', 'g', 's', '\n',
        'h', 'u', 'm', 'd', 'r', 'u', 'm', '\n',
        'h', 'u', 'm', 'e', 'r', 'u', 's', '\n',
        'h', 'u', 'm', 'i', 'd', '\n',
        'h', 'u', 'm', 'i', 'd', 'i', 'f', 'i', 'e', 'r', '\n',
        'h', 'u', 'm', 'i', 'd', 'i', 'f', 'i', 'e', 'r', 's', '\n',
        'h', 'u', 'm', 'i', 'd', 'i', 't', 'y', '\n',
        'h', 'u', 'm', 'i', 'f', 'y', '\n',
        'h', 'u', 'm', 'i', 'l', 'i', 'a', 't', 'e', '\n',
        'h', 'u', 'm', 'i', 'l', 'i', 'a', 't', 'e', 'd', '\n',
        'h', 'u', 'm', 'i', 'l', 'i', 'a', 't', 'e', 's', '\n',
        'h', 'u', 'm', 'i', 'l', 'i', 'a', 't', 'i', 'n', 'g', '\n',
        'h', 'u', 'm', 'i', 'l', 'i', 'a', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'h', 'u', 'm', 'i', 'l', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'h', 'u', 'm', 'i', 'l', 'i', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'h', 'u', 'm', 'i', 'l', 'i', 't', 'y', '\n',
        'h', 'u', 'm', 'm', 'a', 'b', 'l', 'e', '\n',
        'h', 'u', 'm', 'm', 'e', 'd', '\n',
        'h', 'u', 'm', 'm', 'e', 'r', '\n',
        'h', 'u', 'm', 'm', 'i', 'n', 'g', '\n',
        'h', 'u', 'm', 'm', 'i', 'n', 'g', 'b', 'i', 'r', 'd', '\n',
        'h', 'u', 'm', 'm', 'i', 'n', 'g', 'b', 'i', 'r', 'd', 's', '\n',
        'h', 'u', 'm', 'm', 'o', 'c', 'k', '\n',
        'h', 'u', 'm', 'm', 'o', 'c', 'k', 's', '\n',
        'h', 'u', 'm', 'm', 'o', 'c', 'k', 'y', '\n',
        'h', 'u', 'm', 'o', 'r', 'i', 's', 't', '\n',
        'h', 'u', 'm', 'o', 'r', 'o', 'u', 's', '\n',
        'h', 'u', 'm', 'o', 'r', 'o', 'u', 's', 'l', 'y', '\n',
        'h', 'u', 'm', 'o', 'u', 'r', '\n',
        'h', 'u', 'm', 'o', 'u', 'r', 'e', 'd', '\n',
        'h', 'u', 'm', 'o', 'u', 'r', 'i', 'n', 'g', '\n',
        'h', 'u', 'm', 'o', 'u', 'r', 'l', 'e', 's', 's', '\n',
        'h', 'u', 'm', 'o', 'u', 'r', 's', '\n',
        'h', 'u', 'm', 'p', '\n',
        'h', 'u', 'm', 'p', 'b', 'a', 'c', 'k', '\n',
        'h', 'u', 'm', 'p', 'e', 'd', '\n',
        'h', 'u', 'm', 'p', 'i', 'n', 'g', '\n',
        'h', 'u', 'm', 'p', 's', '\n',
        'h', 'u', 'm', 's', '\n',
        'h', 'u', 'm', 'u', 's', '\n',
        'h', 'u', 'n', 'c', 'h', '\n',
        'h', 'u', 'n', 'c', 'h', 'b', 'a', 'c', 'k', '\n',
        'h', 'u', 'n', 'c', 'h', 'b', 'a', 'c', 'k', 'e', 'd', '\n',
        'h', 'u', 'n', 'c', 'h', 'e', 'd', '\n',
        'h', 'u', 'n', 'c', 'h', 'e', 's', '\n',
        'h', 'u', 'n', 'c', 'h', 'i', 'n', 'g', '\n',
        'h', 'u', 'n', 'd', 'r', 'e', 'd', '\n',
        'h', 'u', 'n', 'd', 'r', 'e', 'd', 'f', 'o', 'l', 'd', '\n',
        'h', 'u', 'n', 'd', 'r', 'e', 'd', 's', '\n',
        'h', 'u', 'n', 'd', 'r', 'e', 'd', 't', 'h', '\n',
        'h', 'u', 'n', 'd', 'r', 'e', 'd', 't', 'h', 's', '\n',
        'h', 'u', 'n', 'd', 'r', 'e', 'd', 'w', 'e', 'i', 'g', 'h', 't', '\n',
        'h', 'u', 'n', 'd', 'r', 'e', 'd', 'w', 'e', 'i', 'g', 'h', 't', 's', '\n',
        'h', 'u', 'n', 'g', '\n',
        'h', 'u', 'n', 'g', 'a', 'r', 'y', '\n',
        'h', 'u', 'n', 'g', 'e', 'r', '\n',
        'h', 'u', 'n', 'g', 'e', 'r', 'e', 'd', '\n',
        'h', 'u', 'n', 'g', 'e', 'r', 'i', 'n', 'g', '\n',
        'h', 'u', 'n', 'g', 'e', 'r', 's', '\n',
        'h', 'u', 'n', 'g', 'r', 'i', 'e', 'r', '\n',
        'h', 'u', 'n', 'g', 'r', 'i', 'e', 's', 't', '\n',
        'h', 'u', 'n', 'g', 'r', 'i', 'l', 'y', '\n',
        'h', 'u', 'n', 'g', 'r', 'y', '\n',
        'h', 'u', 'n', 'k', '\n',
        'h', 'u', 'n', 'k', 'e', 'r', 's', '\n',
        'h', 'u', 'n', 'k', 's', '\n',
        'h', 'u', 'n', 't', '\n',
        'h', 'u', 'n', 't', 'e', 'd', '\n',
        'h', 'u', 'n', 't', 'e', 'r', '\n',
        'h', 'u', 'n', 't', 'e', 'r', 'g', 'a', 't', 'h', 'e', 'r', 'e', 'r', '\n',
        'h', 'u', 'n', 't', 'e', 'r', 'g', 'a', 't', 'h', 'e', 'r', 'e', 'r', 's', '\n',
        'h', 'u', 'n', 't', 'e', 'r', 's', '\n',
        'h', 'u', 'n', 't', 'i', 'n', 'g', '\n',
        'h', 'u', 'n', 't', 's', '\n',
        'h', 'u', 'n', 't', 's', 'm', 'a', 'n', '\n',
        'h', 'u', 'n', 't', 's', 'm', 'e', 'n', '\n',
        'h', 'u', 'r', 'd', 'l', 'e', '\n',
        'h', 'u', 'r', 'd', 'l', 'e', 'd', '\n',
        'h', 'u', 'r', 'd', 'l', 'e', 'r', '\n',
        'h', 'u', 'r', 'd', 'l', 'e', 'r', 's', '\n',
        'h', 'u', 'r', 'd', 'l', 'e', 's', '\n',
        'h', 'u', 'r', 'l', '\n',
        'h', 'u', 'r', 'l', 'e', 'd', '\n',
        'h', 'u', 'r', 'l', 'i', 'n', 'g', '\n',
        'h', 'u', 'r', 'l', 's', '\n',
        'h', 'u', 'r', 'l', 'y', 'b', 'u', 'r', 'l', 'y', '\n',
        'h', 'u', 'r', 'r', 'a', 'h', '\n',
        'h', 'u', 'r', 'r', 'a', 'h', 's', '\n',
        'h', 'u', 'r', 'r', 'a', 'y', '\n',
        'h', 'u', 'r', 'r', 'i', 'c', 'a', 'n', 'e', '\n',
        'h', 'u', 'r', 'r', 'i', 'c', 'a', 'n', 'e', 's', '\n',
        'h', 'u', 'r', 'r', 'i', 'e', 'd', '\n',
        'h', 'u', 'r', 'r', 'i', 'e', 'd', 'l', 'y', '\n',
        'h', 'u', 'r', 'r', 'i', 'e', 's', '\n',
        'h', 'u', 'r', 'r', 'y', '\n',
        'h', 'u', 'r', 'r', 'y', 'i', 'n', 'g', '\n',
        'h', 'u', 'r', 't', '\n',
        'h', 'u', 'r', 't', 'f', 'u', 'l', '\n',
        'h', 'u', 'r', 't', 'i', 'n', 'g', '\n',
        'h', 'u', 'r', 't', 'l', 'e', '\n',
        'h', 'u', 'r', 't', 'l', 'e', 'd', '\n',
        'h', 'u', 'r', 't', 'l', 'e', 's', '\n',
        'h', 'u', 'r', 't', 'l', 'i', 'n', 'g', '\n',
        'h', 'u', 'r', 't', 's', '\n',
        'h', 'u', 's', 'b', 'a', 'n', 'd', '\n',
        'h', 'u', 's', 'b', 'a', 'n', 'd', 'm', 'a', 'n', '\n',
        'h', 'u', 's', 'b', 'a', 'n', 'd', 'm', 'e', 'n', '\n',
        'h', 'u', 's', 'b', 'a', 'n', 'd', 'r', 'y', '\n',
        'h', 'u', 's', 'b', 'a', 'n', 'd', 's', '\n',
        'h', 'u', 's', 'h', '\n',
        'h', 'u', 's', 'h', 'e', 'd', '\n',
        'h', 'u', 's', 'h', 'e', 's', '\n',
        'h', 'u', 's', 'h', 'h', 'u', 's', 'h', '\n',
        'h', 'u', 's', 'h', 'i', 'n', 'g', '\n',
        'h', 'u', 's', 'k', '\n',
        'h', 'u', 's', 'k', 'e', 'd', '\n',
        'h', 'u', 's', 'k', 'i', 'e', 'r', '\n',
        'h', 'u', 's', 'k', 'i', 'e', 's', '\n',
        'h', 'u', 's', 'k', 'i', 'e', 's', 't', '\n',
        'h', 'u', 's', 'k', 'i', 'l', 'y', '\n',
        'h', 'u', 's', 'k', 's', '\n',
        'h', 'u', 's', 'k', 'y', '\n',
        'h', 'u', 's', 's', 'i', 'e', 's', '\n',
        'h', 'u', 's', 's', 'y', '\n',
        'h', 'u', 's', 't', 'i', 'n', 'g', 's', '\n',
        'h', 'u', 's', 't', 'l', 'e', '\n',
        'h', 'u', 's', 't', 'l', 'e', 'd', '\n',
        'h', 'u', 's', 't', 'l', 'e', 'r', '\n',
        'h', 'u', 's', 't', 'l', 'e', 'r', 's', '\n',
        'h', 'u', 's', 't', 'l', 'e', 's', '\n',
        'h', 'u', 's', 't', 'l', 'i', 'n', 'g', '\n',
        'h', 'u', 't', '\n',
        'h', 'u', 't', 'c', 'h', '\n',
        'h', 'u', 't', 'c', 'h', 'e', 's', '\n',
        'h', 'u', 't', 's', '\n',
        'h', 'y', 'a', 'c', 'i', 'n', 't', 'h', '\n',
        'h', 'y', 'a', 'c', 'i', 'n', 't', 'h', 's', '\n',
        'h', 'y', 'a', 'e', 'n', 'a', '\n',
        'h', 'y', 'a', 'e', 'n', 'a', 's', '\n',
        'h', 'y', 'b', 'r', 'i', 'd', '\n',
        'h', 'y', 'b', 'r', 'i', 'd', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'h', 'y', 'b', 'r', 'i', 'd', 'i', 's', 'e', 'd', '\n',
        'h', 'y', 'b', 'r', 'i', 'd', 's', '\n',
        'h', 'y', 'd', 'r', 'a', '\n',
        'h', 'y', 'd', 'r', 'a', 'n', 'g', 'e', 'a', '\n',
        'h', 'y', 'd', 'r', 'a', 'n', 'g', 'e', 'a', 's', '\n',
        'h', 'y', 'd', 'r', 'a', 'n', 't', '\n',
        'h', 'y', 'd', 'r', 'a', 'n', 't', 's', '\n',
        'h', 'y', 'd', 'r', 'a', 't', 'e', '\n',
        'h', 'y', 'd', 'r', 'a', 't', 'e', 'd', '\n',
        'h', 'y', 'd', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'h', 'y', 'd', 'r', 'a', 'u', 'l', 'i', 'c', '\n',
        'h', 'y', 'd', 'r', 'a', 'u', 'l', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'h', 'y', 'd', 'r', 'a', 'u', 'l', 'i', 'c', 's', '\n',
        'h', 'y', 'd', 'r', 'a', 'z', 'i', 'n', 'e', '\n',
        'h', 'y', 'd', 'r', 'i', 'd', 'e', '\n',
        'h', 'y', 'd', 'r', 'o', '\n',
        'h', 'y', 'd', 'r', 'o', 'c', 'a', 'r', 'b', 'o', 'n', '\n',
        'h', 'y', 'd', 'r', 'o', 'c', 'a', 'r', 'b', 'o', 'n', 's', '\n',
        'h', 'y', 'd', 'r', 'o', 'c', 'h', 'l', 'o', 'r', 'i', 'c', '\n',
        'h', 'y', 'd', 'r', 'o', 'c', 'h', 'l', 'o', 'r', 'i', 'd', 'e', '\n',
        'h', 'y', 'd', 'r', 'o', 'd', 'y', 'n', 'a', 'm', 'i', 'c', '\n',
        'h', 'y', 'd', 'r', 'o', 'd', 'y', 'n', 'a', 'm', 'i', 'c', 'a', 'l', '\n',
        'h', 'y', 'd', 'r', 'o', 'd', 'y', 'n', 'a', 'm', 'i', 'c', 's', '\n',
        'h', 'y', 'd', 'r', 'o', 'e', 'l', 'e', 'c', 't', 'r', 'i', 'c', '\n',
        'h', 'y', 'd', 'r', 'o', 'e', 'l', 'e', 'c', 't', 'r', 'i', 'c', 'i', 't', 'y', '\n',
        'h', 'y', 'd', 'r', 'o', 'f', 'l', 'u', 'o', 'r', 'i', 'c', '\n',
        'h', 'y', 'd', 'r', 'o', 'f', 'o', 'i', 'l', '\n',
        'h', 'y', 'd', 'r', 'o', 'f', 'o', 'i', 'l', 's', '\n',
        'h', 'y', 'd', 'r', 'o', 'g', 'e', 'n', '\n',
        'h', 'y', 'd', 'r', 'o', 'g', 'e', 'n', 'a', 't', 'e', 'd', '\n',
        'h', 'y', 'd', 'r', 'o', 'g', 'e', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'h', 'y', 'd', 'r', 'o', 'g', 'r', 'a', 'p', 'h', 'e', 'r', '\n',
        'h', 'y', 'd', 'r', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', '\n',
        'h', 'y', 'd', 'r', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'h', 'y', 'd', 'r', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'h', 'y', 'd', 'r', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'h', 'y', 'd', 'r', 'o', 'l', 'o', 'g', 'y', '\n',
        'h', 'y', 'd', 'r', 'o', 'l', 'y', 's', 'i', 's', '\n',
        'h', 'y', 'd', 'r', 'o', 'm', 'a', 'g', 'n', 'e', 't', 'i', 'c', '\n',
        'h', 'y', 'd', 'r', 'o', 'm', 'e', 'c', 'h', 'a', 'n', 'i', 'c', 's', '\n',
        'h', 'y', 'd', 'r', 'o', 'p', 'h', 'o', 'b', 'i', 'a', '\n',
        'h', 'y', 'd', 'r', 'o', 'p', 'h', 'o', 'b', 'i', 'c', '\n',
        'h', 'y', 'd', 'r', 'o', 'p', 'o', 'n', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'h', 'y', 'd', 'r', 'o', 's', 'p', 'h', 'e', 'r', 'e', '\n',
        'h', 'y', 'd', 'r', 'o', 's', 't', 'a', 't', 'i', 'c', '\n',
        'h', 'y', 'd', 'r', 'o', 's', 't', 'a', 't', 'i', 'c', 's', '\n',
        'h', 'y', 'd', 'r', 'o', 't', 'h', 'e', 'r', 'm', 'a', 'l', '\n',
        'h', 'y', 'd', 'r', 'o', 'u', 's', '\n',
        'h', 'y', 'd', 'r', 'o', 'x', 'i', 'd', 'e', '\n',
        'h', 'y', 'd', 'r', 'o', 'x', 'i', 'd', 'e', 's', '\n',
        'h', 'y', 'e', 'n', 'a', '\n',
        'h', 'y', 'e', 'n', 'a', 's', '\n',
        'h', 'y', 'g', 'i', 'e', 'n', 'e', '\n',
        'h', 'y', 'g', 'i', 'e', 'n', 'i', 'c', '\n',
        'h', 'y', 'g', 'i', 'e', 'n', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'h', 'y', 'g', 'i', 'e', 'n', 'i', 's', 't', '\n',
        'h', 'y', 'g', 'i', 'e', 'n', 'i', 's', 't', 's', '\n',
        'h', 'y', 'g', 'r', 'o', 's', 'c', 'o', 'p', 'i', 'c', '\n',
        'h', 'y', 'm', 'e', 'n', '\n',
        'h', 'y', 'm', 'e', 'n', 's', '\n',
        'h', 'y', 'm', 'n', '\n',
        'h', 'y', 'm', 'n', 'a', 'l', '\n',
        'h', 'y', 'm', 'n', 'b', 'o', 'o', 'k', '\n',
        'h', 'y', 'm', 'n', 's', '\n',
        'h', 'y', 'p', 'e', '\n',
        'h', 'y', 'p', 'e', 'r', 'a', 'c', 't', 'i', 'v', 'e', '\n',
        'h', 'y', 'p', 'e', 'r', 'a', 'c', 't', 'i', 'v', 'i', 't', 'y', '\n',
        'h', 'y', 'p', 'e', 'r', 'b', 'o', 'l', 'a', '\n',
        'h', 'y', 'p', 'e', 'r', 'b', 'o', 'l', 'a', 's', '\n',
        'h', 'y', 'p', 'e', 'r', 'b', 'o', 'l', 'e', '\n',
        'h', 'y', 'p', 'e', 'r', 'b', 'o', 'l', 'i', 'c', '\n',
        'h', 'y', 'p', 'e', 'r', 'b', 'o', 'l', 'o', 'i', 'd', '\n',
        'h', 'y', 'p', 'e', 'r', 'b', 'o', 'l', 'o', 'i', 'd', 's', '\n',
        'h', 'y', 'p', 'e', 'r', 'c', 'h', 'o', 'l', 'e', 's', 't', 'e', 'r', 'o', 'l', 'a', 'e', 'm', 'i', 'a', '\n',
        'h', 'y', 'p', 'e', 'r', 'c', 'u', 'b', 'e', '\n',
        'h', 'y', 'p', 'e', 'r', 'c', 'u', 'b', 'e', 's', '\n',
        'h', 'y', 'p', 'e', 'r', 'f', 'i', 'n', 'e', '\n',
        'h', 'y', 'p', 'e', 'r', 'i', 'n', 'f', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'h', 'y', 'p', 'e', 'r', 'm', 'a', 'r', 'k', 'e', 't', '\n',
        'h', 'y', 'p', 'e', 'r', 'm', 'a', 'r', 'k', 'e', 't', 's', '\n',
        'h', 'y', 'p', 'e', 'r', 'p', 'l', 'a', 'n', 'e', '\n',
        'h', 'y', 'p', 'e', 'r', 'p', 'l', 'a', 'n', 'e', 's', '\n',
        'h', 'y', 'p', 'e', 'r', 's', 'e', 'n', 's', 'i', 't', 'i', 'v', 'e', '\n',
        'h', 'y', 'p', 'e', 'r', 's', 'e', 'n', 's', 'i', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'h', 'y', 'p', 'e', 'r', 's', 'e', 'n', 's', 'i', 't', 'i', 'v', 'i', 't', 'y', '\n',
        'h', 'y', 'p', 'e', 'r', 's', 'o', 'n', 'i', 'c', '\n',
        'h', 'y', 'p', 'e', 'r', 's', 'p', 'a', 'c', 'e', '\n',
        'h', 'y', 'p', 'e', 'r', 's', 'p', 'h', 'e', 'r', 'e', '\n',
        'h', 'y', 'p', 'e', 'r', 't', 'e', 'n', 's', 'i', 'o', 'n', '\n',
        'h', 'y', 'p', 'e', 'r', 't', 'e', 'x', 't', '\n',
        'h', 'y', 'p', 'e', 'r', 't', 'o', 'n', 'i', 'c', '\n',
        'h', 'y', 'p', 'e', 'r', 'v', 'e', 'n', 't', 'i', 'l', 'a', 't', 'e', 'd', '\n',
        'h', 'y', 'p', 'e', 'r', 'v', 'e', 'n', 't', 'i', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'h', 'y', 'p', 'e', 'r', 'v', 'e', 'n', 't', 'i', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'h', 'y', 'p', 'h', 'e', 'n', '\n',
        'h', 'y', 'p', 'h', 'e', 'n', 'a', 't', 'e', '\n',
        'h', 'y', 'p', 'h', 'e', 'n', 'a', 't', 'e', 'd', '\n',
        'h', 'y', 'p', 'h', 'e', 'n', 'a', 't', 'e', 's', '\n',
        'h', 'y', 'p', 'h', 'e', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'h', 'y', 'p', 'h', 'e', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'h', 'y', 'p', 'h', 'e', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'h', 'y', 'p', 'h', 'e', 'n', 'e', 'd', '\n',
        'h', 'y', 'p', 'h', 'e', 'n', 's', '\n',
        'h', 'y', 'p', 'n', 'o', 's', 'i', 's', '\n',
        'h', 'y', 'p', 'n', 'o', 't', 'h', 'e', 'r', 'a', 'p', 'i', 's', 't', 's', '\n',
        'h', 'y', 'p', 'n', 'o', 't', 'h', 'e', 'r', 'a', 'p', 'y', '\n',
        'h', 'y', 'p', 'n', 'o', 't', 'i', 'c', '\n',
        'h', 'y', 'p', 'n', 'o', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'h', 'y', 'p', 'n', 'o', 't', 'i', 's', 'e', '\n',
        'h', 'y', 'p', 'n', 'o', 't', 'i', 's', 'e', 'd', '\n',
        'h', 'y', 'p', 'n', 'o', 't', 'i', 's', 'e', 's', '\n',
        'h', 'y', 'p', 'n', 'o', 't', 'i', 's', 'i', 'n', 'g', '\n',
        'h', 'y', 'p', 'n', 'o', 't', 'i', 's', 'm', '\n',
        'h', 'y', 'p', 'n', 'o', 't', 'i', 's', 't', '\n',
        'h', 'y', 'p', 'o', 'c', 'h', 'o', 'n', 'd', 'r', 'i', 'a', '\n',
        'h', 'y', 'p', 'o', 'c', 'h', 'o', 'n', 'd', 'r', 'i', 'a', 'c', '\n',
        'h', 'y', 'p', 'o', 'c', 'h', 'o', 'n', 'd', 'r', 'i', 'a', 'c', 'a', 'l', '\n',
        'h', 'y', 'p', 'o', 'c', 'h', 'o', 'n', 'd', 'r', 'i', 'a', 'c', 's', '\n',
        'h', 'y', 'p', 'o', 'c', 'r', 'i', 's', 'i', 'e', 's', '\n',
        'h', 'y', 'p', 'o', 'c', 'r', 'i', 's', 'y', '\n',
        'h', 'y', 'p', 'o', 'c', 'r', 'i', 't', 'e', '\n',
        'h', 'y', 'p', 'o', 'c', 'r', 'i', 't', 'e', 's', '\n',
        'h', 'y', 'p', 'o', 'c', 'r', 'i', 't', 'i', 'c', 'a', 'l', '\n',
        'h', 'y', 'p', 'o', 'c', 'r', 'i', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'h', 'y', 'p', 'o', 'd', 'e', 'r', 'm', 'i', 'c', '\n',
        'h', 'y', 'p', 'o', 'g', 'l', 'y', 'c', 'a', 'e', 'm', 'i', 'a', '\n',
        'h', 'y', 'p', 'o', 'g', 'l', 'y', 'c', 'a', 'e', 'm', 'i', 'c', '\n',
        'h', 'y', 'p', 'o', 't', 'e', 'n', 's', 'i', 'o', 'n', '\n',
        'h', 'y', 'p', 'o', 't', 'h', 'a', 'l', 'a', 'm', 'u', 's', '\n',
        'h', 'y', 'p', 'o', 't', 'h', 'e', 'r', 'm', 'i', 'a', '\n',
        'h', 'y', 'p', 'o', 't', 'h', 'e', 's', 'e', 's', '\n',
        'h', 'y', 'p', 'o', 't', 'h', 'e', 's', 'i', 's', '\n',
        'h', 'y', 'p', 'o', 't', 'h', 'e', 's', 'i', 's', 'e', '\n',
        'h', 'y', 'p', 'o', 't', 'h', 'e', 's', 'i', 's', 'e', 'd', '\n',
        'h', 'y', 'p', 'o', 't', 'h', 'e', 's', 'i', 's', 'e', 'r', '\n',
        'h', 'y', 'p', 'o', 't', 'h', 'e', 's', 'i', 's', 'e', 's', '\n',
        'h', 'y', 'p', 'o', 't', 'h', 'e', 's', 'i', 's', 'i', 'n', 'g', '\n',
        'h', 'y', 'p', 'o', 't', 'h', 'e', 't', 'i', 'c', 'a', 'l', '\n',
        'h', 'y', 'p', 'o', 't', 'h', 'e', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'h', 'y', 'p', 'o', 'x', 'i', 'a', '\n',
        'h', 'y', 's', 's', 'o', 'p', '\n',
        'h', 'y', 's', 't', 'e', 'r', 'e', 'c', 't', 'o', 'm', 'y', '\n',
        'h', 'y', 's', 't', 'e', 'r', 'e', 's', 'i', 's', '\n',
        'h', 'y', 's', 't', 'e', 'r', 'i', 'a', '\n',
        'h', 'y', 's', 't', 'e', 'r', 'i', 'c', '\n',
        'h', 'y', 's', 't', 'e', 'r', 'i', 'c', 'a', 'l', '\n',
        'h', 'y', 's', 't', 'e', 'r', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'h', 'y', 's', 't', 'e', 'r', 'i', 'c', 's', '\n',
        'i', 'a', 'm', 'b', 'i', 'c', '\n',
        'i', 'a', 'm', 'b', 'u', 's', '\n',
        'i', 'a', 't', 'r', 'o', 'g', 'e', 'n', 'i', 'c', '\n',
        'i', 'b', 'e', 'r', 'i', 'a', '\n',
        'i', 'b', 'e', 'r', 'i', 'a', 'n', '\n',
        'i', 'b', 'e', 'x', '\n',
        'i', 'b', 'e', 'x', 'e', 's', '\n',
        'i', 'b', 'i', 's', '\n',
        'i', 'b', 'i', 's', 'e', 's', '\n',
        'i', 'b', 's', 'e', 'n', '\n',
        'i', 'c', 'a', 'r', 'u', 's', '\n',
        'i', 'c', 'e', '\n',
        'i', 'c', 'e', 'a', 'g', 'e', '\n',
        'i', 'c', 'e', 'b', 'e', 'r', 'g', '\n',
        'i', 'c', 'e', 'b', 'e', 'r', 'g', 's', '\n',
        'i', 'c', 'e', 'b', 'o', 'x', '\n',
        'i', 'c', 'e', 'c', 'a', 'p', '\n',
        'i', 'c', 'e', 'c', 'o', 'l', 'd', '\n',
        'i', 'c', 'e', 'c', 'r', 'e', 'a', 'm', '\n',
        'i', 'c', 'e', 'd', '\n',
        'i', 'c', 'e', 'l', 'a', 'n', 'd', '\n',
        'i', 'c', 'e', 'm', 'a', 'n', '\n',
        'i', 'c', 'e', 'p', 'a', 'c', 'k', '\n',
        'i', 'c', 'e', 'p', 'i', 'c', 'k', '\n',
        'i', 'c', 'e', 'p', 'i', 'c', 'k', 's', '\n',
        'i', 'c', 'e', 's', '\n',
        'i', 'c', 'e', 's', 'k', 'a', 't', 'e', '\n',
        'i', 'c', 'e', 's', 'k', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'c', 'h', 'n', 'e', 'u', 'm', 'o', 'n', '\n',
        'i', 'c', 'i', 'c', 'l', 'e', '\n',
        'i', 'c', 'i', 'c', 'l', 'e', 's', '\n',
        'i', 'c', 'i', 'e', 'r', '\n',
        'i', 'c', 'i', 'e', 's', 't', '\n',
        'i', 'c', 'i', 'l', 'y', '\n',
        'i', 'c', 'i', 'n', 'e', 's', 's', '\n',
        'i', 'c', 'i', 'n', 'g', '\n',
        'i', 'c', 'i', 'n', 'g', 's', '\n',
        'i', 'c', 'o', 'n', '\n',
        'i', 'c', 'o', 'n', 'i', 'c', '\n',
        'i', 'c', 'o', 'n', 'o', 'c', 'l', 'a', 's', 'm', '\n',
        'i', 'c', 'o', 'n', 'o', 'c', 'l', 'a', 's', 't', '\n',
        'i', 'c', 'o', 'n', 'o', 'c', 'l', 'a', 's', 't', 'i', 'c', '\n',
        'i', 'c', 'o', 'n', 'o', 'c', 'l', 'a', 's', 't', 's', '\n',
        'i', 'c', 'o', 'n', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', '\n',
        'i', 'c', 'o', 'n', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', 'a', 'l', '\n',
        'i', 'c', 'o', 'n', 'o', 'g', 'r', 'a', 'p', 'h', 'y', '\n',
        'i', 'c', 'o', 'n', 's', '\n',
        'i', 'c', 'o', 's', 'a', 'h', 'e', 'd', 'r', 'a', '\n',
        'i', 'c', 'o', 's', 'a', 'h', 'e', 'd', 'r', 'a', 'l', '\n',
        'i', 'c', 'o', 's', 'a', 'h', 'e', 'd', 'r', 'o', 'n', '\n',
        'i', 'c', 'y', '\n',
        'i', 'd', '\n',
        'i', 'd', 'a', 'h', 'o', '\n',
        'i', 'd', 'e', 'a', '\n',
        'i', 'd', 'e', 'a', 'l', '\n',
        'i', 'd', 'e', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'd', 'e', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'd', 'e', 'a', 'l', 'i', 's', 'e', '\n',
        'i', 'd', 'e', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'i', 'd', 'e', 'a', 'l', 'i', 's', 'e', 's', '\n',
        'i', 'd', 'e', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'i', 'd', 'e', 'a', 'l', 'i', 's', 'm', '\n',
        'i', 'd', 'e', 'a', 'l', 'i', 's', 't', '\n',
        'i', 'd', 'e', 'a', 'l', 'i', 's', 't', 'i', 'c', '\n',
        'i', 'd', 'e', 'a', 'l', 'i', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'i', 'd', 'e', 'a', 'l', 'i', 's', 't', 's', '\n',
        'i', 'd', 'e', 'a', 'l', 'i', 't', 'y', '\n',
        'i', 'd', 'e', 'a', 'l', 'l', 'y', '\n',
        'i', 'd', 'e', 'a', 'l', 's', '\n',
        'i', 'd', 'e', 'a', 's', '\n',
        'i', 'd', 'e', 'm', '\n',
        'i', 'd', 'e', 'n', 't', 'i', 'c', 'a', 'l', '\n',
        'i', 'd', 'e', 'n', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'i', 'd', 'e', 'n', 't', 'i', 'f', 'i', 'a', 'b', 'l', 'e', '\n',
        'i', 'd', 'e', 'n', 't', 'i', 'f', 'i', 'a', 'b', 'l', 'y', '\n',
        'i', 'd', 'e', 'n', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'd', 'e', 'n', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'd', 'e', 'n', 't', 'i', 'f', 'i', 'e', 'd', '\n',
        'i', 'd', 'e', 'n', 't', 'i', 'f', 'i', 'e', 'r', '\n',
        'i', 'd', 'e', 'n', 't', 'i', 'f', 'i', 'e', 'r', 's', '\n',
        'i', 'd', 'e', 'n', 't', 'i', 'f', 'i', 'e', 's', '\n',
        'i', 'd', 'e', 'n', 't', 'i', 'f', 'y', '\n',
        'i', 'd', 'e', 'n', 't', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'i', 'd', 'e', 'n', 't', 'i', 't', 'i', 'e', 's', '\n',
        'i', 'd', 'e', 'n', 't', 'i', 't', 'y', '\n',
        'i', 'd', 'e', 'o', 'g', 'r', 'a', 'm', 's', '\n',
        'i', 'd', 'e', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', '\n',
        'i', 'd', 'e', 'o', 'g', 'r', 'a', 'p', 'h', 's', '\n',
        'i', 'd', 'e', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'i', 'd', 'e', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'i', 'd', 'e', 'o', 'l', 'o', 'g', 'i', 'e', 's', '\n',
        'i', 'd', 'e', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'i', 'd', 'e', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'i', 'd', 'e', 'o', 'l', 'o', 'g', 'u', 'e', '\n',
        'i', 'd', 'e', 'o', 'l', 'o', 'g', 'u', 'e', 's', '\n',
        'i', 'd', 'e', 'o', 'l', 'o', 'g', 'y', '\n',
        'i', 'd', 'e', 's', '\n',
        'i', 'd', 'i', 'o', 'c', 'i', 'e', 's', '\n',
        'i', 'd', 'i', 'o', 'c', 'y', '\n',
        'i', 'd', 'i', 'o', 'l', 'e', 'c', 't', '\n',
        'i', 'd', 'i', 'o', 'm', '\n',
        'i', 'd', 'i', 'o', 'm', 'a', 't', 'i', 'c', '\n',
        'i', 'd', 'i', 'o', 'm', 'a', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'i', 'd', 'i', 'o', 'm', 's', '\n',
        'i', 'd', 'i', 'o', 'p', 'a', 't', 'h', 'i', 'c', '\n',
        'i', 'd', 'i', 'o', 's', 'y', 'n', 'c', 'r', 'a', 's', 'i', 'e', 's', '\n',
        'i', 'd', 'i', 'o', 's', 'y', 'n', 'c', 'r', 'a', 's', 'y', '\n',
        'i', 'd', 'i', 'o', 's', 'y', 'n', 'c', 'r', 'a', 't', 'i', 'c', '\n',
        'i', 'd', 'i', 'o', 's', 'y', 'n', 'c', 'r', 'a', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'i', 'd', 'i', 'o', 't', '\n',
        'i', 'd', 'i', 'o', 't', 'i', 'c', '\n',
        'i', 'd', 'i', 'o', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'i', 'd', 'i', 'o', 't', 's', '\n',
        'i', 'd', 'l', 'e', '\n',
        'i', 'd', 'l', 'e', 'd', '\n',
        'i', 'd', 'l', 'e', 'n', 'e', 's', 's', '\n',
        'i', 'd', 'l', 'e', 'r', '\n',
        'i', 'd', 'l', 'e', 'r', 's', '\n',
        'i', 'd', 'l', 'e', 's', '\n',
        'i', 'd', 'l', 'e', 's', 't', '\n',
        'i', 'd', 'l', 'i', 'n', 'g', '\n',
        'i', 'd', 'l', 'y', '\n',
        'i', 'd', 'o', 'l', '\n',
        'i', 'd', 'o', 'l', 'a', 't', 'e', 'r', 's', '\n',
        'i', 'd', 'o', 'l', 'a', 't', 'r', 'o', 'u', 's', '\n',
        'i', 'd', 'o', 'l', 'a', 't', 'r', 'y', '\n',
        'i', 'd', 'o', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'd', 'o', 'l', 'i', 's', 'e', '\n',
        'i', 'd', 'o', 'l', 'i', 's', 'e', 'd', '\n',
        'i', 'd', 'o', 'l', 's', '\n',
        'i', 'd', 's', '\n',
        'i', 'd', 'y', 'l', 'l', '\n',
        'i', 'd', 'y', 'l', 'l', 'i', 'c', '\n',
        'i', 'd', 'y', 'l', 'l', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'i', 'f', '\n',
        'i', 'f', 's', '\n',
        'i', 'g', 'l', 'o', 'o', '\n',
        'i', 'g', 'l', 'o', 'o', 's', '\n',
        'i', 'g', 'l', 'u', '\n',
        'i', 'g', 'n', 'e', 'o', 'u', 's', '\n',
        'i', 'g', 'n', 'i', 't', 'e', '\n',
        'i', 'g', 'n', 'i', 't', 'e', 'd', '\n',
        'i', 'g', 'n', 'i', 't', 'e', 'r', '\n',
        'i', 'g', 'n', 'i', 't', 'e', 's', '\n',
        'i', 'g', 'n', 'i', 't', 'i', 'n', 'g', '\n',
        'i', 'g', 'n', 'i', 't', 'i', 'o', 'n', '\n',
        'i', 'g', 'n', 'o', 'b', 'l', 'e', '\n',
        'i', 'g', 'n', 'o', 'b', 'l', 'y', '\n',
        'i', 'g', 'n', 'o', 'm', 'i', 'n', 'i', 'o', 'u', 's', '\n',
        'i', 'g', 'n', 'o', 'm', 'i', 'n', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'i', 'g', 'n', 'o', 'm', 'i', 'n', 'y', '\n',
        'i', 'g', 'n', 'o', 'r', 'a', 'b', 'l', 'e', '\n',
        'i', 'g', 'n', 'o', 'r', 'a', 'm', 'u', 's', '\n',
        'i', 'g', 'n', 'o', 'r', 'a', 'm', 'u', 's', 'e', 's', '\n',
        'i', 'g', 'n', 'o', 'r', 'a', 'n', 'c', 'e', '\n',
        'i', 'g', 'n', 'o', 'r', 'a', 'n', 't', '\n',
        'i', 'g', 'n', 'o', 'r', 'a', 'n', 't', 'l', 'y', '\n',
        'i', 'g', 'n', 'o', 'r', 'e', '\n',
        'i', 'g', 'n', 'o', 'r', 'e', 'd', '\n',
        'i', 'g', 'n', 'o', 'r', 'e', 's', '\n',
        'i', 'g', 'n', 'o', 'r', 'i', 'n', 'g', '\n',
        'i', 'g', 'u', 'a', 'n', 'a', '\n',
        'i', 'g', 'u', 'a', 'n', 'a', 's', '\n',
        'i', 'l', 'e', 'u', 'm', '\n',
        'i', 'l', 'i', 'a', 'd', '\n',
        'i', 'l', 'k', '\n',
        'i', 'l', 'l', '\n',
        'i', 'l', 'l', 'a', 'd', 'v', 'i', 's', 'e', 'd', '\n',
        'i', 'l', 'l', 'b', 'e', 'h', 'a', 'v', 'e', 'd', '\n',
        'i', 'l', 'l', 'c', 'o', 'n', 'c', 'e', 'i', 'v', 'e', 'd', '\n',
        'i', 'l', 'l', 'd', 'e', 'f', 'i', 'n', 'e', 'd', '\n',
        'i', 'l', 'l', 'e', 'g', 'a', 'l', '\n',
        'i', 'l', 'l', 'e', 'g', 'a', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'i', 'l', 'l', 'e', 'g', 'a', 'l', 'i', 't', 'y', '\n',
        'i', 'l', 'l', 'e', 'g', 'a', 'l', 'l', 'y', '\n',
        'i', 'l', 'l', 'e', 'g', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'l', 'l', 'e', 'g', 'i', 'b', 'l', 'e', '\n',
        'i', 'l', 'l', 'e', 'g', 'i', 'b', 'l', 'y', '\n',
        'i', 'l', 'l', 'e', 'g', 'i', 't', 'i', 'm', 'a', 'c', 'y', '\n',
        'i', 'l', 'l', 'e', 'g', 'i', 't', 'i', 'm', 'a', 't', 'e', '\n',
        'i', 'l', 'l', 'e', 'g', 'i', 't', 'i', 'm', 'a', 't', 'e', 'l', 'y', '\n',
        'i', 'l', 'l', 'e', 'q', 'u', 'i', 'p', 'p', 'e', 'd', '\n',
        'i', 'l', 'l', 'f', 'a', 't', 'e', 'd', '\n',
        'i', 'l', 'l', 'f', 'a', 'v', 'o', 'u', 'r', 'e', 'd', '\n',
        'i', 'l', 'l', 'h', 'u', 'm', 'o', 'u', 'r', 'e', 'd', '\n',
        'i', 'l', 'l', 'i', 'b', 'e', 'r', 'a', 'l', '\n',
        'i', 'l', 'l', 'i', 'c', 'i', 't', '\n',
        'i', 'l', 'l', 'i', 'c', 'i', 't', 'l', 'y', '\n',
        'i', 'l', 'l', 'i', 'm', 'i', 't', 'a', 'b', 'l', 'e', '\n',
        'i', 'l', 'l', 'i', 'n', 'f', 'o', 'r', 'm', 'e', 'd', '\n',
        'i', 'l', 'l', 'i', 'n', 'o', 'i', 's', '\n',
        'i', 'l', 'l', 'i', 'q', 'u', 'i', 'd', '\n',
        'i', 'l', 'l', 'i', 't', 'e', 'r', 'a', 'c', 'y', '\n',
        'i', 'l', 'l', 'i', 't', 'e', 'r', 'a', 't', 'e', '\n',
        'i', 'l', 'l', 'i', 't', 'e', 'r', 'a', 't', 'e', 's', '\n',
        'i', 'l', 'l', 'm', 'a', 'n', 'n', 'e', 'r', 'e', 'd', '\n',
        'i', 'l', 'l', 'n', 'e', 's', 's', '\n',
        'i', 'l', 'l', 'n', 'e', 's', 's', 'e', 's', '\n',
        'i', 'l', 'l', 'o', 'g', 'i', 'c', '\n',
        'i', 'l', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'i', 'l', 'l', 'o', 'g', 'i', 'c', 'a', 'l', 'i', 't', 'y', '\n',
        'i', 'l', 'l', 'o', 'g', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'i', 'l', 'l', 's', '\n',
        'i', 'l', 'l', 't', 'e', 'm', 'p', 'e', 'r', 'e', 'd', '\n',
        'i', 'l', 'l', 't', 'r', 'e', 'a', 't', 'e', 'd', '\n',
        'i', 'l', 'l', 'u', 'm', 'i', 'n', 'a', 'n', 't', '\n',
        'i', 'l', 'l', 'u', 'm', 'i', 'n', 'a', 't', 'e', '\n',
        'i', 'l', 'l', 'u', 'm', 'i', 'n', 'a', 't', 'e', 'd', '\n',
        'i', 'l', 'l', 'u', 'm', 'i', 'n', 'a', 't', 'e', 's', '\n',
        'i', 'l', 'l', 'u', 'm', 'i', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'l', 'l', 'u', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'l', 'l', 'u', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'l', 'l', 'u', 'm', 'i', 'n', 'e', '\n',
        'i', 'l', 'l', 'u', 's', 'i', 'o', 'n', '\n',
        'i', 'l', 'l', 'u', 's', 'i', 'o', 'n', 'i', 's', 't', '\n',
        'i', 'l', 'l', 'u', 's', 'i', 'o', 'n', 'i', 's', 't', 's', '\n',
        'i', 'l', 'l', 'u', 's', 'i', 'o', 'n', 's', '\n',
        'i', 'l', 'l', 'u', 's', 'i', 'v', 'e', '\n',
        'i', 'l', 'l', 'u', 's', 'o', 'r', 'y', '\n',
        'i', 'l', 'l', 'u', 's', 't', 'r', 'a', 't', 'e', '\n',
        'i', 'l', 'l', 'u', 's', 't', 'r', 'a', 't', 'e', 'd', '\n',
        'i', 'l', 'l', 'u', 's', 't', 'r', 'a', 't', 'e', 's', '\n',
        'i', 'l', 'l', 'u', 's', 't', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'l', 'l', 'u', 's', 't', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'l', 'l', 'u', 's', 't', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'l', 'l', 'u', 's', 't', 'r', 'a', 't', 'i', 'v', 'e', '\n',
        'i', 'l', 'l', 'u', 's', 't', 'r', 'a', 't', 'o', 'r', '\n',
        'i', 'l', 'l', 'u', 's', 't', 'r', 'a', 't', 'o', 'r', 's', '\n',
        'i', 'l', 'l', 'u', 's', 't', 'r', 'i', 'o', 'u', 's', '\n',
        'i', 'l', 'm', 'e', 'n', 'i', 't', 'e', '\n',
        'i', 'm', '\n',
        'i', 'm', 'a', 'g', 'e', '\n',
        'i', 'm', 'a', 'g', 'e', 'd', '\n',
        'i', 'm', 'a', 'g', 'e', 'r', 'y', '\n',
        'i', 'm', 'a', 'g', 'e', 's', '\n',
        'i', 'm', 'a', 'g', 'i', 'n', 'a', 'b', 'l', 'e', '\n',
        'i', 'm', 'a', 'g', 'i', 'n', 'a', 'r', 'y', '\n',
        'i', 'm', 'a', 'g', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'm', 'a', 'g', 'i', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'm', 'a', 'g', 'i', 'n', 'a', 't', 'i', 'v', 'e', '\n',
        'i', 'm', 'a', 'g', 'i', 'n', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'i', 'm', 'a', 'g', 'i', 'n', 'e', '\n',
        'i', 'm', 'a', 'g', 'i', 'n', 'e', 'd', '\n',
        'i', 'm', 'a', 'g', 'i', 'n', 'e', 's', '\n',
        'i', 'm', 'a', 'g', 'i', 'n', 'g', '\n',
        'i', 'm', 'a', 'g', 'i', 'n', 'i', 'n', 'g', '\n',
        'i', 'm', 'a', 'g', 'i', 'n', 'i', 'n', 'g', 's', '\n',
        'i', 'm', 'a', 'g', 'o', '\n',
        'i', 'm', 'a', 'm', '\n',
        'i', 'm', 'a', 'm', 's', '\n',
        'i', 'm', 'b', 'a', 'l', 'a', 'n', 'c', 'e', '\n',
        'i', 'm', 'b', 'a', 'l', 'a', 'n', 'c', 'e', 'd', '\n',
        'i', 'm', 'b', 'a', 'l', 'a', 'n', 'c', 'e', 's', '\n',
        'i', 'm', 'b', 'e', 'c', 'i', 'l', 'e', '\n',
        'i', 'm', 'b', 'e', 'c', 'i', 'l', 'e', 's', '\n',
        'i', 'm', 'b', 'e', 'c', 'i', 'l', 'i', 'c', '\n',
        'i', 'm', 'b', 'e', 'c', 'i', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'i', 'm', 'b', 'e', 'c', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'm', 'b', 'e', 'd', 'd', 'e', 'd', '\n',
        'i', 'm', 'b', 'e', 'd', 's', '\n',
        'i', 'm', 'b', 'i', 'b', 'e', '\n',
        'i', 'm', 'b', 'i', 'b', 'e', 'd', '\n',
        'i', 'm', 'b', 'i', 'b', 'e', 'r', '\n',
        'i', 'm', 'b', 'i', 'b', 'e', 'r', 's', '\n',
        'i', 'm', 'b', 'i', 'b', 'i', 'n', 'g', '\n',
        'i', 'm', 'b', 'r', 'o', 'g', 'l', 'i', 'o', '\n',
        'i', 'm', 'b', 'u', 'e', '\n',
        'i', 'm', 'b', 'u', 'e', 'd', '\n',
        'i', 'm', 'i', 't', 'a', 't', 'e', '\n',
        'i', 'm', 'i', 't', 'a', 't', 'e', 'd', '\n',
        'i', 'm', 'i', 't', 'a', 't', 'e', 's', '\n',
        'i', 'm', 'i', 't', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'm', 'i', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'm', 'i', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'm', 'i', 't', 'a', 't', 'i', 'v', 'e', '\n',
        'i', 'm', 'i', 't', 'a', 't', 'o', 'r', '\n',
        'i', 'm', 'i', 't', 'a', 't', 'o', 'r', 's', '\n',
        'i', 'm', 'm', 'a', 'c', 'u', 'l', 'a', 't', 'e', '\n',
        'i', 'm', 'm', 'a', 'c', 'u', 'l', 'a', 't', 'e', 'l', 'y', '\n',
        'i', 'm', 'm', 'a', 'n', 'e', 'n', 'c', 'e', '\n',
        'i', 'm', 'm', 'a', 'n', 'e', 'n', 't', '\n',
        'i', 'm', 'm', 'a', 'n', 'e', 'n', 't', 'l', 'y', '\n',
        'i', 'm', 'm', 'a', 't', 'e', 'r', 'i', 'a', 'l', '\n',
        'i', 'm', 'm', 'a', 't', 'u', 'r', 'e', '\n',
        'i', 'm', 'm', 'a', 't', 'u', 'r', 'e', 'l', 'y', '\n',
        'i', 'm', 'm', 'a', 't', 'u', 'r', 'i', 't', 'y', '\n',
        'i', 'm', 'm', 'e', 'a', 's', 'u', 'r', 'a', 'b', 'l', 'e', '\n',
        'i', 'm', 'm', 'e', 'a', 's', 'u', 'r', 'a', 'b', 'l', 'y', '\n',
        'i', 'm', 'm', 'e', 'd', 'i', 'a', 'c', 'y', '\n',
        'i', 'm', 'm', 'e', 'd', 'i', 'a', 't', 'e', '\n',
        'i', 'm', 'm', 'e', 'd', 'i', 'a', 't', 'e', 'l', 'y', '\n',
        'i', 'm', 'm', 'e', 'd', 'i', 'a', 't', 'e', 'n', 'e', 's', 's', '\n',
        'i', 'm', 'm', 'e', 'm', 'o', 'r', 'i', 'a', 'l', '\n',
        'i', 'm', 'm', 'e', 'n', 's', 'e', '\n',
        'i', 'm', 'm', 'e', 'n', 's', 'e', 'l', 'y', '\n',
        'i', 'm', 'm', 'e', 'n', 's', 'e', 'n', 'e', 's', 's', '\n',
        'i', 'm', 'm', 'e', 'n', 's', 'i', 't', 'i', 'e', 's', '\n',
        'i', 'm', 'm', 'e', 'n', 's', 'i', 't', 'y', '\n',
        'i', 'm', 'm', 'e', 'r', 's', 'e', '\n',
        'i', 'm', 'm', 'e', 'r', 's', 'e', 'd', '\n',
        'i', 'm', 'm', 'e', 'r', 's', 'e', 's', '\n',
        'i', 'm', 'm', 'e', 'r', 's', 'i', 'n', 'g', '\n',
        'i', 'm', 'm', 'e', 'r', 's', 'i', 'o', 'n', '\n',
        'i', 'm', 'm', 'i', 'g', 'r', 'a', 'n', 't', '\n',
        'i', 'm', 'm', 'i', 'g', 'r', 'a', 'n', 't', 's', '\n',
        'i', 'm', 'm', 'i', 'g', 'r', 'a', 't', 'e', '\n',
        'i', 'm', 'm', 'i', 'g', 'r', 'a', 't', 'e', 'd', '\n',
        'i', 'm', 'm', 'i', 'g', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'm', 'm', 'i', 'g', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'm', 'm', 'i', 'g', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'm', 'm', 'i', 'n', 'e', 'n', 'c', 'e', '\n',
        'i', 'm', 'm', 'i', 'n', 'e', 'n', 't', '\n',
        'i', 'm', 'm', 'i', 'n', 'e', 'n', 't', 'l', 'y', '\n',
        'i', 'm', 'm', 'i', 's', 'c', 'i', 'b', 'l', 'e', '\n',
        'i', 'm', 'm', 'o', 'b', 'i', 'l', 'e', '\n',
        'i', 'm', 'm', 'o', 'b', 'i', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'm', 'm', 'o', 'b', 'i', 'l', 'i', 's', 'e', '\n',
        'i', 'm', 'm', 'o', 'b', 'i', 'l', 'i', 's', 'e', 'd', '\n',
        'i', 'm', 'm', 'o', 'b', 'i', 'l', 'i', 's', 'e', 'r', '\n',
        'i', 'm', 'm', 'o', 'b', 'i', 'l', 'i', 's', 'e', 's', '\n',
        'i', 'm', 'm', 'o', 'b', 'i', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'i', 'm', 'm', 'o', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'm', 'm', 'o', 'd', 'e', 'r', 'a', 't', 'e', '\n',
        'i', 'm', 'm', 'o', 'd', 'e', 'r', 'a', 't', 'e', 'l', 'y', '\n',
        'i', 'm', 'm', 'o', 'd', 'e', 's', 't', '\n',
        'i', 'm', 'm', 'o', 'l', 'a', 't', 'e', '\n',
        'i', 'm', 'm', 'o', 'l', 'a', 't', 'e', 'd', '\n',
        'i', 'm', 'm', 'o', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'm', 'm', 'o', 'r', 'a', 'l', '\n',
        'i', 'm', 'm', 'o', 'r', 'a', 'l', 'i', 't', 'y', '\n',
        'i', 'm', 'm', 'o', 'r', 'a', 'l', 'l', 'y', '\n',
        'i', 'm', 'm', 'o', 'r', 't', 'a', 'l', '\n',
        'i', 'm', 'm', 'o', 'r', 't', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'i', 'm', 'm', 'o', 'r', 't', 'a', 'l', 'i', 't', 'y', '\n',
        'i', 'm', 'm', 'o', 'r', 't', 'a', 'l', 'l', 'y', '\n',
        'i', 'm', 'm', 'o', 'r', 't', 'a', 'l', 's', '\n',
        'i', 'm', 'm', 'o', 'v', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'm', 'm', 'o', 'v', 'a', 'b', 'l', 'e', '\n',
        'i', 'm', 'm', 'o', 'v', 'e', 'a', 'b', 'l', 'e', '\n',
        'i', 'm', 'm', 'u', 'n', 'e', '\n',
        'i', 'm', 'm', 'u', 'n', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'm', 'm', 'u', 'n', 'i', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'm', 'm', 'u', 'n', 'i', 's', 'e', '\n',
        'i', 'm', 'm', 'u', 'n', 'i', 's', 'e', 'd', '\n',
        'i', 'm', 'm', 'u', 'n', 'i', 's', 'e', 's', '\n',
        'i', 'm', 'm', 'u', 'n', 'i', 't', 'i', 'e', 's', '\n',
        'i', 'm', 'm', 'u', 'n', 'i', 't', 'y', '\n',
        'i', 'm', 'm', 'u', 'n', 'o', 'a', 's', 's', 'a', 'y', '\n',
        'i', 'm', 'm', 'u', 'n', 'o', 'c', 'o', 'm', 'p', 'r', 'o', 'm', 'i', 's', 'e', 'd', '\n',
        'i', 'm', 'm', 'u', 'n', 'o', 'd', 'e', 'f', 'i', 'c', 'i', 'e', 'n', 'c', 'y', '\n',
        'i', 'm', 'm', 'u', 'n', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'i', 'm', 'm', 'u', 'n', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'i', 'm', 'm', 'u', 'n', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'i', 'm', 'm', 'u', 'n', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'i', 'm', 'm', 'u', 'n', 'o', 'l', 'o', 'g', 'y', '\n',
        'i', 'm', 'm', 'u', 'n', 'o', 's', 'u', 'p', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', '\n',
        'i', 'm', 'm', 'u', 'n', 'o', 's', 'u', 'p', 'p', 'r', 'e', 's', 's', 'i', 'v', 'e', '\n',
        'i', 'm', 'm', 'u', 'r', 'e', 'd', '\n',
        'i', 'm', 'm', 'u', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'm', 'm', 'u', 't', 'a', 'b', 'l', 'e', '\n',
        'i', 'm', 'm', 'u', 't', 'a', 'b', 'l', 'y', '\n',
        'i', 'm', 'p', '\n',
        'i', 'm', 'p', 'a', 'c', 't', '\n',
        'i', 'm', 'p', 'a', 'c', 't', 'e', 'd', '\n',
        'i', 'm', 'p', 'a', 'c', 't', 'i', 'n', 'g', '\n',
        'i', 'm', 'p', 'a', 'c', 't', 'i', 'o', 'n', '\n',
        'i', 'm', 'p', 'a', 'c', 't', 's', '\n',
        'i', 'm', 'p', 'a', 'i', 'r', '\n',
        'i', 'm', 'p', 'a', 'i', 'r', 'e', 'd', '\n',
        'i', 'm', 'p', 'a', 'i', 'r', 'i', 'n', 'g', '\n',
        'i', 'm', 'p', 'a', 'i', 'r', 'm', 'e', 'n', 't', '\n',
        'i', 'm', 'p', 'a', 'i', 'r', 'm', 'e', 'n', 't', 's', '\n',
        'i', 'm', 'p', 'a', 'i', 'r', 's', '\n',
        'i', 'm', 'p', 'a', 'l', 'a', '\n',
        'i', 'm', 'p', 'a', 'l', 'a', 's', '\n',
        'i', 'm', 'p', 'a', 'l', 'e', '\n',
        'i', 'm', 'p', 'a', 'l', 'e', 'd', '\n',
        'i', 'm', 'p', 'a', 'l', 'e', 'r', '\n',
        'i', 'm', 'p', 'a', 'l', 'e', 's', '\n',
        'i', 'm', 'p', 'a', 'l', 'i', 'n', 'g', '\n',
        'i', 'm', 'p', 'a', 'l', 'p', 'a', 'b', 'l', 'e', '\n',
        'i', 'm', 'p', 'a', 'r', 't', '\n',
        'i', 'm', 'p', 'a', 'r', 't', 'e', 'd', '\n',
        'i', 'm', 'p', 'a', 'r', 't', 'i', 'a', 'l', '\n',
        'i', 'm', 'p', 'a', 'r', 't', 'i', 'a', 'l', 'i', 't', 'y', '\n',
        'i', 'm', 'p', 'a', 'r', 't', 'i', 'a', 'l', 'l', 'y', '\n',
        'i', 'm', 'p', 'a', 'r', 't', 'i', 'n', 'g', '\n',
        'i', 'm', 'p', 'a', 'r', 't', 's', '\n',
        'i', 'm', 'p', 'a', 's', 's', 'a', 'b', 'l', 'e', '\n',
        'i', 'm', 'p', 'a', 's', 's', 'e', '\n',
        'i', 'm', 'p', 'a', 's', 's', 'i', 'o', 'n', 'e', 'd', '\n',
        'i', 'm', 'p', 'a', 's', 's', 'i', 'v', 'e', '\n',
        'i', 'm', 'p', 'a', 's', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'i', 'm', 'p', 'a', 's', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'i', 'm', 'p', 'a', 's', 's', 'i', 'v', 'i', 't', 'y', '\n',
        'i', 'm', 'p', 'a', 't', 'i', 'e', 'n', 'c', 'e', '\n',
        'i', 'm', 'p', 'a', 't', 'i', 'e', 'n', 't', '\n',
        'i', 'm', 'p', 'a', 't', 'i', 'e', 'n', 't', 'l', 'y', '\n',
        'i', 'm', 'p', 'e', 'a', 'c', 'h', '\n',
        'i', 'm', 'p', 'e', 'a', 'c', 'h', 'e', 'd', '\n',
        'i', 'm', 'p', 'e', 'a', 'c', 'h', 'e', 's', '\n',
        'i', 'm', 'p', 'e', 'a', 'c', 'h', 'm', 'e', 'n', 't', '\n',
        'i', 'm', 'p', 'e', 'a', 'c', 'h', 'm', 'e', 'n', 't', 's', '\n',
        'i', 'm', 'p', 'e', 'c', 'c', 'a', 'b', 'l', 'e', '\n',
        'i', 'm', 'p', 'e', 'c', 'c', 'a', 'b', 'l', 'y', '\n',
        'i', 'm', 'p', 'e', 'c', 'u', 'n', 'i', 'o', 'u', 's', '\n',
        'i', 'm', 'p', 'e', 'd', 'a', 'n', 'c', 'e', '\n',
        'i', 'm', 'p', 'e', 'd', 'e', '\n',
        'i', 'm', 'p', 'e', 'd', 'e', 'd', '\n',
        'i', 'm', 'p', 'e', 'd', 'e', 's', '\n',
        'i', 'm', 'p', 'e', 'd', 'i', 'm', 'e', 'n', 't', '\n',
        'i', 'm', 'p', 'e', 'd', 'i', 'm', 'e', 'n', 't', 'a', '\n',
        'i', 'm', 'p', 'e', 'd', 'i', 'm', 'e', 'n', 't', 's', '\n',
        'i', 'm', 'p', 'e', 'd', 'i', 'n', 'g', '\n',
        'i', 'm', 'p', 'e', 'l', '\n',
        'i', 'm', 'p', 'e', 'l', 'l', 'e', 'd', '\n',
        'i', 'm', 'p', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'i', 'm', 'p', 'e', 'l', 's', '\n',
        'i', 'm', 'p', 'e', 'n', 'd', '\n',
        'i', 'm', 'p', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'i', 'm', 'p', 'e', 'n', 'e', 't', 'r', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'm', 'p', 'e', 'n', 'e', 't', 'r', 'a', 'b', 'l', 'e', '\n',
        'i', 'm', 'p', 'e', 'n', 'e', 't', 'r', 'a', 'b', 'l', 'y', '\n',
        'i', 'm', 'p', 'e', 'r', 'a', 't', 'i', 'v', 'e', '\n',
        'i', 'm', 'p', 'e', 'r', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'i', 'm', 'p', 'e', 'r', 'a', 't', 'i', 'v', 'e', 's', '\n',
        'i', 'm', 'p', 'e', 'r', 'c', 'e', 'p', 't', 'i', 'b', 'l', 'e', '\n',
        'i', 'm', 'p', 'e', 'r', 'c', 'e', 'p', 't', 'i', 'b', 'l', 'y', '\n',
        'i', 'm', 'p', 'e', 'r', 'f', 'e', 'c', 't', '\n',
        'i', 'm', 'p', 'e', 'r', 'f', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'i', 'm', 'p', 'e', 'r', 'f', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'm', 'p', 'e', 'r', 'f', 'e', 'c', 't', 'l', 'y', '\n',
        'i', 'm', 'p', 'e', 'r', 'i', 'a', 'l', '\n',
        'i', 'm', 'p', 'e', 'r', 'i', 'a', 'l', 'i', 's', 'm', '\n',
        'i', 'm', 'p', 'e', 'r', 'i', 'a', 'l', 'i', 's', 't', '\n',
        'i', 'm', 'p', 'e', 'r', 'i', 'a', 'l', 'i', 's', 't', 'i', 'c', '\n',
        'i', 'm', 'p', 'e', 'r', 'i', 'a', 'l', 'i', 's', 't', 's', '\n',
        'i', 'm', 'p', 'e', 'r', 'i', 'a', 'l', 'l', 'y', '\n',
        'i', 'm', 'p', 'e', 'r', 'i', 'l', '\n',
        'i', 'm', 'p', 'e', 'r', 'i', 'l', 'l', 'e', 'd', '\n',
        'i', 'm', 'p', 'e', 'r', 'i', 'o', 'u', 's', '\n',
        'i', 'm', 'p', 'e', 'r', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'i', 'm', 'p', 'e', 'r', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'i', 'm', 'p', 'e', 'r', 'i', 's', 'h', 'a', 'b', 'l', 'e', '\n',
        'i', 'm', 'p', 'e', 'r', 'i', 'u', 'm', '\n',
        'i', 'm', 'p', 'e', 'r', 'm', 'a', 'n', 'e', 'n', 'c', 'e', '\n',
        'i', 'm', 'p', 'e', 'r', 'm', 'a', 'n', 'e', 'n', 't', '\n',
        'i', 'm', 'p', 'e', 'r', 'm', 'e', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'm', 'p', 'e', 'r', 'm', 'e', 'a', 'b', 'l', 'e', '\n',
        'i', 'm', 'p', 'e', 'r', 'm', 'i', 's', 's', 'i', 'b', 'l', 'e', '\n',
        'i', 'm', 'p', 'e', 'r', 's', 'o', 'n', 'a', 'l', '\n',
        'i', 'm', 'p', 'e', 'r', 's', 'o', 'n', 'a', 'l', 'i', 't', 'y', '\n',
        'i', 'm', 'p', 'e', 'r', 's', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'i', 'm', 'p', 'e', 'r', 's', 'o', 'n', 'a', 't', 'e', '\n',
        'i', 'm', 'p', 'e', 'r', 's', 'o', 'n', 'a', 't', 'e', 'd', '\n',
        'i', 'm', 'p', 'e', 'r', 's', 'o', 'n', 'a', 't', 'e', 's', '\n',
        'i', 'm', 'p', 'e', 'r', 's', 'o', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'm', 'p', 'e', 'r', 's', 'o', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'm', 'p', 'e', 'r', 's', 'o', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'm', 'p', 'e', 'r', 's', 'o', 'n', 'a', 't', 'o', 'r', '\n',
        'i', 'm', 'p', 'e', 'r', 's', 'o', 'n', 'a', 't', 'o', 'r', 's', '\n',
        'i', 'm', 'p', 'e', 'r', 't', 'i', 'n', 'e', 'n', 'c', 'e', '\n',
        'i', 'm', 'p', 'e', 'r', 't', 'i', 'n', 'e', 'n', 't', '\n',
        'i', 'm', 'p', 'e', 'r', 't', 'i', 'n', 'e', 'n', 't', 'l', 'y', '\n',
        'i', 'm', 'p', 'e', 'r', 't', 'u', 'r', 'b', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'm', 'p', 'e', 'r', 't', 'u', 'r', 'b', 'a', 'b', 'l', 'e', '\n',
        'i', 'm', 'p', 'e', 'r', 't', 'u', 'r', 'b', 'a', 'b', 'l', 'y', '\n',
        'i', 'm', 'p', 'e', 'r', 'v', 'i', 'o', 'u', 's', '\n',
        'i', 'm', 'p', 'e', 't', 'u', 'o', 's', 'i', 't', 'y', '\n',
        'i', 'm', 'p', 'e', 't', 'u', 'o', 'u', 's', '\n',
        'i', 'm', 'p', 'e', 't', 'u', 'o', 'u', 's', 'l', 'y', '\n',
        'i', 'm', 'p', 'e', 't', 'u', 's', '\n',
        'i', 'm', 'p', 'i', '\n',
        'i', 'm', 'p', 'i', 'e', 't', 'y', '\n',
        'i', 'm', 'p', 'i', 'n', 'g', 'e', '\n',
        'i', 'm', 'p', 'i', 'n', 'g', 'e', 'd', '\n',
        'i', 'm', 'p', 'i', 'n', 'g', 'e', 'm', 'e', 'n', 't', '\n',
        'i', 'm', 'p', 'i', 'n', 'g', 'e', 's', '\n',
        'i', 'm', 'p', 'i', 'n', 'g', 'i', 'n', 'g', '\n',
        'i', 'm', 'p', 'i', 'o', 'u', 's', '\n',
        'i', 'm', 'p', 'i', 's', 'h', '\n',
        'i', 'm', 'p', 'i', 's', 'h', 'l', 'y', '\n',
        'i', 'm', 'p', 'i', 's', 'h', 'n', 'e', 's', 's', '\n',
        'i', 'm', 'p', 'l', 'a', 'c', 'a', 'b', 'l', 'e', '\n',
        'i', 'm', 'p', 'l', 'a', 'c', 'a', 'b', 'l', 'y', '\n',
        'i', 'm', 'p', 'l', 'a', 'n', 't', '\n',
        'i', 'm', 'p', 'l', 'a', 'n', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'm', 'p', 'l', 'a', 'n', 't', 'e', 'd', '\n',
        'i', 'm', 'p', 'l', 'a', 'n', 't', 'i', 'n', 'g', '\n',
        'i', 'm', 'p', 'l', 'a', 'n', 't', 's', '\n',
        'i', 'm', 'p', 'l', 'a', 'u', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'm', 'p', 'l', 'a', 'u', 's', 'i', 'b', 'l', 'e', '\n',
        'i', 'm', 'p', 'l', 'a', 'u', 's', 'i', 'b', 'l', 'y', '\n',
        'i', 'm', 'p', 'l', 'e', 'm', 'e', 'n', 't', '\n',
        'i', 'm', 'p', 'l', 'e', 'm', 'e', 'n', 't', 'a', 'b', 'l', 'e', '\n',
        'i', 'm', 'p', 'l', 'e', 'm', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'm', 'p', 'l', 'e', 'm', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'm', 'p', 'l', 'e', 'm', 'e', 'n', 't', 'e', 'd', '\n',
        'i', 'm', 'p', 'l', 'e', 'm', 'e', 'n', 't', 'e', 'r', '\n',
        'i', 'm', 'p', 'l', 'e', 'm', 'e', 'n', 't', 'e', 'r', 's', '\n',
        'i', 'm', 'p', 'l', 'e', 'm', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'i', 'm', 'p', 'l', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'i', 'm', 'p', 'l', 'i', 'c', 'a', 't', 'e', '\n',
        'i', 'm', 'p', 'l', 'i', 'c', 'a', 't', 'e', 'd', '\n',
        'i', 'm', 'p', 'l', 'i', 'c', 'a', 't', 'e', 's', '\n',
        'i', 'm', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'm', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'm', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'm', 'p', 'l', 'i', 'c', 'i', 't', '\n',
        'i', 'm', 'p', 'l', 'i', 'c', 'i', 't', 'l', 'y', '\n',
        'i', 'm', 'p', 'l', 'i', 'e', 'd', '\n',
        'i', 'm', 'p', 'l', 'i', 'e', 'd', 'l', 'y', '\n',
        'i', 'm', 'p', 'l', 'i', 'e', 's', '\n',
        'i', 'm', 'p', 'l', 'o', 'd', 'e', '\n',
        'i', 'm', 'p', 'l', 'o', 'd', 'e', 'd', '\n',
        'i', 'm', 'p', 'l', 'o', 'd', 'e', 's', '\n',
        'i', 'm', 'p', 'l', 'o', 'd', 'i', 'n', 'g', '\n',
        'i', 'm', 'p', 'l', 'o', 'r', 'e', '\n',
        'i', 'm', 'p', 'l', 'o', 'r', 'e', 'd', '\n',
        'i', 'm', 'p', 'l', 'o', 'r', 'e', 's', '\n',
        'i', 'm', 'p', 'l', 'o', 'r', 'i', 'n', 'g', '\n',
        'i', 'm', 'p', 'l', 'o', 'r', 'i', 'n', 'g', 'l', 'y', '\n',
        'i', 'm', 'p', 'l', 'o', 's', 'i', 'o', 'n', '\n',
        'i', 'm', 'p', 'l', 'y', '\n',
        'i', 'm', 'p', 'l', 'y', 'i', 'n', 'g', '\n',
        'i', 'm', 'p', 'o', 'l', 'i', 't', 'e', '\n',
        'i', 'm', 'p', 'o', 'l', 'i', 't', 'e', 'n', 'e', 's', 's', '\n',
        'i', 'm', 'p', 'o', 'l', 'i', 't', 'i', 'c', '\n',
        'i', 'm', 'p', 'o', 'n', 'd', 'e', 'r', 'a', 'b', 'l', 'e', '\n',
        'i', 'm', 'p', 'o', 'n', 'd', 'e', 'r', 'a', 'b', 'l', 'e', 's', '\n',
        'i', 'm', 'p', 'o', 'r', 't', '\n',
        'i', 'm', 'p', 'o', 'r', 't', 'a', 'b', 'l', 'e', '\n',
        'i', 'm', 'p', 'o', 'r', 't', 'a', 'n', 'c', 'e', '\n',
        'i', 'm', 'p', 'o', 'r', 't', 'a', 'n', 't', '\n',
        'i', 'm', 'p', 'o', 'r', 't', 'a', 'n', 't', 'l', 'y', '\n',
        'i', 'm', 'p', 'o', 'r', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'm', 'p', 'o', 'r', 't', 'e', 'd', '\n',
        'i', 'm', 'p', 'o', 'r', 't', 'e', 'r', '\n',
        'i', 'm', 'p', 'o', 'r', 't', 'e', 'r', 's', '\n',
        'i', 'm', 'p', 'o', 'r', 't', 'i', 'n', 'g', '\n',
        'i', 'm', 'p', 'o', 'r', 't', 's', '\n',
        'i', 'm', 'p', 'o', 'r', 't', 'u', 'n', 'a', 't', 'e', '\n',
        'i', 'm', 'p', 'o', 'r', 't', 'u', 'n', 'a', 't', 'e', 'l', 'y', '\n',
        'i', 'm', 'p', 'o', 'r', 't', 'u', 'n', 'e', '\n',
        'i', 'm', 'p', 'o', 'r', 't', 'u', 'n', 'e', 'd', '\n',
        'i', 'm', 'p', 'o', 'r', 't', 'u', 'n', 'i', 't', 'y', '\n',
        'i', 'm', 'p', 'o', 's', 'a', 'b', 'l', 'e', '\n',
        'i', 'm', 'p', 'o', 's', 'e', '\n',
        'i', 'm', 'p', 'o', 's', 'e', 'd', '\n',
        'i', 'm', 'p', 'o', 's', 'e', 's', '\n',
        'i', 'm', 'p', 'o', 's', 'i', 'n', 'g', '\n',
        'i', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', '\n',
        'i', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'm', 'p', 'o', 's', 's', 'i', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'i', 'm', 'p', 'o', 's', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'm', 'p', 'o', 's', 's', 'i', 'b', 'l', 'e', '\n',
        'i', 'm', 'p', 'o', 's', 's', 'i', 'b', 'l', 'y', '\n',
        'i', 'm', 'p', 'o', 's', 't', 'e', 'r', '\n',
        'i', 'm', 'p', 'o', 's', 't', 'e', 'r', 's', '\n',
        'i', 'm', 'p', 'o', 's', 't', 'o', 'r', '\n',
        'i', 'm', 'p', 'o', 's', 't', 'o', 'r', 's', '\n',
        'i', 'm', 'p', 'o', 't', 'e', 'n', 'c', 'e', '\n',
        'i', 'm', 'p', 'o', 't', 'e', 'n', 'c', 'y', '\n',
        'i', 'm', 'p', 'o', 't', 'e', 'n', 't', '\n',
        'i', 'm', 'p', 'o', 't', 'e', 'n', 't', 'l', 'y', '\n',
        'i', 'm', 'p', 'o', 'u', 'n', 'd', '\n',
        'i', 'm', 'p', 'o', 'u', 'n', 'd', 'e', 'd', '\n',
        'i', 'm', 'p', 'o', 'u', 'n', 'd', 'i', 'n', 'g', '\n',
        'i', 'm', 'p', 'o', 'v', 'e', 'r', 'i', 's', 'h', '\n',
        'i', 'm', 'p', 'o', 'v', 'e', 'r', 'i', 's', 'h', 'e', 'd', '\n',
        'i', 'm', 'p', 'o', 'v', 'e', 'r', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'i', 'm', 'p', 'o', 'v', 'e', 'r', 'i', 's', 'h', 'm', 'e', 'n', 't', '\n',
        'i', 'm', 'p', 'r', 'a', 'c', 't', 'i', 'c', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'm', 'p', 'r', 'a', 'c', 't', 'i', 'c', 'a', 'b', 'l', 'e', '\n',
        'i', 'm', 'p', 'r', 'a', 'c', 't', 'i', 'c', 'a', 'l', '\n',
        'i', 'm', 'p', 'r', 'a', 'c', 't', 'i', 'c', 'a', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'i', 'm', 'p', 'r', 'a', 'c', 't', 'i', 'c', 'a', 'l', 'i', 't', 'y', '\n',
        'i', 'm', 'p', 'r', 'a', 'c', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'i', 'm', 'p', 'r', 'e', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'm', 'p', 'r', 'e', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'm', 'p', 'r', 'e', 'c', 'i', 's', 'e', '\n',
        'i', 'm', 'p', 'r', 'e', 'c', 'i', 's', 'e', 'l', 'y', '\n',
        'i', 'm', 'p', 'r', 'e', 'c', 'i', 's', 'e', 'n', 'e', 's', 's', '\n',
        'i', 'm', 'p', 'r', 'e', 'c', 'i', 's', 'i', 'o', 'n', '\n',
        'i', 'm', 'p', 'r', 'e', 'g', 'n', 'a', 'b', 'l', 'e', '\n',
        'i', 'm', 'p', 'r', 'e', 'g', 'n', 'a', 'b', 'l', 'y', '\n',
        'i', 'm', 'p', 'r', 'e', 'g', 'n', 'a', 't', 'e', '\n',
        'i', 'm', 'p', 'r', 'e', 'g', 'n', 'a', 't', 'e', 'd', '\n',
        'i', 'm', 'p', 'r', 'e', 'g', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'm', 'p', 'r', 'e', 'g', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'm', 'p', 'r', 'e', 's', 'a', 'r', 'i', 'o', '\n',
        'i', 'm', 'p', 'r', 'e', 's', 's', '\n',
        'i', 'm', 'p', 'r', 'e', 's', 's', 'e', 'd', '\n',
        'i', 'm', 'p', 'r', 'e', 's', 's', 'e', 's', '\n',
        'i', 'm', 'p', 'r', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'i', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', '\n',
        'i', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 'a', 'b', 'l', 'e', '\n',
        'i', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 'i', 's', 'm', '\n',
        'i', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 'i', 's', 't', '\n',
        'i', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 'i', 's', 't', 'i', 'c', '\n',
        'i', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 'i', 's', 't', 's', '\n',
        'i', 'm', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 's', '\n',
        'i', 'm', 'p', 'r', 'e', 's', 's', 'i', 'v', 'e', '\n',
        'i', 'm', 'p', 'r', 'e', 's', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'i', 'm', 'p', 'r', 'e', 's', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'i', 'm', 'p', 'r', 'i', 'm', 'a', 't', 'u', 'r', '\n',
        'i', 'm', 'p', 'r', 'i', 'n', 't', '\n',
        'i', 'm', 'p', 'r', 'i', 'n', 't', 'e', 'd', '\n',
        'i', 'm', 'p', 'r', 'i', 'n', 't', 'i', 'n', 'g', '\n',
        'i', 'm', 'p', 'r', 'i', 'n', 't', 's', '\n',
        'i', 'm', 'p', 'r', 'i', 's', 'o', 'n', '\n',
        'i', 'm', 'p', 'r', 'i', 's', 'o', 'n', 'e', 'd', '\n',
        'i', 'm', 'p', 'r', 'i', 's', 'o', 'n', 'i', 'n', 'g', '\n',
        'i', 'm', 'p', 'r', 'i', 's', 'o', 'n', 'm', 'e', 'n', 't', '\n',
        'i', 'm', 'p', 'r', 'i', 's', 'o', 'n', 'm', 'e', 'n', 't', 's', '\n',
        'i', 'm', 'p', 'r', 'i', 's', 'o', 'n', 's', '\n',
        'i', 'm', 'p', 'r', 'o', 'b', 'a', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'i', 'm', 'p', 'r', 'o', 'b', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'm', 'p', 'r', 'o', 'b', 'a', 'b', 'l', 'e', '\n',
        'i', 'm', 'p', 'r', 'o', 'b', 'a', 'b', 'l', 'y', '\n',
        'i', 'm', 'p', 'r', 'o', 'm', 'p', 't', 'u', '\n',
        'i', 'm', 'p', 'r', 'o', 'p', 'e', 'r', '\n',
        'i', 'm', 'p', 'r', 'o', 'p', 'e', 'r', 'l', 'y', '\n',
        'i', 'm', 'p', 'r', 'o', 'p', 'r', 'i', 'e', 't', 'i', 'e', 's', '\n',
        'i', 'm', 'p', 'r', 'o', 'p', 'r', 'i', 'e', 't', 'y', '\n',
        'i', 'm', 'p', 'r', 'o', 'v', 'a', 'b', 'l', 'e', '\n',
        'i', 'm', 'p', 'r', 'o', 'v', 'e', '\n',
        'i', 'm', 'p', 'r', 'o', 'v', 'e', 'd', '\n',
        'i', 'm', 'p', 'r', 'o', 'v', 'e', 'm', 'e', 'n', 't', '\n',
        'i', 'm', 'p', 'r', 'o', 'v', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'i', 'm', 'p', 'r', 'o', 'v', 'e', 'r', '\n',
        'i', 'm', 'p', 'r', 'o', 'v', 'e', 's', '\n',
        'i', 'm', 'p', 'r', 'o', 'v', 'i', 'd', 'e', 'n', 'c', 'e', '\n',
        'i', 'm', 'p', 'r', 'o', 'v', 'i', 'd', 'e', 'n', 't', '\n',
        'i', 'm', 'p', 'r', 'o', 'v', 'i', 'n', 'g', '\n',
        'i', 'm', 'p', 'r', 'o', 'v', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'm', 'p', 'r', 'o', 'v', 'i', 's', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'i', 'm', 'p', 'r', 'o', 'v', 'i', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'm', 'p', 'r', 'o', 'v', 'i', 's', 'a', 't', 'o', 'r', 'y', '\n',
        'i', 'm', 'p', 'r', 'o', 'v', 'i', 's', 'e', '\n',
        'i', 'm', 'p', 'r', 'o', 'v', 'i', 's', 'e', 'd', '\n',
        'i', 'm', 'p', 'r', 'o', 'v', 'i', 's', 'e', 's', '\n',
        'i', 'm', 'p', 'r', 'o', 'v', 'i', 's', 'i', 'n', 'g', '\n',
        'i', 'm', 'p', 'r', 'u', 'd', 'e', 'n', 'c', 'e', '\n',
        'i', 'm', 'p', 'r', 'u', 'd', 'e', 'n', 't', '\n',
        'i', 'm', 'p', 'r', 'u', 'd', 'e', 'n', 't', 'l', 'y', '\n',
        'i', 'm', 'p', 's', '\n',
        'i', 'm', 'p', 'u', 'd', 'e', 'n', 'c', 'e', '\n',
        'i', 'm', 'p', 'u', 'd', 'e', 'n', 't', '\n',
        'i', 'm', 'p', 'u', 'd', 'e', 'n', 't', 'l', 'y', '\n',
        'i', 'm', 'p', 'u', 'g', 'n', '\n',
        'i', 'm', 'p', 'u', 'g', 'n', 'a', 'b', 'l', 'e', '\n',
        'i', 'm', 'p', 'u', 'g', 'n', 'e', 'd', '\n',
        'i', 'm', 'p', 'u', 'g', 'n', 'i', 'n', 'g', '\n',
        'i', 'm', 'p', 'u', 'l', 's', 'e', '\n',
        'i', 'm', 'p', 'u', 'l', 's', 'e', 's', '\n',
        'i', 'm', 'p', 'u', 'l', 's', 'i', 'o', 'n', '\n',
        'i', 'm', 'p', 'u', 'l', 's', 'i', 'v', 'e', '\n',
        'i', 'm', 'p', 'u', 'l', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'i', 'm', 'p', 'u', 'l', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'i', 'm', 'p', 'u', 'n', 'i', 't', 'y', '\n',
        'i', 'm', 'p', 'u', 'r', 'e', '\n',
        'i', 'm', 'p', 'u', 'r', 'i', 't', 'i', 'e', 's', '\n',
        'i', 'm', 'p', 'u', 'r', 'i', 't', 'y', '\n',
        'i', 'm', 'p', 'u', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'm', 'p', 'u', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'm', 'p', 'u', 't', 'e', '\n',
        'i', 'm', 'p', 'u', 't', 'e', 'd', '\n',
        'i', 'm', 'p', 'u', 't', 'i', 'n', 'g', '\n',
        'i', 'n', '\n',
        'i', 'n', 'a', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'i', 'n', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 'a', 'c', 'c', 'e', 's', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 'a', 'c', 'c', 'e', 's', 's', 'i', 'b', 'l', 'e', '\n',
        'i', 'n', 'a', 'c', 'c', 'u', 'r', 'a', 'c', 'i', 'e', 's', '\n',
        'i', 'n', 'a', 'c', 'c', 'u', 'r', 'a', 'c', 'y', '\n',
        'i', 'n', 'a', 'c', 'c', 'u', 'r', 'a', 't', 'e', '\n',
        'i', 'n', 'a', 'c', 'c', 'u', 'r', 'a', 't', 'e', 'l', 'y', '\n',
        'i', 'n', 'a', 'c', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'a', 'c', 't', 'i', 'v', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 'a', 'c', 't', 'i', 'v', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'a', 'c', 't', 'i', 'v', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'a', 'c', 't', 'i', 'v', 'e', '\n',
        'i', 'n', 'a', 'c', 't', 'i', 'v', 'i', 't', 'y', '\n',
        'i', 'n', 'a', 'd', 'e', 'q', 'u', 'a', 'c', 'i', 'e', 's', '\n',
        'i', 'n', 'a', 'd', 'e', 'q', 'u', 'a', 'c', 'y', '\n',
        'i', 'n', 'a', 'd', 'e', 'q', 'u', 'a', 't', 'e', '\n',
        'i', 'n', 'a', 'd', 'e', 'q', 'u', 'a', 't', 'e', 'l', 'y', '\n',
        'i', 'n', 'a', 'd', 'm', 'i', 's', 's', 'i', 'b', 'l', 'e', '\n',
        'i', 'n', 'a', 'd', 'v', 'e', 'r', 't', 'e', 'n', 'c', 'e', '\n',
        'i', 'n', 'a', 'd', 'v', 'e', 'r', 't', 'e', 'n', 't', '\n',
        'i', 'n', 'a', 'd', 'v', 'e', 'r', 't', 'e', 'n', 't', 'l', 'y', '\n',
        'i', 'n', 'a', 'd', 'v', 'i', 's', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 'a', 'd', 'v', 'i', 's', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'a', 'd', 'v', 'i', 's', 'e', 'd', 'l', 'y', '\n',
        'i', 'n', 'a', 'l', 'i', 'e', 'n', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'a', 'n', 'e', '\n',
        'i', 'n', 'a', 'n', 'e', 'l', 'y', '\n',
        'i', 'n', 'a', 'n', 'i', 'm', 'a', 't', 'e', '\n',
        'i', 'n', 'a', 'n', 'i', 't', 'i', 'e', 's', '\n',
        'i', 'n', 'a', 'n', 'i', 't', 'y', '\n',
        'i', 'n', 'a', 'p', 'p', 'l', 'i', 'c', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 'a', 'p', 'p', 'l', 'i', 'c', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'a', 'p', 'p', 'r', 'o', 'p', 'r', 'i', 'a', 't', 'e', '\n',
        'i', 'n', 'a', 'p', 'p', 'r', 'o', 'p', 'r', 'i', 'a', 't', 'e', 'l', 'y', '\n',
        'i', 'n', 'a', 'p', 'p', 'r', 'o', 'p', 'r', 'i', 'a', 't', 'e', 'n', 'e', 's', 's', '\n',
        'i', 'n', 'a', 'p', 't', 'l', 'y', '\n',
        'i', 'n', 'a', 'r', 't', 'i', 'c', 'u', 'l', 'a', 'c', 'y', '\n',
        'i', 'n', 'a', 'r', 't', 'i', 'c', 'u', 'l', 'a', 't', 'e', '\n',
        'i', 'n', 'a', 'r', 't', 'i', 'c', 'u', 'l', 'a', 't', 'e', 'n', 'e', 's', 's', '\n',
        'i', 'n', 'a', 's', 'm', 'u', 'c', 'h', '\n',
        'i', 'n', 'a', 't', 't', 'e', 'n', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'a', 't', 't', 'e', 'n', 't', 'i', 'v', 'e', '\n',
        'i', 'n', 'a', 't', 't', 'e', 'n', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'i', 'n', 'a', 'u', 'd', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 'a', 'u', 'd', 'i', 'b', 'l', 'e', '\n',
        'i', 'n', 'a', 'u', 'd', 'i', 'b', 'l', 'y', '\n',
        'i', 'n', 'a', 'u', 'g', 'u', 'r', 'a', 'l', '\n',
        'i', 'n', 'a', 'u', 'g', 'u', 'r', 'a', 't', 'e', '\n',
        'i', 'n', 'a', 'u', 'g', 'u', 'r', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 'a', 'u', 'g', 'u', 'r', 'a', 't', 'e', 's', '\n',
        'i', 'n', 'a', 'u', 'g', 'u', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'a', 'u', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'a', 'u', 's', 'p', 'i', 'c', 'i', 'o', 'u', 's', '\n',
        'i', 'n', 'a', 'u', 's', 'p', 'i', 'c', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'i', 'n', 'a', 'u', 't', 'h', 'e', 'n', 't', 'i', 'c', 'i', 't', 'y', '\n',
        'i', 'n', 'b', 'o', 'a', 'r', 'd', '\n',
        'i', 'n', 'b', 'o', 'r', 'n', '\n',
        'i', 'n', 'b', 'o', 'u', 'n', 'd', '\n',
        'i', 'n', 'b', 'r', 'e', 'd', '\n',
        'i', 'n', 'b', 'r', 'e', 'e', 'd', 'i', 'n', 'g', '\n',
        'i', 'n', 'b', 'u', 'i', 'l', 't', '\n',
        'i', 'n', 'c', 'a', '\n',
        'i', 'n', 'c', 'a', 'l', 'c', 'u', 'l', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'c', 'a', 'l', 'c', 'u', 'l', 'a', 'b', 'l', 'y', '\n',
        'i', 'n', 'c', 'a', 'n', 'd', 'e', 's', 'c', 'e', 'n', 'c', 'e', '\n',
        'i', 'n', 'c', 'a', 'n', 'd', 'e', 's', 'c', 'e', 'n', 't', '\n',
        'i', 'n', 'c', 'a', 'n', 'd', 'e', 's', 'c', 'e', 'n', 't', 'l', 'y', '\n',
        'i', 'n', 'c', 'a', 'n', 't', '\n',
        'i', 'n', 'c', 'a', 'n', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'c', 'a', 'n', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'c', 'a', 'n', 't', 'a', 't', 'o', 'r', 'y', '\n',
        'i', 'n', 'c', 'a', 'p', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 'c', 'a', 'p', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'c', 'a', 'p', 'a', 'c', 'i', 't', 'a', 't', 'e', '\n',
        'i', 'n', 'c', 'a', 'p', 'a', 'c', 'i', 't', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 'c', 'a', 'p', 'a', 'c', 'i', 't', 'a', 't', 'e', 's', '\n',
        'i', 'n', 'c', 'a', 'p', 'a', 'c', 'i', 't', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'c', 'a', 'p', 'a', 'c', 'i', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'c', 'a', 'p', 'a', 'c', 'i', 't', 'y', '\n',
        'i', 'n', 'c', 'a', 'r', 'c', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 'c', 'a', 'r', 'c', 'e', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'c', 'a', 'r', 'c', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'c', 'a', 'r', 'n', 'a', 't', 'e', '\n',
        'i', 'n', 'c', 'a', 'r', 'n', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 'c', 'a', 'r', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'c', 'a', 'r', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'c', 'a', 's', '\n',
        'i', 'n', 'c', 'a', 's', 'e', 'd', '\n',
        'i', 'n', 'c', 'a', 'u', 't', 'i', 'o', 'u', 's', '\n',
        'i', 'n', 'c', 'a', 'u', 't', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'i', 'n', 'c', 'e', 'n', 'd', 'i', 'a', 'r', 'i', 'e', 's', '\n',
        'i', 'n', 'c', 'e', 'n', 'd', 'i', 'a', 'r', 'y', '\n',
        'i', 'n', 'c', 'e', 'n', 's', 'e', '\n',
        'i', 'n', 'c', 'e', 'n', 's', 'e', 'd', '\n',
        'i', 'n', 'c', 'e', 'n', 's', 'e', 's', '\n',
        'i', 'n', 'c', 'e', 'n', 's', 'i', 'n', 'g', '\n',
        'i', 'n', 'c', 'e', 'n', 't', 'i', 'v', 'e', '\n',
        'i', 'n', 'c', 'e', 'n', 't', 'i', 'v', 'e', 's', '\n',
        'i', 'n', 'c', 'e', 'p', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'c', 'e', 's', 's', 'a', 'n', 't', '\n',
        'i', 'n', 'c', 'e', 's', 's', 'a', 'n', 't', 'l', 'y', '\n',
        'i', 'n', 'c', 'e', 's', 't', '\n',
        'i', 'n', 'c', 'e', 's', 't', 's', '\n',
        'i', 'n', 'c', 'e', 's', 't', 'u', 'o', 'u', 's', '\n',
        'i', 'n', 'c', 'e', 's', 't', 'u', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'i', 'n', 'c', 'h', '\n',
        'i', 'n', 'c', 'h', 'e', 'd', '\n',
        'i', 'n', 'c', 'h', 'e', 's', '\n',
        'i', 'n', 'c', 'h', 'i', 'n', 'g', '\n',
        'i', 'n', 'c', 'h', 'o', 'a', 't', 'e', '\n',
        'i', 'n', 'c', 'i', 'd', 'e', 'n', 'c', 'e', '\n',
        'i', 'n', 'c', 'i', 'd', 'e', 'n', 'c', 'e', 's', '\n',
        'i', 'n', 'c', 'i', 'd', 'e', 'n', 't', '\n',
        'i', 'n', 'c', 'i', 'd', 'e', 'n', 't', 'a', 'l', '\n',
        'i', 'n', 'c', 'i', 'd', 'e', 'n', 't', 'a', 'l', 'l', 'y', '\n',
        'i', 'n', 'c', 'i', 'd', 'e', 'n', 't', 's', '\n',
        'i', 'n', 'c', 'i', 'n', 'e', 'r', 'a', 't', 'e', '\n',
        'i', 'n', 'c', 'i', 'n', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 'c', 'i', 'n', 'e', 'r', 'a', 't', 'e', 's', '\n',
        'i', 'n', 'c', 'i', 'n', 'e', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'c', 'i', 'n', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'c', 'i', 'n', 'e', 'r', 'a', 't', 'o', 'r', '\n',
        'i', 'n', 'c', 'i', 'n', 'e', 'r', 'a', 't', 'o', 'r', 's', '\n',
        'i', 'n', 'c', 'i', 'p', 'i', 'e', 'n', 't', '\n',
        'i', 'n', 'c', 'i', 's', 'e', 'd', '\n',
        'i', 'n', 'c', 'i', 's', 'i', 'o', 'n', '\n',
        'i', 'n', 'c', 'i', 's', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'c', 'i', 's', 'i', 'v', 'e', '\n',
        'i', 'n', 'c', 'i', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'i', 'n', 'c', 'i', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'i', 'n', 'c', 'i', 's', 'o', 'r', '\n',
        'i', 'n', 'c', 'i', 's', 'o', 'r', 's', '\n',
        'i', 'n', 'c', 'i', 't', 'e', '\n',
        'i', 'n', 'c', 'i', 't', 'e', 'd', '\n',
        'i', 'n', 'c', 'i', 't', 'e', 'm', 'e', 'n', 't', '\n',
        'i', 'n', 'c', 'i', 't', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'i', 'n', 'c', 'i', 't', 'e', 'r', '\n',
        'i', 'n', 'c', 'i', 't', 'e', 'r', 's', '\n',
        'i', 'n', 'c', 'i', 't', 'e', 's', '\n',
        'i', 'n', 'c', 'i', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'c', 'l', 'e', 'm', 'e', 'n', 'c', 'y', '\n',
        'i', 'n', 'c', 'l', 'e', 'm', 'e', 'n', 't', '\n',
        'i', 'n', 'c', 'l', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'c', 'l', 'i', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'c', 'l', 'i', 'n', 'e', '\n',
        'i', 'n', 'c', 'l', 'i', 'n', 'e', 'd', '\n',
        'i', 'n', 'c', 'l', 'i', 'n', 'e', 's', '\n',
        'i', 'n', 'c', 'l', 'i', 'n', 'i', 'n', 'g', '\n',
        'i', 'n', 'c', 'l', 'u', 'd', 'e', '\n',
        'i', 'n', 'c', 'l', 'u', 'd', 'e', 'd', '\n',
        'i', 'n', 'c', 'l', 'u', 'd', 'e', 's', '\n',
        'i', 'n', 'c', 'l', 'u', 'd', 'i', 'n', 'g', '\n',
        'i', 'n', 'c', 'l', 'u', 's', 'i', 'o', 'n', '\n',
        'i', 'n', 'c', 'l', 'u', 's', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'c', 'l', 'u', 's', 'i', 'v', 'e', '\n',
        'i', 'n', 'c', 'l', 'u', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'i', 'n', 'c', 'l', 'u', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'i', 'n', 'c', 'o', 'g', 'n', 'i', 't', 'o', '\n',
        'i', 'n', 'c', 'o', 'h', 'e', 'r', 'e', 'n', 'c', 'e', '\n',
        'i', 'n', 'c', 'o', 'h', 'e', 'r', 'e', 'n', 'c', 'y', '\n',
        'i', 'n', 'c', 'o', 'h', 'e', 'r', 'e', 'n', 't', '\n',
        'i', 'n', 'c', 'o', 'h', 'e', 'r', 'e', 'n', 't', 'l', 'y', '\n',
        'i', 'n', 'c', 'o', 'm', 'b', 'u', 's', 't', 'i', 'b', 'l', 'e', '\n',
        'i', 'n', 'c', 'o', 'm', 'e', '\n',
        'i', 'n', 'c', 'o', 'm', 'e', 'r', '\n',
        'i', 'n', 'c', 'o', 'm', 'e', 'r', 's', '\n',
        'i', 'n', 'c', 'o', 'm', 'e', 's', '\n',
        'i', 'n', 'c', 'o', 'm', 'i', 'n', 'g', '\n',
        'i', 'n', 'c', 'o', 'm', 'm', 'e', 'n', 's', 'u', 'r', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'c', 'o', 'm', 'm', 'o', 'd', 'i', 'n', 'g', '\n',
        'i', 'n', 'c', 'o', 'm', 'm', 'u', 'n', 'i', 'c', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'c', 'o', 'm', 'm', 'u', 'n', 'i', 'c', 'a', 'd', 'o', '\n',
        'i', 'n', 'c', 'o', 'm', 'p', 'a', 'r', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'c', 'o', 'm', 'p', 'a', 'r', 'a', 'b', 'l', 'y', '\n',
        'i', 'n', 'c', 'o', 'm', 'p', 'a', 't', 'i', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'i', 'n', 'c', 'o', 'm', 'p', 'a', 't', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 'c', 'o', 'm', 'p', 'a', 't', 'i', 'b', 'l', 'e', '\n',
        'i', 'n', 'c', 'o', 'm', 'p', 'a', 't', 'i', 'b', 'l', 'y', '\n',
        'i', 'n', 'c', 'o', 'm', 'p', 'e', 't', 'e', 'n', 'c', 'e', '\n',
        'i', 'n', 'c', 'o', 'm', 'p', 'e', 't', 'e', 'n', 't', '\n',
        'i', 'n', 'c', 'o', 'm', 'p', 'e', 't', 'e', 'n', 't', 'l', 'y', '\n',
        'i', 'n', 'c', 'o', 'm', 'p', 'e', 't', 'e', 'n', 't', 's', '\n',
        'i', 'n', 'c', 'o', 'm', 'p', 'l', 'e', 't', 'e', '\n',
        'i', 'n', 'c', 'o', 'm', 'p', 'l', 'e', 't', 'e', 'l', 'y', '\n',
        'i', 'n', 'c', 'o', 'm', 'p', 'l', 'e', 't', 'e', 'n', 'e', 's', 's', '\n',
        'i', 'n', 'c', 'o', 'm', 'p', 'r', 'e', 'h', 'e', 'n', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 'c', 'o', 'm', 'p', 'r', 'e', 'h', 'e', 'n', 's', 'i', 'b', 'l', 'e', '\n',
        'i', 'n', 'c', 'o', 'm', 'p', 'r', 'e', 'h', 'e', 'n', 's', 'i', 'b', 'l', 'y', '\n',
        'i', 'n', 'c', 'o', 'm', 'p', 'r', 'e', 'h', 'e', 'n', 's', 'i', 'o', 'n', '\n',
        'i', 'n', 'c', 'o', 'm', 'p', 'r', 'e', 's', 's', 'i', 'b', 'l', 'e', '\n',
        'i', 'n', 'c', 'o', 'n', 'c', 'e', 'i', 'v', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'c', 'o', 'n', 'c', 'e', 'i', 'v', 'a', 'b', 'l', 'y', '\n',
        'i', 'n', 'c', 'o', 'n', 'c', 'l', 'u', 's', 'i', 'v', 'e', '\n',
        'i', 'n', 'c', 'o', 'n', 'c', 'l', 'u', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'i', 'n', 'c', 'o', 'n', 'g', 'r', 'u', 'i', 't', 'i', 'e', 's', '\n',
        'i', 'n', 'c', 'o', 'n', 'g', 'r', 'u', 'i', 't', 'y', '\n',
        'i', 'n', 'c', 'o', 'n', 'g', 'r', 'u', 'o', 'u', 's', '\n',
        'i', 'n', 'c', 'o', 'n', 'g', 'r', 'u', 'o', 'u', 's', 'l', 'y', '\n',
        'i', 'n', 'c', 'o', 'n', 's', 'e', 'q', 'u', 'e', 'n', 't', 'i', 'a', 'l', '\n',
        'i', 'n', 'c', 'o', 'n', 's', 'e', 'q', 'u', 'e', 'n', 't', 'i', 'a', 'l', 'l', 'y', '\n',
        'i', 'n', 'c', 'o', 'n', 's', 'i', 'd', 'e', 'r', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'c', 'o', 'n', 's', 'i', 'd', 'e', 'r', 'a', 't', 'e', '\n',
        'i', 'n', 'c', 'o', 'n', 's', 'i', 'd', 'e', 'r', 'a', 't', 'e', 'l', 'y', '\n',
        'i', 'n', 'c', 'o', 'n', 's', 'i', 'd', 'e', 'r', 'a', 't', 'e', 'n', 'e', 's', 's', '\n',
        'i', 'n', 'c', 'o', 'n', 's', 'i', 's', 't', 'e', 'n', 'c', 'i', 'e', 's', '\n',
        'i', 'n', 'c', 'o', 'n', 's', 'i', 's', 't', 'e', 'n', 'c', 'y', '\n',
        'i', 'n', 'c', 'o', 'n', 's', 'i', 's', 't', 'e', 'n', 't', '\n',
        'i', 'n', 'c', 'o', 'n', 's', 'i', 's', 't', 'e', 'n', 't', 'l', 'y', '\n',
        'i', 'n', 'c', 'o', 'n', 's', 'o', 'l', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'c', 'o', 'n', 's', 'o', 'l', 'a', 'b', 'l', 'y', '\n',
        'i', 'n', 'c', 'o', 'n', 's', 'p', 'i', 'c', 'u', 'o', 'u', 's', '\n',
        'i', 'n', 'c', 'o', 'n', 's', 'p', 'i', 'c', 'u', 'o', 'u', 's', 'l', 'y', '\n',
        'i', 'n', 'c', 'o', 'n', 's', 'p', 'i', 'c', 'u', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'i', 'n', 'c', 'o', 'n', 's', 't', 'a', 'n', 'c', 'y', '\n',
        'i', 'n', 'c', 'o', 'n', 's', 't', 'a', 'n', 't', '\n',
        'i', 'n', 'c', 'o', 'n', 't', 'e', 's', 't', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'c', 'o', 'n', 't', 'e', 's', 't', 'a', 'b', 'l', 'y', '\n',
        'i', 'n', 'c', 'o', 'n', 't', 'i', 'n', 'e', 'n', 'c', 'e', '\n',
        'i', 'n', 'c', 'o', 'n', 't', 'i', 'n', 'e', 'n', 't', '\n',
        'i', 'n', 'c', 'o', 'n', 't', 'i', 'n', 'e', 'n', 't', 'l', 'y', '\n',
        'i', 'n', 'c', 'o', 'n', 't', 'r', 'o', 'v', 'e', 'r', 't', 'i', 'b', 'l', 'e', '\n',
        'i', 'n', 'c', 'o', 'n', 't', 'r', 'o', 'v', 'e', 'r', 't', 'i', 'b', 'l', 'y', '\n',
        'i', 'n', 'c', 'o', 'n', 'v', 'e', 'n', 'i', 'e', 'n', 'c', 'e', '\n',
        'i', 'n', 'c', 'o', 'n', 'v', 'e', 'n', 'i', 'e', 'n', 'c', 'e', 'd', '\n',
        'i', 'n', 'c', 'o', 'n', 'v', 'e', 'n', 'i', 'e', 'n', 'c', 'e', 's', '\n',
        'i', 'n', 'c', 'o', 'n', 'v', 'e', 'n', 'i', 'e', 'n', 'c', 'i', 'n', 'g', '\n',
        'i', 'n', 'c', 'o', 'n', 'v', 'e', 'n', 'i', 'e', 'n', 't', '\n',
        'i', 'n', 'c', 'o', 'n', 'v', 'e', 'n', 'i', 'e', 'n', 't', 'l', 'y', '\n',
        'i', 'n', 'c', 'o', 'r', 'p', 'o', 'r', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'c', 'o', 'r', 'p', 'o', 'r', 'a', 't', 'e', '\n',
        'i', 'n', 'c', 'o', 'r', 'p', 'o', 'r', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 'c', 'o', 'r', 'p', 'o', 'r', 'a', 't', 'e', 's', '\n',
        'i', 'n', 'c', 'o', 'r', 'p', 'o', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'c', 'o', 'r', 'p', 'o', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'c', 'o', 'r', 'r', 'e', 'c', 't', '\n',
        'i', 'n', 'c', 'o', 'r', 'r', 'e', 'c', 't', 'l', 'y', '\n',
        'i', 'n', 'c', 'o', 'r', 'r', 'e', 'c', 't', 'n', 'e', 's', 's', '\n',
        'i', 'n', 'c', 'o', 'r', 'r', 'i', 'g', 'i', 'b', 'l', 'e', '\n',
        'i', 'n', 'c', 'o', 'r', 'r', 'i', 'g', 'i', 'b', 'l', 'y', '\n',
        'i', 'n', 'c', 'o', 'r', 'r', 'u', 'p', 't', 'i', 'b', 'l', 'e', '\n',
        'i', 'n', 'c', 'r', 'e', 'a', 's', 'e', '\n',
        'i', 'n', 'c', 'r', 'e', 'a', 's', 'e', 'd', '\n',
        'i', 'n', 'c', 'r', 'e', 'a', 's', 'e', 's', '\n',
        'i', 'n', 'c', 'r', 'e', 'a', 's', 'i', 'n', 'g', '\n',
        'i', 'n', 'c', 'r', 'e', 'a', 's', 'i', 'n', 'g', 'l', 'y', '\n',
        'i', 'n', 'c', 'r', 'e', 'd', 'i', 'b', 'l', 'e', '\n',
        'i', 'n', 'c', 'r', 'e', 'd', 'i', 'b', 'l', 'y', '\n',
        'i', 'n', 'c', 'r', 'e', 'd', 'u', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 'c', 'r', 'e', 'd', 'u', 'l', 'o', 'u', 's', '\n',
        'i', 'n', 'c', 'r', 'e', 'd', 'u', 'l', 'o', 'u', 's', 'l', 'y', '\n',
        'i', 'n', 'c', 'r', 'e', 'm', 'e', 'n', 't', '\n',
        'i', 'n', 'c', 'r', 'e', 'm', 'e', 'n', 't', 'a', 'l', '\n',
        'i', 'n', 'c', 'r', 'e', 'm', 'e', 'n', 't', 'a', 'l', 'l', 'y', '\n',
        'i', 'n', 'c', 'r', 'e', 'm', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'c', 'r', 'e', 'm', 'e', 'n', 't', 'e', 'd', '\n',
        'i', 'n', 'c', 'r', 'e', 'm', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'c', 'r', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'i', 'n', 'c', 'r', 'i', 'm', 'i', 'n', 'a', 't', 'e', '\n',
        'i', 'n', 'c', 'r', 'i', 'm', 'i', 'n', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 'c', 'r', 'i', 'm', 'i', 'n', 'a', 't', 'e', 's', '\n',
        'i', 'n', 'c', 'r', 'i', 'm', 'i', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'c', 'r', 'i', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'c', 'u', 'b', 'a', 't', 'e', '\n',
        'i', 'n', 'c', 'u', 'b', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 'c', 'u', 'b', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'c', 'u', 'b', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'c', 'u', 'b', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'c', 'u', 'b', 'a', 't', 'o', 'r', '\n',
        'i', 'n', 'c', 'u', 'b', 'a', 't', 'o', 'r', 's', '\n',
        'i', 'n', 'c', 'u', 'l', 'c', 'a', 't', 'e', '\n',
        'i', 'n', 'c', 'u', 'l', 'c', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 'c', 'u', 'l', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'c', 'u', 'l', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'c', 'u', 'm', 'b', 'e', 'n', 'c', 'y', '\n',
        'i', 'n', 'c', 'u', 'm', 'b', 'e', 'n', 't', '\n',
        'i', 'n', 'c', 'u', 'm', 'b', 'e', 'n', 't', 's', '\n',
        'i', 'n', 'c', 'u', 'r', '\n',
        'i', 'n', 'c', 'u', 'r', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'c', 'u', 'r', 'a', 'b', 'l', 'y', '\n',
        'i', 'n', 'c', 'u', 'r', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'i', 'n', 'c', 'u', 'r', 'r', 'e', 'd', '\n',
        'i', 'n', 'c', 'u', 'r', 'r', 'i', 'n', 'g', '\n',
        'i', 'n', 'c', 'u', 'r', 's', '\n',
        'i', 'n', 'c', 'u', 'r', 's', 'i', 'o', 'n', '\n',
        'i', 'n', 'c', 'u', 'r', 's', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'd', 'a', 'b', 'a', '\n',
        'i', 'n', 'd', 'e', 'b', 't', 'e', 'd', '\n',
        'i', 'n', 'd', 'e', 'b', 't', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'i', 'n', 'd', 'e', 'c', 'e', 'n', 'c', 'y', '\n',
        'i', 'n', 'd', 'e', 'c', 'e', 'n', 't', '\n',
        'i', 'n', 'd', 'e', 'c', 'e', 'n', 't', 'l', 'y', '\n',
        'i', 'n', 'd', 'e', 'c', 'i', 'p', 'h', 'e', 'r', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'd', 'e', 'c', 'i', 's', 'i', 'o', 'n', '\n',
        'i', 'n', 'd', 'e', 'c', 'i', 's', 'i', 'v', 'e', '\n',
        'i', 'n', 'd', 'e', 'c', 'i', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'i', 'n', 'd', 'e', 'c', 'i', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'i', 'n', 'd', 'e', 'c', 'l', 'i', 'n', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'd', 'e', 'c', 'o', 'r', 'o', 'u', 's', '\n',
        'i', 'n', 'd', 'e', 'e', 'd', '\n',
        'i', 'n', 'd', 'e', 'f', 'a', 't', 'i', 'g', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'd', 'e', 'f', 'e', 'a', 's', 'i', 'b', 'l', 'e', '\n',
        'i', 'n', 'd', 'e', 'f', 'e', 'n', 's', 'i', 'b', 'l', 'e', '\n',
        'i', 'n', 'd', 'e', 'f', 'i', 'n', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'd', 'e', 'f', 'i', 'n', 'a', 'b', 'l', 'y', '\n',
        'i', 'n', 'd', 'e', 'f', 'i', 'n', 'i', 't', 'e', '\n',
        'i', 'n', 'd', 'e', 'f', 'i', 'n', 'i', 't', 'e', 'l', 'y', '\n',
        'i', 'n', 'd', 'e', 'l', 'i', 'b', 'l', 'e', '\n',
        'i', 'n', 'd', 'e', 'l', 'i', 'b', 'l', 'y', '\n',
        'i', 'n', 'd', 'e', 'l', 'i', 'c', 'a', 'c', 'y', '\n',
        'i', 'n', 'd', 'e', 'l', 'i', 'c', 'a', 't', 'e', '\n',
        'i', 'n', 'd', 'e', 'm', 'n', 'i', 'f', 'i', 'e', 'd', '\n',
        'i', 'n', 'd', 'e', 'm', 'n', 'i', 'f', 'y', '\n',
        'i', 'n', 'd', 'e', 'm', 'n', 'i', 't', 'i', 'e', 's', '\n',
        'i', 'n', 'd', 'e', 'm', 'n', 'i', 't', 'y', '\n',
        'i', 'n', 'd', 'e', 'n', 't', '\n',
        'i', 'n', 'd', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'd', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'd', 'e', 'n', 't', 'e', 'd', '\n',
        'i', 'n', 'd', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'd', 'e', 'n', 't', 's', '\n',
        'i', 'n', 'd', 'e', 'n', 't', 'u', 'r', 'e', 's', '\n',
        'i', 'n', 'd', 'e', 'p', 'e', 'n', 'd', 'e', 'n', 'c', 'e', '\n',
        'i', 'n', 'd', 'e', 'p', 'e', 'n', 'd', 'e', 'n', 't', '\n',
        'i', 'n', 'd', 'e', 'p', 'e', 'n', 'd', 'e', 'n', 't', 'l', 'y', '\n',
        'i', 'n', 'd', 'e', 'p', 'e', 'n', 'd', 'e', 'n', 't', 's', '\n',
        'i', 'n', 'd', 'e', 'p', 't', 'h', '\n',
        'i', 'n', 'd', 'e', 's', 'c', 'r', 'i', 'b', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'd', 'e', 's', 'c', 'r', 'i', 'b', 'a', 'b', 'l', 'y', '\n',
        'i', 'n', 'd', 'e', 's', 't', 'r', 'u', 'c', 't', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 'd', 'e', 's', 't', 'r', 'u', 'c', 't', 'i', 'b', 'l', 'e', '\n',
        'i', 'n', 'd', 'e', 't', 'e', 'r', 'm', 'i', 'n', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'd', 'e', 't', 'e', 'r', 'm', 'i', 'n', 'a', 'c', 'y', '\n',
        'i', 'n', 'd', 'e', 't', 'e', 'r', 'm', 'i', 'n', 'a', 't', 'e', '\n',
        'i', 'n', 'd', 'e', 'x', '\n',
        'i', 'n', 'd', 'e', 'x', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'd', 'e', 'x', 'e', 'd', '\n',
        'i', 'n', 'd', 'e', 'x', 'e', 'r', '\n',
        'i', 'n', 'd', 'e', 'x', 'e', 'r', 's', '\n',
        'i', 'n', 'd', 'e', 'x', 'e', 's', '\n',
        'i', 'n', 'd', 'e', 'x', 'i', 'n', 'g', '\n',
        'i', 'n', 'd', 'i', 'a', '\n',
        'i', 'n', 'd', 'i', 'a', 'n', '\n',
        'i', 'n', 'd', 'i', 'a', 'n', 'a', '\n',
        'i', 'n', 'd', 'i', 'a', 'n', 's', '\n',
        'i', 'n', 'd', 'i', 'c', 'a', 'n', 't', '\n',
        'i', 'n', 'd', 'i', 'c', 'a', 'n', 't', 's', '\n',
        'i', 'n', 'd', 'i', 'c', 'a', 't', 'e', '\n',
        'i', 'n', 'd', 'i', 'c', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 'd', 'i', 'c', 'a', 't', 'e', 's', '\n',
        'i', 'n', 'd', 'i', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'd', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'd', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'd', 'i', 'c', 'a', 't', 'i', 'v', 'e', '\n',
        'i', 'n', 'd', 'i', 'c', 'a', 't', 'o', 'r', '\n',
        'i', 'n', 'd', 'i', 'c', 'a', 't', 'o', 'r', 's', '\n',
        'i', 'n', 'd', 'i', 'c', 'e', 's', '\n',
        'i', 'n', 'd', 'i', 'c', 't', '\n',
        'i', 'n', 'd', 'i', 'c', 't', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'd', 'i', 'c', 't', 'e', 'd', '\n',
        'i', 'n', 'd', 'i', 'c', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'd', 'i', 'c', 't', 'm', 'e', 'n', 't', '\n',
        'i', 'n', 'd', 'i', 'c', 't', 'm', 'e', 'n', 't', 's', '\n',
        'i', 'n', 'd', 'i', 'c', 't', 's', '\n',
        'i', 'n', 'd', 'i', 'f', 'f', 'e', 'r', 'e', 'n', 'c', 'e', '\n',
        'i', 'n', 'd', 'i', 'f', 'f', 'e', 'r', 'e', 'n', 't', '\n',
        'i', 'n', 'd', 'i', 'f', 'f', 'e', 'r', 'e', 'n', 't', 'l', 'y', '\n',
        'i', 'n', 'd', 'i', 'g', 'e', 'n', 'o', 'u', 's', '\n',
        'i', 'n', 'd', 'i', 'g', 'e', 's', 't', 'i', 'b', 'l', 'e', '\n',
        'i', 'n', 'd', 'i', 'g', 'e', 's', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'd', 'i', 'g', 'n', 'a', 'n', 't', '\n',
        'i', 'n', 'd', 'i', 'g', 'n', 'a', 'n', 't', 'l', 'y', '\n',
        'i', 'n', 'd', 'i', 'g', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'd', 'i', 'g', 'n', 'i', 't', 'i', 'e', 's', '\n',
        'i', 'n', 'd', 'i', 'g', 'n', 'i', 't', 'y', '\n',
        'i', 'n', 'd', 'i', 'g', 'o', '\n',
        'i', 'n', 'd', 'i', 'r', 'e', 'c', 't', '\n',
        'i', 'n', 'd', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'd', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'd', 'i', 'r', 'e', 'c', 't', 'l', 'y', '\n',
        'i', 'n', 'd', 'i', 'r', 'e', 'c', 't', 'n', 'e', 's', 's', '\n',
        'i', 'n', 'd', 'i', 's', 'c', 'i', 'p', 'l', 'i', 'n', 'e', '\n',
        'i', 'n', 'd', 'i', 's', 'c', 'r', 'e', 'e', 't', '\n',
        'i', 'n', 'd', 'i', 's', 'c', 'r', 'e', 'e', 't', 'l', 'y', '\n',
        'i', 'n', 'd', 'i', 's', 'c', 'r', 'e', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'd', 'i', 's', 'c', 'r', 'e', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'd', 'i', 's', 'c', 'r', 'i', 'm', 'i', 'n', 'a', 't', 'e', '\n',
        'i', 'n', 'd', 'i', 's', 'c', 'r', 'i', 'm', 'i', 'n', 'a', 't', 'e', 'l', 'y', '\n',
        'i', 'n', 'd', 'i', 's', 'p', 'e', 'n', 's', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 'd', 'i', 's', 'p', 'e', 'n', 's', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'd', 'i', 's', 'p', 'e', 'n', 's', 'a', 'b', 'l', 'y', '\n',
        'i', 'n', 'd', 'i', 's', 'p', 'o', 's', 'e', '\n',
        'i', 'n', 'd', 'i', 's', 'p', 'o', 's', 'e', 'd', '\n',
        'i', 'n', 'd', 'i', 's', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'd', 'i', 's', 'p', 'u', 't', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'd', 'i', 's', 'p', 'u', 't', 'a', 'b', 'l', 'y', '\n',
        'i', 'n', 'd', 'i', 's', 's', 'o', 'l', 'u', 'b', 'l', 'e', '\n',
        'i', 'n', 'd', 'i', 's', 's', 'o', 'l', 'u', 'b', 'l', 'y', '\n',
        'i', 'n', 'd', 'i', 's', 't', 'i', 'n', 'c', 't', '\n',
        'i', 'n', 'd', 'i', 's', 't', 'i', 'n', 'c', 't', 'l', 'y', '\n',
        'i', 'n', 'd', 'i', 's', 't', 'i', 'n', 'c', 't', 'n', 'e', 's', 's', '\n',
        'i', 'n', 'd', 'i', 's', 't', 'i', 'n', 'g', 'u', 'i', 's', 'h', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'd', 'i', 's', 't', 'i', 'n', 'g', 'u', 'i', 's', 'h', 'a', 'b', 'l', 'y', '\n',
        'i', 'n', 'd', 'i', 't', 'e', '\n',
        'i', 'n', 'd', 'i', 'v', 'i', 'd', 'u', 'a', 'l', '\n',
        'i', 'n', 'd', 'i', 'v', 'i', 'd', 'u', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'i', 'n', 'd', 'i', 'v', 'i', 'd', 'u', 'a', 'l', 'i', 's', 'm', '\n',
        'i', 'n', 'd', 'i', 'v', 'i', 'd', 'u', 'a', 'l', 'i', 's', 't', '\n',
        'i', 'n', 'd', 'i', 'v', 'i', 'd', 'u', 'a', 'l', 'i', 's', 't', 'i', 'c', '\n',
        'i', 'n', 'd', 'i', 'v', 'i', 'd', 'u', 'a', 'l', 'i', 's', 't', 's', '\n',
        'i', 'n', 'd', 'i', 'v', 'i', 'd', 'u', 'a', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 'd', 'i', 'v', 'i', 'd', 'u', 'a', 'l', 'l', 'y', '\n',
        'i', 'n', 'd', 'i', 'v', 'i', 'd', 'u', 'a', 'l', 's', '\n',
        'i', 'n', 'd', 'i', 'v', 'i', 'd', 'u', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'd', 'i', 'v', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 'd', 'i', 'v', 'i', 's', 'i', 'b', 'l', 'e', '\n',
        'i', 'n', 'd', 'i', 'v', 'i', 's', 'i', 'b', 'l', 'y', '\n',
        'i', 'n', 'd', 'o', 'c', 't', 'r', 'i', 'n', 'a', 't', 'e', '\n',
        'i', 'n', 'd', 'o', 'c', 't', 'r', 'i', 'n', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 'd', 'o', 'c', 't', 'r', 'i', 'n', 'a', 't', 'e', 's', '\n',
        'i', 'n', 'd', 'o', 'c', 't', 'r', 'i', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'd', 'o', 'c', 't', 'r', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'd', 'o', 'c', 't', 'r', 'i', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'd', 'o', 'c', 't', 'r', 'i', 'n', 'a', 't', 'o', 'r', '\n',
        'i', 'n', 'd', 'o', 'c', 't', 'r', 'i', 'n', 'a', 't', 'o', 'r', 's', '\n',
        'i', 'n', 'd', 'o', 'l', 'e', '\n',
        'i', 'n', 'd', 'o', 'l', 'e', 'n', 'c', 'e', '\n',
        'i', 'n', 'd', 'o', 'l', 'e', 'n', 't', '\n',
        'i', 'n', 'd', 'o', 'l', 'e', 'n', 't', 'l', 'y', '\n',
        'i', 'n', 'd', 'o', 'm', 'i', 't', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'd', 'o', 'o', 'r', '\n',
        'i', 'n', 'd', 'o', 'o', 'r', 's', '\n',
        'i', 'n', 'd', 'o', 'r', 's', 'e', 'd', '\n',
        'i', 'n', 'd', 'o', 'r', 's', 'e', 's', '\n',
        'i', 'n', 'd', 'r', 'a', 'w', 'n', '\n',
        'i', 'n', 'd', 'u', 'b', 'i', 't', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'd', 'u', 'b', 'i', 't', 'a', 'b', 'l', 'y', '\n',
        'i', 'n', 'd', 'u', 'c', 'e', '\n',
        'i', 'n', 'd', 'u', 'c', 'e', 'd', '\n',
        'i', 'n', 'd', 'u', 'c', 'e', 'm', 'e', 'n', 't', '\n',
        'i', 'n', 'd', 'u', 'c', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'i', 'n', 'd', 'u', 'c', 'e', 's', '\n',
        'i', 'n', 'd', 'u', 'c', 'i', 'b', 'l', 'e', '\n',
        'i', 'n', 'd', 'u', 'c', 'i', 'n', 'g', '\n',
        'i', 'n', 'd', 'u', 'c', 't', '\n',
        'i', 'n', 'd', 'u', 'c', 't', 'a', 'n', 'c', 'e', '\n',
        'i', 'n', 'd', 'u', 'c', 't', 'e', 'd', '\n',
        'i', 'n', 'd', 'u', 'c', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'd', 'u', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'd', 'u', 'c', 't', 'i', 'v', 'e', '\n',
        'i', 'n', 'd', 'u', 'c', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'i', 'n', 'd', 'u', 'c', 't', 'o', 'r', '\n',
        'i', 'n', 'd', 'u', 'c', 't', 'o', 'r', 's', '\n',
        'i', 'n', 'd', 'u', 'c', 't', 's', '\n',
        'i', 'n', 'd', 'u', 'l', 'g', 'e', '\n',
        'i', 'n', 'd', 'u', 'l', 'g', 'e', 'd', '\n',
        'i', 'n', 'd', 'u', 'l', 'g', 'e', 'n', 'c', 'e', '\n',
        'i', 'n', 'd', 'u', 'l', 'g', 'e', 'n', 'c', 'e', 's', '\n',
        'i', 'n', 'd', 'u', 'l', 'g', 'e', 'n', 't', '\n',
        'i', 'n', 'd', 'u', 'l', 'g', 'e', 'n', 't', 'l', 'y', '\n',
        'i', 'n', 'd', 'u', 'l', 'g', 'e', 'r', '\n',
        'i', 'n', 'd', 'u', 'l', 'g', 'e', 's', '\n',
        'i', 'n', 'd', 'u', 'l', 'g', 'i', 'n', 'g', '\n',
        'i', 'n', 'd', 'u', 'n', 'a', '\n',
        'i', 'n', 'd', 'u', 's', 't', 'r', 'i', 'a', 'l', '\n',
        'i', 'n', 'd', 'u', 's', 't', 'r', 'i', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'd', 'u', 's', 't', 'r', 'i', 'a', 'l', 'i', 's', 'e', '\n',
        'i', 'n', 'd', 'u', 's', 't', 'r', 'i', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'i', 'n', 'd', 'u', 's', 't', 'r', 'i', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'i', 'n', 'd', 'u', 's', 't', 'r', 'i', 'a', 'l', 'i', 's', 'm', '\n',
        'i', 'n', 'd', 'u', 's', 't', 'r', 'i', 'a', 'l', 'i', 's', 't', '\n',
        'i', 'n', 'd', 'u', 's', 't', 'r', 'i', 'a', 'l', 'i', 's', 't', 's', '\n',
        'i', 'n', 'd', 'u', 's', 't', 'r', 'i', 'a', 'l', 'l', 'y', '\n',
        'i', 'n', 'd', 'u', 's', 't', 'r', 'i', 'e', 's', '\n',
        'i', 'n', 'd', 'u', 's', 't', 'r', 'i', 'o', 'u', 's', '\n',
        'i', 'n', 'd', 'u', 's', 't', 'r', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'i', 'n', 'd', 'u', 's', 't', 'r', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'i', 'n', 'd', 'u', 's', 't', 'r', 'y', '\n',
        'i', 'n', 'e', 'b', 'r', 'i', 'a', 't', 'e', '\n',
        'i', 'n', 'e', 'b', 'r', 'i', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 'e', 'b', 'r', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'e', 'd', 'i', 'b', 'l', 'e', '\n',
        'i', 'n', 'e', 'f', 'f', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'e', 'f', 'f', 'e', 'c', 't', 'i', 'v', 'e', '\n',
        'i', 'n', 'e', 'f', 'f', 'e', 'c', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'i', 'n', 'e', 'f', 'f', 'e', 'c', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'i', 'n', 'e', 'f', 'f', 'e', 'c', 't', 'u', 'a', 'l', '\n',
        'i', 'n', 'e', 'f', 'f', 'e', 'c', 't', 'u', 'a', 'l', 'l', 'y', '\n',
        'i', 'n', 'e', 'f', 'f', 'e', 'c', 't', 'u', 'a', 'l', 'n', 'e', 's', 's', '\n',
        'i', 'n', 'e', 'f', 'f', 'i', 'c', 'i', 'e', 'n', 'c', 'i', 'e', 's', '\n',
        'i', 'n', 'e', 'f', 'f', 'i', 'c', 'i', 'e', 'n', 'c', 'y', '\n',
        'i', 'n', 'e', 'f', 'f', 'i', 'c', 'i', 'e', 'n', 't', '\n',
        'i', 'n', 'e', 'f', 'f', 'i', 'c', 'i', 'e', 'n', 't', 'l', 'y', '\n',
        'i', 'n', 'e', 'l', 'a', 's', 't', 'i', 'c', '\n',
        'i', 'n', 'e', 'l', 'e', 'g', 'a', 'n', 'c', 'e', '\n',
        'i', 'n', 'e', 'l', 'e', 'g', 'a', 'n', 't', '\n',
        'i', 'n', 'e', 'l', 'e', 'g', 'a', 'n', 't', 'l', 'y', '\n',
        'i', 'n', 'e', 'l', 'i', 'g', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 'e', 'l', 'i', 'g', 'i', 'b', 'l', 'e', '\n',
        'i', 'n', 'e', 'l', 'u', 'c', 't', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'e', 'l', 'u', 'c', 't', 'a', 'b', 'l', 'y', '\n',
        'i', 'n', 'e', 'p', 't', '\n',
        'i', 'n', 'e', 'p', 't', 'i', 't', 'u', 'd', 'e', '\n',
        'i', 'n', 'e', 'p', 't', 'l', 'y', '\n',
        'i', 'n', 'e', 'p', 't', 'n', 'e', 's', 's', '\n',
        'i', 'n', 'e', 'q', 'u', 'a', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'i', 'n', 'e', 'q', 'u', 'a', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 'e', 'q', 'u', 'i', 't', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'e', 'q', 'u', 'i', 't', 'i', 'e', 's', '\n',
        'i', 'n', 'e', 'q', 'u', 'i', 't', 'y', '\n',
        'i', 'n', 'e', 'r', 'a', 'd', 'i', 'c', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'e', 'r', 'a', 'd', 'i', 'c', 'a', 'b', 'l', 'y', '\n',
        'i', 'n', 'e', 'r', 't', '\n',
        'i', 'n', 'e', 'r', 't', 'i', 'a', '\n',
        'i', 'n', 'e', 'r', 't', 'i', 'a', 'l', '\n',
        'i', 'n', 'e', 'r', 't', 'n', 'e', 's', 's', '\n',
        'i', 'n', 'e', 's', 'c', 'a', 'p', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'e', 's', 'c', 'a', 'p', 'a', 'b', 'l', 'y', '\n',
        'i', 'n', 'e', 's', 's', 'e', 'n', 't', 'i', 'a', 'l', '\n',
        'i', 'n', 'e', 's', 't', 'i', 'm', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'e', 's', 't', 'i', 'm', 'a', 'b', 'l', 'y', '\n',
        'i', 'n', 'e', 'v', 'i', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 'e', 'v', 'i', 't', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'e', 'v', 'i', 't', 'a', 'b', 'l', 'y', '\n',
        'i', 'n', 'e', 'x', 'a', 'c', 't', '\n',
        'i', 'n', 'e', 'x', 'a', 'c', 't', 'i', 't', 'u', 'd', 'e', '\n',
        'i', 'n', 'e', 'x', 'a', 'c', 't', 'i', 't', 'u', 'd', 'e', 's', '\n',
        'i', 'n', 'e', 'x', 'c', 'u', 's', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'e', 'x', 'c', 'u', 's', 'a', 'b', 'l', 'y', '\n',
        'i', 'n', 'e', 'x', 'h', 'a', 'u', 's', 't', 'i', 'b', 'l', 'e', '\n',
        'i', 'n', 'e', 'x', 'h', 'a', 'u', 's', 't', 'i', 'b', 'l', 'y', '\n',
        'i', 'n', 'e', 'x', 'o', 'r', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 'e', 'x', 'o', 'r', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'e', 'x', 'o', 'r', 'a', 'b', 'l', 'y', '\n',
        'i', 'n', 'e', 'x', 'p', 'e', 'd', 'i', 'e', 'n', 't', '\n',
        'i', 'n', 'e', 'x', 'p', 'e', 'n', 's', 'i', 'v', 'e', '\n',
        'i', 'n', 'e', 'x', 'p', 'e', 'n', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'i', 'n', 'e', 'x', 'p', 'e', 'r', 'i', 'e', 'n', 'c', 'e', '\n',
        'i', 'n', 'e', 'x', 'p', 'e', 'r', 'i', 'e', 'n', 'c', 'e', 'd', '\n',
        'i', 'n', 'e', 'x', 'p', 'e', 'r', 't', '\n',
        'i', 'n', 'e', 'x', 'p', 'e', 'r', 't', 'l', 'y', '\n',
        'i', 'n', 'e', 'x', 'p', 'l', 'i', 'c', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'e', 'x', 'p', 'l', 'i', 'c', 'a', 'b', 'l', 'y', '\n',
        'i', 'n', 'e', 'x', 'p', 'r', 'e', 's', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 'e', 'x', 'p', 'r', 'e', 's', 's', 'i', 'b', 'l', 'e', '\n',
        'i', 'n', 'e', 'x', 'p', 'r', 'e', 's', 's', 'i', 'b', 'l', 'y', '\n',
        'i', 'n', 'e', 'x', 't', 'e', 'n', 's', 'i', 'b', 'l', 'e', '\n',
        'i', 'n', 'e', 'x', 't', 'i', 'n', 'g', 'u', 'i', 's', 'h', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'e', 'x', 't', 'r', 'i', 'c', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'e', 'x', 't', 'r', 'i', 'c', 'a', 'b', 'l', 'y', '\n',
        'i', 'n', 'f', 'a', 'l', 'l', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 'f', 'a', 'l', 'l', 'i', 'b', 'l', 'e', '\n',
        'i', 'n', 'f', 'a', 'l', 'l', 'i', 'b', 'l', 'y', '\n',
        'i', 'n', 'f', 'a', 'm', 'o', 'u', 's', '\n',
        'i', 'n', 'f', 'a', 'm', 'o', 'u', 's', 'l', 'y', '\n',
        'i', 'n', 'f', 'a', 'm', 'y', '\n',
        'i', 'n', 'f', 'a', 'n', 'c', 'y', '\n',
        'i', 'n', 'f', 'a', 'n', 't', '\n',
        'i', 'n', 'f', 'a', 'n', 't', 'a', '\n',
        'i', 'n', 'f', 'a', 'n', 't', 'e', '\n',
        'i', 'n', 'f', 'a', 'n', 't', 'i', 'c', 'i', 'd', 'e', '\n',
        'i', 'n', 'f', 'a', 'n', 't', 'i', 'l', 'e', '\n',
        'i', 'n', 'f', 'a', 'n', 't', 'r', 'y', '\n',
        'i', 'n', 'f', 'a', 'n', 't', 'r', 'y', 'm', 'a', 'n', '\n',
        'i', 'n', 'f', 'a', 'n', 't', 'r', 'y', 'm', 'e', 'n', '\n',
        'i', 'n', 'f', 'a', 'n', 't', 's', '\n',
        'i', 'n', 'f', 'a', 'r', 'c', 't', '\n',
        'i', 'n', 'f', 'a', 'r', 'c', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'f', 'a', 'r', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'f', 'a', 't', 'u', 'a', 't', 'e', '\n',
        'i', 'n', 'f', 'a', 't', 'u', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 'f', 'a', 't', 'u', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'f', 'a', 't', 'u', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'f', 'e', 'a', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 'f', 'e', 'a', 's', 'i', 'b', 'l', 'e', '\n',
        'i', 'n', 'f', 'e', 'c', 't', '\n',
        'i', 'n', 'f', 'e', 'c', 't', 'e', 'd', '\n',
        'i', 'n', 'f', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'f', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'f', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'f', 'e', 'c', 't', 'i', 'o', 'u', 's', '\n',
        'i', 'n', 'f', 'e', 'c', 't', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'i', 'n', 'f', 'e', 'c', 't', 'i', 'v', 'e', '\n',
        'i', 'n', 'f', 'e', 'c', 't', 's', '\n',
        'i', 'n', 'f', 'e', 'l', 'i', 'c', 'i', 't', 'i', 'e', 's', '\n',
        'i', 'n', 'f', 'e', 'l', 'i', 'c', 'i', 't', 'o', 'u', 's', '\n',
        'i', 'n', 'f', 'e', 'l', 'i', 'c', 'i', 't', 'o', 'u', 's', 'l', 'y', '\n',
        'i', 'n', 'f', 'e', 'l', 'i', 'c', 'i', 't', 'y', '\n',
        'i', 'n', 'f', 'e', 'r', '\n',
        'i', 'n', 'f', 'e', 'r', 'e', 'n', 'c', 'e', '\n',
        'i', 'n', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 's', '\n',
        'i', 'n', 'f', 'e', 'r', 'e', 'n', 't', 'i', 'a', 'l', '\n',
        'i', 'n', 'f', 'e', 'r', 'e', 'n', 't', 'i', 'a', 'l', 'l', 'y', '\n',
        'i', 'n', 'f', 'e', 'r', 'i', 'o', 'r', '\n',
        'i', 'n', 'f', 'e', 'r', 'i', 'o', 'r', 'i', 't', 'y', '\n',
        'i', 'n', 'f', 'e', 'r', 'i', 'o', 'r', 's', '\n',
        'i', 'n', 'f', 'e', 'r', 'n', 'a', 'l', '\n',
        'i', 'n', 'f', 'e', 'r', 'n', 'a', 'l', 'l', 'y', '\n',
        'i', 'n', 'f', 'e', 'r', 'n', 'o', '\n',
        'i', 'n', 'f', 'e', 'r', 'r', 'e', 'd', '\n',
        'i', 'n', 'f', 'e', 'r', 'r', 'i', 'n', 'g', '\n',
        'i', 'n', 'f', 'e', 'r', 's', '\n',
        'i', 'n', 'f', 'e', 'r', 't', 'i', 'l', 'e', '\n',
        'i', 'n', 'f', 'e', 'r', 't', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 'f', 'e', 's', 't', '\n',
        'i', 'n', 'f', 'e', 's', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'f', 'e', 's', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'f', 'e', 's', 't', 'e', 'd', '\n',
        'i', 'n', 'f', 'e', 's', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'f', 'e', 's', 't', 's', '\n',
        'i', 'n', 'f', 'i', 'd', 'e', 'l', '\n',
        'i', 'n', 'f', 'i', 'd', 'e', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'i', 'n', 'f', 'i', 'd', 'e', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 'f', 'i', 'd', 'e', 'l', 's', '\n',
        'i', 'n', 'f', 'i', 'e', 'l', 'd', '\n',
        'i', 'n', 'f', 'i', 'g', 'h', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'f', 'i', 'l', 'l', '\n',
        'i', 'n', 'f', 'i', 'l', 'l', 'i', 'n', 'g', '\n',
        'i', 'n', 'f', 'i', 'l', 't', 'r', 'a', 't', 'e', '\n',
        'i', 'n', 'f', 'i', 'l', 't', 'r', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 'f', 'i', 'l', 't', 'r', 'a', 't', 'e', 's', '\n',
        'i', 'n', 'f', 'i', 'l', 't', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'f', 'i', 'l', 't', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'f', 'i', 'l', 't', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'f', 'i', 'l', 't', 'r', 'a', 't', 'o', 'r', '\n',
        'i', 'n', 'f', 'i', 'l', 't', 'r', 'a', 't', 'o', 'r', 's', '\n',
        'i', 'n', 'f', 'i', 'n', 'i', 't', 'e', '\n',
        'i', 'n', 'f', 'i', 'n', 'i', 't', 'e', 'l', 'y', '\n',
        'i', 'n', 'f', 'i', 'n', 'i', 't', 'e', 's', 'i', 'm', 'a', 'l', '\n',
        'i', 'n', 'f', 'i', 'n', 'i', 't', 'e', 's', 'i', 'm', 'a', 'l', 'l', 'y', '\n',
        'i', 'n', 'f', 'i', 'n', 'i', 't', 'e', 's', 'i', 'm', 'a', 'l', 's', '\n',
        'i', 'n', 'f', 'i', 'n', 'i', 't', 'i', 'e', 's', '\n',
        'i', 'n', 'f', 'i', 'n', 'i', 't', 'i', 'v', 'e', '\n',
        'i', 'n', 'f', 'i', 'n', 'i', 't', 'i', 'v', 'e', 's', '\n',
        'i', 'n', 'f', 'i', 'n', 'i', 't', 'u', 'd', 'e', '\n',
        'i', 'n', 'f', 'i', 'n', 'i', 't', 'y', '\n',
        'i', 'n', 'f', 'i', 'r', 'm', '\n',
        'i', 'n', 'f', 'i', 'r', 'm', 'a', 'r', 'i', 'e', 's', '\n',
        'i', 'n', 'f', 'i', 'r', 'm', 'a', 'r', 'y', '\n',
        'i', 'n', 'f', 'i', 'r', 'm', 'i', 't', 'i', 'e', 's', '\n',
        'i', 'n', 'f', 'i', 'r', 'm', 'i', 't', 'y', '\n',
        'i', 'n', 'f', 'i', 'x', '\n',
        'i', 'n', 'f', 'l', 'a', 'm', 'e', '\n',
        'i', 'n', 'f', 'l', 'a', 'm', 'e', 'd', '\n',
        'i', 'n', 'f', 'l', 'a', 'm', 'e', 's', '\n',
        'i', 'n', 'f', 'l', 'a', 'm', 'i', 'n', 'g', '\n',
        'i', 'n', 'f', 'l', 'a', 'm', 'm', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'f', 'l', 'a', 'm', 'm', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'f', 'l', 'a', 'm', 'm', 'a', 't', 'o', 'r', 'y', '\n',
        'i', 'n', 'f', 'l', 'a', 't', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'f', 'l', 'a', 't', 'e', '\n',
        'i', 'n', 'f', 'l', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 'f', 'l', 'a', 't', 'e', 's', '\n',
        'i', 'n', 'f', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'f', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'f', 'l', 'a', 't', 'i', 'o', 'n', 'a', 'r', 'y', '\n',
        'i', 'n', 'f', 'l', 'e', 'c', 't', '\n',
        'i', 'n', 'f', 'l', 'e', 'c', 't', 'e', 'd', '\n',
        'i', 'n', 'f', 'l', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'f', 'l', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'f', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'i', 'n', 'f', 'l', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'f', 'l', 'e', 'c', 't', 's', '\n',
        'i', 'n', 'f', 'l', 'e', 'x', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 'f', 'l', 'e', 'x', 'i', 'b', 'l', 'e', '\n',
        'i', 'n', 'f', 'l', 'e', 'x', 'i', 'b', 'l', 'y', '\n',
        'i', 'n', 'f', 'l', 'e', 'x', 'i', 'o', 'n', '\n',
        'i', 'n', 'f', 'l', 'e', 'x', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'f', 'l', 'i', 'c', 't', '\n',
        'i', 'n', 'f', 'l', 'i', 'c', 't', 'e', 'd', '\n',
        'i', 'n', 'f', 'l', 'i', 'c', 't', 'e', 'r', '\n',
        'i', 'n', 'f', 'l', 'i', 'c', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'f', 'l', 'i', 'c', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'f', 'l', 'i', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'f', 'l', 'i', 'c', 't', 's', '\n',
        'i', 'n', 'f', 'l', 'o', 'w', '\n',
        'i', 'n', 'f', 'l', 'o', 'w', 'i', 'n', 'g', '\n',
        'i', 'n', 'f', 'l', 'o', 'w', 's', '\n',
        'i', 'n', 'f', 'l', 'u', 'e', 'n', 'c', 'e', '\n',
        'i', 'n', 'f', 'l', 'u', 'e', 'n', 'c', 'e', 'd', '\n',
        'i', 'n', 'f', 'l', 'u', 'e', 'n', 'c', 'e', 's', '\n',
        'i', 'n', 'f', 'l', 'u', 'e', 'n', 'c', 'i', 'n', 'g', '\n',
        'i', 'n', 'f', 'l', 'u', 'e', 'n', 't', 'i', 'a', 'l', '\n',
        'i', 'n', 'f', 'l', 'u', 'e', 'n', 'z', 'a', '\n',
        'i', 'n', 'f', 'l', 'u', 'x', '\n',
        'i', 'n', 'f', 'l', 'u', 'x', 'e', 's', '\n',
        'i', 'n', 'f', 'o', '\n',
        'i', 'n', 'f', 'o', 'r', 'm', '\n',
        'i', 'n', 'f', 'o', 'r', 'm', 'a', 'l', '\n',
        'i', 'n', 'f', 'o', 'r', 'm', 'a', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 'f', 'o', 'r', 'm', 'a', 'l', 'l', 'y', '\n',
        'i', 'n', 'f', 'o', 'r', 'm', 'a', 'n', 't', '\n',
        'i', 'n', 'f', 'o', 'r', 'm', 'a', 'n', 't', 's', '\n',
        'i', 'n', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'c', 's', '\n',
        'i', 'n', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'i', 'n', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'v', 'e', '\n',
        'i', 'n', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'i', 'n', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'i', 'n', 'f', 'o', 'r', 'm', 'a', 't', 'o', 'r', 'y', '\n',
        'i', 'n', 'f', 'o', 'r', 'm', 'e', 'd', '\n',
        'i', 'n', 'f', 'o', 'r', 'm', 'e', 'r', '\n',
        'i', 'n', 'f', 'o', 'r', 'm', 'e', 'r', 's', '\n',
        'i', 'n', 'f', 'o', 'r', 'm', 'i', 'n', 'g', '\n',
        'i', 'n', 'f', 'o', 'r', 'm', 's', '\n',
        'i', 'n', 'f', 'r', 'a', '\n',
        'i', 'n', 'f', 'r', 'a', 'c', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'f', 'r', 'a', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'f', 'r', 'a', 'r', 'e', 'd', '\n',
        'i', 'n', 'f', 'r', 'a', 's', 't', 'r', 'u', 'c', 't', 'u', 'r', 'a', 'l', '\n',
        'i', 'n', 'f', 'r', 'a', 's', 't', 'r', 'u', 'c', 't', 'u', 'r', 'e', '\n',
        'i', 'n', 'f', 'r', 'a', 's', 't', 'r', 'u', 'c', 't', 'u', 'r', 'e', 's', '\n',
        'i', 'n', 'f', 'r', 'e', 'q', 'u', 'e', 'n', 'c', 'y', '\n',
        'i', 'n', 'f', 'r', 'e', 'q', 'u', 'e', 'n', 't', '\n',
        'i', 'n', 'f', 'r', 'e', 'q', 'u', 'e', 'n', 't', 'l', 'y', '\n',
        'i', 'n', 'f', 'r', 'i', 'n', 'g', 'e', '\n',
        'i', 'n', 'f', 'r', 'i', 'n', 'g', 'e', 'd', '\n',
        'i', 'n', 'f', 'r', 'i', 'n', 'g', 'e', 'm', 'e', 'n', 't', '\n',
        'i', 'n', 'f', 'r', 'i', 'n', 'g', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'i', 'n', 'f', 'r', 'i', 'n', 'g', 'e', 's', '\n',
        'i', 'n', 'f', 'r', 'i', 'n', 'g', 'i', 'n', 'g', '\n',
        'i', 'n', 'f', 'u', 'r', 'i', 'a', 't', 'e', '\n',
        'i', 'n', 'f', 'u', 'r', 'i', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 'f', 'u', 'r', 'i', 'a', 't', 'e', 's', '\n',
        'i', 'n', 'f', 'u', 'r', 'i', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'f', 'u', 'r', 'i', 'a', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'i', 'n', 'f', 'u', 's', 'e', '\n',
        'i', 'n', 'f', 'u', 's', 'e', 'd', '\n',
        'i', 'n', 'f', 'u', 's', 'e', 's', '\n',
        'i', 'n', 'f', 'u', 's', 'i', 'n', 'g', '\n',
        'i', 'n', 'f', 'u', 's', 'i', 'o', 'n', '\n',
        'i', 'n', 'f', 'u', 's', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'g', 'a', 't', 'h', 'e', 'r', 'e', 'd', '\n',
        'i', 'n', 'g', 'e', 'n', 'i', 'o', 'u', 's', '\n',
        'i', 'n', 'g', 'e', 'n', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'i', 'n', 'g', 'e', 'n', 'u', 'i', 't', 'y', '\n',
        'i', 'n', 'g', 'e', 'n', 'u', 'o', 'u', 's', '\n',
        'i', 'n', 'g', 'e', 'n', 'u', 'o', 'u', 's', 'l', 'y', '\n',
        'i', 'n', 'g', 'e', 'n', 'u', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'i', 'n', 'g', 'e', 's', 't', '\n',
        'i', 'n', 'g', 'e', 's', 't', 'e', 'd', '\n',
        'i', 'n', 'g', 'e', 's', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'g', 'e', 's', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'g', 'l', 'o', 'r', 'i', 'o', 'u', 's', '\n',
        'i', 'n', 'g', 'o', 'i', 'n', 'g', '\n',
        'i', 'n', 'g', 'o', 't', '\n',
        'i', 'n', 'g', 'o', 't', 's', '\n',
        'i', 'n', 'g', 'r', 'a', 'i', 'n', 'e', 'd', '\n',
        'i', 'n', 'g', 'r', 'a', 't', 'e', '\n',
        'i', 'n', 'g', 'r', 'a', 't', 'i', 'a', 't', 'e', '\n',
        'i', 'n', 'g', 'r', 'a', 't', 'i', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 'g', 'r', 'a', 't', 'i', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'g', 'r', 'a', 't', 'i', 'a', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'i', 'n', 'g', 'r', 'a', 't', 'i', 't', 'u', 'd', 'e', '\n',
        'i', 'n', 'g', 'r', 'e', 'd', 'i', 'e', 'n', 't', '\n',
        'i', 'n', 'g', 'r', 'e', 'd', 'i', 'e', 'n', 't', 's', '\n',
        'i', 'n', 'g', 'r', 'e', 's', 's', '\n',
        'i', 'n', 'g', 'r', 'e', 's', 's', 'i', 'o', 'n', '\n',
        'i', 'n', 'g', 'r', 'o', 'w', 'n', '\n',
        'i', 'n', 'h', 'a', 'b', 'i', 't', '\n',
        'i', 'n', 'h', 'a', 'b', 'i', 't', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'h', 'a', 'b', 'i', 't', 'a', 'n', 't', '\n',
        'i', 'n', 'h', 'a', 'b', 'i', 't', 'a', 'n', 't', 's', '\n',
        'i', 'n', 'h', 'a', 'b', 'i', 't', 'e', 'd', '\n',
        'i', 'n', 'h', 'a', 'b', 'i', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'h', 'a', 'b', 'i', 't', 's', '\n',
        'i', 'n', 'h', 'a', 'l', 'a', 'n', 't', '\n',
        'i', 'n', 'h', 'a', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'h', 'a', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'h', 'a', 'l', 'e', '\n',
        'i', 'n', 'h', 'a', 'l', 'e', 'd', '\n',
        'i', 'n', 'h', 'a', 'l', 'e', 'r', '\n',
        'i', 'n', 'h', 'a', 'l', 'e', 'r', 's', '\n',
        'i', 'n', 'h', 'a', 'l', 'e', 's', '\n',
        'i', 'n', 'h', 'a', 'l', 'i', 'n', 'g', '\n',
        'i', 'n', 'h', 'e', 'r', 'e', 'n', 't', '\n',
        'i', 'n', 'h', 'e', 'r', 'e', 'n', 't', 'l', 'y', '\n',
        'i', 'n', 'h', 'e', 'r', 'i', 't', '\n',
        'i', 'n', 'h', 'e', 'r', 'i', 't', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'h', 'e', 'r', 'i', 't', 'a', 'n', 'c', 'e', '\n',
        'i', 'n', 'h', 'e', 'r', 'i', 't', 'a', 'n', 'c', 'e', 's', '\n',
        'i', 'n', 'h', 'e', 'r', 'i', 't', 'e', 'd', '\n',
        'i', 'n', 'h', 'e', 'r', 'i', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'h', 'e', 'r', 'i', 't', 'o', 'r', '\n',
        'i', 'n', 'h', 'e', 'r', 'i', 't', 'o', 'r', 's', '\n',
        'i', 'n', 'h', 'e', 'r', 'i', 't', 's', '\n',
        'i', 'n', 'h', 'i', 'b', 'i', 't', '\n',
        'i', 'n', 'h', 'i', 'b', 'i', 't', 'e', 'd', '\n',
        'i', 'n', 'h', 'i', 'b', 'i', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'h', 'i', 'b', 'i', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'h', 'i', 'b', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'h', 'i', 'b', 'i', 't', 'o', 'r', '\n',
        'i', 'n', 'h', 'i', 'b', 'i', 't', 'o', 'r', 's', '\n',
        'i', 'n', 'h', 'i', 'b', 'i', 't', 'o', 'r', 'y', '\n',
        'i', 'n', 'h', 'i', 'b', 'i', 't', 's', '\n',
        'i', 'n', 'h', 'o', 'm', 'o', 'g', 'e', 'n', 'e', 'i', 't', 'i', 'e', 's', '\n',
        'i', 'n', 'h', 'o', 'm', 'o', 'g', 'e', 'n', 'e', 'i', 't', 'y', '\n',
        'i', 'n', 'h', 'o', 'm', 'o', 'g', 'e', 'n', 'e', 'o', 'u', 's', '\n',
        'i', 'n', 'h', 'o', 's', 'p', 'i', 't', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'h', 'o', 'u', 's', 'e', '\n',
        'i', 'n', 'h', 'u', 'm', 'a', 'n', '\n',
        'i', 'n', 'h', 'u', 'm', 'a', 'n', 'e', '\n',
        'i', 'n', 'h', 'u', 'm', 'a', 'n', 'e', 'l', 'y', '\n',
        'i', 'n', 'h', 'u', 'm', 'a', 'n', 'i', 't', 'i', 'e', 's', '\n',
        'i', 'n', 'h', 'u', 'm', 'a', 'n', 'i', 't', 'y', '\n',
        'i', 'n', 'h', 'u', 'm', 'a', 'n', 'l', 'y', '\n',
        'i', 'n', 'i', 'm', 'i', 'c', 'a', 'l', '\n',
        'i', 'n', 'i', 'm', 'i', 't', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'i', 'm', 'i', 't', 'a', 'b', 'l', 'y', '\n',
        'i', 'n', 'i', 'q', 'u', 'i', 't', 'i', 'e', 's', '\n',
        'i', 'n', 'i', 'q', 'u', 'i', 't', 'o', 'u', 's', '\n',
        'i', 'n', 'i', 'q', 'u', 'i', 't', 'o', 'u', 's', 'l', 'y', '\n',
        'i', 'n', 'i', 'q', 'u', 'i', 't', 'y', '\n',
        'i', 'n', 'i', 't', 'i', 'a', 'l', '\n',
        'i', 'n', 'i', 't', 'i', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'i', 't', 'i', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'i', 't', 'i', 'a', 'l', 'i', 's', 'e', '\n',
        'i', 'n', 'i', 't', 'i', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'i', 'n', 'i', 't', 'i', 'a', 'l', 'i', 's', 'e', 's', '\n',
        'i', 'n', 'i', 't', 'i', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'i', 'n', 'i', 't', 'i', 'a', 'l', 'l', 'e', 'd', '\n',
        'i', 'n', 'i', 't', 'i', 'a', 'l', 'l', 'y', '\n',
        'i', 'n', 'i', 't', 'i', 'a', 'l', 's', '\n',
        'i', 'n', 'i', 't', 'i', 'a', 't', 'e', '\n',
        'i', 'n', 'i', 't', 'i', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 'i', 't', 'i', 'a', 't', 'e', 's', '\n',
        'i', 'n', 'i', 't', 'i', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'i', 't', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'i', 't', 'i', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'i', 't', 'i', 'a', 't', 'i', 'v', 'e', '\n',
        'i', 'n', 'i', 't', 'i', 'a', 't', 'i', 'v', 'e', 's', '\n',
        'i', 'n', 'i', 't', 'i', 'a', 't', 'o', 'r', '\n',
        'i', 'n', 'i', 't', 'i', 'a', 't', 'o', 'r', 's', '\n',
        'i', 'n', 'j', 'e', 'c', 't', '\n',
        'i', 'n', 'j', 'e', 'c', 't', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'j', 'e', 'c', 't', 'e', 'd', '\n',
        'i', 'n', 'j', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'j', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'j', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'j', 'e', 'c', 't', 'o', 'r', '\n',
        'i', 'n', 'j', 'e', 'c', 't', 's', '\n',
        'i', 'n', 'j', 'o', 'k', 'e', '\n',
        'i', 'n', 'j', 'o', 'k', 'e', 's', '\n',
        'i', 'n', 'j', 'u', 'd', 'i', 'c', 'i', 'o', 'u', 's', '\n',
        'i', 'n', 'j', 'u', 'd', 'i', 'c', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'i', 'n', 'j', 'u', 'n', 'c', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'j', 'u', 'n', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'j', 'u', 'r', 'e', '\n',
        'i', 'n', 'j', 'u', 'r', 'e', 'd', '\n',
        'i', 'n', 'j', 'u', 'r', 'e', 's', '\n',
        'i', 'n', 'j', 'u', 'r', 'i', 'e', 's', '\n',
        'i', 'n', 'j', 'u', 'r', 'i', 'n', 'g', '\n',
        'i', 'n', 'j', 'u', 'r', 'i', 'o', 'u', 's', '\n',
        'i', 'n', 'j', 'u', 'r', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'i', 'n', 'j', 'u', 'r', 'y', '\n',
        'i', 'n', 'j', 'u', 's', 't', 'i', 'c', 'e', '\n',
        'i', 'n', 'j', 'u', 's', 't', 'i', 'c', 'e', 's', '\n',
        'i', 'n', 'k', '\n',
        'i', 'n', 'k', 'e', 'd', '\n',
        'i', 'n', 'k', 'i', 'e', 'r', '\n',
        'i', 'n', 'k', 'i', 'e', 's', 't', '\n',
        'i', 'n', 'k', 'i', 'n', 'g', '\n',
        'i', 'n', 'k', 'l', 'i', 'n', 'g', '\n',
        'i', 'n', 'k', 'l', 'i', 'n', 'g', 's', '\n',
        'i', 'n', 'k', 'p', 'a', 'd', '\n',
        'i', 'n', 'k', 'p', 'o', 't', '\n',
        'i', 'n', 'k', 'p', 'o', 't', 's', '\n',
        'i', 'n', 'k', 's', '\n',
        'i', 'n', 'k', 's', 't', 'a', 'n', 'd', '\n',
        'i', 'n', 'k', 's', 't', 'a', 'n', 'd', 's', '\n',
        'i', 'n', 'k', 'w', 'e', 'l', 'l', '\n',
        'i', 'n', 'k', 'w', 'e', 'l', 'l', 's', '\n',
        'i', 'n', 'k', 'y', '\n',
        'i', 'n', 'l', 'a', 'i', 'd', '\n',
        'i', 'n', 'l', 'a', 'n', 'd', '\n',
        'i', 'n', 'l', 'a', 'w', '\n',
        'i', 'n', 'l', 'a', 'w', 's', '\n',
        'i', 'n', 'l', 'a', 'y', '\n',
        'i', 'n', 'l', 'a', 'y', 's', '\n',
        'i', 'n', 'l', 'e', 't', '\n',
        'i', 'n', 'l', 'e', 't', 's', '\n',
        'i', 'n', 'm', 'a', 't', 'e', '\n',
        'i', 'n', 'm', 'a', 't', 'e', 's', '\n',
        'i', 'n', 'm', 'o', 's', 't', '\n',
        'i', 'n', 'n', '\n',
        'i', 'n', 'n', 'a', 'r', 'd', 's', '\n',
        'i', 'n', 'n', 'a', 't', 'e', '\n',
        'i', 'n', 'n', 'a', 't', 'e', 'l', 'y', '\n',
        'i', 'n', 'n', 'e', 'r', '\n',
        'i', 'n', 'n', 'e', 'r', 'm', 'o', 's', 't', '\n',
        'i', 'n', 'n', 'e', 'r', 'v', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'n', 'i', 'n', 'g', 's', '\n',
        'i', 'n', 'n', 'k', 'e', 'e', 'p', 'e', 'r', '\n',
        'i', 'n', 'n', 'k', 'e', 'e', 'p', 'e', 'r', 's', '\n',
        'i', 'n', 'n', 'o', 'c', 'e', 'n', 'c', 'e', '\n',
        'i', 'n', 'n', 'o', 'c', 'e', 'n', 't', '\n',
        'i', 'n', 'n', 'o', 'c', 'e', 'n', 't', 'l', 'y', '\n',
        'i', 'n', 'n', 'o', 'c', 'e', 'n', 't', 's', '\n',
        'i', 'n', 'n', 'o', 'c', 'u', 'o', 'u', 's', '\n',
        'i', 'n', 'n', 'o', 'c', 'u', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'i', 'n', 'n', 'o', 'v', 'a', 't', 'e', '\n',
        'i', 'n', 'n', 'o', 'v', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 'n', 'o', 'v', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'n', 'o', 'v', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'n', 'o', 'v', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'n', 'o', 'v', 'a', 't', 'i', 'v', 'e', '\n',
        'i', 'n', 'n', 'o', 'v', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'i', 'n', 'n', 'o', 'v', 'a', 't', 'o', 'r', '\n',
        'i', 'n', 'n', 'o', 'v', 'a', 't', 'o', 'r', 's', '\n',
        'i', 'n', 'n', 'o', 'v', 'a', 't', 'o', 'r', 'y', '\n',
        'i', 'n', 'n', 's', '\n',
        'i', 'n', 'n', 'u', 'e', 'n', 'd', 'o', '\n',
        'i', 'n', 'n', 'u', 'm', 'e', 'r', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'n', 'u', 'm', 'e', 'r', 'a', 'b', 'l', 'y', '\n',
        'i', 'n', 'n', 'u', 'm', 'e', 'r', 'a', 'c', 'y', '\n',
        'i', 'n', 'n', 'u', 'm', 'e', 'r', 'a', 't', 'e', '\n',
        'i', 'n', 'o', 'c', 'u', 'l', 'a', 't', 'e', '\n',
        'i', 'n', 'o', 'c', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 'o', 'c', 'u', 'l', 'a', 't', 'e', 's', '\n',
        'i', 'n', 'o', 'c', 'u', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'o', 'c', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'o', 'c', 'u', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'o', 'f', 'f', 'e', 'n', 's', 'i', 'v', 'e', '\n',
        'i', 'n', 'o', 'p', 'e', 'r', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'o', 'p', 'e', 'r', 'a', 't', 'i', 'v', 'e', '\n',
        'i', 'n', 'o', 'p', 'p', 'o', 'r', 't', 'u', 'n', 'e', '\n',
        'i', 'n', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'e', '\n',
        'i', 'n', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'e', 'l', 'y', '\n',
        'i', 'n', 'o', 'r', 'g', 'a', 'n', 'i', 'c', '\n',
        'i', 'n', 'p', 'u', 't', '\n',
        'i', 'n', 'p', 'u', 't', 's', '\n',
        'i', 'n', 'p', 'u', 't', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'q', 'u', 'e', 's', 't', '\n',
        'i', 'n', 'q', 'u', 'e', 's', 't', 's', '\n',
        'i', 'n', 'q', 'u', 'i', 'r', 'e', '\n',
        'i', 'n', 'q', 'u', 'i', 'r', 'e', 'd', '\n',
        'i', 'n', 'q', 'u', 'i', 'r', 'e', 'r', '\n',
        'i', 'n', 'q', 'u', 'i', 'r', 'e', 'r', 's', '\n',
        'i', 'n', 'q', 'u', 'i', 'r', 'e', 's', '\n',
        'i', 'n', 'q', 'u', 'i', 'r', 'i', 'e', 's', '\n',
        'i', 'n', 'q', 'u', 'i', 'r', 'i', 'n', 'g', '\n',
        'i', 'n', 'q', 'u', 'i', 'r', 'i', 'n', 'g', 'l', 'y', '\n',
        'i', 'n', 'q', 'u', 'i', 'r', 'y', '\n',
        'i', 'n', 'q', 'u', 'i', 's', 'i', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'q', 'u', 'i', 's', 'i', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'i', 'n', 'q', 'u', 'i', 's', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'q', 'u', 'i', 's', 'i', 't', 'i', 'v', 'e', '\n',
        'i', 'n', 'q', 'u', 'i', 's', 'i', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'i', 'n', 'q', 'u', 'i', 's', 'i', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'i', 'n', 'q', 'u', 'i', 's', 'i', 't', 'o', 'r', '\n',
        'i', 'n', 'q', 'u', 'i', 's', 'i', 't', 'o', 'r', 'i', 'a', 'l', '\n',
        'i', 'n', 'q', 'u', 'i', 's', 'i', 't', 'o', 'r', 'i', 'a', 'l', 'l', 'y', '\n',
        'i', 'n', 'q', 'u', 'i', 's', 'i', 't', 'o', 'r', 's', '\n',
        'i', 'n', 'q', 'u', 'o', 'r', 'a', 't', 'e', '\n',
        'i', 'n', 'r', 'o', 'a', 'd', '\n',
        'i', 'n', 'r', 'o', 'a', 'd', 's', '\n',
        'i', 'n', 'r', 'u', 's', 'h', '\n',
        'i', 'n', 's', '\n',
        'i', 'n', 's', 'a', 'l', 'u', 'b', 'r', 'i', 'o', 'u', 's', '\n',
        'i', 'n', 's', 'a', 'n', 'e', '\n',
        'i', 'n', 's', 'a', 'n', 'e', 'l', 'y', '\n',
        'i', 'n', 's', 'a', 'n', 'i', 't', 'a', 'r', 'y', '\n',
        'i', 'n', 's', 'a', 'n', 'i', 't', 'i', 'e', 's', '\n',
        'i', 'n', 's', 'a', 'n', 'i', 't', 'y', '\n',
        'i', 'n', 's', 'a', 't', 'i', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 's', 'a', 't', 'i', 'a', 'b', 'l', 'y', '\n',
        'i', 'n', 's', 'c', 'r', 'i', 'b', 'e', '\n',
        'i', 'n', 's', 'c', 'r', 'i', 'b', 'e', 'd', '\n',
        'i', 'n', 's', 'c', 'r', 'i', 'b', 'i', 'n', 'g', '\n',
        'i', 'n', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 's', 'c', 'r', 'u', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 's', 'c', 'r', 'u', 't', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 's', 'c', 'r', 'u', 't', 'a', 'b', 'l', 'y', '\n',
        'i', 'n', 's', 'e', 'c', 't', '\n',
        'i', 'n', 's', 'e', 'c', 't', 'i', 'c', 'i', 'd', 'a', 'l', '\n',
        'i', 'n', 's', 'e', 'c', 't', 'i', 'c', 'i', 'd', 'e', '\n',
        'i', 'n', 's', 'e', 'c', 't', 'i', 'c', 'i', 'd', 'e', 's', '\n',
        'i', 'n', 's', 'e', 'c', 't', 'i', 'v', 'o', 'r', 'e', 's', '\n',
        'i', 'n', 's', 'e', 'c', 't', 'i', 'v', 'o', 'r', 'o', 'u', 's', '\n',
        'i', 'n', 's', 'e', 'c', 't', 's', '\n',
        'i', 'n', 's', 'e', 'c', 'u', 'r', 'e', '\n',
        'i', 'n', 's', 'e', 'c', 'u', 'r', 'e', 'l', 'y', '\n',
        'i', 'n', 's', 'e', 'c', 'u', 'r', 'i', 't', 'i', 'e', 's', '\n',
        'i', 'n', 's', 'e', 'c', 'u', 'r', 'i', 't', 'y', '\n',
        'i', 'n', 's', 'e', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 's', 'e', 'n', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 's', 'e', 'n', 's', 'i', 'b', 'l', 'e', '\n',
        'i', 'n', 's', 'e', 'n', 's', 'i', 'b', 'l', 'y', '\n',
        'i', 'n', 's', 'e', 'n', 's', 'i', 't', 'i', 'v', 'e', '\n',
        'i', 'n', 's', 'e', 'n', 's', 'i', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'i', 'n', 's', 'e', 'n', 's', 'i', 't', 'i', 'v', 'i', 't', 'y', '\n',
        'i', 'n', 's', 'e', 'p', 'a', 'r', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 's', 'e', 'p', 'a', 'r', 'a', 'b', 'l', 'y', '\n',
        'i', 'n', 's', 'e', 'r', 't', '\n',
        'i', 'n', 's', 'e', 'r', 't', 'e', 'd', '\n',
        'i', 'n', 's', 'e', 'r', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 's', 'e', 'r', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 's', 'e', 'r', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 's', 'e', 'r', 't', 's', '\n',
        'i', 'n', 's', 'e', 't', '\n',
        'i', 'n', 's', 'e', 't', 's', '\n',
        'i', 'n', 's', 'h', 'o', 'r', 'e', '\n',
        'i', 'n', 's', 'i', 'd', 'e', '\n',
        'i', 'n', 's', 'i', 'd', 'e', 'o', 'u', 't', '\n',
        'i', 'n', 's', 'i', 'd', 'e', 'r', '\n',
        'i', 'n', 's', 'i', 'd', 'e', 'r', 's', '\n',
        'i', 'n', 's', 'i', 'd', 'e', 's', '\n',
        'i', 'n', 's', 'i', 'd', 'i', 'o', 'u', 's', '\n',
        'i', 'n', 's', 'i', 'd', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'i', 'n', 's', 'i', 'g', 'h', 't', '\n',
        'i', 'n', 's', 'i', 'g', 'h', 't', 'f', 'u', 'l', '\n',
        'i', 'n', 's', 'i', 'g', 'h', 't', 's', '\n',
        'i', 'n', 's', 'i', 'g', 'n', 'i', 'a', '\n',
        'i', 'n', 's', 'i', 'g', 'n', 'i', 'f', 'i', 'c', 'a', 'n', 'c', 'e', '\n',
        'i', 'n', 's', 'i', 'g', 'n', 'i', 'f', 'i', 'c', 'a', 'n', 't', '\n',
        'i', 'n', 's', 'i', 'g', 'n', 'i', 'f', 'i', 'c', 'a', 'n', 't', 'l', 'y', '\n',
        'i', 'n', 's', 'i', 'n', 'c', 'e', 'r', 'e', '\n',
        'i', 'n', 's', 'i', 'n', 'c', 'e', 'r', 'e', 'l', 'y', '\n',
        'i', 'n', 's', 'i', 'n', 'c', 'e', 'r', 'i', 't', 'y', '\n',
        'i', 'n', 's', 'i', 'n', 'u', 'a', 't', 'e', '\n',
        'i', 'n', 's', 'i', 'n', 'u', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 's', 'i', 'n', 'u', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 's', 'i', 'n', 'u', 'a', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'i', 'n', 's', 'i', 'n', 'u', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 's', 'i', 'n', 'u', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 's', 'i', 'p', 'i', 'd', '\n',
        'i', 'n', 's', 'i', 's', 't', '\n',
        'i', 'n', 's', 'i', 's', 't', 'e', 'd', '\n',
        'i', 'n', 's', 'i', 's', 't', 'e', 'n', 'c', 'e', '\n',
        'i', 'n', 's', 'i', 's', 't', 'e', 'n', 't', '\n',
        'i', 'n', 's', 'i', 's', 't', 'e', 'n', 't', 'l', 'y', '\n',
        'i', 'n', 's', 'i', 's', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 's', 'i', 's', 't', 's', '\n',
        'i', 'n', 's', 'o', 'f', 'a', 'r', '\n',
        'i', 'n', 's', 'o', 'l', 'e', '\n',
        'i', 'n', 's', 'o', 'l', 'e', 'n', 'c', 'e', '\n',
        'i', 'n', 's', 'o', 'l', 'e', 'n', 't', '\n',
        'i', 'n', 's', 'o', 'l', 'e', 'n', 't', 'l', 'y', '\n',
        'i', 'n', 's', 'o', 'l', 'u', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 's', 'o', 'l', 'u', 'b', 'l', 'e', '\n',
        'i', 'n', 's', 'o', 'l', 'v', 'e', 'n', 'c', 'i', 'e', 's', '\n',
        'i', 'n', 's', 'o', 'l', 'v', 'e', 'n', 'c', 'y', '\n',
        'i', 'n', 's', 'o', 'l', 'v', 'e', 'n', 't', '\n',
        'i', 'n', 's', 'o', 'm', 'n', 'i', 'a', '\n',
        'i', 'n', 's', 'o', 'm', 'n', 'i', 'a', 'c', '\n',
        'i', 'n', 's', 'o', 'm', 'n', 'i', 'a', 'c', 's', '\n',
        'i', 'n', 's', 'o', 'u', 'c', 'i', 'a', 'n', 'c', 'e', '\n',
        'i', 'n', 's', 'o', 'u', 'c', 'i', 'a', 'n', 't', '\n',
        'i', 'n', 's', 'p', 'e', 'c', 't', '\n',
        'i', 'n', 's', 'p', 'e', 'c', 't', 'e', 'd', '\n',
        'i', 'n', 's', 'p', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 's', 'p', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 's', 'p', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 's', 'p', 'e', 'c', 't', 'o', 'r', '\n',
        'i', 'n', 's', 'p', 'e', 'c', 't', 'o', 'r', 'a', 't', 'e', '\n',
        'i', 'n', 's', 'p', 'e', 'c', 't', 'o', 'r', 'a', 't', 'e', 's', '\n',
        'i', 'n', 's', 'p', 'e', 'c', 't', 'o', 'r', 's', '\n',
        'i', 'n', 's', 'p', 'e', 'c', 't', 's', '\n',
        'i', 'n', 's', 'p', 'i', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 's', 'p', 'i', 'r', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'i', 'n', 's', 'p', 'i', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 's', 'p', 'i', 'r', 'e', '\n',
        'i', 'n', 's', 'p', 'i', 'r', 'e', 'd', '\n',
        'i', 'n', 's', 'p', 'i', 'r', 'e', 's', '\n',
        'i', 'n', 's', 'p', 'i', 'r', 'i', 'n', 'g', '\n',
        'i', 'n', 's', 't', 'a', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'i', 'n', 's', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 's', 't', 'a', 'l', 'l', '\n',
        'i', 'n', 's', 't', 'a', 'l', 'l', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 's', 't', 'a', 'l', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 's', 't', 'a', 'l', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 's', 't', 'a', 'l', 'l', 'e', 'd', '\n',
        'i', 'n', 's', 't', 'a', 'l', 'l', 'e', 'r', '\n',
        'i', 'n', 's', 't', 'a', 'l', 'l', 'e', 'r', 's', '\n',
        'i', 'n', 's', 't', 'a', 'l', 'l', 'i', 'n', 'g', '\n',
        'i', 'n', 's', 't', 'a', 'l', 'l', 's', '\n',
        'i', 'n', 's', 't', 'a', 'l', 'm', 'e', 'n', 't', '\n',
        'i', 'n', 's', 't', 'a', 'l', 'm', 'e', 'n', 't', 's', '\n',
        'i', 'n', 's', 't', 'a', 'n', 'c', 'e', '\n',
        'i', 'n', 's', 't', 'a', 'n', 'c', 'e', 'd', '\n',
        'i', 'n', 's', 't', 'a', 'n', 'c', 'e', 's', '\n',
        'i', 'n', 's', 't', 'a', 'n', 'c', 'y', '\n',
        'i', 'n', 's', 't', 'a', 'n', 't', '\n',
        'i', 'n', 's', 't', 'a', 'n', 't', 'a', 'n', 'e', 'o', 'u', 's', '\n',
        'i', 'n', 's', 't', 'a', 'n', 't', 'a', 'n', 'e', 'o', 'u', 's', 'l', 'y', '\n',
        'i', 'n', 's', 't', 'a', 'n', 't', 'i', 'a', 't', 'e', '\n',
        'i', 'n', 's', 't', 'a', 'n', 't', 'i', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 's', 't', 'a', 'n', 't', 'i', 'a', 't', 'e', 's', '\n',
        'i', 'n', 's', 't', 'a', 'n', 't', 'i', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 's', 't', 'a', 'n', 't', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 's', 't', 'a', 'n', 't', 'i', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 's', 't', 'a', 'n', 't', 'l', 'y', '\n',
        'i', 'n', 's', 't', 'a', 'n', 't', 's', '\n',
        'i', 'n', 's', 't', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 's', 't', 'e', 'a', 'd', '\n',
        'i', 'n', 's', 't', 'e', 'p', '\n',
        'i', 'n', 's', 't', 'e', 'p', 's', '\n',
        'i', 'n', 's', 't', 'i', 'g', 'a', 't', 'e', '\n',
        'i', 'n', 's', 't', 'i', 'g', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 's', 't', 'i', 'g', 'a', 't', 'e', 's', '\n',
        'i', 'n', 's', 't', 'i', 'g', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 's', 't', 'i', 'g', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 's', 't', 'i', 'g', 'a', 't', 'o', 'r', '\n',
        'i', 'n', 's', 't', 'i', 'g', 'a', 't', 'o', 'r', 's', '\n',
        'i', 'n', 's', 't', 'i', 'l', '\n',
        'i', 'n', 's', 't', 'i', 'l', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 's', 't', 'i', 'l', 'l', 'e', 'd', '\n',
        'i', 'n', 's', 't', 'i', 'l', 'l', 'i', 'n', 'g', '\n',
        'i', 'n', 's', 't', 'i', 'l', 'l', 's', '\n',
        'i', 'n', 's', 't', 'i', 'l', 's', '\n',
        'i', 'n', 's', 't', 'i', 'n', 'c', 't', '\n',
        'i', 'n', 's', 't', 'i', 'n', 'c', 't', 'i', 'v', 'e', '\n',
        'i', 'n', 's', 't', 'i', 'n', 'c', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'i', 'n', 's', 't', 'i', 'n', 'c', 't', 's', '\n',
        'i', 'n', 's', 't', 'i', 'n', 'c', 't', 'u', 'a', 'l', '\n',
        'i', 'n', 's', 't', 'i', 't', 'u', 't', 'e', '\n',
        'i', 'n', 's', 't', 'i', 't', 'u', 't', 'e', 'd', '\n',
        'i', 'n', 's', 't', 'i', 't', 'u', 't', 'e', 's', '\n',
        'i', 'n', 's', 't', 'i', 't', 'u', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 's', 't', 'i', 't', 'u', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 's', 't', 'i', 't', 'u', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'i', 'n', 's', 't', 'i', 't', 'u', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 's', 't', 'i', 't', 'u', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 'e', '\n',
        'i', 'n', 's', 't', 'i', 't', 'u', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'i', 'n', 's', 't', 'i', 't', 'u', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'i', 'n', 's', 't', 'i', 't', 'u', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 'm', '\n',
        'i', 'n', 's', 't', 'i', 't', 'u', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'i', 'n', 's', 't', 'i', 't', 'u', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 's', 't', 'r', 'u', 'c', 't', '\n',
        'i', 'n', 's', 't', 'r', 'u', 'c', 't', 'e', 'd', '\n',
        'i', 'n', 's', 't', 'r', 'u', 'c', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 's', 't', 'r', 'u', 'c', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 's', 't', 'r', 'u', 'c', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'i', 'n', 's', 't', 'r', 'u', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 's', 't', 'r', 'u', 'c', 't', 'i', 'v', 'e', '\n',
        'i', 'n', 's', 't', 'r', 'u', 'c', 't', 'o', 'r', '\n',
        'i', 'n', 's', 't', 'r', 'u', 'c', 't', 'o', 'r', 's', '\n',
        'i', 'n', 's', 't', 'r', 'u', 'c', 't', 's', '\n',
        'i', 'n', 's', 't', 'r', 'u', 'm', 'e', 'n', 't', '\n',
        'i', 'n', 's', 't', 'r', 'u', 'm', 'e', 'n', 't', 'a', 'l', '\n',
        'i', 'n', 's', 't', 'r', 'u', 'm', 'e', 'n', 't', 'a', 'l', 'i', 's', 't', '\n',
        'i', 'n', 's', 't', 'r', 'u', 'm', 'e', 'n', 't', 'a', 'l', 'i', 's', 't', 's', '\n',
        'i', 'n', 's', 't', 'r', 'u', 'm', 'e', 'n', 't', 'a', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 's', 't', 'r', 'u', 'm', 'e', 'n', 't', 'a', 'l', 'l', 'y', '\n',
        'i', 'n', 's', 't', 'r', 'u', 'm', 'e', 'n', 't', 'a', 'l', 's', '\n',
        'i', 'n', 's', 't', 'r', 'u', 'm', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 's', 't', 'r', 'u', 'm', 'e', 'n', 't', 'e', 'd', '\n',
        'i', 'n', 's', 't', 'r', 'u', 'm', 'e', 'n', 't', 's', '\n',
        'i', 'n', 's', 'u', 'b', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'e', '\n',
        'i', 'n', 's', 'u', 'b', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 's', 'u', 'b', 's', 't', 'a', 'n', 't', 'i', 'a', 'l', '\n',
        'i', 'n', 's', 'u', 'f', 'f', 'e', 'r', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 's', 'u', 'f', 'f', 'e', 'r', 'a', 'b', 'l', 'y', '\n',
        'i', 'n', 's', 'u', 'f', 'f', 'i', 'c', 'i', 'e', 'n', 'c', 'y', '\n',
        'i', 'n', 's', 'u', 'f', 'f', 'i', 'c', 'i', 'e', 'n', 't', '\n',
        'i', 'n', 's', 'u', 'f', 'f', 'i', 'c', 'i', 'e', 'n', 't', 'l', 'y', '\n',
        'i', 'n', 's', 'u', 'l', 'a', 'n', 't', '\n',
        'i', 'n', 's', 'u', 'l', 'a', 'r', '\n',
        'i', 'n', 's', 'u', 'l', 'a', 'r', 'i', 't', 'y', '\n',
        'i', 'n', 's', 'u', 'l', 'a', 't', 'e', '\n',
        'i', 'n', 's', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 's', 'u', 'l', 'a', 't', 'e', 's', '\n',
        'i', 'n', 's', 'u', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 's', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 's', 'u', 'l', 'a', 't', 'o', 'r', '\n',
        'i', 'n', 's', 'u', 'l', 'a', 't', 'o', 'r', 's', '\n',
        'i', 'n', 's', 'u', 'l', 'i', 'n', '\n',
        'i', 'n', 's', 'u', 'l', 't', '\n',
        'i', 'n', 's', 'u', 'l', 't', 'e', 'd', '\n',
        'i', 'n', 's', 'u', 'l', 't', 'e', 'r', '\n',
        'i', 'n', 's', 'u', 'l', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 's', 'u', 'l', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'i', 'n', 's', 'u', 'l', 't', 's', '\n',
        'i', 'n', 's', 'u', 'p', 'e', 'r', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 's', 'u', 'p', 'p', 'o', 'r', 't', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 's', 'u', 'r', 'a', 'n', 'c', 'e', '\n',
        'i', 'n', 's', 'u', 'r', 'a', 'n', 'c', 'e', 's', '\n',
        'i', 'n', 's', 'u', 'r', 'e', '\n',
        'i', 'n', 's', 'u', 'r', 'e', 'd', '\n',
        'i', 'n', 's', 'u', 'r', 'e', 'r', '\n',
        'i', 'n', 's', 'u', 'r', 'e', 'r', 's', '\n',
        'i', 'n', 's', 'u', 'r', 'e', 's', '\n',
        'i', 'n', 's', 'u', 'r', 'g', 'e', 'n', 'c', 'y', '\n',
        'i', 'n', 's', 'u', 'r', 'g', 'e', 'n', 't', '\n',
        'i', 'n', 's', 'u', 'r', 'g', 'e', 'n', 't', 's', '\n',
        'i', 'n', 's', 'u', 'r', 'i', 'n', 'g', '\n',
        'i', 'n', 's', 'u', 'r', 'm', 'o', 'u', 'n', 't', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 's', 'u', 'r', 'm', 'o', 'u', 'n', 't', 'a', 'b', 'l', 'y', '\n',
        'i', 'n', 's', 'u', 'r', 'r', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 's', 'u', 'r', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'a', 'r', 'y', '\n',
        'i', 'n', 's', 'u', 'r', 'r', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 't', 'a', 'c', 't', '\n',
        'i', 'n', 't', 'a', 'g', 'l', 'i', 'o', '\n',
        'i', 'n', 't', 'a', 'k', 'e', '\n',
        'i', 'n', 't', 'a', 'k', 'e', 's', '\n',
        'i', 'n', 't', 'a', 'n', 'g', 'i', 'b', 'l', 'e', '\n',
        'i', 'n', 't', 'a', 'n', 'g', 'i', 'b', 'l', 'e', 's', '\n',
        'i', 'n', 't', 'e', 'g', 'e', 'r', '\n',
        'i', 'n', 't', 'e', 'g', 'e', 'r', 's', '\n',
        'i', 'n', 't', 'e', 'g', 'r', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 't', 'e', 'g', 'r', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 't', 'e', 'g', 'r', 'a', 'l', '\n',
        'i', 'n', 't', 'e', 'g', 'r', 'a', 'l', 'l', 'y', '\n',
        'i', 'n', 't', 'e', 'g', 'r', 'a', 'l', 's', '\n',
        'i', 'n', 't', 'e', 'g', 'r', 'a', 'n', 'd', '\n',
        'i', 'n', 't', 'e', 'g', 'r', 'a', 'n', 'd', 's', '\n',
        'i', 'n', 't', 'e', 'g', 'r', 'a', 't', 'e', '\n',
        'i', 'n', 't', 'e', 'g', 'r', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'g', 'r', 'a', 't', 'e', 's', '\n',
        'i', 'n', 't', 'e', 'g', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'e', 'g', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 't', 'e', 'g', 'r', 'a', 't', 'i', 'o', 'n', 'i', 's', 't', '\n',
        'i', 'n', 't', 'e', 'g', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 't', 'e', 'g', 'r', 'a', 't', 'i', 'v', 'e', '\n',
        'i', 'n', 't', 'e', 'g', 'r', 'a', 't', 'o', 'r', '\n',
        'i', 'n', 't', 'e', 'g', 'r', 'a', 't', 'o', 'r', 's', '\n',
        'i', 'n', 't', 'e', 'g', 'r', 'i', 't', 'y', '\n',
        'i', 'n', 't', 'e', 'l', 'l', 'e', 'c', 't', '\n',
        'i', 'n', 't', 'e', 'l', 'l', 'e', 'c', 't', 's', '\n',
        'i', 'n', 't', 'e', 'l', 'l', 'e', 'c', 't', 'u', 'a', 'l', '\n',
        'i', 'n', 't', 'e', 'l', 'l', 'e', 'c', 't', 'u', 'a', 'l', 'i', 's', 'm', '\n',
        'i', 'n', 't', 'e', 'l', 'l', 'e', 'c', 't', 'u', 'a', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 't', 'e', 'l', 'l', 'e', 'c', 't', 'u', 'a', 'l', 'l', 'y', '\n',
        'i', 'n', 't', 'e', 'l', 'l', 'e', 'c', 't', 'u', 'a', 'l', 's', '\n',
        'i', 'n', 't', 'e', 'l', 'l', 'i', 'g', 'e', 'n', 'c', 'e', '\n',
        'i', 'n', 't', 'e', 'l', 'l', 'i', 'g', 'e', 'n', 'c', 'e', 's', '\n',
        'i', 'n', 't', 'e', 'l', 'l', 'i', 'g', 'e', 'n', 't', '\n',
        'i', 'n', 't', 'e', 'l', 'l', 'i', 'g', 'e', 'n', 't', 'l', 'y', '\n',
        'i', 'n', 't', 'e', 'l', 'l', 'i', 'g', 'e', 'n', 't', 's', 'i', 'a', '\n',
        'i', 'n', 't', 'e', 'l', 'l', 'i', 'g', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 't', 'e', 'l', 'l', 'i', 'g', 'i', 'b', 'l', 'e', '\n',
        'i', 'n', 't', 'e', 'l', 'l', 'i', 'g', 'i', 'b', 'l', 'y', '\n',
        'i', 'n', 't', 'e', 'm', 'p', 'e', 'r', 'a', 'n', 'c', 'e', '\n',
        'i', 'n', 't', 'e', 'm', 'p', 'e', 'r', 'a', 't', 'e', '\n',
        'i', 'n', 't', 'e', 'n', 'd', '\n',
        'i', 'n', 't', 'e', 'n', 'd', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'e', 'n', 'd', 's', '\n',
        'i', 'n', 't', 'e', 'n', 's', 'e', '\n',
        'i', 'n', 't', 'e', 'n', 's', 'e', 'l', 'y', '\n',
        'i', 'n', 't', 'e', 'n', 's', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 't', 'e', 'n', 's', 'i', 'f', 'i', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'n', 's', 'i', 'f', 'i', 'e', 's', '\n',
        'i', 'n', 't', 'e', 'n', 's', 'i', 'f', 'y', '\n',
        'i', 'n', 't', 'e', 'n', 's', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'e', 'n', 's', 'i', 't', 'i', 'e', 's', '\n',
        'i', 'n', 't', 'e', 'n', 's', 'i', 't', 'y', '\n',
        'i', 'n', 't', 'e', 'n', 's', 'i', 'v', 'e', '\n',
        'i', 'n', 't', 'e', 'n', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'i', 'n', 't', 'e', 'n', 't', '\n',
        'i', 'n', 't', 'e', 'n', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 't', 'e', 'n', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'i', 'n', 't', 'e', 'n', 't', 'i', 'o', 'n', 'a', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 't', 'e', 'n', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'i', 'n', 't', 'e', 'n', 't', 'i', 'o', 'n', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'n', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 't', 'e', 'n', 't', 'l', 'y', '\n',
        'i', 'n', 't', 'e', 'n', 't', 'n', 'e', 's', 's', '\n',
        'i', 'n', 't', 'e', 'n', 't', 's', '\n',
        'i', 'n', 't', 'e', 'r', '\n',
        'i', 'n', 't', 'e', 'r', 'a', 'c', 't', '\n',
        'i', 'n', 't', 'e', 'r', 'a', 'c', 't', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'r', 'a', 'c', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'e', 'r', 'a', 'c', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 't', 'e', 'r', 'a', 'c', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'i', 'n', 't', 'e', 'r', 'a', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'a', 'c', 't', 'i', 'v', 'e', '\n',
        'i', 'n', 't', 'e', 'r', 'a', 'c', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'i', 'n', 't', 'e', 'r', 'a', 'c', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'a', 'c', 't', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'a', 't', 'o', 'm', 'i', 'c', '\n',
        'i', 'n', 't', 'e', 'r', 'b', 'a', 'n', 'k', '\n',
        'i', 'n', 't', 'e', 'r', 'b', 'r', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'r', 'b', 'r', 'e', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'r', 'b', 'r', 'e', 'e', 'd', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'e', 'd', 'e', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'e', 'd', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'e', 'd', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'e', 'p', 't', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'e', 'p', 't', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'e', 'p', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'e', 'p', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'e', 'p', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'e', 'p', 't', 'o', 'r', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'e', 'p', 't', 'o', 'r', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'e', 'p', 't', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'e', 's', 's', 'i', 'o', 'n', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'e', 's', 's', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'h', 'a', 'n', 'g', 'e', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'h', 'a', 'n', 'g', 'e', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'h', 'a', 'n', 'g', 'e', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'h', 'a', 'n', 'g', 'e', 'a', 'b', 'l', 'y', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'h', 'a', 'n', 'g', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'h', 'a', 'n', 'g', 'e', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'h', 'a', 'n', 'g', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'i', 't', 'y', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'o', 'l', 'l', 'e', 'g', 'i', 'a', 't', 'e', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'o', 'm', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'o', 'm', 'm', 'u', 'n', 'i', 'c', 'a', 't', 'e', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'o', 'm', 'm', 'u', 'n', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'o', 'n', 'n', 'e', 'c', 't', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'o', 'n', 'n', 'e', 'c', 't', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'o', 'n', 't', 'i', 'n', 'e', 'n', 't', 'a', 'l', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'o', 'n', 'v', 'e', 'r', 's', 'i', 'o', 'n', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'o', 'u', 'n', 't', 'r', 'y', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'o', 'u', 'r', 's', 'e', '\n',
        'i', 'n', 't', 'e', 'r', 'c', 'u', 't', '\n',
        'i', 'n', 't', 'e', 'r', 'd', 'e', 'n', 'o', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'i', 'n', 't', 'e', 'r', 'd', 'e', 'p', 'a', 'r', 't', 'm', 'e', 'n', 't', 'a', 'l', '\n',
        'i', 'n', 't', 'e', 'r', 'd', 'e', 'p', 'e', 'n', 'd', 'e', 'n', 'c', 'e', '\n',
        'i', 'n', 't', 'e', 'r', 'd', 'e', 'p', 'e', 'n', 'd', 'e', 'n', 'c', 'y', '\n',
        'i', 'n', 't', 'e', 'r', 'd', 'e', 'p', 'e', 'n', 'd', 'e', 'n', 't', '\n',
        'i', 'n', 't', 'e', 'r', 'd', 'i', 'c', 't', '\n',
        'i', 'n', 't', 'e', 'r', 'd', 'i', 'c', 't', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'r', 'd', 'i', 's', 'c', 'i', 'p', 'l', 'i', 'n', 'a', 'r', 'y', '\n',
        'i', 'n', 't', 'e', 'r', 'e', 's', 't', '\n',
        'i', 'n', 't', 'e', 'r', 'e', 's', 't', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'r', 'e', 's', 't', 'e', 'd', 'l', 'y', '\n',
        'i', 'n', 't', 'e', 'r', 'e', 's', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'e', 'r', 'e', 's', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'i', 'n', 't', 'e', 'r', 'e', 's', 't', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', '\n',
        'i', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'e', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'f', 'a', 'c', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'e', 'r', 'f', 'e', 'r', 'e', '\n',
        'i', 'n', 't', 'e', 'r', 'f', 'e', 'r', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'r', 'f', 'e', 'r', 'e', 'n', 'c', 'e', '\n',
        'i', 'n', 't', 'e', 'r', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'f', 'e', 'r', 'e', 'r', '\n',
        'i', 'n', 't', 'e', 'r', 'f', 'e', 'r', 'e', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'f', 'e', 'r', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'e', 'r', 'f', 'e', 'r', 'o', 'm', 'e', 't', 'e', 'r', '\n',
        'i', 'n', 't', 'e', 'r', 'f', 'e', 'r', 'o', 'm', 'e', 't', 'e', 'r', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'f', 'e', 'r', 'o', 'm', 'e', 't', 'r', 'i', 'c', '\n',
        'i', 'n', 't', 'e', 'r', 'f', 'e', 'r', 'o', 'm', 'e', 't', 'r', 'y', '\n',
        'i', 'n', 't', 'e', 'r', 'f', 'e', 'r', 'o', 'n', '\n',
        'i', 'n', 't', 'e', 'r', 'g', 'a', 'l', 'a', 'c', 't', 'i', 'c', '\n',
        'i', 'n', 't', 'e', 'r', 'g', 'l', 'a', 'c', 'i', 'a', 'l', '\n',
        'i', 'n', 't', 'e', 'r', 'g', 'o', 'v', 'e', 'r', 'n', 'm', 'e', 'n', 't', 'a', 'l', '\n',
        'i', 'n', 't', 'e', 'r', 'i', 'm', '\n',
        'i', 'n', 't', 'e', 'r', 'i', 'm', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'i', 'o', 'r', '\n',
        'i', 'n', 't', 'e', 'r', 'i', 'o', 'r', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'j', 'e', 'c', 't', '\n',
        'i', 'n', 't', 'e', 'r', 'j', 'e', 'c', 't', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'r', 'j', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'e', 'r', 'j', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 't', 'e', 'r', 'j', 'e', 'c', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'i', 'n', 't', 'e', 'r', 'j', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'j', 'e', 'c', 't', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'l', 'a', 'c', 'e', '\n',
        'i', 'n', 't', 'e', 'r', 'l', 'a', 'c', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'r', 'l', 'a', 'c', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'e', 'r', 'l', 'a', 'p', '\n',
        'i', 'n', 't', 'e', 'r', 'l', 'e', 'a', 'v', 'e', '\n',
        'i', 'n', 't', 'e', 'r', 'l', 'e', 'a', 'v', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'r', 'l', 'e', 'a', 'v', 'e', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'l', 'e', 'a', 'v', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'e', 'r', 'l', 'i', 'n', 'g', 'u', 'a', 'l', '\n',
        'i', 'n', 't', 'e', 'r', 'l', 'i', 'n', 'k', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'r', 'l', 'o', 'c', 'k', '\n',
        'i', 'n', 't', 'e', 'r', 'l', 'o', 'c', 'k', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'r', 'l', 'o', 'c', 'k', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'e', 'r', 'l', 'o', 'c', 'k', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'l', 'o', 'c', 'u', 't', 'o', 'r', '\n',
        'i', 'n', 't', 'e', 'r', 'l', 'o', 'c', 'u', 't', 'o', 'r', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'l', 'o', 'c', 'u', 't', 'o', 'r', 'y', '\n',
        'i', 'n', 't', 'e', 'r', 'l', 'o', 'p', 'e', 'r', '\n',
        'i', 'n', 't', 'e', 'r', 'l', 'o', 'p', 'e', 'r', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'l', 'u', 'd', 'e', '\n',
        'i', 'n', 't', 'e', 'r', 'l', 'u', 'd', 'e', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'm', 'a', 'r', 'r', 'i', 'a', 'g', 'e', '\n',
        'i', 'n', 't', 'e', 'r', 'm', 'a', 'r', 'r', 'i', 'a', 'g', 'e', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'm', 'e', 'd', 'i', 'a', 'r', 'i', 'e', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'm', 'e', 'd', 'i', 'a', 'r', 'y', '\n',
        'i', 'n', 't', 'e', 'r', 'm', 'e', 'd', 'i', 'a', 't', 'e', '\n',
        'i', 'n', 't', 'e', 'r', 'm', 'e', 'd', 'i', 'a', 't', 'e', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'm', 'e', 'n', 't', '\n',
        'i', 'n', 't', 'e', 'r', 'm', 'e', 'n', 't', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'm', 'i', 'n', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 't', 'e', 'r', 'm', 'i', 'n', 'a', 'b', 'l', 'y', '\n',
        'i', 'n', 't', 'e', 'r', 'm', 'i', 'n', 'g', 'l', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'r', 'm', 'i', 'n', 'g', 'l', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'e', 'r', 'm', 'i', 's', 's', 'i', 'o', 'n', '\n',
        'i', 'n', 't', 'e', 'r', 'm', 'i', 's', 's', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'm', 'i', 't', 't', 'e', 'n', 't', '\n',
        'i', 'n', 't', 'e', 'r', 'm', 'i', 't', 't', 'e', 'n', 't', 'l', 'y', '\n',
        'i', 'n', 't', 'e', 'r', 'm', 'i', 'x', '\n',
        'i', 'n', 't', 'e', 'r', 'm', 'i', 'x', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'r', 'm', 'i', 'x', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'e', 'r', 'm', 'o', 'l', 'e', 'c', 'u', 'l', 'a', 'r', '\n',
        'i', 'n', 't', 'e', 'r', 'n', '\n',
        'i', 'n', 't', 'e', 'r', 'n', 'a', 'l', '\n',
        'i', 'n', 't', 'e', 'r', 'n', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 't', 'e', 'r', 'n', 'a', 'l', 'i', 's', 'e', '\n',
        'i', 'n', 't', 'e', 'r', 'n', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'r', 'n', 'a', 'l', 'i', 's', 'e', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'n', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'e', 'r', 'n', 'a', 'l', 'l', 'y', '\n',
        'i', 'n', 't', 'e', 'r', 'n', 'a', 'l', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'n', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'i', 'n', 't', 'e', 'r', 'n', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 't', 'e', 'r', 'n', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'r', 'n', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 'm', '\n',
        'i', 'n', 't', 'e', 'r', 'n', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 't', '\n',
        'i', 'n', 't', 'e', 'r', 'n', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 't', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'n', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'i', 'n', 't', 'e', 'r', 'n', 'a', 't', 'i', 'o', 'n', 'a', 'l', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'n', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'r', 'n', 'e', 'e', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'n', 'e', 't', '\n',
        'i', 'n', 't', 'e', 'r', 'n', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'e', 'r', 'n', 'm', 'e', 'n', 't', '\n',
        'i', 'n', 't', 'e', 'r', 'n', 'm', 'e', 'n', 't', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'n', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'n', 'u', 'c', 'l', 'e', 'a', 'r', '\n',
        'i', 'n', 't', 'e', 'r', 'o', 'c', 'u', 'l', 'a', 'r', '\n',
        'i', 'n', 't', 'e', 'r', 'o', 'p', 'e', 'r', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 't', 'e', 'r', 'o', 'p', 'e', 'r', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 't', 'e', 'r', 'p', 'e', 'l', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 't', 'e', 'r', 'p', 'e', 'n', 'e', 't', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 't', 'e', 'r', 'p', 'e', 'r', 's', 'o', 'n', 'a', 'l', '\n',
        'i', 'n', 't', 'e', 'r', 'p', 'l', 'a', 'n', 'e', 't', 'a', 'r', 'y', '\n',
        'i', 'n', 't', 'e', 'r', 'p', 'l', 'a', 'y', '\n',
        'i', 'n', 't', 'e', 'r', 'p', 'l', 'a', 'y', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'p', 'o', 'l', 'a', 't', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 't', 'e', 'r', 'p', 'o', 'l', 'a', 't', 'e', '\n',
        'i', 'n', 't', 'e', 'r', 'p', 'o', 'l', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'r', 'p', 'o', 'l', 'a', 't', 'e', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'p', 'o', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'e', 'r', 'p', 'o', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 't', 'e', 'r', 'p', 'o', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'p', 'o', 's', 'e', '\n',
        'i', 'n', 't', 'e', 'r', 'p', 'o', 's', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'r', 'p', 'o', 's', 'e', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'p', 'o', 's', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'e', 'r', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 't', 'e', 'r', 'p', 'r', 'e', 't', '\n',
        'i', 'n', 't', 'e', 'r', 'p', 'r', 'e', 't', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 't', 'e', 'r', 'p', 'r', 'e', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 't', 'e', 'r', 'p', 'r', 'e', 't', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'i', 'n', 't', 'e', 'r', 'p', 'r', 'e', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'p', 'r', 'e', 't', 'a', 't', 'i', 'v', 'e', '\n',
        'i', 'n', 't', 'e', 'r', 'p', 'r', 'e', 't', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'r', 'p', 'r', 'e', 't', 'e', 'r', '\n',
        'i', 'n', 't', 'e', 'r', 'p', 'r', 'e', 't', 'e', 'r', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'p', 'r', 'e', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'e', 'r', 'p', 'r', 'e', 't', 'i', 'v', 'e', '\n',
        'i', 'n', 't', 'e', 'r', 'p', 'r', 'e', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'i', 'n', 't', 'e', 'r', 'p', 'r', 'e', 't', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'r', 'a', 'c', 'i', 'a', 'l', '\n',
        'i', 'n', 't', 'e', 'r', 'r', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'r', 'r', 'e', 'g', 'n', 'u', 'm', '\n',
        'i', 'n', 't', 'e', 'r', 'r', 'e', 'l', 'a', 't', 'e', '\n',
        'i', 'n', 't', 'e', 'r', 'r', 'e', 'l', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'r', 'r', 'e', 'l', 'a', 't', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'r', 'e', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 't', 'e', 'r', 'r', 'e', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'r', 'e', 'l', 'a', 't', 'i', 'o', 'n', 's', 'h', 'i', 'p', '\n',
        'i', 'n', 't', 'e', 'r', 'r', 'e', 'l', 'a', 't', 'i', 'o', 'n', 's', 'h', 'i', 'p', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'r', 'o', 'g', 'a', 't', 'e', '\n',
        'i', 'n', 't', 'e', 'r', 'r', 'o', 'g', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'r', 'r', 'o', 'g', 'a', 't', 'e', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'r', 'o', 'g', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'e', 'r', 'r', 'o', 'g', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 't', 'e', 'r', 'r', 'o', 'g', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'r', 'o', 'g', 'a', 't', 'i', 'v', 'e', '\n',
        'i', 'n', 't', 'e', 'r', 'r', 'o', 'g', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'i', 'n', 't', 'e', 'r', 'r', 'o', 'g', 'a', 't', 'i', 'v', 'e', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'r', 'o', 'g', 'a', 't', 'o', 'r', '\n',
        'i', 'n', 't', 'e', 'r', 'r', 'o', 'g', 'a', 't', 'o', 'r', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'r', 'o', 'g', 'a', 't', 'o', 'r', 'y', '\n',
        'i', 'n', 't', 'e', 'r', 'r', 'u', 'p', 't', '\n',
        'i', 'n', 't', 'e', 'r', 'r', 'u', 'p', 't', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'r', 'r', 'u', 'p', 't', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 't', 'e', 'r', 'r', 'u', 'p', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'e', 'r', 'r', 'u', 'p', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 't', 'e', 'r', 'r', 'u', 'p', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'r', 'u', 'p', 't', 's', '\n',
        'i', 'n', 't', 'e', 'r', 's', 'e', 'c', 't', '\n',
        'i', 'n', 't', 'e', 'r', 's', 'e', 'c', 't', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'r', 's', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'e', 'r', 's', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 't', 'e', 'r', 's', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 't', 'e', 'r', 's', 'e', 'c', 't', 's', '\n',
        'i', 'n', 't', 'e', 'r', 's', 'p', 'e', 'r', 's', 'e', '\n',
        'i', 'n', 't', 'e', 'r', 's', 'p', 'e', 'r', 's', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'r', 's', 'p', 'e', 'r', 's', 'e', 's', '\n',
        'i', 'n', 't', 'e', 'r', 's', 'p', 'e', 'r', 's', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'e', 'r', 's', 't', 'e', 'l', 'l', 'a', 'r', '\n',
        'i', 'n', 't', 'e', 'r', 's', 't', 'i', 'c', 'e', 's', '\n',
        'i', 'n', 't', 'e', 'r', 's', 't', 'i', 't', 'i', 'a', 'l', '\n',
        'i', 'n', 't', 'e', 'r', 's', 't', 'i', 't', 'i', 'a', 'l', 'l', 'y', '\n',
        'i', 'n', 't', 'e', 'r', 't', 'i', 'd', 'a', 'l', '\n',
        'i', 'n', 't', 'e', 'r', 't', 'w', 'i', 'n', 'e', '\n',
        'i', 'n', 't', 'e', 'r', 't', 'w', 'i', 'n', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'r', 't', 'w', 'i', 'n', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'e', 'r', 'v', 'a', 'l', '\n',
        'i', 'n', 't', 'e', 'r', 'v', 'a', 'l', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'v', 'e', 'n', 'e', '\n',
        'i', 'n', 't', 'e', 'r', 'v', 'e', 'n', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'r', 'v', 'e', 'n', 'e', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'v', 'e', 'n', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'e', 'r', 'v', 'e', 'n', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 't', 'e', 'r', 'v', 'e', 'n', 't', 'i', 'o', 'n', 'i', 's', 'm', '\n',
        'i', 'n', 't', 'e', 'r', 'v', 'e', 'n', 't', 'i', 'o', 'n', 'i', 's', 't', '\n',
        'i', 'n', 't', 'e', 'r', 'v', 'e', 'n', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'v', 'i', 'e', 'w', '\n',
        'i', 'n', 't', 'e', 'r', 'v', 'i', 'e', 'w', 'e', 'd', '\n',
        'i', 'n', 't', 'e', 'r', 'v', 'i', 'e', 'w', 'e', 'e', '\n',
        'i', 'n', 't', 'e', 'r', 'v', 'i', 'e', 'w', 'e', 'e', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'v', 'i', 'e', 'w', 'e', 'r', '\n',
        'i', 'n', 't', 'e', 'r', 'v', 'i', 'e', 'w', 'e', 'r', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'v', 'i', 'e', 'w', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'e', 'r', 'v', 'i', 'e', 'w', 's', '\n',
        'i', 'n', 't', 'e', 'r', 'w', 'e', 'a', 'v', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'e', 'r', 'w', 'o', 'v', 'e', 'n', '\n',
        'i', 'n', 't', 'e', 's', 't', 'a', 'c', 'y', '\n',
        'i', 'n', 't', 'e', 's', 't', 'a', 't', 'e', '\n',
        'i', 'n', 't', 'e', 's', 't', 'i', 'n', 'a', 'l', '\n',
        'i', 'n', 't', 'e', 's', 't', 'i', 'n', 'e', '\n',
        'i', 'n', 't', 'e', 's', 't', 'i', 'n', 'e', 's', '\n',
        'i', 'n', 't', 'i', 'f', 'a', 'd', 'a', '\n',
        'i', 'n', 't', 'i', 'm', 'a', 'c', 'i', 'e', 's', '\n',
        'i', 'n', 't', 'i', 'm', 'a', 'c', 'y', '\n',
        'i', 'n', 't', 'i', 'm', 'a', 't', 'e', '\n',
        'i', 'n', 't', 'i', 'm', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 't', 'i', 'm', 'a', 't', 'e', 'l', 'y', '\n',
        'i', 'n', 't', 'i', 'm', 'a', 't', 'e', 's', '\n',
        'i', 'n', 't', 'i', 'm', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'i', 'm', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 't', 'i', 'm', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 't', 'i', 'm', 'i', 'd', 'a', 't', 'e', '\n',
        'i', 'n', 't', 'i', 'm', 'i', 'd', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 't', 'i', 'm', 'i', 'd', 'a', 't', 'e', 's', '\n',
        'i', 'n', 't', 'i', 'm', 'i', 'd', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'i', 'm', 'i', 'd', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 't', 'i', 'm', 'i', 'd', 'a', 't', 'o', 'r', 'y', '\n',
        'i', 'n', 't', 'o', '\n',
        'i', 'n', 't', 'o', 'l', 'e', 'r', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 't', 'o', 'l', 'e', 'r', 'a', 'b', 'l', 'y', '\n',
        'i', 'n', 't', 'o', 'l', 'e', 'r', 'a', 'n', 'c', 'e', '\n',
        'i', 'n', 't', 'o', 'l', 'e', 'r', 'a', 'n', 't', '\n',
        'i', 'n', 't', 'o', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 't', 'o', 'n', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'i', 'n', 't', 'o', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 't', 'o', 'n', 'e', '\n',
        'i', 'n', 't', 'o', 'n', 'e', 'd', '\n',
        'i', 'n', 't', 'o', 'n', 'e', 's', '\n',
        'i', 'n', 't', 'o', 'n', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'o', 'x', 'i', 'c', 'a', 'n', 't', '\n',
        'i', 'n', 't', 'o', 'x', 'i', 'c', 'a', 'n', 't', 's', '\n',
        'i', 'n', 't', 'o', 'x', 'i', 'c', 'a', 't', 'e', '\n',
        'i', 'n', 't', 'o', 'x', 'i', 'c', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 't', 'o', 'x', 'i', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'o', 'x', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 't', 'r', 'a', 'c', 'e', 'l', 'l', 'u', 'l', 'a', 'r', '\n',
        'i', 'n', 't', 'r', 'a', 'c', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 't', 'r', 'a', 'c', 't', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 't', 'r', 'a', 'c', 't', 'a', 'b', 'l', 'y', '\n',
        'i', 'n', 't', 'r', 'a', 'm', 'u', 'r', 'a', 'l', '\n',
        'i', 'n', 't', 'r', 'a', 'm', 'u', 's', 'c', 'u', 'l', 'a', 'r', '\n',
        'i', 'n', 't', 'r', 'a', 'n', 's', 'i', 'g', 'e', 'n', 'c', 'e', '\n',
        'i', 'n', 't', 'r', 'a', 'n', 's', 'i', 'g', 'e', 'n', 't', '\n',
        'i', 'n', 't', 'r', 'a', 'n', 's', 'i', 't', 'i', 'v', 'e', '\n',
        'i', 'n', 't', 'r', 'a', 'u', 't', 'e', 'r', 'i', 'n', 'e', '\n',
        'i', 'n', 't', 'r', 'a', 'v', 'e', 'n', 'o', 'u', 's', '\n',
        'i', 'n', 't', 'r', 'a', 'v', 'e', 'n', 'o', 'u', 's', 'l', 'y', '\n',
        'i', 'n', 't', 'r', 'e', 'p', 'i', 'd', '\n',
        'i', 'n', 't', 'r', 'e', 'p', 'i', 'd', 'l', 'y', '\n',
        'i', 'n', 't', 'r', 'i', 'c', 'a', 'c', 'i', 'e', 's', '\n',
        'i', 'n', 't', 'r', 'i', 'c', 'a', 'c', 'y', '\n',
        'i', 'n', 't', 'r', 'i', 'c', 'a', 't', 'e', '\n',
        'i', 'n', 't', 'r', 'i', 'c', 'a', 't', 'e', 'l', 'y', '\n',
        'i', 'n', 't', 'r', 'i', 'g', 'u', 'e', '\n',
        'i', 'n', 't', 'r', 'i', 'g', 'u', 'e', 'd', '\n',
        'i', 'n', 't', 'r', 'i', 'g', 'u', 'e', 's', '\n',
        'i', 'n', 't', 'r', 'i', 'g', 'u', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'r', 'i', 'g', 'u', 'i', 'n', 'g', 'l', 'y', '\n',
        'i', 'n', 't', 'r', 'i', 'n', 's', 'i', 'c', '\n',
        'i', 'n', 't', 'r', 'i', 'n', 's', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'i', 'n', 't', 'r', 'o', '\n',
        'i', 'n', 't', 'r', 'o', 'd', 'u', 'c', 'e', '\n',
        'i', 'n', 't', 'r', 'o', 'd', 'u', 'c', 'e', 'd', '\n',
        'i', 'n', 't', 'r', 'o', 'd', 'u', 'c', 'e', 's', '\n',
        'i', 'n', 't', 'r', 'o', 'd', 'u', 'c', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'r', 'o', 'd', 'u', 'c', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 't', 'r', 'o', 'd', 'u', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 't', 'r', 'o', 'd', 'u', 'c', 't', 'o', 'r', 'y', '\n',
        'i', 'n', 't', 'r', 'o', 's', 'p', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 't', 'r', 'o', 's', 'p', 'e', 'c', 't', 'i', 'v', 'e', '\n',
        'i', 'n', 't', 'r', 'o', 's', 'p', 'e', 'c', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'i', 'n', 't', 'r', 'o', 'v', 'e', 'r', 's', 'i', 'o', 'n', '\n',
        'i', 'n', 't', 'r', 'o', 'v', 'e', 'r', 't', '\n',
        'i', 'n', 't', 'r', 'o', 'v', 'e', 'r', 't', 'e', 'd', '\n',
        'i', 'n', 't', 'r', 'o', 'v', 'e', 'r', 't', 's', '\n',
        'i', 'n', 't', 'r', 'u', 'd', 'e', '\n',
        'i', 'n', 't', 'r', 'u', 'd', 'e', 'd', '\n',
        'i', 'n', 't', 'r', 'u', 'd', 'e', 'r', '\n',
        'i', 'n', 't', 'r', 'u', 'd', 'e', 'r', 's', '\n',
        'i', 'n', 't', 'r', 'u', 'd', 'e', 's', '\n',
        'i', 'n', 't', 'r', 'u', 'd', 'i', 'n', 'g', '\n',
        'i', 'n', 't', 'r', 'u', 's', 'i', 'o', 'n', '\n',
        'i', 'n', 't', 'r', 'u', 's', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 't', 'r', 'u', 's', 'i', 'v', 'e', '\n',
        'i', 'n', 't', 'r', 'u', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'i', 'n', 't', 'u', 'i', 't', 'e', 'd', '\n',
        'i', 'n', 't', 'u', 'i', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 't', 'u', 'i', 't', 'i', 'o', 'n', 'i', 's', 't', '\n',
        'i', 'n', 't', 'u', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 't', 'u', 'i', 't', 'i', 'v', 'e', '\n',
        'i', 'n', 't', 'u', 'i', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'i', 'n', 't', 'u', 'i', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'i', 'n', 'u', 'i', 't', '\n',
        'i', 'n', 'u', 'i', 't', 's', '\n',
        'i', 'n', 'u', 'n', 'd', 'a', 't', 'e', '\n',
        'i', 'n', 'u', 'n', 'd', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 'u', 'n', 'd', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'u', 'r', 'e', '\n',
        'i', 'n', 'u', 'r', 'e', 'd', '\n',
        'i', 'n', 'v', 'a', 'd', 'e', '\n',
        'i', 'n', 'v', 'a', 'd', 'e', 'd', '\n',
        'i', 'n', 'v', 'a', 'd', 'e', 'r', '\n',
        'i', 'n', 'v', 'a', 'd', 'e', 'r', 's', '\n',
        'i', 'n', 'v', 'a', 'd', 'e', 's', '\n',
        'i', 'n', 'v', 'a', 'd', 'i', 'n', 'g', '\n',
        'i', 'n', 'v', 'a', 'l', 'i', 'd', '\n',
        'i', 'n', 'v', 'a', 'l', 'i', 'd', 'a', 't', 'e', '\n',
        'i', 'n', 'v', 'a', 'l', 'i', 'd', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 'v', 'a', 'l', 'i', 'd', 'a', 't', 'e', 's', '\n',
        'i', 'n', 'v', 'a', 'l', 'i', 'd', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'v', 'a', 'l', 'i', 'd', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'v', 'a', 'l', 'i', 'd', 'e', 'd', '\n',
        'i', 'n', 'v', 'a', 'l', 'i', 'd', 'i', 't', 'y', '\n',
        'i', 'n', 'v', 'a', 'l', 'i', 'd', 's', '\n',
        'i', 'n', 'v', 'a', 'l', 'u', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'v', 'a', 'r', 'i', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'v', 'a', 'r', 'i', 'a', 'b', 'l', 'y', '\n',
        'i', 'n', 'v', 'a', 'r', 'i', 'a', 'n', 'c', 'e', '\n',
        'i', 'n', 'v', 'a', 'r', 'i', 'a', 'n', 't', '\n',
        'i', 'n', 'v', 'a', 'r', 'i', 'a', 'n', 't', 's', '\n',
        'i', 'n', 'v', 'a', 's', 'i', 'o', 'n', '\n',
        'i', 'n', 'v', 'a', 's', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'v', 'a', 's', 'i', 'v', 'e', '\n',
        'i', 'n', 'v', 'e', 'c', 't', 'i', 'v', 'e', '\n',
        'i', 'n', 'v', 'e', 'c', 't', 'i', 'v', 'e', 's', '\n',
        'i', 'n', 'v', 'e', 'i', 'g', 'h', '\n',
        'i', 'n', 'v', 'e', 'i', 'g', 'h', 'i', 'n', 'g', '\n',
        'i', 'n', 'v', 'e', 'i', 'g', 'l', 'e', '\n',
        'i', 'n', 'v', 'e', 'i', 'g', 'l', 'e', 'd', '\n',
        'i', 'n', 'v', 'e', 'i', 'g', 'l', 'e', 'r', '\n',
        'i', 'n', 'v', 'e', 'i', 'g', 'l', 'e', 'r', 's', '\n',
        'i', 'n', 'v', 'e', 'i', 'g', 'l', 'i', 'n', 'g', '\n',
        'i', 'n', 'v', 'e', 'n', 't', '\n',
        'i', 'n', 'v', 'e', 'n', 't', 'e', 'd', '\n',
        'i', 'n', 'v', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'v', 'e', 'n', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'v', 'e', 'n', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'v', 'e', 'n', 't', 'i', 'v', 'e', '\n',
        'i', 'n', 'v', 'e', 'n', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'i', 'n', 'v', 'e', 'n', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'i', 'n', 'v', 'e', 'n', 't', 'o', 'r', '\n',
        'i', 'n', 'v', 'e', 'n', 't', 'o', 'r', 'i', 'e', 's', '\n',
        'i', 'n', 'v', 'e', 'n', 't', 'o', 'r', 's', '\n',
        'i', 'n', 'v', 'e', 'n', 't', 'o', 'r', 'y', '\n',
        'i', 'n', 'v', 'e', 'n', 't', 's', '\n',
        'i', 'n', 'v', 'e', 'r', 's', 'e', '\n',
        'i', 'n', 'v', 'e', 'r', 's', 'e', 'l', 'y', '\n',
        'i', 'n', 'v', 'e', 'r', 's', 'e', 's', '\n',
        'i', 'n', 'v', 'e', 'r', 's', 'i', 'o', 'n', '\n',
        'i', 'n', 'v', 'e', 'r', 's', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'v', 'e', 'r', 't', '\n',
        'i', 'n', 'v', 'e', 'r', 't', 'e', 'b', 'r', 'a', 't', 'e', '\n',
        'i', 'n', 'v', 'e', 'r', 't', 'e', 'b', 'r', 'a', 't', 'e', 's', '\n',
        'i', 'n', 'v', 'e', 'r', 't', 'e', 'd', '\n',
        'i', 'n', 'v', 'e', 'r', 't', 'e', 'r', '\n',
        'i', 'n', 'v', 'e', 'r', 't', 'e', 'r', 's', '\n',
        'i', 'n', 'v', 'e', 'r', 't', 'i', 'b', 'l', 'e', '\n',
        'i', 'n', 'v', 'e', 'r', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'v', 'e', 'r', 't', 's', '\n',
        'i', 'n', 'v', 'e', 's', 't', '\n',
        'i', 'n', 'v', 'e', 's', 't', 'e', 'd', '\n',
        'i', 'n', 'v', 'e', 's', 't', 'i', 'g', 'a', 't', 'e', '\n',
        'i', 'n', 'v', 'e', 's', 't', 'i', 'g', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 'v', 'e', 's', 't', 'i', 'g', 'a', 't', 'e', 's', '\n',
        'i', 'n', 'v', 'e', 's', 't', 'i', 'g', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'v', 'e', 's', 't', 'i', 'g', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'v', 'e', 's', 't', 'i', 'g', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'v', 'e', 's', 't', 'i', 'g', 'a', 't', 'i', 'v', 'e', '\n',
        'i', 'n', 'v', 'e', 's', 't', 'i', 'g', 'a', 't', 'o', 'r', '\n',
        'i', 'n', 'v', 'e', 's', 't', 'i', 'g', 'a', 't', 'o', 'r', 's', '\n',
        'i', 'n', 'v', 'e', 's', 't', 'i', 'g', 'a', 't', 'o', 'r', 'y', '\n',
        'i', 'n', 'v', 'e', 's', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'v', 'e', 's', 't', 'i', 't', 'u', 'r', 'e', '\n',
        'i', 'n', 'v', 'e', 's', 't', 'm', 'e', 'n', 't', '\n',
        'i', 'n', 'v', 'e', 's', 't', 'm', 'e', 'n', 't', 's', '\n',
        'i', 'n', 'v', 'e', 's', 't', 'o', 'r', '\n',
        'i', 'n', 'v', 'e', 's', 't', 'o', 'r', 's', '\n',
        'i', 'n', 'v', 'e', 's', 't', 's', '\n',
        'i', 'n', 'v', 'e', 't', 'e', 'r', 'a', 't', 'e', '\n',
        'i', 'n', 'v', 'i', 'd', 'i', 'o', 'u', 's', '\n',
        'i', 'n', 'v', 'i', 'g', 'i', 'l', 'a', 't', 'e', '\n',
        'i', 'n', 'v', 'i', 'g', 'i', 'l', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 'v', 'i', 'g', 'i', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'v', 'i', 'g', 'i', 'l', 'a', 't', 'o', 'r', '\n',
        'i', 'n', 'v', 'i', 'g', 'i', 'l', 'a', 't', 'o', 'r', 's', '\n',
        'i', 'n', 'v', 'i', 'g', 'o', 'r', 'a', 't', 'e', '\n',
        'i', 'n', 'v', 'i', 'g', 'o', 'r', 'a', 't', 'e', 'd', '\n',
        'i', 'n', 'v', 'i', 'g', 'o', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'v', 'i', 'g', 'o', 'r', 'a', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'i', 'n', 'v', 'i', 'n', 'c', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 'v', 'i', 'n', 'c', 'i', 'b', 'l', 'e', '\n',
        'i', 'n', 'v', 'i', 'o', 'l', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 'v', 'i', 'o', 'l', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'v', 'i', 'o', 'l', 'a', 't', 'e', '\n',
        'i', 'n', 'v', 'i', 's', 'c', 'i', 'd', '\n',
        'i', 'n', 'v', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'i', 'n', 'v', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 'v', 'i', 's', 'i', 'b', 'l', 'e', '\n',
        'i', 'n', 'v', 'i', 's', 'i', 'b', 'l', 'e', 's', '\n',
        'i', 'n', 'v', 'i', 's', 'i', 'b', 'l', 'y', '\n',
        'i', 'n', 'v', 'i', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'v', 'i', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'v', 'i', 't', 'e', '\n',
        'i', 'n', 'v', 'i', 't', 'e', 'd', '\n',
        'i', 'n', 'v', 'i', 't', 'e', 's', '\n',
        'i', 'n', 'v', 'i', 't', 'i', 'n', 'g', '\n',
        'i', 'n', 'v', 'i', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'i', 'n', 'v', 'o', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'v', 'o', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'v', 'o', 'i', 'c', 'e', '\n',
        'i', 'n', 'v', 'o', 'i', 'c', 'e', 'd', '\n',
        'i', 'n', 'v', 'o', 'i', 'c', 'e', 's', '\n',
        'i', 'n', 'v', 'o', 'i', 'c', 'i', 'n', 'g', '\n',
        'i', 'n', 'v', 'o', 'k', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'v', 'o', 'k', 'e', '\n',
        'i', 'n', 'v', 'o', 'k', 'e', 'd', '\n',
        'i', 'n', 'v', 'o', 'k', 'e', 'r', '\n',
        'i', 'n', 'v', 'o', 'k', 'e', 'r', 's', '\n',
        'i', 'n', 'v', 'o', 'k', 'e', 's', '\n',
        'i', 'n', 'v', 'o', 'k', 'i', 'n', 'g', '\n',
        'i', 'n', 'v', 'o', 'l', 'u', 'n', 't', 'a', 'r', 'i', 'l', 'y', '\n',
        'i', 'n', 'v', 'o', 'l', 'u', 'n', 't', 'a', 'r', 'y', '\n',
        'i', 'n', 'v', 'o', 'l', 'u', 't', 'e', '\n',
        'i', 'n', 'v', 'o', 'l', 'u', 't', 'i', 'o', 'n', '\n',
        'i', 'n', 'v', 'o', 'l', 'u', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'n', 'v', 'o', 'l', 'v', 'e', '\n',
        'i', 'n', 'v', 'o', 'l', 'v', 'e', 'd', '\n',
        'i', 'n', 'v', 'o', 'l', 'v', 'e', 'm', 'e', 'n', 't', '\n',
        'i', 'n', 'v', 'o', 'l', 'v', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'i', 'n', 'v', 'o', 'l', 'v', 'e', 's', '\n',
        'i', 'n', 'v', 'o', 'l', 'v', 'i', 'n', 'g', '\n',
        'i', 'n', 'v', 'u', 'l', 'n', 'e', 'r', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'n', 'v', 'u', 'l', 'n', 'e', 'r', 'a', 'b', 'l', 'e', '\n',
        'i', 'n', 'w', 'a', 'r', 'd', '\n',
        'i', 'n', 'w', 'a', 'r', 'd', 'l', 'y', '\n',
        'i', 'n', 'w', 'a', 'r', 'd', 'n', 'e', 's', 's', '\n',
        'i', 'n', 'w', 'a', 'r', 'd', 's', '\n',
        'i', 'o', 'd', 'i', 'd', 'e', '\n',
        'i', 'o', 'd', 'i', 'n', 'e', '\n',
        'i', 'o', 'n', '\n',
        'i', 'o', 'n', 'i', 'a', 'n', '\n',
        'i', 'o', 'n', 'i', 'c', '\n',
        'i', 'o', 'n', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'o', 'n', 'i', 's', 'e', '\n',
        'i', 'o', 'n', 'i', 's', 'e', 'd', '\n',
        'i', 'o', 'n', 'i', 's', 'i', 'n', 'g', '\n',
        'i', 'o', 'n', 'o', 's', 'p', 'h', 'e', 'r', 'e', '\n',
        'i', 'o', 'n', 'o', 's', 'p', 'h', 'e', 'r', 'i', 'c', '\n',
        'i', 'o', 'n', 's', '\n',
        'i', 'o', 't', 'a', '\n',
        'i', 'o', 't', 'a', 's', '\n',
        'i', 'r', 'a', 'n', '\n',
        'i', 'r', 'a', 'n', 'i', 'a', 'n', '\n',
        'i', 'r', 'a', 'n', 'i', 'a', 'n', 's', '\n',
        'i', 'r', 'a', 'q', '\n',
        'i', 'r', 'a', 'q', 'i', '\n',
        'i', 'r', 'a', 'q', 'i', 's', '\n',
        'i', 'r', 'a', 's', 'c', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'r', 'a', 's', 'c', 'i', 'b', 'l', 'e', '\n',
        'i', 'r', 'a', 's', 'c', 'i', 'b', 'l', 'y', '\n',
        'i', 'r', 'a', 't', 'e', '\n',
        'i', 'r', 'e', '\n',
        'i', 'r', 'e', 'l', 'a', 'n', 'd', '\n',
        'i', 'r', 'i', 'd', 'e', 's', 'c', 'e', 'n', 'c', 'e', '\n',
        'i', 'r', 'i', 'd', 'e', 's', 'c', 'e', 'n', 't', '\n',
        'i', 'r', 'i', 'd', 'i', 'u', 'm', '\n',
        'i', 'r', 'i', 's', '\n',
        'i', 'r', 'i', 's', 'e', 's', '\n',
        'i', 'r', 'i', 's', 'h', '\n',
        'i', 'r', 'i', 's', 'h', 'm', 'a', 'n', '\n',
        'i', 'r', 'i', 's', 'h', 'm', 'e', 'n', '\n',
        'i', 'r', 'k', '\n',
        'i', 'r', 'k', 'e', 'd', '\n',
        'i', 'r', 'k', 'i', 'n', 'g', '\n',
        'i', 'r', 'k', 's', '\n',
        'i', 'r', 'k', 's', 'o', 'm', 'e', '\n',
        'i', 'r', 'k', 's', 'o', 'm', 'e', 'n', 'e', 's', 's', '\n',
        'i', 'r', 'o', 'n', '\n',
        'i', 'r', 'o', 'n', 'a', 'g', 'e', '\n',
        'i', 'r', 'o', 'n', 'e', 'd', '\n',
        'i', 'r', 'o', 'n', 'i', 'c', '\n',
        'i', 'r', 'o', 'n', 'i', 'c', 'a', 'l', '\n',
        'i', 'r', 'o', 'n', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'i', 'r', 'o', 'n', 'i', 'e', 's', '\n',
        'i', 'r', 'o', 'n', 'i', 'n', 'g', '\n',
        'i', 'r', 'o', 'n', 'l', 'a', 'd', 'y', '\n',
        'i', 'r', 'o', 'n', 'm', 'o', 'n', 'g', 'e', 'r', '\n',
        'i', 'r', 'o', 'n', 'm', 'o', 'n', 'g', 'e', 'r', 's', '\n',
        'i', 'r', 'o', 'n', 'm', 'o', 'n', 'g', 'e', 'r', 'y', '\n',
        'i', 'r', 'o', 'n', 's', '\n',
        'i', 'r', 'o', 'n', 's', 't', 'o', 'n', 'e', '\n',
        'i', 'r', 'o', 'n', 'w', 'o', 'r', 'k', '\n',
        'i', 'r', 'o', 'n', 'w', 'o', 'r', 'k', 's', '\n',
        'i', 'r', 'o', 'n', 'y', '\n',
        'i', 'r', 'r', 'a', 'd', 'i', 'a', 't', 'e', '\n',
        'i', 'r', 'r', 'a', 'd', 'i', 'a', 't', 'e', 'd', '\n',
        'i', 'r', 'r', 'a', 'd', 'i', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'r', 'r', 'a', 'd', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'r', 'r', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'i', 'r', 'r', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'i', 'r', 'r', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 't', 'y', '\n',
        'i', 'r', 'r', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'i', 'r', 'r', 'e', 'c', 'o', 'n', 'c', 'i', 'l', 'a', 'b', 'l', 'e', '\n',
        'i', 'r', 'r', 'e', 'c', 'o', 'v', 'e', 'r', 'a', 'b', 'l', 'e', '\n',
        'i', 'r', 'r', 'e', 'c', 'o', 'v', 'e', 'r', 'a', 'b', 'l', 'y', '\n',
        'i', 'r', 'r', 'e', 'd', 'e', 'e', 'm', 'a', 'b', 'l', 'e', '\n',
        'i', 'r', 'r', 'e', 'd', 'e', 'e', 'm', 'a', 'b', 'l', 'y', '\n',
        'i', 'r', 'r', 'e', 'd', 'u', 'c', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'r', 'r', 'e', 'd', 'u', 'c', 'i', 'b', 'l', 'e', '\n',
        'i', 'r', 'r', 'e', 'd', 'u', 'c', 'i', 'b', 'l', 'y', '\n',
        'i', 'r', 'r', 'e', 'f', 'u', 't', 'a', 'b', 'l', 'e', '\n',
        'i', 'r', 'r', 'e', 'g', 'u', 'l', 'a', 'r', '\n',
        'i', 'r', 'r', 'e', 'g', 'u', 'l', 'a', 'r', 'i', 't', 'i', 'e', 's', '\n',
        'i', 'r', 'r', 'e', 'g', 'u', 'l', 'a', 'r', 'i', 't', 'y', '\n',
        'i', 'r', 'r', 'e', 'g', 'u', 'l', 'a', 'r', 'l', 'y', '\n',
        'i', 'r', 'r', 'e', 'g', 'u', 'l', 'a', 'r', 's', '\n',
        'i', 'r', 'r', 'e', 'l', 'e', 'v', 'a', 'n', 'c', 'e', '\n',
        'i', 'r', 'r', 'e', 'l', 'e', 'v', 'a', 'n', 'c', 'e', 's', '\n',
        'i', 'r', 'r', 'e', 'l', 'e', 'v', 'a', 'n', 'c', 'y', '\n',
        'i', 'r', 'r', 'e', 'l', 'e', 'v', 'a', 'n', 't', '\n',
        'i', 'r', 'r', 'e', 'l', 'e', 'v', 'a', 'n', 't', 'l', 'y', '\n',
        'i', 'r', 'r', 'e', 'l', 'i', 'g', 'i', 'o', 'u', 's', '\n',
        'i', 'r', 'r', 'e', 'm', 'e', 'd', 'i', 'a', 'b', 'l', 'e', '\n',
        'i', 'r', 'r', 'e', 'm', 'o', 'v', 'a', 'b', 'l', 'e', '\n',
        'i', 'r', 'r', 'e', 'p', 'a', 'r', 'a', 'b', 'l', 'e', '\n',
        'i', 'r', 'r', 'e', 'p', 'a', 'r', 'a', 'b', 'l', 'y', '\n',
        'i', 'r', 'r', 'e', 'p', 'l', 'a', 'c', 'e', 'a', 'b', 'l', 'e', '\n',
        'i', 'r', 'r', 'e', 'p', 'r', 'e', 's', 's', 'i', 'b', 'l', 'e', '\n',
        'i', 'r', 'r', 'e', 'p', 'r', 'e', 's', 's', 'i', 'b', 'l', 'y', '\n',
        'i', 'r', 'r', 'e', 'p', 'r', 'o', 'a', 'c', 'h', 'a', 'b', 'l', 'e', '\n',
        'i', 'r', 'r', 'e', 'p', 'r', 'o', 'a', 'c', 'h', 'a', 'b', 'l', 'y', '\n',
        'i', 'r', 'r', 'e', 's', 'i', 's', 't', 'i', 'b', 'l', 'e', '\n',
        'i', 'r', 'r', 'e', 's', 'i', 's', 't', 'i', 'b', 'l', 'y', '\n',
        'i', 'r', 'r', 'e', 's', 'o', 'l', 'u', 't', 'e', '\n',
        'i', 'r', 'r', 'e', 's', 'o', 'l', 'u', 't', 'e', 'l', 'y', '\n',
        'i', 'r', 'r', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', '\n',
        'i', 'r', 'r', 'e', 's', 'o', 'l', 'v', 'a', 'b', 'l', 'e', '\n',
        'i', 'r', 'r', 'e', 's', 'p', 'e', 'c', 't', 'i', 'v', 'e', '\n',
        'i', 'r', 'r', 'e', 's', 'p', 'e', 'c', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'i', 'r', 'r', 'e', 's', 'p', 'o', 'n', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'r', 'r', 'e', 's', 'p', 'o', 'n', 's', 'i', 'b', 'l', 'e', '\n',
        'i', 'r', 'r', 'e', 's', 'p', 'o', 'n', 's', 'i', 'b', 'l', 'y', '\n',
        'i', 'r', 'r', 'e', 't', 'r', 'i', 'e', 'v', 'a', 'b', 'l', 'e', '\n',
        'i', 'r', 'r', 'e', 't', 'r', 'i', 'e', 'v', 'a', 'b', 'l', 'y', '\n',
        'i', 'r', 'r', 'e', 'v', 'e', 'r', 'e', 'n', 'c', 'e', '\n',
        'i', 'r', 'r', 'e', 'v', 'e', 'r', 'e', 'n', 't', '\n',
        'i', 'r', 'r', 'e', 'v', 'e', 'r', 'e', 'n', 't', 'l', 'y', '\n',
        'i', 'r', 'r', 'e', 'v', 'e', 'r', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'r', 'r', 'e', 'v', 'e', 'r', 's', 'i', 'b', 'l', 'e', '\n',
        'i', 'r', 'r', 'e', 'v', 'e', 'r', 's', 'i', 'b', 'l', 'y', '\n',
        'i', 'r', 'r', 'e', 'v', 'o', 'c', 'a', 'b', 'l', 'e', '\n',
        'i', 'r', 'r', 'e', 'v', 'o', 'c', 'a', 'b', 'l', 'y', '\n',
        'i', 'r', 'r', 'i', 'g', 'a', 't', 'e', '\n',
        'i', 'r', 'r', 'i', 'g', 'a', 't', 'e', 'd', '\n',
        'i', 'r', 'r', 'i', 'g', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'r', 'r', 'i', 'g', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'r', 'r', 'i', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'i', 'r', 'r', 'i', 't', 'a', 'b', 'l', 'e', '\n',
        'i', 'r', 'r', 'i', 't', 'a', 'b', 'l', 'y', '\n',
        'i', 'r', 'r', 'i', 't', 'a', 'n', 't', '\n',
        'i', 'r', 'r', 'i', 't', 'a', 'n', 't', 's', '\n',
        'i', 'r', 'r', 'i', 't', 'a', 't', 'e', '\n',
        'i', 'r', 'r', 'i', 't', 'a', 't', 'e', 'd', '\n',
        'i', 'r', 'r', 'i', 't', 'a', 't', 'e', 'd', 'l', 'y', '\n',
        'i', 'r', 'r', 'i', 't', 'a', 't', 'e', 's', '\n',
        'i', 'r', 'r', 'i', 't', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 'r', 'r', 'i', 't', 'a', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'i', 'r', 'r', 'i', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 'r', 'r', 'i', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 'r', 'r', 'u', 'p', 't', 'e', 'd', '\n',
        'i', 'r', 'r', 'u', 'p', 't', 'i', 'o', 'n', '\n',
        'i', 's', '\n',
        'i', 's', 'i', 's', '\n',
        'i', 's', 'l', 'a', 'm', '\n',
        'i', 's', 'l', 'a', 'm', 'i', 'c', '\n',
        'i', 's', 'l', 'a', 'n', 'd', '\n',
        'i', 's', 'l', 'a', 'n', 'd', 'e', 'r', '\n',
        'i', 's', 'l', 'a', 'n', 'd', 'e', 'r', 's', '\n',
        'i', 's', 'l', 'a', 'n', 'd', 's', '\n',
        'i', 's', 'l', 'e', '\n',
        'i', 's', 'l', 'e', 's', '\n',
        'i', 's', 'l', 'e', 't', '\n',
        'i', 's', 'l', 'e', 't', 's', '\n',
        'i', 's', 'm', 's', '\n',
        'i', 's', 'n', 't', '\n',
        'i', 's', 'o', 'b', 'a', 'r', '\n',
        'i', 's', 'o', 'b', 'a', 'r', 's', '\n',
        'i', 's', 'o', 'g', 'r', 'a', 'm', '\n',
        'i', 's', 'o', 'l', 'a', 't', 'e', '\n',
        'i', 's', 'o', 'l', 'a', 't', 'e', 'd', '\n',
        'i', 's', 'o', 'l', 'a', 't', 'e', 's', '\n',
        'i', 's', 'o', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 's', 'o', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 's', 'o', 'l', 'a', 't', 'i', 'o', 'n', 'i', 's', 'm', '\n',
        'i', 's', 'o', 'l', 'a', 't', 'i', 'o', 'n', 'i', 's', 't', '\n',
        'i', 's', 'o', 'l', 'a', 't', 'o', 'r', '\n',
        'i', 's', 'o', 'l', 'a', 't', 'o', 'r', 's', '\n',
        'i', 's', 'o', 'm', 'e', 'r', '\n',
        'i', 's', 'o', 'm', 'e', 'r', 'i', 'c', '\n',
        'i', 's', 'o', 'm', 'e', 'r', 's', '\n',
        'i', 's', 'o', 'm', 'e', 't', 'r', 'i', 'c', '\n',
        'i', 's', 'o', 'm', 'e', 't', 'r', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'i', 's', 'o', 'm', 'e', 't', 'r', 'y', '\n',
        'i', 's', 'o', 'm', 'o', 'r', 'p', 'h', '\n',
        'i', 's', 'o', 'm', 'o', 'r', 'p', 'h', 'i', 'c', '\n',
        'i', 's', 'o', 'm', 'o', 'r', 'p', 'h', 'i', 's', 'm', '\n',
        'i', 's', 'o', 'm', 'o', 'r', 'p', 'h', 'i', 's', 'm', 's', '\n',
        'i', 's', 'o', 'p', 'e', 'r', 'i', 'm', 'e', 't', 'r', 'i', 'c', 'a', 'l', '\n',
        'i', 's', 'o', 's', 'c', 'e', 'l', 'e', 's', '\n',
        'i', 's', 'o', 's', 't', 'a', 't', 'i', 'c', '\n',
        'i', 's', 'o', 't', 'h', 'e', 'r', 'm', 'a', 'l', '\n',
        'i', 's', 'o', 't', 'h', 'e', 'r', 'm', 'a', 'l', 'l', 'y', '\n',
        'i', 's', 'o', 't', 'o', 'n', 'i', 'c', '\n',
        'i', 's', 'o', 't', 'o', 'p', 'e', '\n',
        'i', 's', 'o', 't', 'o', 'p', 'e', 's', '\n',
        'i', 's', 'o', 't', 'o', 'p', 'i', 'c', '\n',
        'i', 's', 'o', 't', 'r', 'o', 'p', 'i', 'c', '\n',
        'i', 's', 'o', 't', 'r', 'o', 'p', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'i', 's', 'o', 't', 'r', 'o', 'p', 'y', '\n',
        'i', 's', 'r', 'a', 'e', 'l', '\n',
        'i', 's', 'r', 'a', 'e', 'l', 'i', '\n',
        'i', 's', 'r', 'a', 'e', 'l', 'i', 's', '\n',
        'i', 's', 's', 'u', 'a', 'b', 'l', 'e', '\n',
        'i', 's', 's', 'u', 'a', 'n', 'c', 'e', '\n',
        'i', 's', 's', 'u', 'e', '\n',
        'i', 's', 's', 'u', 'e', 'd', '\n',
        'i', 's', 's', 'u', 'e', 'r', '\n',
        'i', 's', 's', 'u', 'e', 'r', 's', '\n',
        'i', 's', 's', 'u', 'e', 's', '\n',
        'i', 's', 's', 'u', 'i', 'n', 'g', '\n',
        'i', 's', 't', 'a', 'n', 'b', 'u', 'l', '\n',
        'i', 's', 't', 'h', 'm', 'u', 's', '\n',
        'i', 't', '\n',
        'i', 't', 'a', 'l', 'i', 'a', 'n', '\n',
        'i', 't', 'a', 'l', 'i', 'a', 'n', 's', '\n',
        'i', 't', 'a', 'l', 'i', 'c', '\n',
        'i', 't', 'a', 'l', 'i', 'c', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 't', 'a', 'l', 'i', 'c', 'i', 's', 'e', '\n',
        'i', 't', 'a', 'l', 'i', 'c', 'i', 's', 'e', 'd', '\n',
        'i', 't', 'a', 'l', 'i', 'c', 's', '\n',
        'i', 't', 'a', 'l', 'y', '\n',
        'i', 't', 'c', 'h', '\n',
        'i', 't', 'c', 'h', 'e', 'd', '\n',
        'i', 't', 'c', 'h', 'e', 's', '\n',
        'i', 't', 'c', 'h', 'i', 'e', 'r', '\n',
        'i', 't', 'c', 'h', 'i', 'e', 's', 't', '\n',
        'i', 't', 'c', 'h', 'i', 'n', 'g', '\n',
        'i', 't', 'c', 'h', 'y', '\n',
        'i', 't', 'e', 'm', '\n',
        'i', 't', 'e', 'm', 'i', 's', 'e', '\n',
        'i', 't', 'e', 'm', 'i', 's', 'e', 'd', '\n',
        'i', 't', 'e', 'm', 'i', 's', 'e', 's', '\n',
        'i', 't', 'e', 'm', 'i', 's', 'i', 'n', 'g', '\n',
        'i', 't', 'e', 'm', 's', '\n',
        'i', 't', 'e', 'r', 'a', 't', 'e', '\n',
        'i', 't', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'i', 't', 'e', 'r', 'a', 't', 'e', 's', '\n',
        'i', 't', 'e', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'i', 't', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'i', 't', 'e', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'i', 't', 'e', 'r', 'a', 't', 'i', 'v', 'e', '\n',
        'i', 't', 'e', 'r', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'i', 't', 'e', 'r', 'a', 't', 'o', 'r', 's', '\n',
        'i', 't', 'i', 'n', 'e', 'r', 'a', 'n', 't', '\n',
        'i', 't', 'i', 'n', 'e', 'r', 'a', 'n', 't', 's', '\n',
        'i', 't', 'i', 'n', 'e', 'r', 'a', 'r', 'i', 'e', 's', '\n',
        'i', 't', 'i', 'n', 'e', 'r', 'a', 'r', 'y', '\n',
        'i', 't', 'l', 'l', '\n',
        'i', 't', 's', '\n',
        'i', 't', 's', 'e', 'l', 'f', '\n',
        'i', 'v', 'e', '\n',
        'i', 'v', 'i', 'e', 's', '\n',
        'i', 'v', 'o', 'r', 'i', 'e', 's', '\n',
        'i', 'v', 'o', 'r', 'y', '\n',
        'i', 'v', 'y', '\n',
        'j', 'a', 'b', '\n',
        'j', 'a', 'b', 'b', 'e', 'd', '\n',
        'j', 'a', 'b', 'b', 'e', 'r', '\n',
        'j', 'a', 'b', 'b', 'e', 'r', 'e', 'd', '\n',
        'j', 'a', 'b', 'b', 'e', 'r', 'i', 'n', 'g', '\n',
        'j', 'a', 'b', 'b', 'e', 'r', 's', '\n',
        'j', 'a', 'b', 'b', 'i', 'n', 'g', '\n',
        'j', 'a', 'b', 's', '\n',
        'j', 'a', 'c', 'k', '\n',
        'j', 'a', 'c', 'k', 'a', 'l', '\n',
        'j', 'a', 'c', 'k', 'a', 'l', 's', '\n',
        'j', 'a', 'c', 'k', 'a', 's', 's', '\n',
        'j', 'a', 'c', 'k', 'a', 's', 's', 'e', 's', '\n',
        'j', 'a', 'c', 'k', 'b', 'o', 'o', 't', '\n',
        'j', 'a', 'c', 'k', 'b', 'o', 'o', 't', 'e', 'd', '\n',
        'j', 'a', 'c', 'k', 'b', 'o', 'o', 't', 's', '\n',
        'j', 'a', 'c', 'k', 'd', 'a', 'w', '\n',
        'j', 'a', 'c', 'k', 'd', 'a', 'w', 's', '\n',
        'j', 'a', 'c', 'k', 'e', 'd', '\n',
        'j', 'a', 'c', 'k', 'e', 't', '\n',
        'j', 'a', 'c', 'k', 'e', 't', 's', '\n',
        'j', 'a', 'c', 'k', 'i', 'n', 'g', '\n',
        'j', 'a', 'c', 'k', 'i', 'n', 't', 'h', 'e', 'b', 'o', 'x', '\n',
        'j', 'a', 'c', 'k', 'p', 'o', 't', '\n',
        'j', 'a', 'c', 'k', 'p', 'o', 't', 's', '\n',
        'j', 'a', 'c', 'k', 's', '\n',
        'j', 'a', 'c', 'o', 'b', '\n',
        'j', 'a', 'c', 'u', 'z', 'z', 'i', '\n',
        'j', 'a', 'd', 'e', '\n',
        'j', 'a', 'd', 'e', 'd', '\n',
        'j', 'a', 'd', 'e', 'd', 'l', 'y', '\n',
        'j', 'a', 'd', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'j', 'a', 'd', 'e', 's', '\n',
        'j', 'a', 'g', '\n',
        'j', 'a', 'g', 'g', 'e', 'd', '\n',
        'j', 'a', 'g', 'g', 'e', 'd', 'l', 'y', '\n',
        'j', 'a', 'g', 'u', 'a', 'r', '\n',
        'j', 'a', 'g', 'u', 'a', 'r', 's', '\n',
        'j', 'a', 'h', 'w', 'e', 'h', '\n',
        'j', 'a', 'i', 'l', '\n',
        'j', 'a', 'i', 'l', 'b', 'i', 'r', 'd', '\n',
        'j', 'a', 'i', 'l', 'e', 'd', '\n',
        'j', 'a', 'i', 'l', 'e', 'r', '\n',
        'j', 'a', 'i', 'l', 'e', 'r', 's', '\n',
        'j', 'a', 'i', 'l', 'i', 'n', 'g', '\n',
        'j', 'a', 'i', 'l', 's', '\n',
        'j', 'a', 'k', 'a', 'r', 't', 'a', '\n',
        'j', 'a', 'l', 'o', 'p', 'y', '\n',
        'j', 'a', 'm', '\n',
        'j', 'a', 'm', 'a', 'i', 'c', 'a', '\n',
        'j', 'a', 'm', 'a', 'i', 'c', 'a', 'n', '\n',
        'j', 'a', 'm', 'b', '\n',
        'j', 'a', 'm', 'b', 'o', 'r', 'e', 'e', '\n',
        'j', 'a', 'm', 'b', 's', '\n',
        'j', 'a', 'm', 'e', 's', '\n',
        'j', 'a', 'm', 'm', 'e', 'd', '\n',
        'j', 'a', 'm', 'm', 'i', 'n', 'g', '\n',
        'j', 'a', 'm', 's', '\n',
        'j', 'a', 'n', 'g', 'l', 'e', '\n',
        'j', 'a', 'n', 'g', 'l', 'e', 'd', '\n',
        'j', 'a', 'n', 'g', 'l', 'i', 'n', 'g', '\n',
        'j', 'a', 'n', 'g', 'l', 'y', '\n',
        'j', 'a', 'n', 'i', 't', 'o', 'r', '\n',
        'j', 'a', 'n', 'i', 't', 'o', 'r', 's', '\n',
        'j', 'a', 'n', 'u', 'a', 'r', 'y', '\n',
        'j', 'a', 'n', 'u', 's', '\n',
        'j', 'a', 'p', '\n',
        'j', 'a', 'p', 'a', 'n', '\n',
        'j', 'a', 'p', 'e', '\n',
        'j', 'a', 'p', 'e', 's', '\n',
        'j', 'a', 'p', 'o', 'n', 'i', 'c', 'a', '\n',
        'j', 'a', 'r', '\n',
        'j', 'a', 'r', 'g', 'o', 'n', '\n',
        'j', 'a', 'r', 'g', 'o', 'n', 's', '\n',
        'j', 'a', 'r', 'l', '\n',
        'j', 'a', 'r', 'r', 'e', 'd', '\n',
        'j', 'a', 'r', 'r', 'i', 'n', 'g', '\n',
        'j', 'a', 'r', 's', '\n',
        'j', 'a', 's', 'm', 'i', 'n', 'e', '\n',
        'j', 'a', 'u', 'n', 'd', 'i', 'c', 'e', '\n',
        'j', 'a', 'u', 'n', 'd', 'i', 'c', 'e', 'd', '\n',
        'j', 'a', 'u', 'n', 't', '\n',
        'j', 'a', 'u', 'n', 't', 'e', 'd', '\n',
        'j', 'a', 'u', 'n', 't', 'i', 'e', 'r', '\n',
        'j', 'a', 'u', 'n', 't', 'i', 'e', 's', 't', '\n',
        'j', 'a', 'u', 'n', 't', 'i', 'l', 'y', '\n',
        'j', 'a', 'u', 'n', 't', 'i', 'n', 'g', '\n',
        'j', 'a', 'u', 'n', 't', 's', '\n',
        'j', 'a', 'u', 'n', 't', 'y', '\n',
        'j', 'a', 'v', 'a', '\n',
        'j', 'a', 'v', 'e', 'l', 'i', 'n', '\n',
        'j', 'a', 'v', 'e', 'l', 'i', 'n', 's', '\n',
        'j', 'a', 'w', '\n',
        'j', 'a', 'w', 'b', 'o', 'n', 'e', '\n',
        'j', 'a', 'w', 'b', 'o', 'n', 'e', 's', '\n',
        'j', 'a', 'w', 'e', 'd', '\n',
        'j', 'a', 'w', 'i', 'n', 'g', '\n',
        'j', 'a', 'w', 'l', 'i', 'n', 'e', '\n',
        'j', 'a', 'w', 's', '\n',
        'j', 'a', 'y', '\n',
        'j', 'a', 'y', 's', '\n',
        'j', 'a', 'y', 'w', 'a', 'l', 'k', '\n',
        'j', 'a', 'y', 'w', 'a', 'l', 'k', 'e', 'r', '\n',
        'j', 'a', 'y', 'w', 'a', 'l', 'k', 'i', 'n', 'g', '\n',
        'j', 'a', 'z', 'z', '\n',
        'j', 'a', 'z', 'z', 'e', 'd', '\n',
        'j', 'a', 'z', 'z', 'i', 'e', 'r', '\n',
        'j', 'a', 'z', 'z', 'i', 'e', 's', 't', '\n',
        'j', 'a', 'z', 'z', 'y', '\n',
        'j', 'e', 'a', 'l', 'o', 'u', 's', '\n',
        'j', 'e', 'a', 'l', 'o', 'u', 's', 'i', 'e', 's', '\n',
        'j', 'e', 'a', 'l', 'o', 'u', 's', 'l', 'y', '\n',
        'j', 'e', 'a', 'l', 'o', 'u', 's', 'y', '\n',
        'j', 'e', 'a', 'n', 's', '\n',
        'j', 'e', 'e', 'p', '\n',
        'j', 'e', 'e', 'p', 's', '\n',
        'j', 'e', 'e', 'r', '\n',
        'j', 'e', 'e', 'r', 'e', 'd', '\n',
        'j', 'e', 'e', 'r', 'i', 'n', 'g', '\n',
        'j', 'e', 'e', 'r', 'i', 'n', 'g', 'l', 'y', '\n',
        'j', 'e', 'e', 'r', 'i', 'n', 'g', 's', '\n',
        'j', 'e', 'e', 'r', 's', '\n',
        'j', 'e', 'h', 'a', 'd', '\n',
        'j', 'e', 'j', 'u', 'n', 'e', '\n',
        'j', 'e', 'j', 'u', 'n', 'u', 'm', '\n',
        'j', 'e', 'l', 'l', '\n',
        'j', 'e', 'l', 'l', 'i', 'e', 'd', '\n',
        'j', 'e', 'l', 'l', 'i', 'e', 's', '\n',
        'j', 'e', 'l', 'l', 'i', 'f', 'y', '\n',
        'j', 'e', 'l', 'l', 'y', '\n',
        'j', 'e', 'l', 'l', 'y', 'f', 'i', 's', 'h', '\n',
        'j', 'e', 'm', 'm', 'y', '\n',
        'j', 'e', 'n', 'n', 'e', 't', 's', '\n',
        'j', 'e', 'o', 'p', 'a', 'r', 'd', 'i', 's', 'e', '\n',
        'j', 'e', 'o', 'p', 'a', 'r', 'd', 'i', 's', 'e', 'd', '\n',
        'j', 'e', 'o', 'p', 'a', 'r', 'd', 'i', 's', 'e', 's', '\n',
        'j', 'e', 'o', 'p', 'a', 'r', 'd', 'i', 's', 'i', 'n', 'g', '\n',
        'j', 'e', 'o', 'p', 'a', 'r', 'd', 'y', '\n',
        'j', 'e', 'r', 'b', 'o', 'a', 's', '\n',
        'j', 'e', 'r', 'e', 'm', 'i', 'a', 'h', '\n',
        'j', 'e', 'r', 'i', 'c', 'h', 'o', '\n',
        'j', 'e', 'r', 'k', '\n',
        'j', 'e', 'r', 'k', 'e', 'd', '\n',
        'j', 'e', 'r', 'k', 'i', 'e', 'r', '\n',
        'j', 'e', 'r', 'k', 'i', 'e', 's', 't', '\n',
        'j', 'e', 'r', 'k', 'i', 'l', 'y', '\n',
        'j', 'e', 'r', 'k', 'i', 'n', '\n',
        'j', 'e', 'r', 'k', 'i', 'n', 'g', '\n',
        'j', 'e', 'r', 'k', 'i', 'n', 'g', 's', '\n',
        'j', 'e', 'r', 'k', 'i', 'n', 's', '\n',
        'j', 'e', 'r', 'k', 's', '\n',
        'j', 'e', 'r', 'k', 'y', '\n',
        'j', 'e', 'r', 's', 'e', 'y', '\n',
        'j', 'e', 'r', 's', 'e', 'y', 's', '\n',
        'j', 'e', 's', 't', '\n',
        'j', 'e', 's', 't', 'e', 'd', '\n',
        'j', 'e', 's', 't', 'e', 'r', '\n',
        'j', 'e', 's', 't', 'e', 'r', 's', '\n',
        'j', 'e', 's', 't', 'i', 'n', 'g', '\n',
        'j', 'e', 's', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'j', 'e', 's', 't', 's', '\n',
        'j', 'e', 's', 'u', 'i', 't', '\n',
        'j', 'e', 's', 'u', 's', '\n',
        'j', 'e', 't', '\n',
        'j', 'e', 't', 'l', 'a', 'g', 'g', 'e', 'd', '\n',
        'j', 'e', 't', 'p', 'l', 'a', 'n', 'e', '\n',
        'j', 'e', 't', 'p', 'r', 'o', 'p', 'e', 'l', 'l', 'e', 'd', '\n',
        'j', 'e', 't', 's', '\n',
        'j', 'e', 't', 's', 'a', 'm', '\n',
        'j', 'e', 't', 's', 'e', 't', 't', 'i', 'n', 'g', '\n',
        'j', 'e', 't', 't', 'e', 'd', '\n',
        'j', 'e', 't', 't', 'i', 'e', 's', '\n',
        'j', 'e', 't', 't', 'i', 'n', 'g', '\n',
        'j', 'e', 't', 't', 'i', 's', 'o', 'n', '\n',
        'j', 'e', 't', 't', 'i', 's', 'o', 'n', 'e', 'd', '\n',
        'j', 'e', 't', 't', 'i', 's', 'o', 'n', 'i', 'n', 'g', '\n',
        'j', 'e', 't', 't', 'y', '\n',
        'j', 'e', 'w', '\n',
        'j', 'e', 'w', 'e', 'l', '\n',
        'j', 'e', 'w', 'e', 'l', 'l', 'e', 'd', '\n',
        'j', 'e', 'w', 'e', 'l', 'l', 'e', 'r', '\n',
        'j', 'e', 'w', 'e', 'l', 'l', 'e', 'r', 's', '\n',
        'j', 'e', 'w', 'e', 'l', 'l', 'e', 'r', 'y', '\n',
        'j', 'e', 'w', 'e', 'l', 'r', 'y', '\n',
        'j', 'e', 'w', 'e', 'l', 's', '\n',
        'j', 'e', 'w', 'e', 's', 's', '\n',
        'j', 'e', 'w', 'i', 's', 'h', '\n',
        'j', 'e', 'w', 's', '\n',
        'j', 'e', 'w', 's', 'h', 'a', 'r', 'p', '\n',
        'j', 'e', 'z', 'e', 'b', 'e', 'l', '\n',
        'j', 'i', 'f', 'f', 'y', '\n',
        'j', 'i', 'g', 'g', 'l', 'e', '\n',
        'j', 'i', 'g', 'g', 'l', 'i', 'n', 'g', '\n',
        'j', 'i', 'g', 's', '\n',
        'j', 'i', 'g', 's', 'a', 'w', '\n',
        'j', 'i', 'g', 's', 'a', 'w', 's', '\n',
        'j', 'i', 'h', 'a', 'd', '\n',
        'j', 'i', 'l', 't', '\n',
        'j', 'i', 'l', 't', 'e', 'd', '\n',
        'j', 'i', 'l', 't', 'i', 'n', 'g', '\n',
        'j', 'i', 'l', 't', 's', '\n',
        'j', 'i', 'm', 'm', 'y', '\n',
        'j', 'i', 'n', 'g', 'l', 'e', '\n',
        'j', 'i', 'n', 'g', 'l', 'e', 'd', '\n',
        'j', 'i', 'n', 'g', 'l', 'e', 's', '\n',
        'j', 'i', 'n', 'g', 'l', 'i', 'n', 'g', '\n',
        'j', 'i', 'n', 'g', 'o', '\n',
        'j', 'i', 'n', 'g', 'o', 'i', 's', 'm', '\n',
        'j', 'i', 'n', 'g', 'o', 'i', 's', 't', 'i', 'c', '\n',
        'j', 'i', 'n', 'k', 'e', 'd', '\n',
        'j', 'i', 'n', 'k', 's', '\n',
        'j', 'i', 'n', 'x', '\n',
        'j', 'i', 'n', 'x', 'e', 'd', '\n',
        'j', 'i', 'n', 'x', 'e', 's', '\n',
        'j', 'i', 't', 't', 'e', 'r', '\n',
        'j', 'i', 't', 't', 'e', 'r', 's', '\n',
        'j', 'i', 't', 't', 'e', 'r', 'y', '\n',
        'j', 'i', 'u', 'j', 'i', 't', 's', 'u', '\n',
        'j', 'i', 'v', 'e', '\n',
        'j', 'i', 'v', 'e', 'd', '\n',
        'j', 'i', 'v', 'e', 's', '\n',
        'j', 'o', 'b', '\n',
        'j', 'o', 'b', 'b', 'i', 'n', 'g', '\n',
        'j', 'o', 'b', 'l', 'e', 's', 's', '\n',
        'j', 'o', 'b', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'j', 'o', 'b', 's', '\n',
        'j', 'o', 'c', 'k', '\n',
        'j', 'o', 'c', 'k', 'e', 'y', '\n',
        'j', 'o', 'c', 'k', 'e', 'y', 'i', 'n', 'g', '\n',
        'j', 'o', 'c', 'k', 'e', 'y', 's', '\n',
        'j', 'o', 'c', 'u', 'l', 'a', 'r', '\n',
        'j', 'o', 'c', 'u', 'l', 'a', 'r', 'i', 't', 'y', '\n',
        'j', 'o', 'c', 'u', 'l', 'a', 'r', 'l', 'y', '\n',
        'j', 'o', 'e', 'y', '\n',
        'j', 'o', 'g', '\n',
        'j', 'o', 'g', 'g', 'e', 'd', '\n',
        'j', 'o', 'g', 'g', 'e', 'r', '\n',
        'j', 'o', 'g', 'g', 'e', 'r', 's', '\n',
        'j', 'o', 'g', 'g', 'i', 'n', 'g', '\n',
        'j', 'o', 'g', 's', '\n',
        'j', 'o', 'h', 'n', '\n',
        'j', 'o', 'i', 'n', '\n',
        'j', 'o', 'i', 'n', 'e', 'd', '\n',
        'j', 'o', 'i', 'n', 'e', 'r', '\n',
        'j', 'o', 'i', 'n', 'e', 'r', 's', '\n',
        'j', 'o', 'i', 'n', 'e', 'r', 'y', '\n',
        'j', 'o', 'i', 'n', 'i', 'n', 'g', '\n',
        'j', 'o', 'i', 'n', 's', '\n',
        'j', 'o', 'i', 'n', 't', '\n',
        'j', 'o', 'i', 'n', 't', 'e', 'd', '\n',
        'j', 'o', 'i', 'n', 't', 'i', 'n', 'g', '\n',
        'j', 'o', 'i', 'n', 't', 'l', 'y', '\n',
        'j', 'o', 'i', 'n', 't', 's', '\n',
        'j', 'o', 'i', 'n', 't', 'u', 'r', 'e', 's', '\n',
        'j', 'o', 'i', 's', 't', '\n',
        'j', 'o', 'i', 's', 't', 's', '\n',
        'j', 'o', 'k', 'e', '\n',
        'j', 'o', 'k', 'e', 'd', '\n',
        'j', 'o', 'k', 'e', 'r', '\n',
        'j', 'o', 'k', 'e', 'r', 's', '\n',
        'j', 'o', 'k', 'e', 's', '\n',
        'j', 'o', 'k', 'e', 'y', '\n',
        'j', 'o', 'k', 'i', 'e', 'r', '\n',
        'j', 'o', 'k', 'i', 'l', 'y', '\n',
        'j', 'o', 'k', 'i', 'n', 'g', '\n',
        'j', 'o', 'k', 'i', 'n', 'g', 'l', 'y', '\n',
        'j', 'o', 'l', 'l', 'i', 'e', 'r', '\n',
        'j', 'o', 'l', 'l', 'i', 'e', 's', 't', '\n',
        'j', 'o', 'l', 'l', 'i', 'f', 'y', '\n',
        'j', 'o', 'l', 'l', 'i', 'l', 'y', '\n',
        'j', 'o', 'l', 'l', 'i', 't', 'y', '\n',
        'j', 'o', 'l', 'l', 'y', '\n',
        'j', 'o', 'l', 't', '\n',
        'j', 'o', 'l', 't', 'e', 'd', '\n',
        'j', 'o', 'l', 't', 'i', 'n', 'g', '\n',
        'j', 'o', 'l', 't', 's', '\n',
        'j', 'o', 'n', 'a', 'h', '\n',
        'j', 'o', 'n', 'a', 't', 'h', 'a', 'n', '\n',
        'j', 'o', 's', 'e', 'p', 'h', '\n',
        'j', 'o', 's', 'h', 'u', 'a', '\n',
        'j', 'o', 's', 't', 'l', 'e', '\n',
        'j', 'o', 's', 't', 'l', 'e', 'd', '\n',
        'j', 'o', 's', 't', 'l', 'e', 's', '\n',
        'j', 'o', 's', 't', 'l', 'i', 'n', 'g', '\n',
        'j', 'o', 't', '\n',
        'j', 'o', 't', 's', '\n',
        'j', 'o', 't', 't', 'e', 'd', '\n',
        'j', 'o', 't', 't', 'e', 'r', '\n',
        'j', 'o', 't', 't', 'i', 'n', 'g', '\n',
        'j', 'o', 't', 't', 'i', 'n', 'g', 's', '\n',
        'j', 'o', 'u', 'l', 'e', '\n',
        'j', 'o', 'u', 'l', 'e', 's', '\n',
        'j', 'o', 'u', 'r', 'n', 'a', 'l', '\n',
        'j', 'o', 'u', 'r', 'n', 'a', 'l', 'e', 's', 'e', '\n',
        'j', 'o', 'u', 'r', 'n', 'a', 'l', 'i', 's', 'm', '\n',
        'j', 'o', 'u', 'r', 'n', 'a', 'l', 'i', 's', 't', '\n',
        'j', 'o', 'u', 'r', 'n', 'a', 'l', 'i', 's', 't', 'i', 'c', '\n',
        'j', 'o', 'u', 'r', 'n', 'a', 'l', 'i', 's', 't', 's', '\n',
        'j', 'o', 'u', 'r', 'n', 'a', 'l', 'l', 'e', 'd', '\n',
        'j', 'o', 'u', 'r', 'n', 'a', 'l', 'l', 'i', 'n', 'g', '\n',
        'j', 'o', 'u', 'r', 'n', 'a', 'l', 's', '\n',
        'j', 'o', 'u', 'r', 'n', 'e', 'y', '\n',
        'j', 'o', 'u', 'r', 'n', 'e', 'y', 'e', 'd', '\n',
        'j', 'o', 'u', 'r', 'n', 'e', 'y', 'e', 'r', '\n',
        'j', 'o', 'u', 'r', 'n', 'e', 'y', 'i', 'n', 'g', '\n',
        'j', 'o', 'u', 'r', 'n', 'e', 'y', 'm', 'a', 'n', '\n',
        'j', 'o', 'u', 'r', 'n', 'e', 'y', 's', '\n',
        'j', 'o', 'u', 's', 't', '\n',
        'j', 'o', 'u', 's', 't', 'e', 'r', '\n',
        'j', 'o', 'u', 's', 't', 'i', 'n', 'g', '\n',
        'j', 'o', 'u', 's', 't', 's', '\n',
        'j', 'o', 'v', 'i', 'a', 'l', '\n',
        'j', 'o', 'v', 'i', 'a', 'l', 'i', 't', 'y', '\n',
        'j', 'o', 'v', 'i', 'a', 'l', 'l', 'y', '\n',
        'j', 'o', 'v', 'i', 'a', 'n', '\n',
        'j', 'o', 'w', 'l', '\n',
        'j', 'o', 'w', 'l', 's', '\n',
        'j', 'o', 'y', '\n',
        'j', 'o', 'y', 'e', 'd', '\n',
        'j', 'o', 'y', 'f', 'u', 'l', '\n',
        'j', 'o', 'y', 'f', 'u', 'l', 'l', 'y', '\n',
        'j', 'o', 'y', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'j', 'o', 'y', 'l', 'e', 's', 's', '\n',
        'j', 'o', 'y', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'j', 'o', 'y', 'o', 'u', 's', '\n',
        'j', 'o', 'y', 'o', 'u', 's', 'l', 'y', '\n',
        'j', 'o', 'y', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'j', 'o', 'y', 'r', 'i', 'd', 'e', '\n',
        'j', 'o', 'y', 'r', 'i', 'd', 'e', 'r', '\n',
        'j', 'o', 'y', 'r', 'i', 'd', 'e', 'r', 's', '\n',
        'j', 'o', 'y', 'r', 'i', 'd', 'i', 'n', 'g', '\n',
        'j', 'o', 'y', 's', '\n',
        'j', 'o', 'y', 's', 't', 'i', 'c', 'k', '\n',
        'j', 'o', 'y', 's', 't', 'i', 'c', 'k', 's', '\n',
        'j', 'u', 'b', 'i', 'l', 'a', 'n', 't', '\n',
        'j', 'u', 'b', 'i', 'l', 'a', 'n', 't', 'l', 'y', '\n',
        'j', 'u', 'b', 'i', 'l', 'a', 't', 'e', '\n',
        'j', 'u', 'b', 'i', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'j', 'u', 'b', 'i', 'l', 'e', 'e', '\n',
        'j', 'u', 'b', 'i', 'l', 'e', 'e', 's', '\n',
        'j', 'u', 'd', 'a', 'i', 'c', '\n',
        'j', 'u', 'd', 'a', 'i', 's', 'm', '\n',
        'j', 'u', 'd', 'a', 's', '\n',
        'j', 'u', 'd', 'd', 'e', 'r', '\n',
        'j', 'u', 'd', 'd', 'e', 'r', 'e', 'd', '\n',
        'j', 'u', 'd', 'd', 'e', 'r', 'i', 'n', 'g', '\n',
        'j', 'u', 'd', 'd', 'e', 'r', 's', '\n',
        'j', 'u', 'd', 'g', 'e', '\n',
        'j', 'u', 'd', 'g', 'e', 'd', '\n',
        'j', 'u', 'd', 'g', 'e', 'm', 'e', 'n', 't', '\n',
        'j', 'u', 'd', 'g', 'e', 'm', 'e', 'n', 't', 'a', 'l', '\n',
        'j', 'u', 'd', 'g', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'j', 'u', 'd', 'g', 'e', 's', '\n',
        'j', 'u', 'd', 'g', 'i', 'n', 'g', '\n',
        'j', 'u', 'd', 'g', 'm', 'e', 'n', 't', '\n',
        'j', 'u', 'd', 'g', 'm', 'e', 'n', 't', 'a', 'l', '\n',
        'j', 'u', 'd', 'g', 'm', 'e', 'n', 't', 's', '\n',
        'j', 'u', 'd', 'i', 'c', 'a', 't', 'u', 'r', 'e', '\n',
        'j', 'u', 'd', 'i', 'c', 'i', 'a', 'l', '\n',
        'j', 'u', 'd', 'i', 'c', 'i', 'a', 'l', 'l', 'y', '\n',
        'j', 'u', 'd', 'i', 'c', 'i', 'a', 'r', 'i', 'e', 's', '\n',
        'j', 'u', 'd', 'i', 'c', 'i', 'a', 'r', 'y', '\n',
        'j', 'u', 'd', 'i', 'c', 'i', 'o', 'u', 's', '\n',
        'j', 'u', 'd', 'i', 'c', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'j', 'u', 'd', 'o', '\n',
        'j', 'u', 'g', '\n',
        'j', 'u', 'g', 'g', 'e', 'd', '\n',
        'j', 'u', 'g', 'g', 'e', 'r', 'n', 'a', 'u', 't', '\n',
        'j', 'u', 'g', 'g', 'e', 'r', 'n', 'a', 'u', 't', 's', '\n',
        'j', 'u', 'g', 'g', 'l', 'e', '\n',
        'j', 'u', 'g', 'g', 'l', 'e', 'd', '\n',
        'j', 'u', 'g', 'g', 'l', 'e', 'r', '\n',
        'j', 'u', 'g', 'g', 'l', 'e', 'r', 's', '\n',
        'j', 'u', 'g', 'g', 'l', 'e', 's', '\n',
        'j', 'u', 'g', 'g', 'l', 'i', 'n', 'g', '\n',
        'j', 'u', 'g', 's', '\n',
        'j', 'u', 'g', 'u', 'l', 'a', 'r', '\n',
        'j', 'u', 'i', 'c', 'e', '\n',
        'j', 'u', 'i', 'c', 'e', 's', '\n',
        'j', 'u', 'i', 'c', 'i', 'e', 'r', '\n',
        'j', 'u', 'i', 'c', 'i', 'e', 's', 't', '\n',
        'j', 'u', 'i', 'c', 'i', 'n', 'e', 's', 's', '\n',
        'j', 'u', 'i', 'c', 'y', '\n',
        'j', 'u', 'k', 'e', 'b', 'o', 'x', '\n',
        'j', 'u', 'k', 'e', 'b', 'o', 'x', 'e', 's', '\n',
        'j', 'u', 'l', 'e', 'p', '\n',
        'j', 'u', 'l', 'e', 'p', 's', '\n',
        'j', 'u', 'l', 'y', '\n',
        'j', 'u', 'm', 'b', 'l', 'e', '\n',
        'j', 'u', 'm', 'b', 'l', 'e', 'd', '\n',
        'j', 'u', 'm', 'b', 'l', 'e', 's', '\n',
        'j', 'u', 'm', 'b', 'o', '\n',
        'j', 'u', 'm', 'p', '\n',
        'j', 'u', 'm', 'p', 'e', 'd', '\n',
        'j', 'u', 'm', 'p', 'e', 'r', '\n',
        'j', 'u', 'm', 'p', 'e', 'r', 's', '\n',
        'j', 'u', 'm', 'p', 'i', 'e', 'r', '\n',
        'j', 'u', 'm', 'p', 'i', 'e', 's', 't', '\n',
        'j', 'u', 'm', 'p', 'i', 'n', 'e', 's', 's', '\n',
        'j', 'u', 'm', 'p', 'i', 'n', 'g', '\n',
        'j', 'u', 'm', 'p', 's', '\n',
        'j', 'u', 'm', 'p', 's', 't', 'a', 'r', 't', '\n',
        'j', 'u', 'm', 'p', 's', 't', 'a', 'r', 't', 'i', 'n', 'g', '\n',
        'j', 'u', 'm', 'p', 's', 'u', 'i', 't', '\n',
        'j', 'u', 'm', 'p', 'y', '\n',
        'j', 'u', 'n', 'c', 't', 'i', 'o', 'n', '\n',
        'j', 'u', 'n', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'j', 'u', 'n', 'c', 't', 'u', 'r', 'e', '\n',
        'j', 'u', 'n', 'e', '\n',
        'j', 'u', 'n', 'g', 'l', 'e', '\n',
        'j', 'u', 'n', 'g', 'l', 'e', 's', '\n',
        'j', 'u', 'n', 'i', 'o', 'r', '\n',
        'j', 'u', 'n', 'i', 'o', 'r', 'i', 't', 'y', '\n',
        'j', 'u', 'n', 'i', 'o', 'r', 's', '\n',
        'j', 'u', 'n', 'i', 'p', 'e', 'r', '\n',
        'j', 'u', 'n', 'k', '\n',
        'j', 'u', 'n', 'k', 'e', 'r', '\n',
        'j', 'u', 'n', 'k', 'e', 't', '\n',
        'j', 'u', 'n', 'k', 'i', 'e', '\n',
        'j', 'u', 'n', 'k', 'i', 'e', 's', '\n',
        'j', 'u', 'n', 'k', 'm', 'a', 'i', 'l', '\n',
        'j', 'u', 'n', 'k', 's', '\n',
        'j', 'u', 'n', 'k', 'y', 'a', 'r', 'd', '\n',
        'j', 'u', 'n', 'o', '\n',
        'j', 'u', 'n', 't', 'a', '\n',
        'j', 'u', 'n', 't', 'a', 's', '\n',
        'j', 'u', 'p', 'i', 't', 'e', 'r', '\n',
        'j', 'u', 'r', 'a', 's', 's', 'i', 'c', '\n',
        'j', 'u', 'r', 'i', 'd', 'i', 'c', '\n',
        'j', 'u', 'r', 'i', 'd', 'i', 'c', 'a', 'l', '\n',
        'j', 'u', 'r', 'i', 'e', 's', '\n',
        'j', 'u', 'r', 'i', 's', 'd', 'i', 'c', 't', 'i', 'o', 'n', '\n',
        'j', 'u', 'r', 'i', 's', 'd', 'i', 'c', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'j', 'u', 'r', 'i', 's', 'd', 'i', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'j', 'u', 'r', 'i', 's', 'p', 'r', 'u', 'd', 'e', 'n', 'c', 'e', '\n',
        'j', 'u', 'r', 'i', 's', 'p', 'r', 'u', 'd', 'e', 'n', 't', 'i', 'a', 'l', '\n',
        'j', 'u', 'r', 'i', 's', 't', '\n',
        'j', 'u', 'r', 'i', 's', 't', 'i', 'c', '\n',
        'j', 'u', 'r', 'i', 's', 't', 's', '\n',
        'j', 'u', 'r', 'o', 'r', '\n',
        'j', 'u', 'r', 'o', 'r', 's', '\n',
        'j', 'u', 'r', 'y', '\n',
        'j', 'u', 'r', 'y', 'm', 'a', 'n', '\n',
        'j', 'u', 'r', 'y', 'm', 'e', 'n', '\n',
        'j', 'u', 's', 's', 'i', 'v', 'e', '\n',
        'j', 'u', 's', 't', '\n',
        'j', 'u', 's', 't', 'i', 'c', 'e', '\n',
        'j', 'u', 's', 't', 'i', 'c', 'e', 's', '\n',
        'j', 'u', 's', 't', 'i', 'f', 'i', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'j', 'u', 's', 't', 'i', 'f', 'i', 'a', 'b', 'l', 'e', '\n',
        'j', 'u', 's', 't', 'i', 'f', 'i', 'a', 'b', 'l', 'y', '\n',
        'j', 'u', 's', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'j', 'u', 's', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'j', 'u', 's', 't', 'i', 'f', 'i', 'c', 'a', 't', 'o', 'r', 'y', '\n',
        'j', 'u', 's', 't', 'i', 'f', 'i', 'e', 'd', '\n',
        'j', 'u', 's', 't', 'i', 'f', 'i', 'e', 's', '\n',
        'j', 'u', 's', 't', 'i', 'f', 'y', '\n',
        'j', 'u', 's', 't', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'j', 'u', 's', 't', 'l', 'y', '\n',
        'j', 'u', 's', 't', 'n', 'e', 's', 's', '\n',
        'j', 'u', 't', '\n',
        'j', 'u', 't', 'e', '\n',
        'j', 'u', 't', 's', '\n',
        'j', 'u', 't', 't', 'e', 'd', '\n',
        'j', 'u', 't', 't', 'i', 'n', 'g', '\n',
        'j', 'u', 'v', 'e', 'n', 'i', 'l', 'e', '\n',
        'j', 'u', 'v', 'e', 'n', 'i', 'l', 'e', 's', '\n',
        'j', 'u', 'x', 't', 'a', 'p', 'o', 's', 'e', '\n',
        'j', 'u', 'x', 't', 'a', 'p', 'o', 's', 'e', 'd', '\n',
        'j', 'u', 'x', 't', 'a', 'p', 'o', 's', 'e', 's', '\n',
        'j', 'u', 'x', 't', 'a', 'p', 'o', 's', 'i', 'n', 'g', '\n',
        'j', 'u', 'x', 't', 'a', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', '\n',
        'j', 'u', 'x', 't', 'a', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'k', 'a', 'f', 't', 'a', 'n', '\n',
        'k', 'a', 'f', 't', 'a', 'n', 's', '\n',
        'k', 'a', 'i', 's', 'e', 'r', '\n',
        'k', 'a', 'l', 'a', 'h', 'a', 'r', 'i', '\n',
        'k', 'a', 'l', 'e', '\n',
        'k', 'a', 'l', 'e', 'i', 'd', 'o', 's', 'c', 'o', 'p', 'e', '\n',
        'k', 'a', 'l', 'e', 'i', 'd', 'o', 's', 'c', 'o', 'p', 'i', 'c', '\n',
        'k', 'a', 'l', 'i', 'f', '\n',
        'k', 'a', 'm', 'i', 'k', 'a', 'z', 'e', '\n',
        'k', 'a', 'm', 'p', 'a', 'l', 'a', '\n',
        'k', 'a', 'm', 'p', 'o', 'n', 'g', '\n',
        'k', 'a', 'n', 'g', 'a', 'r', 'o', 'o', '\n',
        'k', 'a', 'n', 'g', 'a', 'r', 'o', 'o', 's', '\n',
        'k', 'a', 'o', 'l', 'i', 'n', '\n',
        'k', 'a', 'r', 'a', 'k', 'u', 'l', '\n',
        'k', 'a', 'r', 'a', 'o', 'k', 'e', '\n',
        'k', 'a', 'r', 'a', 't', 'e', '\n',
        'k', 'a', 'r', 'm', 'a', '\n',
        'k', 'a', 'r', 's', 't', '\n',
        'k', 'a', 't', 'y', 'd', 'i', 'd', '\n',
        'k', 'a', 'y', 'a', 'k', '\n',
        'k', 'a', 'y', 'a', 'k', 's', '\n',
        'k', 'e', 'b', 'a', 'b', '\n',
        'k', 'e', 'b', 'a', 'b', 's', '\n',
        'k', 'e', 'd', 'g', 'e', 'r', 'e', 'e', '\n',
        'k', 'e', 'e', 'l', '\n',
        'k', 'e', 'e', 'l', 'e', 'd', '\n',
        'k', 'e', 'e', 'l', 'h', 'a', 'u', 'l', '\n',
        'k', 'e', 'e', 'l', 'i', 'n', 'g', '\n',
        'k', 'e', 'e', 'l', 's', '\n',
        'k', 'e', 'e', 'n', '\n',
        'k', 'e', 'e', 'n', 'e', 'r', '\n',
        'k', 'e', 'e', 'n', 'e', 's', 't', '\n',
        'k', 'e', 'e', 'n', 'i', 'n', 'g', '\n',
        'k', 'e', 'e', 'n', 'l', 'y', '\n',
        'k', 'e', 'e', 'n', 'n', 'e', 's', 's', '\n',
        'k', 'e', 'e', 'p', '\n',
        'k', 'e', 'e', 'p', 'e', 'r', '\n',
        'k', 'e', 'e', 'p', 'e', 'r', 's', '\n',
        'k', 'e', 'e', 'p', 'i', 'n', 'g', '\n',
        'k', 'e', 'e', 'p', 's', '\n',
        'k', 'e', 'e', 'p', 's', 'a', 'k', 'e', '\n',
        'k', 'e', 'e', 'p', 's', 'a', 'k', 'e', 's', '\n',
        'k', 'e', 'g', '\n',
        'k', 'e', 'g', 's', '\n',
        'k', 'e', 'l', 'p', '\n',
        'k', 'e', 'l', 'p', 'e', 'r', 's', '\n',
        'k', 'e', 'l', 't', '\n',
        'k', 'e', 'l', 't', 's', '\n',
        'k', 'e', 'l', 'v', 'i', 'n', '\n',
        'k', 'e', 'n', '\n',
        'k', 'e', 'n', 'n', 'e', 'd', 'y', '\n',
        'k', 'e', 'n', 'n', 'e', 'l', '\n',
        'k', 'e', 'n', 'n', 'e', 'l', 'l', 'e', 'd', '\n',
        'k', 'e', 'n', 'n', 'e', 'l', 's', '\n',
        'k', 'e', 'n', 't', '\n',
        'k', 'e', 'n', 't', 'u', 'c', 'k', 'y', '\n',
        'k', 'e', 'n', 'y', 'a', '\n',
        'k', 'e', 'n', 'y', 'a', 'n', '\n',
        'k', 'e', 'p', 't', '\n',
        'k', 'e', 'r', 'a', 't', 'i', 'n', '\n',
        'k', 'e', 'r', 'b', '\n',
        'k', 'e', 'r', 'b', 's', '\n',
        'k', 'e', 'r', 'b', 's', 'i', 'd', 'e', '\n',
        'k', 'e', 'r', 'c', 'h', 'i', 'e', 'f', '\n',
        'k', 'e', 'r', 'n', 'e', 'd', '\n',
        'k', 'e', 'r', 'n', 'e', 'l', '\n',
        'k', 'e', 'r', 'n', 'e', 'l', 's', '\n',
        'k', 'e', 'r', 'n', 'i', 'n', 'g', '\n',
        'k', 'e', 'r', 'o', 's', 'e', 'n', 'e', '\n',
        'k', 'e', 's', 't', 'r', 'e', 'l', '\n',
        'k', 'e', 's', 't', 'r', 'e', 'l', 's', '\n',
        'k', 'e', 't', 'c', 'h', '\n',
        'k', 'e', 't', 'c', 'h', 'u', 'p', '\n',
        'k', 'e', 't', 't', 'l', 'e', '\n',
        'k', 'e', 't', 't', 'l', 'e', 'f', 'u', 'l', '\n',
        'k', 'e', 't', 't', 'l', 'e', 's', '\n',
        'k', 'e', 'y', '\n',
        'k', 'e', 'y', 'b', 'o', 'a', 'r', 'd', '\n',
        'k', 'e', 'y', 'b', 'o', 'a', 'r', 'd', 'i', 's', 't', '\n',
        'k', 'e', 'y', 'b', 'o', 'a', 'r', 'd', 's', '\n',
        'k', 'e', 'y', 'e', 'd', '\n',
        'k', 'e', 'y', 'h', 'o', 'l', 'e', '\n',
        'k', 'e', 'y', 'h', 'o', 'l', 'e', 's', '\n',
        'k', 'e', 'y', 'i', 'n', 'g', '\n',
        'k', 'e', 'y', 'n', 'o', 't', 'e', '\n',
        'k', 'e', 'y', 'n', 'o', 't', 'e', 's', '\n',
        'k', 'e', 'y', 'p', 'a', 'd', '\n',
        'k', 'e', 'y', 'p', 'a', 'd', 's', '\n',
        'k', 'e', 'y', 'r', 'i', 'n', 'g', '\n',
        'k', 'e', 'y', 's', '\n',
        'k', 'e', 'y', 's', 't', 'o', 'n', 'e', '\n',
        'k', 'e', 'y', 's', 't', 'o', 'n', 'e', 's', '\n',
        'k', 'e', 'y', 's', 't', 'r', 'o', 'k', 'e', '\n',
        'k', 'e', 'y', 's', 't', 'r', 'o', 'k', 'e', 's', '\n',
        'k', 'e', 'y', 'w', 'o', 'r', 'd', '\n',
        'k', 'e', 'y', 'w', 'o', 'r', 'd', 's', '\n',
        'k', 'h', 'a', 'k', 'i', '\n',
        'k', 'h', 'a', 'l', 'i', 'f', '\n',
        'k', 'h', 'a', 'n', '\n',
        'k', 'h', 'a', 'n', 's', '\n',
        'k', 'h', 'o', 'i', 'k', 'h', 'o', 'i', '\n',
        'k', 'h', 'o', 'i', 's', 'a', 'n', '\n',
        'k', 'i', 'b', 'b', 'u', 't', 'z', '\n',
        'k', 'i', 'c', 'k', '\n',
        'k', 'i', 'c', 'k', 'b', 'a', 'c', 'k', '\n',
        'k', 'i', 'c', 'k', 'e', 'd', '\n',
        'k', 'i', 'c', 'k', 'e', 'r', '\n',
        'k', 'i', 'c', 'k', 'i', 'n', 'g', '\n',
        'k', 'i', 'c', 'k', 's', '\n',
        'k', 'i', 'c', 'k', 's', 't', 'a', 'r', 't', '\n',
        'k', 'i', 'c', 'k', 's', 't', 'a', 'r', 't', 'e', 'd', '\n',
        'k', 'i', 'c', 'k', 's', 't', 'a', 'r', 't', 'i', 'n', 'g', '\n',
        'k', 'i', 'c', 'k', 's', 't', 'a', 'r', 't', 's', '\n',
        'k', 'i', 'd', '\n',
        'k', 'i', 'd', 'd', 'e', 'd', '\n',
        'k', 'i', 'd', 'd', 'i', 'e', '\n',
        'k', 'i', 'd', 'd', 'i', 'n', 'g', '\n',
        'k', 'i', 'd', 'n', 'a', 'p', '\n',
        'k', 'i', 'd', 'n', 'a', 'p', 'p', 'e', 'd', '\n',
        'k', 'i', 'd', 'n', 'a', 'p', 'p', 'e', 'r', '\n',
        'k', 'i', 'd', 'n', 'a', 'p', 'p', 'e', 'r', 's', '\n',
        'k', 'i', 'd', 'n', 'a', 'p', 'p', 'i', 'n', 'g', '\n',
        'k', 'i', 'd', 'n', 'a', 'p', 'p', 'i', 'n', 'g', 's', '\n',
        'k', 'i', 'd', 'n', 'a', 'p', 's', '\n',
        'k', 'i', 'd', 'n', 'e', 'y', '\n',
        'k', 'i', 'd', 'n', 'e', 'y', 's', '\n',
        'k', 'i', 'd', 'n', 'e', 'y', 's', 'h', 'a', 'p', 'e', 'd', '\n',
        'k', 'i', 'd', 's', '\n',
        'k', 'i', 'e', 'v', '\n',
        'k', 'i', 'l', 'l', '\n',
        'k', 'i', 'l', 'l', 'e', 'd', '\n',
        'k', 'i', 'l', 'l', 'e', 'r', '\n',
        'k', 'i', 'l', 'l', 'e', 'r', 's', '\n',
        'k', 'i', 'l', 'l', 'i', 'n', 'g', '\n',
        'k', 'i', 'l', 'l', 'i', 'n', 'g', 's', '\n',
        'k', 'i', 'l', 'l', 'j', 'o', 'y', '\n',
        'k', 'i', 'l', 'l', 'j', 'o', 'y', 's', '\n',
        'k', 'i', 'l', 'l', 's', '\n',
        'k', 'i', 'l', 'n', '\n',
        'k', 'i', 'l', 'n', 's', '\n',
        'k', 'i', 'l', 'o', '\n',
        'k', 'i', 'l', 'o', 'b', 'i', 't', 's', '\n',
        'k', 'i', 'l', 'o', 'b', 'y', 't', 'e', '\n',
        'k', 'i', 'l', 'o', 'b', 'y', 't', 'e', 's', '\n',
        'k', 'i', 'l', 'o', 'h', 'e', 'r', 't', 'z', '\n',
        'k', 'i', 'l', 'o', 'j', 'o', 'u', 'l', 'e', 's', '\n',
        'k', 'i', 'l', 'o', 'm', 'e', 't', 'r', 'e', '\n',
        'k', 'i', 'l', 'o', 'm', 'e', 't', 'r', 'e', 's', '\n',
        'k', 'i', 'l', 'o', 't', 'o', 'n', '\n',
        'k', 'i', 'l', 'o', 't', 'o', 'n', 's', '\n',
        'k', 'i', 'l', 'o', 'v', 'o', 'l', 't', '\n',
        'k', 'i', 'l', 'o', 'w', 'a', 't', 't', '\n',
        'k', 'i', 'l', 'o', 'w', 'a', 't', 't', 's', '\n',
        'k', 'i', 'l', 't', '\n',
        'k', 'i', 'l', 't', 'e', 'd', '\n',
        'k', 'i', 'l', 't', 'e', 'r', '\n',
        'k', 'i', 'l', 't', 's', '\n',
        'k', 'i', 'm', 'o', 'n', 'o', '\n',
        'k', 'i', 'n', '\n',
        'k', 'i', 'n', 'a', '\n',
        'k', 'i', 'n', 'a', 's', 'e', '\n',
        'k', 'i', 'n', 'd', '\n',
        'k', 'i', 'n', 'd', 'e', 'r', '\n',
        'k', 'i', 'n', 'd', 'e', 'r', 'g', 'a', 'r', 't', 'e', 'n', '\n',
        'k', 'i', 'n', 'd', 'e', 'r', 'g', 'a', 'r', 't', 'e', 'n', 's', '\n',
        'k', 'i', 'n', 'd', 'e', 's', 't', '\n',
        'k', 'i', 'n', 'd', 'h', 'e', 'a', 'r', 't', 'e', 'd', '\n',
        'k', 'i', 'n', 'd', 'h', 'e', 'a', 'r', 't', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'k', 'i', 'n', 'd', 'l', 'e', '\n',
        'k', 'i', 'n', 'd', 'l', 'e', 'd', '\n',
        'k', 'i', 'n', 'd', 'l', 'e', 's', '\n',
        'k', 'i', 'n', 'd', 'l', 'i', 'e', 'r', '\n',
        'k', 'i', 'n', 'd', 'l', 'i', 'e', 's', 't', '\n',
        'k', 'i', 'n', 'd', 'l', 'i', 'n', 'e', 's', 's', '\n',
        'k', 'i', 'n', 'd', 'l', 'i', 'n', 'g', '\n',
        'k', 'i', 'n', 'd', 'l', 'y', '\n',
        'k', 'i', 'n', 'd', 'n', 'e', 's', 's', '\n',
        'k', 'i', 'n', 'd', 'n', 'e', 's', 's', 'e', 's', '\n',
        'k', 'i', 'n', 'd', 'r', 'e', 'd', '\n',
        'k', 'i', 'n', 'd', 's', '\n',
        'k', 'i', 'n', 'e', 'm', 'a', 't', 'i', 'c', '\n',
        'k', 'i', 'n', 'e', 'm', 'a', 't', 'i', 'c', 's', '\n',
        'k', 'i', 'n', 'e', 't', 'i', 'c', '\n',
        'k', 'i', 'n', 'e', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'k', 'i', 'n', 'e', 't', 'i', 'c', 's', '\n',
        'k', 'i', 'n', 'f', 'o', 'l', 'k', '\n',
        'k', 'i', 'n', 'g', '\n',
        'k', 'i', 'n', 'g', 'd', 'o', 'm', '\n',
        'k', 'i', 'n', 'g', 'd', 'o', 'm', 's', '\n',
        'k', 'i', 'n', 'g', 'f', 'i', 's', 'h', 'e', 'r', '\n',
        'k', 'i', 'n', 'g', 'f', 'i', 's', 'h', 'e', 'r', 's', '\n',
        'k', 'i', 'n', 'g', 'l', 'y', '\n',
        'k', 'i', 'n', 'g', 'p', 'i', 'n', '\n',
        'k', 'i', 'n', 'g', 's', '\n',
        'k', 'i', 'n', 'g', 's', 'h', 'i', 'p', '\n',
        'k', 'i', 'n', 'g', 's', 'i', 'z', 'e', '\n',
        'k', 'i', 'n', 'g', 's', 'i', 'z', 'e', 'd', '\n',
        'k', 'i', 'n', 'k', '\n',
        'k', 'i', 'n', 'k', 'e', 'd', '\n',
        'k', 'i', 'n', 'k', 's', '\n',
        'k', 'i', 'n', 'k', 'y', '\n',
        'k', 'i', 'n', 's', 'f', 'o', 'l', 'k', '\n',
        'k', 'i', 'n', 's', 'h', 'a', 's', 'a', '\n',
        'k', 'i', 'n', 's', 'h', 'i', 'p', '\n',
        'k', 'i', 'n', 's', 'm', 'a', 'n', '\n',
        'k', 'i', 'n', 's', 'm', 'e', 'n', '\n',
        'k', 'i', 'n', 's', 'w', 'o', 'm', 'a', 'n', '\n',
        'k', 'i', 'o', 's', 'k', '\n',
        'k', 'i', 'o', 's', 'k', 's', '\n',
        'k', 'i', 'p', 'p', 'e', 'r', '\n',
        'k', 'i', 'p', 'p', 'e', 'r', 's', '\n',
        'k', 'i', 'r', 'k', '\n',
        'k', 'i', 's', 'm', 'e', 't', '\n',
        'k', 'i', 's', 's', '\n',
        'k', 'i', 's', 's', 'e', 'd', '\n',
        'k', 'i', 's', 's', 'e', 'r', '\n',
        'k', 'i', 's', 's', 'e', 's', '\n',
        'k', 'i', 's', 's', 'i', 'n', 'g', '\n',
        'k', 'i', 't', '\n',
        'k', 'i', 't', 'b', 'a', 'g', '\n',
        'k', 'i', 't', 'b', 'a', 'g', 's', '\n',
        'k', 'i', 't', 'c', 'h', 'e', 'n', '\n',
        'k', 'i', 't', 'c', 'h', 'e', 'n', 'e', 't', 't', 'e', '\n',
        'k', 'i', 't', 'c', 'h', 'e', 'n', 's', '\n',
        'k', 'i', 't', 'c', 'h', 'e', 'n', 'w', 'a', 'r', 'e', '\n',
        'k', 'i', 't', 'e', '\n',
        'k', 'i', 't', 'e', 's', '\n',
        'k', 'i', 't', 'h', '\n',
        'k', 'i', 't', 's', '\n',
        'k', 'i', 't', 's', 'c', 'h', '\n',
        'k', 'i', 't', 't', 'e', 'd', '\n',
        'k', 'i', 't', 't', 'e', 'n', '\n',
        'k', 'i', 't', 't', 'e', 'n', 'i', 's', 'h', '\n',
        'k', 'i', 't', 't', 'e', 'n', 's', '\n',
        'k', 'i', 't', 't', 'i', 'n', 'g', '\n',
        'k', 'i', 't', 't', 'i', 'w', 'a', 'k', 'e', 's', '\n',
        'k', 'i', 't', 't', 'y', '\n',
        'k', 'i', 'w', 'i', '\n',
        'k', 'i', 'w', 'i', 's', '\n',
        'k', 'l', 'a', 'x', 'o', 'n', '\n',
        'k', 'l', 'a', 'x', 'o', 'n', 's', '\n',
        'k', 'l', 'e', 'p', 't', 'o', 'm', 'a', 'n', 'i', 'a', '\n',
        'k', 'l', 'e', 'p', 't', 'o', 'm', 'a', 'n', 'i', 'a', 'c', '\n',
        'k', 'l', 'e', 'p', 't', 'o', 'm', 'a', 'n', 'i', 'a', 'c', 's', '\n',
        'k', 'l', 'i', 'c', 'k', '\n',
        'k', 'l', 'o', 'o', 'f', '\n',
        'k', 'n', 'a', 'c', 'k', '\n',
        'k', 'n', 'a', 'c', 'k', 'e', 'r', '\n',
        'k', 'n', 'a', 'c', 'k', 'e', 'r', 's', '\n',
        'k', 'n', 'a', 'c', 'k', 's', '\n',
        'k', 'n', 'a', 'p', 's', 'a', 'c', 'k', '\n',
        'k', 'n', 'a', 'p', 's', 'a', 'c', 'k', 's', '\n',
        'k', 'n', 'a', 'v', 'e', '\n',
        'k', 'n', 'a', 'v', 'e', 'r', 'y', '\n',
        'k', 'n', 'a', 'v', 'e', 's', '\n',
        'k', 'n', 'a', 'v', 'i', 's', 'h', '\n',
        'k', 'n', 'e', 'a', 'd', '\n',
        'k', 'n', 'e', 'a', 'd', 'e', 'd', '\n',
        'k', 'n', 'e', 'a', 'd', 'i', 'n', 'g', '\n',
        'k', 'n', 'e', 'a', 'd', 's', '\n',
        'k', 'n', 'e', 'e', '\n',
        'k', 'n', 'e', 'e', 'c', 'a', 'p', '\n',
        'k', 'n', 'e', 'e', 'c', 'a', 'p', 's', '\n',
        'k', 'n', 'e', 'e', 'd', '\n',
        'k', 'n', 'e', 'e', 'd', 'e', 'e', 'p', '\n',
        'k', 'n', 'e', 'e', 'l', '\n',
        'k', 'n', 'e', 'e', 'l', 'e', 'd', '\n',
        'k', 'n', 'e', 'e', 'l', 'e', 'r', '\n',
        'k', 'n', 'e', 'e', 'l', 'i', 'n', 'g', '\n',
        'k', 'n', 'e', 'e', 'l', 's', '\n',
        'k', 'n', 'e', 'e', 's', '\n',
        'k', 'n', 'e', 'l', 'l', '\n',
        'k', 'n', 'e', 'l', 't', '\n',
        'k', 'n', 'e', 's', 's', 'e', 't', '\n',
        'k', 'n', 'e', 'w', '\n',
        'k', 'n', 'i', 'c', 'k', 'e', 'r', 's', '\n',
        'k', 'n', 'i', 'f', 'e', '\n',
        'k', 'n', 'i', 'f', 'e', 'd', '\n',
        'k', 'n', 'i', 'f', 'e', 'p', 'o', 'i', 'n', 't', '\n',
        'k', 'n', 'i', 'f', 'e', 's', '\n',
        'k', 'n', 'i', 'f', 'i', 'n', 'g', '\n',
        'k', 'n', 'i', 'g', 'h', 't', '\n',
        'k', 'n', 'i', 'g', 'h', 't', 'e', 'd', '\n',
        'k', 'n', 'i', 'g', 'h', 't', 'h', 'o', 'o', 'd', '\n',
        'k', 'n', 'i', 'g', 'h', 't', 'h', 'o', 'o', 'd', 's', '\n',
        'k', 'n', 'i', 'g', 'h', 't', 'l', 'y', '\n',
        'k', 'n', 'i', 'g', 'h', 't', 's', '\n',
        'k', 'n', 'i', 't', '\n',
        'k', 'n', 'i', 't', 's', '\n',
        'k', 'n', 'i', 't', 't', 'e', 'd', '\n',
        'k', 'n', 'i', 't', 't', 'e', 'r', '\n',
        'k', 'n', 'i', 't', 't', 'e', 'r', 's', '\n',
        'k', 'n', 'i', 't', 't', 'i', 'n', 'g', '\n',
        'k', 'n', 'i', 't', 'w', 'e', 'a', 'r', '\n',
        'k', 'n', 'i', 'v', 'e', 's', '\n',
        'k', 'n', 'o', 'b', '\n',
        'k', 'n', 'o', 'b', 'b', 'l', 'y', '\n',
        'k', 'n', 'o', 'b', 's', '\n',
        'k', 'n', 'o', 'c', 'k', '\n',
        'k', 'n', 'o', 'c', 'k', 'e', 'd', '\n',
        'k', 'n', 'o', 'c', 'k', 'e', 'r', '\n',
        'k', 'n', 'o', 'c', 'k', 'e', 'r', 's', '\n',
        'k', 'n', 'o', 'c', 'k', 'i', 'n', 'g', '\n',
        'k', 'n', 'o', 'c', 'k', 'i', 'n', 'g', 's', '\n',
        'k', 'n', 'o', 'c', 'k', 'o', 'u', 't', '\n',
        'k', 'n', 'o', 'c', 'k', 's', '\n',
        'k', 'n', 'o', 'l', 'l', '\n',
        'k', 'n', 'o', 'l', 'l', 's', '\n',
        'k', 'n', 'o', 't', '\n',
        'k', 'n', 'o', 't', 's', '\n',
        'k', 'n', 'o', 't', 't', 'e', 'd', '\n',
        'k', 'n', 'o', 't', 't', 'i', 'e', 'r', '\n',
        'k', 'n', 'o', 't', 't', 'i', 'e', 's', 't', '\n',
        'k', 'n', 'o', 't', 't', 'i', 'n', 'g', '\n',
        'k', 'n', 'o', 't', 't', 'y', '\n',
        'k', 'n', 'o', 'w', '\n',
        'k', 'n', 'o', 'w', 'a', 'b', 'l', 'e', '\n',
        'k', 'n', 'o', 'w', 'h', 'o', 'w', '\n',
        'k', 'n', 'o', 'w', 'i', 'n', 'g', '\n',
        'k', 'n', 'o', 'w', 'i', 'n', 'g', 'l', 'y', '\n',
        'k', 'n', 'o', 'w', 'l', 'e', 'd', 'g', 'e', '\n',
        'k', 'n', 'o', 'w', 'l', 'e', 'd', 'g', 'e', 'a', 'b', 'l', 'e', '\n',
        'k', 'n', 'o', 'w', 'l', 'e', 'd', 'g', 'e', 'a', 'b', 'l', 'y', '\n',
        'k', 'n', 'o', 'w', 'n', '\n',
        'k', 'n', 'o', 'w', 's', '\n',
        'k', 'n', 'u', 'c', 'k', 'l', 'e', '\n',
        'k', 'n', 'u', 'c', 'k', 'l', 'e', 'd', '\n',
        'k', 'n', 'u', 'c', 'k', 'l', 'e', 'd', 'u', 's', 't', 'e', 'r', '\n',
        'k', 'n', 'u', 'c', 'k', 'l', 'e', 'd', 'u', 's', 't', 'e', 'r', 's', '\n',
        'k', 'n', 'u', 'c', 'k', 'l', 'e', 's', '\n',
        'k', 'n', 'u', 'c', 'k', 'l', 'i', 'n', 'g', '\n',
        'k', 'o', 'a', 'l', 'a', '\n',
        'k', 'o', 'a', 'l', 'a', 's', '\n',
        'k', 'o', 'n', 'g', 'o', '\n',
        'k', 'o', 'o', 'k', 'a', 'b', 'u', 'r', 'r', 'a', '\n',
        'k', 'o', 'r', 'a', 'n', '\n',
        'k', 'o', 'r', 'e', 'a', '\n',
        'k', 'o', 'r', 'e', 'a', 'n', '\n',
        'k', 'o', 'r', 'e', 'a', 'n', 's', '\n',
        'k', 'o', 's', 'h', 'e', 'r', '\n',
        'k', 'r', 'a', 'a', 'l', '\n',
        'k', 'r', 'a', 'a', 'l', 's', '\n',
        'k', 'r', 'a', 'f', 't', '\n',
        'k', 'r', 'e', 'm', 'l', 'i', 'n', '\n',
        'k', 'r', 'i', 'e', 'g', 's', 'p', 'i', 'e', 'l', '\n',
        'k', 'r', 'i', 'l', 'l', '\n',
        'k', 'r', 'y', 'p', 't', 'o', 'n', '\n',
        'k', 'u', 'd', 'u', '\n',
        'k', 'u', 'd', 'u', 's', '\n',
        'k', 'u', 'n', 'g', 'f', 'u', '\n',
        'k', 'u', 'w', 'a', 'i', 't', '\n',
        'k', 'w', 'a', 'c', 'h', 'a', '\n',
        'k', 'w', 'a', 'c', 'h', 'a', 's', '\n',
        'l', 'a', 'a', 'g', 'e', 'r', '\n',
        'l', 'a', 'b', '\n',
        'l', 'a', 'b', 'e', 'l', '\n',
        'l', 'a', 'b', 'e', 'l', 'l', 'e', 'd', '\n',
        'l', 'a', 'b', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'l', 'a', 'b', 'e', 'l', 'l', 'i', 'n', 'g', 's', '\n',
        'l', 'a', 'b', 'e', 'l', 's', '\n',
        'l', 'a', 'b', 'i', 'a', '\n',
        'l', 'a', 'b', 'i', 'a', 'l', '\n',
        'l', 'a', 'b', 'i', 'a', 'l', 's', '\n',
        'l', 'a', 'b', 'i', 'l', 'e', '\n',
        'l', 'a', 'b', 'i', 'u', 'm', '\n',
        'l', 'a', 'b', 'o', 'r', 'a', 't', 'o', 'r', 'i', 'e', 's', '\n',
        'l', 'a', 'b', 'o', 'r', 'a', 't', 'o', 'r', 'y', '\n',
        'l', 'a', 'b', 'o', 'r', 'i', 'o', 'u', 's', '\n',
        'l', 'a', 'b', 'o', 'r', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'l', 'a', 'b', 'o', 'r', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'l', 'a', 'b', 'o', 'u', 'r', '\n',
        'l', 'a', 'b', 'o', 'u', 'r', 'e', 'd', '\n',
        'l', 'a', 'b', 'o', 'u', 'r', 'e', 'r', '\n',
        'l', 'a', 'b', 'o', 'u', 'r', 'e', 'r', 's', '\n',
        'l', 'a', 'b', 'o', 'u', 'r', 'i', 'n', 'g', '\n',
        'l', 'a', 'b', 'o', 'u', 'r', 'i', 'n', 't', 'e', 'n', 's', 'i', 'v', 'e', '\n',
        'l', 'a', 'b', 'o', 'u', 'r', 's', '\n',
        'l', 'a', 'b', 'o', 'u', 'r', 's', 'a', 'v', 'i', 'n', 'g', '\n',
        'l', 'a', 'b', 's', '\n',
        'l', 'a', 'b', 'u', 'r', 'n', 'u', 'm', '\n',
        'l', 'a', 'b', 'y', 'r', 'i', 'n', 't', 'h', '\n',
        'l', 'a', 'b', 'y', 'r', 'i', 'n', 't', 'h', 'i', 'n', 'e', '\n',
        'l', 'a', 'b', 'y', 'r', 'i', 'n', 't', 'h', 's', '\n',
        'l', 'a', 'c', 'e', '\n',
        'l', 'a', 'c', 'e', 'd', '\n',
        'l', 'a', 'c', 'e', 'r', 'a', 't', 'e', '\n',
        'l', 'a', 'c', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'l', 'a', 'c', 'e', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'l', 'a', 'c', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'l', 'a', 'c', 'e', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'l', 'a', 'c', 'e', 's', '\n',
        'l', 'a', 'c', 'e', 'w', 'o', 'r', 'k', '\n',
        'l', 'a', 'c', 'h', 'e', 's', '\n',
        'l', 'a', 'c', 'h', 'r', 'y', 'm', 'a', 'l', '\n',
        'l', 'a', 'c', 'h', 'r', 'y', 'm', 'o', 's', 'e', '\n',
        'l', 'a', 'c', 'i', 'e', 'r', '\n',
        'l', 'a', 'c', 'i', 'n', 'g', '\n',
        'l', 'a', 'c', 'i', 'n', 'g', 's', '\n',
        'l', 'a', 'c', 'k', '\n',
        'l', 'a', 'c', 'k', 'a', 'd', 'a', 'i', 's', 'i', 'c', 'a', 'l', '\n',
        'l', 'a', 'c', 'k', 'e', 'd', '\n',
        'l', 'a', 'c', 'k', 'e', 'y', '\n',
        'l', 'a', 'c', 'k', 'e', 'y', 's', '\n',
        'l', 'a', 'c', 'k', 'i', 'n', 'g', '\n',
        'l', 'a', 'c', 'k', 'l', 'u', 's', 't', 'r', 'e', '\n',
        'l', 'a', 'c', 'k', 's', '\n',
        'l', 'a', 'c', 'o', 'n', 'i', 'c', '\n',
        'l', 'a', 'c', 'o', 'n', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'l', 'a', 'c', 'q', 'u', 'e', 'r', '\n',
        'l', 'a', 'c', 'q', 'u', 'e', 'r', 'e', 'd', '\n',
        'l', 'a', 'c', 'q', 'u', 'e', 'r', 's', '\n',
        'l', 'a', 'c', 'r', 'o', 's', 's', 'e', '\n',
        'l', 'a', 'c', 's', '\n',
        'l', 'a', 'c', 't', 'a', 't', 'e', '\n',
        'l', 'a', 'c', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'l', 'a', 'c', 't', 'e', 'a', 'l', '\n',
        'l', 'a', 'c', 't', 'i', 'c', '\n',
        'l', 'a', 'c', 't', 'o', 's', 'e', '\n',
        'l', 'a', 'c', 'u', 'n', 'a', '\n',
        'l', 'a', 'c', 'u', 'n', 'a', 'e', '\n',
        'l', 'a', 'c', 'u', 'n', 'a', 's', '\n',
        'l', 'a', 'c', 'y', '\n',
        'l', 'a', 'd', '\n',
        'l', 'a', 'd', 'd', 'e', 'r', '\n',
        'l', 'a', 'd', 'd', 'e', 'r', 'e', 'd', '\n',
        'l', 'a', 'd', 'd', 'e', 'r', 's', '\n',
        'l', 'a', 'd', 'd', 'i', 'e', '\n',
        'l', 'a', 'd', 'd', 'i', 'e', 's', '\n',
        'l', 'a', 'd', 'e', '\n',
        'l', 'a', 'd', 'e', 'n', '\n',
        'l', 'a', 'd', 'i', 'e', 's', '\n',
        'l', 'a', 'd', 'i', 'n', 'g', '\n',
        'l', 'a', 'd', 'l', 'e', '\n',
        'l', 'a', 'd', 'l', 'e', 'd', '\n',
        'l', 'a', 'd', 'l', 'e', 's', '\n',
        'l', 'a', 'd', 'l', 'i', 'n', 'g', '\n',
        'l', 'a', 'd', 's', '\n',
        'l', 'a', 'd', 'y', '\n',
        'l', 'a', 'd', 'y', 'b', 'i', 'r', 'd', '\n',
        'l', 'a', 'd', 'y', 'b', 'i', 'r', 'd', 's', '\n',
        'l', 'a', 'd', 'y', 'b', 'u', 'g', '\n',
        'l', 'a', 'd', 'y', 'l', 'i', 'k', 'e', '\n',
        'l', 'a', 'd', 'y', 's', 'h', 'i', 'p', '\n',
        'l', 'a', 'd', 'y', 's', 'h', 'i', 'p', 's', '\n',
        'l', 'a', 'g', '\n',
        'l', 'a', 'g', 'e', 'r', '\n',
        'l', 'a', 'g', 'e', 'r', 's', '\n',
        'l', 'a', 'g', 'g', 'a', 'r', 'd', '\n',
        'l', 'a', 'g', 'g', 'a', 'r', 'd', 's', '\n',
        'l', 'a', 'g', 'g', 'e', 'd', '\n',
        'l', 'a', 'g', 'g', 'i', 'n', 'g', '\n',
        'l', 'a', 'g', 'o', 'o', 'n', '\n',
        'l', 'a', 'g', 'o', 'o', 'n', 's', '\n',
        'l', 'a', 'g', 'o', 's', '\n',
        'l', 'a', 'g', 's', '\n',
        'l', 'a', 'g', 'u', 'n', 'e', '\n',
        'l', 'a', 'i', 'd', '\n',
        'l', 'a', 'i', 'n', '\n',
        'l', 'a', 'i', 'r', '\n',
        'l', 'a', 'i', 'r', 'd', '\n',
        'l', 'a', 'i', 'r', 'd', 's', '\n',
        'l', 'a', 'i', 'r', 's', '\n',
        'l', 'a', 'i', 's', 's', 'e', 'z', 'f', 'a', 'i', 'r', 'e', '\n',
        'l', 'a', 'i', 't', 'y', '\n',
        'l', 'a', 'k', 'e', '\n',
        'l', 'a', 'k', 'e', 's', '\n',
        'l', 'a', 'k', 'e', 's', 'i', 'd', 'e', '\n',
        'l', 'a', 'm', '\n',
        'l', 'a', 'm', 'a', '\n',
        'l', 'a', 'm', 'a', 's', '\n',
        'l', 'a', 'm', 'b', '\n',
        'l', 'a', 'm', 'b', 'a', 's', 't', 'e', 'd', '\n',
        'l', 'a', 'm', 'b', 'a', 's', 't', 'i', 'n', 'g', '\n',
        'l', 'a', 'm', 'b', 'd', 'a', '\n',
        'l', 'a', 'm', 'b', 'e', 'n', 't', '\n',
        'l', 'a', 'm', 'b', 'i', 'n', 'g', '\n',
        'l', 'a', 'm', 'b', 's', '\n',
        'l', 'a', 'm', 'b', 's', 'k', 'i', 'n', '\n',
        'l', 'a', 'm', 'b', 's', 'w', 'o', 'o', 'l', '\n',
        'l', 'a', 'm', 'e', '\n',
        'l', 'a', 'm', 'e', 'd', '\n',
        'l', 'a', 'm', 'e', 'l', 'y', '\n',
        'l', 'a', 'm', 'e', 'n', 'e', 's', 's', '\n',
        'l', 'a', 'm', 'e', 'n', 't', '\n',
        'l', 'a', 'm', 'e', 'n', 't', 'a', 'b', 'l', 'e', '\n',
        'l', 'a', 'm', 'e', 'n', 't', 'a', 'b', 'l', 'y', '\n',
        'l', 'a', 'm', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'l', 'a', 'm', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'l', 'a', 'm', 'e', 'n', 't', 'e', 'd', '\n',
        'l', 'a', 'm', 'e', 'n', 't', 'e', 'r', '\n',
        'l', 'a', 'm', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'l', 'a', 'm', 'e', 'n', 't', 's', '\n',
        'l', 'a', 'm', 'e', 's', 't', '\n',
        'l', 'a', 'm', 'i', 'n', 'a', '\n',
        'l', 'a', 'm', 'i', 'n', 'a', 'r', '\n',
        'l', 'a', 'm', 'i', 'n', 'a', 't', 'e', '\n',
        'l', 'a', 'm', 'i', 'n', 'a', 't', 'e', 'd', '\n',
        'l', 'a', 'm', 'i', 'n', 'a', 't', 'e', 's', '\n',
        'l', 'a', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'l', 'a', 'm', 'p', '\n',
        'l', 'a', 'm', 'p', 'l', 'i', 'g', 'h', 't', '\n',
        'l', 'a', 'm', 'p', 'l', 'i', 'g', 'h', 't', 'e', 'r', '\n',
        'l', 'a', 'm', 'p', 'l', 'i', 't', '\n',
        'l', 'a', 'm', 'p', 'o', 'o', 'n', '\n',
        'l', 'a', 'm', 'p', 'o', 'o', 'n', 'e', 'd', '\n',
        'l', 'a', 'm', 'p', 'o', 'o', 'n', 'e', 'r', 'y', '\n',
        'l', 'a', 'm', 'p', 'o', 'o', 'n', 'i', 'n', 'g', '\n',
        'l', 'a', 'm', 'p', 'o', 'o', 'n', 's', '\n',
        'l', 'a', 'm', 'p', 'p', 'o', 's', 't', '\n',
        'l', 'a', 'm', 'p', 'p', 'o', 's', 't', 's', '\n',
        'l', 'a', 'm', 'p', 'r', 'e', 'y', '\n',
        'l', 'a', 'm', 'p', 'r', 'e', 'y', 's', '\n',
        'l', 'a', 'm', 'p', 's', '\n',
        'l', 'a', 'm', 'p', 's', 'h', 'a', 'd', 'e', '\n',
        'l', 'a', 'm', 'p', 's', 'h', 'a', 'd', 'e', 's', '\n',
        'l', 'a', 'n', 'c', 'e', '\n',
        'l', 'a', 'n', 'c', 'e', 'd', '\n',
        'l', 'a', 'n', 'c', 'e', 'l', 'o', 't', '\n',
        'l', 'a', 'n', 'c', 'e', 'r', '\n',
        'l', 'a', 'n', 'c', 'e', 'r', 's', '\n',
        'l', 'a', 'n', 'c', 'e', 's', '\n',
        'l', 'a', 'n', 'c', 'e', 't', '\n',
        'l', 'a', 'n', 'c', 'e', 't', 's', '\n',
        'l', 'a', 'n', 'c', 'i', 'n', 'g', '\n',
        'l', 'a', 'n', 'd', '\n',
        'l', 'a', 'n', 'd', 'e', 'd', '\n',
        'l', 'a', 'n', 'd', 'e', 'r', '\n',
        'l', 'a', 'n', 'd', 'f', 'a', 'l', 'l', '\n',
        'l', 'a', 'n', 'd', 'f', 'i', 'l', 'l', '\n',
        'l', 'a', 'n', 'd', 'f', 'o', 'r', 'm', '\n',
        'l', 'a', 'n', 'd', 'f', 'o', 'r', 'm', 's', '\n',
        'l', 'a', 'n', 'd', 'h', 'o', 'l', 'd', 'e', 'r', 's', '\n',
        'l', 'a', 'n', 'd', 'h', 'o', 'l', 'd', 'i', 'n', 'g', '\n',
        'l', 'a', 'n', 'd', 'h', 'o', 'l', 'd', 'i', 'n', 'g', 's', '\n',
        'l', 'a', 'n', 'd', 'i', 'n', 'g', '\n',
        'l', 'a', 'n', 'd', 'i', 'n', 'g', 's', '\n',
        'l', 'a', 'n', 'd', 'l', 'a', 'd', 'i', 'e', 's', '\n',
        'l', 'a', 'n', 'd', 'l', 'a', 'd', 'y', '\n',
        'l', 'a', 'n', 'd', 'l', 'e', 's', 's', '\n',
        'l', 'a', 'n', 'd', 'l', 'i', 'n', 'e', 's', '\n',
        'l', 'a', 'n', 'd', 'l', 'o', 'c', 'k', 'e', 'd', '\n',
        'l', 'a', 'n', 'd', 'l', 'o', 'r', 'd', '\n',
        'l', 'a', 'n', 'd', 'l', 'o', 'r', 'd', 's', '\n',
        'l', 'a', 'n', 'd', 'm', 'a', 'n', '\n',
        'l', 'a', 'n', 'd', 'm', 'a', 'r', 'k', '\n',
        'l', 'a', 'n', 'd', 'm', 'a', 'r', 'k', 's', '\n',
        'l', 'a', 'n', 'd', 'm', 'a', 's', 's', '\n',
        'l', 'a', 'n', 'd', 'm', 'i', 'n', 'e', '\n',
        'l', 'a', 'n', 'd', 'o', 'w', 'n', 'e', 'r', '\n',
        'l', 'a', 'n', 'd', 'o', 'w', 'n', 'e', 'r', 's', '\n',
        'l', 'a', 'n', 'd', 'o', 'w', 'n', 'i', 'n', 'g', '\n',
        'l', 'a', 'n', 'd', 's', '\n',
        'l', 'a', 'n', 'd', 's', 'c', 'a', 'p', 'e', '\n',
        'l', 'a', 'n', 'd', 's', 'c', 'a', 'p', 'e', 'd', '\n',
        'l', 'a', 'n', 'd', 's', 'c', 'a', 'p', 'e', 's', '\n',
        'l', 'a', 'n', 'd', 's', 'c', 'a', 'p', 'i', 'n', 'g', '\n',
        'l', 'a', 'n', 'd', 's', 'i', 'd', 'e', '\n',
        'l', 'a', 'n', 'd', 's', 'l', 'i', 'd', 'e', '\n',
        'l', 'a', 'n', 'd', 's', 'l', 'i', 'd', 'e', 's', '\n',
        'l', 'a', 'n', 'd', 's', 'l', 'i', 'p', '\n',
        'l', 'a', 'n', 'd', 's', 'l', 'i', 'p', 's', '\n',
        'l', 'a', 'n', 'd', 'w', 'a', 'r', 'd', '\n',
        'l', 'a', 'n', 'e', '\n',
        'l', 'a', 'n', 'e', 's', '\n',
        'l', 'a', 'n', 'g', 'u', 'a', 'g', 'e', '\n',
        'l', 'a', 'n', 'g', 'u', 'a', 'g', 'e', 's', '\n',
        'l', 'a', 'n', 'g', 'u', 'i', 'd', '\n',
        'l', 'a', 'n', 'g', 'u', 'i', 'd', 'l', 'y', '\n',
        'l', 'a', 'n', 'g', 'u', 'i', 's', 'h', '\n',
        'l', 'a', 'n', 'g', 'u', 'i', 's', 'h', 'e', 'd', '\n',
        'l', 'a', 'n', 'g', 'u', 'i', 's', 'h', 'e', 's', '\n',
        'l', 'a', 'n', 'g', 'u', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'l', 'a', 'n', 'g', 'u', 'o', 'r', '\n',
        'l', 'a', 'n', 'g', 'u', 'o', 'r', 'o', 'u', 's', '\n',
        'l', 'a', 'n', 'g', 'u', 'o', 'r', 'o', 'u', 's', 'l', 'y', '\n',
        'l', 'a', 'n', 'k', '\n',
        'l', 'a', 'n', 'k', 'i', 'e', 'r', '\n',
        'l', 'a', 'n', 'k', 'i', 'e', 's', 't', '\n',
        'l', 'a', 'n', 'k', 'y', '\n',
        'l', 'a', 'n', 'o', 'l', 'i', 'n', '\n',
        'l', 'a', 'n', 't', 'e', 'r', 'n', '\n',
        'l', 'a', 'n', 't', 'e', 'r', 'n', 's', '\n',
        'l', 'a', 'n', 'y', 'a', 'r', 'd', '\n',
        'l', 'a', 'o', 's', '\n',
        'l', 'a', 'p', '\n',
        'l', 'a', 'p', 'd', 'o', 'g', '\n',
        'l', 'a', 'p', 'd', 'o', 'g', 's', '\n',
        'l', 'a', 'p', 'e', 'l', '\n',
        'l', 'a', 'p', 'e', 'l', 's', '\n',
        'l', 'a', 'p', 'f', 'u', 'l', '\n',
        'l', 'a', 'p', 'i', 'd', 'a', 'r', 'y', '\n',
        'l', 'a', 'p', 'l', 'a', 'n', 'd', '\n',
        'l', 'a', 'p', 'p', '\n',
        'l', 'a', 'p', 'p', 'e', 'd', '\n',
        'l', 'a', 'p', 'p', 'i', 'n', 'g', '\n',
        'l', 'a', 'p', 's', '\n',
        'l', 'a', 'p', 's', 'e', '\n',
        'l', 'a', 'p', 's', 'e', 'd', '\n',
        'l', 'a', 'p', 's', 'e', 's', '\n',
        'l', 'a', 'p', 's', 'i', 'n', 'g', '\n',
        'l', 'a', 'p', 't', 'o', 'p', '\n',
        'l', 'a', 'p', 't', 'o', 'p', 's', '\n',
        'l', 'a', 'p', 'w', 'i', 'n', 'g', '\n',
        'l', 'a', 'p', 'w', 'i', 'n', 'g', 's', '\n',
        'l', 'a', 'r', 'c', 'e', 'n', 'y', '\n',
        'l', 'a', 'r', 'c', 'h', '\n',
        'l', 'a', 'r', 'c', 'h', 'e', 's', '\n',
        'l', 'a', 'r', 'd', '\n',
        'l', 'a', 'r', 'd', 'e', 'r', '\n',
        'l', 'a', 'r', 'd', 'e', 'r', 's', '\n',
        'l', 'a', 'r', 'd', 's', '\n',
        'l', 'a', 'r', 'g', 'e', '\n',
        'l', 'a', 'r', 'g', 'e', 'l', 'y', '\n',
        'l', 'a', 'r', 'g', 'e', 'n', 'e', 's', 's', '\n',
        'l', 'a', 'r', 'g', 'e', 'r', '\n',
        'l', 'a', 'r', 'g', 'e', 's', 't', '\n',
        'l', 'a', 'r', 'g', 'i', 's', 'h', '\n',
        'l', 'a', 'r', 'g', 'o', '\n',
        'l', 'a', 'r', 'k', '\n',
        'l', 'a', 'r', 'k', 'i', 'n', 'g', '\n',
        'l', 'a', 'r', 'k', 's', '\n',
        'l', 'a', 'r', 'v', 'a', '\n',
        'l', 'a', 'r', 'v', 'a', 'e', '\n',
        'l', 'a', 'r', 'v', 'a', 'l', '\n',
        'l', 'a', 'r', 'y', 'n', 'g', 'e', 'a', 'l', '\n',
        'l', 'a', 'r', 'y', 'n', 'g', 'i', 't', 'i', 's', '\n',
        'l', 'a', 'r', 'y', 'n', 'x', '\n',
        'l', 'a', 'r', 'y', 'n', 'x', 'e', 's', '\n',
        'l', 'a', 's', '\n',
        'l', 'a', 's', 'a', 'g', 'n', 'e', '\n',
        'l', 'a', 's', 'c', 'i', 'v', 'i', 'o', 'u', 's', '\n',
        'l', 'a', 's', 'c', 'i', 'v', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'l', 'a', 's', 'c', 'i', 'v', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'l', 'a', 's', 'e', '\n',
        'l', 'a', 's', 'e', 'r', '\n',
        'l', 'a', 's', 'e', 'r', 's', '\n',
        'l', 'a', 's', 'h', '\n',
        'l', 'a', 's', 'h', 'e', 'd', '\n',
        'l', 'a', 's', 'h', 'e', 'r', 's', '\n',
        'l', 'a', 's', 'h', 'e', 's', '\n',
        'l', 'a', 's', 'h', 'i', 'n', 'g', '\n',
        'l', 'a', 's', 'h', 'i', 'n', 'g', 's', '\n',
        'l', 'a', 's', 'i', 'n', 'g', '\n',
        'l', 'a', 's', 's', '\n',
        'l', 'a', 's', 's', 'e', 's', '\n',
        'l', 'a', 's', 's', 'i', 'e', '\n',
        'l', 'a', 's', 's', 'i', 'e', 's', '\n',
        'l', 'a', 's', 's', 'i', 't', 'u', 'd', 'e', '\n',
        'l', 'a', 's', 's', 'o', '\n',
        'l', 'a', 's', 's', 'o', 'e', 'd', '\n',
        'l', 'a', 's', 's', 'o', 'i', 'n', 'g', '\n',
        'l', 'a', 's', 't', '\n',
        'l', 'a', 's', 't', 'e', 'd', '\n',
        'l', 'a', 's', 't', 'i', 'n', 'g', '\n',
        'l', 'a', 's', 't', 'l', 'y', '\n',
        'l', 'a', 's', 't', 's', '\n',
        'l', 'a', 't', 'c', 'h', '\n',
        'l', 'a', 't', 'c', 'h', 'e', 'd', '\n',
        'l', 'a', 't', 'c', 'h', 'e', 's', '\n',
        'l', 'a', 't', 'c', 'h', 'i', 'n', 'g', '\n',
        'l', 'a', 't', 'e', '\n',
        'l', 'a', 't', 'e', 'c', 'o', 'm', 'e', 'r', '\n',
        'l', 'a', 't', 'e', 'c', 'o', 'm', 'e', 'r', 's', '\n',
        'l', 'a', 't', 'e', 'l', 'y', '\n',
        'l', 'a', 't', 'e', 'n', 'c', 'i', 'e', 's', '\n',
        'l', 'a', 't', 'e', 'n', 'c', 'y', '\n',
        'l', 'a', 't', 'e', 'n', 'e', 's', 's', '\n',
        'l', 'a', 't', 'e', 'n', 't', '\n',
        'l', 'a', 't', 'e', 'r', '\n',
        'l', 'a', 't', 'e', 'r', 'a', 'l', '\n',
        'l', 'a', 't', 'e', 'r', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'l', 'a', 't', 'e', 'r', 'a', 'l', 'l', 'y', '\n',
        'l', 'a', 't', 'e', 'r', 'a', 'l', 's', '\n',
        'l', 'a', 't', 'e', 's', 't', '\n',
        'l', 'a', 't', 'e', 'x', '\n',
        'l', 'a', 't', 'h', '\n',
        'l', 'a', 't', 'h', 'e', '\n',
        'l', 'a', 't', 'h', 'e', 'r', '\n',
        'l', 'a', 't', 'h', 'e', 'r', 'e', 'd', '\n',
        'l', 'a', 't', 'h', 'e', 'r', 's', '\n',
        'l', 'a', 't', 'h', 'e', 's', '\n',
        'l', 'a', 't', 'h', 's', '\n',
        'l', 'a', 't', 'i', 'c', 'e', 's', '\n',
        'l', 'a', 't', 'i', 'n', '\n',
        'l', 'a', 't', 'i', 'n', 'o', '\n',
        'l', 'a', 't', 'i', 't', 'u', 'd', 'e', '\n',
        'l', 'a', 't', 'i', 't', 'u', 'd', 'e', 's', '\n',
        'l', 'a', 't', 'i', 't', 'u', 'd', 'i', 'n', 'a', 'l', '\n',
        'l', 'a', 't', 'r', 'i', 'n', 'e', '\n',
        'l', 'a', 't', 'r', 'i', 'n', 'e', 's', '\n',
        'l', 'a', 't', 't', 'e', 'r', '\n',
        'l', 'a', 't', 't', 'i', 'c', 'e', '\n',
        'l', 'a', 't', 't', 'i', 'c', 'e', 'd', '\n',
        'l', 'a', 't', 't', 'i', 'c', 'e', 's', '\n',
        'l', 'a', 't', 'v', 'i', 'a', '\n',
        'l', 'a', 't', 'v', 'i', 'a', 'n', '\n',
        'l', 'a', 'u', 'd', '\n',
        'l', 'a', 'u', 'd', 'a', 'b', 'l', 'e', '\n',
        'l', 'a', 'u', 'd', 'a', 't', 'o', 'r', 'y', '\n',
        'l', 'a', 'u', 'd', 'e', 'd', '\n',
        'l', 'a', 'u', 'd', 'e', 'r', 's', '\n',
        'l', 'a', 'u', 'd', 'i', 'n', 'g', '\n',
        'l', 'a', 'u', 'd', 's', '\n',
        'l', 'a', 'u', 'g', 'h', '\n',
        'l', 'a', 'u', 'g', 'h', 'a', 'b', 'l', 'e', '\n',
        'l', 'a', 'u', 'g', 'h', 'a', 'b', 'l', 'y', '\n',
        'l', 'a', 'u', 'g', 'h', 'e', 'd', '\n',
        'l', 'a', 'u', 'g', 'h', 'e', 'r', '\n',
        'l', 'a', 'u', 'g', 'h', 'i', 'n', 'g', '\n',
        'l', 'a', 'u', 'g', 'h', 'i', 'n', 'g', 'l', 'y', '\n',
        'l', 'a', 'u', 'g', 'h', 's', '\n',
        'l', 'a', 'u', 'g', 'h', 't', 'e', 'r', '\n',
        'l', 'a', 'u', 'n', 'c', 'h', '\n',
        'l', 'a', 'u', 'n', 'c', 'h', 'e', 'd', '\n',
        'l', 'a', 'u', 'n', 'c', 'h', 'e', 'r', '\n',
        'l', 'a', 'u', 'n', 'c', 'h', 'e', 'r', 's', '\n',
        'l', 'a', 'u', 'n', 'c', 'h', 'e', 's', '\n',
        'l', 'a', 'u', 'n', 'c', 'h', 'i', 'n', 'g', '\n',
        'l', 'a', 'u', 'n', 'd', 'e', 'r', '\n',
        'l', 'a', 'u', 'n', 'd', 'e', 'r', 'e', 'd', '\n',
        'l', 'a', 'u', 'n', 'd', 'e', 'r', 'e', 't', 't', 'e', '\n',
        'l', 'a', 'u', 'n', 'd', 'e', 'r', 'e', 't', 't', 'e', 's', '\n',
        'l', 'a', 'u', 'n', 'd', 'e', 'r', 'i', 'n', 'g', '\n',
        'l', 'a', 'u', 'n', 'd', 'r', 'e', 's', 's', '\n',
        'l', 'a', 'u', 'n', 'd', 'r', 'e', 't', 't', 'e', '\n',
        'l', 'a', 'u', 'n', 'd', 'r', 'e', 't', 't', 'e', 's', '\n',
        'l', 'a', 'u', 'n', 'd', 'r', 'i', 'e', 's', '\n',
        'l', 'a', 'u', 'n', 'd', 'r', 'y', '\n',
        'l', 'a', 'u', 'r', 'e', 'a', 't', 'e', '\n',
        'l', 'a', 'u', 'r', 'e', 'l', '\n',
        'l', 'a', 'u', 'r', 'e', 'l', 's', '\n',
        'l', 'a', 'v', 'a', '\n',
        'l', 'a', 'v', 'a', 's', '\n',
        'l', 'a', 'v', 'a', 't', 'o', 'r', 'i', 'a', 'l', '\n',
        'l', 'a', 'v', 'a', 't', 'o', 'r', 'i', 'e', 's', '\n',
        'l', 'a', 'v', 'a', 't', 'o', 'r', 'y', '\n',
        'l', 'a', 'v', 'e', 'n', 'd', 'e', 'r', '\n',
        'l', 'a', 'v', 'i', 's', 'h', '\n',
        'l', 'a', 'v', 'i', 's', 'h', 'e', 'd', '\n',
        'l', 'a', 'v', 'i', 's', 'h', 'e', 's', '\n',
        'l', 'a', 'v', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'l', 'a', 'v', 'i', 's', 'h', 'l', 'y', '\n',
        'l', 'a', 'v', 'i', 's', 'h', 'n', 'e', 's', 's', '\n',
        'l', 'a', 'w', '\n',
        'l', 'a', 'w', 'a', 'b', 'i', 'd', 'i', 'n', 'g', '\n',
        'l', 'a', 'w', 'b', 'r', 'e', 'a', 'k', 'e', 'r', '\n',
        'l', 'a', 'w', 'b', 'r', 'e', 'a', 'k', 'e', 'r', 's', '\n',
        'l', 'a', 'w', 'b', 'r', 'e', 'a', 'k', 'i', 'n', 'g', '\n',
        'l', 'a', 'w', 'f', 'u', 'l', '\n',
        'l', 'a', 'w', 'f', 'u', 'l', 'l', 'y', '\n',
        'l', 'a', 'w', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'l', 'a', 'w', 'l', 'e', 's', 's', '\n',
        'l', 'a', 'w', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'l', 'a', 'w', 'm', 'a', 'k', 'e', 'r', '\n',
        'l', 'a', 'w', 'm', 'a', 'k', 'e', 'r', 's', '\n',
        'l', 'a', 'w', 'm', 'a', 'n', '\n',
        'l', 'a', 'w', 'm', 'e', 'n', '\n',
        'l', 'a', 'w', 'n', '\n',
        'l', 'a', 'w', 'n', 'm', 'o', 'w', 'e', 'r', '\n',
        'l', 'a', 'w', 'n', 'm', 'o', 'w', 'e', 'r', 's', '\n',
        'l', 'a', 'w', 'n', 's', '\n',
        'l', 'a', 'w', 's', '\n',
        'l', 'a', 'w', 's', 'u', 'i', 't', '\n',
        'l', 'a', 'w', 's', 'u', 'i', 't', 's', '\n',
        'l', 'a', 'w', 'y', 'e', 'r', '\n',
        'l', 'a', 'w', 'y', 'e', 'r', 's', '\n',
        'l', 'a', 'x', '\n',
        'l', 'a', 'x', 'a', 't', 'i', 'v', 'e', '\n',
        'l', 'a', 'x', 'a', 't', 'i', 'v', 'e', 's', '\n',
        'l', 'a', 'x', 'e', 'r', '\n',
        'l', 'a', 'x', 'i', 't', 'y', '\n',
        'l', 'a', 'x', 'n', 'e', 's', 's', '\n',
        'l', 'a', 'y', '\n',
        'l', 'a', 'y', 'a', 'b', 'o', 'u', 't', '\n',
        'l', 'a', 'y', 'a', 'b', 'o', 'u', 't', 's', '\n',
        'l', 'a', 'y', 'b', 'y', '\n',
        'l', 'a', 'y', 'b', 'y', 's', '\n',
        'l', 'a', 'y', 'e', 'r', '\n',
        'l', 'a', 'y', 'e', 'r', 'e', 'd', '\n',
        'l', 'a', 'y', 'e', 'r', 'i', 'n', 'g', '\n',
        'l', 'a', 'y', 'e', 'r', 's', '\n',
        'l', 'a', 'y', 'i', 'n', 'g', '\n',
        'l', 'a', 'y', 'm', 'a', 'n', '\n',
        'l', 'a', 'y', 'm', 'e', 'n', '\n',
        'l', 'a', 'y', 'o', 'f', 'f', '\n',
        'l', 'a', 'y', 'o', 'f', 'f', 's', '\n',
        'l', 'a', 'y', 'o', 'u', 't', '\n',
        'l', 'a', 'y', 'o', 'u', 't', 's', '\n',
        'l', 'a', 'y', 'p', 'e', 'r', 's', 'o', 'n', '\n',
        'l', 'a', 'y', 's', '\n',
        'l', 'a', 'z', 'a', 'r', 'e', 't', '\n',
        'l', 'a', 'z', 'a', 'r', 'u', 's', '\n',
        'l', 'a', 'z', 'e', '\n',
        'l', 'a', 'z', 'e', 'd', '\n',
        'l', 'a', 'z', 'i', 'e', 'r', '\n',
        'l', 'a', 'z', 'i', 'e', 's', 't', '\n',
        'l', 'a', 'z', 'i', 'l', 'y', '\n',
        'l', 'a', 'z', 'i', 'n', 'e', 's', 's', '\n',
        'l', 'a', 'z', 'i', 'n', 'g', '\n',
        'l', 'a', 'z', 'u', 'l', 'i', '\n',
        'l', 'a', 'z', 'y', '\n',
        'l', 'a', 'z', 'y', 'b', 'o', 'n', 'e', 's', '\n',
        'l', 'e', 'a', '\n',
        'l', 'e', 'a', 'c', 'h', '\n',
        'l', 'e', 'a', 'c', 'h', 'e', 'd', '\n',
        'l', 'e', 'a', 'c', 'h', 'e', 's', '\n',
        'l', 'e', 'a', 'c', 'h', 'i', 'n', 'g', '\n',
        'l', 'e', 'a', 'd', '\n',
        'l', 'e', 'a', 'd', 'e', 'd', '\n',
        'l', 'e', 'a', 'd', 'e', 'n', '\n',
        'l', 'e', 'a', 'd', 'e', 'r', '\n',
        'l', 'e', 'a', 'd', 'e', 'r', 'l', 'e', 's', 's', '\n',
        'l', 'e', 'a', 'd', 'e', 'r', 's', '\n',
        'l', 'e', 'a', 'd', 'e', 'r', 's', 'h', 'i', 'p', '\n',
        'l', 'e', 'a', 'd', 'e', 'r', 's', 'h', 'i', 'p', 's', '\n',
        'l', 'e', 'a', 'd', 'f', 'r', 'e', 'e', '\n',
        'l', 'e', 'a', 'd', 'i', 'n', 'g', '\n',
        'l', 'e', 'a', 'd', 's', '\n',
        'l', 'e', 'a', 'f', '\n',
        'l', 'e', 'a', 'f', 'e', 'd', '\n',
        'l', 'e', 'a', 'f', 'i', 'e', 'r', '\n',
        'l', 'e', 'a', 'f', 'i', 'e', 's', 't', '\n',
        'l', 'e', 'a', 'f', 'i', 'n', 'e', 's', 's', '\n',
        'l', 'e', 'a', 'f', 'i', 'n', 'g', '\n',
        'l', 'e', 'a', 'f', 'l', 'e', 's', 's', '\n',
        'l', 'e', 'a', 'f', 'l', 'e', 't', '\n',
        'l', 'e', 'a', 'f', 'l', 'e', 't', 's', '\n',
        'l', 'e', 'a', 'f', 'y', '\n',
        'l', 'e', 'a', 'g', 'u', 'e', '\n',
        'l', 'e', 'a', 'g', 'u', 'e', 's', '\n',
        'l', 'e', 'a', 'k', '\n',
        'l', 'e', 'a', 'k', 'a', 'g', 'e', '\n',
        'l', 'e', 'a', 'k', 'a', 'g', 'e', 's', '\n',
        'l', 'e', 'a', 'k', 'e', 'd', '\n',
        'l', 'e', 'a', 'k', 'i', 'e', 'r', '\n',
        'l', 'e', 'a', 'k', 'i', 'e', 's', 't', '\n',
        'l', 'e', 'a', 'k', 'i', 'n', 'e', 's', 's', '\n',
        'l', 'e', 'a', 'k', 'i', 'n', 'g', '\n',
        'l', 'e', 'a', 'k', 's', '\n',
        'l', 'e', 'a', 'k', 'y', '\n',
        'l', 'e', 'a', 'n', '\n',
        'l', 'e', 'a', 'n', 'e', 'd', '\n',
        'l', 'e', 'a', 'n', 'e', 'r', '\n',
        'l', 'e', 'a', 'n', 'e', 's', 't', '\n',
        'l', 'e', 'a', 'n', 'i', 'n', 'g', '\n',
        'l', 'e', 'a', 'n', 'i', 'n', 'g', 's', '\n',
        'l', 'e', 'a', 'n', 'n', 'e', 's', 's', '\n',
        'l', 'e', 'a', 'n', 's', '\n',
        'l', 'e', 'a', 'n', 't', '\n',
        'l', 'e', 'a', 'p', '\n',
        'l', 'e', 'a', 'p', 'e', 'd', '\n',
        'l', 'e', 'a', 'p', 'e', 'r', '\n',
        'l', 'e', 'a', 'p', 'f', 'r', 'o', 'g', '\n',
        'l', 'e', 'a', 'p', 'f', 'r', 'o', 'g', 'g', 'i', 'n', 'g', '\n',
        'l', 'e', 'a', 'p', 'i', 'n', 'g', '\n',
        'l', 'e', 'a', 'p', 's', '\n',
        'l', 'e', 'a', 'p', 't', '\n',
        'l', 'e', 'a', 'p', 'y', 'e', 'a', 'r', '\n',
        'l', 'e', 'a', 'r', 'n', '\n',
        'l', 'e', 'a', 'r', 'n', 'a', 'b', 'l', 'e', '\n',
        'l', 'e', 'a', 'r', 'n', 'e', 'd', '\n',
        'l', 'e', 'a', 'r', 'n', 'e', 'd', 'l', 'y', '\n',
        'l', 'e', 'a', 'r', 'n', 'e', 'r', '\n',
        'l', 'e', 'a', 'r', 'n', 'e', 'r', 's', '\n',
        'l', 'e', 'a', 'r', 'n', 'i', 'n', 'g', '\n',
        'l', 'e', 'a', 'r', 'n', 's', '\n',
        'l', 'e', 'a', 'r', 'n', 't', '\n',
        'l', 'e', 'a', 's', 'e', '\n',
        'l', 'e', 'a', 's', 'e', 'd', '\n',
        'l', 'e', 'a', 's', 'e', 'h', 'o', 'l', 'd', '\n',
        'l', 'e', 'a', 's', 'e', 'h', 'o', 'l', 'd', 'e', 'r', '\n',
        'l', 'e', 'a', 's', 'e', 'h', 'o', 'l', 'd', 'e', 'r', 's', '\n',
        'l', 'e', 'a', 's', 'e', 's', '\n',
        'l', 'e', 'a', 's', 'h', '\n',
        'l', 'e', 'a', 's', 'h', 'e', 'd', '\n',
        'l', 'e', 'a', 's', 'h', 'e', 's', '\n',
        'l', 'e', 'a', 's', 'h', 'i', 'n', 'g', '\n',
        'l', 'e', 'a', 's', 'i', 'n', 'g', '\n',
        'l', 'e', 'a', 's', 't', '\n',
        'l', 'e', 'a', 't', '\n',
        'l', 'e', 'a', 't', 'h', 'e', 'r', '\n',
        'l', 'e', 'a', 't', 'h', 'e', 'r', 's', '\n',
        'l', 'e', 'a', 't', 'h', 'e', 'r', 'y', '\n',
        'l', 'e', 'a', 'v', 'e', '\n',
        'l', 'e', 'a', 'v', 'e', 'd', '\n',
        'l', 'e', 'a', 'v', 'e', 'n', '\n',
        'l', 'e', 'a', 'v', 'e', 'n', 'e', 'd', '\n',
        'l', 'e', 'a', 'v', 'e', 'n', 'i', 'n', 'g', '\n',
        'l', 'e', 'a', 'v', 'e', 'r', '\n',
        'l', 'e', 'a', 'v', 'e', 'r', 's', '\n',
        'l', 'e', 'a', 'v', 'e', 's', '\n',
        'l', 'e', 'a', 'v', 'i', 'n', 'g', '\n',
        'l', 'e', 'a', 'v', 'i', 'n', 'g', 's', '\n',
        'l', 'e', 'b', 'a', 'n', 'o', 'n', '\n',
        'l', 'e', 'b', 'e', 'n', 's', 'r', 'a', 'u', 'm', '\n',
        'l', 'e', 'c', 'h', 'e', 'r', '\n',
        'l', 'e', 'c', 'h', 'e', 'r', 'o', 'u', 's', '\n',
        'l', 'e', 'c', 'h', 'e', 'r', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'l', 'e', 'c', 'h', 'e', 'r', 'y', '\n',
        'l', 'e', 'c', 't', 'e', 'r', 'n', '\n',
        'l', 'e', 'c', 't', 'o', 'r', '\n',
        'l', 'e', 'c', 't', 'o', 'r', 's', '\n',
        'l', 'e', 'c', 't', 'u', 'r', 'e', '\n',
        'l', 'e', 'c', 't', 'u', 'r', 'e', 'd', '\n',
        'l', 'e', 'c', 't', 'u', 'r', 'e', 'r', '\n',
        'l', 'e', 'c', 't', 'u', 'r', 'e', 'r', 's', '\n',
        'l', 'e', 'c', 't', 'u', 'r', 'e', 's', '\n',
        'l', 'e', 'c', 't', 'u', 'r', 'e', 's', 'h', 'i', 'p', '\n',
        'l', 'e', 'c', 't', 'u', 'r', 'e', 's', 'h', 'i', 'p', 's', '\n',
        'l', 'e', 'c', 't', 'u', 'r', 'i', 'n', 'g', '\n',
        'l', 'e', 'd', '\n',
        'l', 'e', 'd', 'g', 'e', '\n',
        'l', 'e', 'd', 'g', 'e', 'r', '\n',
        'l', 'e', 'd', 'g', 'e', 'r', 's', '\n',
        'l', 'e', 'd', 'g', 'e', 's', '\n',
        'l', 'e', 'e', '\n',
        'l', 'e', 'e', 'c', 'h', '\n',
        'l', 'e', 'e', 'c', 'h', 'e', 's', '\n',
        'l', 'e', 'e', 'c', 'h', 'i', 'n', 'g', '\n',
        'l', 'e', 'e', 'd', 's', '\n',
        'l', 'e', 'e', 'k', '\n',
        'l', 'e', 'e', 'k', 's', '\n',
        'l', 'e', 'e', 'r', '\n',
        'l', 'e', 'e', 'r', 'e', 'd', '\n',
        'l', 'e', 'e', 'r', 'i', 'n', 'g', '\n',
        'l', 'e', 'e', 'r', 'i', 'n', 'g', 'l', 'y', '\n',
        'l', 'e', 'e', 'r', 's', '\n',
        'l', 'e', 'e', 's', '\n',
        'l', 'e', 'e', 'w', 'a', 'r', 'd', '\n',
        'l', 'e', 'e', 'w', 'a', 'y', '\n',
        'l', 'e', 'f', 't', '\n',
        'l', 'e', 'f', 't', 'h', 'a', 'n', 'd', 'e', 'd', '\n',
        'l', 'e', 'f', 't', 'h', 'a', 'n', 'd', 'e', 'd', 'l', 'y', '\n',
        'l', 'e', 'f', 't', 'h', 'a', 'n', 'd', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'l', 'e', 'f', 't', 'h', 'a', 'n', 'd', 'e', 'r', '\n',
        'l', 'e', 'f', 't', 'h', 'a', 'n', 'd', 'e', 'r', 's', '\n',
        'l', 'e', 'f', 't', 'i', 'e', 's', '\n',
        'l', 'e', 'f', 't', 'i', 's', 'h', '\n',
        'l', 'e', 'f', 't', 'i', 's', 't', '\n',
        'l', 'e', 'f', 't', 'i', 's', 't', 's', '\n',
        'l', 'e', 'f', 't', 'm', 'o', 's', 't', '\n',
        'l', 'e', 'f', 't', 'o', 'v', 'e', 'r', '\n',
        'l', 'e', 'f', 't', 'o', 'v', 'e', 'r', 's', '\n',
        'l', 'e', 'f', 't', 's', '\n',
        'l', 'e', 'f', 't', 'w', 'a', 'r', 'd', '\n',
        'l', 'e', 'f', 't', 'w', 'a', 'r', 'd', 's', '\n',
        'l', 'e', 'f', 't', 'y', '\n',
        'l', 'e', 'g', '\n',
        'l', 'e', 'g', 'a', 'c', 'i', 'e', 's', '\n',
        'l', 'e', 'g', 'a', 'c', 'y', '\n',
        'l', 'e', 'g', 'a', 'l', '\n',
        'l', 'e', 'g', 'a', 'l', 'e', 's', 'e', '\n',
        'l', 'e', 'g', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'l', 'e', 'g', 'a', 'l', 'i', 's', 'e', '\n',
        'l', 'e', 'g', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'l', 'e', 'g', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'l', 'e', 'g', 'a', 'l', 'i', 's', 'm', '\n',
        'l', 'e', 'g', 'a', 'l', 'i', 's', 't', 'i', 'c', '\n',
        'l', 'e', 'g', 'a', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'l', 'e', 'g', 'a', 'l', 'i', 't', 'y', '\n',
        'l', 'e', 'g', 'a', 'l', 'l', 'y', '\n',
        'l', 'e', 'g', 'a', 't', 'e', '\n',
        'l', 'e', 'g', 'a', 't', 'e', 'e', '\n',
        'l', 'e', 'g', 'a', 't', 'e', 'e', 's', '\n',
        'l', 'e', 'g', 'a', 't', 'e', 's', '\n',
        'l', 'e', 'g', 'a', 't', 'i', 'o', 'n', '\n',
        'l', 'e', 'g', 'a', 't', 'o', '\n',
        'l', 'e', 'g', 'a', 't', 'o', 'r', '\n',
        'l', 'e', 'g', 'e', 'n', 'd', '\n',
        'l', 'e', 'g', 'e', 'n', 'd', 'a', 'r', 'y', '\n',
        'l', 'e', 'g', 'e', 'n', 'd', 's', '\n',
        'l', 'e', 'g', 'e', 'r', 'd', 'e', 'm', 'a', 'i', 'n', '\n',
        'l', 'e', 'g', 'g', 'e', 'd', '\n',
        'l', 'e', 'g', 'g', 'i', 'n', 'g', '\n',
        'l', 'e', 'g', 'g', 'i', 'n', 'g', 's', '\n',
        'l', 'e', 'g', 'g', 'y', '\n',
        'l', 'e', 'g', 'h', 'o', 'r', 'n', '\n',
        'l', 'e', 'g', 'h', 'o', 'r', 'n', 's', '\n',
        'l', 'e', 'g', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'l', 'e', 'g', 'i', 'b', 'l', 'e', '\n',
        'l', 'e', 'g', 'i', 'b', 'l', 'y', '\n',
        'l', 'e', 'g', 'i', 'o', 'n', '\n',
        'l', 'e', 'g', 'i', 'o', 'n', 'a', 'r', 'i', 'e', 's', '\n',
        'l', 'e', 'g', 'i', 'o', 'n', 'a', 'r', 'y', '\n',
        'l', 'e', 'g', 'i', 'o', 'n', 'n', 'a', 'i', 'r', 'e', 's', '\n',
        'l', 'e', 'g', 'i', 'o', 'n', 's', '\n',
        'l', 'e', 'g', 'i', 's', 'l', 'a', 't', 'e', '\n',
        'l', 'e', 'g', 'i', 's', 'l', 'a', 't', 'e', 'd', '\n',
        'l', 'e', 'g', 'i', 's', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'l', 'e', 'g', 'i', 's', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'l', 'e', 'g', 'i', 's', 'l', 'a', 't', 'i', 'v', 'e', '\n',
        'l', 'e', 'g', 'i', 's', 'l', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'l', 'e', 'g', 'i', 's', 'l', 'a', 't', 'o', 'r', '\n',
        'l', 'e', 'g', 'i', 's', 'l', 'a', 't', 'o', 'r', 's', '\n',
        'l', 'e', 'g', 'i', 's', 'l', 'a', 't', 'u', 'r', 'e', '\n',
        'l', 'e', 'g', 'i', 's', 'l', 'a', 't', 'u', 'r', 'e', 's', '\n',
        'l', 'e', 'g', 'i', 't', 'i', 'm', 'a', 'c', 'y', '\n',
        'l', 'e', 'g', 'i', 't', 'i', 'm', 'a', 't', 'e', '\n',
        'l', 'e', 'g', 'i', 't', 'i', 'm', 'a', 't', 'e', 'd', '\n',
        'l', 'e', 'g', 'i', 't', 'i', 'm', 'a', 't', 'e', 'l', 'y', '\n',
        'l', 'e', 'g', 'i', 't', 'i', 'm', 'a', 't', 'i', 'n', 'g', '\n',
        'l', 'e', 'g', 'i', 't', 'i', 'm', 'a', 't', 'i', 'o', 'n', '\n',
        'l', 'e', 'g', 'i', 't', 'i', 'm', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'l', 'e', 'g', 'i', 't', 'i', 'm', 'i', 's', 'e', '\n',
        'l', 'e', 'g', 'i', 't', 'i', 'm', 'i', 's', 'e', 'd', '\n',
        'l', 'e', 'g', 'i', 't', 'i', 'm', 'i', 's', 'i', 'n', 'g', '\n',
        'l', 'e', 'g', 'l', 'e', 's', 's', '\n',
        'l', 'e', 'g', 'm', 'a', 'n', '\n',
        'l', 'e', 'g', 'r', 'o', 'o', 'm', '\n',
        'l', 'e', 'g', 's', '\n',
        'l', 'e', 'g', 'u', 'm', 'e', '\n',
        'l', 'e', 'g', 'u', 'm', 'e', 's', '\n',
        'l', 'e', 'g', 'u', 'm', 'i', 'n', 'o', 'u', 's', '\n',
        'l', 'e', 'g', 'w', 'o', 'r', 'k', '\n',
        'l', 'e', 'i', 'p', 'z', 'i', 'g', '\n',
        'l', 'e', 'i', 's', 'u', 'r', 'e', '\n',
        'l', 'e', 'i', 's', 'u', 'r', 'e', 'd', '\n',
        'l', 'e', 'i', 's', 'u', 'r', 'e', 'l', 'y', '\n',
        'l', 'e', 'i', 's', 'u', 'r', 'e', 'w', 'e', 'a', 'r', '\n',
        'l', 'e', 'i', 't', 'm', 'o', 't', 'i', 'f', '\n',
        'l', 'e', 'i', 't', 'm', 'o', 't', 'i', 'f', 's', '\n',
        'l', 'e', 'i', 't', 'm', 'o', 't', 'i', 'v', '\n',
        'l', 'e', 'i', 't', 'm', 'o', 't', 'i', 'v', 's', '\n',
        'l', 'e', 'm', 'm', 'a', '\n',
        'l', 'e', 'm', 'm', 'a', 's', '\n',
        'l', 'e', 'm', 'm', 'i', 'n', 'g', '\n',
        'l', 'e', 'm', 'm', 'i', 'n', 'g', 's', '\n',
        'l', 'e', 'm', 'o', 'n', '\n',
        'l', 'e', 'm', 'o', 'n', 'a', 'd', 'e', '\n',
        'l', 'e', 'm', 'o', 'n', 's', '\n',
        'l', 'e', 'm', 'u', 'r', '\n',
        'l', 'e', 'm', 'u', 'r', 's', '\n',
        'l', 'e', 'n', 'd', '\n',
        'l', 'e', 'n', 'd', 'e', 'r', '\n',
        'l', 'e', 'n', 'd', 'e', 'r', 's', '\n',
        'l', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'l', 'e', 'n', 'd', 's', '\n',
        'l', 'e', 'n', 'g', 't', 'h', '\n',
        'l', 'e', 'n', 'g', 't', 'h', 'e', 'n', '\n',
        'l', 'e', 'n', 'g', 't', 'h', 'e', 'n', 'e', 'd', '\n',
        'l', 'e', 'n', 'g', 't', 'h', 'e', 'n', 'i', 'n', 'g', '\n',
        'l', 'e', 'n', 'g', 't', 'h', 'e', 'n', 's', '\n',
        'l', 'e', 'n', 'g', 't', 'h', 'i', 'e', 'r', '\n',
        'l', 'e', 'n', 'g', 't', 'h', 'i', 'e', 's', 't', '\n',
        'l', 'e', 'n', 'g', 't', 'h', 'i', 'l', 'y', '\n',
        'l', 'e', 'n', 'g', 't', 'h', 's', '\n',
        'l', 'e', 'n', 'g', 't', 'h', 'w', 'a', 'y', 's', '\n',
        'l', 'e', 'n', 'g', 't', 'h', 'w', 'i', 's', 'e', '\n',
        'l', 'e', 'n', 'g', 't', 'h', 'y', '\n',
        'l', 'e', 'n', 'i', 'e', 'n', 'c', 'y', '\n',
        'l', 'e', 'n', 'i', 'e', 'n', 't', '\n',
        'l', 'e', 'n', 'i', 'e', 'n', 't', 'l', 'y', '\n',
        'l', 'e', 'n', 'i', 'n', '\n',
        'l', 'e', 'n', 's', '\n',
        'l', 'e', 'n', 's', 'e', 's', '\n',
        'l', 'e', 'n', 's', 'i', 'n', 'g', '\n',
        'l', 'e', 'n', 't', '\n',
        'l', 'e', 'n', 't', 'i', 'l', '\n',
        'l', 'e', 'n', 't', 'i', 'l', 's', '\n',
        'l', 'e', 'n', 't', 'o', '\n',
        'l', 'e', 'o', 'n', 'a', 'r', 'd', 'o', '\n',
        'l', 'e', 'o', 'n', 'e', '\n',
        'l', 'e', 'o', 'p', 'a', 'r', 'd', '\n',
        'l', 'e', 'o', 'p', 'a', 'r', 'd', 's', '\n',
        'l', 'e', 'o', 'p', 'a', 'r', 'd', 's', 'k', 'i', 'n', '\n',
        'l', 'e', 'o', 't', 'a', 'r', 'd', '\n',
        'l', 'e', 'o', 't', 'a', 'r', 'd', 's', '\n',
        'l', 'e', 'p', 'e', 'r', '\n',
        'l', 'e', 'p', 'e', 'r', 's', '\n',
        'l', 'e', 'p', 'r', 'e', 'c', 'h', 'a', 'u', 'n', '\n',
        'l', 'e', 'p', 'r', 'e', 'c', 'h', 'a', 'u', 'n', 's', '\n',
        'l', 'e', 'p', 'r', 'o', 's', 'e', '\n',
        'l', 'e', 'p', 'r', 'o', 's', 'y', '\n',
        'l', 'e', 'p', 'r', 'o', 'u', 's', '\n',
        'l', 'e', 'p', 't', 'o', 'n', '\n',
        'l', 'e', 'p', 't', 'o', 'n', 's', '\n',
        'l', 'e', 's', 'b', 'i', 'a', 'n', '\n',
        'l', 'e', 's', 'b', 'i', 'a', 'n', 'i', 's', 'm', '\n',
        'l', 'e', 's', 'b', 'i', 'a', 'n', 's', '\n',
        'l', 'e', 's', 'i', 'o', 'n', '\n',
        'l', 'e', 's', 'i', 'o', 'n', 's', '\n',
        'l', 'e', 's', 'o', 't', 'h', 'o', '\n',
        'l', 'e', 's', 's', '\n',
        'l', 'e', 's', 's', 'e', 'e', '\n',
        'l', 'e', 's', 's', 'e', 'e', 's', '\n',
        'l', 'e', 's', 's', 'e', 'n', '\n',
        'l', 'e', 's', 's', 'e', 'n', 'e', 'd', '\n',
        'l', 'e', 's', 's', 'e', 'n', 'i', 'n', 'g', '\n',
        'l', 'e', 's', 's', 'e', 'n', 's', '\n',
        'l', 'e', 's', 's', 'e', 'r', '\n',
        'l', 'e', 's', 's', 'o', 'n', '\n',
        'l', 'e', 's', 's', 'o', 'n', 's', '\n',
        'l', 'e', 's', 's', 'o', 'r', '\n',
        'l', 'e', 's', 's', 'o', 'r', 's', '\n',
        'l', 'e', 's', 't', '\n',
        'l', 'e', 't', '\n',
        'l', 'e', 't', 'h', 'a', 'l', '\n',
        'l', 'e', 't', 'h', 'a', 'l', 'i', 't', 'y', '\n',
        'l', 'e', 't', 'h', 'a', 'l', 'l', 'y', '\n',
        'l', 'e', 't', 'h', 'a', 'r', 'g', 'i', 'c', '\n',
        'l', 'e', 't', 'h', 'a', 'r', 'g', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'l', 'e', 't', 'h', 'a', 'r', 'g', 'y', '\n',
        'l', 'e', 't', 's', '\n',
        'l', 'e', 't', 't', 'e', 'r', '\n',
        'l', 'e', 't', 't', 'e', 'r', 'b', 'o', 'x', '\n',
        'l', 'e', 't', 't', 'e', 'r', 'b', 'o', 'x', 'e', 's', '\n',
        'l', 'e', 't', 't', 'e', 'r', 'e', 'd', '\n',
        'l', 'e', 't', 't', 'e', 'r', 'h', 'e', 'a', 'd', '\n',
        'l', 'e', 't', 't', 'e', 'r', 'h', 'e', 'a', 'd', 's', '\n',
        'l', 'e', 't', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'l', 'e', 't', 't', 'e', 'r', 'p', 'r', 'e', 's', 's', '\n',
        'l', 'e', 't', 't', 'e', 'r', 's', '\n',
        'l', 'e', 't', 't', 'e', 'r', 'w', 'r', 'i', 't', 'e', 'r', '\n',
        'l', 'e', 't', 't', 'i', 'n', 'g', '\n',
        'l', 'e', 't', 't', 'i', 'n', 'g', 's', '\n',
        'l', 'e', 't', 't', 'i', 's', 'h', '\n',
        'l', 'e', 't', 't', 'u', 'c', 'e', '\n',
        'l', 'e', 't', 't', 'u', 'c', 'e', 's', '\n',
        'l', 'e', 'u', 'c', 'i', 'n', 'e', '\n',
        'l', 'e', 'u', 'k', 'a', 'e', 'm', 'i', 'a', '\n',
        'l', 'e', 'u', 'k', 'e', 'm', 'i', 'a', '\n',
        'l', 'e', 'v', 'e', 'l', '\n',
        'l', 'e', 'v', 'e', 'l', 'h', 'e', 'a', 'd', 'e', 'd', '\n',
        'l', 'e', 'v', 'e', 'l', 'l', 'e', 'd', '\n',
        'l', 'e', 'v', 'e', 'l', 'l', 'e', 'r', '\n',
        'l', 'e', 'v', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'l', 'e', 'v', 'e', 'l', 'l', 'y', '\n',
        'l', 'e', 'v', 'e', 'l', 's', '\n',
        'l', 'e', 'v', 'e', 'r', '\n',
        'l', 'e', 'v', 'e', 'r', 'a', 'g', 'e', '\n',
        'l', 'e', 'v', 'e', 'r', 'a', 'g', 'e', 'd', '\n',
        'l', 'e', 'v', 'e', 'r', 'e', 'd', '\n',
        'l', 'e', 'v', 'e', 'r', 'i', 'n', 'g', '\n',
        'l', 'e', 'v', 'e', 'r', 's', '\n',
        'l', 'e', 'v', 'i', '\n',
        'l', 'e', 'v', 'i', 'a', 't', 'h', 'a', 'n', '\n',
        'l', 'e', 'v', 'i', 'e', 'd', '\n',
        'l', 'e', 'v', 'i', 'e', 's', '\n',
        'l', 'e', 'v', 'i', 't', 'a', 't', 'e', '\n',
        'l', 'e', 'v', 'i', 't', 'a', 't', 'e', 'd', '\n',
        'l', 'e', 'v', 'i', 't', 'a', 't', 'e', 's', '\n',
        'l', 'e', 'v', 'i', 't', 'a', 't', 'i', 'n', 'g', '\n',
        'l', 'e', 'v', 'i', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'l', 'e', 'v', 'i', 't', 'y', '\n',
        'l', 'e', 'v', 'y', '\n',
        'l', 'e', 'v', 'y', 'i', 'n', 'g', '\n',
        'l', 'e', 'w', 'd', '\n',
        'l', 'e', 'w', 'd', 'n', 'e', 's', 's', '\n',
        'l', 'e', 'x', 'e', 'm', 'e', '\n',
        'l', 'e', 'x', 'e', 'm', 'e', 's', '\n',
        'l', 'e', 'x', 'i', 'c', 'a', 'l', '\n',
        'l', 'e', 'x', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'l', 'e', 'x', 'i', 'c', 'o', 'g', 'r', 'a', 'p', 'h', 'e', 'r', '\n',
        'l', 'e', 'x', 'i', 'c', 'o', 'g', 'r', 'a', 'p', 'h', 'e', 'r', 's', '\n',
        'l', 'e', 'x', 'i', 'c', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', '\n',
        'l', 'e', 'x', 'i', 'c', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', 'a', 'l', '\n',
        'l', 'e', 'x', 'i', 'c', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'l', 'e', 'x', 'i', 'c', 'o', 'g', 'r', 'a', 'p', 'h', 'y', '\n',
        'l', 'e', 'x', 'i', 'c', 'o', 'n', '\n',
        'l', 'e', 'x', 'i', 'c', 'o', 'n', 's', '\n',
        'l', 'e', 'y', 'd', 'e', 'n', '\n',
        'l', 'i', 'a', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'l', 'i', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'l', 'i', 'a', 'b', 'l', 'e', '\n',
        'l', 'i', 'a', 'i', 's', 'e', '\n',
        'l', 'i', 'a', 'i', 's', 'e', 'd', '\n',
        'l', 'i', 'a', 'i', 's', 'e', 's', '\n',
        'l', 'i', 'a', 'i', 's', 'i', 'n', 'g', '\n',
        'l', 'i', 'a', 'i', 's', 'o', 'n', '\n',
        'l', 'i', 'a', 'i', 's', 'o', 'n', 's', '\n',
        'l', 'i', 'a', 'r', '\n',
        'l', 'i', 'a', 'r', 's', '\n',
        'l', 'i', 'b', 'a', 't', 'i', 'o', 'n', '\n',
        'l', 'i', 'b', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'l', 'i', 'b', 'e', 'l', '\n',
        'l', 'i', 'b', 'e', 'l', 'e', 'd', '\n',
        'l', 'i', 'b', 'e', 'l', 'e', 'r', '\n',
        'l', 'i', 'b', 'e', 'l', 'l', 'e', 'd', '\n',
        'l', 'i', 'b', 'e', 'l', 'l', 'e', 'r', '\n',
        'l', 'i', 'b', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'l', 'i', 'b', 'e', 'l', 'l', 'o', 'u', 's', '\n',
        'l', 'i', 'b', 'e', 'l', 's', '\n',
        'l', 'i', 'b', 'e', 'r', 'a', 'l', '\n',
        'l', 'i', 'b', 'e', 'r', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'l', 'i', 'b', 'e', 'r', 'a', 'l', 'i', 's', 'e', '\n',
        'l', 'i', 'b', 'e', 'r', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'l', 'i', 'b', 'e', 'r', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'l', 'i', 'b', 'e', 'r', 'a', 'l', 'i', 's', 'm', '\n',
        'l', 'i', 'b', 'e', 'r', 'a', 'l', 'i', 't', 'y', '\n',
        'l', 'i', 'b', 'e', 'r', 'a', 'l', 'l', 'y', '\n',
        'l', 'i', 'b', 'e', 'r', 'a', 'l', 's', '\n',
        'l', 'i', 'b', 'e', 'r', 'a', 't', 'e', '\n',
        'l', 'i', 'b', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'l', 'i', 'b', 'e', 'r', 'a', 't', 'e', 's', '\n',
        'l', 'i', 'b', 'e', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'l', 'i', 'b', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'l', 'i', 'b', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'i', 's', 't', 's', '\n',
        'l', 'i', 'b', 'e', 'r', 'a', 't', 'o', 'r', '\n',
        'l', 'i', 'b', 'e', 'r', 'a', 't', 'o', 'r', 's', '\n',
        'l', 'i', 'b', 'e', 'r', 'i', 'a', '\n',
        'l', 'i', 'b', 'e', 'r', 'o', '\n',
        'l', 'i', 'b', 'e', 'r', 't', 'a', 'r', 'i', 'a', 'n', '\n',
        'l', 'i', 'b', 'e', 'r', 't', 'a', 'r', 'i', 'a', 'n', 'i', 's', 'm', '\n',
        'l', 'i', 'b', 'e', 'r', 't', 'a', 'r', 'i', 'a', 'n', 's', '\n',
        'l', 'i', 'b', 'e', 'r', 't', 'i', 'e', 's', '\n',
        'l', 'i', 'b', 'e', 'r', 't', 'i', 'n', 'e', '\n',
        'l', 'i', 'b', 'e', 'r', 't', 'i', 'n', 'e', 's', '\n',
        'l', 'i', 'b', 'e', 'r', 't', 'y', '\n',
        'l', 'i', 'b', 'i', 'd', 'i', 'n', 'o', 'u', 's', '\n',
        'l', 'i', 'b', 'i', 'd', 'o', '\n',
        'l', 'i', 'b', 'r', 'a', 'r', 'i', 'a', 'n', '\n',
        'l', 'i', 'b', 'r', 'a', 'r', 'i', 'a', 'n', 's', '\n',
        'l', 'i', 'b', 'r', 'a', 'r', 'i', 'a', 'n', 's', 'h', 'i', 'p', '\n',
        'l', 'i', 'b', 'r', 'a', 'r', 'i', 'e', 's', '\n',
        'l', 'i', 'b', 'r', 'a', 'r', 'y', '\n',
        'l', 'i', 'b', 'r', 'a', 't', 'e', '\n',
        'l', 'i', 'b', 'r', 'a', 't', 'e', 'd', '\n',
        'l', 'i', 'b', 'r', 'a', 't', 'e', 's', '\n',
        'l', 'i', 'b', 'r', 'e', 't', 't', 'i', '\n',
        'l', 'i', 'b', 'r', 'e', 't', 't', 'i', 's', 't', '\n',
        'l', 'i', 'b', 'r', 'e', 't', 't', 'i', 's', 't', 's', '\n',
        'l', 'i', 'b', 'r', 'e', 't', 't', 'o', '\n',
        'l', 'i', 'b', 'y', 'a', '\n',
        'l', 'i', 'b', 'y', 'a', 'n', '\n',
        'l', 'i', 'b', 'y', 'a', 'n', 's', '\n',
        'l', 'i', 'c', 'e', '\n',
        'l', 'i', 'c', 'e', 'n', 'c', 'e', '\n',
        'l', 'i', 'c', 'e', 'n', 'c', 'e', 's', '\n',
        'l', 'i', 'c', 'e', 'n', 's', 'e', '\n',
        'l', 'i', 'c', 'e', 'n', 's', 'e', 'd', '\n',
        'l', 'i', 'c', 'e', 'n', 's', 'e', 'e', '\n',
        'l', 'i', 'c', 'e', 'n', 's', 'e', 'e', 's', '\n',
        'l', 'i', 'c', 'e', 'n', 's', 'e', 's', '\n',
        'l', 'i', 'c', 'e', 'n', 's', 'i', 'n', 'g', '\n',
        'l', 'i', 'c', 'e', 'n', 't', 'i', 'a', 't', 'e', '\n',
        'l', 'i', 'c', 'e', 'n', 't', 'i', 'o', 'u', 's', '\n',
        'l', 'i', 'c', 'e', 'n', 't', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'l', 'i', 'c', 'h', 'e', 'e', '\n',
        'l', 'i', 'c', 'h', 'e', 'n', '\n',
        'l', 'i', 'c', 'h', 'e', 'n', 'e', 'd', '\n',
        'l', 'i', 'c', 'h', 'e', 'n', 's', '\n',
        'l', 'i', 'c', 'h', 'i', '\n',
        'l', 'i', 'c', 'h', 'i', 's', '\n',
        'l', 'i', 'c', 'k', '\n',
        'l', 'i', 'c', 'k', 'e', 'd', '\n',
        'l', 'i', 'c', 'k', 'e', 'r', 'i', 's', 'h', '\n',
        'l', 'i', 'c', 'k', 'i', 'n', 'g', '\n',
        'l', 'i', 'c', 'k', 's', '\n',
        'l', 'i', 'c', 'o', 'r', 'i', 'c', 'e', '\n',
        'l', 'i', 'd', '\n',
        'l', 'i', 'd', 'd', 'e', 'd', '\n',
        'l', 'i', 'd', 'l', 'e', 's', 's', '\n',
        'l', 'i', 'd', 'o', '\n',
        'l', 'i', 'd', 's', '\n',
        'l', 'i', 'e', '\n',
        'l', 'i', 'e', 'd', '\n',
        'l', 'i', 'e', 'd', 'e', 'r', '\n',
        'l', 'i', 'e', 'n', '\n',
        'l', 'i', 'e', 'n', 's', '\n',
        'l', 'i', 'e', 's', '\n',
        'l', 'i', 'e', 'u', '\n',
        'l', 'i', 'e', 'u', 't', 'e', 'n', 'a', 'n', 'c', 'y', '\n',
        'l', 'i', 'e', 'u', 't', 'e', 'n', 'a', 'n', 't', '\n',
        'l', 'i', 'e', 'u', 't', 'e', 'n', 'a', 'n', 't', 's', '\n',
        'l', 'i', 'f', 'e', '\n',
        'l', 'i', 'f', 'e', 'a', 'n', 'd', 'd', 'e', 'a', 't', 'h', '\n',
        'l', 'i', 'f', 'e', 'b', 'e', 'l', 't', '\n',
        'l', 'i', 'f', 'e', 'b', 'l', 'o', 'o', 'd', '\n',
        'l', 'i', 'f', 'e', 'b', 'o', 'a', 't', '\n',
        'l', 'i', 'f', 'e', 'b', 'o', 'a', 't', 'm', 'e', 'n', '\n',
        'l', 'i', 'f', 'e', 'b', 'o', 'a', 't', 's', '\n',
        'l', 'i', 'f', 'e', 'f', 'o', 'r', 'm', 's', '\n',
        'l', 'i', 'f', 'e', 'g', 'i', 'v', 'i', 'n', 'g', '\n',
        'l', 'i', 'f', 'e', 'g', 'u', 'a', 'r', 'd', '\n',
        'l', 'i', 'f', 'e', 'g', 'u', 'a', 'r', 'd', 's', '\n',
        'l', 'i', 'f', 'e', 'l', 'e', 's', 's', '\n',
        'l', 'i', 'f', 'e', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'l', 'i', 'f', 'e', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'l', 'i', 'f', 'e', 'l', 'i', 'k', 'e', '\n',
        'l', 'i', 'f', 'e', 'l', 'i', 'n', 'e', '\n',
        'l', 'i', 'f', 'e', 'l', 'i', 'n', 'e', 's', '\n',
        'l', 'i', 'f', 'e', 'l', 'o', 'n', 'g', '\n',
        'l', 'i', 'f', 'e', 'r', 'a', 'f', 't', '\n',
        'l', 'i', 'f', 'e', 'r', 'a', 'f', 't', 's', '\n',
        'l', 'i', 'f', 'e', 's', 'a', 'v', 'i', 'n', 'g', '\n',
        'l', 'i', 'f', 'e', 's', 'i', 'z', 'e', '\n',
        'l', 'i', 'f', 'e', 's', 'i', 'z', 'e', 'd', '\n',
        'l', 'i', 'f', 'e', 's', 'p', 'a', 'n', '\n',
        'l', 'i', 'f', 'e', 's', 'p', 'a', 'n', 's', '\n',
        'l', 'i', 'f', 'e', 's', 't', 'y', 'l', 'e', '\n',
        'l', 'i', 'f', 'e', 's', 't', 'y', 'l', 'e', 's', '\n',
        'l', 'i', 'f', 'e', 't', 'a', 'k', 'i', 'n', 'g', '\n',
        'l', 'i', 'f', 'e', 't', 'h', 'r', 'e', 'a', 't', 'e', 'n', 'i', 'n', 'g', '\n',
        'l', 'i', 'f', 'e', 't', 'i', 'm', 'e', '\n',
        'l', 'i', 'f', 'e', 't', 'i', 'm', 'e', 's', '\n',
        'l', 'i', 'f', 'e', 'w', 'o', 'r', 'k', '\n',
        'l', 'i', 'f', 't', '\n',
        'l', 'i', 'f', 't', 'e', 'd', '\n',
        'l', 'i', 'f', 't', 'e', 'r', '\n',
        'l', 'i', 'f', 't', 'e', 'r', 's', '\n',
        'l', 'i', 'f', 't', 'i', 'n', 'g', '\n',
        'l', 'i', 'f', 't', 'm', 'a', 'n', '\n',
        'l', 'i', 'f', 't', 'm', 'e', 'n', '\n',
        'l', 'i', 'f', 't', 'o', 'f', 'f', '\n',
        'l', 'i', 'f', 't', 's', '\n',
        'l', 'i', 'g', 'a', 'm', 'e', 'n', 't', '\n',
        'l', 'i', 'g', 'a', 'm', 'e', 'n', 't', 's', '\n',
        'l', 'i', 'g', 'a', 'n', 'd', '\n',
        'l', 'i', 'g', 'a', 'n', 'd', 's', '\n',
        'l', 'i', 'g', 'a', 't', 'u', 'r', 'e', '\n',
        'l', 'i', 'g', 'a', 't', 'u', 'r', 'e', 'd', '\n',
        'l', 'i', 'g', 'a', 't', 'u', 'r', 'e', 's', '\n',
        'l', 'i', 'g', 'a', 't', 'u', 'r', 'i', 'n', 'g', '\n',
        'l', 'i', 'g', 'h', 't', '\n',
        'l', 'i', 'g', 'h', 't', 'e', 'd', '\n',
        'l', 'i', 'g', 'h', 't', 'e', 'n', '\n',
        'l', 'i', 'g', 'h', 't', 'e', 'n', 'e', 'd', '\n',
        'l', 'i', 'g', 'h', 't', 'e', 'n', 'i', 'n', 'g', '\n',
        'l', 'i', 'g', 'h', 't', 'e', 'n', 's', '\n',
        'l', 'i', 'g', 'h', 't', 'e', 'r', '\n',
        'l', 'i', 'g', 'h', 't', 'e', 'r', 's', '\n',
        'l', 'i', 'g', 'h', 't', 'e', 's', 't', '\n',
        'l', 'i', 'g', 'h', 't', 'h', 'e', 'a', 'd', 'e', 'd', '\n',
        'l', 'i', 'g', 'h', 't', 'h', 'e', 'a', 'd', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'l', 'i', 'g', 'h', 't', 'h', 'e', 'a', 'r', 't', 'e', 'd', '\n',
        'l', 'i', 'g', 'h', 't', 'h', 'e', 'a', 'r', 't', 'e', 'd', 'l', 'y', '\n',
        'l', 'i', 'g', 'h', 't', 'h', 'e', 'a', 'r', 't', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'l', 'i', 'g', 'h', 't', 'h', 'o', 'u', 's', 'e', '\n',
        'l', 'i', 'g', 'h', 't', 'h', 'o', 'u', 's', 'e', 's', '\n',
        'l', 'i', 'g', 'h', 't', 'i', 'n', 'g', '\n',
        'l', 'i', 'g', 'h', 't', 'l', 'e', 's', 's', '\n',
        'l', 'i', 'g', 'h', 't', 'l', 'y', '\n',
        'l', 'i', 'g', 'h', 't', 'n', 'e', 's', 's', '\n',
        'l', 'i', 'g', 'h', 't', 'n', 'i', 'n', 'g', '\n',
        'l', 'i', 'g', 'h', 't', 's', '\n',
        'l', 'i', 'g', 'h', 't', 's', 'h', 'i', 'p', '\n',
        'l', 'i', 'g', 'h', 't', 'w', 'e', 'i', 'g', 'h', 't', '\n',
        'l', 'i', 'g', 'h', 't', 'w', 'e', 'i', 'g', 'h', 't', 's', '\n',
        'l', 'i', 'g', 'n', 'i', 't', 'e', '\n',
        'l', 'i', 'k', 'a', 'b', 'l', 'e', '\n',
        'l', 'i', 'k', 'e', '\n',
        'l', 'i', 'k', 'e', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'l', 'i', 'k', 'e', 'a', 'b', 'l', 'e', '\n',
        'l', 'i', 'k', 'e', 'd', '\n',
        'l', 'i', 'k', 'e', 'l', 'i', 'e', 'r', '\n',
        'l', 'i', 'k', 'e', 'l', 'i', 'e', 's', 't', '\n',
        'l', 'i', 'k', 'e', 'l', 'i', 'h', 'o', 'o', 'd', '\n',
        'l', 'i', 'k', 'e', 'l', 'y', '\n',
        'l', 'i', 'k', 'e', 'm', 'i', 'n', 'd', 'e', 'd', '\n',
        'l', 'i', 'k', 'e', 'n', '\n',
        'l', 'i', 'k', 'e', 'n', 'e', 'd', '\n',
        'l', 'i', 'k', 'e', 'n', 'e', 's', 's', '\n',
        'l', 'i', 'k', 'e', 'n', 'e', 's', 's', 'e', 's', '\n',
        'l', 'i', 'k', 'e', 'n', 'i', 'n', 'g', '\n',
        'l', 'i', 'k', 'e', 'n', 's', '\n',
        'l', 'i', 'k', 'e', 's', '\n',
        'l', 'i', 'k', 'e', 'w', 'i', 's', 'e', '\n',
        'l', 'i', 'k', 'i', 'n', 'g', '\n',
        'l', 'i', 'k', 'i', 'n', 'g', 's', '\n',
        'l', 'i', 'l', 'a', 'c', '\n',
        'l', 'i', 'l', 'a', 'c', 's', '\n',
        'l', 'i', 'l', 'i', 'e', 's', '\n',
        'l', 'i', 'l', 'l', 'i', 'p', 'u', 't', '\n',
        'l', 'i', 'l', 'l', 'i', 'p', 'u', 't', 'i', 'a', 'n', '\n',
        'l', 'i', 'l', 'o', 'n', 'g', 'w', 'e', '\n',
        'l', 'i', 'l', 't', '\n',
        'l', 'i', 'l', 't', 'i', 'n', 'g', '\n',
        'l', 'i', 'l', 'y', '\n',
        'l', 'i', 'l', 'y', 'l', 'i', 'v', 'e', 'r', 'e', 'd', '\n',
        'l', 'i', 'l', 'y', 'w', 'h', 'i', 't', 'e', '\n',
        'l', 'i', 'm', 'a', '\n',
        'l', 'i', 'm', 'b', '\n',
        'l', 'i', 'm', 'b', 'e', 'r', '\n',
        'l', 'i', 'm', 'b', 'e', 'r', 'i', 'n', 'g', '\n',
        'l', 'i', 'm', 'b', 'e', 'r', 's', '\n',
        'l', 'i', 'm', 'b', 'l', 'e', 's', 's', '\n',
        'l', 'i', 'm', 'b', 'o', '\n',
        'l', 'i', 'm', 'b', 's', '\n',
        'l', 'i', 'm', 'e', '\n',
        'l', 'i', 'm', 'e', 'k', 'i', 'l', 'n', '\n',
        'l', 'i', 'm', 'e', 'l', 'i', 'g', 'h', 't', '\n',
        'l', 'i', 'm', 'e', 'r', 'i', 'c', 'k', '\n',
        'l', 'i', 'm', 'e', 'r', 'i', 'c', 'k', 's', '\n',
        'l', 'i', 'm', 'e', 's', '\n',
        'l', 'i', 'm', 'e', 's', 't', 'o', 'n', 'e', '\n',
        'l', 'i', 'm', 'e', 's', 't', 'o', 'n', 'e', 's', '\n',
        'l', 'i', 'm', 'e', 'y', 's', '\n',
        'l', 'i', 'm', 'i', 'n', 'a', 'l', '\n',
        'l', 'i', 'm', 'i', 'n', 'g', '\n',
        'l', 'i', 'm', 'i', 't', '\n',
        'l', 'i', 'm', 'i', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'l', 'i', 'm', 'i', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'l', 'i', 'm', 'i', 't', 'e', 'd', '\n',
        'l', 'i', 'm', 'i', 't', 'e', 'r', '\n',
        'l', 'i', 'm', 'i', 't', 'e', 'r', 's', '\n',
        'l', 'i', 'm', 'i', 't', 'i', 'n', 'g', '\n',
        'l', 'i', 'm', 'i', 't', 'l', 'e', 's', 's', '\n',
        'l', 'i', 'm', 'i', 't', 's', '\n',
        'l', 'i', 'm', 'o', '\n',
        'l', 'i', 'm', 'o', 'u', 's', 'i', 'n', '\n',
        'l', 'i', 'm', 'o', 'u', 's', 'i', 'n', 'e', '\n',
        'l', 'i', 'm', 'o', 'u', 's', 'i', 'n', 'e', 's', '\n',
        'l', 'i', 'm', 'p', '\n',
        'l', 'i', 'm', 'p', 'e', 'd', '\n',
        'l', 'i', 'm', 'p', 'e', 't', '\n',
        'l', 'i', 'm', 'p', 'e', 't', 's', '\n',
        'l', 'i', 'm', 'p', 'i', 'd', '\n',
        'l', 'i', 'm', 'p', 'i', 'n', 'g', '\n',
        'l', 'i', 'm', 'p', 'l', 'y', '\n',
        'l', 'i', 'm', 'p', 'o', 'p', 'o', '\n',
        'l', 'i', 'm', 'p', 's', '\n',
        'l', 'i', 'n', 'a', 'g', 'e', '\n',
        'l', 'i', 'n', 'c', 'h', 'p', 'i', 'n', '\n',
        'l', 'i', 'n', 'c', 'o', 'l', 'n', '\n',
        'l', 'i', 'n', 'd', 'e', 'n', '\n',
        'l', 'i', 'n', 'e', '\n',
        'l', 'i', 'n', 'e', 'a', 'g', 'e', '\n',
        'l', 'i', 'n', 'e', 'a', 'g', 'e', 's', '\n',
        'l', 'i', 'n', 'e', 'a', 'l', 'l', 'y', '\n',
        'l', 'i', 'n', 'e', 'a', 'm', 'e', 'n', 't', 's', '\n',
        'l', 'i', 'n', 'e', 'a', 'r', '\n',
        'l', 'i', 'n', 'e', 'a', 'r', 'i', 's', 'e', 'd', '\n',
        'l', 'i', 'n', 'e', 'a', 'r', 'i', 't', 'y', '\n',
        'l', 'i', 'n', 'e', 'a', 'r', 'l', 'y', '\n',
        'l', 'i', 'n', 'e', 'd', '\n',
        'l', 'i', 'n', 'e', 'f', 'e', 'e', 'd', '\n',
        'l', 'i', 'n', 'e', 'm', 'a', 'n', '\n',
        'l', 'i', 'n', 'e', 'm', 'e', 'n', '\n',
        'l', 'i', 'n', 'e', 'n', '\n',
        'l', 'i', 'n', 'e', 'n', 's', '\n',
        'l', 'i', 'n', 'e', 'o', 'u', 't', '\n',
        'l', 'i', 'n', 'e', 'o', 'u', 't', 's', '\n',
        'l', 'i', 'n', 'e', 'r', '\n',
        'l', 'i', 'n', 'e', 'r', 's', '\n',
        'l', 'i', 'n', 'e', 's', '\n',
        'l', 'i', 'n', 'e', 's', 'm', 'a', 'n', '\n',
        'l', 'i', 'n', 'e', 's', 'm', 'e', 'n', '\n',
        'l', 'i', 'n', 'e', 'u', 'p', '\n',
        'l', 'i', 'n', 'e', 'u', 'p', 's', '\n',
        'l', 'i', 'n', 'g', 'e', 'r', '\n',
        'l', 'i', 'n', 'g', 'e', 'r', 'e', 'd', '\n',
        'l', 'i', 'n', 'g', 'e', 'r', 'e', 'r', '\n',
        'l', 'i', 'n', 'g', 'e', 'r', 'i', 'e', '\n',
        'l', 'i', 'n', 'g', 'e', 'r', 'i', 'n', 'g', '\n',
        'l', 'i', 'n', 'g', 'e', 'r', 'i', 'n', 'g', 'l', 'y', '\n',
        'l', 'i', 'n', 'g', 'e', 'r', 's', '\n',
        'l', 'i', 'n', 'g', 'u', 'a', '\n',
        'l', 'i', 'n', 'g', 'u', 'a', 'l', '\n',
        'l', 'i', 'n', 'g', 'u', 'i', 's', 't', '\n',
        'l', 'i', 'n', 'g', 'u', 'i', 's', 't', 'i', 'c', '\n',
        'l', 'i', 'n', 'g', 'u', 'i', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'l', 'i', 'n', 'g', 'u', 'i', 's', 't', 'i', 'c', 's', '\n',
        'l', 'i', 'n', 'g', 'u', 'i', 's', 't', 's', '\n',
        'l', 'i', 'n', 'i', 'm', 'e', 'n', 't', '\n',
        'l', 'i', 'n', 'i', 'm', 'e', 'n', 't', 's', '\n',
        'l', 'i', 'n', 'i', 'n', 'g', '\n',
        'l', 'i', 'n', 'i', 'n', 'g', 's', '\n',
        'l', 'i', 'n', 'k', '\n',
        'l', 'i', 'n', 'k', 'a', 'b', 'l', 'e', '\n',
        'l', 'i', 'n', 'k', 'a', 'g', 'e', '\n',
        'l', 'i', 'n', 'k', 'a', 'g', 'e', 's', '\n',
        'l', 'i', 'n', 'k', 'e', 'd', '\n',
        'l', 'i', 'n', 'k', 'e', 'r', '\n',
        'l', 'i', 'n', 'k', 'e', 'r', 's', '\n',
        'l', 'i', 'n', 'k', 'i', 'n', 'g', '\n',
        'l', 'i', 'n', 'k', 's', '\n',
        'l', 'i', 'n', 'k', 'u', 'p', '\n',
        'l', 'i', 'n', 'k', 'u', 'p', 's', '\n',
        'l', 'i', 'n', 'n', 'e', 't', '\n',
        'l', 'i', 'n', 'n', 'e', 't', 's', '\n',
        'l', 'i', 'n', 'o', '\n',
        'l', 'i', 'n', 'o', 'l', 'e', 'u', 'm', '\n',
        'l', 'i', 'n', 's', 'e', 'e', 'd', '\n',
        'l', 'i', 'n', 't', '\n',
        'l', 'i', 'n', 't', 'e', 'l', '\n',
        'l', 'i', 'n', 't', 'e', 'l', 's', '\n',
        'l', 'i', 'n', 'y', '\n',
        'l', 'i', 'o', 'n', '\n',
        'l', 'i', 'o', 'n', 'e', 's', 's', '\n',
        'l', 'i', 'o', 'n', 'e', 's', 's', 'e', 's', '\n',
        'l', 'i', 'o', 'n', 'i', 's', 'e', '\n',
        'l', 'i', 'o', 'n', 'i', 's', 'e', 'd', '\n',
        'l', 'i', 'o', 'n', 's', '\n',
        'l', 'i', 'p', '\n',
        'l', 'i', 'p', 'a', 's', 'e', '\n',
        'l', 'i', 'p', 'i', 'd', '\n',
        'l', 'i', 'p', 'i', 'd', 's', '\n',
        'l', 'i', 'p', 'p', 'e', 'd', '\n',
        'l', 'i', 'p', 'r', 'e', 'a', 'd', '\n',
        'l', 'i', 'p', 'r', 'e', 'a', 'd', 'i', 'n', 'g', '\n',
        'l', 'i', 'p', 's', '\n',
        'l', 'i', 'p', 's', 'e', 'r', 'v', 'i', 'c', 'e', '\n',
        'l', 'i', 'p', 's', 't', 'i', 'c', 'k', '\n',
        'l', 'i', 'p', 's', 't', 'i', 'c', 'k', 's', '\n',
        'l', 'i', 'q', 'u', 'e', 'f', 'a', 'c', 't', 'i', 'o', 'n', '\n',
        'l', 'i', 'q', 'u', 'e', 'f', 'i', 'e', 'd', '\n',
        'l', 'i', 'q', 'u', 'e', 'f', 'y', '\n',
        'l', 'i', 'q', 'u', 'e', 'u', 'r', '\n',
        'l', 'i', 'q', 'u', 'e', 'u', 'r', 's', '\n',
        'l', 'i', 'q', 'u', 'i', 'd', '\n',
        'l', 'i', 'q', 'u', 'i', 'd', 'a', 't', 'e', '\n',
        'l', 'i', 'q', 'u', 'i', 'd', 'a', 't', 'e', 'd', '\n',
        'l', 'i', 'q', 'u', 'i', 'd', 'a', 't', 'i', 'n', 'g', '\n',
        'l', 'i', 'q', 'u', 'i', 'd', 'a', 't', 'i', 'o', 'n', '\n',
        'l', 'i', 'q', 'u', 'i', 'd', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'l', 'i', 'q', 'u', 'i', 'd', 'a', 't', 'o', 'r', '\n',
        'l', 'i', 'q', 'u', 'i', 'd', 'a', 't', 'o', 'r', 's', '\n',
        'l', 'i', 'q', 'u', 'i', 'd', 'i', 's', 'e', '\n',
        'l', 'i', 'q', 'u', 'i', 'd', 'i', 's', 'e', 'd', '\n',
        'l', 'i', 'q', 'u', 'i', 'd', 'i', 's', 'e', 'r', '\n',
        'l', 'i', 'q', 'u', 'i', 'd', 'i', 's', 'i', 'n', 'g', '\n',
        'l', 'i', 'q', 'u', 'i', 'd', 'i', 't', 'y', '\n',
        'l', 'i', 'q', 'u', 'i', 'd', 's', '\n',
        'l', 'i', 'q', 'u', 'i', 'f', 'y', '\n',
        'l', 'i', 'q', 'u', 'o', 'r', '\n',
        'l', 'i', 'q', 'u', 'o', 'r', 'i', 'c', 'e', '\n',
        'l', 'i', 'q', 'u', 'o', 'r', 'i', 's', 'h', '\n',
        'l', 'i', 'q', 'u', 'o', 'r', 's', '\n',
        'l', 'i', 'r', 'a', '\n',
        'l', 'i', 'r', 'e', '\n',
        'l', 'i', 's', 'b', 'o', 'n', '\n',
        'l', 'i', 's', 'p', '\n',
        'l', 'i', 's', 'p', 'e', 'd', '\n',
        'l', 'i', 's', 'p', 'i', 'n', 'g', '\n',
        'l', 'i', 's', 'p', 's', '\n',
        'l', 'i', 's', 's', 'o', 'm', '\n',
        'l', 'i', 's', 's', 'o', 'm', 'e', '\n',
        'l', 'i', 's', 's', 'o', 'm', 'e', 'n', 'e', 's', 's', '\n',
        'l', 'i', 's', 's', 'o', 'm', 'n', 'e', 's', 's', '\n',
        'l', 'i', 's', 't', '\n',
        'l', 'i', 's', 't', 'e', 'd', '\n',
        'l', 'i', 's', 't', 'e', 'n', '\n',
        'l', 'i', 's', 't', 'e', 'n', 'e', 'd', '\n',
        'l', 'i', 's', 't', 'e', 'n', 'e', 'r', '\n',
        'l', 'i', 's', 't', 'e', 'n', 'e', 'r', 's', '\n',
        'l', 'i', 's', 't', 'e', 'n', 'i', 'n', 'g', '\n',
        'l', 'i', 's', 't', 'e', 'n', 's', '\n',
        'l', 'i', 's', 't', 'e', 'r', 'i', 'a', '\n',
        'l', 'i', 's', 't', 'i', 'n', 'g', '\n',
        'l', 'i', 's', 't', 'i', 'n', 'g', 's', '\n',
        'l', 'i', 's', 't', 'l', 'e', 's', 's', '\n',
        'l', 'i', 's', 't', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'l', 'i', 's', 't', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'l', 'i', 's', 't', 's', '\n',
        'l', 'i', 't', '\n',
        'l', 'i', 't', 'a', 'n', 'i', 'e', 's', '\n',
        'l', 'i', 't', 'a', 'n', 'y', '\n',
        'l', 'i', 't', 'c', 'h', 'i', '\n',
        'l', 'i', 't', 'e', 'r', 'a', 'c', 'y', '\n',
        'l', 'i', 't', 'e', 'r', 'a', 'l', '\n',
        'l', 'i', 't', 'e', 'r', 'a', 'l', 'i', 's', 'm', '\n',
        'l', 'i', 't', 'e', 'r', 'a', 'l', 'i', 's', 't', 'i', 'c', '\n',
        'l', 'i', 't', 'e', 'r', 'a', 'l', 'l', 'y', '\n',
        'l', 'i', 't', 'e', 'r', 'a', 'l', 's', '\n',
        'l', 'i', 't', 'e', 'r', 'a', 'r', 'y', '\n',
        'l', 'i', 't', 'e', 'r', 'a', 't', 'e', '\n',
        'l', 'i', 't', 'e', 'r', 'a', 't', 'i', '\n',
        'l', 'i', 't', 'e', 'r', 'a', 't', 'u', 'r', 'e', '\n',
        'l', 'i', 't', 'e', 'r', 'a', 't', 'u', 'r', 'e', 's', '\n',
        'l', 'i', 't', 'h', 'e', '\n',
        'l', 'i', 't', 'h', 'e', 'l', 'y', '\n',
        'l', 'i', 't', 'h', 'i', 'u', 'm', '\n',
        'l', 'i', 't', 'h', 'o', 'g', 'r', 'a', 'p', 'h', '\n',
        'l', 'i', 't', 'h', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', '\n',
        'l', 'i', 't', 'h', 'o', 'g', 'r', 'a', 'p', 'h', 's', '\n',
        'l', 'i', 't', 'h', 'o', 'g', 'r', 'a', 'p', 'h', 'y', '\n',
        'l', 'i', 't', 'h', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'l', 'i', 't', 'h', 'o', 'l', 'o', 'g', 'i', 'e', 's', '\n',
        'l', 'i', 't', 'h', 'o', 'l', 'o', 'g', 'y', '\n',
        'l', 'i', 't', 'h', 'o', 's', 'p', 'h', 'e', 'r', 'e', '\n',
        'l', 'i', 't', 'i', 'g', 'a', 'n', 't', '\n',
        'l', 'i', 't', 'i', 'g', 'a', 'n', 't', 's', '\n',
        'l', 'i', 't', 'i', 'g', 'a', 't', 'e', '\n',
        'l', 'i', 't', 'i', 'g', 'a', 't', 'i', 'n', 'g', '\n',
        'l', 'i', 't', 'i', 'g', 'a', 't', 'i', 'o', 'n', '\n',
        'l', 'i', 't', 'i', 'g', 'i', 'o', 'u', 's', '\n',
        'l', 'i', 't', 'i', 'g', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'l', 'i', 't', 'm', 'u', 's', '\n',
        'l', 'i', 't', 'o', 't', 'e', 's', '\n',
        'l', 'i', 't', 'r', 'e', '\n',
        'l', 'i', 't', 'r', 'e', 's', '\n',
        'l', 'i', 't', 't', 'e', 'r', '\n',
        'l', 'i', 't', 't', 'e', 'r', 'e', 'd', '\n',
        'l', 'i', 't', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'l', 'i', 't', 't', 'e', 'r', 's', '\n',
        'l', 'i', 't', 't', 'l', 'e', '\n',
        'l', 'i', 't', 't', 'l', 'e', 'n', 'e', 's', 's', '\n',
        'l', 'i', 't', 't', 'l', 'e', 'r', '\n',
        'l', 'i', 't', 't', 'l', 'e', 's', 't', '\n',
        'l', 'i', 't', 't', 'o', 'r', 'a', 'l', '\n',
        'l', 'i', 't', 'u', 'r', 'g', 'i', 'c', 'a', 'l', '\n',
        'l', 'i', 't', 'u', 'r', 'g', 'i', 'e', 's', '\n',
        'l', 'i', 't', 'u', 'r', 'g', 'y', '\n',
        'l', 'i', 'v', 'a', 'b', 'l', 'e', '\n',
        'l', 'i', 'v', 'e', '\n',
        'l', 'i', 'v', 'e', 'a', 'b', 'l', 'e', '\n',
        'l', 'i', 'v', 'e', 'd', '\n',
        'l', 'i', 'v', 'e', 'l', 'i', 'e', 'r', '\n',
        'l', 'i', 'v', 'e', 'l', 'i', 'e', 's', 't', '\n',
        'l', 'i', 'v', 'e', 'l', 'i', 'h', 'o', 'o', 'd', '\n',
        'l', 'i', 'v', 'e', 'l', 'i', 'h', 'o', 'o', 'd', 's', '\n',
        'l', 'i', 'v', 'e', 'l', 'i', 'n', 'e', 's', 's', '\n',
        'l', 'i', 'v', 'e', 'l', 'y', '\n',
        'l', 'i', 'v', 'e', 'n', '\n',
        'l', 'i', 'v', 'e', 'n', 'e', 'd', '\n',
        'l', 'i', 'v', 'e', 'n', 'i', 'n', 'g', '\n',
        'l', 'i', 'v', 'e', 'n', 's', '\n',
        'l', 'i', 'v', 'e', 'r', '\n',
        'l', 'i', 'v', 'e', 'r', 'i', 'e', 'd', '\n',
        'l', 'i', 'v', 'e', 'r', 'i', 'e', 's', '\n',
        'l', 'i', 'v', 'e', 'r', 'i', 's', 'h', '\n',
        'l', 'i', 'v', 'e', 'r', 's', '\n',
        'l', 'i', 'v', 'e', 'r', 'w', 'o', 'r', 't', 's', '\n',
        'l', 'i', 'v', 'e', 'r', 'y', '\n',
        'l', 'i', 'v', 'e', 's', '\n',
        'l', 'i', 'v', 'e', 's', 't', 'o', 'c', 'k', '\n',
        'l', 'i', 'v', 'e', 'w', 'i', 'r', 'e', '\n',
        'l', 'i', 'v', 'i', 'd', '\n',
        'l', 'i', 'v', 'i', 'd', 'l', 'y', '\n',
        'l', 'i', 'v', 'i', 'n', 'g', '\n',
        'l', 'i', 'v', 'i', 'n', 'g', 's', '\n',
        'l', 'i', 'z', 'a', 'r', 'd', '\n',
        'l', 'i', 'z', 'a', 'r', 'd', 's', '\n',
        'l', 'l', 'a', 'm', 'a', '\n',
        'l', 'l', 'a', 'm', 'a', 's', '\n',
        'l', 'l', 's', '\n',
        'l', 'o', 'a', 'd', '\n',
        'l', 'o', 'a', 'd', 'a', 'b', 'l', 'e', '\n',
        'l', 'o', 'a', 'd', 'e', 'd', '\n',
        'l', 'o', 'a', 'd', 'e', 'r', '\n',
        'l', 'o', 'a', 'd', 'e', 'r', 's', '\n',
        'l', 'o', 'a', 'd', 'i', 'n', 'g', '\n',
        'l', 'o', 'a', 'd', 'i', 'n', 'g', 's', '\n',
        'l', 'o', 'a', 'd', 's', '\n',
        'l', 'o', 'a', 'f', '\n',
        'l', 'o', 'a', 'f', 'e', 'd', '\n',
        'l', 'o', 'a', 'f', 'e', 'r', '\n',
        'l', 'o', 'a', 'f', 'e', 'r', 's', '\n',
        'l', 'o', 'a', 'f', 'i', 'n', 'g', '\n',
        'l', 'o', 'a', 'f', 's', '\n',
        'l', 'o', 'a', 'm', '\n',
        'l', 'o', 'a', 'm', 's', '\n',
        'l', 'o', 'a', 'm', 'y', '\n',
        'l', 'o', 'a', 'n', '\n',
        'l', 'o', 'a', 'n', 'a', 'b', 'l', 'e', '\n',
        'l', 'o', 'a', 'n', 'e', 'd', '\n',
        'l', 'o', 'a', 'n', 'e', 'r', '\n',
        'l', 'o', 'a', 'n', 'i', 'n', 'g', '\n',
        'l', 'o', 'a', 'n', 's', '\n',
        'l', 'o', 'a', 'n', 'w', 'o', 'r', 'd', '\n',
        'l', 'o', 'a', 'n', 'w', 'o', 'r', 'd', 's', '\n',
        'l', 'o', 'a', 't', 'h', '\n',
        'l', 'o', 'a', 't', 'h', 'e', '\n',
        'l', 'o', 'a', 't', 'h', 'e', 'd', '\n',
        'l', 'o', 'a', 't', 'h', 'e', 's', '\n',
        'l', 'o', 'a', 't', 'h', 'i', 'n', 'g', '\n',
        'l', 'o', 'a', 't', 'h', 's', 'o', 'm', 'e', '\n',
        'l', 'o', 'a', 't', 'h', 's', 'o', 'm', 'e', 'l', 'y', '\n',
        'l', 'o', 'a', 't', 'h', 's', 'o', 'm', 'e', 'n', 'e', 's', 's', '\n',
        'l', 'o', 'a', 'v', 'e', 's', '\n',
        'l', 'o', 'b', '\n',
        'l', 'o', 'b', 'b', 'e', 'd', '\n',
        'l', 'o', 'b', 'b', 'i', 'e', 'd', '\n',
        'l', 'o', 'b', 'b', 'i', 'e', 's', '\n',
        'l', 'o', 'b', 'b', 'i', 'n', 'g', '\n',
        'l', 'o', 'b', 'b', 'y', '\n',
        'l', 'o', 'b', 'b', 'y', 'i', 'n', 'g', '\n',
        'l', 'o', 'b', 'b', 'y', 'i', 's', 't', '\n',
        'l', 'o', 'b', 'b', 'y', 'i', 's', 't', 's', '\n',
        'l', 'o', 'b', 'e', '\n',
        'l', 'o', 'b', 'e', 'd', '\n',
        'l', 'o', 'b', 'e', 'l', 'i', 'a', '\n',
        'l', 'o', 'b', 'e', 's', '\n',
        'l', 'o', 'b', 'o', 't', 'o', 'm', 'i', 'e', 's', '\n',
        'l', 'o', 'b', 'o', 't', 'o', 'm', 'i', 's', 'e', 'd', '\n',
        'l', 'o', 'b', 'o', 't', 'o', 'm', 'i', 's', 'i', 'n', 'g', '\n',
        'l', 'o', 'b', 'o', 't', 'o', 'm', 'i', 's', 't', '\n',
        'l', 'o', 'b', 'o', 't', 'o', 'm', 'y', '\n',
        'l', 'o', 'b', 's', '\n',
        'l', 'o', 'b', 's', 't', 'e', 'r', '\n',
        'l', 'o', 'b', 's', 't', 'e', 'r', 's', '\n',
        'l', 'o', 'b', 'u', 'l', 'a', 'r', '\n',
        'l', 'o', 'c', 'a', 'l', '\n',
        'l', 'o', 'c', 'a', 'l', 'e', '\n',
        'l', 'o', 'c', 'a', 'l', 'e', 's', '\n',
        'l', 'o', 'c', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'l', 'o', 'c', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'l', 'o', 'c', 'a', 'l', 'i', 's', 'e', '\n',
        'l', 'o', 'c', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'l', 'o', 'c', 'a', 'l', 'i', 's', 'e', 's', '\n',
        'l', 'o', 'c', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'l', 'o', 'c', 'a', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'l', 'o', 'c', 'a', 'l', 'i', 't', 'y', '\n',
        'l', 'o', 'c', 'a', 'l', 'l', 'y', '\n',
        'l', 'o', 'c', 'a', 'l', 's', '\n',
        'l', 'o', 'c', 'a', 't', 'a', 'b', 'l', 'e', '\n',
        'l', 'o', 'c', 'a', 't', 'e', '\n',
        'l', 'o', 'c', 'a', 't', 'e', 'd', '\n',
        'l', 'o', 'c', 'a', 't', 'e', 's', '\n',
        'l', 'o', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'l', 'o', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'l', 'o', 'c', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'l', 'o', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'l', 'o', 'c', 'a', 't', 'i', 'v', 'e', '\n',
        'l', 'o', 'c', 'a', 't', 'o', 'r', '\n',
        'l', 'o', 'c', 'a', 't', 'o', 'r', 's', '\n',
        'l', 'o', 'c', 'h', '\n',
        'l', 'o', 'c', 'h', 'n', 'e', 's', 's', '\n',
        'l', 'o', 'c', 'h', 's', '\n',
        'l', 'o', 'c', 'i', '\n',
        'l', 'o', 'c', 'k', '\n',
        'l', 'o', 'c', 'k', 'a', 'b', 'l', 'e', '\n',
        'l', 'o', 'c', 'k', 'a', 'g', 'e', '\n',
        'l', 'o', 'c', 'k', 'e', 'd', '\n',
        'l', 'o', 'c', 'k', 'e', 'r', '\n',
        'l', 'o', 'c', 'k', 'e', 'r', 's', '\n',
        'l', 'o', 'c', 'k', 'e', 't', '\n',
        'l', 'o', 'c', 'k', 'i', 'n', 'g', '\n',
        'l', 'o', 'c', 'k', 'j', 'a', 'w', '\n',
        'l', 'o', 'c', 'k', 'o', 'u', 't', '\n',
        'l', 'o', 'c', 'k', 'o', 'u', 't', 's', '\n',
        'l', 'o', 'c', 'k', 's', '\n',
        'l', 'o', 'c', 'k', 's', 'm', 'i', 't', 'h', '\n',
        'l', 'o', 'c', 'o', '\n',
        'l', 'o', 'c', 'o', 'm', 'o', 't', 'e', '\n',
        'l', 'o', 'c', 'o', 'm', 'o', 't', 'i', 'o', 'n', '\n',
        'l', 'o', 'c', 'o', 'm', 'o', 't', 'i', 'v', 'e', '\n',
        'l', 'o', 'c', 'o', 'm', 'o', 't', 'i', 'v', 'e', 's', '\n',
        'l', 'o', 'c', 'u', 's', '\n',
        'l', 'o', 'c', 'u', 's', 't', '\n',
        'l', 'o', 'c', 'u', 's', 't', 's', '\n',
        'l', 'o', 'd', 'e', '\n',
        'l', 'o', 'd', 'e', 's', 't', 'a', 'r', '\n',
        'l', 'o', 'd', 'e', 's', 't', 'o', 'n', 'e', '\n',
        'l', 'o', 'd', 'g', 'e', '\n',
        'l', 'o', 'd', 'g', 'e', 'd', '\n',
        'l', 'o', 'd', 'g', 'e', 'm', 'e', 'n', 't', '\n',
        'l', 'o', 'd', 'g', 'e', 'r', '\n',
        'l', 'o', 'd', 'g', 'e', 'r', 's', '\n',
        'l', 'o', 'd', 'g', 'e', 's', '\n',
        'l', 'o', 'd', 'g', 'i', 'n', 'g', '\n',
        'l', 'o', 'd', 'g', 'i', 'n', 'g', 's', '\n',
        'l', 'o', 'e', 's', 's', '\n',
        'l', 'o', 'f', 't', '\n',
        'l', 'o', 'f', 't', 'e', 'd', '\n',
        'l', 'o', 'f', 't', 'i', 'e', 'r', '\n',
        'l', 'o', 'f', 't', 'i', 'e', 's', 't', '\n',
        'l', 'o', 'f', 't', 'i', 'l', 'y', '\n',
        'l', 'o', 'f', 't', 'i', 'n', 'e', 's', 's', '\n',
        'l', 'o', 'f', 't', 's', '\n',
        'l', 'o', 'f', 't', 'y', '\n',
        'l', 'o', 'g', '\n',
        'l', 'o', 'g', 'a', 'n', 'b', 'e', 'r', 'r', 'i', 'e', 's', '\n',
        'l', 'o', 'g', 'a', 'n', 'b', 'e', 'r', 'r', 'y', '\n',
        'l', 'o', 'g', 'a', 'r', 'i', 't', 'h', 'm', '\n',
        'l', 'o', 'g', 'a', 'r', 'i', 't', 'h', 'm', 'i', 'c', '\n',
        'l', 'o', 'g', 'a', 'r', 'i', 't', 'h', 'm', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'l', 'o', 'g', 'a', 'r', 'i', 't', 'h', 'm', 's', '\n',
        'l', 'o', 'g', 'b', 'o', 'o', 'k', '\n',
        'l', 'o', 'g', 'b', 'o', 'o', 'k', 's', '\n',
        'l', 'o', 'g', 'g', 'e', 'd', '\n',
        'l', 'o', 'g', 'g', 'e', 'r', '\n',
        'l', 'o', 'g', 'g', 'e', 'r', 'h', 'e', 'a', 'd', 's', '\n',
        'l', 'o', 'g', 'g', 'e', 'r', 's', '\n',
        'l', 'o', 'g', 'g', 'i', 'n', 'g', '\n',
        'l', 'o', 'g', 'i', 'c', '\n',
        'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'l', 'o', 'g', 'i', 'c', 'a', 'l', 'i', 't', 'y', '\n',
        'l', 'o', 'g', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'l', 'o', 'g', 'i', 'c', 'i', 'a', 'n', '\n',
        'l', 'o', 'g', 'i', 'c', 'i', 'a', 'n', 's', '\n',
        'l', 'o', 'g', 'i', 'c', 's', '\n',
        'l', 'o', 'g', 'i', 's', 't', 'i', 'c', '\n',
        'l', 'o', 'g', 'i', 's', 't', 'i', 'c', 'a', 'l', '\n',
        'l', 'o', 'g', 'i', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'l', 'o', 'g', 'i', 's', 't', 'i', 'c', 's', '\n',
        'l', 'o', 'g', 'j', 'a', 'm', '\n',
        'l', 'o', 'g', 'o', '\n',
        'l', 'o', 'g', 'o', 'f', 'f', '\n',
        'l', 'o', 'g', 'o', 's', '\n',
        'l', 'o', 'g', 's', '\n',
        'l', 'o', 'i', 'n', '\n',
        'l', 'o', 'i', 'n', 'c', 'l', 'o', 't', 'h', '\n',
        'l', 'o', 'i', 'n', 's', '\n',
        'l', 'o', 'i', 'r', 'e', '\n',
        'l', 'o', 'i', 't', 'e', 'r', '\n',
        'l', 'o', 'i', 't', 'e', 'r', 'e', 'd', '\n',
        'l', 'o', 'i', 't', 'e', 'r', 'e', 'r', '\n',
        'l', 'o', 'i', 't', 'e', 'r', 'e', 'r', 's', '\n',
        'l', 'o', 'i', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'l', 'o', 'i', 't', 'e', 'r', 's', '\n',
        'l', 'o', 'l', 'l', '\n',
        'l', 'o', 'l', 'l', 'e', 'd', '\n',
        'l', 'o', 'l', 'l', 'i', 'e', 's', '\n',
        'l', 'o', 'l', 'l', 'i', 'n', 'g', '\n',
        'l', 'o', 'l', 'l', 'i', 'p', 'o', 'p', '\n',
        'l', 'o', 'l', 'l', 'i', 'p', 'o', 'p', 's', '\n',
        'l', 'o', 'l', 'l', 'y', '\n',
        'l', 'o', 'n', 'd', 'o', 'n', '\n',
        'l', 'o', 'n', 'd', 'o', 'n', 'e', 'r', '\n',
        'l', 'o', 'n', 'e', '\n',
        'l', 'o', 'n', 'e', 'l', 'i', 'e', 'r', '\n',
        'l', 'o', 'n', 'e', 'l', 'i', 'e', 's', 't', '\n',
        'l', 'o', 'n', 'e', 'l', 'i', 'n', 'e', 's', 's', '\n',
        'l', 'o', 'n', 'e', 'l', 'y', '\n',
        'l', 'o', 'n', 'e', 'r', '\n',
        'l', 'o', 'n', 'e', 'r', 's', '\n',
        'l', 'o', 'n', 'e', 's', 'o', 'm', 'e', '\n',
        'l', 'o', 'n', 'e', 's', 'o', 'm', 'e', 'n', 'e', 's', 's', '\n',
        'l', 'o', 'n', 'g', '\n',
        'l', 'o', 'n', 'g', 'a', 'w', 'a', 'i', 't', 'e', 'd', '\n',
        'l', 'o', 'n', 'g', 'e', 'd', '\n',
        'l', 'o', 'n', 'g', 'e', 'r', '\n',
        'l', 'o', 'n', 'g', 'e', 's', 't', '\n',
        'l', 'o', 'n', 'g', 'e', 'v', 'i', 't', 'y', '\n',
        'l', 'o', 'n', 'g', 'f', 'a', 'c', 'e', 'd', '\n',
        'l', 'o', 'n', 'g', 'h', 'a', 'n', 'd', '\n',
        'l', 'o', 'n', 'g', 'i', 'n', 'g', '\n',
        'l', 'o', 'n', 'g', 'i', 'n', 'g', 'l', 'y', '\n',
        'l', 'o', 'n', 'g', 'i', 'n', 'g', 's', '\n',
        'l', 'o', 'n', 'g', 'i', 's', 'h', '\n',
        'l', 'o', 'n', 'g', 'i', 't', 'u', 'd', 'e', '\n',
        'l', 'o', 'n', 'g', 'i', 't', 'u', 'd', 'e', 's', '\n',
        'l', 'o', 'n', 'g', 'i', 't', 'u', 'd', 'i', 'n', 'a', 'l', '\n',
        'l', 'o', 'n', 'g', 'i', 't', 'u', 'd', 'i', 'n', 'a', 'l', 'l', 'y', '\n',
        'l', 'o', 'n', 'g', 'l', 'a', 's', 't', 'i', 'n', 'g', '\n',
        'l', 'o', 'n', 'g', 'l', 'i', 'v', 'e', 'd', '\n',
        'l', 'o', 'n', 'g', 'l', 'o', 's', 't', '\n',
        'l', 'o', 'n', 'g', 's', '\n',
        'l', 'o', 'n', 'g', 's', 't', 'a', 'n', 'd', 'i', 'n', 'g', '\n',
        'l', 'o', 'n', 'g', 's', 'u', 'f', 'f', 'e', 'r', 'i', 'n', 'g', '\n',
        'l', 'o', 'n', 'g', 'w', 'i', 'n', 'd', 'e', 'd', '\n',
        'l', 'o', 'n', 'g', 'w', 'i', 'n', 'd', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'l', 'o', 'o', '\n',
        'l', 'o', 'o', 'k', '\n',
        'l', 'o', 'o', 'k', 'a', 'l', 'i', 'k', 'e', '\n',
        'l', 'o', 'o', 'k', 'a', 'l', 'i', 'k', 'e', 's', '\n',
        'l', 'o', 'o', 'k', 'e', 'd', '\n',
        'l', 'o', 'o', 'k', 'e', 'r', '\n',
        'l', 'o', 'o', 'k', 'e', 'r', 's', '\n',
        'l', 'o', 'o', 'k', 'i', 'n', 'g', '\n',
        'l', 'o', 'o', 'k', 'i', 'n', 'g', 'g', 'l', 'a', 's', 's', '\n',
        'l', 'o', 'o', 'k', 'i', 'n', 'g', 'g', 'l', 'a', 's', 's', 'e', 's', '\n',
        'l', 'o', 'o', 'k', 'o', 'u', 't', '\n',
        'l', 'o', 'o', 'k', 'o', 'u', 't', 's', '\n',
        'l', 'o', 'o', 'k', 's', '\n',
        'l', 'o', 'o', 'm', '\n',
        'l', 'o', 'o', 'm', 'e', 'd', '\n',
        'l', 'o', 'o', 'm', 'i', 'n', 'g', '\n',
        'l', 'o', 'o', 'm', 's', '\n',
        'l', 'o', 'o', 'n', '\n',
        'l', 'o', 'o', 'n', 'e', 'y', '\n',
        'l', 'o', 'o', 'n', 'y', '\n',
        'l', 'o', 'o', 'p', '\n',
        'l', 'o', 'o', 'p', 'e', 'd', '\n',
        'l', 'o', 'o', 'p', 'h', 'o', 'l', 'e', '\n',
        'l', 'o', 'o', 'p', 'h', 'o', 'l', 'e', 's', '\n',
        'l', 'o', 'o', 'p', 'i', 'n', 'g', '\n',
        'l', 'o', 'o', 'p', 's', '\n',
        'l', 'o', 'o', 'p', 'y', '\n',
        'l', 'o', 'o', 's', 'e', '\n',
        'l', 'o', 'o', 's', 'e', 'd', '\n',
        'l', 'o', 'o', 's', 'e', 'l', 'y', '\n',
        'l', 'o', 'o', 's', 'e', 'n', '\n',
        'l', 'o', 'o', 's', 'e', 'n', 'e', 'd', '\n',
        'l', 'o', 'o', 's', 'e', 'n', 'e', 's', 's', '\n',
        'l', 'o', 'o', 's', 'e', 'n', 'i', 'n', 'g', '\n',
        'l', 'o', 'o', 's', 'e', 'n', 's', '\n',
        'l', 'o', 'o', 's', 'e', 'r', '\n',
        'l', 'o', 'o', 's', 'e', 's', '\n',
        'l', 'o', 'o', 's', 'e', 's', 't', '\n',
        'l', 'o', 'o', 's', 'i', 'n', 'g', '\n',
        'l', 'o', 'o', 't', '\n',
        'l', 'o', 'o', 't', 'e', 'd', '\n',
        'l', 'o', 'o', 't', 'e', 'r', '\n',
        'l', 'o', 'o', 't', 'e', 'r', 's', '\n',
        'l', 'o', 'o', 't', 'i', 'n', 'g', '\n',
        'l', 'o', 'o', 't', 's', '\n',
        'l', 'o', 'p', '\n',
        'l', 'o', 'p', 'e', '\n',
        'l', 'o', 'p', 'e', 'd', '\n',
        'l', 'o', 'p', 'e', 's', '\n',
        'l', 'o', 'p', 'i', 'n', 'g', '\n',
        'l', 'o', 'p', 'p', 'e', 'd', '\n',
        'l', 'o', 'p', 'p', 'e', 'r', '\n',
        'l', 'o', 'p', 'p', 'e', 'r', 's', '\n',
        'l', 'o', 'p', 'p', 'i', 'n', 'g', '\n',
        'l', 'o', 'p', 's', 'i', 'd', 'e', 'd', '\n',
        'l', 'o', 'p', 's', 'i', 'd', 'e', 'd', 'l', 'y', '\n',
        'l', 'o', 'q', 'u', 'a', 'c', 'i', 'o', 'u', 's', '\n',
        'l', 'o', 'q', 'u', 'a', 'c', 'i', 't', 'y', '\n',
        'l', 'o', 'r', 'd', '\n',
        'l', 'o', 'r', 'd', 'i', 'n', 'g', '\n',
        'l', 'o', 'r', 'd', 'l', 'y', '\n',
        'l', 'o', 'r', 'd', 's', '\n',
        'l', 'o', 'r', 'd', 's', 'h', 'i', 'p', '\n',
        'l', 'o', 'r', 'd', 's', 'h', 'i', 'p', 's', '\n',
        'l', 'o', 'r', 'e', '\n',
        'l', 'o', 'r', 'e', 'l', 'e', 'i', '\n',
        'l', 'o', 'r', 'r', 'i', 'e', 's', '\n',
        'l', 'o', 'r', 'r', 'y', '\n',
        'l', 'o', 'r', 'r', 'y', 'l', 'o', 'a', 'd', '\n',
        'l', 'o', 'r', 'r', 'y', 'l', 'o', 'a', 'd', 's', '\n',
        'l', 'o', 's', 'a', 'b', 'l', 'e', '\n',
        'l', 'o', 's', 'e', '\n',
        'l', 'o', 's', 'e', 'r', '\n',
        'l', 'o', 's', 'e', 'r', 's', '\n',
        'l', 'o', 's', 'e', 's', '\n',
        'l', 'o', 's', 'i', 'n', 'g', '\n',
        'l', 'o', 's', 'i', 'n', 'g', 's', '\n',
        'l', 'o', 's', 's', '\n',
        'l', 'o', 's', 's', 'e', 's', '\n',
        'l', 'o', 's', 't', '\n',
        'l', 'o', 't', '\n',
        'l', 'o', 't', 'h', '\n',
        'l', 'o', 't', 'i', 'o', 'n', '\n',
        'l', 'o', 't', 'i', 'o', 'n', 's', '\n',
        'l', 'o', 't', 's', '\n',
        'l', 'o', 't', 't', 'e', 'r', 'i', 'e', 's', '\n',
        'l', 'o', 't', 't', 'e', 'r', 'y', '\n',
        'l', 'o', 't', 't', 'o', '\n',
        'l', 'o', 't', 'u', 's', '\n',
        'l', 'o', 'u', 'c', 'h', 'e', '\n',
        'l', 'o', 'u', 'd', '\n',
        'l', 'o', 'u', 'd', 'e', 'r', '\n',
        'l', 'o', 'u', 'd', 'e', 's', 't', '\n',
        'l', 'o', 'u', 'd', 'h', 'a', 'i', 'l', 'e', 'r', '\n',
        'l', 'o', 'u', 'd', 'h', 'a', 'i', 'l', 'e', 'r', 's', '\n',
        'l', 'o', 'u', 'd', 'l', 'y', '\n',
        'l', 'o', 'u', 'd', 'm', 'o', 'u', 't', 'h', 'e', 'd', '\n',
        'l', 'o', 'u', 'd', 'n', 'e', 's', 's', '\n',
        'l', 'o', 'u', 'd', 's', 'p', 'e', 'a', 'k', 'e', 'r', '\n',
        'l', 'o', 'u', 'd', 's', 'p', 'e', 'a', 'k', 'e', 'r', 's', '\n',
        'l', 'o', 'u', 'i', 's', '\n',
        'l', 'o', 'u', 'n', 'g', 'e', '\n',
        'l', 'o', 'u', 'n', 'g', 'e', 'd', '\n',
        'l', 'o', 'u', 'n', 'g', 'e', 'r', '\n',
        'l', 'o', 'u', 'n', 'g', 'e', 'r', 's', '\n',
        'l', 'o', 'u', 'n', 'g', 'e', 's', '\n',
        'l', 'o', 'u', 'n', 'g', 'i', 'n', 'g', '\n',
        'l', 'o', 'u', 's', 'e', '\n',
        'l', 'o', 'u', 's', 'i', 'e', 's', 't', '\n',
        'l', 'o', 'u', 's', 'i', 'l', 'y', '\n',
        'l', 'o', 'u', 's', 'y', '\n',
        'l', 'o', 'u', 't', '\n',
        'l', 'o', 'u', 't', 'i', 's', 'h', '\n',
        'l', 'o', 'u', 't', 'i', 's', 'h', 'n', 'e', 's', 's', '\n',
        'l', 'o', 'u', 't', 's', '\n',
        'l', 'o', 'u', 'v', 'e', 'r', '\n',
        'l', 'o', 'u', 'v', 'e', 'r', 's', '\n',
        'l', 'o', 'u', 'v', 'r', 'e', '\n',
        'l', 'o', 'u', 'v', 'r', 'e', 'd', '\n',
        'l', 'o', 'u', 'v', 'r', 'e', 's', '\n',
        'l', 'o', 'v', 'a', 'b', 'l', 'e', '\n',
        'l', 'o', 'v', 'e', '\n',
        'l', 'o', 'v', 'e', 'a', 'b', 'l', 'e', '\n',
        'l', 'o', 'v', 'e', 'b', 'i', 'r', 'd', 's', '\n',
        'l', 'o', 'v', 'e', 'd', '\n',
        'l', 'o', 'v', 'e', 'l', 'e', 's', 's', '\n',
        'l', 'o', 'v', 'e', 'l', 'i', 'e', 'r', '\n',
        'l', 'o', 'v', 'e', 'l', 'i', 'e', 's', '\n',
        'l', 'o', 'v', 'e', 'l', 'i', 'e', 's', 't', '\n',
        'l', 'o', 'v', 'e', 'l', 'i', 'n', 'e', 's', 's', '\n',
        'l', 'o', 'v', 'e', 'l', 'o', 'r', 'n', '\n',
        'l', 'o', 'v', 'e', 'l', 'y', '\n',
        'l', 'o', 'v', 'e', 'm', 'a', 'k', 'i', 'n', 'g', '\n',
        'l', 'o', 'v', 'e', 'r', '\n',
        'l', 'o', 'v', 'e', 'r', 's', '\n',
        'l', 'o', 'v', 'e', 's', '\n',
        'l', 'o', 'v', 'e', 's', 'i', 'c', 'k', '\n',
        'l', 'o', 'v', 'e', 's', 't', 'r', 'u', 'c', 'k', '\n',
        'l', 'o', 'v', 'i', 'n', 'g', '\n',
        'l', 'o', 'v', 'i', 'n', 'g', 'l', 'y', '\n',
        'l', 'o', 'w', '\n',
        'l', 'o', 'w', 'e', 'r', '\n',
        'l', 'o', 'w', 'e', 'r', 'c', 'a', 's', 'e', '\n',
        'l', 'o', 'w', 'e', 'r', 'e', 'd', '\n',
        'l', 'o', 'w', 'e', 'r', 'i', 'n', 'g', '\n',
        'l', 'o', 'w', 'e', 'r', 's', '\n',
        'l', 'o', 'w', 'e', 's', 't', '\n',
        'l', 'o', 'w', 'i', 'n', 'g', '\n',
        'l', 'o', 'w', 'i', 's', 'h', '\n',
        'l', 'o', 'w', 'k', 'e', 'y', '\n',
        'l', 'o', 'w', 'l', 'a', 'n', 'd', '\n',
        'l', 'o', 'w', 'l', 'a', 'n', 'd', 'e', 'r', 's', '\n',
        'l', 'o', 'w', 'l', 'a', 'n', 'd', 's', '\n',
        'l', 'o', 'w', 'l', 'i', 'e', 'r', '\n',
        'l', 'o', 'w', 'l', 'i', 'e', 's', 't', '\n',
        'l', 'o', 'w', 'l', 'y', '\n',
        'l', 'o', 'w', 'l', 'y', 'i', 'n', 'g', '\n',
        'l', 'o', 'w', 'n', 'e', 's', 's', '\n',
        'l', 'o', 'w', 'p', 'i', 't', 'c', 'h', 'e', 'd', '\n',
        'l', 'o', 'w', 's', '\n',
        'l', 'o', 'w', 's', 'p', 'i', 'r', 'i', 't', 'e', 'd', '\n',
        'l', 'o', 'y', 'a', 'l', '\n',
        'l', 'o', 'y', 'a', 'l', 'i', 's', 't', '\n',
        'l', 'o', 'y', 'a', 'l', 'i', 's', 't', 's', '\n',
        'l', 'o', 'y', 'a', 'l', 'l', 'y', '\n',
        'l', 'o', 'y', 'a', 'l', 't', 'i', 'e', 's', '\n',
        'l', 'o', 'y', 'a', 'l', 't', 'y', '\n',
        'l', 'o', 'z', 'e', 'n', 'g', 'e', '\n',
        'l', 'o', 'z', 'e', 'n', 'g', 'e', 's', '\n',
        'l', 'u', 'a', 'n', 'd', 'a', '\n',
        'l', 'u', 'b', 'b', 'e', 'r', '\n',
        'l', 'u', 'b', 'b', 'e', 'r', 's', '\n',
        'l', 'u', 'b', 'r', 'i', 'c', 'a', 'n', 't', '\n',
        'l', 'u', 'b', 'r', 'i', 'c', 'a', 'n', 't', 's', '\n',
        'l', 'u', 'b', 'r', 'i', 'c', 'a', 't', 'e', '\n',
        'l', 'u', 'b', 'r', 'i', 'c', 'a', 't', 'e', 'd', '\n',
        'l', 'u', 'b', 'r', 'i', 'c', 'a', 't', 'e', 's', '\n',
        'l', 'u', 'b', 'r', 'i', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'l', 'u', 'b', 'r', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'l', 'u', 'b', 'r', 'i', 'c', 'i', 'o', 'u', 's', '\n',
        'l', 'u', 'c', 'i', 'd', '\n',
        'l', 'u', 'c', 'i', 'd', 'i', 't', 'y', '\n',
        'l', 'u', 'c', 'i', 'd', 'l', 'y', '\n',
        'l', 'u', 'c', 'i', 'f', 'e', 'r', '\n',
        'l', 'u', 'c', 'k', '\n',
        'l', 'u', 'c', 'k', 'i', 'e', 'r', '\n',
        'l', 'u', 'c', 'k', 'i', 'e', 's', 't', '\n',
        'l', 'u', 'c', 'k', 'i', 'l', 'y', '\n',
        'l', 'u', 'c', 'k', 'l', 'e', 's', 's', '\n',
        'l', 'u', 'c', 'k', 'y', '\n',
        'l', 'u', 'c', 'r', 'a', 't', 'i', 'v', 'e', '\n',
        'l', 'u', 'c', 'r', 'e', '\n',
        'l', 'u', 'd', 'i', 'c', 'r', 'o', 'u', 's', '\n',
        'l', 'u', 'd', 'i', 'c', 'r', 'o', 'u', 's', 'l', 'y', '\n',
        'l', 'u', 'd', 'i', 'c', 'r', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'l', 'u', 'd', 'o', '\n',
        'l', 'u', 'g', '\n',
        'l', 'u', 'g', 'g', 'a', 'g', 'e', '\n',
        'l', 'u', 'g', 'g', 'e', 'd', '\n',
        'l', 'u', 'g', 'g', 'i', 'n', 'g', '\n',
        'l', 'u', 'g', 's', '\n',
        'l', 'u', 'g', 'u', 'b', 'r', 'i', 'o', 'u', 's', '\n',
        'l', 'u', 'g', 'u', 'b', 'r', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'l', 'u', 'k', 'e', '\n',
        'l', 'u', 'k', 'e', 'w', 'a', 'r', 'm', '\n',
        'l', 'u', 'l', 'l', '\n',
        'l', 'u', 'l', 'l', 'a', 'b', 'i', 'e', 's', '\n',
        'l', 'u', 'l', 'l', 'a', 'b', 'y', '\n',
        'l', 'u', 'l', 'l', 'e', 'd', '\n',
        'l', 'u', 'l', 'l', 'i', 'n', 'g', '\n',
        'l', 'u', 'l', 'l', 's', '\n',
        'l', 'u', 'l', 'u', '\n',
        'l', 'u', 'm', 'b', 'a', 'g', 'o', '\n',
        'l', 'u', 'm', 'b', 'a', 'r', '\n',
        'l', 'u', 'm', 'b', 'e', 'r', '\n',
        'l', 'u', 'm', 'b', 'e', 'r', 'e', 'd', '\n',
        'l', 'u', 'm', 'b', 'e', 'r', 'i', 'n', 'g', '\n',
        'l', 'u', 'm', 'b', 'e', 'r', 'j', 'a', 'c', 'k', '\n',
        'l', 'u', 'm', 'b', 'e', 'r', 'j', 'a', 'c', 'k', 's', '\n',
        'l', 'u', 'm', 'b', 'e', 'r', 's', '\n',
        'l', 'u', 'm', 'e', 'n', '\n',
        'l', 'u', 'm', 'i', 'n', 'a', 'l', '\n',
        'l', 'u', 'm', 'i', 'n', 'a', 'n', 'c', 'e', '\n',
        'l', 'u', 'm', 'i', 'n', 'a', 'r', 'i', 'e', 's', '\n',
        'l', 'u', 'm', 'i', 'n', 'a', 'r', 'y', '\n',
        'l', 'u', 'm', 'i', 'n', 'e', 's', 'c', 'e', 'n', 'c', 'e', '\n',
        'l', 'u', 'm', 'i', 'n', 'e', 's', 'c', 'e', 'n', 't', '\n',
        'l', 'u', 'm', 'i', 'n', 'o', 's', 'i', 't', 'i', 'e', 's', '\n',
        'l', 'u', 'm', 'i', 'n', 'o', 's', 'i', 't', 'y', '\n',
        'l', 'u', 'm', 'i', 'n', 'o', 'u', 's', '\n',
        'l', 'u', 'm', 'i', 'n', 'o', 'u', 's', 'l', 'y', '\n',
        'l', 'u', 'm', 'p', '\n',
        'l', 'u', 'm', 'p', 'e', 'd', '\n',
        'l', 'u', 'm', 'p', 'e', 'n', '\n',
        'l', 'u', 'm', 'p', 'i', 'e', 'r', '\n',
        'l', 'u', 'm', 'p', 'i', 'e', 's', 't', '\n',
        'l', 'u', 'm', 'p', 'i', 'n', 'e', 's', 's', '\n',
        'l', 'u', 'm', 'p', 'i', 'n', 'g', '\n',
        'l', 'u', 'm', 'p', 'i', 's', 'h', '\n',
        'l', 'u', 'm', 'p', 's', '\n',
        'l', 'u', 'm', 'p', 'y', '\n',
        'l', 'u', 'n', 'a', '\n',
        'l', 'u', 'n', 'a', 'c', 'i', 'e', 's', '\n',
        'l', 'u', 'n', 'a', 'c', 'y', '\n',
        'l', 'u', 'n', 'a', 'r', '\n',
        'l', 'u', 'n', 'a', 't', 'e', '\n',
        'l', 'u', 'n', 'a', 't', 'i', 'c', '\n',
        'l', 'u', 'n', 'a', 't', 'i', 'c', 's', '\n',
        'l', 'u', 'n', 'c', 'h', '\n',
        'l', 'u', 'n', 'c', 'h', 'e', 'd', '\n',
        'l', 'u', 'n', 'c', 'h', 'e', 'o', 'n', '\n',
        'l', 'u', 'n', 'c', 'h', 'e', 'o', 'n', 's', '\n',
        'l', 'u', 'n', 'c', 'h', 'e', 'r', 's', '\n',
        'l', 'u', 'n', 'c', 'h', 'e', 's', '\n',
        'l', 'u', 'n', 'c', 'h', 'i', 'n', 'g', '\n',
        'l', 'u', 'n', 'c', 'h', 'p', 'a', 'c', 'k', '\n',
        'l', 'u', 'n', 'c', 'h', 't', 'i', 'm', 'e', '\n',
        'l', 'u', 'n', 'c', 'h', 't', 'i', 'm', 'e', 's', '\n',
        'l', 'u', 'n', 'e', '\n',
        'l', 'u', 'n', 'g', '\n',
        'l', 'u', 'n', 'g', 'e', '\n',
        'l', 'u', 'n', 'g', 'e', 'd', '\n',
        'l', 'u', 'n', 'g', 'e', 's', '\n',
        'l', 'u', 'n', 'g', 'f', 'i', 's', 'h', '\n',
        'l', 'u', 'n', 'g', 'f', 'u', 'l', '\n',
        'l', 'u', 'n', 'g', 'f', 'u', 'l', 's', '\n',
        'l', 'u', 'n', 'g', 'i', 'n', 'g', '\n',
        'l', 'u', 'n', 'g', 's', '\n',
        'l', 'u', 'p', 'i', 'n', '\n',
        'l', 'u', 'p', 'i', 'n', 'e', 's', '\n',
        'l', 'u', 'p', 'i', 'n', 's', '\n',
        'l', 'u', 'r', '\n',
        'l', 'u', 'r', 'c', 'h', '\n',
        'l', 'u', 'r', 'c', 'h', 'e', 'd', '\n',
        'l', 'u', 'r', 'c', 'h', 'e', 'r', 's', '\n',
        'l', 'u', 'r', 'c', 'h', 'e', 's', '\n',
        'l', 'u', 'r', 'c', 'h', 'i', 'n', 'g', '\n',
        'l', 'u', 'r', 'e', '\n',
        'l', 'u', 'r', 'e', 'd', '\n',
        'l', 'u', 'r', 'e', 's', '\n',
        'l', 'u', 'r', 'e', 'x', '\n',
        'l', 'u', 'r', 'i', 'd', '\n',
        'l', 'u', 'r', 'i', 'd', 'l', 'y', '\n',
        'l', 'u', 'r', 'i', 'n', 'g', '\n',
        'l', 'u', 'r', 'k', '\n',
        'l', 'u', 'r', 'k', 'e', 'd', '\n',
        'l', 'u', 'r', 'k', 'e', 'r', '\n',
        'l', 'u', 'r', 'k', 'e', 'r', 's', '\n',
        'l', 'u', 'r', 'k', 'i', 'n', 'g', '\n',
        'l', 'u', 'r', 'k', 's', '\n',
        'l', 'u', 's', 'a', 'k', 'a', '\n',
        'l', 'u', 's', 'c', 'i', 'o', 'u', 's', '\n',
        'l', 'u', 's', 'c', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'l', 'u', 's', 'h', '\n',
        'l', 'u', 's', 'h', 'e', 'r', '\n',
        'l', 'u', 's', 'h', 'e', 's', 't', '\n',
        'l', 'u', 's', 'h', 'n', 'e', 's', 's', '\n',
        'l', 'u', 's', 't', '\n',
        'l', 'u', 's', 't', 'e', 'd', '\n',
        'l', 'u', 's', 't', 'f', 'u', 'l', '\n',
        'l', 'u', 's', 't', 'f', 'u', 'l', 'l', 'y', '\n',
        'l', 'u', 's', 't', 'i', 'e', 'r', '\n',
        'l', 'u', 's', 't', 'i', 'e', 's', 't', '\n',
        'l', 'u', 's', 't', 'i', 'l', 'y', '\n',
        'l', 'u', 's', 't', 'i', 'n', 'g', '\n',
        'l', 'u', 's', 't', 'r', 'e', '\n',
        'l', 'u', 's', 't', 'r', 'e', 'l', 'e', 's', 's', '\n',
        'l', 'u', 's', 't', 'r', 'o', 'u', 's', '\n',
        'l', 'u', 's', 't', 's', '\n',
        'l', 'u', 's', 't', 'y', '\n',
        'l', 'u', 't', 'e', '\n',
        'l', 'u', 't', 'e', 's', '\n',
        'l', 'u', 't', 'h', 'e', 'r', '\n',
        'l', 'u', 'x', '\n',
        'l', 'u', 'x', 'o', 'r', '\n',
        'l', 'u', 'x', 'u', 'r', 'i', 'a', 'n', 'c', 'e', '\n',
        'l', 'u', 'x', 'u', 'r', 'i', 'a', 'n', 't', '\n',
        'l', 'u', 'x', 'u', 'r', 'i', 'a', 'n', 't', 'l', 'y', '\n',
        'l', 'u', 'x', 'u', 'r', 'i', 'a', 't', 'e', '\n',
        'l', 'u', 'x', 'u', 'r', 'i', 'a', 't', 'i', 'n', 'g', '\n',
        'l', 'u', 'x', 'u', 'r', 'i', 'e', 's', '\n',
        'l', 'u', 'x', 'u', 'r', 'i', 'o', 'u', 's', '\n',
        'l', 'u', 'x', 'u', 'r', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'l', 'u', 'x', 'u', 'r', 'y', '\n',
        'l', 'y', 'c', 'h', 'e', 'e', '\n',
        'l', 'y', 'c', 'h', 'e', 'e', 's', '\n',
        'l', 'y', 'e', '\n',
        'l', 'y', 'i', 'n', 'g', '\n',
        'l', 'y', 'm', 'p', 'h', '\n',
        'l', 'y', 'm', 'p', 'h', 'a', 't', 'i', 'c', '\n',
        'l', 'y', 'm', 'p', 'h', 'o', 'c', 'y', 't', 'e', '\n',
        'l', 'y', 'm', 'p', 'h', 'o', 'c', 'y', 't', 'e', 's', '\n',
        'l', 'y', 'm', 'p', 'h', 'o', 'c', 'y', 't', 'i', 'c', '\n',
        'l', 'y', 'm', 'p', 'h', 'o', 'i', 'd', '\n',
        'l', 'y', 'm', 'p', 'h', 'o', 'm', 'a', '\n',
        'l', 'y', 'm', 'p', 'h', 'o', 'm', 'a', 's', '\n',
        'l', 'y', 'n', 'c', 'h', '\n',
        'l', 'y', 'n', 'c', 'h', 'e', 'd', '\n',
        'l', 'y', 'n', 'c', 'h', 'e', 's', '\n',
        'l', 'y', 'n', 'c', 'h', 'i', 'n', 'g', '\n',
        'l', 'y', 'n', 'c', 'h', 'p', 'i', 'n', '\n',
        'l', 'y', 'n', 'x', '\n',
        'l', 'y', 'n', 'x', 'e', 's', '\n',
        'l', 'y', 'o', 'n', '\n',
        'l', 'y', 'o', 'n', 's', '\n',
        'l', 'y', 'r', 'a', '\n',
        'l', 'y', 'r', 'e', '\n',
        'l', 'y', 'r', 'e', 's', '\n',
        'l', 'y', 'r', 'i', 'c', '\n',
        'l', 'y', 'r', 'i', 'c', 'a', 'l', '\n',
        'l', 'y', 'r', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'l', 'y', 'r', 'i', 'c', 'i', 's', 'm', '\n',
        'l', 'y', 'r', 'i', 'c', 'i', 's', 't', '\n',
        'l', 'y', 'r', 'i', 'c', 'i', 's', 't', 's', '\n',
        'l', 'y', 'r', 'i', 'c', 's', '\n',
        'l', 'y', 'r', 'i', 's', 't', '\n',
        'l', 'y', 's', 'i', 'n', 'e', '\n',
        'm', 'a', 'c', '\n',
        'm', 'a', 'c', 'a', 'b', 'r', 'e', '\n',
        'm', 'a', 'c', 'a', 'q', 'u', 'e', '\n',
        'm', 'a', 'c', 'a', 'q', 'u', 'e', 's', '\n',
        'm', 'a', 'c', 'a', 'r', 'o', 'n', 'i', '\n',
        'm', 'a', 'c', 'a', 'r', 'o', 'o', 'n', '\n',
        'm', 'a', 'c', 'a', 'r', 'o', 'o', 'n', 's', '\n',
        'm', 'a', 'c', 'a', 'w', '\n',
        'm', 'a', 'c', 'a', 'w', 's', '\n',
        'm', 'a', 'c', 'e', '\n',
        'm', 'a', 'c', 'e', 's', '\n',
        'm', 'a', 'c', 'h', 'e', 't', 'e', '\n',
        'm', 'a', 'c', 'h', 'e', 't', 'e', 's', '\n',
        'm', 'a', 'c', 'h', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'a', 'c', 'h', 'i', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'm', 'a', 'c', 'h', 'i', 'n', 'e', '\n',
        'm', 'a', 'c', 'h', 'i', 'n', 'e', 'd', '\n',
        'm', 'a', 'c', 'h', 'i', 'n', 'e', 'g', 'u', 'n', '\n',
        'm', 'a', 'c', 'h', 'i', 'n', 'e', 'g', 'u', 'n', 's', '\n',
        'm', 'a', 'c', 'h', 'i', 'n', 'e', 'r', 'y', '\n',
        'm', 'a', 'c', 'h', 'i', 'n', 'e', 's', '\n',
        'm', 'a', 'c', 'h', 'i', 'n', 'i', 's', 't', '\n',
        'm', 'a', 'c', 'h', 'i', 'n', 'i', 's', 't', 's', '\n',
        'm', 'a', 'c', 'h', 'i', 's', 'm', 'o', '\n',
        'm', 'a', 'c', 'h', 'o', '\n',
        'm', 'a', 'c', 'i', 'n', 't', 'o', 's', 'h', '\n',
        'm', 'a', 'c', 'i', 'n', 't', 'o', 's', 'h', 'e', 's', '\n',
        'm', 'a', 'c', 'k', 'e', 'r', 'e', 'l', '\n',
        'm', 'a', 'c', 'k', 'i', 'n', 't', 'o', 's', 'h', '\n',
        'm', 'a', 'c', 'k', 'i', 'n', 't', 'o', 's', 'h', 'e', 's', '\n',
        'm', 'a', 'c', 'r', 'o', '\n',
        'm', 'a', 'c', 'r', 'o', 'b', 'i', 'o', 't', 'i', 'c', '\n',
        'm', 'a', 'c', 'r', 'o', 'c', 'o', 's', 'm', '\n',
        'm', 'a', 'c', 'r', 'o', 'e', 'c', 'o', 'n', 'o', 'm', 'i', 'c', '\n',
        'm', 'a', 'c', 'r', 'o', 'e', 'c', 'o', 'n', 'o', 'm', 'i', 'c', 's', '\n',
        'm', 'a', 'c', 'r', 'o', 'm', 'o', 'l', 'e', 'c', 'u', 'l', 'a', 'r', '\n',
        'm', 'a', 'c', 'r', 'o', 'm', 'o', 'l', 'e', 'c', 'u', 'l', 'e', 's', '\n',
        'm', 'a', 'c', 'r', 'o', 'n', '\n',
        'm', 'a', 'c', 'r', 'o', 'p', 'h', 'a', 'g', 'e', '\n',
        'm', 'a', 'c', 'r', 'o', 'p', 'h', 'a', 'g', 'e', 's', '\n',
        'm', 'a', 'c', 'r', 'o', 's', 'c', 'o', 'p', 'i', 'c', '\n',
        'm', 'a', 'c', 'r', 'o', 's', 'c', 'o', 'p', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'm', 'a', 'd', '\n',
        'm', 'a', 'd', 'a', 'm', '\n',
        'm', 'a', 'd', 'a', 'm', 'e', '\n',
        'm', 'a', 'd', 'a', 'm', 's', '\n',
        'm', 'a', 'd', 'c', 'a', 'p', '\n',
        'm', 'a', 'd', 'd', 'e', 'n', '\n',
        'm', 'a', 'd', 'd', 'e', 'n', 'e', 'd', '\n',
        'm', 'a', 'd', 'd', 'e', 'n', 'i', 'n', 'g', '\n',
        'm', 'a', 'd', 'd', 'e', 'n', 'i', 'n', 'g', 'l', 'y', '\n',
        'm', 'a', 'd', 'd', 'e', 'n', 's', '\n',
        'm', 'a', 'd', 'd', 'e', 'r', '\n',
        'm', 'a', 'd', 'd', 'e', 's', 't', '\n',
        'm', 'a', 'd', 'e', '\n',
        'm', 'a', 'd', 'e', 'i', 'r', 'a', '\n',
        'm', 'a', 'd', 'e', 'm', 'o', 'i', 's', 'e', 'l', 'l', 'e', '\n',
        'm', 'a', 'd', 'h', 'o', 'u', 's', 'e', '\n',
        'm', 'a', 'd', 'l', 'y', '\n',
        'm', 'a', 'd', 'm', 'a', 'n', '\n',
        'm', 'a', 'd', 'm', 'e', 'n', '\n',
        'm', 'a', 'd', 'n', 'e', 's', 's', '\n',
        'm', 'a', 'd', 'r', 'a', 's', '\n',
        'm', 'a', 'd', 'r', 'i', 'd', '\n',
        'm', 'a', 'd', 'r', 'i', 'g', 'a', 'l', '\n',
        'm', 'a', 'd', 'r', 'i', 'g', 'a', 'l', 's', '\n',
        'm', 'a', 'd', 'w', 'o', 'm', 'a', 'n', '\n',
        'm', 'a', 'e', 'l', 's', 't', 'r', 'o', 'm', '\n',
        'm', 'a', 'e', 's', 't', 'r', 'o', '\n',
        'm', 'a', 'f', 'i', 'a', '\n',
        'm', 'a', 'f', 'i', 'o', 's', 'i', '\n',
        'm', 'a', 'g', '\n',
        'm', 'a', 'g', 'a', 'z', 'i', 'n', 'e', '\n',
        'm', 'a', 'g', 'a', 'z', 'i', 'n', 'e', 's', '\n',
        'm', 'a', 'g', 'e', 'n', 't', 'a', '\n',
        'm', 'a', 'g', 'g', 'o', 't', '\n',
        'm', 'a', 'g', 'g', 'o', 't', 's', '\n',
        'm', 'a', 'g', 'i', '\n',
        'm', 'a', 'g', 'i', 'c', '\n',
        'm', 'a', 'g', 'i', 'c', 'a', 'l', '\n',
        'm', 'a', 'g', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'm', 'a', 'g', 'i', 'c', 'i', 'a', 'n', '\n',
        'm', 'a', 'g', 'i', 'c', 'i', 'a', 'n', 's', '\n',
        'm', 'a', 'g', 'i', 'c', 's', '\n',
        'm', 'a', 'g', 'i', 's', 't', 'e', 'r', 'i', 'a', 'l', '\n',
        'm', 'a', 'g', 'i', 's', 't', 'e', 'r', 'i', 'a', 'l', 'l', 'y', '\n',
        'm', 'a', 'g', 'i', 's', 't', 'r', 'a', 't', 'e', '\n',
        'm', 'a', 'g', 'i', 's', 't', 'r', 'a', 't', 'e', 's', '\n',
        'm', 'a', 'g', 'm', 'a', '\n',
        'm', 'a', 'g', 'm', 'a', 's', '\n',
        'm', 'a', 'g', 'm', 'a', 't', 'i', 'c', '\n',
        'm', 'a', 'g', 'n', 'a', 'n', 'i', 'm', 'i', 't', 'y', '\n',
        'm', 'a', 'g', 'n', 'a', 'n', 'i', 'm', 'o', 's', 'i', 't', 'y', '\n',
        'm', 'a', 'g', 'n', 'a', 'n', 'i', 'm', 'o', 'u', 's', '\n',
        'm', 'a', 'g', 'n', 'a', 'n', 'i', 'm', 'o', 'u', 's', 'l', 'y', '\n',
        'm', 'a', 'g', 'n', 'a', 't', 'e', '\n',
        'm', 'a', 'g', 'n', 'a', 't', 'e', 's', '\n',
        'm', 'a', 'g', 'n', 'e', 's', 'i', 'a', '\n',
        'm', 'a', 'g', 'n', 'e', 's', 'i', 'u', 'm', '\n',
        'm', 'a', 'g', 'n', 'e', 't', '\n',
        'm', 'a', 'g', 'n', 'e', 't', 'i', 'c', '\n',
        'm', 'a', 'g', 'n', 'e', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'm', 'a', 'g', 'n', 'e', 't', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'a', 'g', 'n', 'e', 't', 'i', 's', 'e', '\n',
        'm', 'a', 'g', 'n', 'e', 't', 'i', 's', 'e', 'd', '\n',
        'm', 'a', 'g', 'n', 'e', 't', 'i', 's', 'm', '\n',
        'm', 'a', 'g', 'n', 'e', 't', 'i', 't', 'e', '\n',
        'm', 'a', 'g', 'n', 'e', 't', 'o', '\n',
        'm', 'a', 'g', 'n', 'e', 't', 'o', 'd', 'y', 'n', 'a', 'm', 'i', 'c', 's', '\n',
        'm', 'a', 'g', 'n', 'e', 't', 'o', 'h', 'y', 'd', 'r', 'o', 'd', 'y', 'n', 'a', 'm', 'i', 'c', 'a', 'l', '\n',
        'm', 'a', 'g', 'n', 'e', 't', 'o', 'h', 'y', 'd', 'r', 'o', 'd', 'y', 'n', 'a', 'm', 'i', 'c', 's', '\n',
        'm', 'a', 'g', 'n', 'e', 't', 'o', 'm', 'e', 't', 'e', 'r', '\n',
        'm', 'a', 'g', 'n', 'e', 't', 'o', 'm', 'e', 't', 'e', 'r', 's', '\n',
        'm', 'a', 'g', 'n', 'e', 't', 'o', 's', 'p', 'h', 'e', 'r', 'e', '\n',
        'm', 'a', 'g', 'n', 'e', 't', 'r', 'o', 'n', '\n',
        'm', 'a', 'g', 'n', 'e', 't', 's', '\n',
        'm', 'a', 'g', 'n', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'a', 'g', 'n', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'm', 'a', 'g', 'n', 'i', 'f', 'i', 'c', 'e', 'n', 'c', 'e', '\n',
        'm', 'a', 'g', 'n', 'i', 'f', 'i', 'c', 'e', 'n', 't', '\n',
        'm', 'a', 'g', 'n', 'i', 'f', 'i', 'c', 'e', 'n', 't', 'l', 'y', '\n',
        'm', 'a', 'g', 'n', 'i', 'f', 'i', 'e', 'd', '\n',
        'm', 'a', 'g', 'n', 'i', 'f', 'i', 'e', 'r', '\n',
        'm', 'a', 'g', 'n', 'i', 'f', 'i', 'e', 's', '\n',
        'm', 'a', 'g', 'n', 'i', 'f', 'y', '\n',
        'm', 'a', 'g', 'n', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'm', 'a', 'g', 'n', 'i', 'l', 'o', 'q', 'u', 'e', 'n', 't', '\n',
        'm', 'a', 'g', 'n', 'i', 't', 'u', 'd', 'e', '\n',
        'm', 'a', 'g', 'n', 'i', 't', 'u', 'd', 'e', 's', '\n',
        'm', 'a', 'g', 'n', 'o', 'l', 'i', 'a', '\n',
        'm', 'a', 'g', 'n', 'o', 'l', 'i', 'a', 's', '\n',
        'm', 'a', 'g', 'n', 'u', 'm', '\n',
        'm', 'a', 'g', 'n', 'u', 'm', 's', '\n',
        'm', 'a', 'g', 'p', 'i', 'e', '\n',
        'm', 'a', 'g', 'p', 'i', 'e', 's', '\n',
        'm', 'a', 'g', 's', '\n',
        'm', 'a', 'h', 'a', 't', 'm', 'a', '\n',
        'm', 'a', 'h', 'o', 'g', 'a', 'n', 'y', '\n',
        'm', 'a', 'i', 'd', '\n',
        'm', 'a', 'i', 'd', 'e', 'n', '\n',
        'm', 'a', 'i', 'd', 'e', 'n', 'l', 'y', '\n',
        'm', 'a', 'i', 'd', 'e', 'n', 's', '\n',
        'm', 'a', 'i', 'd', 's', '\n',
        'm', 'a', 'i', 'd', 's', 'e', 'r', 'v', 'a', 'n', 't', '\n',
        'm', 'a', 'i', 'd', 's', 'e', 'r', 'v', 'a', 'n', 't', 's', '\n',
        'm', 'a', 'i', 'l', '\n',
        'm', 'a', 'i', 'l', 'a', 'b', 'l', 'e', '\n',
        'm', 'a', 'i', 'l', 'b', 'o', 'x', '\n',
        'm', 'a', 'i', 'l', 'e', 'd', '\n',
        'm', 'a', 'i', 'l', 'e', 'r', '\n',
        'm', 'a', 'i', 'l', 'i', 'n', 'g', '\n',
        'm', 'a', 'i', 'l', 'i', 'n', 'g', 's', '\n',
        'm', 'a', 'i', 'l', 'm', 'a', 'n', '\n',
        'm', 'a', 'i', 'l', 'm', 'e', 'n', '\n',
        'm', 'a', 'i', 'l', 'o', 'r', 'd', 'e', 'r', '\n',
        'm', 'a', 'i', 'l', 's', '\n',
        'm', 'a', 'i', 'l', 's', 'h', 'o', 't', '\n',
        'm', 'a', 'i', 'l', 's', 'h', 'o', 't', 's', '\n',
        'm', 'a', 'i', 'm', '\n',
        'm', 'a', 'i', 'm', 'e', 'd', '\n',
        'm', 'a', 'i', 'm', 'i', 'n', 'g', '\n',
        'm', 'a', 'i', 'm', 'i', 'n', 'g', 's', '\n',
        'm', 'a', 'i', 'm', 's', '\n',
        'm', 'a', 'i', 'n', '\n',
        'm', 'a', 'i', 'n', 'b', 'r', 'a', 'c', 'e', '\n',
        'm', 'a', 'i', 'n', 'e', '\n',
        'm', 'a', 'i', 'n', 'f', 'r', 'a', 'm', 'e', '\n',
        'm', 'a', 'i', 'n', 'f', 'r', 'a', 'm', 'e', 's', '\n',
        'm', 'a', 'i', 'n', 'l', 'a', 'n', 'd', '\n',
        'm', 'a', 'i', 'n', 'l', 'i', 'n', 'e', '\n',
        'm', 'a', 'i', 'n', 'l', 'y', '\n',
        'm', 'a', 'i', 'n', 's', '\n',
        'm', 'a', 'i', 'n', 's', 'a', 'i', 'l', '\n',
        'm', 'a', 'i', 'n', 's', 'p', 'r', 'i', 'n', 'g', '\n',
        'm', 'a', 'i', 'n', 's', 't', 'a', 'y', '\n',
        'm', 'a', 'i', 'n', 's', 't', 'a', 'y', 's', '\n',
        'm', 'a', 'i', 'n', 's', 't', 'r', 'e', 'a', 'm', '\n',
        'm', 'a', 'i', 'n', 't', 'a', 'i', 'n', '\n',
        'm', 'a', 'i', 'n', 't', 'a', 'i', 'n', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'm', 'a', 'i', 'n', 't', 'a', 'i', 'n', 'a', 'b', 'l', 'e', '\n',
        'm', 'a', 'i', 'n', 't', 'a', 'i', 'n', 'e', 'd', '\n',
        'm', 'a', 'i', 'n', 't', 'a', 'i', 'n', 'e', 'r', '\n',
        'm', 'a', 'i', 'n', 't', 'a', 'i', 'n', 'e', 'r', 's', '\n',
        'm', 'a', 'i', 'n', 't', 'a', 'i', 'n', 'i', 'n', 'g', '\n',
        'm', 'a', 'i', 'n', 't', 'a', 'i', 'n', 's', '\n',
        'm', 'a', 'i', 'n', 't', 'e', 'n', 'a', 'n', 'c', 'e', '\n',
        'm', 'a', 'i', 's', 'o', 'n', 'e', 't', 't', 'e', '\n',
        'm', 'a', 'i', 's', 'o', 'n', 'e', 't', 't', 'e', 's', '\n',
        'm', 'a', 'i', 'z', 'e', '\n',
        'm', 'a', 'i', 'z', 'e', 's', '\n',
        'm', 'a', 'j', 'e', 's', 't', 'i', 'c', '\n',
        'm', 'a', 'j', 'e', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'm', 'a', 'j', 'e', 's', 't', 'i', 'e', 's', '\n',
        'm', 'a', 'j', 'e', 's', 't', 'y', '\n',
        'm', 'a', 'j', 'o', 'l', 'i', 'c', 'a', '\n',
        'm', 'a', 'j', 'o', 'r', '\n',
        'm', 'a', 'j', 'o', 'r', 'e', 't', 't', 'e', '\n',
        'm', 'a', 'j', 'o', 'r', 'e', 't', 't', 'e', 's', '\n',
        'm', 'a', 'j', 'o', 'r', 'i', 't', 'i', 'e', 's', '\n',
        'm', 'a', 'j', 'o', 'r', 'i', 't', 'y', '\n',
        'm', 'a', 'j', 'o', 'r', 's', '\n',
        'm', 'a', 'k', 'e', '\n',
        'm', 'a', 'k', 'e', 'o', 'v', 'e', 'r', '\n',
        'm', 'a', 'k', 'e', 'r', '\n',
        'm', 'a', 'k', 'e', 'r', 's', '\n',
        'm', 'a', 'k', 'e', 's', '\n',
        'm', 'a', 'k', 'e', 's', 'h', 'i', 'f', 't', '\n',
        'm', 'a', 'k', 'e', 'u', 'p', '\n',
        'm', 'a', 'k', 'e', 'w', 'e', 'i', 'g', 'h', 't', '\n',
        'm', 'a', 'k', 'i', 'n', 'g', '\n',
        'm', 'a', 'k', 'i', 'n', 'g', 's', '\n',
        'm', 'a', 'l', 'a', 'c', 'h', 'i', 't', 'e', '\n',
        'm', 'a', 'l', 'a', 'd', 'a', 'p', 't', 'i', 'v', 'e', '\n',
        'm', 'a', 'l', 'a', 'd', 'i', 'e', 's', '\n',
        'm', 'a', 'l', 'a', 'd', 'j', 'u', 's', 't', 'e', 'd', '\n',
        'm', 'a', 'l', 'a', 'd', 'j', 'u', 's', 't', 'm', 'e', 'n', 't', '\n',
        'm', 'a', 'l', 'a', 'd', 'm', 'i', 'n', 'i', 's', 't', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'a', 'l', 'a', 'd', 'r', 'o', 'i', 't', '\n',
        'm', 'a', 'l', 'a', 'd', 'y', '\n',
        'm', 'a', 'l', 'a', 'i', 's', 'e', '\n',
        'm', 'a', 'l', 'a', 'r', 'i', 'a', '\n',
        'm', 'a', 'l', 'a', 'r', 'i', 'a', 'l', '\n',
        'm', 'a', 'l', 'a', 't', 'h', 'i', 'o', 'n', '\n',
        'm', 'a', 'l', 'a', 'w', 'i', '\n',
        'm', 'a', 'l', 'a', 'y', '\n',
        'm', 'a', 'l', 'a', 'y', 'a', 'n', '\n',
        'm', 'a', 'l', 'a', 'y', 's', '\n',
        'm', 'a', 'l', 'a', 'y', 's', 'i', 'a', '\n',
        'm', 'a', 'l', 'c', 'o', 'n', 't', 'e', 'n', 't', '\n',
        'm', 'a', 'l', 'c', 'o', 'n', 't', 'e', 'n', 't', 's', '\n',
        'm', 'a', 'l', 'd', 'i', 'v', 'e', 's', '\n',
        'm', 'a', 'l', 'e', '\n',
        'm', 'a', 'l', 'e', 'f', 'a', 'c', 't', 'i', 'o', 'n', '\n',
        'm', 'a', 'l', 'e', 'f', 'a', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'm', 'a', 'l', 'e', 'f', 'a', 'c', 't', 'o', 'r', '\n',
        'm', 'a', 'l', 'e', 'f', 'a', 'c', 't', 'o', 'r', 's', '\n',
        'm', 'a', 'l', 'e', 'n', 'e', 's', 's', '\n',
        'm', 'a', 'l', 'e', 's', '\n',
        'm', 'a', 'l', 'e', 'v', 'o', 'l', 'e', 'n', 'c', 'e', '\n',
        'm', 'a', 'l', 'e', 'v', 'o', 'l', 'e', 'n', 't', '\n',
        'm', 'a', 'l', 'e', 'v', 'o', 'l', 'e', 'n', 't', 'l', 'y', '\n',
        'm', 'a', 'l', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'a', 'l', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'm', 'a', 'l', 'f', 'o', 'r', 'm', 'e', 'd', '\n',
        'm', 'a', 'l', 'f', 'u', 'n', 'c', 't', 'i', 'o', 'n', '\n',
        'm', 'a', 'l', 'f', 'u', 'n', 'c', 't', 'i', 'o', 'n', 'e', 'd', '\n',
        'm', 'a', 'l', 'f', 'u', 'n', 'c', 't', 'i', 'o', 'n', 'i', 'n', 'g', '\n',
        'm', 'a', 'l', 'f', 'u', 'n', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'm', 'a', 'l', 'i', 'c', 'e', '\n',
        'm', 'a', 'l', 'i', 'c', 'e', 's', '\n',
        'm', 'a', 'l', 'i', 'c', 'i', 'o', 'u', 's', '\n',
        'm', 'a', 'l', 'i', 'c', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'm', 'a', 'l', 'i', 'c', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'm', 'a', 'l', 'i', 'g', 'n', '\n',
        'm', 'a', 'l', 'i', 'g', 'n', 'a', 'n', 'c', 'i', 'e', 's', '\n',
        'm', 'a', 'l', 'i', 'g', 'n', 'a', 'n', 'c', 'y', '\n',
        'm', 'a', 'l', 'i', 'g', 'n', 'a', 'n', 't', '\n',
        'm', 'a', 'l', 'i', 'g', 'n', 'a', 'n', 't', 'l', 'y', '\n',
        'm', 'a', 'l', 'i', 'g', 'n', 'e', 'd', '\n',
        'm', 'a', 'l', 'i', 'g', 'n', 'e', 'r', 's', '\n',
        'm', 'a', 'l', 'i', 'g', 'n', 'i', 'n', 'g', '\n',
        'm', 'a', 'l', 'i', 'g', 'n', 'i', 't', 'y', '\n',
        'm', 'a', 'l', 'i', 'g', 'n', 's', '\n',
        'm', 'a', 'l', 'i', 'n', 'g', 'e', 'r', 'e', 'r', 's', '\n',
        'm', 'a', 'l', 'i', 'n', 'g', 'e', 'r', 'i', 'n', 'g', '\n',
        'm', 'a', 'l', 'l', '\n',
        'm', 'a', 'l', 'l', 'a', 'r', 'd', '\n',
        'm', 'a', 'l', 'l', 'a', 'r', 'd', 's', '\n',
        'm', 'a', 'l', 'l', 'e', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'm', 'a', 'l', 'l', 'e', 'a', 'b', 'l', 'e', '\n',
        'm', 'a', 'l', 'l', 'e', 't', '\n',
        'm', 'a', 'l', 'l', 'e', 't', 's', '\n',
        'm', 'a', 'l', 'l', 'o', 'w', '\n',
        'm', 'a', 'l', 'l', 's', '\n',
        'm', 'a', 'l', 'n', 'o', 'u', 'r', 'i', 's', 'h', 'e', 'd', '\n',
        'm', 'a', 'l', 'n', 'o', 'u', 'r', 'i', 's', 'h', 'm', 'e', 'n', 't', '\n',
        'm', 'a', 'l', 'n', 'u', 't', 'r', 'i', 't', 'i', 'o', 'n', '\n',
        'm', 'a', 'l', 'o', 'd', 'o', 'r', 'o', 'u', 's', '\n',
        'm', 'a', 'l', 'p', 'r', 'a', 'c', 't', 'i', 'c', 'e', '\n',
        'm', 'a', 'l', 'p', 'r', 'a', 'c', 't', 'i', 'c', 'e', 's', '\n',
        'm', 'a', 'l', 't', '\n',
        'm', 'a', 'l', 't', 'a', '\n',
        'm', 'a', 'l', 't', 'e', 'd', '\n',
        'm', 'a', 'l', 't', 'e', 's', 'e', '\n',
        'm', 'a', 'l', 't', 'i', 'n', 'g', '\n',
        'm', 'a', 'l', 't', 'r', 'e', 'a', 't', '\n',
        'm', 'a', 'l', 't', 'r', 'e', 'a', 't', 'e', 'd', '\n',
        'm', 'a', 'l', 't', 'r', 'e', 'a', 't', 'm', 'e', 'n', 't', '\n',
        'm', 'a', 'l', 't', 's', '\n',
        'm', 'a', 'l', 't', 'y', '\n',
        'm', 'a', 'l', 'v', 'a', '\n',
        'm', 'a', 'm', 'a', '\n',
        'm', 'a', 'm', 'a', 's', '\n',
        'm', 'a', 'm', 'b', 'a', '\n',
        'm', 'a', 'm', 'b', 'a', 's', '\n',
        'm', 'a', 'm', 'm', 'a', 'l', '\n',
        'm', 'a', 'm', 'm', 'a', 'l', 'i', 'a', '\n',
        'm', 'a', 'm', 'm', 'a', 'l', 'i', 'a', 'n', '\n',
        'm', 'a', 'm', 'm', 'a', 'l', 's', '\n',
        'm', 'a', 'm', 'm', 'a', 'r', 'y', '\n',
        'm', 'a', 'm', 'm', 'o', 't', 'h', '\n',
        'm', 'a', 'm', 'm', 'o', 't', 'h', 's', '\n',
        'm', 'a', 'm', 'm', 'y', '\n',
        'm', 'a', 'n', '\n',
        'm', 'a', 'n', 'a', 'c', 'l', 'e', '\n',
        'm', 'a', 'n', 'a', 'c', 'l', 'e', 'd', '\n',
        'm', 'a', 'n', 'a', 'c', 'l', 'e', 's', '\n',
        'm', 'a', 'n', 'a', 'g', 'e', '\n',
        'm', 'a', 'n', 'a', 'g', 'e', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'm', 'a', 'n', 'a', 'g', 'e', 'a', 'b', 'l', 'e', '\n',
        'm', 'a', 'n', 'a', 'g', 'e', 'd', '\n',
        'm', 'a', 'n', 'a', 'g', 'e', 'm', 'e', 'n', 't', '\n',
        'm', 'a', 'n', 'a', 'g', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'm', 'a', 'n', 'a', 'g', 'e', 'r', '\n',
        'm', 'a', 'n', 'a', 'g', 'e', 'r', 'e', 's', 's', '\n',
        'm', 'a', 'n', 'a', 'g', 'e', 'r', 'e', 's', 's', 'e', 's', '\n',
        'm', 'a', 'n', 'a', 'g', 'e', 'r', 'i', 'a', 'l', '\n',
        'm', 'a', 'n', 'a', 'g', 'e', 'r', 'i', 'a', 'l', 'l', 'y', '\n',
        'm', 'a', 'n', 'a', 'g', 'e', 'r', 's', '\n',
        'm', 'a', 'n', 'a', 'g', 'e', 'r', 's', 'h', 'i', 'p', '\n',
        'm', 'a', 'n', 'a', 'g', 'e', 's', '\n',
        'm', 'a', 'n', 'a', 'g', 'i', 'n', 'g', '\n',
        'm', 'a', 'n', 'a', 't', 'e', 'e', '\n',
        'm', 'a', 'n', 'c', 'i', 'p', 'l', 'e', '\n',
        'm', 'a', 'n', 'd', 'a', 'r', 'i', 'n', '\n',
        'm', 'a', 'n', 'd', 'a', 'r', 'i', 'n', 's', '\n',
        'm', 'a', 'n', 'd', 'a', 't', 'e', '\n',
        'm', 'a', 'n', 'd', 'a', 't', 'e', 'd', '\n',
        'm', 'a', 'n', 'd', 'a', 't', 'e', 's', '\n',
        'm', 'a', 'n', 'd', 'a', 't', 'i', 'n', 'g', '\n',
        'm', 'a', 'n', 'd', 'a', 't', 'o', 'r', 'y', '\n',
        'm', 'a', 'n', 'd', 'e', 'l', 'a', '\n',
        'm', 'a', 'n', 'd', 'i', 'b', 'l', 'e', '\n',
        'm', 'a', 'n', 'd', 'i', 'b', 'l', 'e', 's', '\n',
        'm', 'a', 'n', 'd', 'i', 'b', 'u', 'l', 'a', 'r', '\n',
        'm', 'a', 'n', 'd', 'o', 'l', 'i', 'n', '\n',
        'm', 'a', 'n', 'd', 'o', 'l', 'i', 'n', 's', '\n',
        'm', 'a', 'n', 'd', 'r', 'a', 'k', 'e', '\n',
        'm', 'a', 'n', 'd', 'r', 'i', 'l', '\n',
        'm', 'a', 'n', 'd', 'r', 'i', 'l', 'l', '\n',
        'm', 'a', 'n', 'e', '\n',
        'm', 'a', 'n', 'e', 'd', '\n',
        'm', 'a', 'n', 'e', 's', '\n',
        'm', 'a', 'n', 'e', 'u', 'v', 'e', 'r', '\n',
        'm', 'a', 'n', 'f', 'u', 'l', 'l', 'y', '\n',
        'm', 'a', 'n', 'g', 'a', 'n', 'e', 's', 'e', '\n',
        'm', 'a', 'n', 'g', 'e', '\n',
        'm', 'a', 'n', 'g', 'e', 'r', '\n',
        'm', 'a', 'n', 'g', 'e', 'r', 's', '\n',
        'm', 'a', 'n', 'g', 'l', 'e', '\n',
        'm', 'a', 'n', 'g', 'l', 'e', 'd', '\n',
        'm', 'a', 'n', 'g', 'l', 'e', 'r', '\n',
        'm', 'a', 'n', 'g', 'l', 'e', 's', '\n',
        'm', 'a', 'n', 'g', 'l', 'i', 'n', 'g', '\n',
        'm', 'a', 'n', 'g', 'o', '\n',
        'm', 'a', 'n', 'g', 'r', 'o', 'v', 'e', '\n',
        'm', 'a', 'n', 'g', 'r', 'o', 'v', 'e', 's', '\n',
        'm', 'a', 'n', 'h', 'a', 'n', 'd', 'l', 'e', '\n',
        'm', 'a', 'n', 'h', 'a', 'n', 'd', 'l', 'e', 'd', '\n',
        'm', 'a', 'n', 'h', 'a', 'n', 'd', 'l', 'i', 'n', 'g', '\n',
        'm', 'a', 'n', 'h', 'o', 'l', 'e', '\n',
        'm', 'a', 'n', 'h', 'o', 'l', 'e', 's', '\n',
        'm', 'a', 'n', 'h', 'o', 'o', 'd', '\n',
        'm', 'a', 'n', 'h', 'u', 'n', 't', '\n',
        'm', 'a', 'n', 'h', 'u', 'n', 't', 's', '\n',
        'm', 'a', 'n', 'i', 'a', '\n',
        'm', 'a', 'n', 'i', 'a', 'c', '\n',
        'm', 'a', 'n', 'i', 'a', 'c', 'a', 'l', '\n',
        'm', 'a', 'n', 'i', 'a', 'c', 'a', 'l', 'l', 'y', '\n',
        'm', 'a', 'n', 'i', 'a', 'c', 's', '\n',
        'm', 'a', 'n', 'i', 'a', 's', '\n',
        'm', 'a', 'n', 'i', 'c', '\n',
        'm', 'a', 'n', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'm', 'a', 'n', 'i', 'c', 'd', 'e', 'p', 'r', 'e', 's', 's', 'i', 'v', 'e', '\n',
        'm', 'a', 'n', 'i', 'c', 'u', 'r', 'e', '\n',
        'm', 'a', 'n', 'i', 'c', 'u', 'r', 'e', 'd', '\n',
        'm', 'a', 'n', 'i', 'f', 'e', 's', 't', '\n',
        'm', 'a', 'n', 'i', 'f', 'e', 's', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'a', 'n', 'i', 'f', 'e', 's', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'm', 'a', 'n', 'i', 'f', 'e', 's', 't', 'e', 'd', '\n',
        'm', 'a', 'n', 'i', 'f', 'e', 's', 't', 'i', 'n', 'g', '\n',
        'm', 'a', 'n', 'i', 'f', 'e', 's', 't', 'l', 'y', '\n',
        'm', 'a', 'n', 'i', 'f', 'e', 's', 't', 'o', '\n',
        'm', 'a', 'n', 'i', 'f', 'e', 's', 't', 's', '\n',
        'm', 'a', 'n', 'i', 'f', 'o', 'l', 'd', '\n',
        'm', 'a', 'n', 'i', 'f', 'o', 'l', 'd', 's', '\n',
        'm', 'a', 'n', 'i', 'k', 'i', 'n', '\n',
        'm', 'a', 'n', 'i', 'l', 'a', '\n',
        'm', 'a', 'n', 'i', 'p', 'u', 'l', 'a', 'b', 'l', 'e', '\n',
        'm', 'a', 'n', 'i', 'p', 'u', 'l', 'a', 't', 'e', '\n',
        'm', 'a', 'n', 'i', 'p', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'm', 'a', 'n', 'i', 'p', 'u', 'l', 'a', 't', 'e', 's', '\n',
        'm', 'a', 'n', 'i', 'p', 'u', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'm', 'a', 'n', 'i', 'p', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'a', 'n', 'i', 'p', 'u', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'm', 'a', 'n', 'i', 'p', 'u', 'l', 'a', 't', 'i', 'v', 'e', '\n',
        'm', 'a', 'n', 'i', 'p', 'u', 'l', 'a', 't', 'o', 'r', '\n',
        'm', 'a', 'n', 'i', 'p', 'u', 'l', 'a', 't', 'o', 'r', 's', '\n',
        'm', 'a', 'n', 'k', 'i', 'n', 'd', '\n',
        'm', 'a', 'n', 'l', 'i', 'e', 's', 't', '\n',
        'm', 'a', 'n', 'l', 'i', 'n', 'e', 's', 's', '\n',
        'm', 'a', 'n', 'l', 'y', '\n',
        'm', 'a', 'n', 'm', 'a', 'd', 'e', '\n',
        'm', 'a', 'n', 'n', 'a', '\n',
        'm', 'a', 'n', 'n', 'e', 'd', '\n',
        'm', 'a', 'n', 'n', 'e', 'q', 'u', 'i', 'n', '\n',
        'm', 'a', 'n', 'n', 'e', 'q', 'u', 'i', 'n', 's', '\n',
        'm', 'a', 'n', 'n', 'e', 'r', '\n',
        'm', 'a', 'n', 'n', 'e', 'r', 'e', 'd', '\n',
        'm', 'a', 'n', 'n', 'e', 'r', 'i', 's', 'm', '\n',
        'm', 'a', 'n', 'n', 'e', 'r', 'i', 's', 'm', 's', '\n',
        'm', 'a', 'n', 'n', 'e', 'r', 'i', 's', 't', '\n',
        'm', 'a', 'n', 'n', 'e', 'r', 'l', 'i', 'n', 'e', 's', 's', '\n',
        'm', 'a', 'n', 'n', 'e', 'r', 'l', 'y', '\n',
        'm', 'a', 'n', 'n', 'e', 'r', 's', '\n',
        'm', 'a', 'n', 'n', 'i', 'n', 'g', '\n',
        'm', 'a', 'n', 'o', 'e', 'u', 'v', 'r', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'm', 'a', 'n', 'o', 'e', 'u', 'v', 'r', 'a', 'b', 'l', 'e', '\n',
        'm', 'a', 'n', 'o', 'e', 'u', 'v', 'r', 'e', '\n',
        'm', 'a', 'n', 'o', 'e', 'u', 'v', 'r', 'e', 'd', '\n',
        'm', 'a', 'n', 'o', 'e', 'u', 'v', 'r', 'e', 's', '\n',
        'm', 'a', 'n', 'o', 'e', 'u', 'v', 'r', 'i', 'n', 'g', '\n',
        'm', 'a', 'n', 'o', 'e', 'u', 'v', 'r', 'i', 'n', 'g', 's', '\n',
        'm', 'a', 'n', 'o', 'm', 'e', 't', 'e', 'r', '\n',
        'm', 'a', 'n', 'o', 'r', '\n',
        'm', 'a', 'n', 'o', 'r', 'i', 'a', 'l', '\n',
        'm', 'a', 'n', 'o', 'r', 's', '\n',
        'm', 'a', 'n', 'p', 'o', 'w', 'e', 'r', '\n',
        'm', 'a', 'n', 's', 'e', '\n',
        'm', 'a', 'n', 's', 'e', 'r', 'v', 'a', 'n', 't', '\n',
        'm', 'a', 'n', 's', 'i', 'o', 'n', '\n',
        'm', 'a', 'n', 's', 'i', 'o', 'n', 's', '\n',
        'm', 'a', 'n', 's', 'i', 'z', 'e', 'd', '\n',
        'm', 'a', 'n', 's', 'l', 'a', 'u', 'g', 'h', 't', 'e', 'r', '\n',
        'm', 'a', 'n', 't', 'e', 'l', '\n',
        'm', 'a', 'n', 't', 'e', 'l', 'p', 'i', 'e', 'c', 'e', '\n',
        'm', 'a', 'n', 't', 'e', 'l', 'p', 'i', 'e', 'c', 'e', 's', '\n',
        'm', 'a', 'n', 't', 'e', 'l', 's', 'h', 'e', 'l', 'f', '\n',
        'm', 'a', 'n', 't', 'i', 'd', 's', '\n',
        'm', 'a', 'n', 't', 'i', 's', '\n',
        'm', 'a', 'n', 't', 'i', 's', 's', 'a', '\n',
        'm', 'a', 'n', 't', 'i', 's', 's', 'a', 's', '\n',
        'm', 'a', 'n', 't', 'l', 'e', '\n',
        'm', 'a', 'n', 't', 'l', 'e', 'd', '\n',
        'm', 'a', 'n', 't', 'l', 'e', 's', '\n',
        'm', 'a', 'n', 't', 'l', 'i', 'n', 'g', '\n',
        'm', 'a', 'n', 't', 'r', 'a', '\n',
        'm', 'a', 'n', 't', 'r', 'a', 'p', '\n',
        'm', 'a', 'n', 't', 'r', 'a', 'p', 's', '\n',
        'm', 'a', 'n', 't', 'r', 'a', 's', '\n',
        'm', 'a', 'n', 'u', 'a', 'l', '\n',
        'm', 'a', 'n', 'u', 'a', 'l', 'l', 'y', '\n',
        'm', 'a', 'n', 'u', 'a', 'l', 's', '\n',
        'm', 'a', 'n', 'u', 'f', 'a', 'c', 't', 'u', 'r', 'e', '\n',
        'm', 'a', 'n', 'u', 'f', 'a', 'c', 't', 'u', 'r', 'e', 'd', '\n',
        'm', 'a', 'n', 'u', 'f', 'a', 'c', 't', 'u', 'r', 'e', 'r', '\n',
        'm', 'a', 'n', 'u', 'f', 'a', 'c', 't', 'u', 'r', 'e', 'r', 's', '\n',
        'm', 'a', 'n', 'u', 'f', 'a', 'c', 't', 'u', 'r', 'e', 's', '\n',
        'm', 'a', 'n', 'u', 'f', 'a', 'c', 't', 'u', 'r', 'i', 'n', 'g', '\n',
        'm', 'a', 'n', 'u', 'r', 'e', '\n',
        'm', 'a', 'n', 'u', 'r', 'e', 'd', '\n',
        'm', 'a', 'n', 'u', 'r', 'e', 's', '\n',
        'm', 'a', 'n', 'u', 'r', 'i', 'n', 'g', '\n',
        'm', 'a', 'n', 'u', 's', 'c', 'r', 'i', 'p', 't', '\n',
        'm', 'a', 'n', 'u', 's', 'c', 'r', 'i', 'p', 't', 's', '\n',
        'm', 'a', 'n', 'y', '\n',
        'm', 'a', 'o', 'i', 's', 'm', '\n',
        'm', 'a', 'o', 'i', 's', 't', '\n',
        'm', 'a', 'o', 'i', 's', 't', 's', '\n',
        'm', 'a', 'o', 'r', 'i', '\n',
        'm', 'a', 'p', '\n',
        'm', 'a', 'p', 'l', 'e', '\n',
        'm', 'a', 'p', 'l', 'e', 's', '\n',
        'm', 'a', 'p', 'p', 'a', 'b', 'l', 'e', '\n',
        'm', 'a', 'p', 'p', 'e', 'd', '\n',
        'm', 'a', 'p', 'p', 'e', 'r', '\n',
        'm', 'a', 'p', 'p', 'e', 'r', 's', '\n',
        'm', 'a', 'p', 'p', 'i', 'n', 'g', '\n',
        'm', 'a', 'p', 'p', 'i', 'n', 'g', 's', '\n',
        'm', 'a', 'p', 's', '\n',
        'm', 'a', 'p', 'u', 't', 'o', '\n',
        'm', 'a', 'q', 'u', 'e', 't', 't', 'e', 's', '\n',
        'm', 'a', 'r', '\n',
        'm', 'a', 'r', 'a', '\n',
        'm', 'a', 'r', 'a', 't', 'h', 'o', 'n', '\n',
        'm', 'a', 'r', 'a', 't', 'h', 'o', 'n', 's', '\n',
        'm', 'a', 'r', 'a', 'u', 'd', 'e', 'r', 's', '\n',
        'm', 'a', 'r', 'a', 'u', 'd', 'i', 'n', 'g', '\n',
        'm', 'a', 'r', 'b', 'l', 'e', '\n',
        'm', 'a', 'r', 'b', 'l', 'e', 'd', '\n',
        'm', 'a', 'r', 'b', 'l', 'e', 's', '\n',
        'm', 'a', 'r', 'c', 'h', '\n',
        'm', 'a', 'r', 'c', 'h', 'e', 'd', '\n',
        'm', 'a', 'r', 'c', 'h', 'e', 'r', '\n',
        'm', 'a', 'r', 'c', 'h', 'e', 'r', 's', '\n',
        'm', 'a', 'r', 'c', 'h', 'e', 's', '\n',
        'm', 'a', 'r', 'c', 'h', 'i', 'n', 'g', '\n',
        'm', 'a', 'r', 'c', 'h', 'i', 'o', 'n', 'e', 's', 's', '\n',
        'm', 'a', 'r', 'e', '\n',
        'm', 'a', 'r', 'e', 's', '\n',
        'm', 'a', 'r', 'g', 'a', 'r', 'i', 'n', 'e', '\n',
        'm', 'a', 'r', 'g', 'a', 'r', 'i', 'n', 'e', 's', '\n',
        'm', 'a', 'r', 'g', 'a', 't', 'e', '\n',
        'm', 'a', 'r', 'g', 'i', 'n', '\n',
        'm', 'a', 'r', 'g', 'i', 'n', 'a', 'l', '\n',
        'm', 'a', 'r', 'g', 'i', 'n', 'a', 'l', 'i', 'a', '\n',
        'm', 'a', 'r', 'g', 'i', 'n', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'a', 'r', 'g', 'i', 'n', 'a', 'l', 'i', 's', 'e', '\n',
        'm', 'a', 'r', 'g', 'i', 'n', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'm', 'a', 'r', 'g', 'i', 'n', 'a', 'l', 'i', 's', 'e', 's', '\n',
        'm', 'a', 'r', 'g', 'i', 'n', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'm', 'a', 'r', 'g', 'i', 'n', 'a', 'l', 'i', 't', 'y', '\n',
        'm', 'a', 'r', 'g', 'i', 'n', 'a', 'l', 'l', 'y', '\n',
        'm', 'a', 'r', 'g', 'i', 'n', 'a', 'l', 's', '\n',
        'm', 'a', 'r', 'g', 'i', 'n', 's', '\n',
        'm', 'a', 'r', 'i', 'a', '\n',
        'm', 'a', 'r', 'i', 'g', 'o', 'l', 'd', '\n',
        'm', 'a', 'r', 'i', 'g', 'o', 'l', 'd', 's', '\n',
        'm', 'a', 'r', 'i', 'j', 'u', 'a', 'n', 'a', '\n',
        'm', 'a', 'r', 'i', 'n', 'a', '\n',
        'm', 'a', 'r', 'i', 'n', 'a', 'd', 'e', '\n',
        'm', 'a', 'r', 'i', 'n', 'a', 's', '\n',
        'm', 'a', 'r', 'i', 'n', 'a', 't', 'e', '\n',
        'm', 'a', 'r', 'i', 'n', 'a', 't', 'e', 'd', '\n',
        'm', 'a', 'r', 'i', 'n', 'e', '\n',
        'm', 'a', 'r', 'i', 'n', 'e', 'r', '\n',
        'm', 'a', 'r', 'i', 'n', 'e', 'r', 's', '\n',
        'm', 'a', 'r', 'i', 'n', 'e', 's', '\n',
        'm', 'a', 'r', 'i', 'o', 'n', 'e', 't', 't', 'e', '\n',
        'm', 'a', 'r', 'i', 'o', 'n', 'e', 't', 't', 'e', 's', '\n',
        'm', 'a', 'r', 'i', 't', 'a', 'l', '\n',
        'm', 'a', 'r', 'i', 't', 'i', 'm', 'e', '\n',
        'm', 'a', 'r', 'k', '\n',
        'm', 'a', 'r', 'k', 'e', 'd', '\n',
        'm', 'a', 'r', 'k', 'e', 'd', 'l', 'y', '\n',
        'm', 'a', 'r', 'k', 'e', 'r', '\n',
        'm', 'a', 'r', 'k', 'e', 'r', 's', '\n',
        'm', 'a', 'r', 'k', 'e', 't', '\n',
        'm', 'a', 'r', 'k', 'e', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'm', 'a', 'r', 'k', 'e', 't', 'a', 'b', 'l', 'e', '\n',
        'm', 'a', 'r', 'k', 'e', 't', 'e', 'd', '\n',
        'm', 'a', 'r', 'k', 'e', 't', 'e', 'e', 'r', '\n',
        'm', 'a', 'r', 'k', 'e', 't', 'e', 'e', 'r', 's', '\n',
        'm', 'a', 'r', 'k', 'e', 't', 'e', 'r', '\n',
        'm', 'a', 'r', 'k', 'e', 't', 'i', 'n', 'g', '\n',
        'm', 'a', 'r', 'k', 'e', 't', 'p', 'l', 'a', 'c', 'e', '\n',
        'm', 'a', 'r', 'k', 'e', 't', 's', '\n',
        'm', 'a', 'r', 'k', 'i', 'n', 'g', '\n',
        'm', 'a', 'r', 'k', 'i', 'n', 'g', 's', '\n',
        'm', 'a', 'r', 'k', 's', '\n',
        'm', 'a', 'r', 'k', 's', 'm', 'a', 'n', '\n',
        'm', 'a', 'r', 'k', 's', 'm', 'a', 'n', 's', 'h', 'i', 'p', '\n',
        'm', 'a', 'r', 'k', 's', 'm', 'e', 'n', '\n',
        'm', 'a', 'r', 'k', 'u', 'p', '\n',
        'm', 'a', 'r', 'k', 'u', 'p', 's', '\n',
        'm', 'a', 'r', 'l', '\n',
        'm', 'a', 'r', 'l', 's', '\n',
        'm', 'a', 'r', 'm', 'a', 'l', 'a', 'd', 'e', '\n',
        'm', 'a', 'r', 'm', 'o', 's', 'e', 't', '\n',
        'm', 'a', 'r', 'm', 'o', 's', 'e', 't', 's', '\n',
        'm', 'a', 'r', 'm', 'o', 't', '\n',
        'm', 'a', 'r', 'm', 'o', 't', 's', '\n',
        'm', 'a', 'r', 'o', 'o', 'n', '\n',
        'm', 'a', 'r', 'o', 'o', 'n', 'e', 'd', '\n',
        'm', 'a', 'r', 'o', 'o', 'n', 'i', 'n', 'g', '\n',
        'm', 'a', 'r', 'o', 'o', 'n', 's', '\n',
        'm', 'a', 'r', 'q', 'u', 'e', '\n',
        'm', 'a', 'r', 'q', 'u', 'e', 'e', '\n',
        'm', 'a', 'r', 'q', 'u', 'e', 'e', 's', '\n',
        'm', 'a', 'r', 'q', 'u', 'e', 's', '\n',
        'm', 'a', 'r', 'q', 'u', 'e', 's', 's', '\n',
        'm', 'a', 'r', 'q', 'u', 'e', 't', 'r', 'y', '\n',
        'm', 'a', 'r', 'q', 'u', 'i', 's', '\n',
        'm', 'a', 'r', 'r', 'e', 'd', '\n',
        'm', 'a', 'r', 'r', 'i', 'a', 'g', 'e', '\n',
        'm', 'a', 'r', 'r', 'i', 'a', 'g', 'e', 'a', 'b', 'l', 'e', '\n',
        'm', 'a', 'r', 'r', 'i', 'a', 'g', 'e', 's', '\n',
        'm', 'a', 'r', 'r', 'i', 'e', 'd', '\n',
        'm', 'a', 'r', 'r', 'i', 'e', 's', '\n',
        'm', 'a', 'r', 'r', 'i', 'n', 'g', '\n',
        'm', 'a', 'r', 'r', 'o', 'w', '\n',
        'm', 'a', 'r', 'r', 'o', 'w', 's', '\n',
        'm', 'a', 'r', 'r', 'y', '\n',
        'm', 'a', 'r', 'r', 'y', 'i', 'n', 'g', '\n',
        'm', 'a', 'r', 's', '\n',
        'm', 'a', 'r', 's', 'a', 'l', 'a', '\n',
        'm', 'a', 'r', 's', 'h', '\n',
        'm', 'a', 'r', 's', 'h', 'a', 'l', '\n',
        'm', 'a', 'r', 's', 'h', 'a', 'l', 'l', 'e', 'd', '\n',
        'm', 'a', 'r', 's', 'h', 'a', 'l', 'l', 'e', 'r', '\n',
        'm', 'a', 'r', 's', 'h', 'a', 'l', 'l', 'i', 'n', 'g', '\n',
        'm', 'a', 'r', 's', 'h', 'a', 'l', 's', '\n',
        'm', 'a', 'r', 's', 'h', 'e', 's', '\n',
        'm', 'a', 'r', 's', 'h', 'g', 'a', 's', '\n',
        'm', 'a', 'r', 's', 'h', 'i', 'e', 'r', '\n',
        'm', 'a', 'r', 's', 'h', 'i', 'e', 's', 't', '\n',
        'm', 'a', 'r', 's', 'h', 'i', 'n', 'e', 's', 's', '\n',
        'm', 'a', 'r', 's', 'h', 'l', 'a', 'n', 'd', '\n',
        'm', 'a', 'r', 's', 'h', 'm', 'a', 'l', 'l', 'o', 'w', '\n',
        'm', 'a', 'r', 's', 'h', 'm', 'a', 'l', 'l', 'o', 'w', 's', '\n',
        'm', 'a', 'r', 's', 'h', 'y', '\n',
        'm', 'a', 'r', 's', 'u', 'p', 'i', 'a', 'l', '\n',
        'm', 'a', 'r', 's', 'u', 'p', 'i', 'a', 'l', 's', '\n',
        'm', 'a', 'r', 't', '\n',
        'm', 'a', 'r', 't', 'e', 'n', '\n',
        'm', 'a', 'r', 't', 'e', 'n', 's', '\n',
        'm', 'a', 'r', 't', 'i', 'a', 'l', '\n',
        'm', 'a', 'r', 't', 'i', 'a', 'n', '\n',
        'm', 'a', 'r', 't', 'i', 'a', 'n', 's', '\n',
        'm', 'a', 'r', 't', 'i', 'n', '\n',
        'm', 'a', 'r', 't', 'i', 'n', 'e', 't', '\n',
        'm', 'a', 'r', 't', 'i', 'n', 'g', 'a', 'l', 'e', '\n',
        'm', 'a', 'r', 't', 'i', 'n', 'g', 'a', 'l', 'e', 's', '\n',
        'm', 'a', 'r', 't', 'i', 'n', 'i', '\n',
        'm', 'a', 'r', 't', 'i', 'n', 's', '\n',
        'm', 'a', 'r', 't', 'y', 'r', '\n',
        'm', 'a', 'r', 't', 'y', 'r', 'd', 'o', 'm', '\n',
        'm', 'a', 'r', 't', 'y', 'r', 'e', 'd', '\n',
        'm', 'a', 'r', 't', 'y', 'r', 's', '\n',
        'm', 'a', 'r', 't', 'y', 'r', 'y', '\n',
        'm', 'a', 'r', 'v', 'e', 'l', '\n',
        'm', 'a', 'r', 'v', 'e', 'l', 'l', 'e', 'd', '\n',
        'm', 'a', 'r', 'v', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'm', 'a', 'r', 'v', 'e', 'l', 'l', 'o', 'u', 's', '\n',
        'm', 'a', 'r', 'v', 'e', 'l', 'l', 'o', 'u', 's', 'l', 'y', '\n',
        'm', 'a', 'r', 'v', 'e', 'l', 's', '\n',
        'm', 'a', 'r', 'x', '\n',
        'm', 'a', 'r', 'x', 'i', 's', 'm', '\n',
        'm', 'a', 'r', 'x', 'i', 's', 't', '\n',
        'm', 'a', 'r', 'x', 'i', 's', 't', 's', '\n',
        'm', 'a', 'r', 'y', '\n',
        'm', 'a', 'r', 'z', 'i', 'p', 'a', 'n', '\n',
        'm', 'a', 's', '\n',
        'm', 'a', 's', 'c', 'a', 'r', 'a', '\n',
        'm', 'a', 's', 'c', 'o', 't', '\n',
        'm', 'a', 's', 'c', 'o', 't', 's', '\n',
        'm', 'a', 's', 'c', 'u', 'l', 'i', 'n', 'e', '\n',
        'm', 'a', 's', 'c', 'u', 'l', 'i', 'n', 'i', 't', 'y', '\n',
        'm', 'a', 's', 'e', 'r', '\n',
        'm', 'a', 's', 'e', 'r', 'u', '\n',
        'm', 'a', 's', 'h', '\n',
        'm', 'a', 's', 'h', 'e', 'd', '\n',
        'm', 'a', 's', 'h', 'e', 'r', '\n',
        'm', 'a', 's', 'h', 'i', 'n', 'g', '\n',
        'm', 'a', 's', 'k', '\n',
        'm', 'a', 's', 'k', 'e', 'd', '\n',
        'm', 'a', 's', 'k', 'i', 'n', 'g', '\n',
        'm', 'a', 's', 'k', 's', '\n',
        'm', 'a', 's', 'o', 'c', 'h', 'i', 's', 'm', '\n',
        'm', 'a', 's', 'o', 'c', 'h', 'i', 's', 't', '\n',
        'm', 'a', 's', 'o', 'c', 'h', 'i', 's', 't', 'i', 'c', '\n',
        'm', 'a', 's', 'o', 'c', 'h', 'i', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'm', 'a', 's', 'o', 'c', 'h', 'i', 's', 't', 's', '\n',
        'm', 'a', 's', 'o', 'n', '\n',
        'm', 'a', 's', 'o', 'n', 'i', 'c', '\n',
        'm', 'a', 's', 'o', 'n', 'r', 'y', '\n',
        'm', 'a', 's', 'o', 'n', 's', '\n',
        'm', 'a', 's', 'q', 'u', 'e', '\n',
        'm', 'a', 's', 'q', 'u', 'e', 'r', 'a', 'd', 'e', '\n',
        'm', 'a', 's', 'q', 'u', 'e', 'r', 'a', 'd', 'e', 'd', '\n',
        'm', 'a', 's', 'q', 'u', 'e', 'r', 'a', 'd', 'e', 's', '\n',
        'm', 'a', 's', 'q', 'u', 'e', 'r', 'a', 'd', 'i', 'n', 'g', '\n',
        'm', 'a', 's', 'q', 'u', 'e', 's', '\n',
        'm', 'a', 's', 's', '\n',
        'm', 'a', 's', 's', 'a', 'c', 'r', 'e', '\n',
        'm', 'a', 's', 's', 'a', 'c', 'r', 'e', 'd', '\n',
        'm', 'a', 's', 's', 'a', 'c', 'r', 'e', 's', '\n',
        'm', 'a', 's', 's', 'a', 'c', 'r', 'i', 'n', 'g', '\n',
        'm', 'a', 's', 's', 'a', 'g', 'e', '\n',
        'm', 'a', 's', 's', 'a', 'g', 'e', 'd', '\n',
        'm', 'a', 's', 's', 'a', 'g', 'e', 'r', '\n',
        'm', 'a', 's', 's', 'a', 'g', 'e', 's', '\n',
        'm', 'a', 's', 's', 'a', 'g', 'i', 'n', 'g', '\n',
        'm', 'a', 's', 's', 'e', 'd', '\n',
        'm', 'a', 's', 's', 'e', 's', '\n',
        'm', 'a', 's', 's', 'e', 'u', 'r', '\n',
        'm', 'a', 's', 's', 'e', 'u', 'r', 's', '\n',
        'm', 'a', 's', 's', 'e', 'u', 's', 'e', '\n',
        'm', 'a', 's', 's', 'e', 'u', 's', 'e', 's', '\n',
        'm', 'a', 's', 's', 'i', 'f', '\n',
        'm', 'a', 's', 's', 'i', 'n', 'g', '\n',
        'm', 'a', 's', 's', 'i', 'v', 'e', '\n',
        'm', 'a', 's', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'm', 'a', 's', 's', 'l', 'e', 's', 's', '\n',
        'm', 'a', 's', 's', 'p', 'r', 'o', 'd', 'u', 'c', 'e', 'd', '\n',
        'm', 'a', 's', 's', 'p', 'r', 'o', 'd', 'u', 'c', 'i', 'n', 'g', '\n',
        'm', 'a', 's', 't', '\n',
        'm', 'a', 's', 't', 'e', 'c', 't', 'o', 'm', 'y', '\n',
        'm', 'a', 's', 't', 'e', 'd', '\n',
        'm', 'a', 's', 't', 'e', 'r', '\n',
        'm', 'a', 's', 't', 'e', 'r', 'c', 'l', 'a', 's', 's', '\n',
        'm', 'a', 's', 't', 'e', 'r', 'e', 'd', '\n',
        'm', 'a', 's', 't', 'e', 'r', 'f', 'u', 'l', '\n',
        'm', 'a', 's', 't', 'e', 'r', 'f', 'u', 'l', 'l', 'y', '\n',
        'm', 'a', 's', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'm', 'a', 's', 't', 'e', 'r', 'l', 'y', '\n',
        'm', 'a', 's', 't', 'e', 'r', 'm', 'i', 'n', 'd', '\n',
        'm', 'a', 's', 't', 'e', 'r', 'm', 'i', 'n', 'd', 'e', 'd', '\n',
        'm', 'a', 's', 't', 'e', 'r', 'm', 'i', 'n', 'd', 'i', 'n', 'g', '\n',
        'm', 'a', 's', 't', 'e', 'r', 'p', 'i', 'e', 'c', 'e', '\n',
        'm', 'a', 's', 't', 'e', 'r', 'p', 'i', 'e', 'c', 'e', 's', '\n',
        'm', 'a', 's', 't', 'e', 'r', 's', '\n',
        'm', 'a', 's', 't', 'e', 'r', 's', 'h', 'i', 'p', '\n',
        'm', 'a', 's', 't', 'e', 'r', 'w', 'o', 'r', 'k', '\n',
        'm', 'a', 's', 't', 'e', 'r', 'w', 'o', 'r', 'k', 's', '\n',
        'm', 'a', 's', 't', 'e', 'r', 'y', '\n',
        'm', 'a', 's', 't', 'h', 'e', 'a', 'd', '\n',
        'm', 'a', 's', 't', 'i', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'm', 'a', 's', 't', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'a', 's', 't', 'i', 'f', 'f', '\n',
        'm', 'a', 's', 't', 'i', 't', 'i', 's', '\n',
        'm', 'a', 's', 't', 'o', 'd', 'o', 'n', '\n',
        'm', 'a', 's', 't', 'o', 'd', 'o', 'n', 's', '\n',
        'm', 'a', 's', 't', 'o', 'i', 'd', '\n',
        'm', 'a', 's', 't', 'o', 'i', 'd', 's', '\n',
        'm', 'a', 's', 't', 's', '\n',
        'm', 'a', 't', '\n',
        'm', 'a', 't', 'a', 'd', 'o', 'r', '\n',
        'm', 'a', 't', 'a', 'd', 'o', 'r', 's', '\n',
        'm', 'a', 't', 'c', 'h', '\n',
        'm', 'a', 't', 'c', 'h', 'a', 'b', 'l', 'e', '\n',
        'm', 'a', 't', 'c', 'h', 'b', 'o', 'x', '\n',
        'm', 'a', 't', 'c', 'h', 'b', 'o', 'x', 'e', 's', '\n',
        'm', 'a', 't', 'c', 'h', 'e', 'd', '\n',
        'm', 'a', 't', 'c', 'h', 'e', 'r', '\n',
        'm', 'a', 't', 'c', 'h', 'e', 's', '\n',
        'm', 'a', 't', 'c', 'h', 'i', 'n', 'g', '\n',
        'm', 'a', 't', 'c', 'h', 'l', 'e', 's', 's', '\n',
        'm', 'a', 't', 'c', 'h', 'm', 'a', 'k', 'e', 'r', '\n',
        'm', 'a', 't', 'c', 'h', 'm', 'a', 'k', 'i', 'n', 'g', '\n',
        'm', 'a', 't', 'c', 'h', 'p', 'l', 'a', 'y', '\n',
        'm', 'a', 't', 'c', 'h', 's', 't', 'i', 'c', 'k', '\n',
        'm', 'a', 't', 'c', 'h', 's', 't', 'i', 'c', 'k', 's', '\n',
        'm', 'a', 't', 'e', '\n',
        'm', 'a', 't', 'e', 'd', '\n',
        'm', 'a', 't', 'e', 'r', '\n',
        'm', 'a', 't', 'e', 'r', 'i', 'a', 'l', '\n',
        'm', 'a', 't', 'e', 'r', 'i', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'a', 't', 'e', 'r', 'i', 'a', 'l', 'i', 's', 'e', '\n',
        'm', 'a', 't', 'e', 'r', 'i', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'm', 'a', 't', 'e', 'r', 'i', 'a', 'l', 'i', 's', 'e', 's', '\n',
        'm', 'a', 't', 'e', 'r', 'i', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'm', 'a', 't', 'e', 'r', 'i', 'a', 'l', 'i', 's', 'm', '\n',
        'm', 'a', 't', 'e', 'r', 'i', 'a', 'l', 'i', 's', 't', '\n',
        'm', 'a', 't', 'e', 'r', 'i', 'a', 'l', 'i', 's', 't', 'i', 'c', '\n',
        'm', 'a', 't', 'e', 'r', 'i', 'a', 'l', 'i', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'm', 'a', 't', 'e', 'r', 'i', 'a', 'l', 'i', 's', 't', 's', '\n',
        'm', 'a', 't', 'e', 'r', 'i', 'a', 'l', 'i', 't', 'y', '\n',
        'm', 'a', 't', 'e', 'r', 'i', 'a', 'l', 'l', 'y', '\n',
        'm', 'a', 't', 'e', 'r', 'i', 'a', 'l', 's', '\n',
        'm', 'a', 't', 'e', 'r', 'n', 'a', 'l', '\n',
        'm', 'a', 't', 'e', 'r', 'n', 'a', 'l', 'l', 'y', '\n',
        'm', 'a', 't', 'e', 'r', 'n', 'i', 't', 'y', '\n',
        'm', 'a', 't', 'e', 's', '\n',
        'm', 'a', 't', 'h', '\n',
        'm', 'a', 't', 'h', 'e', 'm', 'a', 't', 'i', 'c', 'a', 'l', '\n',
        'm', 'a', 't', 'h', 'e', 'm', 'a', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'm', 'a', 't', 'h', 'e', 'm', 'a', 't', 'i', 'c', 'i', 'a', 'n', '\n',
        'm', 'a', 't', 'h', 'e', 'm', 'a', 't', 'i', 'c', 'i', 'a', 'n', 's', '\n',
        'm', 'a', 't', 'h', 'e', 'm', 'a', 't', 'i', 'c', 's', '\n',
        'm', 'a', 't', 'h', 's', '\n',
        'm', 'a', 't', 'i', 'n', 'e', 'e', '\n',
        'm', 'a', 't', 'i', 'n', 'e', 'e', 's', '\n',
        'm', 'a', 't', 'i', 'n', 'g', '\n',
        'm', 'a', 't', 'i', 'n', 'g', 's', '\n',
        'm', 'a', 't', 'i', 'n', 's', '\n',
        'm', 'a', 't', 'r', 'i', 'a', 'r', 'c', 'h', '\n',
        'm', 'a', 't', 'r', 'i', 'a', 'r', 'c', 'h', 'a', 'l', '\n',
        'm', 'a', 't', 'r', 'i', 'a', 'r', 'c', 'h', 'i', 'e', 's', '\n',
        'm', 'a', 't', 'r', 'i', 'a', 'r', 'c', 'h', 'y', '\n',
        'm', 'a', 't', 'r', 'i', 'c', 'e', 's', '\n',
        'm', 'a', 't', 'r', 'i', 'c', 'u', 'l', 'a', 't', 'e', '\n',
        'm', 'a', 't', 'r', 'i', 'c', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'm', 'a', 't', 'r', 'i', 'c', 'u', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'm', 'a', 't', 'r', 'i', 'c', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'a', 't', 'r', 'i', 'l', 'i', 'n', 'e', 'a', 'l', '\n',
        'm', 'a', 't', 'r', 'i', 'm', 'o', 'n', 'i', 'a', 'l', '\n',
        'm', 'a', 't', 'r', 'i', 'm', 'o', 'n', 'i', 'a', 'l', 'l', 'y', '\n',
        'm', 'a', 't', 'r', 'i', 'm', 'o', 'n', 'y', '\n',
        'm', 'a', 't', 'r', 'i', 'x', '\n',
        'm', 'a', 't', 'r', 'i', 'x', 'e', 's', '\n',
        'm', 'a', 't', 'r', 'o', 'n', '\n',
        'm', 'a', 't', 'r', 'o', 'n', 'l', 'y', '\n',
        'm', 'a', 't', 'r', 'o', 'n', 's', '\n',
        'm', 'a', 't', 's', '\n',
        'm', 'a', 't', 't', '\n',
        'm', 'a', 't', 't', 'e', '\n',
        'm', 'a', 't', 't', 'e', 'd', '\n',
        'm', 'a', 't', 't', 'e', 'r', '\n',
        'm', 'a', 't', 't', 'e', 'r', 'e', 'd', '\n',
        'm', 'a', 't', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'm', 'a', 't', 't', 'e', 'r', 'o', 'f', 'f', 'a', 'c', 't', '\n',
        'm', 'a', 't', 't', 'e', 'r', 's', '\n',
        'm', 'a', 't', 't', 'h', 'e', 'w', '\n',
        'm', 'a', 't', 't', 'i', 'n', 'g', '\n',
        'm', 'a', 't', 't', 'r', 'e', 's', 's', '\n',
        'm', 'a', 't', 't', 'r', 'e', 's', 's', 'e', 's', '\n',
        'm', 'a', 't', 'u', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'a', 't', 'u', 'r', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'm', 'a', 't', 'u', 'r', 'e', '\n',
        'm', 'a', 't', 'u', 'r', 'e', 'd', '\n',
        'm', 'a', 't', 'u', 'r', 'e', 'l', 'y', '\n',
        'm', 'a', 't', 'u', 'r', 'e', 'r', '\n',
        'm', 'a', 't', 'u', 'r', 'e', 's', '\n',
        'm', 'a', 't', 'u', 'r', 'i', 'n', 'g', '\n',
        'm', 'a', 't', 'u', 'r', 'i', 't', 'y', '\n',
        'm', 'a', 'u', 'd', 'l', 'i', 'n', '\n',
        'm', 'a', 'u', 'l', '\n',
        'm', 'a', 'u', 'l', 'e', 'd', '\n',
        'm', 'a', 'u', 'l', 'e', 'r', '\n',
        'm', 'a', 'u', 'l', 'e', 'r', 's', '\n',
        'm', 'a', 'u', 'l', 'i', 'n', 'g', '\n',
        'm', 'a', 'u', 'l', 's', '\n',
        'm', 'a', 'u', 'm', 'a', 'u', '\n',
        'm', 'a', 'u', 's', 'o', 'l', 'e', 'u', 'm', '\n',
        'm', 'a', 'u', 's', 'o', 'l', 'e', 'u', 'm', 's', '\n',
        'm', 'a', 'u', 'v', 'e', '\n',
        'm', 'a', 'v', 'e', 'r', 'i', 'c', 'k', '\n',
        'm', 'a', 'v', 'e', 'r', 'i', 'c', 'k', 's', '\n',
        'm', 'a', 'w', '\n',
        'm', 'a', 'w', 'k', 'i', 's', 'h', '\n',
        'm', 'a', 'w', 'k', 'i', 's', 'h', 'n', 'e', 's', 's', '\n',
        'm', 'a', 'x', 'i', '\n',
        'm', 'a', 'x', 'i', 'm', '\n',
        'm', 'a', 'x', 'i', 'm', 'a', '\n',
        'm', 'a', 'x', 'i', 'm', 'a', 'l', '\n',
        'm', 'a', 'x', 'i', 'm', 'a', 'l', 'i', 't', 'y', '\n',
        'm', 'a', 'x', 'i', 'm', 'a', 'l', 'l', 'y', '\n',
        'm', 'a', 'x', 'i', 'm', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'a', 'x', 'i', 'm', 'i', 's', 'e', '\n',
        'm', 'a', 'x', 'i', 'm', 'i', 's', 'e', 'd', '\n',
        'm', 'a', 'x', 'i', 'm', 'i', 's', 'e', 'r', '\n',
        'm', 'a', 'x', 'i', 'm', 'i', 's', 'e', 's', '\n',
        'm', 'a', 'x', 'i', 'm', 'i', 's', 'i', 'n', 'g', '\n',
        'm', 'a', 'x', 'i', 'm', 's', '\n',
        'm', 'a', 'x', 'i', 'm', 'u', 'm', '\n',
        'm', 'a', 'y', '\n',
        'm', 'a', 'y', 'a', '\n',
        'm', 'a', 'y', 'a', 's', '\n',
        'm', 'a', 'y', 'b', 'e', '\n',
        'm', 'a', 'y', 'd', 'a', 'y', '\n',
        'm', 'a', 'y', 'd', 'a', 'y', 's', '\n',
        'm', 'a', 'y', 'f', 'l', 'i', 'e', 's', '\n',
        'm', 'a', 'y', 'f', 'l', 'o', 'w', 'e', 'r', '\n',
        'm', 'a', 'y', 'f', 'l', 'y', '\n',
        'm', 'a', 'y', 'h', 'a', 'p', '\n',
        'm', 'a', 'y', 'h', 'e', 'm', '\n',
        'm', 'a', 'y', 'o', 'n', 'n', 'a', 'i', 's', 'e', '\n',
        'm', 'a', 'y', 'o', 'r', '\n',
        'm', 'a', 'y', 'o', 'r', 'a', 'l', '\n',
        'm', 'a', 'y', 'o', 'r', 'a', 'l', 't', 'y', '\n',
        'm', 'a', 'y', 'o', 'r', 'e', 's', 's', '\n',
        'm', 'a', 'y', 'o', 'r', 's', '\n',
        'm', 'a', 'y', 'p', 'o', 'l', 'e', '\n',
        'm', 'a', 'z', 'e', '\n',
        'm', 'a', 'z', 'e', 's', '\n',
        'm', 'a', 'z', 'i', 'e', 'r', '\n',
        'm', 'a', 'z', 'i', 'e', 's', 't', '\n',
        'm', 'a', 'z', 'u', 'r', 'k', 'a', '\n',
        'm', 'a', 'z', 'y', '\n',
        'm', 'b', 'a', 'b', 'a', 'n', 'e', '\n',
        'm', 'e', '\n',
        'm', 'e', 'a', 'd', '\n',
        'm', 'e', 'a', 'd', 'o', 'w', '\n',
        'm', 'e', 'a', 'd', 'o', 'w', 'l', 'a', 'n', 'd', '\n',
        'm', 'e', 'a', 'd', 'o', 'w', 's', '\n',
        'm', 'e', 'a', 'g', 'r', 'e', '\n',
        'm', 'e', 'a', 'g', 'r', 'e', 'l', 'y', '\n',
        'm', 'e', 'a', 'g', 'r', 'e', 'n', 'e', 's', 's', '\n',
        'm', 'e', 'a', 'l', '\n',
        'm', 'e', 'a', 'l', 'i', 'e', '\n',
        'm', 'e', 'a', 'l', 'i', 'e', 's', '\n',
        'm', 'e', 'a', 'l', 's', '\n',
        'm', 'e', 'a', 'l', 't', 'i', 'm', 'e', '\n',
        'm', 'e', 'a', 'l', 't', 'i', 'm', 'e', 's', '\n',
        'm', 'e', 'a', 'l', 'y', '\n',
        'm', 'e', 'a', 'n', '\n',
        'm', 'e', 'a', 'n', 'd', 'e', 'r', '\n',
        'm', 'e', 'a', 'n', 'd', 'e', 'r', 'e', 'd', '\n',
        'm', 'e', 'a', 'n', 'd', 'e', 'r', 'i', 'n', 'g', '\n',
        'm', 'e', 'a', 'n', 'd', 'e', 'r', 'i', 'n', 'g', 's', '\n',
        'm', 'e', 'a', 'n', 'd', 'e', 'r', 's', '\n',
        'm', 'e', 'a', 'n', 'e', 'r', '\n',
        'm', 'e', 'a', 'n', 'e', 's', 't', '\n',
        'm', 'e', 'a', 'n', 'i', 'e', '\n',
        'm', 'e', 'a', 'n', 'i', 'e', 's', '\n',
        'm', 'e', 'a', 'n', 'i', 'n', 'g', '\n',
        'm', 'e', 'a', 'n', 'i', 'n', 'g', 'f', 'u', 'l', '\n',
        'm', 'e', 'a', 'n', 'i', 'n', 'g', 'f', 'u', 'l', 'l', 'y', '\n',
        'm', 'e', 'a', 'n', 'i', 'n', 'g', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'm', 'e', 'a', 'n', 'i', 'n', 'g', 'l', 'e', 's', 's', '\n',
        'm', 'e', 'a', 'n', 'i', 'n', 'g', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'm', 'e', 'a', 'n', 'i', 'n', 'g', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'm', 'e', 'a', 'n', 'i', 'n', 'g', 's', '\n',
        'm', 'e', 'a', 'n', 'l', 'y', '\n',
        'm', 'e', 'a', 'n', 'n', 'e', 's', 's', '\n',
        'm', 'e', 'a', 'n', 's', '\n',
        'm', 'e', 'a', 'n', 't', '\n',
        'm', 'e', 'a', 'n', 't', 'i', 'm', 'e', '\n',
        'm', 'e', 'a', 'n', 'w', 'h', 'i', 'l', 'e', '\n',
        'm', 'e', 'a', 'n', 'y', '\n',
        'm', 'e', 'a', 's', 'l', 'e', 's', '\n',
        'm', 'e', 'a', 's', 'l', 'y', '\n',
        'm', 'e', 'a', 's', 'u', 'r', 'a', 'b', 'l', 'e', '\n',
        'm', 'e', 'a', 's', 'u', 'r', 'a', 'b', 'l', 'y', '\n',
        'm', 'e', 'a', 's', 'u', 'r', 'e', '\n',
        'm', 'e', 'a', 's', 'u', 'r', 'e', 'd', '\n',
        'm', 'e', 'a', 's', 'u', 'r', 'e', 'l', 'e', 's', 's', '\n',
        'm', 'e', 'a', 's', 'u', 'r', 'e', 'm', 'e', 'n', 't', '\n',
        'm', 'e', 'a', 's', 'u', 'r', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'm', 'e', 'a', 's', 'u', 'r', 'e', 's', '\n',
        'm', 'e', 'a', 's', 'u', 'r', 'i', 'n', 'g', '\n',
        'm', 'e', 'a', 't', '\n',
        'm', 'e', 'a', 't', 'a', 'x', 'e', '\n',
        'm', 'e', 'a', 't', 'b', 'a', 'l', 'l', '\n',
        'm', 'e', 'a', 't', 'b', 'a', 'l', 'l', 's', '\n',
        'm', 'e', 'a', 't', 'i', 'e', 'r', '\n',
        'm', 'e', 'a', 't', 'i', 'e', 's', 't', '\n',
        'm', 'e', 'a', 't', 'l', 'e', 's', 's', '\n',
        'm', 'e', 'a', 't', 'p', 'i', 'e', '\n',
        'm', 'e', 'a', 't', 's', '\n',
        'm', 'e', 'a', 't', 'y', '\n',
        'm', 'e', 'c', 'c', 'a', '\n',
        'm', 'e', 'c', 'h', 'a', 'n', 'i', 'c', '\n',
        'm', 'e', 'c', 'h', 'a', 'n', 'i', 'c', 'a', 'l', '\n',
        'm', 'e', 'c', 'h', 'a', 'n', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'm', 'e', 'c', 'h', 'a', 'n', 'i', 'c', 'a', 'l', 's', '\n',
        'm', 'e', 'c', 'h', 'a', 'n', 'i', 'c', 's', '\n',
        'm', 'e', 'c', 'h', 'a', 'n', 'i', 's', 'a', 'b', 'l', 'e', '\n',
        'm', 'e', 'c', 'h', 'a', 'n', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'e', 'c', 'h', 'a', 'n', 'i', 's', 'e', '\n',
        'm', 'e', 'c', 'h', 'a', 'n', 'i', 's', 'e', 'd', '\n',
        'm', 'e', 'c', 'h', 'a', 'n', 'i', 's', 'i', 'n', 'g', '\n',
        'm', 'e', 'c', 'h', 'a', 'n', 'i', 's', 'm', '\n',
        'm', 'e', 'c', 'h', 'a', 'n', 'i', 's', 'm', 's', '\n',
        'm', 'e', 'c', 'h', 'a', 'n', 'i', 's', 't', '\n',
        'm', 'e', 'c', 'h', 'a', 'n', 'i', 's', 't', 'i', 'c', '\n',
        'm', 'e', 'c', 'h', 'a', 'n', 'i', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'm', 'e', 'd', 'a', 'l', '\n',
        'm', 'e', 'd', 'a', 'l', 'l', 'i', 'o', 'n', '\n',
        'm', 'e', 'd', 'a', 'l', 'l', 'i', 'o', 'n', 's', '\n',
        'm', 'e', 'd', 'a', 'l', 'l', 'i', 's', 't', '\n',
        'm', 'e', 'd', 'a', 'l', 'l', 'i', 's', 't', 's', '\n',
        'm', 'e', 'd', 'a', 'l', 's', '\n',
        'm', 'e', 'd', 'd', 'l', 'e', '\n',
        'm', 'e', 'd', 'd', 'l', 'e', 'd', '\n',
        'm', 'e', 'd', 'd', 'l', 'e', 'r', '\n',
        'm', 'e', 'd', 'd', 'l', 'e', 'r', 's', '\n',
        'm', 'e', 'd', 'd', 'l', 'e', 's', '\n',
        'm', 'e', 'd', 'd', 'l', 'e', 's', 'o', 'm', 'e', '\n',
        'm', 'e', 'd', 'd', 'l', 'i', 'n', 'g', '\n',
        'm', 'e', 'd', 'i', 'a', '\n',
        'm', 'e', 'd', 'i', 'a', 'e', 'v', 'a', 'l', '\n',
        'm', 'e', 'd', 'i', 'a', 'l', '\n',
        'm', 'e', 'd', 'i', 'a', 'l', 'l', 'y', '\n',
        'm', 'e', 'd', 'i', 'a', 'n', '\n',
        'm', 'e', 'd', 'i', 'a', 'n', 's', '\n',
        'm', 'e', 'd', 'i', 'a', 't', 'e', '\n',
        'm', 'e', 'd', 'i', 'a', 't', 'e', 'd', '\n',
        'm', 'e', 'd', 'i', 'a', 't', 'e', 's', '\n',
        'm', 'e', 'd', 'i', 'a', 't', 'i', 'n', 'g', '\n',
        'm', 'e', 'd', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'e', 'd', 'i', 'a', 't', 'o', 'r', '\n',
        'm', 'e', 'd', 'i', 'a', 't', 'o', 'r', 's', '\n',
        'm', 'e', 'd', 'i', 'a', 't', 'o', 'r', 'y', '\n',
        'm', 'e', 'd', 'i', 'c', '\n',
        'm', 'e', 'd', 'i', 'c', 'a', 'l', '\n',
        'm', 'e', 'd', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'm', 'e', 'd', 'i', 'c', 'a', 'l', 's', '\n',
        'm', 'e', 'd', 'i', 'c', 'a', 't', 'e', '\n',
        'm', 'e', 'd', 'i', 'c', 'a', 't', 'e', 'd', '\n',
        'm', 'e', 'd', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'e', 'd', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'm', 'e', 'd', 'i', 'c', 'i', 'n', 'a', 'l', '\n',
        'm', 'e', 'd', 'i', 'c', 'i', 'n', 'e', '\n',
        'm', 'e', 'd', 'i', 'c', 'i', 'n', 'e', 's', '\n',
        'm', 'e', 'd', 'i', 'c', 's', '\n',
        'm', 'e', 'd', 'i', 'e', 'v', 'a', 'l', '\n',
        'm', 'e', 'd', 'i', 'e', 'v', 'a', 'l', 'i', 's', 't', '\n',
        'm', 'e', 'd', 'i', 'e', 'v', 'a', 'l', 'i', 's', 't', 's', '\n',
        'm', 'e', 'd', 'i', 'o', 'c', 'r', 'e', '\n',
        'm', 'e', 'd', 'i', 'o', 'c', 'r', 'i', 't', 'y', '\n',
        'm', 'e', 'd', 'i', 't', 'a', 't', 'e', '\n',
        'm', 'e', 'd', 'i', 't', 'a', 't', 'e', 'd', '\n',
        'm', 'e', 'd', 'i', 't', 'a', 't', 'e', 's', '\n',
        'm', 'e', 'd', 'i', 't', 'a', 't', 'i', 'n', 'g', '\n',
        'm', 'e', 'd', 'i', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'e', 'd', 'i', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'm', 'e', 'd', 'i', 't', 'a', 't', 'i', 'v', 'e', '\n',
        'm', 'e', 'd', 'i', 't', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'm', 'e', 'd', 'i', 't', 'a', 't', 'o', 'r', '\n',
        'm', 'e', 'd', 'i', 'u', 'm', '\n',
        'm', 'e', 'd', 'i', 'u', 'm', 's', '\n',
        'm', 'e', 'd', 'i', 'u', 'm', 's', 'i', 'z', 'e', 'd', '\n',
        'm', 'e', 'd', 'l', 'a', 'r', '\n',
        'm', 'e', 'd', 'l', 'e', 'y', '\n',
        'm', 'e', 'd', 'l', 'e', 'y', 's', '\n',
        'm', 'e', 'd', 'u', 'l', 'l', 'a', '\n',
        'm', 'e', 'd', 'u', 's', 'a', '\n',
        'm', 'e', 'e', 'k', '\n',
        'm', 'e', 'e', 'k', 'e', 'r', '\n',
        'm', 'e', 'e', 'k', 'e', 's', 't', '\n',
        'm', 'e', 'e', 'k', 'l', 'y', '\n',
        'm', 'e', 'e', 'k', 'n', 'e', 's', 's', '\n',
        'm', 'e', 'e', 't', '\n',
        'm', 'e', 'e', 't', 'e', 'r', '\n',
        'm', 'e', 'e', 't', 'i', 'n', 'g', '\n',
        'm', 'e', 'e', 't', 'i', 'n', 'g', 's', '\n',
        'm', 'e', 'e', 't', 's', '\n',
        'm', 'e', 'g', 'a', '\n',
        'm', 'e', 'g', 'a', 'b', 'y', 't', 'e', '\n',
        'm', 'e', 'g', 'a', 'b', 'y', 't', 'e', 's', '\n',
        'm', 'e', 'g', 'a', 'h', 'e', 'r', 't', 'z', '\n',
        'm', 'e', 'g', 'a', 'j', 'o', 'u', 'l', 'e', 's', '\n',
        'm', 'e', 'g', 'a', 'l', 'i', 't', 'h', '\n',
        'm', 'e', 'g', 'a', 'l', 'i', 't', 'h', 'i', 'c', '\n',
        'm', 'e', 'g', 'a', 'l', 'o', 'm', 'a', 'n', 'i', 'a', '\n',
        'm', 'e', 'g', 'a', 'l', 'o', 'm', 'a', 'n', 'i', 'a', 'c', '\n',
        'm', 'e', 'g', 'a', 'l', 'o', 'm', 'a', 'n', 'i', 'a', 'c', 's', '\n',
        'm', 'e', 'g', 'a', 'p', 'a', 'r', 's', 'e', 'c', '\n',
        'm', 'e', 'g', 'a', 'p', 'h', 'o', 'n', 'e', '\n',
        'm', 'e', 'g', 'a', 's', 't', 'a', 'r', '\n',
        'm', 'e', 'g', 'a', 't', 'o', 'n', '\n',
        'm', 'e', 'g', 'a', 't', 'o', 'n', 's', '\n',
        'm', 'e', 'g', 'a', 'v', 'o', 'l', 't', '\n',
        'm', 'e', 'g', 'a', 'w', 'a', 't', 't', '\n',
        'm', 'e', 'g', 'a', 'w', 'a', 't', 't', 's', '\n',
        'm', 'e', 'i', 'o', 's', 'i', 's', '\n',
        'm', 'e', 'i', 'o', 't', 'i', 'c', '\n',
        'm', 'e', 'l', 'a', 'n', 'c', 'h', 'o', 'l', 'i', 'a', '\n',
        'm', 'e', 'l', 'a', 'n', 'c', 'h', 'o', 'l', 'i', 'c', '\n',
        'm', 'e', 'l', 'a', 'n', 'c', 'h', 'o', 'l', 'i', 'e', 's', '\n',
        'm', 'e', 'l', 'a', 'n', 'c', 'h', 'o', 'l', 'y', '\n',
        'm', 'e', 'l', 'a', 'n', 'g', 'e', '\n',
        'm', 'e', 'l', 'a', 'n', 'i', 'n', '\n',
        'm', 'e', 'l', 'a', 'n', 'o', 'm', 'a', '\n',
        'm', 'e', 'l', 'a', 'n', 'o', 'm', 'a', 's', '\n',
        'm', 'e', 'l', 'a', 't', 'o', 'n', 'i', 'n', '\n',
        'm', 'e', 'l', 'd', '\n',
        'm', 'e', 'l', 'e', 'e', '\n',
        'm', 'e', 'l', 'l', 'i', 'f', 'l', 'u', 'o', 'u', 's', '\n',
        'm', 'e', 'l', 'l', 'i', 'f', 'l', 'u', 'o', 'u', 's', 'l', 'y', '\n',
        'm', 'e', 'l', 'l', 'i', 'f', 'l', 'u', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'm', 'e', 'l', 'l', 'o', 'w', '\n',
        'm', 'e', 'l', 'l', 'o', 'w', 'e', 'd', '\n',
        'm', 'e', 'l', 'l', 'o', 'w', 'e', 'r', '\n',
        'm', 'e', 'l', 'l', 'o', 'w', 'i', 'n', 'g', '\n',
        'm', 'e', 'l', 'l', 'o', 'w', 's', '\n',
        'm', 'e', 'l', 'o', 'd', 'i', 'c', '\n',
        'm', 'e', 'l', 'o', 'd', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'm', 'e', 'l', 'o', 'd', 'i', 'e', 's', '\n',
        'm', 'e', 'l', 'o', 'd', 'i', 'o', 'u', 's', '\n',
        'm', 'e', 'l', 'o', 'd', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'm', 'e', 'l', 'o', 'd', 'r', 'a', 'm', 'a', '\n',
        'm', 'e', 'l', 'o', 'd', 'r', 'a', 'm', 'a', 's', '\n',
        'm', 'e', 'l', 'o', 'd', 'r', 'a', 'm', 'a', 't', 'i', 'c', '\n',
        'm', 'e', 'l', 'o', 'd', 'r', 'a', 'm', 'a', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'm', 'e', 'l', 'o', 'd', 'y', '\n',
        'm', 'e', 'l', 'o', 'n', '\n',
        'm', 'e', 'l', 'o', 'n', 's', '\n',
        'm', 'e', 'l', 't', '\n',
        'm', 'e', 'l', 't', 'd', 'o', 'w', 'n', '\n',
        'm', 'e', 'l', 't', 'e', 'd', '\n',
        'm', 'e', 'l', 't', 'e', 'r', '\n',
        'm', 'e', 'l', 't', 'i', 'n', 'g', '\n',
        'm', 'e', 'l', 't', 's', '\n',
        'm', 'e', 'm', 'b', 'e', 'r', '\n',
        'm', 'e', 'm', 'b', 'e', 'r', 's', '\n',
        'm', 'e', 'm', 'b', 'e', 'r', 's', 'h', 'i', 'p', '\n',
        'm', 'e', 'm', 'b', 'e', 'r', 's', 'h', 'i', 'p', 's', '\n',
        'm', 'e', 'm', 'b', 'r', 'a', 'n', 'e', '\n',
        'm', 'e', 'm', 'b', 'r', 'a', 'n', 'e', 's', '\n',
        'm', 'e', 'm', 'e', 'n', 't', 'o', '\n',
        'm', 'e', 'm', 'o', '\n',
        'm', 'e', 'm', 'o', 'i', 'r', '\n',
        'm', 'e', 'm', 'o', 'i', 'r', 's', '\n',
        'm', 'e', 'm', 'o', 'r', 'a', 'b', 'i', 'l', 'i', 'a', '\n',
        'm', 'e', 'm', 'o', 'r', 'a', 'b', 'l', 'e', '\n',
        'm', 'e', 'm', 'o', 'r', 'a', 'b', 'l', 'y', '\n',
        'm', 'e', 'm', 'o', 'r', 'a', 'n', 'd', 'a', '\n',
        'm', 'e', 'm', 'o', 'r', 'a', 'n', 'd', 'u', 'm', '\n',
        'm', 'e', 'm', 'o', 'r', 'a', 'n', 'd', 'u', 'm', 's', '\n',
        'm', 'e', 'm', 'o', 'r', 'i', 'a', 'l', '\n',
        'm', 'e', 'm', 'o', 'r', 'i', 'a', 'l', 's', '\n',
        'm', 'e', 'm', 'o', 'r', 'i', 'e', 's', '\n',
        'm', 'e', 'm', 'o', 'r', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'e', 'm', 'o', 'r', 'i', 's', 'e', '\n',
        'm', 'e', 'm', 'o', 'r', 'i', 's', 'e', 'd', '\n',
        'm', 'e', 'm', 'o', 'r', 'i', 's', 'e', 's', '\n',
        'm', 'e', 'm', 'o', 'r', 'i', 's', 'i', 'n', 'g', '\n',
        'm', 'e', 'm', 'o', 'r', 'y', '\n',
        'm', 'e', 'm', 'p', 'h', 'i', 's', '\n',
        'm', 'e', 'n', '\n',
        'm', 'e', 'n', 'a', 'c', 'e', '\n',
        'm', 'e', 'n', 'a', 'c', 'e', 'd', '\n',
        'm', 'e', 'n', 'a', 'c', 'e', 's', '\n',
        'm', 'e', 'n', 'a', 'c', 'i', 'n', 'g', '\n',
        'm', 'e', 'n', 'a', 'c', 'i', 'n', 'g', 'l', 'y', '\n',
        'm', 'e', 'n', 'a', 'g', 'e', 'r', 'i', 'e', '\n',
        'm', 'e', 'n', 'a', 'r', 'c', 'h', 'e', '\n',
        'm', 'e', 'n', 'd', '\n',
        'm', 'e', 'n', 'd', 'a', 'c', 'i', 'o', 'u', 's', '\n',
        'm', 'e', 'n', 'd', 'a', 'c', 'i', 't', 'y', '\n',
        'm', 'e', 'n', 'd', 'e', 'd', '\n',
        'm', 'e', 'n', 'd', 'e', 'l', '\n',
        'm', 'e', 'n', 'd', 'e', 'l', 'e', 'v', 'i', 'u', 'm', '\n',
        'm', 'e', 'n', 'd', 'e', 'r', '\n',
        'm', 'e', 'n', 'd', 'e', 'r', 's', '\n',
        'm', 'e', 'n', 'd', 'i', 'c', 'a', 'n', 't', '\n',
        'm', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'm', 'e', 'n', 'd', 's', '\n',
        'm', 'e', 'n', 'f', 'o', 'l', 'k', '\n',
        'm', 'e', 'n', 'h', 'i', 'r', '\n',
        'm', 'e', 'n', 'h', 'i', 'r', 's', '\n',
        'm', 'e', 'n', 'i', 'a', 'l', '\n',
        'm', 'e', 'n', 'i', 'n', 'g', 'i', 't', 'i', 's', '\n',
        'm', 'e', 'n', 'i', 's', 'c', 'u', 's', '\n',
        'm', 'e', 'n', 'o', 'p', 'a', 'u', 's', 'a', 'l', '\n',
        'm', 'e', 'n', 'o', 'p', 'a', 'u', 's', 'e', '\n',
        'm', 'e', 'n', 'o', 'r', 'a', 'h', '\n',
        'm', 'e', 'n', 's', 't', 'r', 'u', 'a', 'l', '\n',
        'm', 'e', 'n', 's', 't', 'r', 'u', 'a', 't', 'i', 'n', 'g', '\n',
        'm', 'e', 'n', 's', 't', 'r', 'u', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'e', 'n', 's', 'w', 'e', 'a', 'r', '\n',
        'm', 'e', 'n', 't', 'a', 'l', '\n',
        'm', 'e', 'n', 't', 'a', 'l', 'i', 's', 't', 'i', 'c', '\n',
        'm', 'e', 'n', 't', 'a', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'm', 'e', 'n', 't', 'a', 'l', 'i', 't', 'y', '\n',
        'm', 'e', 'n', 't', 'a', 'l', 'l', 'y', '\n',
        'm', 'e', 'n', 't', 'h', 'o', 'l', '\n',
        'm', 'e', 'n', 't', 'i', 'o', 'n', '\n',
        'm', 'e', 'n', 't', 'i', 'o', 'n', 'a', 'b', 'l', 'e', '\n',
        'm', 'e', 'n', 't', 'i', 'o', 'n', 'e', 'd', '\n',
        'm', 'e', 'n', 't', 'i', 'o', 'n', 'i', 'n', 'g', '\n',
        'm', 'e', 'n', 't', 'i', 'o', 'n', 's', '\n',
        'm', 'e', 'n', 't', 'o', 'r', '\n',
        'm', 'e', 'n', 't', 'o', 'r', 's', '\n',
        'm', 'e', 'n', 'u', '\n',
        'm', 'e', 'n', 'u', 's', '\n',
        'm', 'e', 'o', 'w', '\n',
        'm', 'e', 'o', 'w', 's', '\n',
        'm', 'e', 'r', 'c', 'a', 'n', 't', 'i', 'l', 'e', '\n',
        'm', 'e', 'r', 'c', 'e', 'n', 'a', 'r', 'i', 'e', 's', '\n',
        'm', 'e', 'r', 'c', 'e', 'n', 'a', 'r', 'y', '\n',
        'm', 'e', 'r', 'c', 'h', 'a', 'n', 'd', 'i', 's', 'e', '\n',
        'm', 'e', 'r', 'c', 'h', 'a', 'n', 'd', 'i', 's', 'i', 'n', 'g', '\n',
        'm', 'e', 'r', 'c', 'h', 'a', 'n', 't', '\n',
        'm', 'e', 'r', 'c', 'h', 'a', 'n', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'm', 'e', 'r', 'c', 'h', 'a', 'n', 't', 'a', 'b', 'l', 'e', '\n',
        'm', 'e', 'r', 'c', 'h', 'a', 'n', 't', 'm', 'a', 'n', '\n',
        'm', 'e', 'r', 'c', 'h', 'a', 'n', 't', 'm', 'e', 'n', '\n',
        'm', 'e', 'r', 'c', 'h', 'a', 'n', 't', 's', '\n',
        'm', 'e', 'r', 'c', 'i', 'e', 's', '\n',
        'm', 'e', 'r', 'c', 'i', 'f', 'u', 'l', '\n',
        'm', 'e', 'r', 'c', 'i', 'f', 'u', 'l', 'l', 'y', '\n',
        'm', 'e', 'r', 'c', 'i', 'l', 'e', 's', 's', '\n',
        'm', 'e', 'r', 'c', 'i', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'm', 'e', 'r', 'c', 'u', 'r', 'i', 'a', 'l', '\n',
        'm', 'e', 'r', 'c', 'u', 'r', 'i', 'c', '\n',
        'm', 'e', 'r', 'c', 'u', 'r', 'y', '\n',
        'm', 'e', 'r', 'c', 'y', '\n',
        'm', 'e', 'r', 'e', '\n',
        'm', 'e', 'r', 'e', 'l', 'y', '\n',
        'm', 'e', 'r', 'e', 's', 't', '\n',
        'm', 'e', 'r', 'e', 't', 'r', 'i', 'c', 'i', 'o', 'u', 's', '\n',
        'm', 'e', 'r', 'g', 'e', '\n',
        'm', 'e', 'r', 'g', 'e', 'd', '\n',
        'm', 'e', 'r', 'g', 'e', 'r', '\n',
        'm', 'e', 'r', 'g', 'e', 'r', 's', '\n',
        'm', 'e', 'r', 'g', 'e', 's', '\n',
        'm', 'e', 'r', 'g', 'i', 'n', 'g', '\n',
        'm', 'e', 'r', 'i', 'd', 'i', 'a', 'n', '\n',
        'm', 'e', 'r', 'i', 'd', 'i', 'a', 'n', 's', '\n',
        'm', 'e', 'r', 'i', 'd', 'i', 'o', 'n', 'a', 'l', '\n',
        'm', 'e', 'r', 'i', 'n', 'g', 'u', 'e', '\n',
        'm', 'e', 'r', 'i', 'n', 'g', 'u', 'e', 's', '\n',
        'm', 'e', 'r', 'i', 'n', 'o', '\n',
        'm', 'e', 'r', 'i', 't', '\n',
        'm', 'e', 'r', 'i', 't', 'e', 'd', '\n',
        'm', 'e', 'r', 'i', 't', 'i', 'n', 'g', '\n',
        'm', 'e', 'r', 'i', 't', 'o', 'c', 'r', 'a', 'c', 'y', '\n',
        'm', 'e', 'r', 'i', 't', 'o', 'c', 'r', 'a', 't', 'i', 'c', '\n',
        'm', 'e', 'r', 'i', 't', 'o', 'c', 'r', 'a', 't', 's', '\n',
        'm', 'e', 'r', 'i', 't', 'o', 'r', 'i', 'o', 'u', 's', '\n',
        'm', 'e', 'r', 'i', 't', 's', '\n',
        'm', 'e', 'r', 'm', 'a', 'i', 'd', '\n',
        'm', 'e', 'r', 'm', 'a', 'i', 'd', 's', '\n',
        'm', 'e', 'r', 'm', 'a', 'n', '\n',
        'm', 'e', 'r', 'm', 'e', 'n', '\n',
        'm', 'e', 'r', 'o', 'm', 'o', 'r', 'p', 'h', 'i', 'c', '\n',
        'm', 'e', 'r', 'r', 'i', 'e', 'r', '\n',
        'm', 'e', 'r', 'r', 'i', 'e', 's', 't', '\n',
        'm', 'e', 'r', 'r', 'i', 'l', 'y', '\n',
        'm', 'e', 'r', 'r', 'i', 'm', 'e', 'n', 't', '\n',
        'm', 'e', 'r', 'r', 'y', '\n',
        'm', 'e', 'r', 'r', 'y', 'g', 'o', 'r', 'o', 'u', 'n', 'd', '\n',
        'm', 'e', 'r', 'r', 'y', 'g', 'o', 'r', 'o', 'u', 'n', 'd', 's', '\n',
        'm', 'e', 'r', 'r', 'y', 'm', 'a', 'k', 'i', 'n', 'g', '\n',
        'm', 'e', 's', 'c', 'a', 'l', 'i', 'n', 'e', '\n',
        'm', 'e', 's', 'h', '\n',
        'm', 'e', 's', 'h', 'e', 'd', '\n',
        'm', 'e', 's', 'h', 'e', 's', '\n',
        'm', 'e', 's', 'h', 'i', 'n', 'g', '\n',
        'm', 'e', 's', 'm', 'e', 'r', 'i', 'c', '\n',
        'm', 'e', 's', 'm', 'e', 'r', 'i', 's', 'e', 'd', '\n',
        'm', 'e', 's', 'm', 'e', 'r', 'i', 's', 'i', 'n', 'g', '\n',
        'm', 'e', 's', 'o', 'l', 'i', 't', 'h', 'i', 'c', '\n',
        'm', 'e', 's', 'o', 'n', '\n',
        'm', 'e', 's', 'o', 'n', 's', '\n',
        'm', 'e', 's', 'o', 's', 'p', 'h', 'e', 'r', 'e', '\n',
        'm', 'e', 's', 'o', 'z', 'o', 'i', 'c', '\n',
        'm', 'e', 's', 's', '\n',
        'm', 'e', 's', 's', 'a', 'g', 'e', '\n',
        'm', 'e', 's', 's', 'a', 'g', 'e', 's', '\n',
        'm', 'e', 's', 's', 'a', 'g', 'i', 'n', 'g', '\n',
        'm', 'e', 's', 's', 'e', 'd', '\n',
        'm', 'e', 's', 's', 'e', 'n', 'g', 'e', 'r', '\n',
        'm', 'e', 's', 's', 'e', 'n', 'g', 'e', 'r', 's', '\n',
        'm', 'e', 's', 's', 'e', 's', '\n',
        'm', 'e', 's', 's', 'i', 'a', 'h', '\n',
        'm', 'e', 's', 's', 'i', 'e', 'r', '\n',
        'm', 'e', 's', 's', 'i', 'e', 's', 't', '\n',
        'm', 'e', 's', 's', 'i', 'l', 'y', '\n',
        'm', 'e', 's', 's', 'i', 'n', 'e', 's', 's', '\n',
        'm', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'm', 'e', 's', 's', 'y', '\n',
        'm', 'e', 's', 't', 'i', 'z', 'o', '\n',
        'm', 'e', 't', '\n',
        'm', 'e', 't', 'a', 'b', 'o', 'l', 'i', 'c', '\n',
        'm', 'e', 't', 'a', 'b', 'o', 'l', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'm', 'e', 't', 'a', 'b', 'o', 'l', 'i', 's', 'e', '\n',
        'm', 'e', 't', 'a', 'b', 'o', 'l', 'i', 's', 'e', 'd', '\n',
        'm', 'e', 't', 'a', 'b', 'o', 'l', 'i', 's', 'e', 's', '\n',
        'm', 'e', 't', 'a', 'b', 'o', 'l', 'i', 's', 'm', '\n',
        'm', 'e', 't', 'a', 'b', 'o', 'l', 'i', 's', 'm', 's', '\n',
        'm', 'e', 't', 'a', 'l', '\n',
        'm', 'e', 't', 'a', 'l', 'a', 'n', 'g', 'u', 'a', 'g', 'e', '\n',
        'm', 'e', 't', 'a', 'l', 'i', 'n', 'g', 'u', 'i', 's', 't', 'i', 'c', '\n',
        'm', 'e', 't', 'a', 'l', 'l', 'e', 'd', '\n',
        'm', 'e', 't', 'a', 'l', 'l', 'i', 'c', '\n',
        'm', 'e', 't', 'a', 'l', 'l', 'i', 's', 'e', 'd', '\n',
        'm', 'e', 't', 'a', 'l', 'l', 'u', 'r', 'g', 'i', 'c', 'a', 'l', '\n',
        'm', 'e', 't', 'a', 'l', 'l', 'u', 'r', 'g', 'i', 's', 't', '\n',
        'm', 'e', 't', 'a', 'l', 'l', 'u', 'r', 'g', 'y', '\n',
        'm', 'e', 't', 'a', 'l', 's', '\n',
        'm', 'e', 't', 'a', 'l', 'w', 'o', 'r', 'k', '\n',
        'm', 'e', 't', 'a', 'l', 'w', 'o', 'r', 'k', 'i', 'n', 'g', '\n',
        'm', 'e', 't', 'a', 'm', 'o', 'r', 'p', 'h', 'i', 'c', '\n',
        'm', 'e', 't', 'a', 'm', 'o', 'r', 'p', 'h', 'i', 's', 'm', '\n',
        'm', 'e', 't', 'a', 'm', 'o', 'r', 'p', 'h', 'o', 's', 'e', '\n',
        'm', 'e', 't', 'a', 'm', 'o', 'r', 'p', 'h', 'o', 's', 'e', 'd', '\n',
        'm', 'e', 't', 'a', 'm', 'o', 'r', 'p', 'h', 'o', 's', 'e', 's', '\n',
        'm', 'e', 't', 'a', 'm', 'o', 'r', 'p', 'h', 'o', 's', 'i', 's', '\n',
        'm', 'e', 't', 'a', 'p', 'h', 'o', 'r', '\n',
        'm', 'e', 't', 'a', 'p', 'h', 'o', 'r', 'i', 'c', '\n',
        'm', 'e', 't', 'a', 'p', 'h', 'o', 'r', 'i', 'c', 'a', 'l', '\n',
        'm', 'e', 't', 'a', 'p', 'h', 'o', 'r', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'm', 'e', 't', 'a', 'p', 'h', 'o', 'r', 's', '\n',
        'm', 'e', 't', 'a', 'p', 'h', 'y', 's', 'i', 'c', 'a', 'l', '\n',
        'm', 'e', 't', 'a', 'p', 'h', 'y', 's', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'm', 'e', 't', 'a', 'p', 'h', 'y', 's', 'i', 'c', 's', '\n',
        'm', 'e', 't', 'a', 's', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'm', 'e', 't', 'a', 's', 't', 'a', 'b', 'l', 'e', '\n',
        'm', 'e', 't', 'a', 's', 't', 'a', 's', 'e', 's', '\n',
        'm', 'e', 't', 'a', 's', 't', 'a', 's', 'i', 's', '\n',
        'm', 'e', 't', 'a', 's', 't', 'a', 't', 'i', 'c', '\n',
        'm', 'e', 't', 'a', 't', 'a', 'r', 's', 'a', 'l', '\n',
        'm', 'e', 't', 'e', 'd', '\n',
        'm', 'e', 't', 'e', 'm', 'p', 's', 'y', 'c', 'h', 'o', 's', 'i', 's', '\n',
        'm', 'e', 't', 'e', 'o', 'r', '\n',
        'm', 'e', 't', 'e', 'o', 'r', 'i', 'c', '\n',
        'm', 'e', 't', 'e', 'o', 'r', 'i', 't', 'e', '\n',
        'm', 'e', 't', 'e', 'o', 'r', 'i', 't', 'e', 's', '\n',
        'm', 'e', 't', 'e', 'o', 'r', 'i', 't', 'i', 'c', '\n',
        'm', 'e', 't', 'e', 'o', 'r', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'm', 'e', 't', 'e', 'o', 'r', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'm', 'e', 't', 'e', 'o', 'r', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'm', 'e', 't', 'e', 'o', 'r', 'o', 'l', 'o', 'g', 'y', '\n',
        'm', 'e', 't', 'e', 'o', 'r', 's', '\n',
        'm', 'e', 't', 'e', 'r', '\n',
        'm', 'e', 't', 'e', 'r', 'e', 'd', '\n',
        'm', 'e', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'm', 'e', 't', 'e', 'r', 's', '\n',
        'm', 'e', 't', 'h', 'a', 'd', 'o', 'n', 'e', '\n',
        'm', 'e', 't', 'h', 'a', 'n', 'e', '\n',
        'm', 'e', 't', 'h', 'a', 'n', 'o', 'l', '\n',
        'm', 'e', 't', 'h', 'i', 'o', 'n', 'i', 'n', 'e', '\n',
        'm', 'e', 't', 'h', 'o', 'd', '\n',
        'm', 'e', 't', 'h', 'o', 'd', 'i', 'c', 'a', 'l', '\n',
        'm', 'e', 't', 'h', 'o', 'd', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'm', 'e', 't', 'h', 'o', 'd', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'm', 'e', 't', 'h', 'o', 'd', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'm', 'e', 't', 'h', 'o', 'd', 'o', 'l', 'o', 'g', 'i', 'e', 's', '\n',
        'm', 'e', 't', 'h', 'o', 'd', 'o', 'l', 'o', 'g', 'y', '\n',
        'm', 'e', 't', 'h', 'o', 'd', 's', '\n',
        'm', 'e', 't', 'h', 'y', 'l', '\n',
        'm', 'e', 't', 'h', 'y', 'l', 'a', 't', 'e', 'd', '\n',
        'm', 'e', 't', 'h', 'y', 'l', 'e', 'n', 'e', '\n',
        'm', 'e', 't', 'i', 'c', 'u', 'l', 'o', 'u', 's', '\n',
        'm', 'e', 't', 'i', 'c', 'u', 'l', 'o', 'u', 's', 'l', 'y', '\n',
        'm', 'e', 't', 'i', 'e', 'r', '\n',
        'm', 'e', 't', 'o', 'n', 'y', 'm', 'i', 'c', '\n',
        'm', 'e', 't', 'o', 'n', 'y', 'm', 'y', '\n',
        'm', 'e', 't', 'r', 'e', '\n',
        'm', 'e', 't', 'r', 'e', 's', '\n',
        'm', 'e', 't', 'r', 'i', 'c', '\n',
        'm', 'e', 't', 'r', 'i', 'c', 'a', 'l', '\n',
        'm', 'e', 't', 'r', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'm', 'e', 't', 'r', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'e', 't', 'r', 'i', 'c', 's', '\n',
        'm', 'e', 't', 'r', 'o', '\n',
        'm', 'e', 't', 'r', 'o', 'n', 'o', 'm', 'e', '\n',
        'm', 'e', 't', 'r', 'o', 'n', 'o', 'm', 'e', 's', '\n',
        'm', 'e', 't', 'r', 'o', 'n', 'o', 'm', 'i', 'c', '\n',
        'm', 'e', 't', 'r', 'o', 'p', 'o', 'l', 'i', 's', '\n',
        'm', 'e', 't', 'r', 'o', 'p', 'o', 'l', 'i', 's', 'e', 's', '\n',
        'm', 'e', 't', 'r', 'o', 'p', 'o', 'l', 'i', 't', 'a', 'n', '\n',
        'm', 'e', 't', 't', 'l', 'e', '\n',
        'm', 'e', 'w', '\n',
        'm', 'e', 'w', 'i', 'n', 'g', '\n',
        'm', 'e', 'w', 's', '\n',
        'm', 'e', 'x', 'i', 'c', 'a', 'n', '\n',
        'm', 'e', 'x', 'i', 'c', 'a', 'n', 's', '\n',
        'm', 'e', 'x', 'i', 'c', 'o', '\n',
        'm', 'e', 'z', 'z', 'a', 'n', 'i', 'n', 'e', '\n',
        'm', 'e', 'z', 'z', 'o', 's', 'o', 'p', 'r', 'a', 'n', 'o', '\n',
        'm', 'i', 'a', 'm', 'i', '\n',
        'm', 'i', 'a', 's', 'm', 'a', '\n',
        'm', 'i', 'c', 'a', '\n',
        'm', 'i', 'c', 'e', '\n',
        'm', 'i', 'c', 'e', 'l', 'l', 'e', 's', '\n',
        'm', 'i', 'c', 'h', 'i', 'g', 'a', 'n', '\n',
        'm', 'i', 'c', 'r', 'o', '\n',
        'm', 'i', 'c', 'r', 'o', 'a', 'n', 'a', 'l', 'y', 's', 'e', 's', '\n',
        'm', 'i', 'c', 'r', 'o', 'b', 'e', '\n',
        'm', 'i', 'c', 'r', 'o', 'b', 'e', 's', '\n',
        'm', 'i', 'c', 'r', 'o', 'b', 'i', 'a', 'l', '\n',
        'm', 'i', 'c', 'r', 'o', 'b', 'i', 'c', '\n',
        'm', 'i', 'c', 'r', 'o', 'b', 'i', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'm', 'i', 'c', 'r', 'o', 'b', 'i', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'm', 'i', 'c', 'r', 'o', 'b', 'i', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'm', 'i', 'c', 'r', 'o', 'b', 'i', 'o', 'l', 'o', 'g', 'y', '\n',
        'm', 'i', 'c', 'r', 'o', 'c', 'h', 'i', 'p', '\n',
        'm', 'i', 'c', 'r', 'o', 'c', 'h', 'i', 'p', 's', '\n',
        'm', 'i', 'c', 'r', 'o', 'c', 'o', 'd', 'e', '\n',
        'm', 'i', 'c', 'r', 'o', 'c', 'o', 'm', 'p', 'u', 't', 'e', 'r', '\n',
        'm', 'i', 'c', 'r', 'o', 'c', 'o', 'm', 'p', 'u', 't', 'e', 'r', 's', '\n',
        'm', 'i', 'c', 'r', 'o', 'c', 'o', 's', 'm', '\n',
        'm', 'i', 'c', 'r', 'o', 'c', 'o', 's', 'm', 'i', 'c', '\n',
        'm', 'i', 'c', 'r', 'o', 'd', 'e', 'n', 's', 'i', 't', 'o', 'm', 'e', 't', 'e', 'r', '\n',
        'm', 'i', 'c', 'r', 'o', 'd', 'o', 't', '\n',
        'm', 'i', 'c', 'r', 'o', 'e', 'l', 'e', 'c', 't', 'r', 'o', 'n', 'i', 'c', '\n',
        'm', 'i', 'c', 'r', 'o', 'e', 'l', 'e', 'c', 't', 'r', 'o', 'n', 'i', 'c', 's', '\n',
        'm', 'i', 'c', 'r', 'o', 'f', 'a', 'r', 'a', 'd', '\n',
        'm', 'i', 'c', 'r', 'o', 'f', 'i', 'c', 'h', 'e', '\n',
        'm', 'i', 'c', 'r', 'o', 'f', 'i', 'l', 'm', '\n',
        'm', 'i', 'c', 'r', 'o', 'f', 'i', 'l', 'm', 'i', 'n', 'g', '\n',
        'm', 'i', 'c', 'r', 'o', 'g', 'r', 'a', 'm', 'm', 'e', 's', '\n',
        'm', 'i', 'c', 'r', 'o', 'g', 'r', 'a', 'm', 's', '\n',
        'm', 'i', 'c', 'r', 'o', 'g', 'r', 'a', 'p', 'h', '\n',
        'm', 'i', 'c', 'r', 'o', 'g', 'r', 'a', 'p', 'h', 's', '\n',
        'm', 'i', 'c', 'r', 'o', 'g', 'r', 'a', 'v', 'i', 't', 'y', '\n',
        'm', 'i', 'c', 'r', 'o', 'h', 'y', 'd', 'r', 'o', 'd', 'y', 'n', 'a', 'm', 'i', 'c', 's', '\n',
        'm', 'i', 'c', 'r', 'o', 'l', 'i', 'g', 'h', 't', '\n',
        'm', 'i', 'c', 'r', 'o', 'm', 'e', 't', 'e', 'r', '\n',
        'm', 'i', 'c', 'r', 'o', 'm', 'e', 't', 'e', 'r', 's', '\n',
        'm', 'i', 'c', 'r', 'o', 'm', 'e', 't', 'r', 'e', 's', '\n',
        'm', 'i', 'c', 'r', 'o', 'n', '\n',
        'm', 'i', 'c', 'r', 'o', 'n', 's', '\n',
        'm', 'i', 'c', 'r', 'o', 'o', 'r', 'g', 'a', 'n', 'i', 's', 'm', '\n',
        'm', 'i', 'c', 'r', 'o', 'o', 'r', 'g', 'a', 'n', 'i', 's', 'm', 's', '\n',
        'm', 'i', 'c', 'r', 'o', 'p', 'h', 'o', 'n', 'e', '\n',
        'm', 'i', 'c', 'r', 'o', 'p', 'h', 'o', 'n', 'e', 's', '\n',
        'm', 'i', 'c', 'r', 'o', 'p', 'r', 'o', 'c', 'e', 's', 's', 'o', 'r', '\n',
        'm', 'i', 'c', 'r', 'o', 'p', 'r', 'o', 'c', 'e', 's', 's', 'o', 'r', 's', '\n',
        'm', 'i', 'c', 'r', 'o', 'p', 'r', 'o', 'g', 'r', 'a', 'm', '\n',
        'm', 'i', 'c', 'r', 'o', 's', 'c', 'o', 'p', 'e', '\n',
        'm', 'i', 'c', 'r', 'o', 's', 'c', 'o', 'p', 'e', 's', '\n',
        'm', 'i', 'c', 'r', 'o', 's', 'c', 'o', 'p', 'i', 'c', '\n',
        'm', 'i', 'c', 'r', 'o', 's', 'c', 'o', 'p', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'm', 'i', 'c', 'r', 'o', 's', 'c', 'o', 'p', 'i', 's', 't', '\n',
        'm', 'i', 'c', 'r', 'o', 's', 'c', 'o', 'p', 'y', '\n',
        'm', 'i', 'c', 'r', 'o', 's', 'e', 'c', 'o', 'n', 'd', '\n',
        'm', 'i', 'c', 'r', 'o', 's', 'e', 'c', 'o', 'n', 'd', 's', '\n',
        'm', 'i', 'c', 'r', 'o', 's', 'u', 'r', 'g', 'e', 'r', 'y', '\n',
        'm', 'i', 'c', 'r', 'o', 'w', 'a', 'v', 'e', '\n',
        'm', 'i', 'c', 'r', 'o', 'w', 'a', 'v', 'e', 'a', 'b', 'l', 'e', '\n',
        'm', 'i', 'c', 'r', 'o', 'w', 'a', 'v', 'e', 'd', '\n',
        'm', 'i', 'c', 'r', 'o', 'w', 'a', 'v', 'e', 's', '\n',
        'm', 'i', 'c', 't', 'u', 'r', 'i', 't', 'i', 'o', 'n', '\n',
        'm', 'i', 'd', '\n',
        'm', 'i', 'd', 'a', 'f', 't', 'e', 'r', 'n', 'o', 'o', 'n', '\n',
        'm', 'i', 'd', 'a', 'i', 'r', '\n',
        'm', 'i', 'd', 'a', 's', '\n',
        'm', 'i', 'd', 'd', 'a', 'y', '\n',
        'm', 'i', 'd', 'd', 'a', 'y', 's', '\n',
        'm', 'i', 'd', 'd', 'e', 'n', '\n',
        'm', 'i', 'd', 'd', 'l', 'e', '\n',
        'm', 'i', 'd', 'd', 'l', 'e', 'a', 'g', 'e', '\n',
        'm', 'i', 'd', 'd', 'l', 'e', 'a', 'g', 'e', 'd', '\n',
        'm', 'i', 'd', 'd', 'l', 'e', 'c', 'l', 'a', 's', 's', '\n',
        'm', 'i', 'd', 'd', 'l', 'e', 'm', 'a', 'n', '\n',
        'm', 'i', 'd', 'd', 'l', 'e', 'm', 'e', 'n', '\n',
        'm', 'i', 'd', 'd', 'l', 'e', 'o', 'f', 't', 'h', 'e', 'r', 'o', 'a', 'd', '\n',
        'm', 'i', 'd', 'd', 'l', 'e', 's', '\n',
        'm', 'i', 'd', 'd', 'l', 'e', 's', 'i', 'z', 'e', 'd', '\n',
        'm', 'i', 'd', 'd', 'l', 'e', 'w', 'e', 'i', 'g', 'h', 't', '\n',
        'm', 'i', 'd', 'd', 'l', 'i', 'n', 'g', '\n',
        'm', 'i', 'd', 'e', 'v', 'e', 'n', 'i', 'n', 'g', '\n',
        'm', 'i', 'd', 'f', 'i', 'e', 'l', 'd', '\n',
        'm', 'i', 'd', 'f', 'i', 'e', 'l', 'd', 'e', 'r', '\n',
        'm', 'i', 'd', 'f', 'i', 'e', 'l', 'd', 'e', 'r', 's', '\n',
        'm', 'i', 'd', 'f', 'l', 'i', 'g', 'h', 't', '\n',
        'm', 'i', 'd', 'g', 'e', '\n',
        'm', 'i', 'd', 'g', 'e', 's', '\n',
        'm', 'i', 'd', 'g', 'e', 't', '\n',
        'm', 'i', 'd', 'g', 'e', 't', 's', '\n',
        'm', 'i', 'd', 'i', '\n',
        'm', 'i', 'd', 'l', 'a', 'n', 'd', '\n',
        'm', 'i', 'd', 'l', 'a', 'n', 'd', 's', '\n',
        'm', 'i', 'd', 'l', 'i', 'f', 'e', '\n',
        'm', 'i', 'd', 'l', 'i', 'n', 'e', '\n',
        'm', 'i', 'd', 'm', 'o', 'r', 'n', 'i', 'n', 'g', '\n',
        'm', 'i', 'd', 'm', 'o', 's', 't', '\n',
        'm', 'i', 'd', 'n', 'i', 'g', 'h', 't', '\n',
        'm', 'i', 'd', 'n', 'i', 'g', 'h', 't', 's', '\n',
        'm', 'i', 'd', 'r', 'i', 'b', 's', '\n',
        'm', 'i', 'd', 'r', 'i', 'f', 'f', '\n',
        'm', 'i', 'd', 's', 'h', 'i', 'p', '\n',
        'm', 'i', 'd', 's', 'h', 'i', 'p', 'm', 'a', 'n', '\n',
        'm', 'i', 'd', 's', 'h', 'i', 'p', 's', '\n',
        'm', 'i', 'd', 's', 't', '\n',
        'm', 'i', 'd', 's', 't', 'r', 'e', 'a', 'm', '\n',
        'm', 'i', 'd', 's', 'u', 'm', 'm', 'e', 'r', '\n',
        'm', 'i', 'd', 'w', 'a', 'y', '\n',
        'm', 'i', 'd', 'w', 'e', 'e', 'k', '\n',
        'm', 'i', 'd', 'w', 'i', 'c', 'k', 'e', 't', '\n',
        'm', 'i', 'd', 'w', 'i', 'f', 'e', '\n',
        'm', 'i', 'd', 'w', 'i', 'f', 'e', 'r', 'y', '\n',
        'm', 'i', 'd', 'w', 'i', 'n', 't', 'e', 'r', '\n',
        'm', 'i', 'd', 'w', 'i', 'v', 'e', 's', '\n',
        'm', 'i', 'e', 'n', '\n',
        'm', 'i', 'g', 'h', 't', '\n',
        'm', 'i', 'g', 'h', 't', 'i', 'e', 'r', '\n',
        'm', 'i', 'g', 'h', 't', 'i', 'e', 's', 't', '\n',
        'm', 'i', 'g', 'h', 't', 'i', 'l', 'y', '\n',
        'm', 'i', 'g', 'h', 't', 's', '\n',
        'm', 'i', 'g', 'h', 't', 'y', '\n',
        'm', 'i', 'g', 'r', 'a', 'i', 'n', 'e', '\n',
        'm', 'i', 'g', 'r', 'a', 'i', 'n', 'e', 's', '\n',
        'm', 'i', 'g', 'r', 'a', 'n', 't', '\n',
        'm', 'i', 'g', 'r', 'a', 'n', 't', 's', '\n',
        'm', 'i', 'g', 'r', 'a', 't', 'e', '\n',
        'm', 'i', 'g', 'r', 'a', 't', 'e', 'd', '\n',
        'm', 'i', 'g', 'r', 'a', 't', 'e', 's', '\n',
        'm', 'i', 'g', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'm', 'i', 'g', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'i', 'g', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'm', 'i', 'g', 'r', 'a', 't', 'o', 'r', 'y', '\n',
        'm', 'i', 'k', 'e', '\n',
        'm', 'i', 'k', 'e', 's', '\n',
        'm', 'i', 'l', 'a', 'd', 'y', '\n',
        'm', 'i', 'l', 'a', 'n', '\n',
        'm', 'i', 'l', 'd', '\n',
        'm', 'i', 'l', 'd', 'e', 'r', '\n',
        'm', 'i', 'l', 'd', 'e', 's', 't', '\n',
        'm', 'i', 'l', 'd', 'e', 'w', '\n',
        'm', 'i', 'l', 'd', 'e', 'w', 'e', 'd', '\n',
        'm', 'i', 'l', 'd', 'e', 'w', 's', '\n',
        'm', 'i', 'l', 'd', 'e', 'w', 'y', '\n',
        'm', 'i', 'l', 'd', 'l', 'y', '\n',
        'm', 'i', 'l', 'd', 'm', 'a', 'n', 'n', 'e', 'r', 'e', 'd', '\n',
        'm', 'i', 'l', 'd', 'n', 'e', 's', 's', '\n',
        'm', 'i', 'l', 'e', '\n',
        'm', 'i', 'l', 'e', 'a', 'g', 'e', '\n',
        'm', 'i', 'l', 'e', 'a', 'g', 'e', 's', '\n',
        'm', 'i', 'l', 'e', 'p', 'o', 's', 't', '\n',
        'm', 'i', 'l', 'e', 'p', 'o', 's', 't', 's', '\n',
        'm', 'i', 'l', 'e', 'r', '\n',
        'm', 'i', 'l', 'e', 's', '\n',
        'm', 'i', 'l', 'e', 's', 't', 'o', 'n', 'e', '\n',
        'm', 'i', 'l', 'e', 's', 't', 'o', 'n', 'e', 's', '\n',
        'm', 'i', 'l', 'i', 'e', 'u', '\n',
        'm', 'i', 'l', 'i', 'e', 'u', 's', '\n',
        'm', 'i', 'l', 'i', 'e', 'u', 'x', '\n',
        'm', 'i', 'l', 'i', 't', 'a', 'n', 'c', 'y', '\n',
        'm', 'i', 'l', 'i', 't', 'a', 'n', 't', '\n',
        'm', 'i', 'l', 'i', 't', 'a', 'n', 't', 'l', 'y', '\n',
        'm', 'i', 'l', 'i', 't', 'a', 'n', 't', 's', '\n',
        'm', 'i', 'l', 'i', 't', 'a', 'r', 'i', 'l', 'y', '\n',
        'm', 'i', 'l', 'i', 't', 'a', 'r', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'i', 'l', 'i', 't', 'a', 'r', 'i', 's', 'e', 'd', '\n',
        'm', 'i', 'l', 'i', 't', 'a', 'r', 'i', 's', 'm', '\n',
        'm', 'i', 'l', 'i', 't', 'a', 'r', 'i', 's', 't', '\n',
        'm', 'i', 'l', 'i', 't', 'a', 'r', 'i', 's', 't', 'i', 'c', '\n',
        'm', 'i', 'l', 'i', 't', 'a', 'r', 'y', '\n',
        'm', 'i', 'l', 'i', 't', 'a', 't', 'e', '\n',
        'm', 'i', 'l', 'i', 't', 'a', 't', 'e', 'd', '\n',
        'm', 'i', 'l', 'i', 't', 'a', 't', 'e', 's', '\n',
        'm', 'i', 'l', 'i', 't', 'a', 't', 'i', 'n', 'g', '\n',
        'm', 'i', 'l', 'i', 't', 'i', 'a', '\n',
        'm', 'i', 'l', 'i', 't', 'i', 'a', 'm', 'a', 'n', '\n',
        'm', 'i', 'l', 'i', 't', 'i', 'a', 'm', 'e', 'n', '\n',
        'm', 'i', 'l', 'i', 't', 'i', 'a', 's', '\n',
        'm', 'i', 'l', 'k', '\n',
        'm', 'i', 'l', 'k', 'e', 'd', '\n',
        'm', 'i', 'l', 'k', 'e', 'r', '\n',
        'm', 'i', 'l', 'k', 'e', 'r', 's', '\n',
        'm', 'i', 'l', 'k', 'i', 'e', 'r', '\n',
        'm', 'i', 'l', 'k', 'i', 'e', 's', 't', '\n',
        'm', 'i', 'l', 'k', 'i', 'n', 'g', '\n',
        'm', 'i', 'l', 'k', 'm', 'a', 'i', 'd', '\n',
        'm', 'i', 'l', 'k', 'm', 'a', 'i', 'd', 's', '\n',
        'm', 'i', 'l', 'k', 'm', 'a', 'n', '\n',
        'm', 'i', 'l', 'k', 'm', 'e', 'n', '\n',
        'm', 'i', 'l', 'k', 's', '\n',
        'm', 'i', 'l', 'k', 's', 'h', 'a', 'k', 'e', '\n',
        'm', 'i', 'l', 'k', 's', 'h', 'a', 'k', 'e', 's', '\n',
        'm', 'i', 'l', 'k', 'y', '\n',
        'm', 'i', 'l', 'k', 'y', 'w', 'a', 'y', '\n',
        'm', 'i', 'l', 'l', '\n',
        'm', 'i', 'l', 'l', 'e', 'd', '\n',
        'm', 'i', 'l', 'l', 'e', 'n', 'a', 'r', 'i', 'a', 'n', '\n',
        'm', 'i', 'l', 'l', 'e', 'n', 'a', 'r', 'i', 'a', 'n', 'i', 's', 'm', '\n',
        'm', 'i', 'l', 'l', 'e', 'n', 'n', 'i', 'a', '\n',
        'm', 'i', 'l', 'l', 'e', 'n', 'n', 'i', 'a', 'l', '\n',
        'm', 'i', 'l', 'l', 'e', 'n', 'n', 'i', 'u', 'm', '\n',
        'm', 'i', 'l', 'l', 'e', 'r', '\n',
        'm', 'i', 'l', 'l', 'e', 'r', 's', '\n',
        'm', 'i', 'l', 'l', 'e', 't', '\n',
        'm', 'i', 'l', 'l', 'i', 'b', 'a', 'r', 's', '\n',
        'm', 'i', 'l', 'l', 'i', 'g', 'r', 'a', 'm', '\n',
        'm', 'i', 'l', 'l', 'i', 'g', 'r', 'a', 'm', 's', '\n',
        'm', 'i', 'l', 'l', 'i', 'l', 'i', 't', 'r', 'e', 's', '\n',
        'm', 'i', 'l', 'l', 'i', 'm', 'e', 't', 'r', 'e', '\n',
        'm', 'i', 'l', 'l', 'i', 'm', 'e', 't', 'r', 'e', 's', '\n',
        'm', 'i', 'l', 'l', 'i', 'n', 'e', 'r', '\n',
        'm', 'i', 'l', 'l', 'i', 'n', 'e', 'r', 's', '\n',
        'm', 'i', 'l', 'l', 'i', 'n', 'e', 'r', 'y', '\n',
        'm', 'i', 'l', 'l', 'i', 'n', 'g', '\n',
        'm', 'i', 'l', 'l', 'i', 'o', 'n', '\n',
        'm', 'i', 'l', 'l', 'i', 'o', 'n', 'a', 'i', 'r', 'e', '\n',
        'm', 'i', 'l', 'l', 'i', 'o', 'n', 'a', 'i', 'r', 'e', 's', '\n',
        'm', 'i', 'l', 'l', 'i', 'o', 'n', 's', '\n',
        'm', 'i', 'l', 'l', 'i', 'o', 'n', 't', 'h', '\n',
        'm', 'i', 'l', 'l', 'i', 'o', 'n', 't', 'h', 's', '\n',
        'm', 'i', 'l', 'l', 'i', 'p', 'e', 'd', 'e', '\n',
        'm', 'i', 'l', 'l', 'i', 'p', 'e', 'd', 'e', 's', '\n',
        'm', 'i', 'l', 'l', 'i', 's', 'e', 'c', 'o', 'n', 'd', '\n',
        'm', 'i', 'l', 'l', 'i', 's', 'e', 'c', 'o', 'n', 'd', 's', '\n',
        'm', 'i', 'l', 'l', 'p', 'o', 'n', 'd', '\n',
        'm', 'i', 'l', 'l', 's', '\n',
        'm', 'i', 'l', 'l', 's', 't', 'o', 'n', 'e', '\n',
        'm', 'i', 'l', 'l', 's', 't', 'o', 'n', 'e', 's', '\n',
        'm', 'i', 'l', 'o', 'r', 'd', '\n',
        'm', 'i', 'l', 't', '\n',
        'm', 'i', 'm', 'e', '\n',
        'm', 'i', 'm', 'e', 'd', '\n',
        'm', 'i', 'm', 'e', 'o', 'g', 'r', 'a', 'p', 'h', 'e', 'd', '\n',
        'm', 'i', 'm', 'e', 's', '\n',
        'm', 'i', 'm', 'e', 't', 'i', 'c', '\n',
        'm', 'i', 'm', 'i', 'c', '\n',
        'm', 'i', 'm', 'i', 'c', 'k', 'e', 'd', '\n',
        'm', 'i', 'm', 'i', 'c', 'k', 'e', 'r', '\n',
        'm', 'i', 'm', 'i', 'c', 'k', 'i', 'n', 'g', '\n',
        'm', 'i', 'm', 'i', 'c', 'r', 'y', '\n',
        'm', 'i', 'm', 'i', 'c', 's', '\n',
        'm', 'i', 'm', 'i', 'n', 'g', '\n',
        'm', 'i', 'm', 'o', 's', 'a', '\n',
        'm', 'i', 'n', 'a', 'r', 'e', 't', '\n',
        'm', 'i', 'n', 'a', 'r', 'e', 't', 's', '\n',
        'm', 'i', 'n', 'c', 'e', '\n',
        'm', 'i', 'n', 'c', 'e', 'd', '\n',
        'm', 'i', 'n', 'c', 'e', 'm', 'e', 'a', 't', '\n',
        'm', 'i', 'n', 'c', 'e', 'r', '\n',
        'm', 'i', 'n', 'c', 'e', 'r', 's', '\n',
        'm', 'i', 'n', 'c', 'e', 's', '\n',
        'm', 'i', 'n', 'c', 'i', 'n', 'g', '\n',
        'm', 'i', 'n', 'd', '\n',
        'm', 'i', 'n', 'd', 'b', 'o', 'g', 'g', 'l', 'i', 'n', 'g', '\n',
        'm', 'i', 'n', 'd', 'b', 'o', 'g', 'g', 'l', 'i', 'n', 'g', 'l', 'y', '\n',
        'm', 'i', 'n', 'd', 'e', 'd', '\n',
        'm', 'i', 'n', 'd', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'm', 'i', 'n', 'd', 'e', 'r', '\n',
        'm', 'i', 'n', 'd', 'e', 'r', 's', '\n',
        'm', 'i', 'n', 'd', 'f', 'u', 'l', '\n',
        'm', 'i', 'n', 'd', 'i', 'n', 'g', '\n',
        'm', 'i', 'n', 'd', 'l', 'e', 's', 's', '\n',
        'm', 'i', 'n', 'd', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'm', 'i', 'n', 'd', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'm', 'i', 'n', 'd', 'r', 'e', 'a', 'd', 'e', 'r', '\n',
        'm', 'i', 'n', 'd', 's', '\n',
        'm', 'i', 'n', 'd', 's', 'e', 't', '\n',
        'm', 'i', 'n', 'e', '\n',
        'm', 'i', 'n', 'e', 'd', '\n',
        'm', 'i', 'n', 'e', 'd', 'e', 't', 'e', 'c', 't', 'o', 'r', '\n',
        'm', 'i', 'n', 'e', 'f', 'i', 'e', 'l', 'd', '\n',
        'm', 'i', 'n', 'e', 'f', 'i', 'e', 'l', 'd', 's', '\n',
        'm', 'i', 'n', 'e', 'r', '\n',
        'm', 'i', 'n', 'e', 'r', 'a', 'l', '\n',
        'm', 'i', 'n', 'e', 'r', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'i', 'n', 'e', 'r', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'm', 'i', 'n', 'e', 'r', 'a', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'm', 'i', 'n', 'e', 'r', 'a', 'l', 'o', 'g', 'y', '\n',
        'm', 'i', 'n', 'e', 'r', 'a', 'l', 's', '\n',
        'm', 'i', 'n', 'e', 'r', 's', '\n',
        'm', 'i', 'n', 'e', 's', '\n',
        'm', 'i', 'n', 'e', 's', 'h', 'a', 'f', 't', '\n',
        'm', 'i', 'n', 'e', 's', 't', 'r', 'o', 'n', 'e', '\n',
        'm', 'i', 'n', 'e', 's', 'w', 'e', 'e', 'p', 'e', 'r', '\n',
        'm', 'i', 'n', 'e', 's', 'w', 'e', 'e', 'p', 'e', 'r', 's', '\n',
        'm', 'i', 'n', 'e', 'w', 'o', 'r', 'k', 'e', 'r', 's', '\n',
        'm', 'i', 'n', 'g', 'l', 'e', '\n',
        'm', 'i', 'n', 'g', 'l', 'e', 'd', '\n',
        'm', 'i', 'n', 'g', 'l', 'e', 's', '\n',
        'm', 'i', 'n', 'g', 'l', 'i', 'n', 'g', '\n',
        'm', 'i', 'n', 'i', '\n',
        'm', 'i', 'n', 'i', 'a', 't', 'u', 'r', 'e', '\n',
        'm', 'i', 'n', 'i', 'a', 't', 'u', 'r', 'e', 's', '\n',
        'm', 'i', 'n', 'i', 'a', 't', 'u', 'r', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'i', 'n', 'i', 'a', 't', 'u', 'r', 'i', 's', 'e', '\n',
        'm', 'i', 'n', 'i', 'a', 't', 'u', 'r', 'i', 's', 'e', 'd', '\n',
        'm', 'i', 'n', 'i', 'a', 't', 'u', 'r', 'i', 's', 'e', 's', '\n',
        'm', 'i', 'n', 'i', 'a', 't', 'u', 'r', 'i', 's', 'i', 'n', 'g', '\n',
        'm', 'i', 'n', 'i', 'a', 't', 'u', 'r', 'i', 's', 't', '\n',
        'm', 'i', 'n', 'i', 'b', 'a', 'r', '\n',
        'm', 'i', 'n', 'i', 'b', 'u', 's', '\n',
        'm', 'i', 'n', 'i', 'b', 'u', 's', 'e', 's', '\n',
        'm', 'i', 'n', 'i', 'c', 'a', 'b', '\n',
        'm', 'i', 'n', 'i', 'c', 'o', 'm', 'p', 'u', 't', 'e', 'r', '\n',
        'm', 'i', 'n', 'i', 'c', 'o', 'm', 'p', 'u', 't', 'e', 'r', 's', '\n',
        'm', 'i', 'n', 'i', 'f', 'y', '\n',
        'm', 'i', 'n', 'i', 'm', '\n',
        'm', 'i', 'n', 'i', 'm', 'a', '\n',
        'm', 'i', 'n', 'i', 'm', 'a', 'l', '\n',
        'm', 'i', 'n', 'i', 'm', 'a', 'l', 'i', 's', 'm', '\n',
        'm', 'i', 'n', 'i', 'm', 'a', 'l', 'i', 's', 't', '\n',
        'm', 'i', 'n', 'i', 'm', 'a', 'l', 'i', 's', 't', 'i', 'c', '\n',
        'm', 'i', 'n', 'i', 'm', 'a', 'l', 'i', 's', 't', 's', '\n',
        'm', 'i', 'n', 'i', 'm', 'a', 'l', 'i', 't', 'y', '\n',
        'm', 'i', 'n', 'i', 'm', 'a', 'l', 'l', 'y', '\n',
        'm', 'i', 'n', 'i', 'm', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'i', 'n', 'i', 'm', 'i', 's', 'e', '\n',
        'm', 'i', 'n', 'i', 'm', 'i', 's', 'e', 'd', '\n',
        'm', 'i', 'n', 'i', 'm', 'i', 's', 'e', 'r', '\n',
        'm', 'i', 'n', 'i', 'm', 'i', 's', 'e', 's', '\n',
        'm', 'i', 'n', 'i', 'm', 'i', 's', 'i', 'n', 'g', '\n',
        'm', 'i', 'n', 'i', 'm', 'u', 'm', '\n',
        'm', 'i', 'n', 'i', 'n', 'g', '\n',
        'm', 'i', 'n', 'i', 'n', 'g', 's', '\n',
        'm', 'i', 'n', 'i', 'o', 'n', '\n',
        'm', 'i', 'n', 'i', 'o', 'n', 's', '\n',
        'm', 'i', 'n', 'i', 's', 'k', 'i', 'r', 't', '\n',
        'm', 'i', 'n', 'i', 's', 't', 'e', 'r', '\n',
        'm', 'i', 'n', 'i', 's', 't', 'e', 'r', 'e', 'd', '\n',
        'm', 'i', 'n', 'i', 's', 't', 'e', 'r', 'i', 'a', 'l', '\n',
        'm', 'i', 'n', 'i', 's', 't', 'e', 'r', 'i', 'a', 'l', 'l', 'y', '\n',
        'm', 'i', 'n', 'i', 's', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'm', 'i', 'n', 'i', 's', 't', 'e', 'r', 's', '\n',
        'm', 'i', 'n', 'i', 's', 't', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'i', 'n', 'i', 's', 't', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'm', 'i', 'n', 'i', 's', 't', 'r', 'i', 'e', 's', '\n',
        'm', 'i', 'n', 'i', 's', 't', 'r', 'y', '\n',
        'm', 'i', 'n', 'k', '\n',
        'm', 'i', 'n', 'k', 'e', '\n',
        'm', 'i', 'n', 'k', 's', '\n',
        'm', 'i', 'n', 'n', 'o', 'w', '\n',
        'm', 'i', 'n', 'n', 'o', 'w', 's', '\n',
        'm', 'i', 'n', 'o', 'r', '\n',
        'm', 'i', 'n', 'o', 'r', 'i', 't', 'i', 'e', 's', '\n',
        'm', 'i', 'n', 'o', 'r', 'i', 't', 'y', '\n',
        'm', 'i', 'n', 'o', 'r', 's', '\n',
        'm', 'i', 'n', 's', 't', 'e', 'r', '\n',
        'm', 'i', 'n', 's', 't', 'r', 'e', 'l', '\n',
        'm', 'i', 'n', 's', 't', 'r', 'e', 'l', 's', '\n',
        'm', 'i', 'n', 't', '\n',
        'm', 'i', 'n', 't', 'e', 'd', '\n',
        'm', 'i', 'n', 't', 'i', 'e', 'r', '\n',
        'm', 'i', 'n', 't', 'i', 'e', 's', 't', '\n',
        'm', 'i', 'n', 't', 'i', 'n', 'g', '\n',
        'm', 'i', 'n', 't', 's', '\n',
        'm', 'i', 'n', 't', 'y', '\n',
        'm', 'i', 'n', 'u', 'e', 't', '\n',
        'm', 'i', 'n', 'u', 'e', 't', 's', '\n',
        'm', 'i', 'n', 'u', 's', '\n',
        'm', 'i', 'n', 'u', 's', 'c', 'u', 'l', 'e', '\n',
        'm', 'i', 'n', 'u', 's', 'e', 's', '\n',
        'm', 'i', 'n', 'u', 't', 'e', '\n',
        'm', 'i', 'n', 'u', 't', 'e', 'd', '\n',
        'm', 'i', 'n', 'u', 't', 'e', 'l', 'y', '\n',
        'm', 'i', 'n', 'u', 't', 'e', 'n', 'e', 's', 's', '\n',
        'm', 'i', 'n', 'u', 't', 'e', 's', '\n',
        'm', 'i', 'n', 'u', 't', 'e', 's', 't', '\n',
        'm', 'i', 'n', 'u', 't', 'i', 'a', 'e', '\n',
        'm', 'i', 'n', 'x', '\n',
        'm', 'i', 'n', 'x', 'e', 's', '\n',
        'm', 'i', 'o', 's', 'i', 's', '\n',
        'm', 'i', 'r', 'a', 'c', 'l', 'e', '\n',
        'm', 'i', 'r', 'a', 'c', 'l', 'e', 's', '\n',
        'm', 'i', 'r', 'a', 'c', 'u', 'l', 'o', 'u', 's', '\n',
        'm', 'i', 'r', 'a', 'c', 'u', 'l', 'o', 'u', 's', 'l', 'y', '\n',
        'm', 'i', 'r', 'a', 'c', 'u', 'l', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'm', 'i', 'r', 'a', 'g', 'e', '\n',
        'm', 'i', 'r', 'a', 'g', 'e', 's', '\n',
        'm', 'i', 'r', 'e', '\n',
        'm', 'i', 'r', 'e', 'd', '\n',
        'm', 'i', 'r', 'e', 's', '\n',
        'm', 'i', 'r', 'r', 'o', 'r', '\n',
        'm', 'i', 'r', 'r', 'o', 'r', 'e', 'd', '\n',
        'm', 'i', 'r', 'r', 'o', 'r', 'i', 'n', 'g', '\n',
        'm', 'i', 'r', 'r', 'o', 'r', 's', '\n',
        'm', 'i', 'r', 't', 'h', '\n',
        'm', 'i', 'r', 't', 'h', 'f', 'u', 'l', '\n',
        'm', 'i', 'r', 't', 'h', 'l', 'e', 's', 's', '\n',
        'm', 'i', 'r', 't', 'h', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'm', 'i', 's', 'a', 'd', 'v', 'e', 'n', 't', 'u', 'r', 'e', '\n',
        'm', 'i', 's', 'a', 'l', 'i', 'g', 'n', 'e', 'd', '\n',
        'm', 'i', 's', 'a', 'l', 'i', 'g', 'n', 'm', 'e', 'n', 't', '\n',
        'm', 'i', 's', 'a', 'n', 'a', 'l', 'y', 's', 'e', 'd', '\n',
        'm', 'i', 's', 'a', 'n', 't', 'h', 'r', 'o', 'p', 'e', '\n',
        'm', 'i', 's', 'a', 'n', 't', 'h', 'r', 'o', 'p', 'e', 's', '\n',
        'm', 'i', 's', 'a', 'n', 't', 'h', 'r', 'o', 'p', 'i', 'c', '\n',
        'm', 'i', 's', 'a', 'n', 't', 'h', 'r', 'o', 'p', 'i', 's', 't', 's', '\n',
        'm', 'i', 's', 'a', 'n', 't', 'h', 'r', 'o', 'p', 'y', '\n',
        'm', 'i', 's', 'a', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'i', 's', 'a', 'p', 'p', 'l', 'y', '\n',
        'm', 'i', 's', 'a', 'p', 'p', 'r', 'e', 'h', 'e', 'n', 's', 'i', 'o', 'n', '\n',
        'm', 'i', 's', 'a', 'p', 'p', 'r', 'e', 'h', 'e', 'n', 's', 'i', 'o', 'n', 's', '\n',
        'm', 'i', 's', 'a', 'p', 'p', 'r', 'o', 'p', 'r', 'i', 'a', 't', 'e', 'd', '\n',
        'm', 'i', 's', 'a', 'p', 'p', 'r', 'o', 'p', 'r', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'i', 's', 'b', 'e', 'g', 'o', 't', 't', 'e', 'n', '\n',
        'm', 'i', 's', 'b', 'e', 'h', 'a', 'v', 'e', '\n',
        'm', 'i', 's', 'b', 'e', 'h', 'a', 'v', 'e', 'd', '\n',
        'm', 'i', 's', 'b', 'e', 'h', 'a', 'v', 'e', 's', '\n',
        'm', 'i', 's', 'b', 'e', 'h', 'a', 'v', 'i', 'n', 'g', '\n',
        'm', 'i', 's', 'b', 'e', 'h', 'a', 'v', 'i', 'o', 'u', 'r', '\n',
        'm', 'i', 's', 'c', 'a', 'l', 'c', 'u', 'l', 'a', 't', 'e', '\n',
        'm', 'i', 's', 'c', 'a', 'l', 'c', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'm', 'i', 's', 'c', 'a', 'l', 'c', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'i', 's', 'c', 'a', 'l', 'c', 'u', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'm', 'i', 's', 'c', 'a', 'r', 'r', 'i', 'a', 'g', 'e', '\n',
        'm', 'i', 's', 'c', 'a', 'r', 'r', 'i', 'a', 'g', 'e', 's', '\n',
        'm', 'i', 's', 'c', 'a', 'r', 'r', 'i', 'e', 'd', '\n',
        'm', 'i', 's', 'c', 'a', 'r', 'r', 'y', '\n',
        'm', 'i', 's', 'c', 'a', 'r', 'r', 'y', 'i', 'n', 'g', '\n',
        'm', 'i', 's', 'c', 'a', 's', 't', '\n',
        'm', 'i', 's', 'c', 'a', 's', 't', 'i', 'n', 'g', '\n',
        'm', 'i', 's', 'c', 'e', 'g', 'e', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'i', 's', 'c', 'e', 'l', 'l', 'a', 'n', 'e', 'a', '\n',
        'm', 'i', 's', 'c', 'e', 'l', 'l', 'a', 'n', 'e', 'o', 'u', 's', '\n',
        'm', 'i', 's', 'c', 'e', 'l', 'l', 'a', 'n', 'i', 'e', 's', '\n',
        'm', 'i', 's', 'c', 'e', 'l', 'l', 'a', 'n', 'y', '\n',
        'm', 'i', 's', 'c', 'h', 'a', 'n', 'c', 'e', '\n',
        'm', 'i', 's', 'c', 'h', 'i', 'e', 'f', '\n',
        'm', 'i', 's', 'c', 'h', 'i', 'e', 'f', 'm', 'a', 'k', 'e', 'r', 's', '\n',
        'm', 'i', 's', 'c', 'h', 'i', 'e', 'f', 'm', 'a', 'k', 'i', 'n', 'g', '\n',
        'm', 'i', 's', 'c', 'h', 'i', 'e', 'v', 'o', 'u', 's', '\n',
        'm', 'i', 's', 'c', 'h', 'i', 'e', 'v', 'o', 'u', 's', 'l', 'y', '\n',
        'm', 'i', 's', 'c', 'i', 'b', 'l', 'e', '\n',
        'm', 'i', 's', 'c', 'l', 'a', 's', 's', 'i', 'f', 'i', 'e', 'd', '\n',
        'm', 'i', 's', 'c', 'o', 'm', 'p', 'r', 'e', 'h', 'e', 'n', 'd', 'e', 'd', '\n',
        'm', 'i', 's', 'c', 'o', 'n', 'c', 'e', 'i', 'v', 'e', 'd', '\n',
        'm', 'i', 's', 'c', 'o', 'n', 'c', 'e', 'p', 't', 'i', 'o', 'n', '\n',
        'm', 'i', 's', 'c', 'o', 'n', 'c', 'e', 'p', 't', 'i', 'o', 'n', 's', '\n',
        'm', 'i', 's', 'c', 'o', 'n', 'd', 'u', 'c', 't', '\n',
        'm', 'i', 's', 'c', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'i', 's', 'c', 'o', 'n', 's', 't', 'r', 'u', 'e', 'd', '\n',
        'm', 'i', 's', 'c', 'o', 'p', 'y', 'i', 'n', 'g', '\n',
        'm', 'i', 's', 'c', 'o', 'u', 'n', 't', '\n',
        'm', 'i', 's', 'c', 'o', 'u', 'n', 't', 'e', 'd', '\n',
        'm', 'i', 's', 'c', 'o', 'u', 'n', 't', 'i', 'n', 'g', '\n',
        'm', 'i', 's', 'c', 'r', 'e', 'a', 'n', 't', '\n',
        'm', 'i', 's', 'c', 'r', 'e', 'a', 'n', 't', 's', '\n',
        'm', 'i', 's', 'c', 'u', 'e', '\n',
        'm', 'i', 's', 'c', 'u', 'e', 's', '\n',
        'm', 'i', 's', 'd', 'a', 't', 'e', '\n',
        'm', 'i', 's', 'd', 'e', 'a', 'l', '\n',
        'm', 'i', 's', 'd', 'e', 'a', 'l', 'i', 'n', 'g', '\n',
        'm', 'i', 's', 'd', 'e', 'e', 'd', '\n',
        'm', 'i', 's', 'd', 'e', 'e', 'd', 's', '\n',
        'm', 'i', 's', 'd', 'e', 'm', 'e', 'a', 'n', 'o', 'u', 'r', '\n',
        'm', 'i', 's', 'd', 'e', 'm', 'e', 'a', 'n', 'o', 'u', 'r', 's', '\n',
        'm', 'i', 's', 'd', 'i', 'a', 'g', 'n', 'o', 's', 'i', 's', '\n',
        'm', 'i', 's', 'd', 'i', 'r', 'e', 'c', 't', '\n',
        'm', 'i', 's', 'd', 'i', 'r', 'e', 'c', 't', 'e', 'd', '\n',
        'm', 'i', 's', 'd', 'i', 'r', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'm', 'i', 's', 'd', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'm', 'i', 's', 'd', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'm', 'i', 's', 'd', 'o', 'i', 'n', 'g', '\n',
        'm', 'i', 's', 'e', 'r', '\n',
        'm', 'i', 's', 'e', 'r', 'a', 'b', 'l', 'e', '\n',
        'm', 'i', 's', 'e', 'r', 'a', 'b', 'l', 'y', '\n',
        'm', 'i', 's', 'e', 'r', 'i', 'e', 's', '\n',
        'm', 'i', 's', 'e', 'r', 'l', 'i', 'n', 'e', 's', 's', '\n',
        'm', 'i', 's', 'e', 'r', 'l', 'y', '\n',
        'm', 'i', 's', 'e', 'r', 's', '\n',
        'm', 'i', 's', 'e', 'r', 'y', '\n',
        'm', 'i', 's', 'f', 'i', 'e', 'l', 'd', '\n',
        'm', 'i', 's', 'f', 'i', 'l', 'e', 'd', '\n',
        'm', 'i', 's', 'f', 'i', 'r', 'e', '\n',
        'm', 'i', 's', 'f', 'i', 'r', 'e', 'd', '\n',
        'm', 'i', 's', 'f', 'i', 'r', 'e', 's', '\n',
        'm', 'i', 's', 'f', 'i', 't', '\n',
        'm', 'i', 's', 'f', 'i', 't', 's', '\n',
        'm', 'i', 's', 'f', 'o', 'r', 't', 'u', 'n', 'e', '\n',
        'm', 'i', 's', 'f', 'o', 'r', 't', 'u', 'n', 'e', 's', '\n',
        'm', 'i', 's', 'g', 'i', 'v', 'e', '\n',
        'm', 'i', 's', 'g', 'i', 'v', 'i', 'n', 'g', '\n',
        'm', 'i', 's', 'g', 'i', 'v', 'i', 'n', 'g', 's', '\n',
        'm', 'i', 's', 'g', 'o', 'v', 'e', 'r', 'n', 'm', 'e', 'n', 't', '\n',
        'm', 'i', 's', 'g', 'u', 'i', 'd', 'e', '\n',
        'm', 'i', 's', 'g', 'u', 'i', 'd', 'e', 'd', '\n',
        'm', 'i', 's', 'g', 'u', 'i', 'd', 'e', 'd', 'l', 'y', '\n',
        'm', 'i', 's', 'h', 'a', 'n', 'd', 'l', 'e', '\n',
        'm', 'i', 's', 'h', 'a', 'n', 'd', 'l', 'e', 'd', '\n',
        'm', 'i', 's', 'h', 'a', 'n', 'd', 'l', 'e', 's', '\n',
        'm', 'i', 's', 'h', 'a', 'n', 'd', 'l', 'i', 'n', 'g', '\n',
        'm', 'i', 's', 'h', 'a', 'p', '\n',
        'm', 'i', 's', 'h', 'a', 'p', 's', '\n',
        'm', 'i', 's', 'h', 'e', 'a', 'r', '\n',
        'm', 'i', 's', 'h', 'e', 'a', 'r', 'd', '\n',
        'm', 'i', 's', 'h', 'e', 'a', 'r', 'i', 'n', 'g', '\n',
        'm', 'i', 's', 'h', 'e', 'a', 'r', 's', '\n',
        'm', 'i', 's', 'h', 'i', 't', 't', 'i', 'n', 'g', '\n',
        'm', 'i', 's', 'i', 'd', 'e', 'n', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'i', 's', 'i', 'n', 'f', 'o', 'r', 'm', '\n',
        'm', 'i', 's', 'i', 'n', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'i', 's', 'i', 'n', 'f', 'o', 'r', 'm', 'e', 'd', '\n',
        'm', 'i', 's', 'i', 'n', 't', 'e', 'r', 'p', 'r', 'e', 't', '\n',
        'm', 'i', 's', 'i', 'n', 't', 'e', 'r', 'p', 'r', 'e', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'i', 's', 'i', 'n', 't', 'e', 'r', 'p', 'r', 'e', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'm', 'i', 's', 'i', 'n', 't', 'e', 'r', 'p', 'r', 'e', 't', 'e', 'd', '\n',
        'm', 'i', 's', 'i', 'n', 't', 'e', 'r', 'p', 'r', 'e', 't', 'i', 'n', 'g', '\n',
        'm', 'i', 's', 'i', 'n', 't', 'e', 'r', 'p', 'r', 'e', 't', 's', '\n',
        'm', 'i', 's', 'j', 'u', 'd', 'g', 'e', '\n',
        'm', 'i', 's', 'j', 'u', 'd', 'g', 'e', 'd', '\n',
        'm', 'i', 's', 'j', 'u', 'd', 'g', 'e', 'm', 'e', 'n', 't', '\n',
        'm', 'i', 's', 'j', 'u', 'd', 'g', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'm', 'i', 's', 'j', 'u', 'd', 'g', 'i', 'n', 'g', '\n',
        'm', 'i', 's', 'j', 'u', 'd', 'g', 'm', 'e', 'n', 't', '\n',
        'm', 'i', 's', 'l', 'a', 'b', 'e', 'l', 'l', 'e', 'd', '\n',
        'm', 'i', 's', 'l', 'a', 'i', 'd', '\n',
        'm', 'i', 's', 'l', 'a', 'y', '\n',
        'm', 'i', 's', 'l', 'e', 'a', 'd', '\n',
        'm', 'i', 's', 'l', 'e', 'a', 'd', 'i', 'n', 'g', '\n',
        'm', 'i', 's', 'l', 'e', 'a', 'd', 'i', 'n', 'g', 'l', 'y', '\n',
        'm', 'i', 's', 'l', 'e', 'a', 'd', 's', '\n',
        'm', 'i', 's', 'l', 'e', 'd', '\n',
        'm', 'i', 's', 'm', 'a', 'n', 'a', 'g', 'e', '\n',
        'm', 'i', 's', 'm', 'a', 'n', 'a', 'g', 'e', 'd', '\n',
        'm', 'i', 's', 'm', 'a', 'n', 'a', 'g', 'e', 'm', 'e', 'n', 't', '\n',
        'm', 'i', 's', 'm', 'a', 't', 'c', 'h', '\n',
        'm', 'i', 's', 'm', 'a', 't', 'c', 'h', 'e', 'd', '\n',
        'm', 'i', 's', 'm', 'a', 't', 'c', 'h', 'e', 's', '\n',
        'm', 'i', 's', 'm', 'a', 't', 'c', 'h', 'i', 'n', 'g', '\n',
        'm', 'i', 's', 'n', 'a', 'm', 'e', '\n',
        'm', 'i', 's', 'n', 'a', 'm', 'e', 'd', '\n',
        'm', 'i', 's', 'n', 'o', 'm', 'e', 'r', '\n',
        'm', 'i', 's', 'n', 'o', 'm', 'e', 'r', 's', '\n',
        'm', 'i', 's', 'o', 'g', 'y', 'n', 'i', 's', 't', '\n',
        'm', 'i', 's', 'o', 'g', 'y', 'n', 'i', 's', 't', 'i', 'c', '\n',
        'm', 'i', 's', 'o', 'g', 'y', 'n', 'i', 's', 't', 's', '\n',
        'm', 'i', 's', 'o', 'g', 'y', 'n', 'y', '\n',
        'm', 'i', 's', 'p', 'l', 'a', 'c', 'e', '\n',
        'm', 'i', 's', 'p', 'l', 'a', 'c', 'e', 'd', '\n',
        'm', 'i', 's', 'p', 'l', 'a', 'c', 'e', 'm', 'e', 'n', 't', '\n',
        'm', 'i', 's', 'p', 'l', 'a', 'c', 'e', 's', '\n',
        'm', 'i', 's', 'p', 'l', 'a', 'c', 'i', 'n', 'g', '\n',
        'm', 'i', 's', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'e', 'd', '\n',
        'm', 'i', 's', 'p', 'r', 'i', 'n', 't', '\n',
        'm', 'i', 's', 'p', 'r', 'i', 'n', 't', 'e', 'd', '\n',
        'm', 'i', 's', 'p', 'r', 'i', 'n', 't', 'i', 'n', 'g', '\n',
        'm', 'i', 's', 'p', 'r', 'i', 'n', 't', 's', '\n',
        'm', 'i', 's', 'p', 'r', 'o', 'n', 'o', 'u', 'n', 'c', 'e', 'd', '\n',
        'm', 'i', 's', 'p', 'r', 'o', 'n', 'o', 'u', 'n', 'c', 'i', 'n', 'g', '\n',
        'm', 'i', 's', 'p', 'r', 'o', 'n', 'u', 'n', 'c', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'i', 's', 'p', 'r', 'o', 'n', 'u', 'n', 'c', 'i', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'm', 'i', 's', 'q', 'u', 'o', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'i', 's', 'q', 'u', 'o', 't', 'e', '\n',
        'm', 'i', 's', 'q', 'u', 'o', 't', 'e', 'd', '\n',
        'm', 'i', 's', 'q', 'u', 'o', 't', 'e', 's', '\n',
        'm', 'i', 's', 'q', 'u', 'o', 't', 'i', 'n', 'g', '\n',
        'm', 'i', 's', 'r', 'e', 'a', 'd', '\n',
        'm', 'i', 's', 'r', 'e', 'a', 'd', 'i', 'n', 'g', '\n',
        'm', 'i', 's', 'r', 'e', 'm', 'e', 'm', 'b', 'e', 'r', '\n',
        'm', 'i', 's', 'r', 'e', 'm', 'e', 'm', 'b', 'e', 'r', 'e', 'd', '\n',
        'm', 'i', 's', 'r', 'e', 'm', 'e', 'm', 'b', 'e', 'r', 'i', 'n', 'g', '\n',
        'm', 'i', 's', 'r', 'e', 'p', 'r', 'e', 's', 'e', 'n', 't', '\n',
        'm', 'i', 's', 'r', 'e', 'p', 'r', 'e', 's', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'i', 's', 'r', 'e', 'p', 'r', 'e', 's', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'm', 'i', 's', 'r', 'e', 'p', 'r', 'e', 's', 'e', 'n', 't', 'e', 'd', '\n',
        'm', 'i', 's', 'r', 'e', 'p', 'r', 'e', 's', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'm', 'i', 's', 'r', 'e', 'p', 'r', 'e', 's', 'e', 'n', 't', 's', '\n',
        'm', 'i', 's', 'r', 'u', 'l', 'e', '\n',
        'm', 'i', 's', 's', '\n',
        'm', 'i', 's', 's', 'a', 'l', '\n',
        'm', 'i', 's', 's', 'a', 'l', 's', '\n',
        'm', 'i', 's', 's', 'e', 'd', '\n',
        'm', 'i', 's', 's', 'e', 's', '\n',
        'm', 'i', 's', 's', 'h', 'a', 'p', 'e', 'n', '\n',
        'm', 'i', 's', 's', 'i', 'l', 'e', '\n',
        'm', 'i', 's', 's', 'i', 'l', 'e', 's', '\n',
        'm', 'i', 's', 's', 'i', 'n', 'g', '\n',
        'm', 'i', 's', 's', 'i', 'o', 'n', '\n',
        'm', 'i', 's', 's', 'i', 'o', 'n', 'a', 'r', 'i', 'e', 's', '\n',
        'm', 'i', 's', 's', 'i', 'o', 'n', 'a', 'r', 'y', '\n',
        'm', 'i', 's', 's', 'i', 'o', 'n', 's', '\n',
        'm', 'i', 's', 's', 'i', 'v', 'e', '\n',
        'm', 'i', 's', 's', 'i', 'v', 'e', 's', '\n',
        'm', 'i', 's', 's', 'o', 'u', 'r', 'i', '\n',
        'm', 'i', 's', 's', 'p', 'e', 'l', 'l', '\n',
        'm', 'i', 's', 's', 'p', 'e', 'l', 'l', 'e', 'd', '\n',
        'm', 'i', 's', 's', 'p', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'm', 'i', 's', 's', 'p', 'e', 'l', 'l', 'i', 'n', 'g', 's', '\n',
        'm', 'i', 's', 's', 'p', 'e', 'l', 'l', 's', '\n',
        'm', 'i', 's', 's', 'p', 'e', 'l', 't', '\n',
        'm', 'i', 's', 's', 'p', 'e', 'n', 'd', '\n',
        'm', 'i', 's', 's', 'p', 'e', 'n', 't', '\n',
        'm', 'i', 's', 's', 't', 'a', 't', 'e', 'm', 'e', 'n', 't', '\n',
        'm', 'i', 's', 's', 't', 'e', 'p', 's', '\n',
        'm', 'i', 's', 's', 'u', 's', '\n',
        'm', 'i', 's', 's', 'u', 's', 'e', 's', '\n',
        'm', 'i', 's', 's', 'y', '\n',
        'm', 'i', 's', 't', '\n',
        'm', 'i', 's', 't', 'a', 'k', 'e', '\n',
        'm', 'i', 's', 't', 'a', 'k', 'e', 'n', '\n',
        'm', 'i', 's', 't', 'a', 'k', 'e', 'n', 'l', 'y', '\n',
        'm', 'i', 's', 't', 'a', 'k', 'e', 's', '\n',
        'm', 'i', 's', 't', 'a', 'k', 'i', 'n', 'g', '\n',
        'm', 'i', 's', 't', 'e', 'd', '\n',
        'm', 'i', 's', 't', 'e', 'r', '\n',
        'm', 'i', 's', 't', 'e', 'r', 's', '\n',
        'm', 'i', 's', 't', 'i', 'e', 'r', '\n',
        'm', 'i', 's', 't', 'i', 'e', 's', 't', '\n',
        'm', 'i', 's', 't', 'i', 'l', 'y', '\n',
        'm', 'i', 's', 't', 'i', 'm', 'e', '\n',
        'm', 'i', 's', 't', 'i', 'm', 'e', 'd', '\n',
        'm', 'i', 's', 't', 'i', 'n', 'e', 's', 's', '\n',
        'm', 'i', 's', 't', 'i', 'n', 'g', '\n',
        'm', 'i', 's', 't', 'l', 'e', 't', 'o', 'e', '\n',
        'm', 'i', 's', 't', 'o', 'o', 'k', '\n',
        'm', 'i', 's', 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'e', 'd', '\n',
        'm', 'i', 's', 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'e', 's', '\n',
        'm', 'i', 's', 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'm', 'i', 's', 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'i', 's', 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'm', 'i', 's', 't', 'r', 'e', 'a', 't', '\n',
        'm', 'i', 's', 't', 'r', 'e', 'a', 't', 'e', 'd', '\n',
        'm', 'i', 's', 't', 'r', 'e', 'a', 't', 'i', 'n', 'g', '\n',
        'm', 'i', 's', 't', 'r', 'e', 'a', 't', 'm', 'e', 'n', 't', '\n',
        'm', 'i', 's', 't', 'r', 'e', 's', 's', '\n',
        'm', 'i', 's', 't', 'r', 'e', 's', 's', 'e', 's', '\n',
        'm', 'i', 's', 't', 'r', 'u', 's', 't', '\n',
        'm', 'i', 's', 't', 'r', 'u', 's', 't', 'e', 'd', '\n',
        'm', 'i', 's', 't', 'r', 'u', 's', 't', 'f', 'u', 'l', '\n',
        'm', 'i', 's', 't', 'r', 'u', 's', 't', 'f', 'u', 'l', 'l', 'y', '\n',
        'm', 'i', 's', 't', 'r', 'u', 's', 't', 'i', 'n', 'g', '\n',
        'm', 'i', 's', 't', 'r', 'u', 's', 't', 's', '\n',
        'm', 'i', 's', 't', 's', '\n',
        'm', 'i', 's', 't', 'y', '\n',
        'm', 'i', 's', 't', 'y', 'p', 'e', '\n',
        'm', 'i', 's', 't', 'y', 'p', 'e', 'd', '\n',
        'm', 'i', 's', 't', 'y', 'p', 'e', 's', '\n',
        'm', 'i', 's', 't', 'y', 'p', 'i', 'n', 'g', '\n',
        'm', 'i', 's', 't', 'y', 'p', 'i', 'n', 'g', 's', '\n',
        'm', 'i', 's', 'u', 'n', 'd', 'e', 'r', 's', 't', 'a', 'n', 'd', '\n',
        'm', 'i', 's', 'u', 'n', 'd', 'e', 'r', 's', 't', 'a', 'n', 'd', 'i', 'n', 'g', '\n',
        'm', 'i', 's', 'u', 'n', 'd', 'e', 'r', 's', 't', 'a', 'n', 'd', 'i', 'n', 'g', 's', '\n',
        'm', 'i', 's', 'u', 'n', 'd', 'e', 'r', 's', 't', 'a', 'n', 'd', 's', '\n',
        'm', 'i', 's', 'u', 'n', 'd', 'e', 'r', 's', 't', 'o', 'o', 'd', '\n',
        'm', 'i', 's', 'u', 's', 'e', '\n',
        'm', 'i', 's', 'u', 's', 'e', 'd', '\n',
        'm', 'i', 's', 'u', 's', 'e', 'r', '\n',
        'm', 'i', 's', 'u', 's', 'e', 's', '\n',
        'm', 'i', 's', 'u', 's', 'i', 'n', 'g', '\n',
        'm', 'i', 't', 'e', '\n',
        'm', 'i', 't', 'e', 's', '\n',
        'm', 'i', 't', 'i', 'g', 'a', 't', 'e', '\n',
        'm', 'i', 't', 'i', 'g', 'a', 't', 'e', 'd', '\n',
        'm', 'i', 't', 'i', 'g', 'a', 't', 'e', 's', '\n',
        'm', 'i', 't', 'i', 'g', 'a', 't', 'i', 'n', 'g', '\n',
        'm', 'i', 't', 'i', 'g', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'i', 't', 'i', 'g', 'a', 't', 'o', 'r', 'y', '\n',
        'm', 'i', 't', 'o', 'c', 'h', 'o', 'n', 'd', 'r', 'i', 'a', '\n',
        'm', 'i', 't', 'o', 'c', 'h', 'o', 'n', 'd', 'r', 'i', 'a', 'l', '\n',
        'm', 'i', 't', 'o', 's', 'i', 's', '\n',
        'm', 'i', 't', 'r', 'e', '\n',
        'm', 'i', 't', 'r', 'e', 'd', '\n',
        'm', 'i', 't', 'r', 'e', 's', '\n',
        'm', 'i', 't', 't', '\n',
        'm', 'i', 't', 't', 'e', 'n', '\n',
        'm', 'i', 't', 't', 'e', 'n', 's', '\n',
        'm', 'i', 't', 't', 's', '\n',
        'm', 'i', 'x', '\n',
        'm', 'i', 'x', 'a', 'b', 'l', 'e', '\n',
        'm', 'i', 'x', 'e', 'd', '\n',
        'm', 'i', 'x', 'e', 'r', '\n',
        'm', 'i', 'x', 'e', 'r', 's', '\n',
        'm', 'i', 'x', 'e', 's', '\n',
        'm', 'i', 'x', 'i', 'n', 'g', '\n',
        'm', 'i', 'x', 't', 'u', 'r', 'e', '\n',
        'm', 'i', 'x', 't', 'u', 'r', 'e', 's', '\n',
        'm', 'i', 'x', 'u', 'p', '\n',
        'm', 'i', 'x', 'u', 'p', 's', '\n',
        'm', 'n', 'e', 'm', 'o', 'n', 'i', 'c', '\n',
        'm', 'n', 'e', 'm', 'o', 'n', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'm', 'n', 'e', 'm', 'o', 'n', 'i', 'c', 's', '\n',
        'm', 'o', 'a', 'n', '\n',
        'm', 'o', 'a', 'n', 'e', 'd', '\n',
        'm', 'o', 'a', 'n', 'e', 'r', '\n',
        'm', 'o', 'a', 'n', 'e', 'r', 's', '\n',
        'm', 'o', 'a', 'n', 'i', 'n', 'g', '\n',
        'm', 'o', 'a', 'n', 's', '\n',
        'm', 'o', 'a', 's', '\n',
        'm', 'o', 'a', 't', '\n',
        'm', 'o', 'a', 't', 'e', 'd', '\n',
        'm', 'o', 'a', 't', 's', '\n',
        'm', 'o', 'b', '\n',
        'm', 'o', 'b', 'b', 'e', 'd', '\n',
        'm', 'o', 'b', 'b', 'i', 'n', 'g', '\n',
        'm', 'o', 'b', 'b', 'i', 's', 'h', '\n',
        'm', 'o', 'b', 'i', 'l', 'e', '\n',
        'm', 'o', 'b', 'i', 'l', 'e', 's', '\n',
        'm', 'o', 'b', 'i', 'l', 'i', 's', 'a', 'b', 'l', 'e', '\n',
        'm', 'o', 'b', 'i', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'o', 'b', 'i', 'l', 'i', 's', 'e', '\n',
        'm', 'o', 'b', 'i', 'l', 'i', 's', 'e', 'd', '\n',
        'm', 'o', 'b', 'i', 'l', 'i', 's', 'e', 's', '\n',
        'm', 'o', 'b', 'i', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'm', 'o', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'm', 'o', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'm', 'o', 'b', 's', '\n',
        'm', 'o', 'b', 's', 't', 'e', 'r', '\n',
        'm', 'o', 'b', 's', 't', 'e', 'r', 's', '\n',
        'm', 'o', 'c', 'c', 'a', 's', 'i', 'n', '\n',
        'm', 'o', 'c', 'c', 'a', 's', 'i', 'n', 's', '\n',
        'm', 'o', 'c', 'k', '\n',
        'm', 'o', 'c', 'k', 'e', 'd', '\n',
        'm', 'o', 'c', 'k', 'e', 'r', '\n',
        'm', 'o', 'c', 'k', 'e', 'r', 'i', 'e', 's', '\n',
        'm', 'o', 'c', 'k', 'e', 'r', 's', '\n',
        'm', 'o', 'c', 'k', 'e', 'r', 'y', '\n',
        'm', 'o', 'c', 'k', 'i', 'n', 'g', '\n',
        'm', 'o', 'c', 'k', 'i', 'n', 'g', 'b', 'i', 'r', 'd', '\n',
        'm', 'o', 'c', 'k', 'i', 'n', 'g', 'l', 'y', '\n',
        'm', 'o', 'c', 'k', 's', '\n',
        'm', 'o', 'c', 'k', 'u', 'p', '\n',
        'm', 'o', 'c', 'k', 'u', 'p', 's', '\n',
        'm', 'o', 'd', '\n',
        'm', 'o', 'd', 'a', 'l', '\n',
        'm', 'o', 'd', 'a', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'm', 'o', 'd', 'a', 'l', 'i', 't', 'y', '\n',
        'm', 'o', 'd', 'e', '\n',
        'm', 'o', 'd', 'e', 'l', '\n',
        'm', 'o', 'd', 'e', 'l', 'l', 'e', 'd', '\n',
        'm', 'o', 'd', 'e', 'l', 'l', 'e', 'r', '\n',
        'm', 'o', 'd', 'e', 'l', 'l', 'e', 'r', 's', '\n',
        'm', 'o', 'd', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'm', 'o', 'd', 'e', 'l', 's', '\n',
        'm', 'o', 'd', 'e', 'm', '\n',
        'm', 'o', 'd', 'e', 'm', 's', '\n',
        'm', 'o', 'd', 'e', 'r', 'a', 't', 'e', '\n',
        'm', 'o', 'd', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'm', 'o', 'd', 'e', 'r', 'a', 't', 'e', 'l', 'y', '\n',
        'm', 'o', 'd', 'e', 'r', 'a', 't', 'e', 's', '\n',
        'm', 'o', 'd', 'e', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'm', 'o', 'd', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'o', 'd', 'e', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'm', 'o', 'd', 'e', 'r', 'a', 't', 'o', 'r', '\n',
        'm', 'o', 'd', 'e', 'r', 'a', 't', 'o', 'r', 's', '\n',
        'm', 'o', 'd', 'e', 'r', 'n', '\n',
        'm', 'o', 'd', 'e', 'r', 'n', 'e', 'r', '\n',
        'm', 'o', 'd', 'e', 'r', 'n', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'o', 'd', 'e', 'r', 'n', 'i', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'm', 'o', 'd', 'e', 'r', 'n', 'i', 's', 'e', '\n',
        'm', 'o', 'd', 'e', 'r', 'n', 'i', 's', 'e', 'd', '\n',
        'm', 'o', 'd', 'e', 'r', 'n', 'i', 's', 'i', 'n', 'g', '\n',
        'm', 'o', 'd', 'e', 'r', 'n', 'i', 's', 'm', '\n',
        'm', 'o', 'd', 'e', 'r', 'n', 'i', 's', 't', '\n',
        'm', 'o', 'd', 'e', 'r', 'n', 'i', 's', 't', 'i', 'c', '\n',
        'm', 'o', 'd', 'e', 'r', 'n', 'i', 's', 't', 's', '\n',
        'm', 'o', 'd', 'e', 'r', 'n', 'i', 't', 'y', '\n',
        'm', 'o', 'd', 'e', 's', '\n',
        'm', 'o', 'd', 'e', 's', 't', '\n',
        'm', 'o', 'd', 'e', 's', 't', 'l', 'y', '\n',
        'm', 'o', 'd', 'e', 's', 't', 'y', '\n',
        'm', 'o', 'd', 'i', 'c', 'u', 'm', '\n',
        'm', 'o', 'd', 'i', 'f', 'i', 'a', 'b', 'l', 'e', '\n',
        'm', 'o', 'd', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'o', 'd', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'm', 'o', 'd', 'i', 'f', 'i', 'e', 'd', '\n',
        'm', 'o', 'd', 'i', 'f', 'i', 'e', 'r', '\n',
        'm', 'o', 'd', 'i', 'f', 'i', 'e', 'r', 's', '\n',
        'm', 'o', 'd', 'i', 'f', 'i', 'e', 's', '\n',
        'm', 'o', 'd', 'i', 'f', 'y', '\n',
        'm', 'o', 'd', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'm', 'o', 'd', 'i', 's', 'h', '\n',
        'm', 'o', 'd', 'i', 's', 'h', 'l', 'y', '\n',
        'm', 'o', 'd', 'u', 'l', 'a', 'r', '\n',
        'm', 'o', 'd', 'u', 'l', 'a', 'r', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'o', 'd', 'u', 'l', 'a', 'r', 'i', 's', 'e', '\n',
        'm', 'o', 'd', 'u', 'l', 'a', 'r', 'i', 's', 'e', 'd', '\n',
        'm', 'o', 'd', 'u', 'l', 'a', 'r', 'i', 's', 'i', 'n', 'g', '\n',
        'm', 'o', 'd', 'u', 'l', 'a', 'r', 'i', 't', 'y', '\n',
        'm', 'o', 'd', 'u', 'l', 'a', 't', 'e', '\n',
        'm', 'o', 'd', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'm', 'o', 'd', 'u', 'l', 'a', 't', 'e', 's', '\n',
        'm', 'o', 'd', 'u', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'm', 'o', 'd', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'o', 'd', 'u', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'm', 'o', 'd', 'u', 'l', 'a', 't', 'o', 'r', '\n',
        'm', 'o', 'd', 'u', 'l', 'e', '\n',
        'm', 'o', 'd', 'u', 'l', 'e', 's', '\n',
        'm', 'o', 'd', 'u', 'l', 'i', '\n',
        'm', 'o', 'd', 'u', 'l', 'u', 's', '\n',
        'm', 'o', 'g', 'u', 'l', '\n',
        'm', 'o', 'g', 'u', 'l', 's', '\n',
        'm', 'o', 'h', 'a', 'i', 'r', '\n',
        'm', 'o', 'h', 'a', 'i', 'r', 's', '\n',
        'm', 'o', 'i', 'e', 't', 'y', '\n',
        'm', 'o', 'i', 's', 't', '\n',
        'm', 'o', 'i', 's', 't', 'e', 'n', '\n',
        'm', 'o', 'i', 's', 't', 'e', 'n', 'e', 'd', '\n',
        'm', 'o', 'i', 's', 't', 'e', 'n', 'i', 'n', 'g', '\n',
        'm', 'o', 'i', 's', 't', 'e', 'n', 's', '\n',
        'm', 'o', 'i', 's', 't', 'e', 'r', '\n',
        'm', 'o', 'i', 's', 't', 'n', 'e', 's', 's', '\n',
        'm', 'o', 'i', 's', 't', 'u', 'r', 'e', '\n',
        'm', 'o', 'i', 's', 't', 'u', 'r', 'i', 's', 'e', '\n',
        'm', 'o', 'i', 's', 't', 'u', 'r', 'i', 's', 'e', 'r', '\n',
        'm', 'o', 'i', 's', 't', 'u', 'r', 'i', 's', 'e', 'r', 's', '\n',
        'm', 'o', 'i', 's', 't', 'u', 'r', 'i', 's', 'i', 'n', 'g', '\n',
        'm', 'o', 'l', 'a', 'r', '\n',
        'm', 'o', 'l', 'a', 'r', 'i', 't', 'i', 'e', 's', '\n',
        'm', 'o', 'l', 'a', 'r', 'i', 't', 'y', '\n',
        'm', 'o', 'l', 'a', 'r', 's', '\n',
        'm', 'o', 'l', 'a', 's', 's', 'e', 's', '\n',
        'm', 'o', 'l', 'd', '\n',
        'm', 'o', 'l', 'd', 's', '\n',
        'm', 'o', 'l', 'd', 'y', '\n',
        'm', 'o', 'l', 'e', '\n',
        'm', 'o', 'l', 'e', 'c', 'u', 'l', 'a', 'r', '\n',
        'm', 'o', 'l', 'e', 'c', 'u', 'l', 'e', '\n',
        'm', 'o', 'l', 'e', 'c', 'u', 'l', 'e', 's', '\n',
        'm', 'o', 'l', 'e', 'h', 'i', 'l', 'l', '\n',
        'm', 'o', 'l', 'e', 'h', 'i', 'l', 'l', 's', '\n',
        'm', 'o', 'l', 'e', 's', '\n',
        'm', 'o', 'l', 'e', 's', 'k', 'i', 'n', '\n',
        'm', 'o', 'l', 'e', 's', 't', '\n',
        'm', 'o', 'l', 'e', 's', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'o', 'l', 'e', 's', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'm', 'o', 'l', 'e', 's', 't', 'e', 'd', '\n',
        'm', 'o', 'l', 'e', 's', 't', 'e', 'r', '\n',
        'm', 'o', 'l', 'e', 's', 't', 'e', 'r', 's', '\n',
        'm', 'o', 'l', 'e', 's', 't', 'i', 'n', 'g', '\n',
        'm', 'o', 'l', 'e', 's', 't', 's', '\n',
        'm', 'o', 'l', 'l', 'i', 'f', 'i', 'e', 'd', '\n',
        'm', 'o', 'l', 'l', 'i', 'f', 'i', 'e', 's', '\n',
        'm', 'o', 'l', 'l', 'i', 'f', 'y', '\n',
        'm', 'o', 'l', 'l', 'u', 's', 'c', '\n',
        'm', 'o', 'l', 'l', 'u', 's', 'c', 'a', 'n', '\n',
        'm', 'o', 'l', 'l', 'u', 's', 'c', 's', '\n',
        'm', 'o', 'l', 't', 'e', 'n', '\n',
        'm', 'o', 'l', 't', 's', '\n',
        'm', 'o', 'l', 'y', 'b', 'd', 'e', 'n', 'u', 'm', '\n',
        'm', 'o', 'm', '\n',
        'm', 'o', 'm', 'e', 'n', 't', '\n',
        'm', 'o', 'm', 'e', 'n', 't', 'a', 'r', 'i', 'l', 'y', '\n',
        'm', 'o', 'm', 'e', 'n', 't', 'a', 'r', 'y', '\n',
        'm', 'o', 'm', 'e', 'n', 't', 'o', 'u', 's', '\n',
        'm', 'o', 'm', 'e', 'n', 't', 's', '\n',
        'm', 'o', 'm', 'e', 'n', 't', 'u', 'm', '\n',
        'm', 'o', 'm', 's', '\n',
        'm', 'o', 'n', 'a', 'c', 'o', '\n',
        'm', 'o', 'n', 'a', 'd', 'i', 'c', '\n',
        'm', 'o', 'n', 'a', 'l', 'i', 's', 'a', '\n',
        'm', 'o', 'n', 'a', 'r', 'c', 'h', '\n',
        'm', 'o', 'n', 'a', 'r', 'c', 'h', 'i', 'c', '\n',
        'm', 'o', 'n', 'a', 'r', 'c', 'h', 'i', 'c', 'a', 'l', '\n',
        'm', 'o', 'n', 'a', 'r', 'c', 'h', 'i', 'e', 's', '\n',
        'm', 'o', 'n', 'a', 'r', 'c', 'h', 'i', 's', 't', '\n',
        'm', 'o', 'n', 'a', 'r', 'c', 'h', 'i', 's', 't', 's', '\n',
        'm', 'o', 'n', 'a', 'r', 'c', 'h', 's', '\n',
        'm', 'o', 'n', 'a', 'r', 'c', 'h', 'y', '\n',
        'm', 'o', 'n', 'a', 's', 't', 'e', 'r', 'i', 'e', 's', '\n',
        'm', 'o', 'n', 'a', 's', 't', 'e', 'r', 'y', '\n',
        'm', 'o', 'n', 'a', 's', 't', 'i', 'c', '\n',
        'm', 'o', 'n', 'a', 's', 't', 'i', 'c', 'i', 's', 'm', '\n',
        'm', 'o', 'n', 'a', 'u', 'r', 'a', 'l', '\n',
        'm', 'o', 'n', 'd', 'a', 'y', '\n',
        'm', 'o', 'n', 'd', 'a', 'y', 's', '\n',
        'm', 'o', 'n', 'e', 't', 'a', 'r', 'i', 's', 'm', '\n',
        'm', 'o', 'n', 'e', 't', 'a', 'r', 'i', 's', 't', '\n',
        'm', 'o', 'n', 'e', 't', 'a', 'r', 'i', 's', 't', 's', '\n',
        'm', 'o', 'n', 'e', 't', 'a', 'r', 'y', '\n',
        'm', 'o', 'n', 'e', 'y', '\n',
        'm', 'o', 'n', 'e', 'y', 'e', 'd', '\n',
        'm', 'o', 'n', 'e', 'y', 'l', 'e', 'n', 'd', 'e', 'r', '\n',
        'm', 'o', 'n', 'e', 'y', 'l', 'e', 'n', 'd', 'e', 'r', 's', '\n',
        'm', 'o', 'n', 'e', 'y', 'l', 'e', 's', 's', '\n',
        'm', 'o', 'n', 'e', 'y', 's', '\n',
        'm', 'o', 'n', 'g', 'e', 'r', '\n',
        'm', 'o', 'n', 'g', 'e', 'r', 's', '\n',
        'm', 'o', 'n', 'g', 'o', 'l', '\n',
        'm', 'o', 'n', 'g', 'o', 'l', 's', '\n',
        'm', 'o', 'n', 'g', 'o', 'o', 's', 'e', '\n',
        'm', 'o', 'n', 'g', 'r', 'e', 'l', '\n',
        'm', 'o', 'n', 'g', 'r', 'e', 'l', 's', '\n',
        'm', 'o', 'n', 'i', 'e', 's', '\n',
        'm', 'o', 'n', 'i', 't', 'i', 'o', 'n', '\n',
        'm', 'o', 'n', 'i', 't', 'o', 'r', '\n',
        'm', 'o', 'n', 'i', 't', 'o', 'r', 'e', 'd', '\n',
        'm', 'o', 'n', 'i', 't', 'o', 'r', 'i', 'n', 'g', '\n',
        'm', 'o', 'n', 'i', 't', 'o', 'r', 's', '\n',
        'm', 'o', 'n', 'k', '\n',
        'm', 'o', 'n', 'k', 'e', 'y', '\n',
        'm', 'o', 'n', 'k', 'e', 'y', 'e', 'd', '\n',
        'm', 'o', 'n', 'k', 'e', 'y', 'i', 'n', 'g', '\n',
        'm', 'o', 'n', 'k', 'e', 'y', 's', '\n',
        'm', 'o', 'n', 'k', 'f', 'i', 's', 'h', '\n',
        'm', 'o', 'n', 'k', 'i', 's', 'h', '\n',
        'm', 'o', 'n', 'k', 's', '\n',
        'm', 'o', 'n', 'o', '\n',
        'm', 'o', 'n', 'o', 'c', 'h', 'r', 'o', 'm', 'a', 't', 'i', 'c', '\n',
        'm', 'o', 'n', 'o', 'c', 'h', 'r', 'o', 'm', 'e', '\n',
        'm', 'o', 'n', 'o', 'c', 'l', 'e', '\n',
        'm', 'o', 'n', 'o', 'c', 'l', 'e', 'd', '\n',
        'm', 'o', 'n', 'o', 'c', 'l', 'o', 'n', 'a', 'l', '\n',
        'm', 'o', 'n', 'o', 'c', 'u', 'l', 'a', 'r', '\n',
        'm', 'o', 'n', 'o', 'c', 'u', 'l', 't', 'u', 'r', 'e', '\n',
        'm', 'o', 'n', 'o', 'c', 'y', 't', 'e', 's', '\n',
        'm', 'o', 'n', 'o', 'g', 'a', 'm', 'o', 'u', 's', '\n',
        'm', 'o', 'n', 'o', 'g', 'a', 'm', 'o', 'u', 's', 'l', 'y', '\n',
        'm', 'o', 'n', 'o', 'g', 'a', 'm', 'y', '\n',
        'm', 'o', 'n', 'o', 'g', 'r', 'a', 'm', '\n',
        'm', 'o', 'n', 'o', 'g', 'r', 'a', 'm', 'm', 'e', 'd', '\n',
        'm', 'o', 'n', 'o', 'g', 'r', 'a', 'p', 'h', '\n',
        'm', 'o', 'n', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', '\n',
        'm', 'o', 'n', 'o', 'g', 'r', 'a', 'p', 'h', 's', '\n',
        'm', 'o', 'n', 'o', 'l', 'a', 'y', 'e', 'r', '\n',
        'm', 'o', 'n', 'o', 'l', 'a', 'y', 'e', 'r', 's', '\n',
        'm', 'o', 'n', 'o', 'l', 'i', 'n', 'g', 'u', 'a', 'l', '\n',
        'm', 'o', 'n', 'o', 'l', 'i', 't', 'h', '\n',
        'm', 'o', 'n', 'o', 'l', 'i', 't', 'h', 'i', 'c', '\n',
        'm', 'o', 'n', 'o', 'l', 'i', 't', 'h', 's', '\n',
        'm', 'o', 'n', 'o', 'l', 'o', 'g', 'u', 'e', '\n',
        'm', 'o', 'n', 'o', 'l', 'o', 'g', 'u', 'e', 's', '\n',
        'm', 'o', 'n', 'o', 'm', 'a', 'n', 'i', 'a', '\n',
        'm', 'o', 'n', 'o', 'm', 'e', 'r', '\n',
        'm', 'o', 'n', 'o', 'm', 'e', 'r', 'i', 'c', '\n',
        'm', 'o', 'n', 'o', 'm', 'e', 'r', 's', '\n',
        'm', 'o', 'n', 'o', 'm', 'i', 'a', 'l', '\n',
        'm', 'o', 'n', 'o', 'm', 'i', 'a', 'l', 's', '\n',
        'm', 'o', 'n', 'o', 'm', 'o', 'l', 'e', 'c', 'u', 'l', 'a', 'r', '\n',
        'm', 'o', 'n', 'o', 'p', 'h', 'o', 'n', 'i', 'c', '\n',
        'm', 'o', 'n', 'o', 'p', 'h', 't', 'h', 'o', 'n', 'g', 's', '\n',
        'm', 'o', 'n', 'o', 'p', 'l', 'a', 'n', 'e', '\n',
        'm', 'o', 'n', 'o', 'p', 'o', 'l', 'e', '\n',
        'm', 'o', 'n', 'o', 'p', 'o', 'l', 'e', 's', '\n',
        'm', 'o', 'n', 'o', 'p', 'o', 'l', 'i', 'e', 's', '\n',
        'm', 'o', 'n', 'o', 'p', 'o', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'o', 'n', 'o', 'p', 'o', 'l', 'i', 's', 'e', '\n',
        'm', 'o', 'n', 'o', 'p', 'o', 'l', 'i', 's', 'e', 'd', '\n',
        'm', 'o', 'n', 'o', 'p', 'o', 'l', 'i', 's', 'e', 's', '\n',
        'm', 'o', 'n', 'o', 'p', 'o', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'm', 'o', 'n', 'o', 'p', 'o', 'l', 'i', 's', 't', '\n',
        'm', 'o', 'n', 'o', 'p', 'o', 'l', 'i', 's', 't', 'i', 'c', '\n',
        'm', 'o', 'n', 'o', 'p', 'o', 'l', 'i', 's', 't', 's', '\n',
        'm', 'o', 'n', 'o', 'p', 'o', 'l', 'y', '\n',
        'm', 'o', 'n', 'o', 'r', 'a', 'i', 'l', '\n',
        'm', 'o', 'n', 'o', 's', 't', 'a', 'b', 'l', 'e', '\n',
        'm', 'o', 'n', 'o', 's', 'y', 'l', 'l', 'a', 'b', 'i', 'c', '\n',
        'm', 'o', 'n', 'o', 's', 'y', 'l', 'l', 'a', 'b', 'l', 'e', '\n',
        'm', 'o', 'n', 'o', 's', 'y', 'l', 'l', 'a', 'b', 'l', 'e', 's', '\n',
        'm', 'o', 'n', 'o', 't', 'h', 'e', 'i', 's', 'm', '\n',
        'm', 'o', 'n', 'o', 't', 'h', 'e', 'i', 's', 't', '\n',
        'm', 'o', 'n', 'o', 't', 'h', 'e', 'i', 's', 't', 'i', 'c', '\n',
        'm', 'o', 'n', 'o', 't', 'h', 'e', 'i', 's', 't', 's', '\n',
        'm', 'o', 'n', 'o', 't', 'o', 'n', 'e', '\n',
        'm', 'o', 'n', 'o', 't', 'o', 'n', 'i', 'c', '\n',
        'm', 'o', 'n', 'o', 't', 'o', 'n', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'm', 'o', 'n', 'o', 't', 'o', 'n', 'i', 'c', 'i', 't', 'y', '\n',
        'm', 'o', 'n', 'o', 't', 'o', 'n', 'o', 'u', 's', '\n',
        'm', 'o', 'n', 'o', 't', 'o', 'n', 'o', 'u', 's', 'l', 'y', '\n',
        'm', 'o', 'n', 'o', 't', 'o', 'n', 'y', '\n',
        'm', 'o', 'n', 'o', 'x', 'i', 'd', 'e', '\n',
        'm', 'o', 'n', 'r', 'o', 'e', '\n',
        'm', 'o', 'n', 's', 'i', 'e', 'u', 'r', '\n',
        'm', 'o', 'n', 's', 'o', 'o', 'n', '\n',
        'm', 'o', 'n', 's', 'o', 'o', 'n', 's', '\n',
        'm', 'o', 'n', 's', 't', 'e', 'r', '\n',
        'm', 'o', 'n', 's', 't', 'e', 'r', 's', '\n',
        'm', 'o', 'n', 's', 't', 'r', 'o', 's', 'i', 't', 'i', 'e', 's', '\n',
        'm', 'o', 'n', 's', 't', 'r', 'o', 's', 'i', 't', 'y', '\n',
        'm', 'o', 'n', 's', 't', 'r', 'o', 'u', 's', '\n',
        'm', 'o', 'n', 's', 't', 'r', 'o', 'u', 's', 'l', 'y', '\n',
        'm', 'o', 'n', 't', 'a', 'g', 'e', '\n',
        'm', 'o', 'n', 't', 'a', 'g', 'e', 's', '\n',
        'm', 'o', 'n', 't', 'h', '\n',
        'm', 'o', 'n', 't', 'h', 'l', 'i', 'e', 's', '\n',
        'm', 'o', 'n', 't', 'h', 'l', 'y', '\n',
        'm', 'o', 'n', 't', 'h', 's', '\n',
        'm', 'o', 'n', 't', 'r', 'e', 'a', 'l', '\n',
        'm', 'o', 'n', 'u', 'm', 'e', 'n', 't', '\n',
        'm', 'o', 'n', 'u', 'm', 'e', 'n', 't', 'a', 'l', '\n',
        'm', 'o', 'n', 'u', 'm', 'e', 'n', 't', 'a', 'l', 'l', 'y', '\n',
        'm', 'o', 'n', 'u', 'm', 'e', 'n', 't', 's', '\n',
        'm', 'o', 'o', '\n',
        'm', 'o', 'o', 'd', '\n',
        'm', 'o', 'o', 'd', 'i', 'e', 's', 't', '\n',
        'm', 'o', 'o', 'd', 'i', 'l', 'y', '\n',
        'm', 'o', 'o', 'd', 'i', 'n', 'e', 's', 's', '\n',
        'm', 'o', 'o', 'd', 's', '\n',
        'm', 'o', 'o', 'd', 'y', '\n',
        'm', 'o', 'o', 'e', 'd', '\n',
        'm', 'o', 'o', 'i', 'n', 'g', '\n',
        'm', 'o', 'o', 'n', '\n',
        'm', 'o', 'o', 'n', 'b', 'e', 'a', 'm', '\n',
        'm', 'o', 'o', 'n', 'b', 'e', 'a', 'm', 's', '\n',
        'm', 'o', 'o', 'n', 'i', 'n', 'g', '\n',
        'm', 'o', 'o', 'n', 'l', 'e', 's', 's', '\n',
        'm', 'o', 'o', 'n', 'l', 'i', 'g', 'h', 't', '\n',
        'm', 'o', 'o', 'n', 'l', 'i', 'g', 'h', 't', 'i', 'n', 'g', '\n',
        'm', 'o', 'o', 'n', 'l', 'i', 't', '\n',
        'm', 'o', 'o', 'n', 'r', 'i', 's', 'e', '\n',
        'm', 'o', 'o', 'n', 's', '\n',
        'm', 'o', 'o', 'n', 's', 'h', 'i', 'n', 'e', '\n',
        'm', 'o', 'o', 'n', 's', 'h', 'o', 't', '\n',
        'm', 'o', 'o', 'n', 's', 'h', 'o', 't', 's', '\n',
        'm', 'o', 'o', 'n', 's', 't', 'o', 'n', 'e', 's', '\n',
        'm', 'o', 'o', 'r', '\n',
        'm', 'o', 'o', 'r', 'e', 'd', '\n',
        'm', 'o', 'o', 'r', 'h', 'e', 'n', '\n',
        'm', 'o', 'o', 'r', 'h', 'e', 'n', 's', '\n',
        'm', 'o', 'o', 'r', 'i', 'n', 'g', '\n',
        'm', 'o', 'o', 'r', 'i', 'n', 'g', 's', '\n',
        'm', 'o', 'o', 'r', 'l', 'a', 'n', 'd', '\n',
        'm', 'o', 'o', 'r', 'l', 'a', 'n', 'd', 's', '\n',
        'm', 'o', 'o', 'r', 's', '\n',
        'm', 'o', 'o', 's', '\n',
        'm', 'o', 'o', 's', 'e', '\n',
        'm', 'o', 'o', 't', '\n',
        'm', 'o', 'o', 't', 'e', 'd', '\n',
        'm', 'o', 'p', '\n',
        'm', 'o', 'p', 'e', '\n',
        'm', 'o', 'p', 'e', 'd', '\n',
        'm', 'o', 'p', 'e', 'd', 's', '\n',
        'm', 'o', 'p', 'e', 's', '\n',
        'm', 'o', 'p', 'i', 'n', 'g', '\n',
        'm', 'o', 'p', 'p', 'e', 'd', '\n',
        'm', 'o', 'p', 'p', 'i', 'n', 'g', '\n',
        'm', 'o', 'p', 's', '\n',
        'm', 'o', 'r', 'a', 'i', 'n', 'e', '\n',
        'm', 'o', 'r', 'a', 'i', 'n', 'e', 's', '\n',
        'm', 'o', 'r', 'a', 'l', '\n',
        'm', 'o', 'r', 'a', 'l', 'e', '\n',
        'm', 'o', 'r', 'a', 'l', 'e', 's', '\n',
        'm', 'o', 'r', 'a', 'l', 'i', 's', 'e', '\n',
        'm', 'o', 'r', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'm', 'o', 'r', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'm', 'o', 'r', 'a', 'l', 'i', 's', 'm', '\n',
        'm', 'o', 'r', 'a', 'l', 'i', 's', 't', '\n',
        'm', 'o', 'r', 'a', 'l', 'i', 's', 't', 'i', 'c', '\n',
        'm', 'o', 'r', 'a', 'l', 'i', 's', 't', 's', '\n',
        'm', 'o', 'r', 'a', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'm', 'o', 'r', 'a', 'l', 'i', 't', 'y', '\n',
        'm', 'o', 'r', 'a', 'l', 'l', 'y', '\n',
        'm', 'o', 'r', 'a', 'l', 's', '\n',
        'm', 'o', 'r', 'a', 's', 's', '\n',
        'm', 'o', 'r', 'a', 's', 's', 'e', 's', '\n',
        'm', 'o', 'r', 'a', 't', 'o', 'r', 'i', 'u', 'm', '\n',
        'm', 'o', 'r', 'a', 'y', '\n',
        'm', 'o', 'r', 'a', 'y', 's', '\n',
        'm', 'o', 'r', 'b', 'i', 'd', '\n',
        'm', 'o', 'r', 'b', 'i', 'd', 'i', 't', 'y', '\n',
        'm', 'o', 'r', 'b', 'i', 'd', 'l', 'y', '\n',
        'm', 'o', 'r', 'd', 'a', 'n', 't', '\n',
        'm', 'o', 'r', 'e', '\n',
        'm', 'o', 'r', 'e', 'o', 'v', 'e', 'r', '\n',
        'm', 'o', 'r', 'e', 's', '\n',
        'm', 'o', 'r', 'g', 'u', 'e', '\n',
        'm', 'o', 'r', 'i', 'b', 'u', 'n', 'd', '\n',
        'm', 'o', 'r', 'i', 'b', 'u', 'n', 'd', 'i', 't', 'y', '\n',
        'm', 'o', 'r', 'i', 'b', 'u', 'n', 'd', 'l', 'y', '\n',
        'm', 'o', 'r', 'm', 'o', 'n', '\n',
        'm', 'o', 'r', 'm', 'o', 'n', 's', '\n',
        'm', 'o', 'r', 'n', '\n',
        'm', 'o', 'r', 'n', 'i', 'n', 'g', '\n',
        'm', 'o', 'r', 'n', 'i', 'n', 'g', 's', '\n',
        'm', 'o', 'r', 'n', 's', '\n',
        'm', 'o', 'r', 'o', 'c', 'c', 'a', 'n', '\n',
        'm', 'o', 'r', 'o', 'c', 'c', 'o', '\n',
        'm', 'o', 'r', 'o', 'n', '\n',
        'm', 'o', 'r', 'o', 'n', 'i', 'c', '\n',
        'm', 'o', 'r', 'o', 'n', 's', '\n',
        'm', 'o', 'r', 'o', 's', 'e', '\n',
        'm', 'o', 'r', 'o', 's', 'e', 'l', 'y', '\n',
        'm', 'o', 'r', 'o', 's', 'e', 'n', 'e', 's', 's', '\n',
        'm', 'o', 'r', 'p', 'h', '\n',
        'm', 'o', 'r', 'p', 'h', 'e', 'm', 'e', '\n',
        'm', 'o', 'r', 'p', 'h', 'e', 'm', 'e', 's', '\n',
        'm', 'o', 'r', 'p', 'h', 'e', 'u', 's', '\n',
        'm', 'o', 'r', 'p', 'h', 'i', 'a', '\n',
        'm', 'o', 'r', 'p', 'h', 'i', 'n', 'e', '\n',
        'm', 'o', 'r', 'p', 'h', 'i', 's', 'm', '\n',
        'm', 'o', 'r', 'p', 'h', 'i', 's', 'm', 's', '\n',
        'm', 'o', 'r', 'p', 'h', 'o', 'g', 'e', 'n', 'e', 's', 'i', 's', '\n',
        'm', 'o', 'r', 'p', 'h', 'o', 'g', 'e', 'n', 'e', 't', 'i', 'c', '\n',
        'm', 'o', 'r', 'p', 'h', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'm', 'o', 'r', 'p', 'h', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'm', 'o', 'r', 'p', 'h', 'o', 'l', 'o', 'g', 'i', 'e', 's', '\n',
        'm', 'o', 'r', 'p', 'h', 'o', 'l', 'o', 'g', 'y', '\n',
        'm', 'o', 'r', 'r', 'o', 'w', '\n',
        'm', 'o', 'r', 's', 'e', '\n',
        'm', 'o', 'r', 's', 'e', 'l', '\n',
        'm', 'o', 'r', 's', 'e', 'l', 's', '\n',
        'm', 'o', 'r', 't', '\n',
        'm', 'o', 'r', 't', 'a', 'l', '\n',
        'm', 'o', 'r', 't', 'a', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'm', 'o', 'r', 't', 'a', 'l', 'i', 't', 'y', '\n',
        'm', 'o', 'r', 't', 'a', 'l', 'l', 'y', '\n',
        'm', 'o', 'r', 't', 'a', 'l', 's', '\n',
        'm', 'o', 'r', 't', 'a', 'r', '\n',
        'm', 'o', 'r', 't', 'a', 'r', 's', '\n',
        'm', 'o', 'r', 't', 'g', 'a', 'g', 'e', '\n',
        'm', 'o', 'r', 't', 'g', 'a', 'g', 'e', 'a', 'b', 'l', 'e', '\n',
        'm', 'o', 'r', 't', 'g', 'a', 'g', 'e', 'd', '\n',
        'm', 'o', 'r', 't', 'g', 'a', 'g', 'e', 'e', '\n',
        'm', 'o', 'r', 't', 'g', 'a', 'g', 'e', 'e', 's', '\n',
        'm', 'o', 'r', 't', 'g', 'a', 'g', 'e', 's', '\n',
        'm', 'o', 'r', 't', 'g', 'a', 'g', 'i', 'n', 'g', '\n',
        'm', 'o', 'r', 't', 'g', 'a', 'g', 'o', 'r', '\n',
        'm', 'o', 'r', 't', 'i', 'c', 'e', '\n',
        'm', 'o', 'r', 't', 'i', 'c', 'e', 's', '\n',
        'm', 'o', 'r', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'o', 'r', 't', 'i', 'f', 'i', 'e', 'd', '\n',
        'm', 'o', 'r', 't', 'i', 'f', 'y', '\n',
        'm', 'o', 'r', 't', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'm', 'o', 'r', 't', 'i', 's', 'e', '\n',
        'm', 'o', 'r', 't', 'i', 's', 'e', 's', '\n',
        'm', 'o', 'r', 't', 'u', 'a', 'r', 'y', '\n',
        'm', 'o', 's', 'a', 'i', 'c', '\n',
        'm', 'o', 's', 'a', 'i', 'c', 's', '\n',
        'm', 'o', 's', 'c', 'o', 'w', '\n',
        'm', 'o', 's', 'e', 's', '\n',
        'm', 'o', 's', 'q', 'u', 'e', '\n',
        'm', 'o', 's', 'q', 'u', 'e', 's', '\n',
        'm', 'o', 's', 'q', 'u', 'i', 't', 'o', '\n',
        'm', 'o', 's', 's', '\n',
        'm', 'o', 's', 's', 'e', 's', '\n',
        'm', 'o', 's', 's', 'i', 'e', 'r', '\n',
        'm', 'o', 's', 's', 'i', 'e', 's', 't', '\n',
        'm', 'o', 's', 's', 'y', '\n',
        'm', 'o', 's', 't', '\n',
        'm', 'o', 's', 't', 'l', 'y', '\n',
        'm', 'o', 't', 'e', 'l', '\n',
        'm', 'o', 't', 'e', 'l', 's', '\n',
        'm', 'o', 't', 'e', 's', '\n',
        'm', 'o', 't', 'e', 't', '\n',
        'm', 'o', 't', 'e', 't', 's', '\n',
        'm', 'o', 't', 'h', '\n',
        'm', 'o', 't', 'h', 'b', 'a', 'l', 'l', '\n',
        'm', 'o', 't', 'h', 'b', 'a', 'l', 'l', 'e', 'd', '\n',
        'm', 'o', 't', 'h', 'b', 'a', 'l', 'l', 's', '\n',
        'm', 'o', 't', 'h', 'e', 'a', 't', 'e', 'n', '\n',
        'm', 'o', 't', 'h', 'e', 'r', '\n',
        'm', 'o', 't', 'h', 'e', 'r', 'b', 'o', 'a', 'r', 'd', '\n',
        'm', 'o', 't', 'h', 'e', 'r', 'b', 'o', 'a', 'r', 'd', 's', '\n',
        'm', 'o', 't', 'h', 'e', 'r', 'e', 'd', '\n',
        'm', 'o', 't', 'h', 'e', 'r', 'h', 'o', 'o', 'd', '\n',
        'm', 'o', 't', 'h', 'e', 'r', 'i', 'n', 'g', '\n',
        'm', 'o', 't', 'h', 'e', 'r', 'i', 'n', 'l', 'a', 'w', '\n',
        'm', 'o', 't', 'h', 'e', 'r', 'l', 'a', 'n', 'd', '\n',
        'm', 'o', 't', 'h', 'e', 'r', 'l', 'e', 's', 's', '\n',
        'm', 'o', 't', 'h', 'e', 'r', 'l', 'y', '\n',
        'm', 'o', 't', 'h', 'e', 'r', 'o', 'f', 'p', 'e', 'a', 'r', 'l', '\n',
        'm', 'o', 't', 'h', 'e', 'r', 's', '\n',
        'm', 'o', 't', 'h', 'e', 'r', 's', 'i', 'n', 'l', 'a', 'w', '\n',
        'm', 'o', 't', 'h', 'e', 'r', 's', 't', 'o', 'b', 'e', '\n',
        'm', 'o', 't', 'h', 's', '\n',
        'm', 'o', 't', 'i', 'f', '\n',
        'm', 'o', 't', 'i', 'f', 's', '\n',
        'm', 'o', 't', 'i', 'l', 'e', '\n',
        'm', 'o', 't', 'i', 'l', 'i', 't', 'y', '\n',
        'm', 'o', 't', 'i', 'o', 'n', '\n',
        'm', 'o', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'm', 'o', 't', 'i', 'o', 'n', 'e', 'd', '\n',
        'm', 'o', 't', 'i', 'o', 'n', 'i', 'n', 'g', '\n',
        'm', 'o', 't', 'i', 'o', 'n', 'l', 'e', 's', 's', '\n',
        'm', 'o', 't', 'i', 'o', 'n', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'm', 'o', 't', 'i', 'o', 'n', 's', '\n',
        'm', 'o', 't', 'i', 'v', 'a', 't', 'e', '\n',
        'm', 'o', 't', 'i', 'v', 'a', 't', 'e', 'd', '\n',
        'm', 'o', 't', 'i', 'v', 'a', 't', 'e', 's', '\n',
        'm', 'o', 't', 'i', 'v', 'a', 't', 'i', 'n', 'g', '\n',
        'm', 'o', 't', 'i', 'v', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'o', 't', 'i', 'v', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'm', 'o', 't', 'i', 'v', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'm', 'o', 't', 'i', 'v', 'a', 't', 'o', 'r', '\n',
        'm', 'o', 't', 'i', 'v', 'a', 't', 'o', 'r', 's', '\n',
        'm', 'o', 't', 'i', 'v', 'e', '\n',
        'm', 'o', 't', 'i', 'v', 'e', 'l', 'e', 's', 's', '\n',
        'm', 'o', 't', 'i', 'v', 'e', 's', '\n',
        'm', 'o', 't', 'l', 'e', 'y', '\n',
        'm', 'o', 't', 'l', 'i', 'e', 'r', '\n',
        'm', 'o', 't', 'l', 'i', 'e', 's', 't', '\n',
        'm', 'o', 't', 'o', 'c', 'r', 'o', 's', 's', '\n',
        'm', 'o', 't', 'o', 'r', '\n',
        'm', 'o', 't', 'o', 'r', 'b', 'i', 'k', 'e', '\n',
        'm', 'o', 't', 'o', 'r', 'b', 'i', 'k', 'e', 's', '\n',
        'm', 'o', 't', 'o', 'r', 'c', 'a', 'd', 'e', '\n',
        'm', 'o', 't', 'o', 'r', 'c', 'a', 'r', '\n',
        'm', 'o', 't', 'o', 'r', 'c', 'a', 'r', 's', '\n',
        'm', 'o', 't', 'o', 'r', 'c', 'y', 'c', 'l', 'e', '\n',
        'm', 'o', 't', 'o', 'r', 'c', 'y', 'c', 'l', 'e', 's', '\n',
        'm', 'o', 't', 'o', 'r', 'c', 'y', 'c', 'l', 'i', 'n', 'g', '\n',
        'm', 'o', 't', 'o', 'r', 'c', 'y', 'c', 'l', 'i', 's', 't', '\n',
        'm', 'o', 't', 'o', 'r', 'c', 'y', 'c', 'l', 'i', 's', 't', 's', '\n',
        'm', 'o', 't', 'o', 'r', 'e', 'd', '\n',
        'm', 'o', 't', 'o', 'r', 'i', 'n', 'g', '\n',
        'm', 'o', 't', 'o', 'r', 'i', 's', 'e', 'd', '\n',
        'm', 'o', 't', 'o', 'r', 'i', 's', 't', '\n',
        'm', 'o', 't', 'o', 'r', 'i', 's', 't', 's', '\n',
        'm', 'o', 't', 'o', 'r', 's', '\n',
        'm', 'o', 't', 'o', 'r', 'w', 'a', 'y', '\n',
        'm', 'o', 't', 'o', 'r', 'w', 'a', 'y', 's', '\n',
        'm', 'o', 't', 't', 'l', 'e', 'd', '\n',
        'm', 'o', 't', 't', 'o', '\n',
        'm', 'o', 'u', 'l', 'd', '\n',
        'm', 'o', 'u', 'l', 'd', 'e', 'd', '\n',
        'm', 'o', 'u', 'l', 'd', 'e', 'r', '\n',
        'm', 'o', 'u', 'l', 'd', 'e', 'r', 'i', 'n', 'g', '\n',
        'm', 'o', 'u', 'l', 'd', 'e', 'r', 's', '\n',
        'm', 'o', 'u', 'l', 'd', 'i', 'e', 'r', '\n',
        'm', 'o', 'u', 'l', 'd', 'i', 'e', 's', 't', '\n',
        'm', 'o', 'u', 'l', 'd', 'i', 'n', 'g', '\n',
        'm', 'o', 'u', 'l', 'd', 'i', 'n', 'g', 's', '\n',
        'm', 'o', 'u', 'l', 'd', 's', '\n',
        'm', 'o', 'u', 'l', 'd', 'y', '\n',
        'm', 'o', 'u', 'l', 't', '\n',
        'm', 'o', 'u', 'l', 't', 'e', 'd', '\n',
        'm', 'o', 'u', 'l', 't', 'i', 'n', 'g', '\n',
        'm', 'o', 'u', 'l', 't', 's', '\n',
        'm', 'o', 'u', 'n', 'd', '\n',
        'm', 'o', 'u', 'n', 'd', 'e', 'd', '\n',
        'm', 'o', 'u', 'n', 'd', 's', '\n',
        'm', 'o', 'u', 'n', 't', '\n',
        'm', 'o', 'u', 'n', 't', 'a', 'b', 'l', 'e', '\n',
        'm', 'o', 'u', 'n', 't', 'a', 'i', 'n', '\n',
        'm', 'o', 'u', 'n', 't', 'a', 'i', 'n', 'e', 'e', 'r', '\n',
        'm', 'o', 'u', 'n', 't', 'a', 'i', 'n', 'e', 'e', 'r', 'i', 'n', 'g', '\n',
        'm', 'o', 'u', 'n', 't', 'a', 'i', 'n', 'e', 'e', 'r', 's', '\n',
        'm', 'o', 'u', 'n', 't', 'a', 'i', 'n', 'o', 'u', 's', '\n',
        'm', 'o', 'u', 'n', 't', 'a', 'i', 'n', 's', '\n',
        'm', 'o', 'u', 'n', 't', 'a', 'i', 'n', 's', 'i', 'd', 'e', '\n',
        'm', 'o', 'u', 'n', 't', 'a', 'i', 'n', 's', 'i', 'd', 'e', 's', '\n',
        'm', 'o', 'u', 'n', 't', 'e', 'd', '\n',
        'm', 'o', 'u', 'n', 't', 'i', 'e', '\n',
        'm', 'o', 'u', 'n', 't', 'i', 'e', 's', '\n',
        'm', 'o', 'u', 'n', 't', 'i', 'n', 'g', '\n',
        'm', 'o', 'u', 'n', 't', 'i', 'n', 'g', 's', '\n',
        'm', 'o', 'u', 'n', 't', 's', '\n',
        'm', 'o', 'u', 'r', 'n', '\n',
        'm', 'o', 'u', 'r', 'n', 'e', 'd', '\n',
        'm', 'o', 'u', 'r', 'n', 'e', 'r', '\n',
        'm', 'o', 'u', 'r', 'n', 'e', 'r', 's', '\n',
        'm', 'o', 'u', 'r', 'n', 'f', 'u', 'l', '\n',
        'm', 'o', 'u', 'r', 'n', 'f', 'u', 'l', 'l', 'y', '\n',
        'm', 'o', 'u', 'r', 'n', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'm', 'o', 'u', 'r', 'n', 'i', 'n', 'g', '\n',
        'm', 'o', 'u', 'r', 'n', 's', '\n',
        'm', 'o', 'u', 's', 'e', '\n',
        'm', 'o', 'u', 's', 'e', 'l', 'i', 'k', 'e', '\n',
        'm', 'o', 'u', 's', 'e', 't', 'r', 'a', 'p', '\n',
        'm', 'o', 'u', 's', 'e', 't', 'r', 'a', 'p', 's', '\n',
        'm', 'o', 'u', 's', 'e', 'y', '\n',
        'm', 'o', 'u', 's', 's', 'a', 'k', 'a', '\n',
        'm', 'o', 'u', 's', 's', 'e', '\n',
        'm', 'o', 'u', 's', 's', 'e', 's', '\n',
        'm', 'o', 'u', 's', 't', 'a', 'c', 'h', 'e', '\n',
        'm', 'o', 'u', 's', 't', 'a', 'c', 'h', 'e', 'd', '\n',
        'm', 'o', 'u', 's', 't', 'a', 'c', 'h', 'e', 's', '\n',
        'm', 'o', 'u', 's', 'y', '\n',
        'm', 'o', 'u', 't', 'h', '\n',
        'm', 'o', 'u', 't', 'h', 'e', 'd', '\n',
        'm', 'o', 'u', 't', 'h', 'f', 'u', 'l', '\n',
        'm', 'o', 'u', 't', 'h', 'f', 'u', 'l', 's', '\n',
        'm', 'o', 'u', 't', 'h', 'i', 'n', 'g', '\n',
        'm', 'o', 'u', 't', 'h', 'o', 'r', 'g', 'a', 'n', '\n',
        'm', 'o', 'u', 't', 'h', 'p', 'a', 'r', 't', 's', '\n',
        'm', 'o', 'u', 't', 'h', 'p', 'i', 'e', 'c', 'e', '\n',
        'm', 'o', 'u', 't', 'h', 'p', 'i', 'e', 'c', 'e', 's', '\n',
        'm', 'o', 'u', 't', 'h', 's', '\n',
        'm', 'o', 'u', 't', 'h', 't', 'o', 'm', 'o', 'u', 't', 'h', '\n',
        'm', 'o', 'u', 't', 'h', 'w', 'a', 's', 'h', '\n',
        'm', 'o', 'u', 't', 'h', 'w', 'a', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'm', 'o', 'v', 'a', 'b', 'l', 'e', '\n',
        'm', 'o', 'v', 'e', '\n',
        'm', 'o', 'v', 'e', 'a', 'b', 'l', 'e', '\n',
        'm', 'o', 'v', 'e', 'd', '\n',
        'm', 'o', 'v', 'e', 'm', 'e', 'n', 't', '\n',
        'm', 'o', 'v', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'm', 'o', 'v', 'e', 'r', '\n',
        'm', 'o', 'v', 'e', 'r', 's', '\n',
        'm', 'o', 'v', 'e', 's', '\n',
        'm', 'o', 'v', 'i', 'e', '\n',
        'm', 'o', 'v', 'i', 'e', 's', '\n',
        'm', 'o', 'v', 'i', 'n', 'g', '\n',
        'm', 'o', 'v', 'i', 'n', 'g', 'l', 'y', '\n',
        'm', 'o', 'w', '\n',
        'm', 'o', 'w', 'e', 'd', '\n',
        'm', 'o', 'w', 'e', 'r', '\n',
        'm', 'o', 'w', 'e', 'r', 's', '\n',
        'm', 'o', 'w', 'i', 'n', 'g', '\n',
        'm', 'o', 'w', 'n', '\n',
        'm', 'o', 'w', 's', '\n',
        'm', 'o', 'z', 'a', 'r', 't', '\n',
        'm', 'r', '\n',
        'm', 'r', 's', '\n',
        'm', 's', '\n',
        'm', 'u', '\n',
        'm', 'u', 'c', 'h', '\n',
        'm', 'u', 'c', 'h', 'n', 'e', 's', 's', '\n',
        'm', 'u', 'c', 'k', '\n',
        'm', 'u', 'c', 'k', 'e', 'd', '\n',
        'm', 'u', 'c', 'k', 'i', 'n', 'g', '\n',
        'm', 'u', 'c', 'k', 's', '\n',
        'm', 'u', 'c', 'k', 'y', '\n',
        'm', 'u', 'c', 'o', 's', 'a', '\n',
        'm', 'u', 'c', 'o', 'u', 's', '\n',
        'm', 'u', 'c', 'u', 's', '\n',
        'm', 'u', 'd', '\n',
        'm', 'u', 'd', 'd', 'i', 'e', 'd', '\n',
        'm', 'u', 'd', 'd', 'i', 'e', 'r', '\n',
        'm', 'u', 'd', 'd', 'i', 'e', 's', '\n',
        'm', 'u', 'd', 'd', 'i', 'e', 's', 't', '\n',
        'm', 'u', 'd', 'd', 'l', 'e', '\n',
        'm', 'u', 'd', 'd', 'l', 'e', 'd', '\n',
        'm', 'u', 'd', 'd', 'l', 'e', 's', '\n',
        'm', 'u', 'd', 'd', 'l', 'i', 'n', 'g', '\n',
        'm', 'u', 'd', 'd', 'y', '\n',
        'm', 'u', 'd', 'd', 'y', 'i', 'n', 'g', '\n',
        'm', 'u', 'd', 'f', 'l', 'a', 't', 's', '\n',
        'm', 'u', 'd', 'f', 'l', 'o', 'w', '\n',
        'm', 'u', 'd', 'f', 'l', 'o', 'w', 's', '\n',
        'm', 'u', 'd', 'g', 'u', 'a', 'r', 'd', '\n',
        'm', 'u', 'd', 'g', 'u', 'a', 'r', 'd', 's', '\n',
        'm', 'u', 'd', 'l', 'a', 'r', 'k', 's', '\n',
        'm', 'u', 'd', 's', '\n',
        'm', 'u', 'e', 's', 'l', 'i', '\n',
        'm', 'u', 'f', 'f', '\n',
        'm', 'u', 'f', 'f', 'e', 'd', '\n',
        'm', 'u', 'f', 'f', 'i', 'n', '\n',
        'm', 'u', 'f', 'f', 'i', 'n', 's', '\n',
        'm', 'u', 'f', 'f', 'l', 'e', '\n',
        'm', 'u', 'f', 'f', 'l', 'e', 'd', '\n',
        'm', 'u', 'f', 'f', 'l', 'e', 'r', '\n',
        'm', 'u', 'f', 'f', 'l', 'e', 'r', 's', '\n',
        'm', 'u', 'f', 'f', 'l', 'i', 'n', 'g', '\n',
        'm', 'u', 'f', 'f', 's', '\n',
        'm', 'u', 'f', 't', 'i', '\n',
        'm', 'u', 'g', '\n',
        'm', 'u', 'g', 'g', 'e', 'd', '\n',
        'm', 'u', 'g', 'g', 'e', 'r', '\n',
        'm', 'u', 'g', 'g', 'e', 'r', 's', '\n',
        'm', 'u', 'g', 'g', 'i', 'e', 'r', '\n',
        'm', 'u', 'g', 'g', 'i', 'n', 'g', '\n',
        'm', 'u', 'g', 'g', 'i', 'n', 'g', 's', '\n',
        'm', 'u', 'g', 'g', 'y', '\n',
        'm', 'u', 'g', 's', '\n',
        'm', 'u', 'g', 's', 'h', 'o', 't', 's', '\n',
        'm', 'u', 'l', 'b', 'e', 'r', 'r', 'i', 'e', 's', '\n',
        'm', 'u', 'l', 'b', 'e', 'r', 'r', 'y', '\n',
        'm', 'u', 'l', 'c', 'h', '\n',
        'm', 'u', 'l', 'c', 'h', 'e', 's', '\n',
        'm', 'u', 'l', 'c', 'h', 'i', 'n', 'g', '\n',
        'm', 'u', 'l', 'e', '\n',
        'm', 'u', 'l', 'e', 's', '\n',
        'm', 'u', 'l', 'l', '\n',
        'm', 'u', 'l', 'l', 'a', 'h', '\n',
        'm', 'u', 'l', 'l', 'a', 'h', 's', '\n',
        'm', 'u', 'l', 'l', 'e', 'd', '\n',
        'm', 'u', 'l', 'l', 'e', 't', '\n',
        'm', 'u', 'l', 'l', 'i', 'n', 'g', '\n',
        'm', 'u', 'l', 'l', 'i', 'o', 'n', 'e', 'd', '\n',
        'm', 'u', 'l', 'l', 'i', 'o', 'n', 's', '\n',
        'm', 'u', 'l', 't', 'i', 'c', 'h', 'a', 'n', 'n', 'e', 'l', '\n',
        'm', 'u', 'l', 't', 'i', 'c', 'o', 'l', 'o', 'u', 'r', '\n',
        'm', 'u', 'l', 't', 'i', 'c', 'o', 'l', 'o', 'u', 'r', 'e', 'd', '\n',
        'm', 'u', 'l', 't', 'i', 'c', 'u', 'l', 't', 'u', 'r', 'a', 'l', '\n',
        'm', 'u', 'l', 't', 'i', 'c', 'u', 'l', 't', 'u', 'r', 'a', 'l', 'i', 's', 'm', '\n',
        'm', 'u', 'l', 't', 'i', 'd', 'i', 'm', 'e', 'n', 's', 'i', 'o', 'n', 'a', 'l', '\n',
        'm', 'u', 'l', 't', 'i', 'f', 'a', 'r', 'i', 'o', 'u', 's', '\n',
        'm', 'u', 'l', 't', 'i', 'f', 'o', 'r', 'm', '\n',
        'm', 'u', 'l', 't', 'i', 'f', 'u', 'n', 'c', 't', 'i', 'o', 'n', '\n',
        'm', 'u', 'l', 't', 'i', 'f', 'u', 'n', 'c', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'm', 'u', 'l', 't', 'i', 'l', 'a', 't', 'e', 'r', 'a', 'l', '\n',
        'm', 'u', 'l', 't', 'i', 'l', 'a', 't', 'e', 'r', 'a', 'l', 'i', 's', 'm', '\n',
        'm', 'u', 'l', 't', 'i', 'l', 'a', 'y', 'e', 'r', '\n',
        'm', 'u', 'l', 't', 'i', 'l', 'e', 'v', 'e', 'l', '\n',
        'm', 'u', 'l', 't', 'i', 'l', 'i', 'n', 'g', 'u', 'a', 'l', '\n',
        'm', 'u', 'l', 't', 'i', 'm', 'e', 'd', 'i', 'a', '\n',
        'm', 'u', 'l', 't', 'i', 'm', 'e', 't', 'e', 'r', '\n',
        'm', 'u', 'l', 't', 'i', 'm', 'i', 'l', 'l', 'i', 'o', 'n', '\n',
        'm', 'u', 'l', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'm', 'u', 'l', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 'a', 'l', 's', '\n',
        'm', 'u', 'l', 't', 'i', 'p', 'h', 'a', 's', 'e', '\n',
        'm', 'u', 'l', 't', 'i', 'p', 'l', 'e', '\n',
        'm', 'u', 'l', 't', 'i', 'p', 'l', 'e', 's', '\n',
        'm', 'u', 'l', 't', 'i', 'p', 'l', 'e', 'x', '\n',
        'm', 'u', 'l', 't', 'i', 'p', 'l', 'e', 'x', 'e', 'd', '\n',
        'm', 'u', 'l', 't', 'i', 'p', 'l', 'e', 'x', 'e', 'r', '\n',
        'm', 'u', 'l', 't', 'i', 'p', 'l', 'e', 'x', 'e', 'r', 's', '\n',
        'm', 'u', 'l', 't', 'i', 'p', 'l', 'e', 'x', 'e', 's', '\n',
        'm', 'u', 'l', 't', 'i', 'p', 'l', 'e', 'x', 'i', 'n', 'g', '\n',
        'm', 'u', 'l', 't', 'i', 'p', 'l', 'e', 'x', 'o', 'r', '\n',
        'm', 'u', 'l', 't', 'i', 'p', 'l', 'e', 'x', 'o', 'r', 's', '\n',
        'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'v', 'e', '\n',
        'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'c', 'i', 't', 'i', 'e', 's', '\n',
        'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'c', 'i', 't', 'y', '\n',
        'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'd', '\n',
        'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'r', '\n',
        'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'r', 's', '\n',
        'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 's', '\n',
        'm', 'u', 'l', 't', 'i', 'p', 'l', 'y', '\n',
        'm', 'u', 'l', 't', 'i', 'p', 'l', 'y', 'i', 'n', 'g', '\n',
        'm', 'u', 'l', 't', 'i', 'p', 'r', 'o', 'c', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'm', 'u', 'l', 't', 'i', 'p', 'r', 'o', 'c', 'e', 's', 's', 'o', 'r', '\n',
        'm', 'u', 'l', 't', 'i', 'p', 'r', 'o', 'c', 'e', 's', 's', 'o', 'r', 's', '\n',
        'm', 'u', 'l', 't', 'i', 'p', 'r', 'o', 'g', 'r', 'a', 'm', 'm', 'i', 'n', 'g', '\n',
        'm', 'u', 'l', 't', 'i', 'r', 'a', 'c', 'i', 'a', 'l', '\n',
        'm', 'u', 'l', 't', 'i', 't', 'u', 'd', 'e', '\n',
        'm', 'u', 'l', 't', 'i', 't', 'u', 'd', 'e', 's', '\n',
        'm', 'u', 'm', '\n',
        'm', 'u', 'm', 'b', 'l', 'e', '\n',
        'm', 'u', 'm', 'b', 'l', 'e', 'd', '\n',
        'm', 'u', 'm', 'b', 'l', 'e', 'r', '\n',
        'm', 'u', 'm', 'b', 'l', 'e', 's', '\n',
        'm', 'u', 'm', 'b', 'l', 'i', 'n', 'g', '\n',
        'm', 'u', 'm', 'b', 'l', 'i', 'n', 'g', 's', '\n',
        'm', 'u', 'm', 'b', 'o', 'j', 'u', 'm', 'b', 'o', '\n',
        'm', 'u', 'm', 'm', 'i', 'e', 's', '\n',
        'm', 'u', 'm', 'm', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'u', 'm', 'm', 'i', 'f', 'i', 'e', 'd', '\n',
        'm', 'u', 'm', 'm', 'i', 'f', 'y', '\n',
        'm', 'u', 'm', 'm', 'y', '\n',
        'm', 'u', 'm', 'p', 's', '\n',
        'm', 'u', 'm', 's', '\n',
        'm', 'u', 'n', 'c', 'h', '\n',
        'm', 'u', 'n', 'c', 'h', 'e', 'd', '\n',
        'm', 'u', 'n', 'c', 'h', 'e', 'r', '\n',
        'm', 'u', 'n', 'c', 'h', 'e', 'r', 's', '\n',
        'm', 'u', 'n', 'c', 'h', 'e', 's', '\n',
        'm', 'u', 'n', 'c', 'h', 'i', 'n', 'g', '\n',
        'm', 'u', 'n', 'd', 'a', 'n', 'e', '\n',
        'm', 'u', 'n', 'd', 'a', 'n', 'e', 'l', 'y', '\n',
        'm', 'u', 'n', 'i', 'c', 'h', '\n',
        'm', 'u', 'n', 'i', 'c', 'i', 'p', 'a', 'l', '\n',
        'm', 'u', 'n', 'i', 'c', 'i', 'p', 'a', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'm', 'u', 'n', 'i', 'c', 'i', 'p', 'a', 'l', 'i', 't', 'y', '\n',
        'm', 'u', 'n', 'i', 'f', 'i', 'c', 'e', 'n', 'c', 'e', '\n',
        'm', 'u', 'n', 'i', 'f', 'i', 'c', 'e', 'n', 't', '\n',
        'm', 'u', 'n', 'i', 'f', 'i', 'c', 'e', 'n', 't', 'l', 'y', '\n',
        'm', 'u', 'n', 'i', 't', 'i', 'o', 'n', '\n',
        'm', 'u', 'n', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'm', 'u', 'o', 'n', 's', '\n',
        'm', 'u', 'r', 'a', 'l', '\n',
        'm', 'u', 'r', 'a', 'l', 's', '\n',
        'm', 'u', 'r', 'd', 'e', 'r', '\n',
        'm', 'u', 'r', 'd', 'e', 'r', 'e', 'd', '\n',
        'm', 'u', 'r', 'd', 'e', 'r', 'e', 'r', '\n',
        'm', 'u', 'r', 'd', 'e', 'r', 'e', 'r', 's', '\n',
        'm', 'u', 'r', 'd', 'e', 'r', 'e', 's', 's', '\n',
        'm', 'u', 'r', 'd', 'e', 'r', 'i', 'n', 'g', '\n',
        'm', 'u', 'r', 'd', 'e', 'r', 'o', 'u', 's', '\n',
        'm', 'u', 'r', 'd', 'e', 'r', 'o', 'u', 's', 'l', 'y', '\n',
        'm', 'u', 'r', 'd', 'e', 'r', 's', '\n',
        'm', 'u', 'r', 'k', '\n',
        'm', 'u', 'r', 'k', 'i', 'e', 'r', '\n',
        'm', 'u', 'r', 'k', 'i', 'e', 's', 't', '\n',
        'm', 'u', 'r', 'k', 'i', 'n', 'e', 's', 's', '\n',
        'm', 'u', 'r', 'k', 'y', '\n',
        'm', 'u', 'r', 'm', 'u', 'r', '\n',
        'm', 'u', 'r', 'm', 'u', 'r', 'e', 'd', '\n',
        'm', 'u', 'r', 'm', 'u', 'r', 'e', 'r', '\n',
        'm', 'u', 'r', 'm', 'u', 'r', 'i', 'n', 'g', '\n',
        'm', 'u', 'r', 'm', 'u', 'r', 'i', 'n', 'g', 's', '\n',
        'm', 'u', 'r', 'm', 'u', 'r', 's', '\n',
        'm', 'u', 'r', 'r', 'a', 'y', '\n',
        'm', 'u', 's', 'c', 'a', 'd', 'e', 'l', '\n',
        'm', 'u', 's', 'c', 'a', 't', '\n',
        'm', 'u', 's', 'c', 'l', 'e', '\n',
        'm', 'u', 's', 'c', 'l', 'e', 'd', '\n',
        'm', 'u', 's', 'c', 'l', 'e', 's', '\n',
        'm', 'u', 's', 'c', 'l', 'i', 'n', 'g', '\n',
        'm', 'u', 's', 'c', 'u', 'l', 'a', 'r', '\n',
        'm', 'u', 's', 'c', 'u', 'l', 'a', 'r', 'i', 't', 'y', '\n',
        'm', 'u', 's', 'c', 'u', 'l', 'a', 't', 'u', 'r', 'e', '\n',
        'm', 'u', 's', 'c', 'u', 'l', 'o', 's', 'k', 'e', 'l', 'e', 't', 'a', 'l', '\n',
        'm', 'u', 's', 'e', '\n',
        'm', 'u', 's', 'e', 'd', '\n',
        'm', 'u', 's', 'e', 's', '\n',
        'm', 'u', 's', 'e', 'u', 'm', '\n',
        'm', 'u', 's', 'e', 'u', 'm', 's', '\n',
        'm', 'u', 's', 'h', '\n',
        'm', 'u', 's', 'h', 'e', 's', '\n',
        'm', 'u', 's', 'h', 'r', 'o', 'o', 'm', '\n',
        'm', 'u', 's', 'h', 'r', 'o', 'o', 'm', 'e', 'd', '\n',
        'm', 'u', 's', 'h', 'r', 'o', 'o', 'm', 'i', 'n', 'g', '\n',
        'm', 'u', 's', 'h', 'r', 'o', 'o', 'm', 's', '\n',
        'm', 'u', 's', 'h', 'y', '\n',
        'm', 'u', 's', 'i', 'c', '\n',
        'm', 'u', 's', 'i', 'c', 'a', 'l', '\n',
        'm', 'u', 's', 'i', 'c', 'a', 'l', 'i', 't', 'y', '\n',
        'm', 'u', 's', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'm', 'u', 's', 'i', 'c', 'a', 'l', 's', '\n',
        'm', 'u', 's', 'i', 'c', 'i', 'a', 'n', '\n',
        'm', 'u', 's', 'i', 'c', 'i', 'a', 'n', 's', '\n',
        'm', 'u', 's', 'i', 'c', 'i', 'a', 'n', 's', 'h', 'i', 'p', '\n',
        'm', 'u', 's', 'i', 'c', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'm', 'u', 's', 'i', 'c', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'm', 'u', 's', 'i', 'c', 'o', 'l', 'o', 'g', 'y', '\n',
        'm', 'u', 's', 'i', 'n', 'g', '\n',
        'm', 'u', 's', 'i', 'n', 'g', 'l', 'y', '\n',
        'm', 'u', 's', 'i', 'n', 'g', 's', '\n',
        'm', 'u', 's', 'k', '\n',
        'm', 'u', 's', 'k', 'e', 't', '\n',
        'm', 'u', 's', 'k', 'e', 't', 'e', 'e', 'r', '\n',
        'm', 'u', 's', 'k', 'e', 't', 'e', 'e', 'r', 's', '\n',
        'm', 'u', 's', 'k', 'e', 't', 's', '\n',
        'm', 'u', 's', 'k', 'i', 'e', 'r', '\n',
        'm', 'u', 's', 'k', 'i', 'e', 's', 't', '\n',
        'm', 'u', 's', 'k', 's', '\n',
        'm', 'u', 's', 'k', 'y', '\n',
        'm', 'u', 's', 'l', 'i', 'm', '\n',
        'm', 'u', 's', 'l', 'i', 'm', 's', '\n',
        'm', 'u', 's', 'l', 'i', 'n', '\n',
        'm', 'u', 's', 's', 'e', 'l', '\n',
        'm', 'u', 's', 's', 'e', 'l', 's', '\n',
        'm', 'u', 's', 't', '\n',
        'm', 'u', 's', 't', 'a', 'c', 'h', 'e', '\n',
        'm', 'u', 's', 't', 'a', 'n', 'g', '\n',
        'm', 'u', 's', 't', 'a', 'n', 'g', 's', '\n',
        'm', 'u', 's', 't', 'a', 'r', 'd', '\n',
        'm', 'u', 's', 't', 'e', 'r', '\n',
        'm', 'u', 's', 't', 'e', 'r', 'e', 'd', '\n',
        'm', 'u', 's', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'm', 'u', 's', 't', 'e', 'r', 's', '\n',
        'm', 'u', 's', 't', 'i', 'e', 'r', '\n',
        'm', 'u', 's', 't', 'i', 'e', 's', 't', '\n',
        'm', 'u', 's', 't', 'i', 'l', 'y', '\n',
        'm', 'u', 's', 't', 'i', 'n', 'e', 's', 's', '\n',
        'm', 'u', 's', 't', 's', '\n',
        'm', 'u', 's', 't', 'y', '\n',
        'm', 'u', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'm', 'u', 't', 'a', 'b', 'l', 'e', '\n',
        'm', 'u', 't', 'a', 'g', 'e', 'n', 's', '\n',
        'm', 'u', 't', 'a', 'n', 't', '\n',
        'm', 'u', 't', 'a', 'n', 't', 's', '\n',
        'm', 'u', 't', 'a', 't', 'e', '\n',
        'm', 'u', 't', 'a', 't', 'e', 'd', '\n',
        'm', 'u', 't', 'a', 't', 'e', 's', '\n',
        'm', 'u', 't', 'a', 't', 'i', 'n', 'g', '\n',
        'm', 'u', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'u', 't', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'm', 'u', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'm', 'u', 't', 'e', '\n',
        'm', 'u', 't', 'e', 'd', '\n',
        'm', 'u', 't', 'e', 'l', 'y', '\n',
        'm', 'u', 't', 'e', 'n', 'e', 's', 's', '\n',
        'm', 'u', 't', 'e', 's', '\n',
        'm', 'u', 't', 'i', 'l', 'a', 't', 'e', '\n',
        'm', 'u', 't', 'i', 'l', 'a', 't', 'e', 'd', '\n',
        'm', 'u', 't', 'i', 'l', 'a', 't', 'e', 's', '\n',
        'm', 'u', 't', 'i', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'm', 'u', 't', 'i', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'u', 't', 'i', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'm', 'u', 't', 'i', 'n', 'e', 'e', 'r', '\n',
        'm', 'u', 't', 'i', 'n', 'e', 'e', 'r', 's', '\n',
        'm', 'u', 't', 'i', 'n', 'g', '\n',
        'm', 'u', 't', 'i', 'n', 'i', 'e', 'd', '\n',
        'm', 'u', 't', 'i', 'n', 'i', 'e', 's', '\n',
        'm', 'u', 't', 'i', 'n', 'o', 'u', 's', '\n',
        'm', 'u', 't', 'i', 'n', 'o', 'u', 's', 'l', 'y', '\n',
        'm', 'u', 't', 'i', 'n', 'y', '\n',
        'm', 'u', 't', 't', '\n',
        'm', 'u', 't', 't', 'e', 'r', '\n',
        'm', 'u', 't', 't', 'e', 'r', 'e', 'd', '\n',
        'm', 'u', 't', 't', 'e', 'r', 'e', 'r', '\n',
        'm', 'u', 't', 't', 'e', 'r', 'e', 'r', 's', '\n',
        'm', 'u', 't', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'm', 'u', 't', 't', 'e', 'r', 'i', 'n', 'g', 's', '\n',
        'm', 'u', 't', 't', 'e', 'r', 's', '\n',
        'm', 'u', 't', 't', 'o', 'n', '\n',
        'm', 'u', 't', 't', 'o', 'n', 's', '\n',
        'm', 'u', 't', 't', 's', '\n',
        'm', 'u', 't', 'u', 'a', 'l', '\n',
        'm', 'u', 't', 'u', 'a', 'l', 'i', 't', 'y', '\n',
        'm', 'u', 't', 'u', 'a', 'l', 'l', 'y', '\n',
        'm', 'u', 'z', 'a', 'k', '\n',
        'm', 'u', 'z', 'z', 'l', 'e', '\n',
        'm', 'u', 'z', 'z', 'l', 'e', 'd', '\n',
        'm', 'u', 'z', 'z', 'l', 'e', 's', '\n',
        'm', 'u', 'z', 'z', 'l', 'i', 'n', 'g', '\n',
        'm', 'y', '\n',
        'm', 'y', 'a', 'l', 'g', 'i', 'c', '\n',
        'm', 'y', 'e', 'l', 'i', 'n', '\n',
        'm', 'y', 'n', 'a', '\n',
        'm', 'y', 'n', 'a', 'h', 's', '\n',
        'm', 'y', 'o', 'c', 'a', 'r', 'd', 'i', 'a', 'l', '\n',
        'm', 'y', 'o', 'p', 'e', '\n',
        'm', 'y', 'o', 'p', 'i', 'a', '\n',
        'm', 'y', 'o', 'p', 'i', 'c', '\n',
        'm', 'y', 'o', 'p', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'm', 'y', 'r', 'i', 'a', 'd', '\n',
        'm', 'y', 'r', 'i', 'a', 'd', 's', '\n',
        'm', 'y', 'r', 'r', 'h', '\n',
        'm', 'y', 's', 'e', 'l', 'f', '\n',
        'm', 'y', 's', 't', 'e', 'r', 'i', 'e', 's', '\n',
        'm', 'y', 's', 't', 'e', 'r', 'i', 'o', 'u', 's', '\n',
        'm', 'y', 's', 't', 'e', 'r', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'm', 'y', 's', 't', 'e', 'r', 'y', '\n',
        'm', 'y', 's', 't', 'i', 'c', '\n',
        'm', 'y', 's', 't', 'i', 'c', 'a', 'l', '\n',
        'm', 'y', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'm', 'y', 's', 't', 'i', 'c', 'i', 's', 'm', '\n',
        'm', 'y', 's', 't', 'i', 'c', 's', '\n',
        'm', 'y', 's', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'm', 'y', 's', 't', 'i', 'f', 'i', 'e', 'd', '\n',
        'm', 'y', 's', 't', 'i', 'f', 'i', 'e', 's', '\n',
        'm', 'y', 's', 't', 'i', 'f', 'y', '\n',
        'm', 'y', 's', 't', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'm', 'y', 's', 't', 'i', 'q', 'u', 'e', '\n',
        'm', 'y', 't', 'h', '\n',
        'm', 'y', 't', 'h', 'i', 'c', '\n',
        'm', 'y', 't', 'h', 'i', 'c', 'a', 'l', '\n',
        'm', 'y', 't', 'h', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'm', 'y', 't', 'h', 'o', 'l', 'o', 'g', 'i', 'e', 's', '\n',
        'm', 'y', 't', 'h', 'o', 'l', 'o', 'g', 'i', 's', 'e', 'd', '\n',
        'm', 'y', 't', 'h', 'o', 'l', 'o', 'g', 'y', '\n',
        'm', 'y', 't', 'h', 's', '\n',
        'm', 'y', 'x', 'o', 'm', 'a', 't', 'o', 's', 'i', 's', '\n',
        'n', 'a', 'b', '\n',
        'n', 'a', 'b', 'b', 'e', 'd', '\n',
        'n', 'a', 'b', 's', '\n',
        'n', 'a', 'd', 'i', 'r', '\n',
        'n', 'a', 'g', '\n',
        'n', 'a', 'g', 'a', 's', 'a', 'k', 'i', '\n',
        'n', 'a', 'g', 'g', 'e', 'd', '\n',
        'n', 'a', 'g', 'g', 'e', 'r', '\n',
        'n', 'a', 'g', 'g', 'i', 'n', 'g', '\n',
        'n', 'a', 'g', 's', '\n',
        'n', 'a', 'i', 'a', 'd', '\n',
        'n', 'a', 'i', 'a', 'd', 's', '\n',
        'n', 'a', 'i', 'l', '\n',
        'n', 'a', 'i', 'l', 'b', 'i', 't', 'i', 'n', 'g', '\n',
        'n', 'a', 'i', 'l', 'e', 'd', '\n',
        'n', 'a', 'i', 'l', 'i', 'n', 'g', '\n',
        'n', 'a', 'i', 'l', 's', '\n',
        'n', 'a', 'i', 'r', 'o', 'b', 'i', '\n',
        'n', 'a', 'i', 'v', 'e', '\n',
        'n', 'a', 'i', 'v', 'e', 'l', 'y', '\n',
        'n', 'a', 'i', 'v', 'e', 't', 'e', '\n',
        'n', 'a', 'i', 'v', 'e', 't', 'y', '\n',
        'n', 'a', 'k', 'e', 'd', '\n',
        'n', 'a', 'k', 'e', 'd', 'l', 'y', '\n',
        'n', 'a', 'k', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'n', 'a', 'm', 'e', '\n',
        'n', 'a', 'm', 'e', 'a', 'b', 'l', 'e', '\n',
        'n', 'a', 'm', 'e', 'c', 'a', 'l', 'l', 'i', 'n', 'g', '\n',
        'n', 'a', 'm', 'e', 'd', '\n',
        'n', 'a', 'm', 'e', 'd', 'r', 'o', 'p', 'p', 'i', 'n', 'g', '\n',
        'n', 'a', 'm', 'e', 'l', 'e', 's', 's', '\n',
        'n', 'a', 'm', 'e', 'l', 'y', '\n',
        'n', 'a', 'm', 'e', 'p', 'l', 'a', 't', 'e', '\n',
        'n', 'a', 'm', 'e', 'p', 'l', 'a', 't', 'e', 's', '\n',
        'n', 'a', 'm', 'e', 's', '\n',
        'n', 'a', 'm', 'e', 's', 'a', 'k', 'e', '\n',
        'n', 'a', 'm', 'e', 's', 'a', 'k', 'e', 's', '\n',
        'n', 'a', 'm', 'i', 'b', 'i', 'a', '\n',
        'n', 'a', 'm', 'i', 'b', 'i', 'a', 'n', '\n',
        'n', 'a', 'm', 'i', 'n', 'g', '\n',
        'n', 'a', 'm', 'i', 'n', 'g', 's', '\n',
        'n', 'a', 'n', 'n', 'i', 'e', 's', '\n',
        'n', 'a', 'n', 'n', 'y', '\n',
        'n', 'a', 'n', 'o', 'm', 'e', 't', 'r', 'e', '\n',
        'n', 'a', 'n', 'o', 'm', 'e', 't', 'r', 'e', 's', '\n',
        'n', 'a', 'n', 'o', 's', 'e', 'c', 'o', 'n', 'd', '\n',
        'n', 'a', 'n', 'o', 's', 'e', 'c', 'o', 'n', 'd', 's', '\n',
        'n', 'a', 'n', 'o', 't', 'e', 'c', 'h', 'n', 'o', 'l', 'o', 'g', 'y', '\n',
        'n', 'a', 'o', 'm', 'i', '\n',
        'n', 'a', 'p', '\n',
        'n', 'a', 'p', 'a', 'l', 'm', '\n',
        'n', 'a', 'p', 'e', '\n',
        'n', 'a', 'p', 'h', 't', 'h', 'a', '\n',
        'n', 'a', 'p', 'k', 'i', 'n', '\n',
        'n', 'a', 'p', 'k', 'i', 'n', 's', '\n',
        'n', 'a', 'p', 'l', 'e', 's', '\n',
        'n', 'a', 'p', 'o', 'l', 'e', 'o', 'n', '\n',
        'n', 'a', 'p', 'p', 'e', 'd', '\n',
        'n', 'a', 'p', 'p', 'i', 'e', 's', '\n',
        'n', 'a', 'p', 'p', 'i', 'n', 'g', '\n',
        'n', 'a', 'p', 'p', 'y', '\n',
        'n', 'a', 'p', 's', '\n',
        'n', 'a', 'r', 'c', 'i', 's', 's', 'i', 's', 'm', '\n',
        'n', 'a', 'r', 'c', 'i', 's', 's', 'i', 's', 't', 'i', 'c', '\n',
        'n', 'a', 'r', 'c', 'o', 'l', 'e', 'p', 't', 'i', 'c', '\n',
        'n', 'a', 'r', 'c', 'o', 's', 'i', 's', '\n',
        'n', 'a', 'r', 'c', 'o', 't', 'i', 'c', '\n',
        'n', 'a', 'r', 'c', 'o', 't', 'i', 'c', 's', '\n',
        'n', 'a', 'r', 'r', 'a', 't', 'e', '\n',
        'n', 'a', 'r', 'r', 'a', 't', 'e', 'd', '\n',
        'n', 'a', 'r', 'r', 'a', 't', 'e', 's', '\n',
        'n', 'a', 'r', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'n', 'a', 'r', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'n', 'a', 'r', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'n', 'a', 'r', 'r', 'a', 't', 'i', 'v', 'e', '\n',
        'n', 'a', 'r', 'r', 'a', 't', 'i', 'v', 'e', 's', '\n',
        'n', 'a', 'r', 'r', 'a', 't', 'o', 'l', 'o', 'g', 'y', '\n',
        'n', 'a', 'r', 'r', 'a', 't', 'o', 'r', '\n',
        'n', 'a', 'r', 'r', 'a', 't', 'o', 'r', 's', '\n',
        'n', 'a', 'r', 'r', 'o', 'w', '\n',
        'n', 'a', 'r', 'r', 'o', 'w', 'e', 'd', '\n',
        'n', 'a', 'r', 'r', 'o', 'w', 'e', 'r', '\n',
        'n', 'a', 'r', 'r', 'o', 'w', 'e', 's', 't', '\n',
        'n', 'a', 'r', 'r', 'o', 'w', 'i', 'n', 'g', '\n',
        'n', 'a', 'r', 'r', 'o', 'w', 'l', 'y', '\n',
        'n', 'a', 'r', 'r', 'o', 'w', 'm', 'i', 'n', 'd', 'e', 'd', '\n',
        'n', 'a', 'r', 'r', 'o', 'w', 'm', 'i', 'n', 'd', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'n', 'a', 'r', 'r', 'o', 'w', 'n', 'e', 's', 's', '\n',
        'n', 'a', 'r', 'r', 'o', 'w', 's', '\n',
        'n', 'a', 'r', 'w', 'h', 'a', 'l', '\n',
        'n', 'a', 's', 'a', 'l', '\n',
        'n', 'a', 's', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'n', 'a', 's', 'a', 'l', 'l', 'y', '\n',
        'n', 'a', 's', 'c', 'e', 'n', 't', '\n',
        'n', 'a', 's', 't', 'i', 'e', 'r', '\n',
        'n', 'a', 's', 't', 'i', 'e', 's', 't', '\n',
        'n', 'a', 's', 't', 'i', 'l', 'y', '\n',
        'n', 'a', 's', 't', 'i', 'n', 'e', 's', 's', '\n',
        'n', 'a', 's', 't', 'u', 'r', 't', 'i', 'u', 'm', '\n',
        'n', 'a', 's', 't', 'u', 'r', 't', 'i', 'u', 'm', 's', '\n',
        'n', 'a', 's', 't', 'y', '\n',
        'n', 'a', 't', 'a', 'l', '\n',
        'n', 'a', 't', 'i', 'o', 'n', '\n',
        'n', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'n', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'n', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'n', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 'e', '\n',
        'n', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'n', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'n', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 'm', '\n',
        'n', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 't', '\n',
        'n', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 't', 'i', 'c', '\n',
        'n', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 't', 's', '\n',
        'n', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'n', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 't', 'y', '\n',
        'n', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'n', 'a', 't', 'i', 'o', 'n', 'a', 'l', 's', '\n',
        'n', 'a', 't', 'i', 'o', 'n', 'h', 'o', 'o', 'd', '\n',
        'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'n', 'a', 't', 'i', 'o', 'n', 'w', 'i', 'd', 'e', '\n',
        'n', 'a', 't', 'i', 'v', 'e', '\n',
        'n', 'a', 't', 'i', 'v', 'e', 's', '\n',
        'n', 'a', 't', 'i', 'v', 'i', 't', 'y', '\n',
        'n', 'a', 't', 'o', '\n',
        'n', 'a', 't', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'n', 'a', 't', 'u', 'r', 'a', 'l', '\n',
        'n', 'a', 't', 'u', 'r', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'n', 'a', 't', 'u', 'r', 'a', 'l', 'i', 's', 'e', '\n',
        'n', 'a', 't', 'u', 'r', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'n', 'a', 't', 'u', 'r', 'a', 'l', 'i', 's', 'm', '\n',
        'n', 'a', 't', 'u', 'r', 'a', 'l', 'i', 's', 't', '\n',
        'n', 'a', 't', 'u', 'r', 'a', 'l', 'i', 's', 't', 'i', 'c', '\n',
        'n', 'a', 't', 'u', 'r', 'a', 'l', 'i', 's', 't', 's', '\n',
        'n', 'a', 't', 'u', 'r', 'a', 'l', 'l', 'y', '\n',
        'n', 'a', 't', 'u', 'r', 'a', 'l', 'n', 'e', 's', 's', '\n',
        'n', 'a', 't', 'u', 'r', 'e', '\n',
        'n', 'a', 't', 'u', 'r', 'e', 's', '\n',
        'n', 'a', 't', 'u', 'r', 'i', 's', 't', '\n',
        'n', 'a', 't', 'u', 'r', 'i', 's', 't', 's', '\n',
        'n', 'a', 'u', 'g', 'h', 't', '\n',
        'n', 'a', 'u', 'g', 'h', 't', 'i', 'e', 's', 't', '\n',
        'n', 'a', 'u', 'g', 'h', 't', 'i', 'l', 'y', '\n',
        'n', 'a', 'u', 'g', 'h', 't', 'i', 'n', 'e', 's', 's', '\n',
        'n', 'a', 'u', 'g', 'h', 't', 's', '\n',
        'n', 'a', 'u', 'g', 'h', 't', 'y', '\n',
        'n', 'a', 'u', 's', 'e', 'a', '\n',
        'n', 'a', 'u', 's', 'e', 'a', 't', 'e', '\n',
        'n', 'a', 'u', 's', 'e', 'a', 't', 'e', 'd', '\n',
        'n', 'a', 'u', 's', 'e', 'a', 't', 'e', 's', '\n',
        'n', 'a', 'u', 's', 'e', 'a', 't', 'i', 'n', 'g', '\n',
        'n', 'a', 'u', 's', 'e', 'a', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'n', 'a', 'u', 's', 'e', 'o', 'u', 's', '\n',
        'n', 'a', 'u', 's', 'e', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'n', 'a', 'u', 't', 'i', 'c', 'a', 'l', '\n',
        'n', 'a', 'u', 't', 'i', 'l', 'i', '\n',
        'n', 'a', 'u', 't', 'i', 'l', 'u', 's', '\n',
        'n', 'a', 'v', 'a', 'l', '\n',
        'n', 'a', 'v', 'e', '\n',
        'n', 'a', 'v', 'e', 'l', '\n',
        'n', 'a', 'v', 'e', 'l', 's', '\n',
        'n', 'a', 'v', 'i', 'e', 's', '\n',
        'n', 'a', 'v', 'i', 'g', 'a', 'b', 'l', 'e', '\n',
        'n', 'a', 'v', 'i', 'g', 'a', 't', 'e', '\n',
        'n', 'a', 'v', 'i', 'g', 'a', 't', 'e', 'd', '\n',
        'n', 'a', 'v', 'i', 'g', 'a', 't', 'i', 'n', 'g', '\n',
        'n', 'a', 'v', 'i', 'g', 'a', 't', 'i', 'o', 'n', '\n',
        'n', 'a', 'v', 'i', 'g', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'n', 'a', 'v', 'i', 'g', 'a', 't', 'o', 'r', '\n',
        'n', 'a', 'v', 'i', 'g', 'a', 't', 'o', 'r', 's', '\n',
        'n', 'a', 'v', 'v', 'i', 'e', 's', '\n',
        'n', 'a', 'v', 'v', 'y', '\n',
        'n', 'a', 'v', 'y', '\n',
        'n', 'a', 'y', '\n',
        'n', 'a', 'z', 'i', '\n',
        'n', 'a', 'z', 'i', 'i', 's', 'm', '\n',
        'n', 'a', 'z', 'i', 's', '\n',
        'n', 'a', 'z', 'i', 's', 'm', '\n',
        'n', 'd', 'e', 'b', 'e', 'l', 'e', '\n',
        'n', 'e', '\n',
        'n', 'e', 'a', 'r', '\n',
        'n', 'e', 'a', 'r', 'b', 'y', '\n',
        'n', 'e', 'a', 'r', 'e', 'd', '\n',
        'n', 'e', 'a', 'r', 'e', 'r', '\n',
        'n', 'e', 'a', 'r', 'e', 's', 't', '\n',
        'n', 'e', 'a', 'r', 'i', 'n', 'g', '\n',
        'n', 'e', 'a', 'r', 'l', 'y', '\n',
        'n', 'e', 'a', 'r', 'n', 'e', 's', 's', '\n',
        'n', 'e', 'a', 'r', 's', '\n',
        'n', 'e', 'a', 'r', 's', 'i', 'd', 'e', '\n',
        'n', 'e', 'a', 'r', 's', 'i', 'g', 'h', 't', 'e', 'd', '\n',
        'n', 'e', 'a', 't', '\n',
        'n', 'e', 'a', 't', 'e', 'n', '\n',
        'n', 'e', 'a', 't', 'e', 'n', 'i', 'n', 'g', '\n',
        'n', 'e', 'a', 't', 'e', 'n', 's', '\n',
        'n', 'e', 'a', 't', 'e', 'r', '\n',
        'n', 'e', 'a', 't', 'e', 's', 't', '\n',
        'n', 'e', 'a', 't', 'l', 'y', '\n',
        'n', 'e', 'a', 't', 'n', 'e', 's', 's', '\n',
        'n', 'e', 'b', 'u', 'l', 'a', '\n',
        'n', 'e', 'b', 'u', 'l', 'a', 'e', '\n',
        'n', 'e', 'b', 'u', 'l', 'a', 'r', '\n',
        'n', 'e', 'b', 'u', 'l', 'a', 's', '\n',
        'n', 'e', 'b', 'u', 'l', 'o', 's', 'i', 't', 'y', '\n',
        'n', 'e', 'b', 'u', 'l', 'o', 'u', 's', '\n',
        'n', 'e', 'b', 'u', 'l', 'o', 'u', 's', 'l', 'y', '\n',
        'n', 'e', 'b', 'u', 'l', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'n', 'e', 'c', 'e', 's', 's', 'a', 'r', 'i', 'e', 's', '\n',
        'n', 'e', 'c', 'e', 's', 's', 'a', 'r', 'i', 'l', 'y', '\n',
        'n', 'e', 'c', 'e', 's', 's', 'a', 'r', 'y', '\n',
        'n', 'e', 'c', 'e', 's', 's', 'i', 't', 'a', 't', 'e', '\n',
        'n', 'e', 'c', 'e', 's', 's', 'i', 't', 'a', 't', 'e', 'd', '\n',
        'n', 'e', 'c', 'e', 's', 's', 'i', 't', 'a', 't', 'e', 's', '\n',
        'n', 'e', 'c', 'e', 's', 's', 'i', 't', 'a', 't', 'i', 'n', 'g', '\n',
        'n', 'e', 'c', 'e', 's', 's', 'i', 't', 'i', 'e', 's', '\n',
        'n', 'e', 'c', 'e', 's', 's', 'i', 't', 'y', '\n',
        'n', 'e', 'c', 'k', '\n',
        'n', 'e', 'c', 'k', 'b', 'a', 'n', 'd', '\n',
        'n', 'e', 'c', 'k', 'e', 'd', '\n',
        'n', 'e', 'c', 'k', 'i', 'n', 'g', '\n',
        'n', 'e', 'c', 'k', 'l', 'a', 'c', 'e', '\n',
        'n', 'e', 'c', 'k', 'l', 'a', 'c', 'e', 's', '\n',
        'n', 'e', 'c', 'k', 'l', 'i', 'n', 'e', '\n',
        'n', 'e', 'c', 'k', 'l', 'i', 'n', 'e', 's', '\n',
        'n', 'e', 'c', 'k', 's', '\n',
        'n', 'e', 'c', 'k', 't', 'i', 'e', '\n',
        'n', 'e', 'c', 'r', 'o', 'm', 'a', 'n', 'c', 'e', 'r', '\n',
        'n', 'e', 'c', 'r', 'o', 'm', 'a', 'n', 'c', 'e', 'r', 's', '\n',
        'n', 'e', 'c', 'r', 'o', 'm', 'a', 'n', 'c', 'y', '\n',
        'n', 'e', 'c', 'r', 'o', 'm', 'a', 'n', 't', 'i', 'c', '\n',
        'n', 'e', 'c', 'r', 'o', 'p', 'h', 'i', 'l', 'i', 'a', '\n',
        'n', 'e', 'c', 'r', 'o', 'p', 'h', 'i', 'l', 'i', 'a', 'c', '\n',
        'n', 'e', 'c', 'r', 'o', 'p', 'h', 'i', 'l', 'i', 'a', 'c', 's', '\n',
        'n', 'e', 'c', 'r', 'o', 'p', 'o', 'l', 'i', 's', '\n',
        'n', 'e', 'c', 'r', 'o', 'p', 's', 'y', '\n',
        'n', 'e', 'c', 'r', 'o', 's', 'i', 's', '\n',
        'n', 'e', 'c', 'r', 'o', 't', 'i', 'c', '\n',
        'n', 'e', 'c', 't', 'a', 'r', '\n',
        'n', 'e', 'c', 't', 'a', 'r', 'i', 'n', 'e', 's', '\n',
        'n', 'e', 'c', 't', 'a', 'r', 's', '\n',
        'n', 'e', 'e', '\n',
        'n', 'e', 'e', 'd', '\n',
        'n', 'e', 'e', 'd', 'e', 'd', '\n',
        'n', 'e', 'e', 'd', 'f', 'u', 'l', '\n',
        'n', 'e', 'e', 'd', 'i', 'e', 'r', '\n',
        'n', 'e', 'e', 'd', 'i', 'e', 's', 't', '\n',
        'n', 'e', 'e', 'd', 'i', 'n', 'e', 's', 's', '\n',
        'n', 'e', 'e', 'd', 'i', 'n', 'g', '\n',
        'n', 'e', 'e', 'd', 'l', 'e', '\n',
        'n', 'e', 'e', 'd', 'l', 'e', 'c', 'r', 'a', 'f', 't', '\n',
        'n', 'e', 'e', 'd', 'l', 'e', 'd', '\n',
        'n', 'e', 'e', 'd', 'l', 'e', 's', '\n',
        'n', 'e', 'e', 'd', 'l', 'e', 's', 's', '\n',
        'n', 'e', 'e', 'd', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'n', 'e', 'e', 'd', 'l', 'e', 'w', 'o', 'r', 'k', '\n',
        'n', 'e', 'e', 'd', 'l', 'i', 'n', 'g', '\n',
        'n', 'e', 'e', 'd', 's', '\n',
        'n', 'e', 'e', 'd', 'y', '\n',
        'n', 'e', 'g', 'a', 't', 'e', '\n',
        'n', 'e', 'g', 'a', 't', 'e', 'd', '\n',
        'n', 'e', 'g', 'a', 't', 'e', 's', '\n',
        'n', 'e', 'g', 'a', 't', 'i', 'n', 'g', '\n',
        'n', 'e', 'g', 'a', 't', 'i', 'o', 'n', '\n',
        'n', 'e', 'g', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'n', 'e', 'g', 'a', 't', 'i', 'v', 'e', '\n',
        'n', 'e', 'g', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'n', 'e', 'g', 'a', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'n', 'e', 'g', 'a', 't', 'i', 'v', 'e', 's', '\n',
        'n', 'e', 'g', 'a', 't', 'i', 'v', 'i', 's', 'm', '\n',
        'n', 'e', 'g', 'a', 't', 'i', 'v', 'i', 't', 'y', '\n',
        'n', 'e', 'g', 'e', 'v', '\n',
        'n', 'e', 'g', 'l', 'e', 'c', 't', '\n',
        'n', 'e', 'g', 'l', 'e', 'c', 't', 'e', 'd', '\n',
        'n', 'e', 'g', 'l', 'e', 'c', 't', 'f', 'u', 'l', '\n',
        'n', 'e', 'g', 'l', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'n', 'e', 'g', 'l', 'e', 'c', 't', 's', '\n',
        'n', 'e', 'g', 'l', 'i', 'g', 'e', 'e', '\n',
        'n', 'e', 'g', 'l', 'i', 'g', 'e', 'e', 's', '\n',
        'n', 'e', 'g', 'l', 'i', 'g', 'e', 'n', 'c', 'e', '\n',
        'n', 'e', 'g', 'l', 'i', 'g', 'e', 'n', 't', '\n',
        'n', 'e', 'g', 'l', 'i', 'g', 'e', 'n', 't', 'l', 'y', '\n',
        'n', 'e', 'g', 'l', 'i', 'g', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'n', 'e', 'g', 'l', 'i', 'g', 'i', 'b', 'l', 'e', '\n',
        'n', 'e', 'g', 'l', 'i', 'g', 'i', 'b', 'l', 'y', '\n',
        'n', 'e', 'g', 'o', 't', 'i', 'a', 'b', 'l', 'e', '\n',
        'n', 'e', 'g', 'o', 't', 'i', 'a', 't', 'e', '\n',
        'n', 'e', 'g', 'o', 't', 'i', 'a', 't', 'e', 'd', '\n',
        'n', 'e', 'g', 'o', 't', 'i', 'a', 't', 'e', 's', '\n',
        'n', 'e', 'g', 'o', 't', 'i', 'a', 't', 'i', 'n', 'g', '\n',
        'n', 'e', 'g', 'o', 't', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'n', 'e', 'g', 'o', 't', 'i', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'n', 'e', 'g', 'o', 't', 'i', 'a', 't', 'o', 'r', '\n',
        'n', 'e', 'g', 'o', 't', 'i', 'a', 't', 'o', 'r', 's', '\n',
        'n', 'e', 'g', 'r', 'o', 'i', 'd', '\n',
        'n', 'e', 'i', 'g', 'h', '\n',
        'n', 'e', 'i', 'g', 'h', 'b', 'o', 'u', 'r', '\n',
        'n', 'e', 'i', 'g', 'h', 'b', 'o', 'u', 'r', 'h', 'o', 'o', 'd', '\n',
        'n', 'e', 'i', 'g', 'h', 'b', 'o', 'u', 'r', 'h', 'o', 'o', 'd', 's', '\n',
        'n', 'e', 'i', 'g', 'h', 'b', 'o', 'u', 'r', 'i', 'n', 'g', '\n',
        'n', 'e', 'i', 'g', 'h', 'b', 'o', 'u', 'r', 'l', 'i', 'n', 'e', 's', 's', '\n',
        'n', 'e', 'i', 'g', 'h', 'b', 'o', 'u', 'r', 'l', 'y', '\n',
        'n', 'e', 'i', 'g', 'h', 'b', 'o', 'u', 'r', 's', '\n',
        'n', 'e', 'i', 'g', 'h', 'e', 'd', '\n',
        'n', 'e', 'i', 'g', 'h', 'i', 'n', 'g', '\n',
        'n', 'e', 'i', 't', 'h', 'e', 'r', '\n',
        'n', 'e', 'm', 'a', 't', 'o', 'd', 'e', '\n',
        'n', 'e', 'm', 'a', 't', 'o', 'd', 'e', 's', '\n',
        'n', 'e', 'm', 'e', 's', 'i', 's', '\n',
        'n', 'e', 'o', 'l', 'i', 't', 'h', 'i', 'c', '\n',
        'n', 'e', 'o', 'l', 'o', 'g', 'i', 's', 'm', '\n',
        'n', 'e', 'o', 'l', 'o', 'g', 'i', 's', 'm', 's', '\n',
        'n', 'e', 'o', 'n', '\n',
        'n', 'e', 'o', 'n', 'a', 't', 'a', 'l', '\n',
        'n', 'e', 'o', 'n', 'a', 't', 'e', '\n',
        'n', 'e', 'o', 'n', 'a', 't', 'e', 's', '\n',
        'n', 'e', 'o', 'p', 'h', 'y', 't', 'e', '\n',
        'n', 'e', 'o', 'p', 'h', 'y', 't', 'e', 's', '\n',
        'n', 'e', 'o', 'p', 'l', 'a', 's', 'm', '\n',
        'n', 'e', 'o', 'p', 'l', 'a', 's', 'm', 's', '\n',
        'n', 'e', 'o', 'p', 'r', 'e', 'n', 'e', '\n',
        'n', 'e', 'p', 'a', 'l', '\n',
        'n', 'e', 'p', 'h', 'e', 'w', '\n',
        'n', 'e', 'p', 'h', 'e', 'w', 's', '\n',
        'n', 'e', 'p', 'h', 'r', 'i', 't', 'i', 's', '\n',
        'n', 'e', 'p', 'o', 't', 'i', 's', 'm', '\n',
        'n', 'e', 'p', 't', 'u', 'n', 'e', '\n',
        'n', 'e', 'p', 't', 'u', 'n', 'i', 'u', 'm', '\n',
        'n', 'e', 'r', 'd', '\n',
        'n', 'e', 'r', 'd', 's', '\n',
        'n', 'e', 'r', 'v', 'e', '\n',
        'n', 'e', 'r', 'v', 'e', 'l', 'e', 's', 's', '\n',
        'n', 'e', 'r', 'v', 'e', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'n', 'e', 'r', 'v', 'e', 's', '\n',
        'n', 'e', 'r', 'v', 'o', 'u', 's', '\n',
        'n', 'e', 'r', 'v', 'o', 'u', 's', 'l', 'y', '\n',
        'n', 'e', 'r', 'v', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'n', 'e', 'r', 'v', 'y', '\n',
        'n', 'e', 's', 't', '\n',
        'n', 'e', 's', 't', 'a', 'b', 'l', 'e', '\n',
        'n', 'e', 's', 't', 'e', 'd', '\n',
        'n', 'e', 's', 't', 'e', 'g', 'g', '\n',
        'n', 'e', 's', 't', 'i', 'n', 'g', '\n',
        'n', 'e', 's', 't', 'l', 'e', '\n',
        'n', 'e', 's', 't', 'l', 'e', 'd', '\n',
        'n', 'e', 's', 't', 'l', 'e', 's', '\n',
        'n', 'e', 's', 't', 'l', 'i', 'n', 'g', '\n',
        'n', 'e', 's', 't', 's', '\n',
        'n', 'e', 't', '\n',
        'n', 'e', 't', 'b', 'a', 'l', 'l', '\n',
        'n', 'e', 't', 'h', 'e', 'r', '\n',
        'n', 'e', 't', 'h', 'e', 'r', 'm', 'o', 's', 't', '\n',
        'n', 'e', 't', 's', '\n',
        'n', 'e', 't', 't', '\n',
        'n', 'e', 't', 't', 'e', 'd', '\n',
        'n', 'e', 't', 't', 'i', 'n', 'g', '\n',
        'n', 'e', 't', 't', 'l', 'e', '\n',
        'n', 'e', 't', 't', 'l', 'e', 'd', '\n',
        'n', 'e', 't', 't', 'l', 'e', 's', '\n',
        'n', 'e', 't', 't', 's', '\n',
        'n', 'e', 't', 'w', 'o', 'r', 'k', '\n',
        'n', 'e', 't', 'w', 'o', 'r', 'k', 'e', 'd', '\n',
        'n', 'e', 't', 'w', 'o', 'r', 'k', 'i', 'n', 'g', '\n',
        'n', 'e', 't', 'w', 'o', 'r', 'k', 's', '\n',
        'n', 'e', 'u', 'r', 'a', 'l', '\n',
        'n', 'e', 'u', 'r', 'a', 'l', 'g', 'i', 'a', '\n',
        'n', 'e', 'u', 'r', 'o', 'b', 'i', 'o', 'l', 'o', 'g', 'y', '\n',
        'n', 'e', 'u', 'r', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'n', 'e', 'u', 'r', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'n', 'e', 'u', 'r', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'n', 'e', 'u', 'r', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'n', 'e', 'u', 'r', 'o', 'l', 'o', 'g', 'y', '\n',
        'n', 'e', 'u', 'r', 'o', 'n', '\n',
        'n', 'e', 'u', 'r', 'o', 'n', 'a', 'l', '\n',
        'n', 'e', 'u', 'r', 'o', 'n', 'e', '\n',
        'n', 'e', 'u', 'r', 'o', 'n', 'e', 's', '\n',
        'n', 'e', 'u', 'r', 'o', 'n', 's', '\n',
        'n', 'e', 'u', 'r', 'o', 'p', 'h', 'y', 's', 'i', 'o', 'l', 'o', 'g', 'y', '\n',
        'n', 'e', 'u', 'r', 'o', 's', 'c', 'i', 'e', 'n', 'c', 'e', '\n',
        'n', 'e', 'u', 'r', 'o', 's', 'c', 'i', 'e', 'n', 't', 'i', 's', 't', 's', '\n',
        'n', 'e', 'u', 'r', 'o', 's', 'e', 's', '\n',
        'n', 'e', 'u', 'r', 'o', 's', 'i', 's', '\n',
        'n', 'e', 'u', 'r', 'o', 's', 'u', 'r', 'g', 'e', 'o', 'n', '\n',
        'n', 'e', 'u', 'r', 'o', 's', 'u', 'r', 'g', 'e', 'o', 'n', 's', '\n',
        'n', 'e', 'u', 'r', 'o', 's', 'u', 'r', 'g', 'e', 'r', 'y', '\n',
        'n', 'e', 'u', 'r', 'o', 't', 'i', 'c', '\n',
        'n', 'e', 'u', 'r', 'o', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'n', 'e', 'u', 'r', 'o', 't', 'i', 'c', 's', '\n',
        'n', 'e', 'u', 'r', 'o', 't', 'r', 'a', 'n', 's', 'm', 'i', 't', 't', 'e', 'r', '\n',
        'n', 'e', 'u', 'r', 'o', 't', 'r', 'a', 'n', 's', 'm', 'i', 't', 't', 'e', 'r', 's', '\n',
        'n', 'e', 'u', 't', 'e', 'r', '\n',
        'n', 'e', 'u', 't', 'e', 'r', 'e', 'd', '\n',
        'n', 'e', 'u', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'n', 'e', 'u', 't', 'e', 'r', 's', '\n',
        'n', 'e', 'u', 't', 'r', 'a', 'l', '\n',
        'n', 'e', 'u', 't', 'r', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'n', 'e', 'u', 't', 'r', 'a', 'l', 'i', 's', 'e', '\n',
        'n', 'e', 'u', 't', 'r', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'n', 'e', 'u', 't', 'r', 'a', 'l', 'i', 's', 'e', 'r', '\n',
        'n', 'e', 'u', 't', 'r', 'a', 'l', 'i', 's', 'e', 's', '\n',
        'n', 'e', 'u', 't', 'r', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'n', 'e', 'u', 't', 'r', 'a', 'l', 'i', 's', 'm', '\n',
        'n', 'e', 'u', 't', 'r', 'a', 'l', 'i', 's', 't', '\n',
        'n', 'e', 'u', 't', 'r', 'a', 'l', 'i', 't', 'y', '\n',
        'n', 'e', 'u', 't', 'r', 'a', 'l', 'l', 'y', '\n',
        'n', 'e', 'u', 't', 'r', 'a', 'l', 's', '\n',
        'n', 'e', 'u', 't', 'r', 'i', 'n', 'o', '\n',
        'n', 'e', 'u', 't', 'r', 'o', 'n', '\n',
        'n', 'e', 'u', 't', 'r', 'o', 'n', 's', '\n',
        'n', 'e', 'v', 'e', 'r', '\n',
        'n', 'e', 'v', 'e', 'r', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'n', 'e', 'v', 'e', 'r', 't', 'h', 'e', 'l', 'e', 's', 's', '\n',
        'n', 'e', 'w', '\n',
        'n', 'e', 'w', 'b', 'o', 'r', 'n', '\n',
        'n', 'e', 'w', 'c', 'o', 'm', 'e', 'r', '\n',
        'n', 'e', 'w', 'c', 'o', 'm', 'e', 'r', 's', '\n',
        'n', 'e', 'w', 'e', 'r', '\n',
        'n', 'e', 'w', 'e', 's', 't', '\n',
        'n', 'e', 'w', 'f', 'a', 'n', 'g', 'l', 'e', 'd', '\n',
        'n', 'e', 'w', 'f', 'o', 'u', 'n', 'd', '\n',
        'n', 'e', 'w', 'i', 's', 'h', '\n',
        'n', 'e', 'w', 'l', 'o', 'o', 'k', '\n',
        'n', 'e', 'w', 'l', 'y', '\n',
        'n', 'e', 'w', 'l', 'y', 'w', 'e', 'd', '\n',
        'n', 'e', 'w', 'l', 'y', 'w', 'e', 'd', 's', '\n',
        'n', 'e', 'w', 'n', 'e', 's', 's', '\n',
        'n', 'e', 'w', 's', '\n',
        'n', 'e', 'w', 's', 'a', 'g', 'e', 'n', 't', '\n',
        'n', 'e', 'w', 's', 'a', 'g', 'e', 'n', 't', 's', '\n',
        'n', 'e', 'w', 's', 'b', 'o', 'y', '\n',
        'n', 'e', 'w', 's', 'c', 'a', 's', 't', '\n',
        'n', 'e', 'w', 's', 'c', 'a', 's', 't', 'e', 'r', 's', '\n',
        'n', 'e', 'w', 's', 'f', 'l', 'a', 's', 'h', '\n',
        'n', 'e', 'w', 's', 'f', 'l', 'a', 's', 'h', 'e', 's', '\n',
        'n', 'e', 'w', 's', 'l', 'e', 't', 't', 'e', 'r', '\n',
        'n', 'e', 'w', 's', 'l', 'e', 't', 't', 'e', 'r', 's', '\n',
        'n', 'e', 'w', 's', 'm', 'a', 'n', '\n',
        'n', 'e', 'w', 's', 'm', 'e', 'n', '\n',
        'n', 'e', 'w', 's', 'p', 'a', 'p', 'e', 'r', '\n',
        'n', 'e', 'w', 's', 'p', 'a', 'p', 'e', 'r', 'm', 'e', 'n', '\n',
        'n', 'e', 'w', 's', 'p', 'a', 'p', 'e', 'r', 's', '\n',
        'n', 'e', 'w', 's', 'p', 'r', 'i', 'n', 't', '\n',
        'n', 'e', 'w', 's', 'r', 'e', 'a', 'd', 'e', 'r', '\n',
        'n', 'e', 'w', 's', 'r', 'e', 'a', 'd', 'e', 'r', 's', '\n',
        'n', 'e', 'w', 's', 'r', 'e', 'e', 'l', '\n',
        'n', 'e', 'w', 's', 'r', 'e', 'e', 'l', 's', '\n',
        'n', 'e', 'w', 's', 'r', 'o', 'o', 'm', '\n',
        'n', 'e', 'w', 's', 's', 't', 'a', 'n', 'd', '\n',
        'n', 'e', 'w', 's', 's', 't', 'a', 'n', 'd', 's', '\n',
        'n', 'e', 'w', 's', 'w', 'o', 'r', 't', 'h', 'y', '\n',
        'n', 'e', 'w', 's', 'y', '\n',
        'n', 'e', 'w', 't', '\n',
        'n', 'e', 'w', 't', 'o', 'n', '\n',
        'n', 'e', 'w', 't', 's', '\n',
        'n', 'e', 'x', 't', '\n',
        'n', 'g', 'o', 'i', 'n', 'g', '\n',
        'n', 'g', 'u', 'n', 'i', '\n',
        'n', 'g', 'u', 'n', 'i', 's', '\n',
        'n', 'i', 'a', 'g', 'a', 'r', 'a', '\n',
        'n', 'i', 'b', '\n',
        'n', 'i', 'b', 'b', 'l', 'e', '\n',
        'n', 'i', 'b', 'b', 'l', 'e', 'd', '\n',
        'n', 'i', 'b', 'b', 'l', 'e', 'r', '\n',
        'n', 'i', 'b', 'b', 'l', 'e', 'r', 's', '\n',
        'n', 'i', 'b', 'b', 'l', 'e', 's', '\n',
        'n', 'i', 'b', 'b', 'l', 'i', 'n', 'g', '\n',
        'n', 'i', 'b', 's', '\n',
        'n', 'i', 'c', 'e', '\n',
        'n', 'i', 'c', 'e', 'l', 'y', '\n',
        'n', 'i', 'c', 'e', 'n', 'e', 's', 's', '\n',
        'n', 'i', 'c', 'e', 'r', '\n',
        'n', 'i', 'c', 'e', 's', 't', '\n',
        'n', 'i', 'c', 'e', 't', 'i', 'e', 's', '\n',
        'n', 'i', 'c', 'e', 't', 'y', '\n',
        'n', 'i', 'c', 'h', 'e', '\n',
        'n', 'i', 'c', 'h', 'e', 's', '\n',
        'n', 'i', 'c', 'k', '\n',
        'n', 'i', 'c', 'k', 'e', 'd', '\n',
        'n', 'i', 'c', 'k', 'e', 'l', '\n',
        'n', 'i', 'c', 'k', 'i', 'n', 'g', '\n',
        'n', 'i', 'c', 'k', 'n', 'a', 'm', 'e', '\n',
        'n', 'i', 'c', 'k', 'n', 'a', 'm', 'e', 'd', '\n',
        'n', 'i', 'c', 'k', 'n', 'a', 'm', 'e', 's', '\n',
        'n', 'i', 'c', 'k', 's', '\n',
        'n', 'i', 'c', 'o', 't', 'i', 'n', 'e', '\n',
        'n', 'i', 'e', 'c', 'e', '\n',
        'n', 'i', 'e', 'c', 'e', 's', '\n',
        'n', 'i', 'f', 't', 'i', 'l', 'y', '\n',
        'n', 'i', 'f', 't', 'y', '\n',
        'n', 'i', 'g', 'e', 'r', '\n',
        'n', 'i', 'g', 'e', 'r', 'i', 'a', '\n',
        'n', 'i', 'g', 'g', 'a', 'r', 'd', 'l', 'y', '\n',
        'n', 'i', 'g', 'g', 'l', 'e', '\n',
        'n', 'i', 'g', 'g', 'l', 'e', 'd', '\n',
        'n', 'i', 'g', 'g', 'l', 'e', 's', '\n',
        'n', 'i', 'g', 'g', 'l', 'i', 'n', 'g', '\n',
        'n', 'i', 'g', 'h', '\n',
        'n', 'i', 'g', 'h', 't', '\n',
        'n', 'i', 'g', 'h', 't', 'c', 'a', 'p', '\n',
        'n', 'i', 'g', 'h', 't', 'c', 'a', 'p', 's', '\n',
        'n', 'i', 'g', 'h', 't', 'c', 'l', 'o', 't', 'h', 'e', 's', '\n',
        'n', 'i', 'g', 'h', 't', 'c', 'l', 'u', 'b', '\n',
        'n', 'i', 'g', 'h', 't', 'c', 'l', 'u', 'b', 's', '\n',
        'n', 'i', 'g', 'h', 't', 'd', 'r', 'e', 's', 's', '\n',
        'n', 'i', 'g', 'h', 't', 'd', 'r', 'e', 's', 's', 'e', 's', '\n',
        'n', 'i', 'g', 'h', 't', 'f', 'a', 'l', 'l', '\n',
        'n', 'i', 'g', 'h', 't', 'g', 'o', 'w', 'n', '\n',
        'n', 'i', 'g', 'h', 't', 'i', 'e', '\n',
        'n', 'i', 'g', 'h', 't', 'i', 'e', 's', '\n',
        'n', 'i', 'g', 'h', 't', 'i', 'n', 'g', 'a', 'l', 'e', '\n',
        'n', 'i', 'g', 'h', 't', 'i', 'n', 'g', 'a', 'l', 'e', 's', '\n',
        'n', 'i', 'g', 'h', 't', 'l', 'i', 'f', 'e', '\n',
        'n', 'i', 'g', 'h', 't', 'l', 'y', '\n',
        'n', 'i', 'g', 'h', 't', 'm', 'a', 'r', 'e', '\n',
        'n', 'i', 'g', 'h', 't', 'm', 'a', 'r', 'e', 's', '\n',
        'n', 'i', 'g', 'h', 't', 'm', 'a', 'r', 'i', 's', 'h', '\n',
        'n', 'i', 'g', 'h', 't', 's', '\n',
        'n', 'i', 'g', 'h', 't', 'w', 'a', 't', 'c', 'h', 'm', 'a', 'n', '\n',
        'n', 'i', 'g', 'h', 't', 'w', 'e', 'a', 'r', '\n',
        'n', 'i', 'h', 'i', 'l', 'i', 's', 'm', '\n',
        'n', 'i', 'h', 'i', 'l', 'i', 's', 't', '\n',
        'n', 'i', 'h', 'i', 'l', 'i', 's', 't', 'i', 'c', '\n',
        'n', 'i', 'l', '\n',
        'n', 'i', 'l', 'e', '\n',
        'n', 'i', 'l', 's', '\n',
        'n', 'i', 'm', 'b', 'l', 'e', '\n',
        'n', 'i', 'm', 'b', 'l', 'e', 'n', 'e', 's', 's', '\n',
        'n', 'i', 'm', 'b', 'l', 'y', '\n',
        'n', 'i', 'm', 'b', 'u', 's', '\n',
        'n', 'i', 'n', 'c', 'o', 'm', 'p', 'o', 'o', 'p', '\n',
        'n', 'i', 'n', 'e', '\n',
        'n', 'i', 'n', 'e', 'f', 'o', 'l', 'd', '\n',
        'n', 'i', 'n', 'e', 's', '\n',
        'n', 'i', 'n', 'e', 't', 'e', 'e', 'n', '\n',
        'n', 'i', 'n', 'e', 't', 'e', 'e', 'n', 't', 'h', '\n',
        'n', 'i', 'n', 'e', 't', 'i', 'e', 's', '\n',
        'n', 'i', 'n', 'e', 't', 'i', 'e', 't', 'h', '\n',
        'n', 'i', 'n', 'e', 't', 'y', '\n',
        'n', 'i', 'n', 'e', 'v', 'e', 'h', '\n',
        'n', 'i', 'n', 'n', 'y', '\n',
        'n', 'i', 'n', 't', 'h', '\n',
        'n', 'i', 'n', 't', 'h', 's', '\n',
        'n', 'i', 'p', '\n',
        'n', 'i', 'p', 'p', 'e', 'd', '\n',
        'n', 'i', 'p', 'p', 'e', 'r', '\n',
        'n', 'i', 'p', 'p', 'i', 'n', 'g', '\n',
        'n', 'i', 'p', 'p', 'l', 'e', '\n',
        'n', 'i', 'p', 'p', 'l', 'e', 's', '\n',
        'n', 'i', 'p', 'p', 'o', 'n', '\n',
        'n', 'i', 'p', 's', '\n',
        'n', 'i', 'r', 'v', 'a', 'n', 'a', '\n',
        'n', 'i', 't', '\n',
        'n', 'i', 't', 'p', 'i', 'c', 'k', 'i', 'n', 'g', '\n',
        'n', 'i', 't', 'r', 'a', 't', 'e', '\n',
        'n', 'i', 't', 'r', 'a', 't', 'e', 's', '\n',
        'n', 'i', 't', 'r', 'i', 'c', '\n',
        'n', 'i', 't', 'r', 'o', 'g', 'e', 'n', '\n',
        'n', 'i', 't', 'r', 'o', 'g', 'e', 'n', 'o', 'u', 's', '\n',
        'n', 'i', 't', 'r', 'o', 'g', 'l', 'y', 'c', 'e', 'r', 'i', 'n', 'e', '\n',
        'n', 'i', 't', 'r', 'o', 'u', 's', '\n',
        'n', 'i', 't', 's', '\n',
        'n', 'i', 't', 'w', 'i', 't', '\n',
        'n', 'i', 'x', 'o', 'n', '\n',
        'n', 'o', '\n',
        'n', 'o', 'a', 'h', '\n',
        'n', 'o', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'n', 'o', 'b', 'l', 'e', '\n',
        'n', 'o', 'b', 'l', 'e', 'm', 'a', 'n', '\n',
        'n', 'o', 'b', 'l', 'e', 'm', 'e', 'n', '\n',
        'n', 'o', 'b', 'l', 'e', 'n', 'e', 's', 's', '\n',
        'n', 'o', 'b', 'l', 'e', 'r', '\n',
        'n', 'o', 'b', 'l', 'e', 's', '\n',
        'n', 'o', 'b', 'l', 'e', 's', 't', '\n',
        'n', 'o', 'b', 'l', 'y', '\n',
        'n', 'o', 'b', 'o', 'd', 'i', 'e', 's', '\n',
        'n', 'o', 'b', 'o', 'd', 'y', '\n',
        'n', 'o', 'c', 't', 'u', 'i', 'd', 's', '\n',
        'n', 'o', 'c', 't', 'u', 'r', 'n', 'a', 'l', '\n',
        'n', 'o', 'c', 't', 'u', 'r', 'n', 'a', 'l', 'l', 'y', '\n',
        'n', 'o', 'c', 't', 'u', 'r', 'n', 'e', '\n',
        'n', 'o', 'c', 't', 'u', 'r', 'n', 'e', 's', '\n',
        'n', 'o', 'd', '\n',
        'n', 'o', 'd', 'a', 'l', '\n',
        'n', 'o', 'd', 'd', 'e', 'd', '\n',
        'n', 'o', 'd', 'd', 'i', 'n', 'g', '\n',
        'n', 'o', 'd', 'd', 'l', 'e', '\n',
        'n', 'o', 'd', 'd', 'y', '\n',
        'n', 'o', 'd', 'e', '\n',
        'n', 'o', 'd', 'e', 's', '\n',
        'n', 'o', 'd', 's', '\n',
        'n', 'o', 'd', 'u', 'l', 'a', 'r', '\n',
        'n', 'o', 'd', 'u', 'l', 'e', '\n',
        'n', 'o', 'd', 'u', 'l', 'e', 'd', '\n',
        'n', 'o', 'd', 'u', 'l', 'e', 's', '\n',
        'n', 'o', 'e', 'l', '\n',
        'n', 'o', 'g', 'g', 'i', 'n', '\n',
        'n', 'o', 'g', 'g', 'i', 'n', 'g', '\n',
        'n', 'o', 'h', 'o', 'w', '\n',
        'n', 'o', 'i', 's', 'e', '\n',
        'n', 'o', 'i', 's', 'e', 'l', 'e', 's', 's', '\n',
        'n', 'o', 'i', 's', 'e', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'n', 'o', 'i', 's', 'e', 's', '\n',
        'n', 'o', 'i', 's', 'i', 'e', 'r', '\n',
        'n', 'o', 'i', 's', 'i', 'e', 's', 't', '\n',
        'n', 'o', 'i', 's', 'i', 'l', 'y', '\n',
        'n', 'o', 'i', 's', 'i', 'n', 'e', 's', 's', '\n',
        'n', 'o', 'i', 's', 'o', 'm', 'e', '\n',
        'n', 'o', 'i', 's', 'y', '\n',
        'n', 'o', 'm', 'a', 'd', '\n',
        'n', 'o', 'm', 'a', 'd', 'i', 'c', '\n',
        'n', 'o', 'm', 'a', 'd', 's', '\n',
        'n', 'o', 'm', 'e', 'n', 'c', 'l', 'a', 't', 'u', 'r', 'e', '\n',
        'n', 'o', 'm', 'e', 'n', 'c', 'l', 'a', 't', 'u', 'r', 'e', 's', '\n',
        'n', 'o', 'm', 'i', 'n', 'a', 'l', '\n',
        'n', 'o', 'm', 'i', 'n', 'a', 'l', 'l', 'y', '\n',
        'n', 'o', 'm', 'i', 'n', 'a', 't', 'e', '\n',
        'n', 'o', 'm', 'i', 'n', 'a', 't', 'e', 'd', '\n',
        'n', 'o', 'm', 'i', 'n', 'a', 't', 'e', 's', '\n',
        'n', 'o', 'm', 'i', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'n', 'o', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'n', 'o', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'n', 'o', 'm', 'i', 'n', 'a', 't', 'i', 'v', 'e', '\n',
        'n', 'o', 'm', 'i', 'n', 'a', 't', 'o', 'r', '\n',
        'n', 'o', 'm', 'i', 'n', 'e', 'e', '\n',
        'n', 'o', 'm', 'i', 'n', 'e', 'e', 's', '\n',
        'n', 'o', 'n', '\n',
        'n', 'o', 'n', 'b', 'e', 'l', 'i', 'e', 'v', 'e', 'r', '\n',
        'n', 'o', 'n', 'b', 'e', 'l', 'i', 'e', 'v', 'e', 'r', 's', '\n',
        'n', 'o', 'n', 'c', 'h', 'a', 'l', 'a', 'n', 'c', 'e', '\n',
        'n', 'o', 'n', 'c', 'h', 'a', 'l', 'a', 'n', 't', '\n',
        'n', 'o', 'n', 'c', 'h', 'a', 'l', 'a', 'n', 't', 'l', 'y', '\n',
        'n', 'o', 'n', 'c', 'o', 'n', 'f', 'o', 'r', 'm', 'i', 's', 't', '\n',
        'n', 'o', 'n', 'c', 'o', 'n', 'f', 'o', 'r', 'm', 'i', 's', 't', 's', '\n',
        'n', 'o', 'n', 'c', 'o', 'n', 'f', 'o', 'r', 'm', 'i', 't', 'y', '\n',
        'n', 'o', 'n', 'd', 'r', 'i', 'n', 'k', 'e', 'r', 's', '\n',
        'n', 'o', 'n', 'e', '\n',
        'n', 'o', 'n', 'e', 'n', 't', 'i', 't', 'i', 'e', 's', '\n',
        'n', 'o', 'n', 'e', 'n', 't', 'i', 't', 'y', '\n',
        'n', 'o', 'n', 'e', 's', 's', 'e', 'n', 't', 'i', 'a', 'l', '\n',
        'n', 'o', 'n', 'e', 's', 's', 'e', 'n', 't', 'i', 'a', 'l', 's', '\n',
        'n', 'o', 'n', 'e', 't', 'h', 'e', 'l', 'e', 's', 's', '\n',
        'n', 'o', 'n', 'e', 'v', 'e', 'n', 't', '\n',
        'n', 'o', 'n', 'e', 'x', 'i', 's', 't', 'e', 'n', 'c', 'e', '\n',
        'n', 'o', 'n', 'e', 'x', 'i', 's', 't', 'e', 'n', 't', '\n',
        'n', 'o', 'n', 'f', 'u', 'n', 'c', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'n', 'o', 'n', 'i', 'n', 't', 'e', 'r', 'f', 'e', 'r', 'e', 'n', 'c', 'e', '\n',
        'n', 'o', 'n', 'i', 'n', 't', 'e', 'r', 'v', 'e', 'n', 't', 'i', 'o', 'n', '\n',
        'n', 'o', 'n', 'p', 'a', 'r', 't', 'i', 'c', 'i', 'p', 'a', 't', 'i', 'o', 'n', '\n',
        'n', 'o', 'n', 'p', 'a', 'y', 'm', 'e', 'n', 't', '\n',
        'n', 'o', 'n', 'p', 'l', 'u', 's', 's', 'e', 'd', '\n',
        'n', 'o', 'n', 's', 'e', 'n', 's', 'e', '\n',
        'n', 'o', 'n', 's', 'e', 'n', 's', 'e', 's', '\n',
        'n', 'o', 'n', 's', 'e', 'n', 's', 'i', 'c', 'a', 'l', '\n',
        'n', 'o', 'n', 's', 'm', 'o', 'k', 'e', 'r', '\n',
        'n', 'o', 'n', 's', 'm', 'o', 'k', 'e', 'r', 's', '\n',
        'n', 'o', 'n', 's', 'm', 'o', 'k', 'i', 'n', 'g', '\n',
        'n', 'o', 'n', 'v', 'i', 'o', 'l', 'e', 'n', 'c', 'e', '\n',
        'n', 'o', 'n', 'v', 'i', 'o', 'l', 'e', 'n', 't', '\n',
        'n', 'o', 'o', 'd', 'l', 'e', '\n',
        'n', 'o', 'o', 'd', 'l', 'e', 's', '\n',
        'n', 'o', 'o', 'k', '\n',
        'n', 'o', 'o', 'k', 's', '\n',
        'n', 'o', 'o', 'n', '\n',
        'n', 'o', 'o', 'n', 'd', 'a', 'y', '\n',
        'n', 'o', 'o', 'n', 's', '\n',
        'n', 'o', 'o', 'n', 't', 'i', 'd', 'e', '\n',
        'n', 'o', 'o', 's', 'e', '\n',
        'n', 'o', 'o', 's', 'e', 'd', '\n',
        'n', 'o', 'o', 's', 'e', 's', '\n',
        'n', 'o', 'r', '\n',
        'n', 'o', 'r', 'a', 'd', 'r', 'e', 'n', 'a', 'l', 'i', 'n', '\n',
        'n', 'o', 'r', 'a', 'd', 'r', 'e', 'n', 'a', 'l', 'i', 'n', 'e', '\n',
        'n', 'o', 'r', 'd', 'i', 'c', '\n',
        'n', 'o', 'r', 'm', '\n',
        'n', 'o', 'r', 'm', 'a', 'l', '\n',
        'n', 'o', 'r', 'm', 'a', 'l', 'c', 'y', '\n',
        'n', 'o', 'r', 'm', 'a', 'l', 'i', 's', 'a', 'b', 'l', 'e', '\n',
        'n', 'o', 'r', 'm', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'n', 'o', 'r', 'm', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'n', 'o', 'r', 'm', 'a', 'l', 'i', 's', 'e', '\n',
        'n', 'o', 'r', 'm', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'n', 'o', 'r', 'm', 'a', 'l', 'i', 's', 'e', 'r', '\n',
        'n', 'o', 'r', 'm', 'a', 'l', 'i', 's', 'e', 'r', 's', '\n',
        'n', 'o', 'r', 'm', 'a', 'l', 'i', 's', 'e', 's', '\n',
        'n', 'o', 'r', 'm', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'n', 'o', 'r', 'm', 'a', 'l', 'i', 't', 'y', '\n',
        'n', 'o', 'r', 'm', 'a', 'l', 'l', 'y', '\n',
        'n', 'o', 'r', 'm', 'a', 'l', 's', '\n',
        'n', 'o', 'r', 'm', 'a', 'n', '\n',
        'n', 'o', 'r', 'm', 'a', 'n', 'd', 'y', '\n',
        'n', 'o', 'r', 'm', 'a', 'n', 's', '\n',
        'n', 'o', 'r', 'm', 'a', 't', 'i', 'v', 'e', '\n',
        'n', 'o', 'r', 'm', 'e', 'd', '\n',
        'n', 'o', 'r', 'm', 's', '\n',
        'n', 'o', 'r', 's', 'e', 'm', 'e', 'n', '\n',
        'n', 'o', 'r', 't', 'h', '\n',
        'n', 'o', 'r', 't', 'h', 'b', 'o', 'u', 'n', 'd', '\n',
        'n', 'o', 'r', 't', 'h', 'e', 'r', 'l', 'y', '\n',
        'n', 'o', 'r', 't', 'h', 'e', 'r', 'n', '\n',
        'n', 'o', 'r', 't', 'h', 'e', 'r', 'n', 'e', 'r', '\n',
        'n', 'o', 'r', 't', 'h', 'e', 'r', 'n', 'e', 'r', 's', '\n',
        'n', 'o', 'r', 't', 'h', 'e', 'r', 'n', 'm', 'o', 's', 't', '\n',
        'n', 'o', 'r', 't', 'h', 'm', 'e', 'n', '\n',
        'n', 'o', 'r', 't', 'h', 'w', 'a', 'r', 'd', '\n',
        'n', 'o', 'r', 't', 'h', 'w', 'a', 'r', 'd', 's', '\n',
        'n', 'o', 'r', 'w', 'a', 'y', '\n',
        'n', 'o', 's', 'e', '\n',
        'n', 'o', 's', 'e', 'd', '\n',
        'n', 'o', 's', 'e', 'd', 'i', 'v', 'e', '\n',
        'n', 'o', 's', 'e', 's', '\n',
        'n', 'o', 's', 'e', 'y', '\n',
        'n', 'o', 's', 'i', 'e', 'r', '\n',
        'n', 'o', 's', 'i', 'e', 's', 't', '\n',
        'n', 'o', 's', 'i', 'l', 'y', '\n',
        'n', 'o', 's', 'i', 'n', 'e', 's', 's', '\n',
        'n', 'o', 's', 'i', 'n', 'g', '\n',
        'n', 'o', 's', 't', 'a', 'l', 'g', 'i', 'a', '\n',
        'n', 'o', 's', 't', 'a', 'l', 'g', 'i', 'c', '\n',
        'n', 'o', 's', 't', 'a', 'l', 'g', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'n', 'o', 's', 't', 'r', 'i', 'l', '\n',
        'n', 'o', 's', 't', 'r', 'i', 'l', 's', '\n',
        'n', 'o', 's', 't', 'r', 'u', 'm', '\n',
        'n', 'o', 's', 'y', '\n',
        'n', 'o', 't', '\n',
        'n', 'o', 't', 'a', 'b', 'l', 'e', '\n',
        'n', 'o', 't', 'a', 'b', 'l', 'e', 's', '\n',
        'n', 'o', 't', 'a', 'b', 'l', 'y', '\n',
        'n', 'o', 't', 'a', 'r', 'i', 'e', 's', '\n',
        'n', 'o', 't', 'a', 'r', 'y', '\n',
        'n', 'o', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'n', 'o', 't', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'n', 'o', 't', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'n', 'o', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'n', 'o', 't', 'c', 'h', '\n',
        'n', 'o', 't', 'c', 'h', 'e', 'd', '\n',
        'n', 'o', 't', 'c', 'h', 'e', 's', '\n',
        'n', 'o', 't', 'c', 'h', 'i', 'n', 'g', '\n',
        'n', 'o', 't', 'e', '\n',
        'n', 'o', 't', 'e', 'b', 'o', 'o', 'k', '\n',
        'n', 'o', 't', 'e', 'b', 'o', 'o', 'k', 's', '\n',
        'n', 'o', 't', 'e', 'd', '\n',
        'n', 'o', 't', 'e', 'p', 'a', 'd', '\n',
        'n', 'o', 't', 'e', 'p', 'a', 'd', 's', '\n',
        'n', 'o', 't', 'e', 'p', 'a', 'p', 'e', 'r', '\n',
        'n', 'o', 't', 'e', 's', '\n',
        'n', 'o', 't', 'e', 'w', 'o', 'r', 't', 'h', 'y', '\n',
        'n', 'o', 't', 'h', 'i', 'n', 'g', '\n',
        'n', 'o', 't', 'h', 'i', 'n', 'g', 'n', 'e', 's', 's', '\n',
        'n', 'o', 't', 'h', 'i', 'n', 'g', 's', '\n',
        'n', 'o', 't', 'i', 'c', 'e', '\n',
        'n', 'o', 't', 'i', 'c', 'e', 'a', 'b', 'l', 'e', '\n',
        'n', 'o', 't', 'i', 'c', 'e', 'a', 'b', 'l', 'y', '\n',
        'n', 'o', 't', 'i', 'c', 'e', 'b', 'o', 'a', 'r', 'd', '\n',
        'n', 'o', 't', 'i', 'c', 'e', 'b', 'o', 'a', 'r', 'd', 's', '\n',
        'n', 'o', 't', 'i', 'c', 'e', 'd', '\n',
        'n', 'o', 't', 'i', 'c', 'e', 's', '\n',
        'n', 'o', 't', 'i', 'c', 'i', 'n', 'g', '\n',
        'n', 'o', 't', 'i', 'f', 'i', 'a', 'b', 'l', 'e', '\n',
        'n', 'o', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'n', 'o', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'n', 'o', 't', 'i', 'f', 'i', 'e', 'd', '\n',
        'n', 'o', 't', 'i', 'f', 'i', 'e', 's', '\n',
        'n', 'o', 't', 'i', 'f', 'y', '\n',
        'n', 'o', 't', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'n', 'o', 't', 'i', 'n', 'g', '\n',
        'n', 'o', 't', 'i', 'o', 'n', '\n',
        'n', 'o', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'n', 'o', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'n', 'o', 't', 'i', 'o', 'n', 's', '\n',
        'n', 'o', 't', 'o', 'r', 'i', 'e', 't', 'y', '\n',
        'n', 'o', 't', 'o', 'r', 'i', 'o', 'u', 's', '\n',
        'n', 'o', 't', 'o', 'r', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'n', 'o', 't', 'w', 'i', 't', 'h', 's', 't', 'a', 'n', 'd', 'i', 'n', 'g', '\n',
        'n', 'o', 'u', 'g', 'a', 't', '\n',
        'n', 'o', 'u', 'g', 'a', 't', 's', '\n',
        'n', 'o', 'u', 'g', 'h', 't', '\n',
        'n', 'o', 'u', 'g', 'h', 't', 's', '\n',
        'n', 'o', 'u', 'n', '\n',
        'n', 'o', 'u', 'n', 'a', 'l', '\n',
        'n', 'o', 'u', 'n', 's', '\n',
        'n', 'o', 'u', 'r', 'i', 's', 'h', '\n',
        'n', 'o', 'u', 'r', 'i', 's', 'h', 'e', 'd', '\n',
        'n', 'o', 'u', 'r', 'i', 's', 'h', 'e', 's', '\n',
        'n', 'o', 'u', 'r', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'n', 'o', 'u', 'r', 'i', 's', 'h', 'm', 'e', 'n', 't', '\n',
        'n', 'o', 'v', 'e', 'l', '\n',
        'n', 'o', 'v', 'e', 'l', 'e', 't', 't', 'e', '\n',
        'n', 'o', 'v', 'e', 'l', 'i', 's', 't', '\n',
        'n', 'o', 'v', 'e', 'l', 'i', 's', 't', 'i', 'c', '\n',
        'n', 'o', 'v', 'e', 'l', 'i', 's', 't', 's', '\n',
        'n', 'o', 'v', 'e', 'l', 'l', 'e', '\n',
        'n', 'o', 'v', 'e', 'l', 's', '\n',
        'n', 'o', 'v', 'e', 'l', 't', 'i', 'e', 's', '\n',
        'n', 'o', 'v', 'e', 'l', 't', 'y', '\n',
        'n', 'o', 'v', 'e', 'm', 'b', 'e', 'r', '\n',
        'n', 'o', 'v', 'i', 'c', 'e', '\n',
        'n', 'o', 'v', 'i', 'c', 'e', 's', '\n',
        'n', 'o', 'w', '\n',
        'n', 'o', 'w', 'a', 'd', 'a', 'y', 's', '\n',
        'n', 'o', 'w', 'h', 'e', 'r', 'e', '\n',
        'n', 'o', 'x', 'i', 'o', 'u', 's', '\n',
        'n', 'o', 'x', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'n', 'o', 'x', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'n', 'o', 'z', 'z', 'l', 'e', '\n',
        'n', 'o', 'z', 'z', 'l', 'e', 's', '\n',
        'n', 'u', '\n',
        'n', 'u', 'a', 'n', 'c', 'e', '\n',
        'n', 'u', 'a', 'n', 'c', 'e', 's', '\n',
        'n', 'u', 'c', 'l', 'e', 'a', 'r', '\n',
        'n', 'u', 'c', 'l', 'e', 'i', '\n',
        'n', 'u', 'c', 'l', 'e', 'i', 'c', '\n',
        'n', 'u', 'c', 'l', 'e', 'u', 's', '\n',
        'n', 'u', 'd', 'e', '\n',
        'n', 'u', 'd', 'e', 'n', 'e', 's', 's', '\n',
        'n', 'u', 'd', 'e', 's', '\n',
        'n', 'u', 'd', 'g', 'e', '\n',
        'n', 'u', 'd', 'g', 'e', 'd', '\n',
        'n', 'u', 'd', 'g', 'e', 's', '\n',
        'n', 'u', 'd', 'g', 'i', 'n', 'g', '\n',
        'n', 'u', 'd', 'i', 's', 'm', '\n',
        'n', 'u', 'd', 'i', 's', 't', '\n',
        'n', 'u', 'd', 'i', 's', 't', 's', '\n',
        'n', 'u', 'd', 'i', 't', 'i', 'e', 's', '\n',
        'n', 'u', 'd', 'i', 't', 'y', '\n',
        'n', 'u', 'g', 'g', 'e', 't', '\n',
        'n', 'u', 'g', 'g', 'e', 't', 's', '\n',
        'n', 'u', 'i', 's', 'a', 'n', 'c', 'e', '\n',
        'n', 'u', 'i', 's', 'a', 'n', 'c', 'e', 's', '\n',
        'n', 'u', 'k', 'e', '\n',
        'n', 'u', 'l', 'l', '\n',
        'n', 'u', 'l', 'l', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'n', 'u', 'l', 'l', 'i', 'f', 'i', 'e', 'd', '\n',
        'n', 'u', 'l', 'l', 'i', 'f', 'i', 'e', 's', '\n',
        'n', 'u', 'l', 'l', 'i', 'f', 'y', '\n',
        'n', 'u', 'l', 'l', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'n', 'u', 'l', 'l', 'i', 't', 'y', '\n',
        'n', 'u', 'l', 'l', 's', '\n',
        'n', 'u', 'm', 'b', '\n',
        'n', 'u', 'm', 'b', 'e', 'd', '\n',
        'n', 'u', 'm', 'b', 'e', 'r', '\n',
        'n', 'u', 'm', 'b', 'e', 'r', 'e', 'd', '\n',
        'n', 'u', 'm', 'b', 'e', 'r', 'i', 'n', 'g', '\n',
        'n', 'u', 'm', 'b', 'e', 'r', 'i', 'n', 'g', 's', '\n',
        'n', 'u', 'm', 'b', 'e', 'r', 'l', 'e', 's', 's', '\n',
        'n', 'u', 'm', 'b', 'e', 'r', 'p', 'l', 'a', 't', 'e', '\n',
        'n', 'u', 'm', 'b', 'e', 'r', 's', '\n',
        'n', 'u', 'm', 'b', 'i', 'n', 'g', '\n',
        'n', 'u', 'm', 'b', 'i', 'n', 'g', 'l', 'y', '\n',
        'n', 'u', 'm', 'b', 'l', 'y', '\n',
        'n', 'u', 'm', 'b', 'n', 'e', 's', 's', '\n',
        'n', 'u', 'm', 'b', 's', '\n',
        'n', 'u', 'm', 'b', 's', 'k', 'u', 'l', 'l', '\n',
        'n', 'u', 'm', 'e', 'r', 'a', 'c', 'y', '\n',
        'n', 'u', 'm', 'e', 'r', 'a', 'l', '\n',
        'n', 'u', 'm', 'e', 'r', 'a', 'l', 's', '\n',
        'n', 'u', 'm', 'e', 'r', 'a', 't', 'e', '\n',
        'n', 'u', 'm', 'e', 'r', 'a', 't', 'o', 'r', '\n',
        'n', 'u', 'm', 'e', 'r', 'a', 't', 'o', 'r', 's', '\n',
        'n', 'u', 'm', 'e', 'r', 'i', 'c', '\n',
        'n', 'u', 'm', 'e', 'r', 'i', 'c', 'a', 'l', '\n',
        'n', 'u', 'm', 'e', 'r', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'n', 'u', 'm', 'e', 'r', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'n', 'u', 'm', 'e', 'r', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'n', 'u', 'm', 'e', 'r', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'n', 'u', 'm', 'e', 'r', 'o', 'l', 'o', 'g', 'y', '\n',
        'n', 'u', 'm', 'e', 'r', 'o', 'u', 's', '\n',
        'n', 'u', 'm', 'i', 's', 'm', 'a', 't', 'i', 'c', '\n',
        'n', 'u', 'm', 'i', 's', 'm', 'a', 't', 'i', 'c', 's', '\n',
        'n', 'u', 'm', 's', 'k', 'u', 'l', 'l', '\n',
        'n', 'u', 'n', '\n',
        'n', 'u', 'n', 'n', 'e', 'r', 'i', 'e', 's', '\n',
        'n', 'u', 'n', 'n', 'e', 'r', 'y', '\n',
        'n', 'u', 'n', 's', '\n',
        'n', 'u', 'p', 't', 'i', 'a', 'l', '\n',
        'n', 'u', 'p', 't', 'i', 'a', 'l', 's', '\n',
        'n', 'u', 'r', 's', 'e', '\n',
        'n', 'u', 'r', 's', 'e', 'd', '\n',
        'n', 'u', 'r', 's', 'e', 'm', 'a', 'i', 'd', '\n',
        'n', 'u', 'r', 's', 'e', 'm', 'a', 'i', 'd', 's', '\n',
        'n', 'u', 'r', 's', 'e', 'r', 'i', 'e', 's', '\n',
        'n', 'u', 'r', 's', 'e', 'r', 'y', '\n',
        'n', 'u', 'r', 's', 'e', 'r', 'y', 'm', 'a', 'n', '\n',
        'n', 'u', 'r', 's', 'e', 'r', 'y', 'm', 'e', 'n', '\n',
        'n', 'u', 'r', 's', 'e', 's', '\n',
        'n', 'u', 'r', 's', 'i', 'n', 'g', '\n',
        'n', 'u', 'r', 't', 'u', 'r', 'e', '\n',
        'n', 'u', 'r', 't', 'u', 'r', 'e', 'd', '\n',
        'n', 'u', 'r', 't', 'u', 'r', 'e', 's', '\n',
        'n', 'u', 'r', 't', 'u', 'r', 'i', 'n', 'g', '\n',
        'n', 'u', 't', '\n',
        'n', 'u', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'n', 'u', 't', 'c', 'r', 'a', 'c', 'k', 'e', 'r', '\n',
        'n', 'u', 't', 'c', 'r', 'a', 'c', 'k', 'e', 'r', 's', '\n',
        'n', 'u', 't', 'm', 'e', 'g', '\n',
        'n', 'u', 't', 'm', 'e', 'g', 's', '\n',
        'n', 'u', 't', 'r', 'i', 'e', 'n', 't', '\n',
        'n', 'u', 't', 'r', 'i', 'e', 'n', 't', 's', '\n',
        'n', 'u', 't', 'r', 'i', 'm', 'e', 'n', 't', '\n',
        'n', 'u', 't', 'r', 'i', 't', 'i', 'o', 'n', '\n',
        'n', 'u', 't', 'r', 'i', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'n', 'u', 't', 'r', 'i', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'n', 'u', 't', 'r', 'i', 't', 'i', 'o', 'n', 'i', 's', 't', '\n',
        'n', 'u', 't', 'r', 'i', 't', 'i', 'o', 'n', 'i', 's', 't', 's', '\n',
        'n', 'u', 't', 'r', 'i', 't', 'i', 'o', 'u', 's', '\n',
        'n', 'u', 't', 'r', 'i', 't', 'i', 'v', 'e', '\n',
        'n', 'u', 't', 's', '\n',
        'n', 'u', 't', 's', 'h', 'e', 'l', 'l', '\n',
        'n', 'u', 't', 't', 'i', 'e', 'r', '\n',
        'n', 'u', 't', 't', 'y', '\n',
        'n', 'u', 'z', 'z', 'l', 'e', '\n',
        'n', 'u', 'z', 'z', 'l', 'e', 'd', '\n',
        'n', 'u', 'z', 'z', 'l', 'e', 's', '\n',
        'n', 'u', 'z', 'z', 'l', 'i', 'n', 'g', '\n',
        'n', 'y', 'a', 'l', 'a', '\n',
        'n', 'y', 'l', 'o', 'n', '\n',
        'n', 'y', 'l', 'o', 'n', 's', '\n',
        'n', 'y', 'm', 'p', 'h', '\n',
        'n', 'y', 'm', 'p', 'h', 'o', 'l', 'e', 'p', 's', 'y', '\n',
        'n', 'y', 'm', 'p', 'h', 'o', 'm', 'a', 'n', 'i', 'a', '\n',
        'n', 'y', 'm', 'p', 'h', 'o', 'm', 'a', 'n', 'i', 'a', 'c', '\n',
        'n', 'y', 'm', 'p', 'h', 's', '\n',
        'o', 'a', 'f', '\n',
        'o', 'a', 'f', 'i', 's', 'h', '\n',
        'o', 'a', 'f', 's', '\n',
        'o', 'a', 'k', '\n',
        'o', 'a', 'k', 'e', 'n', '\n',
        'o', 'a', 'k', 's', '\n',
        'o', 'a', 'k', 'u', 'm', '\n',
        'o', 'a', 'r', '\n',
        'o', 'a', 'r', 's', '\n',
        'o', 'a', 'r', 's', 'm', 'a', 'n', '\n',
        'o', 'a', 'r', 's', 'm', 'e', 'n', '\n',
        'o', 'a', 's', 'e', 's', '\n',
        'o', 'a', 's', 'i', 's', '\n',
        'o', 'a', 's', 't', '\n',
        'o', 'a', 't', '\n',
        'o', 'a', 't', 'c', 'a', 'k', 'e', 's', '\n',
        'o', 'a', 't', 'h', '\n',
        'o', 'a', 't', 'h', 's', '\n',
        'o', 'a', 't', 'm', 'e', 'a', 'l', '\n',
        'o', 'a', 't', 's', '\n',
        'o', 'b', 'd', 'u', 'r', 'a', 'c', 'y', '\n',
        'o', 'b', 'd', 'u', 'r', 'a', 't', 'e', '\n',
        'o', 'b', 'd', 'u', 'r', 'a', 't', 'e', 'l', 'y', '\n',
        'o', 'b', 'e', 'd', 'i', 'e', 'n', 'c', 'e', '\n',
        'o', 'b', 'e', 'd', 'i', 'e', 'n', 't', '\n',
        'o', 'b', 'e', 'd', 'i', 'e', 'n', 't', 'l', 'y', '\n',
        'o', 'b', 'e', 'i', 's', 'a', 'n', 'c', 'e', '\n',
        'o', 'b', 'e', 'l', 'i', 's', 'k', '\n',
        'o', 'b', 'e', 'l', 'i', 's', 'k', 's', '\n',
        'o', 'b', 'e', 's', 'e', '\n',
        'o', 'b', 'e', 's', 'i', 't', 'y', '\n',
        'o', 'b', 'e', 'y', '\n',
        'o', 'b', 'e', 'y', 'e', 'd', '\n',
        'o', 'b', 'e', 'y', 'i', 'n', 'g', '\n',
        'o', 'b', 'e', 'y', 's', '\n',
        'o', 'b', 'f', 'u', 's', 'c', 'a', 't', 'e', '\n',
        'o', 'b', 'f', 'u', 's', 'c', 'a', 't', 'e', 'd', '\n',
        'o', 'b', 'f', 'u', 's', 'c', 'a', 't', 'e', 's', '\n',
        'o', 'b', 'f', 'u', 's', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'o', 'b', 'f', 'u', 's', 'c', 'a', 't', 'o', 'r', 'y', '\n',
        'o', 'b', 'i', 't', 'u', 'a', 'r', 'i', 'e', 's', '\n',
        'o', 'b', 'i', 't', 'u', 'a', 'r', 'y', '\n',
        'o', 'b', 'j', 'e', 'c', 't', '\n',
        'o', 'b', 'j', 'e', 'c', 't', 'e', 'd', '\n',
        'o', 'b', 'j', 'e', 'c', 't', 'i', 'f', 'i', 'e', 'd', '\n',
        'o', 'b', 'j', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'o', 'b', 'j', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'o', 'b', 'j', 'e', 'c', 't', 'i', 'o', 'n', 'a', 'b', 'l', 'e', '\n',
        'o', 'b', 'j', 'e', 'c', 't', 'i', 'o', 'n', 'a', 'b', 'l', 'e', 'n', 'e', 's', 's', '\n',
        'o', 'b', 'j', 'e', 'c', 't', 'i', 'o', 'n', 'a', 'b', 'l', 'y', '\n',
        'o', 'b', 'j', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'o', 'b', 'j', 'e', 'c', 't', 'i', 'v', 'e', '\n',
        'o', 'b', 'j', 'e', 'c', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'o', 'b', 'j', 'e', 'c', 't', 'i', 'v', 'e', 's', '\n',
        'o', 'b', 'j', 'e', 'c', 't', 'i', 'v', 'i', 't', 'y', '\n',
        'o', 'b', 'j', 'e', 'c', 't', 'l', 'e', 's', 's', '\n',
        'o', 'b', 'j', 'e', 'c', 't', 'o', 'r', '\n',
        'o', 'b', 'j', 'e', 'c', 't', 'o', 'r', 's', '\n',
        'o', 'b', 'j', 'e', 'c', 't', 's', '\n',
        'o', 'b', 'l', 'a', 't', 'e', '\n',
        'o', 'b', 'l', 'i', 'g', 'a', 't', 'e', '\n',
        'o', 'b', 'l', 'i', 'g', 'a', 't', 'e', 'd', '\n',
        'o', 'b', 'l', 'i', 'g', 'a', 't', 'i', 'o', 'n', '\n',
        'o', 'b', 'l', 'i', 'g', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'o', 'b', 'l', 'i', 'g', 'a', 't', 'o', 'r', 'i', 'l', 'y', '\n',
        'o', 'b', 'l', 'i', 'g', 'a', 't', 'o', 'r', 'y', '\n',
        'o', 'b', 'l', 'i', 'g', 'e', '\n',
        'o', 'b', 'l', 'i', 'g', 'e', 'd', '\n',
        'o', 'b', 'l', 'i', 'g', 'e', 's', '\n',
        'o', 'b', 'l', 'i', 'g', 'i', 'n', 'g', '\n',
        'o', 'b', 'l', 'i', 'g', 'i', 'n', 'g', 'l', 'y', '\n',
        'o', 'b', 'l', 'i', 'q', 'u', 'e', '\n',
        'o', 'b', 'l', 'i', 'q', 'u', 'e', 'd', '\n',
        'o', 'b', 'l', 'i', 'q', 'u', 'e', 'l', 'y', '\n',
        'o', 'b', 'l', 'i', 'q', 'u', 'e', 'n', 'e', 's', 's', '\n',
        'o', 'b', 'l', 'i', 'q', 'u', 'i', 't', 'y', '\n',
        'o', 'b', 'l', 'i', 't', 'e', 'r', 'a', 't', 'e', '\n',
        'o', 'b', 'l', 'i', 't', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'o', 'b', 'l', 'i', 't', 'e', 'r', 'a', 't', 'e', 's', '\n',
        'o', 'b', 'l', 'i', 't', 'e', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'o', 'b', 'l', 'i', 't', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'o', 'b', 'l', 'i', 'v', 'i', 'o', 'n', '\n',
        'o', 'b', 'l', 'i', 'v', 'i', 'o', 'u', 's', '\n',
        'o', 'b', 'l', 'i', 'v', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'o', 'b', 'l', 'o', 'n', 'g', '\n',
        'o', 'b', 'l', 'o', 'n', 'g', 's', '\n',
        'o', 'b', 'l', 'o', 'q', 'u', 'y', '\n',
        'o', 'b', 'n', 'o', 'x', 'i', 'o', 'u', 's', '\n',
        'o', 'b', 'n', 'o', 'x', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'o', 'b', 'n', 'o', 'x', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'o', 'b', 'o', 'e', '\n',
        'o', 'b', 'o', 'e', 's', '\n',
        'o', 'b', 'o', 'i', 's', 't', '\n',
        'o', 'b', 's', 'c', 'e', 'n', 'e', '\n',
        'o', 'b', 's', 'c', 'e', 'n', 'e', 'l', 'y', '\n',
        'o', 'b', 's', 'c', 'e', 'n', 'i', 't', 'i', 'e', 's', '\n',
        'o', 'b', 's', 'c', 'e', 'n', 'i', 't', 'y', '\n',
        'o', 'b', 's', 'c', 'u', 'r', 'a', 'n', 't', 'i', 's', 'm', '\n',
        'o', 'b', 's', 'c', 'u', 'r', 'a', 'n', 't', 'i', 's', 't', '\n',
        'o', 'b', 's', 'c', 'u', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'o', 'b', 's', 'c', 'u', 'r', 'e', '\n',
        'o', 'b', 's', 'c', 'u', 'r', 'e', 'd', '\n',
        'o', 'b', 's', 'c', 'u', 'r', 'e', 'l', 'y', '\n',
        'o', 'b', 's', 'c', 'u', 'r', 'e', 'n', 'e', 's', 's', '\n',
        'o', 'b', 's', 'c', 'u', 'r', 'e', 'r', '\n',
        'o', 'b', 's', 'c', 'u', 'r', 'e', 's', '\n',
        'o', 'b', 's', 'c', 'u', 'r', 'e', 's', 't', '\n',
        'o', 'b', 's', 'c', 'u', 'r', 'i', 'n', 'g', '\n',
        'o', 'b', 's', 'c', 'u', 'r', 'i', 't', 'i', 'e', 's', '\n',
        'o', 'b', 's', 'c', 'u', 'r', 'i', 't', 'y', '\n',
        'o', 'b', 's', 'e', 'q', 'u', 'i', 'o', 'u', 's', '\n',
        'o', 'b', 's', 'e', 'q', 'u', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'o', 'b', 's', 'e', 'q', 'u', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'o', 'b', 's', 'e', 'r', 'v', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'o', 'b', 's', 'e', 'r', 'v', 'a', 'b', 'l', 'e', '\n',
        'o', 'b', 's', 'e', 'r', 'v', 'a', 'b', 'l', 'e', 's', '\n',
        'o', 'b', 's', 'e', 'r', 'v', 'a', 'b', 'l', 'y', '\n',
        'o', 'b', 's', 'e', 'r', 'v', 'a', 'n', 'c', 'e', '\n',
        'o', 'b', 's', 'e', 'r', 'v', 'a', 'n', 'c', 'e', 's', '\n',
        'o', 'b', 's', 'e', 'r', 'v', 'a', 'n', 't', '\n',
        'o', 'b', 's', 'e', 'r', 'v', 'a', 't', 'i', 'o', 'n', '\n',
        'o', 'b', 's', 'e', 'r', 'v', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'o', 'b', 's', 'e', 'r', 'v', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'o', 'b', 's', 'e', 'r', 'v', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'o', 'b', 's', 'e', 'r', 'v', 'a', 't', 'o', 'r', 'i', 'e', 's', '\n',
        'o', 'b', 's', 'e', 'r', 'v', 'a', 't', 'o', 'r', 'y', '\n',
        'o', 'b', 's', 'e', 'r', 'v', 'e', '\n',
        'o', 'b', 's', 'e', 'r', 'v', 'e', 'd', '\n',
        'o', 'b', 's', 'e', 'r', 'v', 'e', 'r', '\n',
        'o', 'b', 's', 'e', 'r', 'v', 'e', 'r', 's', '\n',
        'o', 'b', 's', 'e', 'r', 'v', 'e', 's', '\n',
        'o', 'b', 's', 'e', 'r', 'v', 'i', 'n', 'g', '\n',
        'o', 'b', 's', 'e', 's', 's', '\n',
        'o', 'b', 's', 'e', 's', 's', 'e', 'd', '\n',
        'o', 'b', 's', 'e', 's', 's', 'e', 's', '\n',
        'o', 'b', 's', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'o', 'b', 's', 'e', 's', 's', 'i', 'o', 'n', '\n',
        'o', 'b', 's', 'e', 's', 's', 'i', 'o', 'n', 'a', 'l', '\n',
        'o', 'b', 's', 'e', 's', 's', 'i', 'o', 'n', 's', '\n',
        'o', 'b', 's', 'e', 's', 's', 'i', 'v', 'e', '\n',
        'o', 'b', 's', 'e', 's', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'o', 'b', 's', 'e', 's', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'o', 'b', 's', 'i', 'd', 'i', 'a', 'n', '\n',
        'o', 'b', 's', 'o', 'l', 'e', 's', 'c', 'e', 'n', 'c', 'e', '\n',
        'o', 'b', 's', 'o', 'l', 'e', 's', 'c', 'e', 'n', 't', '\n',
        'o', 'b', 's', 'o', 'l', 'e', 't', 'e', '\n',
        'o', 'b', 's', 't', 'a', 'c', 'l', 'e', '\n',
        'o', 'b', 's', 't', 'a', 'c', 'l', 'e', 's', '\n',
        'o', 'b', 's', 't', 'e', 't', 'r', 'i', 'c', '\n',
        'o', 'b', 's', 't', 'e', 't', 'r', 'i', 'c', 'i', 'a', 'n', '\n',
        'o', 'b', 's', 't', 'e', 't', 'r', 'i', 'c', 'i', 'a', 'n', 's', '\n',
        'o', 'b', 's', 't', 'e', 't', 'r', 'i', 'c', 's', '\n',
        'o', 'b', 's', 't', 'i', 'n', 'a', 'c', 'y', '\n',
        'o', 'b', 's', 't', 'i', 'n', 'a', 't', 'e', '\n',
        'o', 'b', 's', 't', 'i', 'n', 'a', 't', 'e', 'l', 'y', '\n',
        'o', 'b', 's', 't', 'r', 'e', 'p', 'e', 'r', 'o', 'u', 's', '\n',
        'o', 'b', 's', 't', 'r', 'u', 'c', 't', '\n',
        'o', 'b', 's', 't', 'r', 'u', 'c', 't', 'e', 'd', '\n',
        'o', 'b', 's', 't', 'r', 'u', 'c', 't', 'i', 'n', 'g', '\n',
        'o', 'b', 's', 't', 'r', 'u', 'c', 't', 'i', 'o', 'n', '\n',
        'o', 'b', 's', 't', 'r', 'u', 'c', 't', 'i', 'o', 'n', 'i', 's', 'm', '\n',
        'o', 'b', 's', 't', 'r', 'u', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'o', 'b', 's', 't', 'r', 'u', 'c', 't', 'i', 'v', 'e', '\n',
        'o', 'b', 's', 't', 'r', 'u', 'c', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'o', 'b', 's', 't', 'r', 'u', 'c', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'o', 'b', 's', 't', 'r', 'u', 'c', 't', 's', '\n',
        'o', 'b', 't', 'a', 'i', 'n', '\n',
        'o', 'b', 't', 'a', 'i', 'n', 'a', 'b', 'l', 'e', '\n',
        'o', 'b', 't', 'a', 'i', 'n', 'e', 'd', '\n',
        'o', 'b', 't', 'a', 'i', 'n', 'i', 'n', 'g', '\n',
        'o', 'b', 't', 'a', 'i', 'n', 's', '\n',
        'o', 'b', 't', 'r', 'u', 'd', 'e', '\n',
        'o', 'b', 't', 'r', 'u', 'd', 'e', 'd', '\n',
        'o', 'b', 't', 'r', 'u', 'd', 'i', 'n', 'g', '\n',
        'o', 'b', 't', 'r', 'u', 's', 'i', 'v', 'e', '\n',
        'o', 'b', 't', 'r', 'u', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'o', 'b', 't', 'u', 's', 'e', '\n',
        'o', 'b', 't', 'u', 's', 'e', 'l', 'y', '\n',
        'o', 'b', 't', 'u', 's', 'e', 'n', 'e', 's', 's', '\n',
        'o', 'b', 'v', 'e', 'r', 's', 'e', '\n',
        'o', 'b', 'v', 'i', 'a', 't', 'e', '\n',
        'o', 'b', 'v', 'i', 'a', 't', 'e', 'd', '\n',
        'o', 'b', 'v', 'i', 'a', 't', 'e', 's', '\n',
        'o', 'b', 'v', 'i', 'a', 't', 'i', 'n', 'g', '\n',
        'o', 'b', 'v', 'i', 'o', 'u', 's', '\n',
        'o', 'b', 'v', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'o', 'b', 'v', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'o', 'c', 'c', 'a', 's', 'i', 'o', 'n', '\n',
        'o', 'c', 'c', 'a', 's', 'i', 'o', 'n', 'a', 'l', '\n',
        'o', 'c', 'c', 'a', 's', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'o', 'c', 'c', 'a', 's', 'i', 'o', 'n', 'e', 'd', '\n',
        'o', 'c', 'c', 'a', 's', 'i', 'o', 'n', 'i', 'n', 'g', '\n',
        'o', 'c', 'c', 'a', 's', 'i', 'o', 'n', 's', '\n',
        'o', 'c', 'c', 'i', 'd', 'e', 'n', 't', '\n',
        'o', 'c', 'c', 'i', 'd', 'e', 'n', 't', 'a', 'l', '\n',
        'o', 'c', 'c', 'i', 'p', 'i', 't', 'a', 'l', '\n',
        'o', 'c', 'c', 'l', 'u', 'd', 'e', 'd', '\n',
        'o', 'c', 'c', 'l', 'u', 'd', 'e', 's', '\n',
        'o', 'c', 'c', 'l', 'u', 's', 'i', 'o', 'n', '\n',
        'o', 'c', 'c', 'u', 'l', 't', '\n',
        'o', 'c', 'c', 'u', 'l', 't', 'i', 's', 'm', '\n',
        'o', 'c', 'c', 'u', 'l', 't', 's', '\n',
        'o', 'c', 'c', 'u', 'p', 'a', 'n', 'c', 'i', 'e', 's', '\n',
        'o', 'c', 'c', 'u', 'p', 'a', 'n', 'c', 'y', '\n',
        'o', 'c', 'c', 'u', 'p', 'a', 'n', 't', '\n',
        'o', 'c', 'c', 'u', 'p', 'a', 'n', 't', 's', '\n',
        'o', 'c', 'c', 'u', 'p', 'a', 't', 'i', 'o', 'n', '\n',
        'o', 'c', 'c', 'u', 'p', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'o', 'c', 'c', 'u', 'p', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'o', 'c', 'c', 'u', 'p', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'o', 'c', 'c', 'u', 'p', 'i', 'e', 'd', '\n',
        'o', 'c', 'c', 'u', 'p', 'i', 'e', 'r', '\n',
        'o', 'c', 'c', 'u', 'p', 'i', 'e', 'r', 's', '\n',
        'o', 'c', 'c', 'u', 'p', 'i', 'e', 's', '\n',
        'o', 'c', 'c', 'u', 'p', 'y', '\n',
        'o', 'c', 'c', 'u', 'p', 'y', 'i', 'n', 'g', '\n',
        'o', 'c', 'c', 'u', 'r', '\n',
        'o', 'c', 'c', 'u', 'r', 'r', 'e', 'd', '\n',
        'o', 'c', 'c', 'u', 'r', 'r', 'e', 'n', 'c', 'e', '\n',
        'o', 'c', 'c', 'u', 'r', 'r', 'e', 'n', 'c', 'e', 's', '\n',
        'o', 'c', 'c', 'u', 'r', 'r', 'i', 'n', 'g', '\n',
        'o', 'c', 'c', 'u', 'r', 's', '\n',
        'o', 'c', 'e', 'a', 'n', '\n',
        'o', 'c', 'e', 'a', 'n', 'i', 'c', '\n',
        'o', 'c', 'e', 'a', 'n', 'o', 'g', 'r', 'a', 'p', 'h', 'e', 'r', '\n',
        'o', 'c', 'e', 'a', 'n', 'o', 'g', 'r', 'a', 'p', 'h', 'e', 'r', 's', '\n',
        'o', 'c', 'e', 'a', 'n', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', '\n',
        'o', 'c', 'e', 'a', 'n', 'o', 'g', 'r', 'a', 'p', 'h', 'y', '\n',
        'o', 'c', 'e', 'a', 'n', 's', '\n',
        'o', 'c', 'e', 'l', 'o', 't', '\n',
        'o', 'c', 'e', 'l', 'o', 't', 's', '\n',
        'o', 'c', 'h', 'r', 'e', '\n',
        'o', 'c', 'h', 'r', 'e', 's', '\n',
        'o', 'c', 't', 'a', 'g', 'o', 'n', '\n',
        'o', 'c', 't', 'a', 'g', 'o', 'n', 'a', 'l', '\n',
        'o', 'c', 't', 'a', 'g', 'o', 'n', 's', '\n',
        'o', 'c', 't', 'a', 'h', 'e', 'd', 'r', 'a', 'l', '\n',
        'o', 'c', 't', 'a', 'h', 'e', 'd', 'r', 'o', 'n', '\n',
        'o', 'c', 't', 'a', 'l', '\n',
        'o', 'c', 't', 'a', 'n', 'e', '\n',
        'o', 'c', 't', 'a', 'n', 'e', 's', '\n',
        'o', 'c', 't', 'a', 'n', 't', '\n',
        'o', 'c', 't', 'a', 'v', 'e', '\n',
        'o', 'c', 't', 'a', 'v', 'e', 's', '\n',
        'o', 'c', 't', 'a', 'v', 'o', '\n',
        'o', 'c', 't', 'e', 't', '\n',
        'o', 'c', 't', 'e', 't', 's', '\n',
        'o', 'c', 't', 'o', 'b', 'e', 'r', '\n',
        'o', 'c', 't', 'o', 'g', 'e', 'n', 'a', 'r', 'i', 'a', 'n', '\n',
        'o', 'c', 't', 'o', 'g', 'e', 'n', 'a', 'r', 'i', 'a', 'n', 's', '\n',
        'o', 'c', 't', 'o', 'p', 'u', 's', '\n',
        'o', 'c', 't', 'o', 'p', 'u', 's', 'e', 's', '\n',
        'o', 'c', 'u', 'l', 'a', 'r', '\n',
        'o', 'c', 'u', 'l', 'i', 's', 't', '\n',
        'o', 'd', 'd', '\n',
        'o', 'd', 'd', 'e', 'r', '\n',
        'o', 'd', 'd', 'e', 's', 't', '\n',
        'o', 'd', 'd', 'i', 't', 'i', 'e', 's', '\n',
        'o', 'd', 'd', 'i', 't', 'y', '\n',
        'o', 'd', 'd', 'j', 'o', 'b', '\n',
        'o', 'd', 'd', 'l', 'y', '\n',
        'o', 'd', 'd', 'm', 'e', 'n', 't', '\n',
        'o', 'd', 'd', 'm', 'e', 'n', 't', 's', '\n',
        'o', 'd', 'd', 'n', 'e', 's', 's', '\n',
        'o', 'd', 'd', 's', '\n',
        'o', 'd', 'e', '\n',
        'o', 'd', 'e', 's', '\n',
        'o', 'd', 'i', 'n', '\n',
        'o', 'd', 'i', 'o', 'u', 's', '\n',
        'o', 'd', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'o', 'd', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'o', 'd', 'i', 'u', 'm', '\n',
        'o', 'd', 'i', 'u', 'm', 's', '\n',
        'o', 'd', 'o', 'm', 'e', 't', 'e', 'r', '\n',
        'o', 'd', 'o', 'r', 'i', 'f', 'e', 'r', 'o', 'u', 's', '\n',
        'o', 'd', 'o', 'r', 'o', 'u', 's', '\n',
        'o', 'd', 'o', 'u', 'r', '\n',
        'o', 'd', 'o', 'u', 'r', 'l', 'e', 's', 's', '\n',
        'o', 'd', 'o', 'u', 'r', 's', '\n',
        'o', 'd', 'y', 's', 's', 'e', 'y', '\n',
        'o', 'e', 'd', 'e', 'm', 'a', '\n',
        'o', 'e', 'd', 'i', 'p', 'u', 's', '\n',
        'o', 'e', 's', 'o', 'p', 'h', 'a', 'g', 'u', 's', '\n',
        'o', 'e', 's', 't', 'r', 'o', 'g', 'e', 'n', '\n',
        'o', 'e', 's', 't', 'r', 'o', 'g', 'e', 'n', 's', '\n',
        'o', 'e', 's', 't', 'r', 'u', 's', '\n',
        'o', 'e', 'u', 'v', 'r', 'e', '\n',
        'o', 'e', 'u', 'v', 'r', 'e', 's', '\n',
        'o', 'f', '\n',
        'o', 'f', 'f', '\n',
        'o', 'f', 'f', 'a', 'l', '\n',
        'o', 'f', 'f', 'b', 'e', 'a', 't', '\n',
        'o', 'f', 'f', 'c', 'u', 't', '\n',
        'o', 'f', 'f', 'c', 'u', 't', 's', '\n',
        'o', 'f', 'f', 'e', 'n', 'c', 'e', '\n',
        'o', 'f', 'f', 'e', 'n', 'c', 'e', 's', '\n',
        'o', 'f', 'f', 'e', 'n', 'd', '\n',
        'o', 'f', 'f', 'e', 'n', 'd', 'e', 'd', '\n',
        'o', 'f', 'f', 'e', 'n', 'd', 'e', 'r', '\n',
        'o', 'f', 'f', 'e', 'n', 'd', 'e', 'r', 's', '\n',
        'o', 'f', 'f', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'o', 'f', 'f', 'e', 'n', 'd', 's', '\n',
        'o', 'f', 'f', 'e', 'n', 's', 'i', 'v', 'e', '\n',
        'o', 'f', 'f', 'e', 'n', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'o', 'f', 'f', 'e', 'n', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'o', 'f', 'f', 'e', 'n', 's', 'i', 'v', 'e', 's', '\n',
        'o', 'f', 'f', 'e', 'r', '\n',
        'o', 'f', 'f', 'e', 'r', 'e', 'd', '\n',
        'o', 'f', 'f', 'e', 'r', 'i', 'n', 'g', '\n',
        'o', 'f', 'f', 'e', 'r', 'i', 'n', 'g', 's', '\n',
        'o', 'f', 'f', 'e', 'r', 's', '\n',
        'o', 'f', 'f', 'e', 'r', 't', 'o', 'r', 'y', '\n',
        'o', 'f', 'f', 'h', 'a', 'n', 'd', '\n',
        'o', 'f', 'f', 'i', 'c', 'e', '\n',
        'o', 'f', 'f', 'i', 'c', 'e', 'r', '\n',
        'o', 'f', 'f', 'i', 'c', 'e', 'r', 's', '\n',
        'o', 'f', 'f', 'i', 'c', 'e', 'r', 's', 'h', 'i', 'p', '\n',
        'o', 'f', 'f', 'i', 'c', 'e', 'r', 's', 'h', 'i', 'p', 's', '\n',
        'o', 'f', 'f', 'i', 'c', 'e', 's', '\n',
        'o', 'f', 'f', 'i', 'c', 'i', 'a', 'l', '\n',
        'o', 'f', 'f', 'i', 'c', 'i', 'a', 'l', 'd', 'o', 'm', '\n',
        'o', 'f', 'f', 'i', 'c', 'i', 'a', 'l', 'l', 'y', '\n',
        'o', 'f', 'f', 'i', 'c', 'i', 'a', 'l', 'n', 'e', 's', 's', '\n',
        'o', 'f', 'f', 'i', 'c', 'i', 'a', 'l', 's', '\n',
        'o', 'f', 'f', 'i', 'c', 'i', 'a', 't', 'e', '\n',
        'o', 'f', 'f', 'i', 'c', 'i', 'a', 't', 'e', 'd', '\n',
        'o', 'f', 'f', 'i', 'c', 'i', 'a', 't', 'i', 'n', 'g', '\n',
        'o', 'f', 'f', 'i', 'c', 'i', 'o', 'u', 's', '\n',
        'o', 'f', 'f', 'i', 'c', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'o', 'f', 'f', 'i', 'c', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'o', 'f', 'f', 'p', 'r', 'i', 'n', 't', '\n',
        'o', 'f', 'f', 's', 'e', 't', '\n',
        'o', 'f', 'f', 's', 'h', 'o', 'o', 't', '\n',
        'o', 'f', 'f', 's', 'h', 'o', 'r', 'e', '\n',
        'o', 'f', 't', '\n',
        'o', 'f', 't', 'e', 'n', '\n',
        'o', 'g', 'l', 'e', '\n',
        'o', 'g', 'l', 'e', 'd', '\n',
        'o', 'g', 'l', 'i', 'n', 'g', '\n',
        'o', 'g', 'r', 'e', '\n',
        'o', 'g', 'r', 'e', 's', '\n',
        'o', 'g', 'r', 'i', 's', 'h', '\n',
        'o', 'h', '\n',
        'o', 'h', 'i', 'o', '\n',
        'o', 'h', 'm', '\n',
        'o', 'h', 'm', 'i', 'c', '\n',
        'o', 'h', 'm', 's', '\n',
        'o', 'i', 'l', '\n',
        'o', 'i', 'l', 'c', 'l', 'o', 't', 'h', '\n',
        'o', 'i', 'l', 'e', 'd', '\n',
        'o', 'i', 'l', 'e', 'r', '\n',
        'o', 'i', 'l', 'e', 'r', 's', '\n',
        'o', 'i', 'l', 'f', 'i', 'e', 'l', 'd', '\n',
        'o', 'i', 'l', 'f', 'i', 'e', 'l', 'd', 's', '\n',
        'o', 'i', 'l', 'i', 'e', 'r', '\n',
        'o', 'i', 'l', 'i', 'e', 's', 't', '\n',
        'o', 'i', 'l', 'i', 'n', 'e', 's', 's', '\n',
        'o', 'i', 'l', 'i', 'n', 'g', '\n',
        'o', 'i', 'l', 'm', 'a', 'n', '\n',
        'o', 'i', 'l', 'm', 'e', 'n', '\n',
        'o', 'i', 'l', 'r', 'i', 'g', '\n',
        'o', 'i', 'l', 's', '\n',
        'o', 'i', 'l', 'y', '\n',
        'o', 'i', 'n', 'k', '\n',
        'o', 'i', 'n', 'k', 'e', 'd', '\n',
        'o', 'i', 'n', 'k', 's', '\n',
        'o', 'i', 'n', 't', 'm', 'e', 'n', 't', '\n',
        'o', 'i', 'n', 't', 'm', 'e', 'n', 't', 's', '\n',
        'o', 'k', '\n',
        'o', 'k', 'a', 'p', 'i', '\n',
        'o', 'k', 'a', 'p', 'i', 's', '\n',
        'o', 'k', 'a', 'y', '\n',
        'o', 'k', 'a', 'y', 'e', 'd', '\n',
        'o', 'k', 'a', 'y', 's', '\n',
        'o', 'k', 'l', 'a', 'h', 'o', 'm', 'a', '\n',
        'o', 'l', 'd', '\n',
        'o', 'l', 'd', 'a', 'g', 'e', '\n',
        'o', 'l', 'd', 'e', 'n', '\n',
        'o', 'l', 'd', 'e', 'r', '\n',
        'o', 'l', 'd', 'e', 's', 't', '\n',
        'o', 'l', 'd', 'f', 'a', 's', 'h', 'i', 'o', 'n', 'e', 'd', '\n',
        'o', 'l', 'd', 'i', 'e', '\n',
        'o', 'l', 'd', 'i', 's', 'h', '\n',
        'o', 'l', 'd', 'm', 'a', 'i', 'd', 's', '\n',
        'o', 'l', 'd', 't', 'i', 'm', 'e', 'r', '\n',
        'o', 'l', 'd', 't', 'i', 'm', 'e', 'r', 's', '\n',
        'o', 'l', 'e', '\n',
        'o', 'l', 'e', 'a', 'n', 'd', 'e', 'r', '\n',
        'o', 'l', 'e', 'a', 'n', 'd', 'e', 'r', 's', '\n',
        'o', 'l', 'f', 'a', 'c', 't', 'o', 'r', 'y', '\n',
        'o', 'l', 'i', 'v', 'e', '\n',
        'o', 'l', 'i', 'v', 'e', 'o', 'i', 'l', '\n',
        'o', 'l', 'i', 'v', 'e', 'r', '\n',
        'o', 'l', 'i', 'v', 'e', 's', '\n',
        'o', 'l', 'm', '\n',
        'o', 'l', 'm', 's', '\n',
        'o', 'l', 'y', 'm', 'p', 'i', 'a', '\n',
        'o', 'l', 'y', 'm', 'p', 'i', 'a', 'd', '\n',
        'o', 'l', 'y', 'm', 'p', 'i', 'a', 'n', '\n',
        'o', 'l', 'y', 'm', 'p', 'i', 'c', '\n',
        'o', 'l', 'y', 'm', 'p', 'i', 'c', 's', '\n',
        'o', 'l', 'y', 'm', 'p', 'u', 's', '\n',
        'o', 'm', 'b', 'u', 'd', 's', 'm', 'a', 'n', '\n',
        'o', 'm', 'b', 'u', 'd', 's', 'm', 'e', 'n', '\n',
        'o', 'm', 'e', 'g', 'a', '\n',
        'o', 'm', 'e', 'l', 'e', 't', 't', 'e', '\n',
        'o', 'm', 'e', 'l', 'e', 't', 't', 'e', 's', '\n',
        'o', 'm', 'e', 'n', '\n',
        'o', 'm', 'e', 'n', 's', '\n',
        'o', 'm', 'i', 'n', 'o', 'u', 's', '\n',
        'o', 'm', 'i', 'n', 'o', 'u', 's', 'l', 'y', '\n',
        'o', 'm', 'i', 's', 's', 'i', 'o', 'n', '\n',
        'o', 'm', 'i', 's', 's', 'i', 'o', 'n', 's', '\n',
        'o', 'm', 'i', 't', '\n',
        'o', 'm', 'i', 't', 's', '\n',
        'o', 'm', 'i', 't', 't', 'e', 'd', '\n',
        'o', 'm', 'i', 't', 't', 'i', 'n', 'g', '\n',
        'o', 'm', 'n', 'i', 'b', 'u', 's', '\n',
        'o', 'm', 'n', 'i', 'b', 'u', 's', 'e', 's', '\n',
        'o', 'm', 'n', 'i', 'd', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'o', 'm', 'n', 'i', 'p', 'o', 't', 'e', 'n', 'c', 'e', '\n',
        'o', 'm', 'n', 'i', 'p', 'o', 't', 'e', 'n', 't', '\n',
        'o', 'm', 'n', 'i', 'p', 'r', 'e', 's', 'e', 'n', 'c', 'e', '\n',
        'o', 'm', 'n', 'i', 'p', 'r', 'e', 's', 'e', 'n', 't', '\n',
        'o', 'm', 'n', 'i', 's', 'c', 'i', 'e', 'n', 'c', 'e', '\n',
        'o', 'm', 'n', 'i', 's', 'c', 'i', 'e', 'n', 't', '\n',
        'o', 'm', 'n', 'i', 'v', 'o', 'r', 'e', '\n',
        'o', 'm', 'n', 'i', 'v', 'o', 'r', 'e', 's', '\n',
        'o', 'm', 'n', 'i', 'v', 'o', 'r', 'o', 'u', 's', '\n',
        'o', 'n', '\n',
        'o', 'n', 'a', 'g', 'e', 'r', '\n',
        'o', 'n', 'a', 'g', 'e', 'r', 's', '\n',
        'o', 'n', 'c', 'e', '\n',
        'o', 'n', 'e', '\n',
        'o', 'n', 'e', 'n', 'e', 's', 's', '\n',
        'o', 'n', 'e', 'r', '\n',
        'o', 'n', 'e', 'r', 'o', 'u', 's', '\n',
        'o', 'n', 'e', 's', '\n',
        'o', 'n', 'e', 's', 'e', 'l', 'f', '\n',
        'o', 'n', 'e', 's', 'i', 'd', 'e', 'd', '\n',
        'o', 'n', 'e', 's', 'i', 'd', 'e', 'd', 'l', 'y', '\n',
        'o', 'n', 'e', 's', 'i', 'd', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'o', 'n', 'g', 'o', 'i', 'n', 'g', '\n',
        'o', 'n', 'i', 'o', 'n', '\n',
        'o', 'n', 'i', 'o', 'n', 's', '\n',
        'o', 'n', 'l', 'o', 'o', 'k', 'e', 'r', '\n',
        'o', 'n', 'l', 'o', 'o', 'k', 'e', 'r', 's', '\n',
        'o', 'n', 'l', 'o', 'o', 'k', 'i', 'n', 'g', '\n',
        'o', 'n', 'l', 'y', '\n',
        'o', 'n', 'l', 'y', 'b', 'e', 'g', 'o', 't', 't', 'e', 'n', '\n',
        'o', 'n', 's', 'e', 't', '\n',
        'o', 'n', 's', 'h', 'o', 'r', 'e', '\n',
        'o', 'n', 's', 'l', 'a', 'u', 'g', 'h', 't', '\n',
        'o', 'n', 's', 'l', 'a', 'u', 'g', 'h', 't', 's', '\n',
        'o', 'n', 't', 'a', 'r', 'i', 'o', '\n',
        'o', 'n', 't', 'o', '\n',
        'o', 'n', 't', 'o', 'g', 'e', 'n', 'y', '\n',
        'o', 'n', 't', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'o', 'n', 't', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'o', 'n', 't', 'o', 'l', 'o', 'g', 'y', '\n',
        'o', 'n', 'u', 's', '\n',
        'o', 'n', 'u', 's', 'e', 's', '\n',
        'o', 'n', 'w', 'a', 'r', 'd', '\n',
        'o', 'n', 'w', 'a', 'r', 'd', 's', '\n',
        'o', 'n', 'y', 'x', '\n',
        'o', 'n', 'y', 'x', 'e', 's', '\n',
        'o', 'o', 'c', 'y', 't', 'e', 's', '\n',
        'o', 'o', 'd', 'l', 'e', 's', '\n',
        'o', 'o', 'h', '\n',
        'o', 'o', 'l', 'i', 't', 'i', 'c', '\n',
        'o', 'o', 'l', 'o', 'g', 'y', '\n',
        'o', 'o', 'm', 'p', 'a', 'h', '\n',
        'o', 'o', 'p', 's', '\n',
        'o', 'o', 'z', 'e', '\n',
        'o', 'o', 'z', 'e', 'd', '\n',
        'o', 'o', 'z', 'e', 's', '\n',
        'o', 'o', 'z', 'i', 'n', 'g', '\n',
        'o', 'o', 'z', 'y', '\n',
        'o', 'p', 'a', 'c', 'i', 't', 'y', '\n',
        'o', 'p', 'a', 'l', '\n',
        'o', 'p', 'a', 'l', 'e', 's', 'c', 'e', 'n', 't', '\n',
        'o', 'p', 'a', 'l', 's', '\n',
        'o', 'p', 'a', 'q', 'u', 'e', '\n',
        'o', 'p', 'e', 'n', '\n',
        'o', 'p', 'e', 'n', 'e', 'd', '\n',
        'o', 'p', 'e', 'n', 'e', 'r', '\n',
        'o', 'p', 'e', 'n', 'e', 'r', 's', '\n',
        'o', 'p', 'e', 'n', 'h', 'a', 'n', 'd', 'e', 'd', '\n',
        'o', 'p', 'e', 'n', 'h', 'a', 'n', 'd', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'o', 'p', 'e', 'n', 'h', 'e', 'a', 'r', 't', '\n',
        'o', 'p', 'e', 'n', 'h', 'e', 'a', 'r', 't', 'e', 'd', '\n',
        'o', 'p', 'e', 'n', 'i', 'n', 'g', '\n',
        'o', 'p', 'e', 'n', 'i', 'n', 'g', 's', '\n',
        'o', 'p', 'e', 'n', 'l', 'y', '\n',
        'o', 'p', 'e', 'n', 'm', 'i', 'n', 'd', 'e', 'd', '\n',
        'o', 'p', 'e', 'n', 'm', 'i', 'n', 'd', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'o', 'p', 'e', 'n', 'n', 'e', 's', 's', '\n',
        'o', 'p', 'e', 'n', 's', '\n',
        'o', 'p', 'e', 'r', 'a', '\n',
        'o', 'p', 'e', 'r', 'a', 'b', 'l', 'e', '\n',
        'o', 'p', 'e', 'r', 'a', 'n', 'd', '\n',
        'o', 'p', 'e', 'r', 'a', 'n', 'd', 's', '\n',
        'o', 'p', 'e', 'r', 'a', 's', '\n',
        'o', 'p', 'e', 'r', 'a', 't', 'e', '\n',
        'o', 'p', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'o', 'p', 'e', 'r', 'a', 't', 'e', 's', '\n',
        'o', 'p', 'e', 'r', 'a', 't', 'i', 'c', '\n',
        'o', 'p', 'e', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'o', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'o', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'o', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'o', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'o', 'p', 'e', 'r', 'a', 't', 'i', 'v', 'e', '\n',
        'o', 'p', 'e', 'r', 'a', 't', 'i', 'v', 'e', 's', '\n',
        'o', 'p', 'e', 'r', 'a', 't', 'o', 'r', '\n',
        'o', 'p', 'e', 'r', 'a', 't', 'o', 'r', 's', '\n',
        'o', 'p', 'e', 'r', 'c', 'u', 'l', 'u', 'm', '\n',
        'o', 'p', 'e', 'r', 'e', 't', 't', 'a', '\n',
        'o', 'p', 'e', 'r', 'e', 't', 't', 'a', 's', '\n',
        'o', 'p', 'h', 't', 'h', 'a', 'l', 'm', 'i', 'c', '\n',
        'o', 'p', 'h', 't', 'h', 'a', 'l', 'm', 'i', 'c', 's', '\n',
        'o', 'p', 'h', 't', 'h', 'a', 'l', 'm', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'o', 'p', 'h', 't', 'h', 'a', 'l', 'm', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'o', 'p', 'h', 't', 'h', 'a', 'l', 'm', 'o', 'l', 'o', 'g', 'y', '\n',
        'o', 'p', 'i', 'a', 't', 'e', '\n',
        'o', 'p', 'i', 'a', 't', 'e', 's', '\n',
        'o', 'p', 'i', 'n', 'e', '\n',
        'o', 'p', 'i', 'n', 'e', 'd', '\n',
        'o', 'p', 'i', 'n', 'e', 's', '\n',
        'o', 'p', 'i', 'n', 'i', 'n', 'g', '\n',
        'o', 'p', 'i', 'n', 'i', 'o', 'n', '\n',
        'o', 'p', 'i', 'n', 'i', 'o', 'n', 'a', 't', 'e', 'd', '\n',
        'o', 'p', 'i', 'n', 'i', 'o', 'n', 's', '\n',
        'o', 'p', 'i', 'o', 'i', 'd', '\n',
        'o', 'p', 'i', 'o', 'i', 'd', 's', '\n',
        'o', 'p', 'i', 'u', 'm', '\n',
        'o', 'p', 'o', 's', 's', 'u', 'm', '\n',
        'o', 'p', 'p', 'o', 'n', 'e', 'n', 't', '\n',
        'o', 'p', 'p', 'o', 'n', 'e', 'n', 't', 's', '\n',
        'o', 'p', 'p', 'o', 'r', 't', 'u', 'n', 'e', '\n',
        'o', 'p', 'p', 'o', 'r', 't', 'u', 'n', 'e', 'l', 'y', '\n',
        'o', 'p', 'p', 'o', 'r', 't', 'u', 'n', 'i', 's', 'm', '\n',
        'o', 'p', 'p', 'o', 'r', 't', 'u', 'n', 'i', 's', 't', '\n',
        'o', 'p', 'p', 'o', 'r', 't', 'u', 'n', 'i', 's', 't', 'i', 'c', '\n',
        'o', 'p', 'p', 'o', 'r', 't', 'u', 'n', 'i', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'o', 'p', 'p', 'o', 'r', 't', 'u', 'n', 'i', 's', 't', 's', '\n',
        'o', 'p', 'p', 'o', 'r', 't', 'u', 'n', 'i', 't', 'i', 'e', 's', '\n',
        'o', 'p', 'p', 'o', 'r', 't', 'u', 'n', 'i', 't', 'y', '\n',
        'o', 'p', 'p', 'o', 's', 'e', '\n',
        'o', 'p', 'p', 'o', 's', 'e', 'd', '\n',
        'o', 'p', 'p', 'o', 's', 'e', 's', '\n',
        'o', 'p', 'p', 'o', 's', 'i', 'n', 'g', '\n',
        'o', 'p', 'p', 'o', 's', 'i', 't', 'e', '\n',
        'o', 'p', 'p', 'o', 's', 'i', 't', 'e', 'l', 'y', '\n',
        'o', 'p', 'p', 'o', 's', 'i', 't', 'e', 's', '\n',
        'o', 'p', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', '\n',
        'o', 'p', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'o', 'p', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'o', 'p', 'p', 'r', 'e', 's', 's', '\n',
        'o', 'p', 'p', 'r', 'e', 's', 's', 'e', 'd', '\n',
        'o', 'p', 'p', 'r', 'e', 's', 's', 'e', 's', '\n',
        'o', 'p', 'p', 'r', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'o', 'p', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', '\n',
        'o', 'p', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 's', '\n',
        'o', 'p', 'p', 'r', 'e', 's', 's', 'i', 'v', 'e', '\n',
        'o', 'p', 'p', 'r', 'e', 's', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'o', 'p', 'p', 'r', 'e', 's', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'o', 'p', 'p', 'r', 'e', 's', 's', 'o', 'r', '\n',
        'o', 'p', 'p', 'r', 'e', 's', 's', 'o', 'r', 's', '\n',
        'o', 'p', 'p', 'r', 'o', 'b', 'r', 'i', 'o', 'u', 's', '\n',
        'o', 'p', 'p', 'r', 'o', 'b', 'r', 'i', 'u', 'm', '\n',
        'o', 'p', 't', '\n',
        'o', 'p', 't', 'e', 'd', '\n',
        'o', 'p', 't', 'i', 'c', '\n',
        'o', 'p', 't', 'i', 'c', 'a', 'l', '\n',
        'o', 'p', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'o', 'p', 't', 'i', 'c', 'i', 'a', 'n', '\n',
        'o', 'p', 't', 'i', 'c', 'i', 'a', 'n', 's', '\n',
        'o', 'p', 't', 'i', 'c', 's', '\n',
        'o', 'p', 't', 'i', 'm', 'a', '\n',
        'o', 'p', 't', 'i', 'm', 'a', 'l', '\n',
        'o', 'p', 't', 'i', 'm', 'a', 'l', 'i', 't', 'y', '\n',
        'o', 'p', 't', 'i', 'm', 'a', 'l', 'l', 'y', '\n',
        'o', 'p', 't', 'i', 'm', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'o', 'p', 't', 'i', 'm', 'i', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'o', 'p', 't', 'i', 'm', 'i', 's', 'e', '\n',
        'o', 'p', 't', 'i', 'm', 'i', 's', 'e', 'd', '\n',
        'o', 'p', 't', 'i', 'm', 'i', 's', 'e', 'r', '\n',
        'o', 'p', 't', 'i', 'm', 'i', 's', 'e', 'r', 's', '\n',
        'o', 'p', 't', 'i', 'm', 'i', 's', 'e', 's', '\n',
        'o', 'p', 't', 'i', 'm', 'i', 's', 'i', 'n', 'g', '\n',
        'o', 'p', 't', 'i', 'm', 'i', 's', 'm', '\n',
        'o', 'p', 't', 'i', 'm', 'i', 's', 't', '\n',
        'o', 'p', 't', 'i', 'm', 'i', 's', 't', 'i', 'c', '\n',
        'o', 'p', 't', 'i', 'm', 'i', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'o', 'p', 't', 'i', 'm', 'i', 's', 't', 's', '\n',
        'o', 'p', 't', 'i', 'm', 'u', 'm', '\n',
        'o', 'p', 't', 'i', 'n', 'g', '\n',
        'o', 'p', 't', 'i', 'o', 'n', '\n',
        'o', 'p', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'o', 'p', 't', 'i', 'o', 'n', 'a', 'l', 'i', 't', 'y', '\n',
        'o', 'p', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'o', 'p', 't', 'i', 'o', 'n', 's', '\n',
        'o', 'p', 't', 'o', 'e', 'l', 'e', 'c', 't', 'r', 'o', 'n', 'i', 'c', '\n',
        'o', 'p', 't', 's', '\n',
        'o', 'p', 'u', 'l', 'e', 'n', 'c', 'e', '\n',
        'o', 'p', 'u', 'l', 'e', 'n', 't', '\n',
        'o', 'p', 'u', 's', '\n',
        'o', 'p', 'u', 's', 'e', 's', '\n',
        'o', 'r', '\n',
        'o', 'r', 'a', 'c', 'l', 'e', '\n',
        'o', 'r', 'a', 'c', 'l', 'e', 's', '\n',
        'o', 'r', 'a', 'c', 'u', 'l', 'a', 'r', '\n',
        'o', 'r', 'a', 'l', '\n',
        'o', 'r', 'a', 'l', 'l', 'y', '\n',
        'o', 'r', 'a', 'n', 'g', '\n',
        'o', 'r', 'a', 'n', 'g', 'e', '\n',
        'o', 'r', 'a', 'n', 'g', 'e', 's', '\n',
        'o', 'r', 'a', 'n', 'g', 's', '\n',
        'o', 'r', 'a', 'n', 'g', 'u', 't', 'a', 'n', '\n',
        'o', 'r', 'a', 'n', 'g', 'u', 't', 'a', 'n', 's', '\n',
        'o', 'r', 'a', 't', 'e', '\n',
        'o', 'r', 'a', 't', 'e', 'd', '\n',
        'o', 'r', 'a', 't', 'e', 's', '\n',
        'o', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'o', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'o', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'o', 'r', 'a', 't', 'o', 'r', '\n',
        'o', 'r', 'a', 't', 'o', 'r', 'i', 'c', 'a', 'l', '\n',
        'o', 'r', 'a', 't', 'o', 'r', 'i', 'o', '\n',
        'o', 'r', 'a', 't', 'o', 'r', 's', '\n',
        'o', 'r', 'a', 't', 'o', 'r', 'y', '\n',
        'o', 'r', 'b', '\n',
        'o', 'r', 'b', 'i', 't', '\n',
        'o', 'r', 'b', 'i', 't', 'a', 'l', '\n',
        'o', 'r', 'b', 'i', 't', 'a', 'l', 's', '\n',
        'o', 'r', 'b', 'i', 't', 'e', 'd', '\n',
        'o', 'r', 'b', 'i', 't', 'e', 'r', '\n',
        'o', 'r', 'b', 'i', 't', 'i', 'n', 'g', '\n',
        'o', 'r', 'b', 'i', 't', 's', '\n',
        'o', 'r', 'b', 's', '\n',
        'o', 'r', 'c', 'a', '\n',
        'o', 'r', 'c', 'h', 'a', 'r', 'd', '\n',
        'o', 'r', 'c', 'h', 'a', 'r', 'd', 's', '\n',
        'o', 'r', 'c', 'h', 'e', 's', 't', 'r', 'a', '\n',
        'o', 'r', 'c', 'h', 'e', 's', 't', 'r', 'a', 'l', '\n',
        'o', 'r', 'c', 'h', 'e', 's', 't', 'r', 'a', 's', '\n',
        'o', 'r', 'c', 'h', 'e', 's', 't', 'r', 'a', 't', 'e', '\n',
        'o', 'r', 'c', 'h', 'e', 's', 't', 'r', 'a', 't', 'e', 'd', '\n',
        'o', 'r', 'c', 'h', 'e', 's', 't', 'r', 'a', 't', 'e', 's', '\n',
        'o', 'r', 'c', 'h', 'e', 's', 't', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'o', 'r', 'c', 'h', 'e', 's', 't', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'o', 'r', 'c', 'h', 'e', 's', 't', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'o', 'r', 'c', 'h', 'e', 's', 't', 'r', 'a', 't', 'o', 'r', '\n',
        'o', 'r', 'c', 'h', 'i', 'd', '\n',
        'o', 'r', 'c', 'h', 'i', 'd', 's', '\n',
        'o', 'r', 'd', 'a', 'i', 'n', '\n',
        'o', 'r', 'd', 'a', 'i', 'n', 'e', 'd', '\n',
        'o', 'r', 'd', 'a', 'i', 'n', 'i', 'n', 'g', '\n',
        'o', 'r', 'd', 'a', 'i', 'n', 's', '\n',
        'o', 'r', 'd', 'e', 'a', 'l', '\n',
        'o', 'r', 'd', 'e', 'a', 'l', 's', '\n',
        'o', 'r', 'd', 'e', 'r', '\n',
        'o', 'r', 'd', 'e', 'r', 'e', 'd', '\n',
        'o', 'r', 'd', 'e', 'r', 'i', 'n', 'g', '\n',
        'o', 'r', 'd', 'e', 'r', 'i', 'n', 'g', 's', '\n',
        'o', 'r', 'd', 'e', 'r', 'l', 'e', 's', 's', '\n',
        'o', 'r', 'd', 'e', 'r', 'l', 'i', 'e', 's', '\n',
        'o', 'r', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 's', 's', '\n',
        'o', 'r', 'd', 'e', 'r', 'l', 'y', '\n',
        'o', 'r', 'd', 'e', 'r', 's', '\n',
        'o', 'r', 'd', 'i', 'n', 'a', 'l', '\n',
        'o', 'r', 'd', 'i', 'n', 'a', 'l', 's', '\n',
        'o', 'r', 'd', 'i', 'n', 'a', 'n', 'c', 'e', '\n',
        'o', 'r', 'd', 'i', 'n', 'a', 'n', 'c', 'e', 's', '\n',
        'o', 'r', 'd', 'i', 'n', 'a', 'n', 'd', 's', '\n',
        'o', 'r', 'd', 'i', 'n', 'a', 'r', 'i', 'l', 'y', '\n',
        'o', 'r', 'd', 'i', 'n', 'a', 'r', 'i', 'n', 'e', 's', 's', '\n',
        'o', 'r', 'd', 'i', 'n', 'a', 'r', 'y', '\n',
        'o', 'r', 'd', 'i', 'n', 'a', 't', 'e', '\n',
        'o', 'r', 'd', 'i', 'n', 'a', 't', 'e', 's', '\n',
        'o', 'r', 'd', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'o', 'r', 'd', 'i', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'o', 'r', 'd', 'n', 'a', 'n', 'c', 'e', '\n',
        'o', 'r', 'd', 'u', 'r', 'e', '\n',
        'o', 'r', 'e', '\n',
        'o', 'r', 'e', 's', '\n',
        'o', 'r', 'g', 'a', 'n', '\n',
        'o', 'r', 'g', 'a', 'n', 'e', 'l', 'l', 'e', 's', '\n',
        'o', 'r', 'g', 'a', 'n', 'i', 'c', '\n',
        'o', 'r', 'g', 'a', 'n', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'o', 'r', 'g', 'a', 'n', 'i', 'c', 's', '\n',
        'o', 'r', 'g', 'a', 'n', 'i', 's', 'a', 'b', 'l', 'e', '\n',
        'o', 'r', 'g', 'a', 'n', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'o', 'r', 'g', 'a', 'n', 'i', 's', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'o', 'r', 'g', 'a', 'n', 'i', 's', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'o', 'r', 'g', 'a', 'n', 'i', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'o', 'r', 'g', 'a', 'n', 'i', 's', 'e', '\n',
        'o', 'r', 'g', 'a', 'n', 'i', 's', 'e', 'd', '\n',
        'o', 'r', 'g', 'a', 'n', 'i', 's', 'e', 'r', '\n',
        'o', 'r', 'g', 'a', 'n', 'i', 's', 'e', 'r', 's', '\n',
        'o', 'r', 'g', 'a', 'n', 'i', 's', 'e', 's', '\n',
        'o', 'r', 'g', 'a', 'n', 'i', 's', 'i', 'n', 'g', '\n',
        'o', 'r', 'g', 'a', 'n', 'i', 's', 'm', '\n',
        'o', 'r', 'g', 'a', 'n', 'i', 's', 'm', 's', '\n',
        'o', 'r', 'g', 'a', 'n', 'i', 's', 't', '\n',
        'o', 'r', 'g', 'a', 'n', 'i', 's', 't', 's', '\n',
        'o', 'r', 'g', 'a', 'n', 's', '\n',
        'o', 'r', 'g', 'a', 'n', 'z', 'a', '\n',
        'o', 'r', 'g', 'i', 'e', 's', '\n',
        'o', 'r', 'g', 'y', '\n',
        'o', 'r', 'i', 'e', 'n', 't', '\n',
        'o', 'r', 'i', 'e', 'n', 't', 'a', 'b', 'l', 'e', '\n',
        'o', 'r', 'i', 'e', 'n', 't', 'a', 'l', '\n',
        'o', 'r', 'i', 'e', 'n', 't', 'a', 'l', 'i', 's', 'm', '\n',
        'o', 'r', 'i', 'e', 'n', 't', 'a', 'l', 's', '\n',
        'o', 'r', 'i', 'e', 'n', 't', 'a', 't', 'e', '\n',
        'o', 'r', 'i', 'e', 'n', 't', 'a', 't', 'e', 'd', '\n',
        'o', 'r', 'i', 'e', 'n', 't', 'a', 't', 'e', 's', '\n',
        'o', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'o', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'o', 'r', 'i', 'e', 'n', 't', 'e', 'd', '\n',
        'o', 'r', 'i', 'e', 'n', 't', 'e', 'e', 'r', 'i', 'n', 'g', '\n',
        'o', 'r', 'i', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'o', 'r', 'i', 'f', 'i', 'c', 'e', '\n',
        'o', 'r', 'i', 'f', 'i', 'c', 'e', 's', '\n',
        'o', 'r', 'i', 'g', 'a', 'm', 'i', '\n',
        'o', 'r', 'i', 'g', 'i', 'n', '\n',
        'o', 'r', 'i', 'g', 'i', 'n', 'a', 'l', '\n',
        'o', 'r', 'i', 'g', 'i', 'n', 'a', 'l', 'i', 't', 'y', '\n',
        'o', 'r', 'i', 'g', 'i', 'n', 'a', 'l', 'l', 'y', '\n',
        'o', 'r', 'i', 'g', 'i', 'n', 'a', 'l', 's', '\n',
        'o', 'r', 'i', 'g', 'i', 'n', 'a', 't', 'e', '\n',
        'o', 'r', 'i', 'g', 'i', 'n', 'a', 't', 'e', 'd', '\n',
        'o', 'r', 'i', 'g', 'i', 'n', 'a', 't', 'e', 's', '\n',
        'o', 'r', 'i', 'g', 'i', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'o', 'r', 'i', 'g', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'o', 'r', 'i', 'g', 'i', 'n', 'a', 't', 'o', 'r', '\n',
        'o', 'r', 'i', 'g', 'i', 'n', 'a', 't', 'o', 'r', 's', '\n',
        'o', 'r', 'i', 'g', 'i', 'n', 's', '\n',
        'o', 'r', 'i', 'm', 'u', 'l', 's', 'i', 'o', 'n', '\n',
        'o', 'r', 'n', 'a', 'm', 'e', 'n', 't', '\n',
        'o', 'r', 'n', 'a', 'm', 'e', 'n', 't', 'a', 'l', '\n',
        'o', 'r', 'n', 'a', 'm', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'o', 'r', 'n', 'a', 'm', 'e', 'n', 't', 'e', 'd', '\n',
        'o', 'r', 'n', 'a', 'm', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'o', 'r', 'n', 'a', 'm', 'e', 'n', 't', 's', '\n',
        'o', 'r', 'n', 'a', 't', 'e', '\n',
        'o', 'r', 'n', 'a', 't', 'e', 'l', 'y', '\n',
        'o', 'r', 'n', 'i', 't', 'h', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'o', 'r', 'n', 'i', 't', 'h', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'o', 'r', 'n', 'i', 't', 'h', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'o', 'r', 'n', 'i', 't', 'h', 'o', 'l', 'o', 'g', 'y', '\n',
        'o', 'r', 'p', 'h', 'a', 'n', '\n',
        'o', 'r', 'p', 'h', 'a', 'n', 'a', 'g', 'e', '\n',
        'o', 'r', 'p', 'h', 'a', 'n', 'a', 'g', 'e', 's', '\n',
        'o', 'r', 'p', 'h', 'a', 'n', 'e', 'd', '\n',
        'o', 'r', 'p', 'h', 'a', 'n', 's', '\n',
        'o', 'r', 'p', 'h', 'e', 'u', 's', '\n',
        'o', 'r', 't', 'h', 'o', 'd', 'o', 'n', 't', 'i', 's', 't', '\n',
        'o', 'r', 't', 'h', 'o', 'd', 'o', 'x', '\n',
        'o', 'r', 't', 'h', 'o', 'd', 'o', 'x', 'i', 'e', 's', '\n',
        'o', 'r', 't', 'h', 'o', 'd', 'o', 'x', 'y', '\n',
        'o', 'r', 't', 'h', 'o', 'g', 'o', 'n', 'a', 'l', '\n',
        'o', 'r', 't', 'h', 'o', 'g', 'o', 'n', 'a', 'l', 'i', 't', 'y', '\n',
        'o', 'r', 't', 'h', 'o', 'g', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'o', 'r', 't', 'h', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', '\n',
        'o', 'r', 't', 'h', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', 'a', 'l', '\n',
        'o', 'r', 't', 'h', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'o', 'r', 't', 'h', 'o', 'g', 'r', 'a', 'p', 'h', 'y', '\n',
        'o', 'r', 't', 'h', 'o', 'n', 'o', 'r', 'm', 'a', 'l', '\n',
        'o', 'r', 't', 'h', 'o', 'p', 'a', 'e', 'd', 'i', 'c', '\n',
        'o', 'r', 't', 'h', 'o', 'p', 'a', 'e', 'd', 'i', 'c', 's', '\n',
        'o', 'r', 't', 'h', 'o', 'r', 'h', 'o', 'm', 'b', 'i', 'c', '\n',
        'o', 'r', 'y', 'x', 'e', 's', '\n',
        'o', 's', 'c', 'a', 'r', '\n',
        'o', 's', 'c', 'a', 'r', 's', '\n',
        'o', 's', 'c', 'i', 'l', 'l', 'a', 't', 'e', '\n',
        'o', 's', 'c', 'i', 'l', 'l', 'a', 't', 'e', 'd', '\n',
        'o', 's', 'c', 'i', 'l', 'l', 'a', 't', 'e', 's', '\n',
        'o', 's', 'c', 'i', 'l', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'o', 's', 'c', 'i', 'l', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'o', 's', 'c', 'i', 'l', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'o', 's', 'c', 'i', 'l', 'l', 'a', 't', 'o', 'r', '\n',
        'o', 's', 'c', 'i', 'l', 'l', 'a', 't', 'o', 'r', 's', '\n',
        'o', 's', 'c', 'i', 'l', 'l', 'a', 't', 'o', 'r', 'y', '\n',
        'o', 's', 'c', 'i', 'l', 'l', 'o', 's', 'c', 'o', 'p', 'e', '\n',
        'o', 's', 'c', 'i', 'l', 'l', 'o', 's', 'c', 'o', 'p', 'e', 's', '\n',
        'o', 's', 'i', 'r', 'i', 's', '\n',
        'o', 's', 'l', 'o', '\n',
        'o', 's', 'm', 'i', 'u', 'm', '\n',
        'o', 's', 'm', 'o', 's', 'i', 's', '\n',
        'o', 's', 'm', 'o', 't', 'i', 'c', '\n',
        'o', 's', 'p', 'r', 'e', 'y', '\n',
        'o', 's', 'p', 'r', 'e', 'y', 's', '\n',
        'o', 's', 's', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'o', 's', 's', 'i', 'f', 'i', 'e', 'd', '\n',
        'o', 's', 't', 'e', 'n', 's', 'i', 'b', 'l', 'e', '\n',
        'o', 's', 't', 'e', 'n', 's', 'i', 'b', 'l', 'y', '\n',
        'o', 's', 't', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'o', 's', 't', 'e', 'n', 't', 'a', 't', 'i', 'o', 'u', 's', '\n',
        'o', 's', 't', 'e', 'n', 't', 'a', 't', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'o', 's', 't', 'e', 'o', 'a', 'r', 't', 'h', 'r', 'i', 't', 'i', 's', '\n',
        'o', 's', 't', 'e', 'o', 'p', 'a', 't', 'h', '\n',
        'o', 's', 't', 'e', 'o', 'p', 'a', 't', 'h', 's', '\n',
        'o', 's', 't', 'e', 'o', 'p', 'a', 't', 'h', 'y', '\n',
        'o', 's', 't', 'e', 'o', 'p', 'o', 'r', 'o', 's', 'i', 's', '\n',
        'o', 's', 't', 'l', 'e', 'r', '\n',
        'o', 's', 't', 'l', 'e', 'r', 's', '\n',
        'o', 's', 't', 'r', 'a', 'c', 'i', 's', 'e', '\n',
        'o', 's', 't', 'r', 'a', 'c', 'i', 's', 'e', 'd', '\n',
        'o', 's', 't', 'r', 'a', 'c', 'i', 's', 'm', '\n',
        'o', 's', 't', 'r', 'i', 'c', 'h', '\n',
        'o', 's', 't', 'r', 'i', 'c', 'h', 'e', 's', '\n',
        'o', 't', 'h', 'e', 'r', '\n',
        'o', 't', 'h', 'e', 'r', 'n', 'e', 's', 's', '\n',
        'o', 't', 'h', 'e', 'r', 's', '\n',
        'o', 't', 'h', 'e', 'r', 'w', 'i', 's', 'e', '\n',
        'o', 't', 't', 'e', 'r', '\n',
        'o', 't', 't', 'e', 'r', 's', '\n',
        'o', 't', 't', 'o', 'm', 'a', 'n', '\n',
        'o', 'u', 'c', 'h', '\n',
        'o', 'u', 'g', 'h', 't', '\n',
        'o', 'u', 'n', 'c', 'e', '\n',
        'o', 'u', 'n', 'c', 'e', 's', '\n',
        'o', 'u', 'r', '\n',
        'o', 'u', 'r', 's', '\n',
        'o', 'u', 'r', 's', 'e', 'l', 'v', 'e', 's', '\n',
        'o', 'u', 's', 't', '\n',
        'o', 'u', 's', 't', 'e', 'd', '\n',
        'o', 'u', 's', 't', 'e', 'r', '\n',
        'o', 'u', 's', 't', 'i', 'n', 'g', '\n',
        'o', 'u', 's', 't', 's', '\n',
        'o', 'u', 't', '\n',
        'o', 'u', 't', 'a', 'g', 'e', '\n',
        'o', 'u', 't', 'a', 'g', 'e', 's', '\n',
        'o', 'u', 't', 'b', 'a', 'c', 'k', '\n',
        'o', 'u', 't', 'b', 'i', 'd', '\n',
        'o', 'u', 't', 'b', 'i', 'd', 's', '\n',
        'o', 'u', 't', 'b', 'o', 'a', 'r', 'd', '\n',
        'o', 'u', 't', 'b', 'o', 'u', 'n', 'd', '\n',
        'o', 'u', 't', 'b', 'r', 'e', 'a', 'k', '\n',
        'o', 'u', 't', 'b', 'r', 'e', 'a', 'k', 's', '\n',
        'o', 'u', 't', 'b', 'r', 'e', 'd', '\n',
        'o', 'u', 't', 'b', 'u', 'i', 'l', 'd', 'i', 'n', 'g', '\n',
        'o', 'u', 't', 'b', 'u', 'i', 'l', 'd', 'i', 'n', 'g', 's', '\n',
        'o', 'u', 't', 'b', 'u', 'r', 's', 't', '\n',
        'o', 'u', 't', 'b', 'u', 'r', 's', 't', 's', '\n',
        'o', 'u', 't', 'c', 'a', 'l', 'l', '\n',
        'o', 'u', 't', 'c', 'a', 's', 't', '\n',
        'o', 'u', 't', 'c', 'a', 's', 't', 's', '\n',
        'o', 'u', 't', 'c', 'l', 'a', 's', 's', 'e', 'd', '\n',
        'o', 'u', 't', 'c', 'o', 'm', 'e', '\n',
        'o', 'u', 't', 'c', 'o', 'm', 'e', 's', '\n',
        'o', 'u', 't', 'c', 'r', 'i', 'e', 's', '\n',
        'o', 'u', 't', 'c', 'r', 'o', 'p', '\n',
        'o', 'u', 't', 'c', 'r', 'o', 'p', 's', '\n',
        'o', 'u', 't', 'c', 'r', 'y', '\n',
        'o', 'u', 't', 'd', 'a', 't', 'e', 'd', '\n',
        'o', 'u', 't', 'd', 'i', 'd', '\n',
        'o', 'u', 't', 'd', 'o', '\n',
        'o', 'u', 't', 'd', 'o', 'e', 's', '\n',
        'o', 'u', 't', 'd', 'o', 'i', 'n', 'g', '\n',
        'o', 'u', 't', 'd', 'o', 'n', 'e', '\n',
        'o', 'u', 't', 'd', 'o', 'o', 'r', '\n',
        'o', 'u', 't', 'd', 'o', 'o', 'r', 's', '\n',
        'o', 'u', 't', 'e', 'r', '\n',
        'o', 'u', 't', 'e', 'r', 'm', 'o', 's', 't', '\n',
        'o', 'u', 't', 'f', 'a', 'c', 'e', '\n',
        'o', 'u', 't', 'f', 'a', 'l', 'l', '\n',
        'o', 'u', 't', 'f', 'a', 'l', 'l', 's', '\n',
        'o', 'u', 't', 'f', 'i', 'e', 'l', 'd', '\n',
        'o', 'u', 't', 'f', 'i', 't', '\n',
        'o', 'u', 't', 'f', 'i', 't', 's', '\n',
        'o', 'u', 't', 'f', 'i', 't', 't', 'e', 'r', 's', '\n',
        'o', 'u', 't', 'f', 'l', 'a', 'n', 'k', '\n',
        'o', 'u', 't', 'f', 'l', 'a', 'n', 'k', 'e', 'd', '\n',
        'o', 'u', 't', 'f', 'l', 'o', 'w', '\n',
        'o', 'u', 't', 'f', 'l', 'o', 'w', 's', '\n',
        'o', 'u', 't', 'f', 'o', 'x', '\n',
        'o', 'u', 't', 'f', 'o', 'x', 'e', 'd', '\n',
        'o', 'u', 't', 'f', 'o', 'x', 'e', 's', '\n',
        'o', 'u', 't', 'g', 'o', '\n',
        'o', 'u', 't', 'g', 'o', 'i', 'n', 'g', '\n',
        'o', 'u', 't', 'g', 'o', 'i', 'n', 'g', 's', '\n',
        'o', 'u', 't', 'g', 'r', 'e', 'w', '\n',
        'o', 'u', 't', 'g', 'r', 'o', 'w', '\n',
        'o', 'u', 't', 'g', 'r', 'o', 'w', 'i', 'n', 'g', '\n',
        'o', 'u', 't', 'g', 'r', 'o', 'w', 'n', '\n',
        'o', 'u', 't', 'g', 'r', 'o', 'w', 't', 'h', '\n',
        'o', 'u', 't', 'g', 'r', 'o', 'w', 't', 'h', 's', '\n',
        'o', 'u', 't', 'g', 'u', 'e', 's', 's', '\n',
        'o', 'u', 't', 'h', 'o', 'u', 's', 'e', '\n',
        'o', 'u', 't', 'h', 'o', 'u', 's', 'e', 's', '\n',
        'o', 'u', 't', 'i', 'n', 'g', '\n',
        'o', 'u', 't', 'i', 'n', 'g', 's', '\n',
        'o', 'u', 't', 'l', 'a', 'n', 'd', 'i', 's', 'h', '\n',
        'o', 'u', 't', 'l', 'a', 's', 't', '\n',
        'o', 'u', 't', 'l', 'a', 's', 't', 'e', 'd', '\n',
        'o', 'u', 't', 'l', 'a', 's', 't', 's', '\n',
        'o', 'u', 't', 'l', 'a', 'w', '\n',
        'o', 'u', 't', 'l', 'a', 'w', 'e', 'd', '\n',
        'o', 'u', 't', 'l', 'a', 'w', 'i', 'n', 'g', '\n',
        'o', 'u', 't', 'l', 'a', 'w', 'r', 'y', '\n',
        'o', 'u', 't', 'l', 'a', 'w', 's', '\n',
        'o', 'u', 't', 'l', 'a', 'y', '\n',
        'o', 'u', 't', 'l', 'a', 'y', 's', '\n',
        'o', 'u', 't', 'l', 'e', 't', '\n',
        'o', 'u', 't', 'l', 'e', 't', 's', '\n',
        'o', 'u', 't', 'l', 'i', 'e', 'r', '\n',
        'o', 'u', 't', 'l', 'i', 'e', 'r', 's', '\n',
        'o', 'u', 't', 'l', 'i', 'n', 'e', '\n',
        'o', 'u', 't', 'l', 'i', 'n', 'e', 'd', '\n',
        'o', 'u', 't', 'l', 'i', 'n', 'e', 's', '\n',
        'o', 'u', 't', 'l', 'i', 'n', 'i', 'n', 'g', '\n',
        'o', 'u', 't', 'l', 'i', 'v', 'e', '\n',
        'o', 'u', 't', 'l', 'i', 'v', 'e', 'd', '\n',
        'o', 'u', 't', 'l', 'i', 'v', 'e', 's', '\n',
        'o', 'u', 't', 'l', 'i', 'v', 'i', 'n', 'g', '\n',
        'o', 'u', 't', 'l', 'o', 'o', 'k', '\n',
        'o', 'u', 't', 'l', 'o', 'o', 'k', 's', '\n',
        'o', 'u', 't', 'l', 'y', 'i', 'n', 'g', '\n',
        'o', 'u', 't', 'm', 'a', 'n', 'o', 'e', 'u', 'v', 'r', 'e', '\n',
        'o', 'u', 't', 'm', 'a', 'n', 'o', 'e', 'u', 'v', 'r', 'e', 'd', '\n',
        'o', 'u', 't', 'm', 'o', 'd', 'e', 'd', '\n',
        'o', 'u', 't', 'm', 'o', 's', 't', '\n',
        'o', 'u', 't', 'n', 'u', 'm', 'b', 'e', 'r', '\n',
        'o', 'u', 't', 'n', 'u', 'm', 'b', 'e', 'r', 'e', 'd', '\n',
        'o', 'u', 't', 'n', 'u', 'm', 'b', 'e', 'r', 'i', 'n', 'g', '\n',
        'o', 'u', 't', 'n', 'u', 'm', 'b', 'e', 'r', 's', '\n',
        'o', 'u', 't', 'p', 'a', 'c', 'e', '\n',
        'o', 'u', 't', 'p', 'a', 'c', 'e', 'd', '\n',
        'o', 'u', 't', 'p', 'a', 'c', 'i', 'n', 'g', '\n',
        'o', 'u', 't', 'p', 'a', 't', 'i', 'e', 'n', 't', '\n',
        'o', 'u', 't', 'p', 'a', 't', 'i', 'e', 'n', 't', 's', '\n',
        'o', 'u', 't', 'p', 'e', 'r', 'f', 'o', 'r', 'm', '\n',
        'o', 'u', 't', 'p', 'e', 'r', 'f', 'o', 'r', 'm', 'e', 'd', '\n',
        'o', 'u', 't', 'p', 'e', 'r', 'f', 'o', 'r', 'm', 'i', 'n', 'g', '\n',
        'o', 'u', 't', 'p', 'e', 'r', 'f', 'o', 'r', 'm', 's', '\n',
        'o', 'u', 't', 'p', 'l', 'a', 'c', 'e', 'm', 'e', 'n', 't', '\n',
        'o', 'u', 't', 'p', 'l', 'a', 'y', '\n',
        'o', 'u', 't', 'p', 'l', 'a', 'y', 'e', 'd', '\n',
        'o', 'u', 't', 'p', 'o', 'i', 'n', 't', 'e', 'd', '\n',
        'o', 'u', 't', 'p', 'o', 'i', 'n', 't', 'i', 'n', 'g', '\n',
        'o', 'u', 't', 'p', 'o', 's', 't', '\n',
        'o', 'u', 't', 'p', 'o', 's', 't', 's', '\n',
        'o', 'u', 't', 'p', 'o', 'u', 'r', 'i', 'n', 'g', '\n',
        'o', 'u', 't', 'p', 'o', 'u', 'r', 'i', 'n', 'g', 's', '\n',
        'o', 'u', 't', 'p', 'u', 't', '\n',
        'o', 'u', 't', 'p', 'u', 't', 's', '\n',
        'o', 'u', 't', 'p', 'u', 't', 't', 'i', 'n', 'g', '\n',
        'o', 'u', 't', 'r', 'a', 'g', 'e', '\n',
        'o', 'u', 't', 'r', 'a', 'g', 'e', 'd', '\n',
        'o', 'u', 't', 'r', 'a', 'g', 'e', 'o', 'u', 's', '\n',
        'o', 'u', 't', 'r', 'a', 'g', 'e', 'o', 'u', 's', 'l', 'y', '\n',
        'o', 'u', 't', 'r', 'a', 'g', 'e', 's', '\n',
        'o', 'u', 't', 'r', 'a', 'g', 'i', 'n', 'g', '\n',
        'o', 'u', 't', 'r', 'a', 'n', '\n',
        'o', 'u', 't', 'r', 'a', 'n', 'k', '\n',
        'o', 'u', 't', 'r', 'e', 'a', 'c', 'h', '\n',
        'o', 'u', 't', 'r', 'i', 'd', 'e', '\n',
        'o', 'u', 't', 'r', 'i', 'd', 'e', 'r', '\n',
        'o', 'u', 't', 'r', 'i', 'd', 'e', 'r', 's', '\n',
        'o', 'u', 't', 'r', 'i', 'g', 'g', 'e', 'r', '\n',
        'o', 'u', 't', 'r', 'i', 'g', 'h', 't', '\n',
        'o', 'u', 't', 'r', 'u', 'n', '\n',
        'o', 'u', 't', 'r', 'u', 'n', 's', '\n',
        'o', 'u', 't', 's', '\n',
        'o', 'u', 't', 's', 'e', 'l', 'l', '\n',
        'o', 'u', 't', 's', 'e', 't', '\n',
        'o', 'u', 't', 's', 'e', 't', 's', '\n',
        'o', 'u', 't', 's', 'h', 'i', 'n', 'e', '\n',
        'o', 'u', 't', 's', 'h', 'i', 'n', 'e', 's', '\n',
        'o', 'u', 't', 's', 'h', 'i', 'n', 'i', 'n', 'g', '\n',
        'o', 'u', 't', 's', 'h', 'o', 'n', 'e', '\n',
        'o', 'u', 't', 's', 'i', 'd', 'e', '\n',
        'o', 'u', 't', 's', 'i', 'd', 'e', 'r', '\n',
        'o', 'u', 't', 's', 'i', 'd', 'e', 'r', 's', '\n',
        'o', 'u', 't', 's', 'i', 'd', 'e', 's', '\n',
        'o', 'u', 't', 's', 'i', 'z', 'e', '\n',
        'o', 'u', 't', 's', 'k', 'i', 'r', 't', 's', '\n',
        'o', 'u', 't', 's', 'm', 'a', 'r', 't', '\n',
        'o', 'u', 't', 's', 'o', 'l', 'd', '\n',
        'o', 'u', 't', 's', 'o', 'u', 'r', 'c', 'i', 'n', 'g', '\n',
        'o', 'u', 't', 's', 'p', 'a', 'n', '\n',
        'o', 'u', 't', 's', 'p', 'o', 'k', 'e', 'n', '\n',
        'o', 'u', 't', 's', 'p', 'o', 'k', 'e', 'n', 'l', 'y', '\n',
        'o', 'u', 't', 's', 'p', 'o', 'k', 'e', 'n', 'n', 'e', 's', 's', '\n',
        'o', 'u', 't', 's', 'p', 'r', 'e', 'a', 'd', '\n',
        'o', 'u', 't', 's', 't', 'a', 'n', 'd', 'i', 'n', 'g', '\n',
        'o', 'u', 't', 's', 't', 'a', 'n', 'd', 'i', 'n', 'g', 'l', 'y', '\n',
        'o', 'u', 't', 's', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'o', 'u', 't', 's', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'o', 'u', 't', 's', 't', 'a', 'y', '\n',
        'o', 'u', 't', 's', 't', 'a', 'y', 'e', 'd', '\n',
        'o', 'u', 't', 's', 't', 'e', 'p', '\n',
        'o', 'u', 't', 's', 't', 'r', 'e', 't', 'c', 'h', 'e', 'd', '\n',
        'o', 'u', 't', 's', 't', 'r', 'i', 'p', '\n',
        'o', 'u', 't', 's', 't', 'r', 'i', 'p', 'p', 'e', 'd', '\n',
        'o', 'u', 't', 's', 't', 'r', 'i', 'p', 'p', 'i', 'n', 'g', '\n',
        'o', 'u', 't', 's', 't', 'r', 'i', 'p', 's', '\n',
        'o', 'u', 't', 'v', 'o', 't', 'e', 'd', '\n',
        'o', 'u', 't', 'w', 'a', 'r', 'd', '\n',
        'o', 'u', 't', 'w', 'a', 'r', 'd', 'l', 'y', '\n',
        'o', 'u', 't', 'w', 'a', 'r', 'd', 's', '\n',
        'o', 'u', 't', 'w', 'e', 'i', 'g', 'h', '\n',
        'o', 'u', 't', 'w', 'e', 'i', 'g', 'h', 'e', 'd', '\n',
        'o', 'u', 't', 'w', 'e', 'i', 'g', 'h', 'i', 'n', 'g', '\n',
        'o', 'u', 't', 'w', 'e', 'i', 'g', 'h', 's', '\n',
        'o', 'u', 't', 'w', 'i', 't', '\n',
        'o', 'u', 't', 'w', 'i', 't', 'h', '\n',
        'o', 'u', 't', 'w', 'i', 't', 's', '\n',
        'o', 'u', 't', 'w', 'i', 't', 't', 'e', 'd', '\n',
        'o', 'u', 't', 'w', 'i', 't', 't', 'i', 'n', 'g', '\n',
        'o', 'u', 't', 'w', 'o', 'r', 'k', '\n',
        'o', 'u', 't', 'w', 'o', 'r', 'k', 'i', 'n', 'g', '\n',
        'o', 'v', 'a', '\n',
        'o', 'v', 'a', 'l', '\n',
        'o', 'v', 'a', 'l', 's', '\n',
        'o', 'v', 'a', 'r', 'i', 'a', 'n', '\n',
        'o', 'v', 'a', 'r', 'i', 'e', 's', '\n',
        'o', 'v', 'a', 'r', 'y', '\n',
        'o', 'v', 'a', 't', 'e', '\n',
        'o', 'v', 'a', 't', 'i', 'o', 'n', '\n',
        'o', 'v', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'o', 'v', 'e', 'n', '\n',
        'o', 'v', 'e', 'n', 's', '\n',
        'o', 'v', 'e', 'r', '\n',
        'o', 'v', 'e', 'r', 'a', 'c', 't', '\n',
        'o', 'v', 'e', 'r', 'a', 'c', 't', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'a', 'c', 't', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'a', 'c', 't', 'i', 'v', 'e', '\n',
        'o', 'v', 'e', 'r', 'a', 'c', 't', 's', '\n',
        'o', 'v', 'e', 'r', 'a', 'l', 'l', '\n',
        'o', 'v', 'e', 'r', 'a', 'l', 'l', 'o', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'o', 'v', 'e', 'r', 'a', 'l', 'l', 's', '\n',
        'o', 'v', 'e', 'r', 'a', 'm', 'b', 'i', 't', 'i', 'o', 'u', 's', '\n',
        'o', 'v', 'e', 'r', 'a', 'n', 'x', 'i', 'o', 'u', 's', '\n',
        'o', 'v', 'e', 'r', 'a', 't', 'e', '\n',
        'o', 'v', 'e', 'r', 'b', 'e', 'a', 'r', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'b', 'o', 'a', 'r', 'd', '\n',
        'o', 'v', 'e', 'r', 'b', 'u', 'r', 'd', 'e', 'n', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'c', 'a', 'm', 'e', '\n',
        'o', 'v', 'e', 'r', 'c', 'a', 'p', 'a', 'c', 'i', 't', 'y', '\n',
        'o', 'v', 'e', 'r', 'c', 'a', 's', 't', '\n',
        'o', 'v', 'e', 'r', 'c', 'h', 'a', 'r', 'g', 'e', '\n',
        'o', 'v', 'e', 'r', 'c', 'h', 'a', 'r', 'g', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'c', 'h', 'a', 'r', 'g', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'c', 'o', 'a', 't', '\n',
        'o', 'v', 'e', 'r', 'c', 'o', 'a', 't', 's', '\n',
        'o', 'v', 'e', 'r', 'c', 'o', 'm', 'e', '\n',
        'o', 'v', 'e', 'r', 'c', 'o', 'm', 'e', 's', '\n',
        'o', 'v', 'e', 'r', 'c', 'o', 'm', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'c', 'o', 'm', 'm', 'i', 't', 'm', 'e', 'n', 't', '\n',
        'o', 'v', 'e', 'r', 'c', 'o', 'm', 'm', 'i', 't', 'm', 'e', 'n', 't', 's', '\n',
        'o', 'v', 'e', 'r', 'c', 'o', 'm', 'p', 'e', 'n', 's', 'a', 't', 'e', '\n',
        'o', 'v', 'e', 'r', 'c', 'o', 'm', 'p', 'l', 'e', 'x', 'i', 't', 'y', '\n',
        'o', 'v', 'e', 'r', 'c', 'o', 'm', 'p', 'l', 'i', 'c', 'a', 't', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'c', 'o', 'n', 'f', 'i', 'd', 'e', 'n', 't', '\n',
        'o', 'v', 'e', 'r', 'c', 'o', 'o', 'k', '\n',
        'o', 'v', 'e', 'r', 'c', 'o', 'o', 'k', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'c', 'r', 'o', 'w', 'd', '\n',
        'o', 'v', 'e', 'r', 'c', 'r', 'o', 'w', 'd', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'c', 'r', 'o', 'w', 'd', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'd', 'e', 't', 'e', 'r', 'm', 'i', 'n', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'd', 'i', 'd', '\n',
        'o', 'v', 'e', 'r', 'd', 'o', '\n',
        'o', 'v', 'e', 'r', 'd', 'o', 'e', 's', '\n',
        'o', 'v', 'e', 'r', 'd', 'o', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'd', 'o', 'n', 'e', '\n',
        'o', 'v', 'e', 'r', 'd', 'o', 's', 'e', '\n',
        'o', 'v', 'e', 'r', 'd', 'o', 's', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'd', 'o', 's', 'e', 's', '\n',
        'o', 'v', 'e', 'r', 'd', 'o', 's', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'd', 'r', 'a', 'f', 't', '\n',
        'o', 'v', 'e', 'r', 'd', 'r', 'a', 'f', 't', 's', '\n',
        'o', 'v', 'e', 'r', 'd', 'r', 'a', 'm', 'a', 't', 'i', 'c', '\n',
        'o', 'v', 'e', 'r', 'd', 'r', 'a', 'w', '\n',
        'o', 'v', 'e', 'r', 'd', 'r', 'a', 'w', 'n', '\n',
        'o', 'v', 'e', 'r', 'd', 'r', 'e', 's', 's', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'd', 'r', 'i', 'v', 'e', '\n',
        'o', 'v', 'e', 'r', 'd', 'u', 'b', 'b', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'd', 'u', 'e', '\n',
        'o', 'v', 'e', 'r', 'e', 'a', 't', '\n',
        'o', 'v', 'e', 'r', 'e', 'a', 't', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'e', 'a', 't', 's', '\n',
        'o', 'v', 'e', 'r', 'e', 'm', 'o', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'o', 'v', 'e', 'r', 'e', 'm', 'p', 'h', 'a', 's', 'i', 's', '\n',
        'o', 'v', 'e', 'r', 'e', 'm', 'p', 'h', 'a', 's', 'i', 's', 'e', '\n',
        'o', 'v', 'e', 'r', 'e', 'm', 'p', 'h', 'a', 's', 'i', 's', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'e', 'n', 't', 'h', 'u', 's', 'i', 'a', 's', 't', 'i', 'c', '\n',
        'o', 'v', 'e', 'r', 'e', 's', 't', 'i', 'm', 'a', 't', 'e', '\n',
        'o', 'v', 'e', 'r', 'e', 's', 't', 'i', 'm', 'a', 't', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'e', 's', 't', 'i', 'm', 'a', 't', 'e', 's', '\n',
        'o', 'v', 'e', 'r', 'e', 's', 't', 'i', 'm', 'a', 't', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'e', 's', 't', 'i', 'm', 'a', 't', 'i', 'o', 'n', '\n',
        'o', 'v', 'e', 'r', 'e', 'x', 'p', 'o', 's', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'e', 'x', 'p', 'o', 's', 'u', 'r', 'e', '\n',
        'o', 'v', 'e', 'r', 'e', 'x', 't', 'e', 'n', 'd', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'f', 'a', 'm', 'i', 'l', 'i', 'a', 'r', 'i', 't', 'y', '\n',
        'o', 'v', 'e', 'r', 'f', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'f', 'e', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'f', 'e', 'e', 'd', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'f', 'i', 'l', 'l', '\n',
        'o', 'v', 'e', 'r', 'f', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'f', 'l', 'o', 'w', '\n',
        'o', 'v', 'e', 'r', 'f', 'l', 'o', 'w', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'f', 'l', 'o', 'w', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'f', 'l', 'o', 'w', 'n', '\n',
        'o', 'v', 'e', 'r', 'f', 'l', 'o', 'w', 's', '\n',
        'o', 'v', 'e', 'r', 'f', 'l', 'y', '\n',
        'o', 'v', 'e', 'r', 'f', 'l', 'y', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'f', 'u', 'l', 'l', '\n',
        'o', 'v', 'e', 'r', 'g', 'e', 'n', 'e', 'r', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'g', 'e', 'n', 'e', 'r', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'g', 'r', 'a', 'z', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'g', 'r', 'o', 'u', 'n', 'd', '\n',
        'o', 'v', 'e', 'r', 'g', 'r', 'o', 'w', 'n', '\n',
        'o', 'v', 'e', 'r', 'g', 'r', 'o', 'w', 't', 'h', '\n',
        'o', 'v', 'e', 'r', 'h', 'a', 'n', 'd', '\n',
        'o', 'v', 'e', 'r', 'h', 'a', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'h', 'a', 'n', 'g', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'h', 'a', 'n', 'g', 's', '\n',
        'o', 'v', 'e', 'r', 'h', 'a', 's', 't', 'y', '\n',
        'o', 'v', 'e', 'r', 'h', 'a', 'u', 'l', '\n',
        'o', 'v', 'e', 'r', 'h', 'a', 'u', 'l', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'h', 'a', 'u', 'l', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'h', 'a', 'u', 'l', 's', '\n',
        'o', 'v', 'e', 'r', 'h', 'e', 'a', 'd', '\n',
        'o', 'v', 'e', 'r', 'h', 'e', 'a', 'd', 's', '\n',
        'o', 'v', 'e', 'r', 'h', 'e', 'a', 'r', '\n',
        'o', 'v', 'e', 'r', 'h', 'e', 'a', 'r', 'd', '\n',
        'o', 'v', 'e', 'r', 'h', 'e', 'a', 'r', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'h', 'e', 'a', 'r', 's', '\n',
        'o', 'v', 'e', 'r', 'h', 'e', 'a', 't', '\n',
        'o', 'v', 'e', 'r', 'h', 'e', 'a', 't', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'h', 'e', 'a', 't', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'h', 'u', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'i', 'n', 'c', 'r', 'e', 'd', 'u', 'l', 'o', 'u', 's', '\n',
        'o', 'v', 'e', 'r', 'i', 'n', 'd', 'u', 'l', 'g', 'e', 'n', 'c', 'e', '\n',
        'o', 'v', 'e', 'r', 'i', 'n', 'd', 'u', 'l', 'g', 'e', 'n', 't', '\n',
        'o', 'v', 'e', 'r', 'i', 'n', 'f', 'l', 'a', 't', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'j', 'o', 'y', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'k', 'i', 'l', 'l', '\n',
        'o', 'v', 'e', 'r', 'l', 'a', 'd', 'e', 'n', '\n',
        'o', 'v', 'e', 'r', 'l', 'a', 'i', 'd', '\n',
        'o', 'v', 'e', 'r', 'l', 'a', 'i', 'n', '\n',
        'o', 'v', 'e', 'r', 'l', 'a', 'n', 'd', '\n',
        'o', 'v', 'e', 'r', 'l', 'a', 'p', '\n',
        'o', 'v', 'e', 'r', 'l', 'a', 'p', 'p', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'l', 'a', 'p', 'p', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'l', 'a', 'p', 's', '\n',
        'o', 'v', 'e', 'r', 'l', 'a', 'y', '\n',
        'o', 'v', 'e', 'r', 'l', 'a', 'y', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'l', 'a', 'y', 's', '\n',
        'o', 'v', 'e', 'r', 'l', 'e', 'a', 'f', '\n',
        'o', 'v', 'e', 'r', 'l', 'i', 'e', '\n',
        'o', 'v', 'e', 'r', 'l', 'i', 'e', 's', '\n',
        'o', 'v', 'e', 'r', 'l', 'o', 'a', 'd', '\n',
        'o', 'v', 'e', 'r', 'l', 'o', 'a', 'd', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'l', 'o', 'a', 'd', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'l', 'o', 'a', 'd', 's', '\n',
        'o', 'v', 'e', 'r', 'l', 'o', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'l', 'o', 'o', 'k', '\n',
        'o', 'v', 'e', 'r', 'l', 'o', 'o', 'k', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'l', 'o', 'o', 'k', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'l', 'o', 'o', 'k', 's', '\n',
        'o', 'v', 'e', 'r', 'l', 'o', 'r', 'd', '\n',
        'o', 'v', 'e', 'r', 'l', 'o', 'r', 'd', 's', '\n',
        'o', 'v', 'e', 'r', 'l', 'y', '\n',
        'o', 'v', 'e', 'r', 'l', 'y', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'm', 'a', 'n', 'n', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'm', 'a', 'n', 't', 'e', 'l', '\n',
        'o', 'v', 'e', 'r', 'm', 'a', 't', 'c', 'h', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'm', 'u', 'c', 'h', '\n',
        'o', 'v', 'e', 'r', 'n', 'i', 'g', 'h', 't', '\n',
        'o', 'v', 'e', 'r', 'o', 'p', 't', 'i', 'm', 'i', 's', 't', 'i', 'c', '\n',
        'o', 'v', 'e', 'r', 'p', 'a', 'i', 'd', '\n',
        'o', 'v', 'e', 'r', 'p', 'a', 's', 's', '\n',
        'o', 'v', 'e', 'r', 'p', 'a', 'y', '\n',
        'o', 'v', 'e', 'r', 'p', 'a', 'y', 'm', 'e', 'n', 't', '\n',
        'o', 'v', 'e', 'r', 'p', 'l', 'a', 'y', '\n',
        'o', 'v', 'e', 'r', 'p', 'l', 'a', 'y', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'p', 'l', 'a', 'y', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'p', 'o', 'p', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'p', 'o', 'p', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'o', 'v', 'e', 'r', 'p', 'o', 'p', 'u', 'l', 'o', 'u', 's', '\n',
        'o', 'v', 'e', 'r', 'p', 'o', 'w', 'e', 'r', '\n',
        'o', 'v', 'e', 'r', 'p', 'o', 'w', 'e', 'r', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'p', 'o', 'w', 'e', 'r', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'p', 'o', 'w', 'e', 'r', 'i', 'n', 'g', 'l', 'y', '\n',
        'o', 'v', 'e', 'r', 'p', 'o', 'w', 'e', 'r', 's', '\n',
        'o', 'v', 'e', 'r', 'p', 'r', 'e', 's', 's', 'u', 'r', 'e', '\n',
        'o', 'v', 'e', 'r', 'p', 'r', 'i', 'c', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'p', 'r', 'i', 'n', 't', '\n',
        'o', 'v', 'e', 'r', 'p', 'r', 'i', 'n', 't', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'p', 'r', 'i', 'n', 't', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'p', 'r', 'i', 'n', 't', 's', '\n',
        'o', 'v', 'e', 'r', 'p', 'r', 'o', 'd', 'u', 'c', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'p', 'r', 'o', 'd', 'u', 'c', 't', 'i', 'o', 'n', '\n',
        'o', 'v', 'e', 'r', 'q', 'u', 'a', 'l', 'i', 'f', 'i', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'r', 'a', 'n', '\n',
        'o', 'v', 'e', 'r', 'r', 'a', 't', 'e', '\n',
        'o', 'v', 'e', 'r', 'r', 'a', 't', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'r', 'e', 'a', 'c', 'h', '\n',
        'o', 'v', 'e', 'r', 'r', 'e', 'a', 'c', 'h', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'r', 'e', 'a', 'c', 'h', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'r', 'e', 'a', 'c', 't', '\n',
        'o', 'v', 'e', 'r', 'r', 'e', 'a', 'c', 't', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'r', 'e', 'a', 'c', 't', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'r', 'e', 'a', 'c', 't', 'i', 'o', 'n', '\n',
        'o', 'v', 'e', 'r', 'r', 'e', 'a', 'c', 't', 's', '\n',
        'o', 'v', 'e', 'r', 'r', 'e', 'p', 'r', 'e', 's', 'e', 'n', 't', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'r', 'i', 'd', 'd', 'e', 'n', '\n',
        'o', 'v', 'e', 'r', 'r', 'i', 'd', 'e', '\n',
        'o', 'v', 'e', 'r', 'r', 'i', 'd', 'e', 's', '\n',
        'o', 'v', 'e', 'r', 'r', 'i', 'd', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'r', 'i', 'p', 'e', '\n',
        'o', 'v', 'e', 'r', 'r', 'o', 'd', 'e', '\n',
        'o', 'v', 'e', 'r', 'r', 'u', 'l', 'e', '\n',
        'o', 'v', 'e', 'r', 'r', 'u', 'l', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'r', 'u', 'l', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'r', 'u', 'n', '\n',
        'o', 'v', 'e', 'r', 'r', 'u', 'n', 'n', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'r', 'u', 'n', 's', '\n',
        'o', 'v', 'e', 'r', 's', '\n',
        'o', 'v', 'e', 'r', 's', 'a', 'm', 'p', 'l', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 's', 'a', 'm', 'p', 'l', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 's', 'a', 'w', '\n',
        'o', 'v', 'e', 'r', 's', 'e', 'a', 's', '\n',
        'o', 'v', 'e', 'r', 's', 'e', 'e', '\n',
        'o', 'v', 'e', 'r', 's', 'e', 'e', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 's', 'e', 'e', 'n', '\n',
        'o', 'v', 'e', 'r', 's', 'e', 'e', 'r', '\n',
        'o', 'v', 'e', 'r', 's', 'e', 'e', 'r', 's', '\n',
        'o', 'v', 'e', 'r', 's', 'e', 'e', 's', '\n',
        'o', 'v', 'e', 'r', 's', 'e', 'n', 's', 'i', 't', 'i', 'v', 'e', '\n',
        'o', 'v', 'e', 'r', 's', 'e', 'n', 's', 'i', 't', 'i', 'v', 'i', 't', 'y', '\n',
        'o', 'v', 'e', 'r', 's', 'e', 'x', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 's', 'h', 'a', 'd', 'o', 'w', '\n',
        'o', 'v', 'e', 'r', 's', 'h', 'a', 'd', 'o', 'w', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 's', 'h', 'a', 'd', 'o', 'w', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 's', 'h', 'a', 'd', 'o', 'w', 's', '\n',
        'o', 'v', 'e', 'r', 's', 'h', 'o', 'o', 't', '\n',
        'o', 'v', 'e', 'r', 's', 'h', 'o', 'o', 't', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 's', 'h', 'o', 'o', 't', 's', '\n',
        'o', 'v', 'e', 'r', 's', 'h', 'o', 't', '\n',
        'o', 'v', 'e', 'r', 's', 'i', 'g', 'h', 't', '\n',
        'o', 'v', 'e', 'r', 's', 'i', 'g', 'h', 't', 's', '\n',
        'o', 'v', 'e', 'r', 's', 'i', 'm', 'p', 'l', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'o', 'v', 'e', 'r', 's', 'i', 'm', 'p', 'l', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'o', 'v', 'e', 'r', 's', 'i', 'm', 'p', 'l', 'i', 'f', 'i', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 's', 'i', 'm', 'p', 'l', 'i', 'f', 'i', 'e', 's', '\n',
        'o', 'v', 'e', 'r', 's', 'i', 'm', 'p', 'l', 'i', 'f', 'y', '\n',
        'o', 'v', 'e', 'r', 's', 'i', 'm', 'p', 'l', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 's', 'i', 'z', 'e', '\n',
        'o', 'v', 'e', 'r', 's', 'i', 'z', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 's', 'l', 'e', 'e', 'p', '\n',
        'o', 'v', 'e', 'r', 's', 'l', 'e', 'p', 't', '\n',
        'o', 'v', 'e', 'r', 's', 'p', 'e', 'n', 'd', '\n',
        'o', 'v', 'e', 'r', 's', 'p', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 's', 'p', 'e', 'n', 't', '\n',
        'o', 'v', 'e', 'r', 's', 'p', 'i', 'l', 'l', '\n',
        'o', 'v', 'e', 'r', 's', 't', 'a', 'f', 'f', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 's', 't', 'a', 't', 'e', '\n',
        'o', 'v', 'e', 'r', 's', 't', 'a', 't', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 's', 't', 'a', 't', 'e', 'm', 'e', 'n', 't', '\n',
        'o', 'v', 'e', 'r', 's', 't', 'a', 't', 'e', 's', '\n',
        'o', 'v', 'e', 'r', 's', 't', 'a', 't', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 's', 't', 'e', 'p', '\n',
        'o', 'v', 'e', 'r', 's', 't', 'e', 'p', 'p', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 's', 't', 'e', 'p', 'p', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 's', 't', 'e', 'p', 's', '\n',
        'o', 'v', 'e', 'r', 's', 't', 'o', 'c', 'k', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 's', 't', 'o', 'c', 'k', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 's', 't', 'r', 'e', 's', 's', '\n',
        'o', 'v', 'e', 'r', 's', 't', 'r', 'e', 's', 's', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 's', 't', 'r', 'e', 't', 'c', 'h', '\n',
        'o', 'v', 'e', 'r', 's', 't', 'r', 'e', 't', 'c', 'h', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 's', 't', 'r', 'u', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 's', 't', 'u', 'f', 'f', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 's', 'u', 'b', 's', 'c', 'r', 'i', 'b', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 's', 'u', 'p', 'p', 'l', 'y', '\n',
        'o', 'v', 'e', 'r', 't', '\n',
        'o', 'v', 'e', 'r', 't', 'a', 'k', 'e', '\n',
        'o', 'v', 'e', 'r', 't', 'a', 'k', 'e', 'n', '\n',
        'o', 'v', 'e', 'r', 't', 'a', 'k', 'e', 'r', '\n',
        'o', 'v', 'e', 'r', 't', 'a', 'k', 'e', 'r', 's', '\n',
        'o', 'v', 'e', 'r', 't', 'a', 'k', 'e', 's', '\n',
        'o', 'v', 'e', 'r', 't', 'a', 'k', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 't', 'a', 'x', '\n',
        'o', 'v', 'e', 'r', 't', 'h', 'e', 't', 'o', 'p', '\n',
        'o', 'v', 'e', 'r', 't', 'h', 'r', 'e', 'w', '\n',
        'o', 'v', 'e', 'r', 't', 'h', 'r', 'o', 'w', '\n',
        'o', 'v', 'e', 'r', 't', 'h', 'r', 'o', 'w', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 't', 'h', 'r', 'o', 'w', 'n', '\n',
        'o', 'v', 'e', 'r', 't', 'h', 'r', 'o', 'w', 's', '\n',
        'o', 'v', 'e', 'r', 't', 'i', 'g', 'h', 't', 'e', 'n', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 't', 'i', 'm', 'e', '\n',
        'o', 'v', 'e', 'r', 't', 'l', 'y', '\n',
        'o', 'v', 'e', 'r', 't', 'n', 'e', 's', 's', '\n',
        'o', 'v', 'e', 'r', 't', 'o', 'n', 'e', '\n',
        'o', 'v', 'e', 'r', 't', 'o', 'n', 'e', 's', '\n',
        'o', 'v', 'e', 'r', 't', 'o', 'o', 'k', '\n',
        'o', 'v', 'e', 'r', 't', 'o', 'p', 's', '\n',
        'o', 'v', 'e', 'r', 't', 'u', 'r', 'e', '\n',
        'o', 'v', 'e', 'r', 't', 'u', 'r', 'e', 's', '\n',
        'o', 'v', 'e', 'r', 't', 'u', 'r', 'n', '\n',
        'o', 'v', 'e', 'r', 't', 'u', 'r', 'n', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 't', 'u', 'r', 'n', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 't', 'u', 'r', 'n', 's', '\n',
        'o', 'v', 'e', 'r', 'u', 's', 'e', '\n',
        'o', 'v', 'e', 'r', 'u', 's', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'u', 's', 'e', 's', '\n',
        'o', 'v', 'e', 'r', 'v', 'a', 'l', 'u', 'e', '\n',
        'o', 'v', 'e', 'r', 'v', 'a', 'l', 'u', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'v', 'i', 'e', 'w', '\n',
        'o', 'v', 'e', 'r', 'v', 'i', 'e', 'w', 's', '\n',
        'o', 'v', 'e', 'r', 'w', 'e', 'e', 'n', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'w', 'e', 'i', 'g', 'h', 't', '\n',
        'o', 'v', 'e', 'r', 'w', 'h', 'e', 'l', 'm', '\n',
        'o', 'v', 'e', 'r', 'w', 'h', 'e', 'l', 'm', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'w', 'h', 'e', 'l', 'm', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'w', 'h', 'e', 'l', 'm', 'i', 'n', 'g', 'l', 'y', '\n',
        'o', 'v', 'e', 'r', 'w', 'h', 'e', 'l', 'm', 's', '\n',
        'o', 'v', 'e', 'r', 'w', 'i', 'n', 't', 'e', 'r', '\n',
        'o', 'v', 'e', 'r', 'w', 'i', 'n', 't', 'e', 'r', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'w', 'i', 'n', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'w', 'o', 'r', 'k', '\n',
        'o', 'v', 'e', 'r', 'w', 'o', 'r', 'k', 'e', 'd', '\n',
        'o', 'v', 'e', 'r', 'w', 'o', 'r', 'k', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'w', 'r', 'i', 't', 'e', '\n',
        'o', 'v', 'e', 'r', 'w', 'r', 'i', 't', 'e', 's', '\n',
        'o', 'v', 'e', 'r', 'w', 'r', 'i', 't', 'i', 'n', 'g', '\n',
        'o', 'v', 'e', 'r', 'w', 'r', 'i', 't', 't', 'e', 'n', '\n',
        'o', 'v', 'e', 'r', 'w', 'r', 'o', 't', 'e', '\n',
        'o', 'v', 'e', 'r', 'w', 'r', 'o', 'u', 'g', 'h', 't', '\n',
        'o', 'v', 'i', 'd', 'u', 'c', 't', '\n',
        'o', 'v', 'o', 'i', 'd', '\n',
        'o', 'v', 'u', 'l', 'a', 'r', '\n',
        'o', 'v', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'o', 'v', 'u', 'm', '\n',
        'o', 'w', '\n',
        'o', 'w', 'e', '\n',
        'o', 'w', 'e', 'd', '\n',
        'o', 'w', 'e', 's', '\n',
        'o', 'w', 'i', 'n', 'g', '\n',
        'o', 'w', 'l', '\n',
        'o', 'w', 'l', 'e', 't', '\n',
        'o', 'w', 'l', 'e', 't', 's', '\n',
        'o', 'w', 'l', 'i', 's', 'h', '\n',
        'o', 'w', 'l', 'i', 's', 'h', 'l', 'y', '\n',
        'o', 'w', 'l', 's', '\n',
        'o', 'w', 'n', '\n',
        'o', 'w', 'n', 'e', 'd', '\n',
        'o', 'w', 'n', 'e', 'r', '\n',
        'o', 'w', 'n', 'e', 'r', 's', '\n',
        'o', 'w', 'n', 'e', 'r', 's', 'h', 'i', 'p', '\n',
        'o', 'w', 'n', 'e', 'r', 's', 'h', 'i', 'p', 's', '\n',
        'o', 'w', 'n', 'i', 'n', 'g', '\n',
        'o', 'w', 'n', 's', '\n',
        'o', 'x', '\n',
        'o', 'x', 'a', 'l', 'a', 't', 'e', '\n',
        'o', 'x', 'a', 'l', 'i', 'c', '\n',
        'o', 'x', 'c', 'a', 'r', 't', '\n',
        'o', 'x', 'e', 'n', '\n',
        'o', 'x', 'f', 'o', 'r', 'd', '\n',
        'o', 'x', 'i', 'd', 'a', 'n', 't', '\n',
        'o', 'x', 'i', 'd', 'a', 'n', 't', 's', '\n',
        'o', 'x', 'i', 'd', 'a', 't', 'i', 'o', 'n', '\n',
        'o', 'x', 'i', 'd', 'e', '\n',
        'o', 'x', 'i', 'd', 'e', 's', '\n',
        'o', 'x', 'i', 'd', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'o', 'x', 'i', 'd', 'i', 's', 'e', '\n',
        'o', 'x', 'i', 'd', 'i', 's', 'e', 'd', '\n',
        'o', 'x', 'i', 'd', 'i', 's', 'e', 'r', '\n',
        'o', 'x', 'i', 'd', 'i', 's', 'i', 'n', 'g', '\n',
        'o', 'x', 't', 'a', 'i', 'l', '\n',
        'o', 'x', 't', 'a', 'i', 'l', 's', '\n',
        'o', 'x', 'y', 'g', 'e', 'n', '\n',
        'o', 'x', 'y', 'g', 'e', 'n', 'a', 't', 'e', 'd', '\n',
        'o', 'x', 'y', 'g', 'e', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'o', 'x', 'y', 'g', 'e', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'o', 'x', 'y', 'm', 'o', 'r', 'o', 'n', '\n',
        'o', 'y', 's', 't', 'e', 'r', '\n',
        'o', 'y', 's', 't', 'e', 'r', 's', '\n',
        'o', 'z', 'o', 'n', 'e', '\n',
        'o', 'z', 'o', 'n', 'e', 'f', 'r', 'i', 'e', 'n', 'd', 'l', 'y', '\n',
        'p', 'a', '\n',
        'p', 'a', 'c', 'e', '\n',
        'p', 'a', 'c', 'e', 'd', '\n',
        'p', 'a', 'c', 'e', 'm', 'a', 'k', 'e', 'r', '\n',
        'p', 'a', 'c', 'e', 'm', 'a', 'k', 'e', 'r', 's', '\n',
        'p', 'a', 'c', 'e', 'm', 'a', 'n', '\n',
        'p', 'a', 'c', 'e', 'm', 'e', 'n', '\n',
        'p', 'a', 'c', 'e', 'r', '\n',
        'p', 'a', 'c', 'e', 'r', 's', '\n',
        'p', 'a', 'c', 'e', 's', '\n',
        'p', 'a', 'c', 'e', 'y', '\n',
        'p', 'a', 'c', 'h', 'y', 'd', 'e', 'r', 'm', '\n',
        'p', 'a', 'c', 'i', 'f', 'i', 'c', '\n',
        'p', 'a', 'c', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'a', 'c', 'i', 'f', 'i', 'e', 'd', '\n',
        'p', 'a', 'c', 'i', 'f', 'i', 'e', 'r', '\n',
        'p', 'a', 'c', 'i', 'f', 'i', 'e', 's', '\n',
        'p', 'a', 'c', 'i', 'f', 'i', 's', 'm', '\n',
        'p', 'a', 'c', 'i', 'f', 'i', 's', 't', '\n',
        'p', 'a', 'c', 'i', 'f', 'i', 's', 't', 's', '\n',
        'p', 'a', 'c', 'i', 'f', 'y', '\n',
        'p', 'a', 'c', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'p', 'a', 'c', 'i', 'n', 'g', '\n',
        'p', 'a', 'c', 'k', '\n',
        'p', 'a', 'c', 'k', 'a', 'b', 'l', 'e', '\n',
        'p', 'a', 'c', 'k', 'a', 'g', 'e', '\n',
        'p', 'a', 'c', 'k', 'a', 'g', 'e', 'd', '\n',
        'p', 'a', 'c', 'k', 'a', 'g', 'e', 's', '\n',
        'p', 'a', 'c', 'k', 'a', 'g', 'i', 'n', 'g', '\n',
        'p', 'a', 'c', 'k', 'e', 'd', '\n',
        'p', 'a', 'c', 'k', 'e', 'r', '\n',
        'p', 'a', 'c', 'k', 'e', 'r', 's', '\n',
        'p', 'a', 'c', 'k', 'e', 't', '\n',
        'p', 'a', 'c', 'k', 'e', 't', 's', '\n',
        'p', 'a', 'c', 'k', 'h', 'o', 'r', 's', 'e', '\n',
        'p', 'a', 'c', 'k', 'i', 'n', 'g', '\n',
        'p', 'a', 'c', 'k', 'i', 'n', 'g', 's', '\n',
        'p', 'a', 'c', 'k', 's', '\n',
        'p', 'a', 'c', 't', '\n',
        'p', 'a', 'c', 't', 's', '\n',
        'p', 'a', 'd', '\n',
        'p', 'a', 'd', 'd', 'e', 'd', '\n',
        'p', 'a', 'd', 'd', 'i', 'n', 'g', '\n',
        'p', 'a', 'd', 'd', 'i', 'n', 'g', 's', '\n',
        'p', 'a', 'd', 'd', 'l', 'e', '\n',
        'p', 'a', 'd', 'd', 'l', 'e', 'd', '\n',
        'p', 'a', 'd', 'd', 'l', 'e', 'r', '\n',
        'p', 'a', 'd', 'd', 'l', 'e', 'r', 's', '\n',
        'p', 'a', 'd', 'd', 'l', 'e', 's', '\n',
        'p', 'a', 'd', 'd', 'l', 'i', 'n', 'g', '\n',
        'p', 'a', 'd', 'd', 'o', 'c', 'k', '\n',
        'p', 'a', 'd', 'd', 'o', 'c', 'k', 's', '\n',
        'p', 'a', 'd', 'd', 'y', '\n',
        'p', 'a', 'd', 'l', 'o', 'c', 'k', '\n',
        'p', 'a', 'd', 'l', 'o', 'c', 'k', 'e', 'd', '\n',
        'p', 'a', 'd', 'l', 'o', 'c', 'k', 'i', 'n', 'g', '\n',
        'p', 'a', 'd', 'l', 'o', 'c', 'k', 's', '\n',
        'p', 'a', 'd', 'r', 'e', '\n',
        'p', 'a', 'd', 'r', 'e', 's', '\n',
        'p', 'a', 'd', 's', '\n',
        'p', 'a', 'e', 'a', 'n', '\n',
        'p', 'a', 'e', 'a', 'n', 's', '\n',
        'p', 'a', 'e', 'd', 'i', 'a', 't', 'r', 'i', 'c', '\n',
        'p', 'a', 'e', 'd', 'i', 'a', 't', 'r', 'i', 'c', 'i', 'a', 'n', '\n',
        'p', 'a', 'e', 'd', 'i', 'a', 't', 'r', 'i', 'c', 'i', 'a', 'n', 's', '\n',
        'p', 'a', 'e', 'd', 'i', 'a', 't', 'r', 'i', 'c', 's', '\n',
        'p', 'a', 'e', 'd', 'o', 'p', 'h', 'i', 'l', 'e', '\n',
        'p', 'a', 'e', 'd', 'o', 'p', 'h', 'i', 'l', 'e', 's', '\n',
        'p', 'a', 'e', 'd', 'o', 'p', 'h', 'i', 'l', 'i', 'a', '\n',
        'p', 'a', 'e', 'l', 'l', 'a', '\n',
        'p', 'a', 'e', 'o', 'n', 'y', '\n',
        'p', 'a', 'g', 'a', 'n', '\n',
        'p', 'a', 'g', 'a', 'n', 'i', 's', 'm', '\n',
        'p', 'a', 'g', 'a', 'n', 's', '\n',
        'p', 'a', 'g', 'e', '\n',
        'p', 'a', 'g', 'e', 'a', 'n', 't', '\n',
        'p', 'a', 'g', 'e', 'a', 'n', 't', 'r', 'y', '\n',
        'p', 'a', 'g', 'e', 'a', 'n', 't', 's', '\n',
        'p', 'a', 'g', 'e', 'b', 'o', 'y', '\n',
        'p', 'a', 'g', 'e', 'd', '\n',
        'p', 'a', 'g', 'e', 'f', 'u', 'l', '\n',
        'p', 'a', 'g', 'e', 'r', '\n',
        'p', 'a', 'g', 'e', 'r', 's', '\n',
        'p', 'a', 'g', 'e', 's', '\n',
        'p', 'a', 'g', 'i', 'n', 'a', 'l', '\n',
        'p', 'a', 'g', 'i', 'n', 'a', 't', 'e', '\n',
        'p', 'a', 'g', 'i', 'n', 'a', 't', 'e', 'd', '\n',
        'p', 'a', 'g', 'i', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'p', 'a', 'g', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'a', 'g', 'i', 'n', 'g', '\n',
        'p', 'a', 'g', 'o', 'd', 'a', '\n',
        'p', 'a', 'g', 'o', 'd', 'a', 's', '\n',
        'p', 'a', 'i', 'd', '\n',
        'p', 'a', 'i', 'd', 'u', 'p', '\n',
        'p', 'a', 'i', 'l', '\n',
        'p', 'a', 'i', 'l', 's', '\n',
        'p', 'a', 'i', 'n', '\n',
        'p', 'a', 'i', 'n', 'e', 'd', '\n',
        'p', 'a', 'i', 'n', 'f', 'u', 'l', '\n',
        'p', 'a', 'i', 'n', 'f', 'u', 'l', 'l', 'y', '\n',
        'p', 'a', 'i', 'n', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'p', 'a', 'i', 'n', 'i', 'n', 'g', '\n',
        'p', 'a', 'i', 'n', 'k', 'i', 'l', 'l', 'e', 'r', '\n',
        'p', 'a', 'i', 'n', 'k', 'i', 'l', 'l', 'e', 'r', 's', '\n',
        'p', 'a', 'i', 'n', 'l', 'e', 's', 's', '\n',
        'p', 'a', 'i', 'n', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'p', 'a', 'i', 'n', 's', '\n',
        'p', 'a', 'i', 'n', 's', 't', 'a', 'k', 'i', 'n', 'g', '\n',
        'p', 'a', 'i', 'n', 's', 't', 'a', 'k', 'i', 'n', 'g', 'l', 'y', '\n',
        'p', 'a', 'i', 'n', 't', '\n',
        'p', 'a', 'i', 'n', 't', 'b', 'o', 'x', '\n',
        'p', 'a', 'i', 'n', 't', 'b', 'r', 'u', 's', 'h', '\n',
        'p', 'a', 'i', 'n', 't', 'e', 'd', '\n',
        'p', 'a', 'i', 'n', 't', 'e', 'r', '\n',
        'p', 'a', 'i', 'n', 't', 'e', 'r', 's', '\n',
        'p', 'a', 'i', 'n', 't', 'i', 'n', 'g', '\n',
        'p', 'a', 'i', 'n', 't', 'i', 'n', 'g', 's', '\n',
        'p', 'a', 'i', 'n', 't', 's', '\n',
        'p', 'a', 'i', 'n', 't', 'w', 'o', 'r', 'k', '\n',
        'p', 'a', 'i', 'r', '\n',
        'p', 'a', 'i', 'r', 'e', 'd', '\n',
        'p', 'a', 'i', 'r', 'i', 'n', 'g', '\n',
        'p', 'a', 'i', 'r', 'i', 'n', 'g', 's', '\n',
        'p', 'a', 'i', 'r', 's', '\n',
        'p', 'a', 'i', 'r', 'w', 'i', 's', 'e', '\n',
        'p', 'a', 'j', 'a', 'm', 'a', '\n',
        'p', 'a', 'j', 'a', 'm', 'a', 's', '\n',
        'p', 'a', 'k', 'i', 's', 't', 'a', 'n', '\n',
        'p', 'a', 'l', '\n',
        'p', 'a', 'l', 'a', 'c', 'e', '\n',
        'p', 'a', 'l', 'a', 'c', 'e', 's', '\n',
        'p', 'a', 'l', 'a', 'e', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', '\n',
        'p', 'a', 'l', 'a', 'e', 'o', 'l', 'i', 't', 'h', 'i', 'c', '\n',
        'p', 'a', 'l', 'a', 'e', 'o', 'n', 't', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'p', 'a', 'l', 'a', 'e', 'o', 'n', 't', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'p', 'a', 'l', 'a', 'e', 'o', 'n', 't', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'p', 'a', 'l', 'a', 'e', 'o', 'n', 't', 'o', 'l', 'o', 'g', 'y', '\n',
        'p', 'a', 'l', 'a', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'p', 'a', 'l', 'a', 't', 'a', 'b', 'l', 'e', '\n',
        'p', 'a', 'l', 'a', 't', 'a', 'l', '\n',
        'p', 'a', 'l', 'a', 't', 'e', '\n',
        'p', 'a', 'l', 'a', 't', 'e', 's', '\n',
        'p', 'a', 'l', 'a', 't', 'i', 'a', 'l', '\n',
        'p', 'a', 'l', 'a', 't', 'i', 'n', 'a', 't', 'e', '\n',
        'p', 'a', 'l', 'a', 't', 'i', 'n', 'e', '\n',
        'p', 'a', 'l', 'a', 'v', 'e', 'r', '\n',
        'p', 'a', 'l', 'e', '\n',
        'p', 'a', 'l', 'e', 'd', '\n',
        'p', 'a', 'l', 'e', 'f', 'a', 'c', 'e', '\n',
        'p', 'a', 'l', 'e', 'l', 'y', '\n',
        'p', 'a', 'l', 'e', 'n', 'e', 's', 's', '\n',
        'p', 'a', 'l', 'e', 'r', '\n',
        'p', 'a', 'l', 'e', 's', '\n',
        'p', 'a', 'l', 'e', 's', 't', '\n',
        'p', 'a', 'l', 'e', 't', 't', 'e', '\n',
        'p', 'a', 'l', 'e', 't', 't', 'e', 's', '\n',
        'p', 'a', 'l', 'i', 'm', 'p', 's', 'e', 's', 't', '\n',
        'p', 'a', 'l', 'i', 'n', 'd', 'r', 'o', 'm', 'e', '\n',
        'p', 'a', 'l', 'i', 'n', 'd', 'r', 'o', 'm', 'e', 's', '\n',
        'p', 'a', 'l', 'i', 'n', 'd', 'r', 'o', 'm', 'i', 'c', '\n',
        'p', 'a', 'l', 'i', 'n', 'g', '\n',
        'p', 'a', 'l', 'i', 's', 'a', 'd', 'e', '\n',
        'p', 'a', 'l', 'i', 's', 'a', 'd', 'e', 's', '\n',
        'p', 'a', 'l', 'l', '\n',
        'p', 'a', 'l', 'l', 'a', 'd', 'i', 'u', 'm', '\n',
        'p', 'a', 'l', 'l', 'b', 'e', 'a', 'r', 'e', 'r', 's', '\n',
        'p', 'a', 'l', 'l', 'e', 'd', '\n',
        'p', 'a', 'l', 'l', 'e', 't', '\n',
        'p', 'a', 'l', 'l', 'e', 't', 's', '\n',
        'p', 'a', 'l', 'l', 'i', 'a', 't', 'i', 'v', 'e', '\n',
        'p', 'a', 'l', 'l', 'i', 'a', 't', 'i', 'v', 'e', 's', '\n',
        'p', 'a', 'l', 'l', 'i', 'd', '\n',
        'p', 'a', 'l', 'l', 'm', 'a', 'l', 'l', '\n',
        'p', 'a', 'l', 'l', 'o', 'r', '\n',
        'p', 'a', 'l', 'l', 's', '\n',
        'p', 'a', 'l', 'm', '\n',
        'p', 'a', 'l', 'm', 'e', 'd', '\n',
        'p', 'a', 'l', 'm', 'i', 'n', 'g', '\n',
        'p', 'a', 'l', 'm', 'i', 's', 't', '\n',
        'p', 'a', 'l', 'm', 'i', 's', 't', 'r', 'y', '\n',
        'p', 'a', 'l', 'm', 's', '\n',
        'p', 'a', 'l', 'm', 't', 'o', 'p', '\n',
        'p', 'a', 'l', 'm', 't', 'o', 'p', 's', '\n',
        'p', 'a', 'l', 'm', 'y', '\n',
        'p', 'a', 'l', 'p', '\n',
        'p', 'a', 'l', 'p', 'a', 'b', 'l', 'e', '\n',
        'p', 'a', 'l', 'p', 'a', 'b', 'l', 'y', '\n',
        'p', 'a', 'l', 'p', 'a', 't', 'e', '\n',
        'p', 'a', 'l', 'p', 'a', 't', 'e', 'd', '\n',
        'p', 'a', 'l', 'p', 'a', 't', 'e', 's', '\n',
        'p', 'a', 'l', 'p', 'i', 't', 'a', 't', 'e', '\n',
        'p', 'a', 'l', 'p', 'i', 't', 'a', 't', 'e', 'd', '\n',
        'p', 'a', 'l', 'p', 'i', 't', 'a', 't', 'i', 'n', 'g', '\n',
        'p', 'a', 'l', 'p', 'i', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'a', 'l', 'p', 'i', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'a', 'l', 's', '\n',
        'p', 'a', 'l', 's', 'i', 'e', 'd', '\n',
        'p', 'a', 'l', 's', 'y', '\n',
        'p', 'a', 'l', 't', 'r', 'i', 'e', 'r', '\n',
        'p', 'a', 'l', 't', 'r', 'i', 'e', 's', 't', '\n',
        'p', 'a', 'l', 't', 'r', 'i', 'n', 'e', 's', 's', '\n',
        'p', 'a', 'l', 't', 'r', 'y', '\n',
        'p', 'a', 'l', 'u', 'd', 'a', 'l', '\n',
        'p', 'a', 'm', 'p', 'a', 's', '\n',
        'p', 'a', 'm', 'p', 'e', 'r', '\n',
        'p', 'a', 'm', 'p', 'e', 'r', 'e', 'd', '\n',
        'p', 'a', 'm', 'p', 'e', 'r', 'i', 'n', 'g', '\n',
        'p', 'a', 'm', 'p', 'e', 'r', 's', '\n',
        'p', 'a', 'm', 'p', 'h', 'l', 'e', 't', '\n',
        'p', 'a', 'm', 'p', 'h', 'l', 'e', 't', 'e', 'e', 'r', '\n',
        'p', 'a', 'm', 'p', 'h', 'l', 'e', 't', 'e', 'e', 'r', 's', '\n',
        'p', 'a', 'm', 'p', 'h', 'l', 'e', 't', 's', '\n',
        'p', 'a', 'n', '\n',
        'p', 'a', 'n', 'a', 'c', 'e', 'a', '\n',
        'p', 'a', 'n', 'a', 'c', 'e', 'a', 's', '\n',
        'p', 'a', 'n', 'a', 'c', 'h', 'e', '\n',
        'p', 'a', 'n', 'a', 'm', 'a', '\n',
        'p', 'a', 'n', 'c', 'a', 'k', 'e', '\n',
        'p', 'a', 'n', 'c', 'a', 'k', 'e', 'd', '\n',
        'p', 'a', 'n', 'c', 'a', 'k', 'e', 's', '\n',
        'p', 'a', 'n', 'c', 'r', 'e', 'a', 's', '\n',
        'p', 'a', 'n', 'c', 'r', 'e', 'a', 't', 'i', 'c', '\n',
        'p', 'a', 'n', 'd', 'a', '\n',
        'p', 'a', 'n', 'd', 'a', 's', '\n',
        'p', 'a', 'n', 'd', 'e', 'm', 'i', 'c', '\n',
        'p', 'a', 'n', 'd', 'e', 'm', 'i', 'c', 's', '\n',
        'p', 'a', 'n', 'd', 'e', 'm', 'o', 'n', 'i', 'u', 'm', '\n',
        'p', 'a', 'n', 'd', 'e', 'r', '\n',
        'p', 'a', 'n', 'd', 'e', 'r', 'i', 'n', 'g', '\n',
        'p', 'a', 'n', 'd', 'e', 'r', 's', '\n',
        'p', 'a', 'n', 'd', 'o', 'r', 'a', '\n',
        'p', 'a', 'n', 'e', '\n',
        'p', 'a', 'n', 'e', 'd', '\n',
        'p', 'a', 'n', 'e', 'l', '\n',
        'p', 'a', 'n', 'e', 'l', 'l', 'e', 'd', '\n',
        'p', 'a', 'n', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'p', 'a', 'n', 'e', 'l', 'l', 'i', 's', 't', '\n',
        'p', 'a', 'n', 'e', 'l', 'l', 'i', 's', 't', 's', '\n',
        'p', 'a', 'n', 'e', 'l', 's', '\n',
        'p', 'a', 'n', 'e', 's', '\n',
        'p', 'a', 'n', 'g', '\n',
        'p', 'a', 'n', 'g', 'a', '\n',
        'p', 'a', 'n', 'g', 'a', 's', '\n',
        'p', 'a', 'n', 'g', 'o', 'l', 'i', 'n', '\n',
        'p', 'a', 'n', 'g', 's', '\n',
        'p', 'a', 'n', 'i', 'c', '\n',
        'p', 'a', 'n', 'i', 'c', 'k', 'e', 'd', '\n',
        'p', 'a', 'n', 'i', 'c', 'k', 'i', 'n', 'g', '\n',
        'p', 'a', 'n', 'i', 'c', 'k', 'y', '\n',
        'p', 'a', 'n', 'i', 'c', 's', '\n',
        'p', 'a', 'n', 'i', 'c', 's', 't', 'r', 'i', 'c', 'k', 'e', 'n', '\n',
        'p', 'a', 'n', 'j', 'a', 'n', 'd', 'r', 'u', 'm', '\n',
        'p', 'a', 'n', 'n', 'e', 'd', '\n',
        'p', 'a', 'n', 'n', 'i', 'e', 'r', '\n',
        'p', 'a', 'n', 'n', 'i', 'e', 'r', 's', '\n',
        'p', 'a', 'n', 'n', 'i', 'n', 'g', '\n',
        'p', 'a', 'n', 'o', 'p', 'l', 'y', '\n',
        'p', 'a', 'n', 'o', 'r', 'a', 'm', 'a', '\n',
        'p', 'a', 'n', 'o', 'r', 'a', 'm', 'a', 's', '\n',
        'p', 'a', 'n', 'o', 'r', 'a', 'm', 'i', 'c', '\n',
        'p', 'a', 'n', 's', '\n',
        'p', 'a', 'n', 's', 'i', 'e', 's', '\n',
        'p', 'a', 'n', 's', 'y', '\n',
        'p', 'a', 'n', 't', '\n',
        'p', 'a', 'n', 't', 'a', 'l', 'o', 'o', 'n', 's', '\n',
        'p', 'a', 'n', 't', 'e', 'c', 'h', 'n', 'i', 'c', 'o', 'n', '\n',
        'p', 'a', 'n', 't', 'e', 'd', '\n',
        'p', 'a', 'n', 't', 'h', 'e', 'i', 's', 'm', '\n',
        'p', 'a', 'n', 't', 'h', 'e', 'i', 's', 't', '\n',
        'p', 'a', 'n', 't', 'h', 'e', 'i', 's', 't', 'i', 'c', '\n',
        'p', 'a', 'n', 't', 'h', 'e', 'o', 'n', '\n',
        'p', 'a', 'n', 't', 'h', 'e', 'r', '\n',
        'p', 'a', 'n', 't', 'h', 'e', 'r', 's', '\n',
        'p', 'a', 'n', 't', 'i', 'e', 's', '\n',
        'p', 'a', 'n', 't', 'i', 'l', 'e', '\n',
        'p', 'a', 'n', 't', 'i', 'l', 'e', 'd', '\n',
        'p', 'a', 'n', 't', 'i', 'l', 'e', 's', '\n',
        'p', 'a', 'n', 't', 'i', 'n', 'g', '\n',
        'p', 'a', 'n', 't', 'o', 'g', 'r', 'a', 'p', 'h', '\n',
        'p', 'a', 'n', 't', 'o', 'g', 'r', 'a', 'p', 'h', 's', '\n',
        'p', 'a', 'n', 't', 'o', 'm', 'i', 'm', 'e', '\n',
        'p', 'a', 'n', 't', 'o', 'm', 'i', 'm', 'e', 's', '\n',
        'p', 'a', 'n', 't', 'r', 'i', 'e', 's', '\n',
        'p', 'a', 'n', 't', 'r', 'y', '\n',
        'p', 'a', 'n', 't', 's', '\n',
        'p', 'a', 'n', 'z', 'e', 'r', '\n',
        'p', 'a', 'p', '\n',
        'p', 'a', 'p', 'a', '\n',
        'p', 'a', 'p', 'a', 'c', 'y', '\n',
        'p', 'a', 'p', 'a', 'l', '\n',
        'p', 'a', 'p', 'a', 'r', 'a', 'z', 'z', 'i', '\n',
        'p', 'a', 'p', 'a', 's', '\n',
        'p', 'a', 'p', 'a', 'w', '\n',
        'p', 'a', 'p', 'a', 'w', 's', '\n',
        'p', 'a', 'p', 'a', 'y', 'a', '\n',
        'p', 'a', 'p', 'e', 'r', '\n',
        'p', 'a', 'p', 'e', 'r', 'b', 'a', 'c', 'k', '\n',
        'p', 'a', 'p', 'e', 'r', 'b', 'a', 'c', 'k', 's', '\n',
        'p', 'a', 'p', 'e', 'r', 'e', 'd', '\n',
        'p', 'a', 'p', 'e', 'r', 'i', 'n', 'g', '\n',
        'p', 'a', 'p', 'e', 'r', 'l', 'e', 's', 's', '\n',
        'p', 'a', 'p', 'e', 'r', 's', '\n',
        'p', 'a', 'p', 'e', 'r', 't', 'h', 'i', 'n', '\n',
        'p', 'a', 'p', 'e', 'r', 'w', 'e', 'i', 'g', 'h', 't', '\n',
        'p', 'a', 'p', 'e', 'r', 'w', 'e', 'i', 'g', 'h', 't', 's', '\n',
        'p', 'a', 'p', 'e', 'r', 'w', 'o', 'r', 'k', '\n',
        'p', 'a', 'p', 'e', 'r', 'y', '\n',
        'p', 'a', 'p', 'i', 'l', 'l', 'a', '\n',
        'p', 'a', 'p', 'i', 's', 't', '\n',
        'p', 'a', 'p', 'p', 'y', '\n',
        'p', 'a', 'p', 'r', 'i', 'k', 'a', '\n',
        'p', 'a', 'p', 'u', 'a', '\n',
        'p', 'a', 'p', 'u', 'l', 'e', '\n',
        'p', 'a', 'p', 'y', 'r', 'i', '\n',
        'p', 'a', 'p', 'y', 'r', 'u', 's', '\n',
        'p', 'a', 'r', '\n',
        'p', 'a', 'r', 'a', 'b', 'l', 'e', '\n',
        'p', 'a', 'r', 'a', 'b', 'l', 'e', 's', '\n',
        'p', 'a', 'r', 'a', 'b', 'o', 'l', 'a', '\n',
        'p', 'a', 'r', 'a', 'b', 'o', 'l', 'a', 's', '\n',
        'p', 'a', 'r', 'a', 'b', 'o', 'l', 'i', 'c', '\n',
        'p', 'a', 'r', 'a', 'b', 'o', 'l', 'o', 'i', 'd', '\n',
        'p', 'a', 'r', 'a', 'b', 'o', 'l', 'o', 'i', 'd', 's', '\n',
        'p', 'a', 'r', 'a', 'c', 'e', 't', 'a', 'm', 'o', 'l', '\n',
        'p', 'a', 'r', 'a', 'c', 'h', 'u', 't', 'e', '\n',
        'p', 'a', 'r', 'a', 'c', 'h', 'u', 't', 'e', 'd', '\n',
        'p', 'a', 'r', 'a', 'c', 'h', 'u', 't', 'e', 's', '\n',
        'p', 'a', 'r', 'a', 'c', 'h', 'u', 't', 'i', 'n', 'g', '\n',
        'p', 'a', 'r', 'a', 'c', 'h', 'u', 't', 'i', 's', 't', '\n',
        'p', 'a', 'r', 'a', 'c', 'h', 'u', 't', 'i', 's', 't', 's', '\n',
        'p', 'a', 'r', 'a', 'd', 'e', '\n',
        'p', 'a', 'r', 'a', 'd', 'e', 'd', '\n',
        'p', 'a', 'r', 'a', 'd', 'e', 'r', '\n',
        'p', 'a', 'r', 'a', 'd', 'e', 's', '\n',
        'p', 'a', 'r', 'a', 'd', 'i', 'g', 'm', '\n',
        'p', 'a', 'r', 'a', 'd', 'i', 'g', 'm', 'a', 't', 'i', 'c', '\n',
        'p', 'a', 'r', 'a', 'd', 'i', 'g', 'm', 's', '\n',
        'p', 'a', 'r', 'a', 'd', 'i', 'n', 'g', '\n',
        'p', 'a', 'r', 'a', 'd', 'i', 's', 'e', '\n',
        'p', 'a', 'r', 'a', 'd', 'i', 's', 'e', 's', '\n',
        'p', 'a', 'r', 'a', 'd', 'o', 'x', '\n',
        'p', 'a', 'r', 'a', 'd', 'o', 'x', 'e', 's', '\n',
        'p', 'a', 'r', 'a', 'd', 'o', 'x', 'i', 'c', 'a', 'l', '\n',
        'p', 'a', 'r', 'a', 'd', 'o', 'x', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'p', 'a', 'r', 'a', 'f', 'f', 'i', 'n', '\n',
        'p', 'a', 'r', 'a', 'g', 'l', 'i', 'd', 'i', 'n', 'g', '\n',
        'p', 'a', 'r', 'a', 'g', 'o', 'n', '\n',
        'p', 'a', 'r', 'a', 'g', 'o', 'n', 's', '\n',
        'p', 'a', 'r', 'a', 'g', 'r', 'a', 'p', 'h', '\n',
        'p', 'a', 'r', 'a', 'g', 'r', 'a', 'p', 'h', 'i', 'n', 'g', '\n',
        'p', 'a', 'r', 'a', 'g', 'r', 'a', 'p', 'h', 's', '\n',
        'p', 'a', 'r', 'a', 'g', 'u', 'a', 'y', '\n',
        'p', 'a', 'r', 'a', 'k', 'e', 'e', 't', '\n',
        'p', 'a', 'r', 'a', 'k', 'e', 'e', 't', 's', '\n',
        'p', 'a', 'r', 'a', 'l', 'i', 'n', 'g', 'u', 'i', 's', 't', 'i', 'c', '\n',
        'p', 'a', 'r', 'a', 'l', 'l', 'a', 'x', '\n',
        'p', 'a', 'r', 'a', 'l', 'l', 'a', 'x', 'e', 's', '\n',
        'p', 'a', 'r', 'a', 'l', 'l', 'e', 'l', '\n',
        'p', 'a', 'r', 'a', 'l', 'l', 'e', 'l', 'e', 'd', '\n',
        'p', 'a', 'r', 'a', 'l', 'l', 'e', 'l', 'e', 'p', 'i', 'p', 'e', 'd', '\n',
        'p', 'a', 'r', 'a', 'l', 'l', 'e', 'l', 'i', 'n', 'g', '\n',
        'p', 'a', 'r', 'a', 'l', 'l', 'e', 'l', 'i', 's', 'm', '\n',
        'p', 'a', 'r', 'a', 'l', 'l', 'e', 'l', 'o', 'g', 'r', 'a', 'm', '\n',
        'p', 'a', 'r', 'a', 'l', 'l', 'e', 'l', 'o', 'g', 'r', 'a', 'm', 's', '\n',
        'p', 'a', 'r', 'a', 'l', 'l', 'e', 'l', 's', '\n',
        'p', 'a', 'r', 'a', 'l', 'y', 's', 'e', '\n',
        'p', 'a', 'r', 'a', 'l', 'y', 's', 'e', 'd', '\n',
        'p', 'a', 'r', 'a', 'l', 'y', 's', 'e', 's', '\n',
        'p', 'a', 'r', 'a', 'l', 'y', 's', 'i', 'n', 'g', '\n',
        'p', 'a', 'r', 'a', 'l', 'y', 's', 'i', 's', '\n',
        'p', 'a', 'r', 'a', 'l', 'y', 't', 'i', 'c', '\n',
        'p', 'a', 'r', 'a', 'l', 'y', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'p', 'a', 'r', 'a', 'm', 'a', 'g', 'n', 'e', 't', 'i', 'c', '\n',
        'p', 'a', 'r', 'a', 'm', 'a', 'g', 'n', 'e', 't', 'i', 's', 'm', '\n',
        'p', 'a', 'r', 'a', 'm', 'e', 'd', 'i', 'c', '\n',
        'p', 'a', 'r', 'a', 'm', 'e', 'd', 'i', 'c', 'a', 'l', '\n',
        'p', 'a', 'r', 'a', 'm', 'e', 'd', 'i', 'c', 's', '\n',
        'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', '\n',
        'p', 'a', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '\n',
        'p', 'a', 'r', 'a', 'm', 'e', 't', 'r', 'i', 'c', '\n',
        'p', 'a', 'r', 'a', 'm', 'e', 't', 'r', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'p', 'a', 'r', 'a', 'm', 'e', 't', 'r', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'a', 'r', 'a', 'm', 'e', 't', 'r', 'i', 's', 'e', '\n',
        'p', 'a', 'r', 'a', 'm', 'e', 't', 'r', 'i', 's', 'e', 'd', '\n',
        'p', 'a', 'r', 'a', 'm', 'e', 't', 'r', 'i', 's', 'e', 's', '\n',
        'p', 'a', 'r', 'a', 'm', 'i', 'l', 'i', 't', 'a', 'r', 'i', 'e', 's', '\n',
        'p', 'a', 'r', 'a', 'm', 'i', 'l', 'i', 't', 'a', 'r', 'y', '\n',
        'p', 'a', 'r', 'a', 'm', 'o', 'u', 'n', 't', '\n',
        'p', 'a', 'r', 'a', 'm', 'o', 'u', 'n', 't', 'c', 'y', '\n',
        'p', 'a', 'r', 'a', 'm', 'o', 'u', 'r', '\n',
        'p', 'a', 'r', 'a', 'n', 'o', 'i', 'a', '\n',
        'p', 'a', 'r', 'a', 'n', 'o', 'i', 'a', 'c', '\n',
        'p', 'a', 'r', 'a', 'n', 'o', 'i', 'a', 'c', 's', '\n',
        'p', 'a', 'r', 'a', 'n', 'o', 'i', 'd', '\n',
        'p', 'a', 'r', 'a', 'n', 'o', 'r', 'm', 'a', 'l', '\n',
        'p', 'a', 'r', 'a', 'p', 'e', 't', '\n',
        'p', 'a', 'r', 'a', 'p', 'e', 't', 's', '\n',
        'p', 'a', 'r', 'a', 'p', 'h', 'e', 'r', 'n', 'a', 'l', 'i', 'a', '\n',
        'p', 'a', 'r', 'a', 'p', 'h', 'r', 'a', 's', 'e', '\n',
        'p', 'a', 'r', 'a', 'p', 'h', 'r', 'a', 's', 'e', 'd', '\n',
        'p', 'a', 'r', 'a', 'p', 'h', 'r', 'a', 's', 'e', 's', '\n',
        'p', 'a', 'r', 'a', 'p', 'h', 'r', 'a', 's', 'i', 'n', 'g', '\n',
        'p', 'a', 'r', 'a', 'p', 'l', 'e', 'g', 'i', 'c', '\n',
        'p', 'a', 'r', 'a', 'p', 's', 'y', 'c', 'h', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'p', 'a', 'r', 'a', 'p', 's', 'y', 'c', 'h', 'o', 'l', 'o', 'g', 'y', '\n',
        'p', 'a', 'r', 'a', 'q', 'u', 'a', 't', '\n',
        'p', 'a', 'r', 'a', 's', 'i', 't', 'e', '\n',
        'p', 'a', 'r', 'a', 's', 'i', 't', 'e', 's', '\n',
        'p', 'a', 'r', 'a', 's', 'i', 't', 'i', 'c', '\n',
        'p', 'a', 'r', 'a', 's', 'i', 't', 'i', 'c', 'a', 'l', '\n',
        'p', 'a', 'r', 'a', 's', 'i', 't', 'i', 's', 'e', 'd', '\n',
        'p', 'a', 'r', 'a', 's', 'i', 't', 'i', 's', 'm', '\n',
        'p', 'a', 'r', 'a', 's', 'i', 't', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'p', 'a', 'r', 'a', 's', 'i', 't', 'o', 'l', 'o', 'g', 'y', '\n',
        'p', 'a', 'r', 'a', 's', 'o', 'l', '\n',
        'p', 'a', 'r', 'a', 's', 'o', 'l', 's', '\n',
        'p', 'a', 'r', 'a', 't', 'r', 'o', 'o', 'p', '\n',
        'p', 'a', 'r', 'a', 't', 'r', 'o', 'o', 'p', 'e', 'r', '\n',
        'p', 'a', 'r', 'a', 't', 'r', 'o', 'o', 'p', 'e', 'r', 's', '\n',
        'p', 'a', 'r', 'a', 't', 'r', 'o', 'o', 'p', 's', '\n',
        'p', 'a', 'r', 'b', 'o', 'i', 'l', '\n',
        'p', 'a', 'r', 'c', 'e', 'l', '\n',
        'p', 'a', 'r', 'c', 'e', 'l', 'l', 'e', 'd', '\n',
        'p', 'a', 'r', 'c', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'p', 'a', 'r', 'c', 'e', 'l', 's', '\n',
        'p', 'a', 'r', 'c', 'h', '\n',
        'p', 'a', 'r', 'c', 'h', 'e', 'd', '\n',
        'p', 'a', 'r', 'c', 'h', 'e', 's', '\n',
        'p', 'a', 'r', 'c', 'h', 'm', 'e', 'n', 't', '\n',
        'p', 'a', 'r', 'c', 'h', 'm', 'e', 'n', 't', 's', '\n',
        'p', 'a', 'r', 'd', 'o', 'n', '\n',
        'p', 'a', 'r', 'd', 'o', 'n', 'a', 'b', 'l', 'e', '\n',
        'p', 'a', 'r', 'd', 'o', 'n', 'e', 'd', '\n',
        'p', 'a', 'r', 'd', 'o', 'n', 'i', 'n', 'g', '\n',
        'p', 'a', 'r', 'd', 'o', 'n', 's', '\n',
        'p', 'a', 'r', 'e', '\n',
        'p', 'a', 'r', 'e', 'd', '\n',
        'p', 'a', 'r', 'e', 'n', 't', '\n',
        'p', 'a', 'r', 'e', 'n', 't', 'a', 'g', 'e', '\n',
        'p', 'a', 'r', 'e', 'n', 't', 'a', 'l', '\n',
        'p', 'a', 'r', 'e', 'n', 't', 'e', 'd', '\n',
        'p', 'a', 'r', 'e', 'n', 't', 'e', 'r', 'a', 'l', '\n',
        'p', 'a', 'r', 'e', 'n', 't', 'h', 'e', 's', 'e', 's', '\n',
        'p', 'a', 'r', 'e', 'n', 't', 'h', 'e', 's', 'i', 's', '\n',
        'p', 'a', 'r', 'e', 'n', 't', 'h', 'e', 's', 'i', 's', 'e', '\n',
        'p', 'a', 'r', 'e', 'n', 't', 'h', 'e', 's', 'i', 's', 'e', 'd', '\n',
        'p', 'a', 'r', 'e', 'n', 't', 'h', 'e', 't', 'i', 'c', '\n',
        'p', 'a', 'r', 'e', 'n', 't', 'h', 'e', 't', 'i', 'c', 'a', 'l', '\n',
        'p', 'a', 'r', 'e', 'n', 't', 'h', 'e', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'p', 'a', 'r', 'e', 'n', 't', 'h', 'o', 'o', 'd', '\n',
        'p', 'a', 'r', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'p', 'a', 'r', 'e', 'n', 't', 'i', 'n', 'l', 'a', 'w', '\n',
        'p', 'a', 'r', 'e', 'n', 't', 's', '\n',
        'p', 'a', 'r', 'e', 'n', 't', 's', 'i', 'n', 'l', 'a', 'w', '\n',
        'p', 'a', 'r', 'e', 's', '\n',
        'p', 'a', 'r', 'f', 'a', 'i', 't', '\n',
        'p', 'a', 'r', 'f', 'a', 'i', 't', 's', '\n',
        'p', 'a', 'r', 'i', 'a', 'h', '\n',
        'p', 'a', 'r', 'i', 'a', 'h', 's', '\n',
        'p', 'a', 'r', 'i', 'e', 't', 'a', 'l', '\n',
        'p', 'a', 'r', 'i', 'n', 'g', '\n',
        'p', 'a', 'r', 'i', 's', '\n',
        'p', 'a', 'r', 'i', 's', 'h', '\n',
        'p', 'a', 'r', 'i', 's', 'h', 'e', 's', '\n',
        'p', 'a', 'r', 'i', 's', 'h', 'i', 'o', 'n', 'e', 'r', '\n',
        'p', 'a', 'r', 'i', 's', 'h', 'i', 'o', 'n', 'e', 'r', 's', '\n',
        'p', 'a', 'r', 'i', 's', 'i', 'a', 'n', '\n',
        'p', 'a', 'r', 'i', 't', 'i', 'e', 's', '\n',
        'p', 'a', 'r', 'i', 't', 'y', '\n',
        'p', 'a', 'r', 'k', '\n',
        'p', 'a', 'r', 'k', 'a', '\n',
        'p', 'a', 'r', 'k', 'a', 's', '\n',
        'p', 'a', 'r', 'k', 'e', 'd', '\n',
        'p', 'a', 'r', 'k', 'i', 'n', 'g', '\n',
        'p', 'a', 'r', 'k', 'l', 'a', 'n', 'd', '\n',
        'p', 'a', 'r', 'k', 's', '\n',
        'p', 'a', 'r', 'l', 'a', 'n', 'c', 'e', '\n',
        'p', 'a', 'r', 'l', 'e', 'y', '\n',
        'p', 'a', 'r', 'l', 'e', 'y', 'i', 'n', 'g', '\n',
        'p', 'a', 'r', 'l', 'i', 'a', 'm', 'e', 'n', 't', '\n',
        'p', 'a', 'r', 'l', 'i', 'a', 'm', 'e', 'n', 't', 'a', 'r', 'i', 'a', 'n', '\n',
        'p', 'a', 'r', 'l', 'i', 'a', 'm', 'e', 'n', 't', 'a', 'r', 'i', 'a', 'n', 's', '\n',
        'p', 'a', 'r', 'l', 'i', 'a', 'm', 'e', 'n', 't', 'a', 'r', 'y', '\n',
        'p', 'a', 'r', 'l', 'i', 'a', 'm', 'e', 'n', 't', 's', '\n',
        'p', 'a', 'r', 'l', 'o', 'u', 'r', '\n',
        'p', 'a', 'r', 'l', 'o', 'u', 'r', 'm', 'a', 'i', 'd', '\n',
        'p', 'a', 'r', 'l', 'o', 'u', 'r', 's', '\n',
        'p', 'a', 'r', 'l', 'o', 'u', 's', '\n',
        'p', 'a', 'r', 'o', 'c', 'h', 'i', 'a', 'l', '\n',
        'p', 'a', 'r', 'o', 'c', 'h', 'i', 'a', 'l', 'i', 's', 'm', '\n',
        'p', 'a', 'r', 'o', 'c', 'h', 'i', 'a', 'l', 'i', 't', 'y', '\n',
        'p', 'a', 'r', 'o', 'd', 'i', 'e', 'd', '\n',
        'p', 'a', 'r', 'o', 'd', 'i', 'e', 's', '\n',
        'p', 'a', 'r', 'o', 'd', 'i', 's', 't', '\n',
        'p', 'a', 'r', 'o', 'd', 'y', '\n',
        'p', 'a', 'r', 'o', 'd', 'y', 'i', 'n', 'g', '\n',
        'p', 'a', 'r', 'o', 'l', 'e', '\n',
        'p', 'a', 'r', 'o', 'x', 'y', 's', 'm', '\n',
        'p', 'a', 'r', 'o', 'x', 'y', 's', 'm', 's', '\n',
        'p', 'a', 'r', 'q', 'u', 'e', 't', '\n',
        'p', 'a', 'r', 'r', 'i', 'e', 'd', '\n',
        'p', 'a', 'r', 'r', 'i', 'e', 's', '\n',
        'p', 'a', 'r', 'r', 'o', 't', '\n',
        'p', 'a', 'r', 'r', 'o', 't', 'i', 'n', 'g', '\n',
        'p', 'a', 'r', 'r', 'o', 't', 's', '\n',
        'p', 'a', 'r', 'r', 'y', '\n',
        'p', 'a', 'r', 'r', 'y', 'i', 'n', 'g', '\n',
        'p', 'a', 'r', 's', 'e', '\n',
        'p', 'a', 'r', 's', 'e', 'c', '\n',
        'p', 'a', 'r', 's', 'e', 'c', 's', '\n',
        'p', 'a', 'r', 's', 'e', 'd', '\n',
        'p', 'a', 'r', 's', 'e', 'r', '\n',
        'p', 'a', 'r', 's', 'e', 'r', 's', '\n',
        'p', 'a', 'r', 's', 'e', 's', '\n',
        'p', 'a', 'r', 's', 'i', 'm', 'o', 'n', 'i', 'o', 'u', 's', '\n',
        'p', 'a', 'r', 's', 'i', 'm', 'o', 'n', 'y', '\n',
        'p', 'a', 'r', 's', 'i', 'n', 'g', '\n',
        'p', 'a', 'r', 's', 'i', 'n', 'g', 's', '\n',
        'p', 'a', 'r', 's', 'l', 'e', 'y', '\n',
        'p', 'a', 'r', 's', 'n', 'i', 'p', '\n',
        'p', 'a', 'r', 's', 'n', 'i', 'p', 's', '\n',
        'p', 'a', 'r', 's', 'o', 'n', '\n',
        'p', 'a', 'r', 's', 'o', 'n', 'a', 'g', 'e', '\n',
        'p', 'a', 'r', 's', 'o', 'n', 's', '\n',
        'p', 'a', 'r', 't', '\n',
        'p', 'a', 'r', 't', 'a', 'k', 'e', '\n',
        'p', 'a', 'r', 't', 'a', 'k', 'e', 'n', '\n',
        'p', 'a', 'r', 't', 'a', 'k', 'e', 'r', '\n',
        'p', 'a', 'r', 't', 'a', 'k', 'e', 'r', 's', '\n',
        'p', 'a', 'r', 't', 'a', 'k', 'e', 's', '\n',
        'p', 'a', 'r', 't', 'a', 'k', 'i', 'n', 'g', '\n',
        'p', 'a', 'r', 't', 'e', 'd', '\n',
        'p', 'a', 'r', 't', 'h', 'e', 'n', 'o', 'g', 'e', 'n', 'e', 's', 'i', 's', '\n',
        'p', 'a', 'r', 't', 'i', 'a', 'l', '\n',
        'p', 'a', 'r', 't', 'i', 'a', 'l', 'i', 't', 'y', '\n',
        'p', 'a', 'r', 't', 'i', 'a', 'l', 'l', 'y', '\n',
        'p', 'a', 'r', 't', 'i', 'c', 'i', 'p', 'a', 'n', 't', '\n',
        'p', 'a', 'r', 't', 'i', 'c', 'i', 'p', 'a', 'n', 't', 's', '\n',
        'p', 'a', 'r', 't', 'i', 'c', 'i', 'p', 'a', 't', 'e', '\n',
        'p', 'a', 'r', 't', 'i', 'c', 'i', 'p', 'a', 't', 'e', 'd', '\n',
        'p', 'a', 'r', 't', 'i', 'c', 'i', 'p', 'a', 't', 'e', 's', '\n',
        'p', 'a', 'r', 't', 'i', 'c', 'i', 'p', 'a', 't', 'i', 'n', 'g', '\n',
        'p', 'a', 'r', 't', 'i', 'c', 'i', 'p', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'a', 'r', 't', 'i', 'c', 'i', 'p', 'a', 't', 'i', 'v', 'e', '\n',
        'p', 'a', 'r', 't', 'i', 'c', 'i', 'p', 'a', 't', 'o', 'r', 's', '\n',
        'p', 'a', 'r', 't', 'i', 'c', 'i', 'p', 'a', 't', 'o', 'r', 'y', '\n',
        'p', 'a', 'r', 't', 'i', 'c', 'i', 'p', 'l', 'e', '\n',
        'p', 'a', 'r', 't', 'i', 'c', 'i', 'p', 'l', 'e', 's', '\n',
        'p', 'a', 'r', 't', 'i', 'c', 'l', 'e', '\n',
        'p', 'a', 'r', 't', 'i', 'c', 'l', 'e', 's', '\n',
        'p', 'a', 'r', 't', 'i', 'c', 'u', 'l', 'a', 'r', '\n',
        'p', 'a', 'r', 't', 'i', 'c', 'u', 'l', 'a', 'r', 'i', 's', 'e', '\n',
        'p', 'a', 'r', 't', 'i', 'c', 'u', 'l', 'a', 'r', 'i', 's', 'e', 'd', '\n',
        'p', 'a', 'r', 't', 'i', 'c', 'u', 'l', 'a', 'r', 'i', 's', 'm', '\n',
        'p', 'a', 'r', 't', 'i', 'c', 'u', 'l', 'a', 'r', 'i', 't', 'i', 'e', 's', '\n',
        'p', 'a', 'r', 't', 'i', 'c', 'u', 'l', 'a', 'r', 'i', 't', 'y', '\n',
        'p', 'a', 'r', 't', 'i', 'c', 'u', 'l', 'a', 'r', 'l', 'y', '\n',
        'p', 'a', 'r', 't', 'i', 'c', 'u', 'l', 'a', 'r', 's', '\n',
        'p', 'a', 'r', 't', 'i', 'c', 'u', 'l', 'a', 't', 'e', '\n',
        'p', 'a', 'r', 't', 'i', 'c', 'u', 'l', 'a', 't', 'e', 's', '\n',
        'p', 'a', 'r', 't', 'i', 'e', 's', '\n',
        'p', 'a', 'r', 't', 'i', 'n', 'g', '\n',
        'p', 'a', 'r', 't', 'i', 'n', 'g', 's', '\n',
        'p', 'a', 'r', 't', 'i', 's', 'a', 'n', '\n',
        'p', 'a', 'r', 't', 'i', 's', 'a', 'n', 's', '\n',
        'p', 'a', 'r', 't', 'i', 's', 'a', 'n', 's', 'h', 'i', 'p', '\n',
        'p', 'a', 'r', 't', 'i', 't', 'i', 'o', 'n', '\n',
        'p', 'a', 'r', 't', 'i', 't', 'i', 'o', 'n', 'e', 'd', '\n',
        'p', 'a', 'r', 't', 'i', 't', 'i', 'o', 'n', 'i', 'n', 'g', '\n',
        'p', 'a', 'r', 't', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'a', 'r', 't', 'l', 'y', '\n',
        'p', 'a', 'r', 't', 'n', 'e', 'r', '\n',
        'p', 'a', 'r', 't', 'n', 'e', 'r', 'e', 'd', '\n',
        'p', 'a', 'r', 't', 'n', 'e', 'r', 'i', 'n', 'g', '\n',
        'p', 'a', 'r', 't', 'n', 'e', 'r', 's', '\n',
        'p', 'a', 'r', 't', 'n', 'e', 'r', 's', 'h', 'i', 'p', '\n',
        'p', 'a', 'r', 't', 'n', 'e', 'r', 's', 'h', 'i', 'p', 's', '\n',
        'p', 'a', 'r', 't', 'o', 'o', 'k', '\n',
        'p', 'a', 'r', 't', 'r', 'i', 'd', 'g', 'e', '\n',
        'p', 'a', 'r', 't', 'r', 'i', 'd', 'g', 'e', 's', '\n',
        'p', 'a', 'r', 't', 's', '\n',
        'p', 'a', 'r', 't', 't', 'i', 'm', 'e', '\n',
        'p', 'a', 'r', 't', 'y', '\n',
        'p', 'a', 'r', 'v', 'e', 'n', 'u', '\n',
        'p', 'a', 's', 'c', 'a', 'l', '\n',
        'p', 'a', 's', 'c', 'a', 'l', 's', '\n',
        'p', 'a', 's', 'c', 'h', 'a', 'l', '\n',
        'p', 'a', 's', 's', '\n',
        'p', 'a', 's', 's', 'a', 'b', 'l', 'e', '\n',
        'p', 'a', 's', 's', 'a', 'b', 'l', 'y', '\n',
        'p', 'a', 's', 's', 'a', 'g', 'e', '\n',
        'p', 'a', 's', 's', 'a', 'g', 'e', 's', '\n',
        'p', 'a', 's', 's', 'a', 'g', 'e', 'w', 'a', 'y', '\n',
        'p', 'a', 's', 's', 'a', 'g', 'e', 'w', 'a', 'y', 's', '\n',
        'p', 'a', 's', 's', 'a', 'n', 't', '\n',
        'p', 'a', 's', 's', 'e', '\n',
        'p', 'a', 's', 's', 'e', 'd', '\n',
        'p', 'a', 's', 's', 'e', 'n', 'g', 'e', 'r', '\n',
        'p', 'a', 's', 's', 'e', 'n', 'g', 'e', 'r', 's', '\n',
        'p', 'a', 's', 's', 'e', 'r', '\n',
        'p', 'a', 's', 's', 'e', 'r', 's', '\n',
        'p', 'a', 's', 's', 'e', 'r', 's', 'b', 'y', '\n',
        'p', 'a', 's', 's', 'e', 's', '\n',
        'p', 'a', 's', 's', 'i', 'm', '\n',
        'p', 'a', 's', 's', 'i', 'n', 'g', '\n',
        'p', 'a', 's', 's', 'i', 'o', 'n', '\n',
        'p', 'a', 's', 's', 'i', 'o', 'n', 'a', 't', 'e', '\n',
        'p', 'a', 's', 's', 'i', 'o', 'n', 'a', 't', 'e', 'l', 'y', '\n',
        'p', 'a', 's', 's', 'i', 'o', 'n', 'a', 't', 'e', 'n', 'e', 's', 's', '\n',
        'p', 'a', 's', 's', 'i', 'o', 'n', 'l', 'e', 's', 's', '\n',
        'p', 'a', 's', 's', 'i', 'o', 'n', 's', '\n',
        'p', 'a', 's', 's', 'i', 'v', 'a', 't', 'e', 'd', '\n',
        'p', 'a', 's', 's', 'i', 'v', 'e', '\n',
        'p', 'a', 's', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'p', 'a', 's', 's', 'i', 'v', 'e', 's', '\n',
        'p', 'a', 's', 's', 'i', 'v', 'i', 't', 'y', '\n',
        'p', 'a', 's', 's', 'm', 'a', 'r', 'k', '\n',
        'p', 'a', 's', 's', 'o', 'v', 'e', 'r', '\n',
        'p', 'a', 's', 's', 'p', 'o', 'r', 't', '\n',
        'p', 'a', 's', 's', 'p', 'o', 'r', 't', 's', '\n',
        'p', 'a', 's', 's', 'w', 'o', 'r', 'd', '\n',
        'p', 'a', 's', 's', 'w', 'o', 'r', 'd', 's', '\n',
        'p', 'a', 's', 't', '\n',
        'p', 'a', 's', 't', 'a', '\n',
        'p', 'a', 's', 't', 'a', 's', '\n',
        'p', 'a', 's', 't', 'e', '\n',
        'p', 'a', 's', 't', 'e', 'b', 'o', 'a', 'r', 'd', '\n',
        'p', 'a', 's', 't', 'e', 'd', '\n',
        'p', 'a', 's', 't', 'e', 'l', '\n',
        'p', 'a', 's', 't', 'e', 'l', 's', '\n',
        'p', 'a', 's', 't', 'e', 's', '\n',
        'p', 'a', 's', 't', 'e', 'u', 'r', '\n',
        'p', 'a', 's', 't', 'e', 'u', 'r', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'a', 's', 't', 'e', 'u', 'r', 'i', 's', 'e', 'd', '\n',
        'p', 'a', 's', 't', 'i', 'c', 'h', 'e', '\n',
        'p', 'a', 's', 't', 'i', 'c', 'h', 'e', 's', '\n',
        'p', 'a', 's', 't', 'i', 'e', 's', '\n',
        'p', 'a', 's', 't', 'i', 'l', 'l', 'e', '\n',
        'p', 'a', 's', 't', 'i', 'm', 'e', '\n',
        'p', 'a', 's', 't', 'i', 'm', 'e', 's', '\n',
        'p', 'a', 's', 't', 'i', 'n', 'g', '\n',
        'p', 'a', 's', 't', 'i', 's', '\n',
        'p', 'a', 's', 't', 'o', 'r', '\n',
        'p', 'a', 's', 't', 'o', 'r', 'a', 'l', '\n',
        'p', 'a', 's', 't', 'o', 'r', 'a', 'l', 'i', 's', 'm', '\n',
        'p', 'a', 's', 't', 'o', 'r', 's', '\n',
        'p', 'a', 's', 't', 'r', 'a', 'm', 'i', '\n',
        'p', 'a', 's', 't', 'r', 'i', 'e', 's', '\n',
        'p', 'a', 's', 't', 'r', 'y', '\n',
        'p', 'a', 's', 't', 's', '\n',
        'p', 'a', 's', 't', 'u', 'r', 'e', '\n',
        'p', 'a', 's', 't', 'u', 'r', 'e', 'd', '\n',
        'p', 'a', 's', 't', 'u', 'r', 'e', 'l', 'a', 'n', 'd', '\n',
        'p', 'a', 's', 't', 'u', 'r', 'e', 's', '\n',
        'p', 'a', 's', 't', 'u', 'r', 'i', 'n', 'g', '\n',
        'p', 'a', 's', 't', 'y', '\n',
        'p', 'a', 't', '\n',
        'p', 'a', 't', 'c', 'h', '\n',
        'p', 'a', 't', 'c', 'h', 'a', 'b', 'l', 'e', '\n',
        'p', 'a', 't', 'c', 'h', 'e', 'd', '\n',
        'p', 'a', 't', 'c', 'h', 'e', 's', '\n',
        'p', 'a', 't', 'c', 'h', 'i', 'e', 'r', '\n',
        'p', 'a', 't', 'c', 'h', 'i', 'e', 's', 't', '\n',
        'p', 'a', 't', 'c', 'h', 'i', 'l', 'y', '\n',
        'p', 'a', 't', 'c', 'h', 'i', 'n', 'e', 's', 's', '\n',
        'p', 'a', 't', 'c', 'h', 'i', 'n', 'g', '\n',
        'p', 'a', 't', 'c', 'h', 'u', 'p', '\n',
        'p', 'a', 't', 'c', 'h', 'w', 'o', 'r', 'k', '\n',
        'p', 'a', 't', 'c', 'h', 'y', '\n',
        'p', 'a', 't', 'e', '\n',
        'p', 'a', 't', 'e', 'l', 'l', 'a', '\n',
        'p', 'a', 't', 'e', 'n', '\n',
        'p', 'a', 't', 'e', 'n', 't', '\n',
        'p', 'a', 't', 'e', 'n', 't', 'a', 'b', 'l', 'e', '\n',
        'p', 'a', 't', 'e', 'n', 't', 'e', 'd', '\n',
        'p', 'a', 't', 'e', 'n', 't', 'e', 'e', '\n',
        'p', 'a', 't', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'p', 'a', 't', 'e', 'n', 't', 'l', 'y', '\n',
        'p', 'a', 't', 'e', 'n', 't', 's', '\n',
        'p', 'a', 't', 'e', 'r', '\n',
        'p', 'a', 't', 'e', 'r', 'n', 'a', 'l', '\n',
        'p', 'a', 't', 'e', 'r', 'n', 'a', 'l', 'i', 's', 'm', '\n',
        'p', 'a', 't', 'e', 'r', 'n', 'a', 'l', 'i', 's', 't', '\n',
        'p', 'a', 't', 'e', 'r', 'n', 'a', 'l', 'i', 's', 't', 'i', 'c', '\n',
        'p', 'a', 't', 'e', 'r', 'n', 'a', 'l', 'l', 'y', '\n',
        'p', 'a', 't', 'e', 'r', 'n', 'i', 't', 'y', '\n',
        'p', 'a', 't', 'e', 's', '\n',
        'p', 'a', 't', 'h', '\n',
        'p', 'a', 't', 'h', 'e', 't', 'i', 'c', '\n',
        'p', 'a', 't', 'h', 'e', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'p', 'a', 't', 'h', 'f', 'i', 'n', 'd', 'e', 'r', '\n',
        'p', 'a', 't', 'h', 'f', 'i', 'n', 'd', 'e', 'r', 's', '\n',
        'p', 'a', 't', 'h', 'l', 'e', 's', 's', '\n',
        'p', 'a', 't', 'h', 'o', 'g', 'e', 'n', '\n',
        'p', 'a', 't', 'h', 'o', 'g', 'e', 'n', 'e', 's', 'i', 's', '\n',
        'p', 'a', 't', 'h', 'o', 'g', 'e', 'n', 'i', 'c', '\n',
        'p', 'a', 't', 'h', 'o', 'g', 'e', 'n', 's', '\n',
        'p', 'a', 't', 'h', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'p', 'a', 't', 'h', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'p', 'a', 't', 'h', 'o', 'l', 'o', 'g', 'i', 'e', 's', '\n',
        'p', 'a', 't', 'h', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'p', 'a', 't', 'h', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'p', 'a', 't', 'h', 'o', 'l', 'o', 'g', 'y', '\n',
        'p', 'a', 't', 'h', 'o', 's', '\n',
        'p', 'a', 't', 'h', 's', '\n',
        'p', 'a', 't', 'h', 'w', 'a', 'y', '\n',
        'p', 'a', 't', 'h', 'w', 'a', 'y', 's', '\n',
        'p', 'a', 't', 'i', 'e', 'n', 'c', 'e', '\n',
        'p', 'a', 't', 'i', 'e', 'n', 't', '\n',
        'p', 'a', 't', 'i', 'e', 'n', 't', 'l', 'y', '\n',
        'p', 'a', 't', 'i', 'e', 'n', 't', 's', '\n',
        'p', 'a', 't', 'i', 'n', 'a', '\n',
        'p', 'a', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'a', 't', 'i', 'o', '\n',
        'p', 'a', 't', 'i', 's', 's', 'e', 'r', 'i', 'e', '\n',
        'p', 'a', 't', 'o', 'i', 's', '\n',
        'p', 'a', 't', 'r', 'i', 'a', 'r', 'c', 'h', '\n',
        'p', 'a', 't', 'r', 'i', 'a', 'r', 'c', 'h', 'a', 'l', '\n',
        'p', 'a', 't', 'r', 'i', 'a', 'r', 'c', 'h', 'i', 'e', 's', '\n',
        'p', 'a', 't', 'r', 'i', 'a', 'r', 'c', 'h', 's', '\n',
        'p', 'a', 't', 'r', 'i', 'a', 'r', 'c', 'h', 'y', '\n',
        'p', 'a', 't', 'r', 'i', 'c', 'i', 'a', 'n', '\n',
        'p', 'a', 't', 'r', 'i', 'c', 'i', 'a', 'n', 's', '\n',
        'p', 'a', 't', 'r', 'i', 'l', 'i', 'n', 'e', 'a', 'l', '\n',
        'p', 'a', 't', 'r', 'i', 'm', 'o', 'n', 'y', '\n',
        'p', 'a', 't', 'r', 'i', 'o', 't', '\n',
        'p', 'a', 't', 'r', 'i', 'o', 't', 'i', 'c', '\n',
        'p', 'a', 't', 'r', 'i', 'o', 't', 'i', 's', 'm', '\n',
        'p', 'a', 't', 'r', 'i', 'o', 't', 's', '\n',
        'p', 'a', 't', 'r', 'o', 'l', '\n',
        'p', 'a', 't', 'r', 'o', 'l', 'l', 'e', 'd', '\n',
        'p', 'a', 't', 'r', 'o', 'l', 'l', 'i', 'n', 'g', '\n',
        'p', 'a', 't', 'r', 'o', 'l', 's', '\n',
        'p', 'a', 't', 'r', 'o', 'n', '\n',
        'p', 'a', 't', 'r', 'o', 'n', 'a', 'g', 'e', '\n',
        'p', 'a', 't', 'r', 'o', 'n', 'e', 's', 's', '\n',
        'p', 'a', 't', 'r', 'o', 'n', 'e', 's', 's', 'e', 's', '\n',
        'p', 'a', 't', 'r', 'o', 'n', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'a', 't', 'r', 'o', 'n', 'i', 's', 'e', '\n',
        'p', 'a', 't', 'r', 'o', 'n', 'i', 's', 'e', 'd', '\n',
        'p', 'a', 't', 'r', 'o', 'n', 'i', 's', 'e', 's', '\n',
        'p', 'a', 't', 'r', 'o', 'n', 'i', 's', 'i', 'n', 'g', '\n',
        'p', 'a', 't', 'r', 'o', 'n', 'i', 's', 'i', 'n', 'g', 'l', 'y', '\n',
        'p', 'a', 't', 'r', 'o', 'n', 's', '\n',
        'p', 'a', 't', 's', '\n',
        'p', 'a', 't', 't', 'e', 'd', '\n',
        'p', 'a', 't', 't', 'e', 'n', '\n',
        'p', 'a', 't', 't', 'e', 'n', 's', '\n',
        'p', 'a', 't', 't', 'e', 'r', '\n',
        'p', 'a', 't', 't', 'e', 'r', 'e', 'd', '\n',
        'p', 'a', 't', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'p', 'a', 't', 't', 'e', 'r', 'n', '\n',
        'p', 'a', 't', 't', 'e', 'r', 'n', 'e', 'd', '\n',
        'p', 'a', 't', 't', 'e', 'r', 'n', 'i', 'n', 'g', '\n',
        'p', 'a', 't', 't', 'e', 'r', 'n', 'l', 'e', 's', 's', '\n',
        'p', 'a', 't', 't', 'e', 'r', 'n', 's', '\n',
        'p', 'a', 't', 't', 'e', 'r', 's', '\n',
        'p', 'a', 't', 't', 'i', 'e', 's', '\n',
        'p', 'a', 't', 't', 'i', 'n', 'g', '\n',
        'p', 'a', 'u', 'c', 'i', 't', 'y', '\n',
        'p', 'a', 'u', 'l', '\n',
        'p', 'a', 'u', 'n', 'c', 'h', '\n',
        'p', 'a', 'u', 'n', 'c', 'h', 'y', '\n',
        'p', 'a', 'u', 'p', 'e', 'r', '\n',
        'p', 'a', 'u', 'p', 'e', 'r', 's', '\n',
        'p', 'a', 'u', 's', 'e', '\n',
        'p', 'a', 'u', 's', 'e', 'd', '\n',
        'p', 'a', 'u', 's', 'e', 's', '\n',
        'p', 'a', 'u', 's', 'i', 'n', 'g', '\n',
        'p', 'a', 'v', 'e', '\n',
        'p', 'a', 'v', 'e', 'd', '\n',
        'p', 'a', 'v', 'e', 'm', 'e', 'n', 't', '\n',
        'p', 'a', 'v', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'p', 'a', 'v', 'e', 's', '\n',
        'p', 'a', 'v', 'i', 'l', 'i', 'o', 'n', '\n',
        'p', 'a', 'v', 'i', 'l', 'i', 'o', 'n', 's', '\n',
        'p', 'a', 'v', 'i', 'n', 'g', '\n',
        'p', 'a', 'v', 'i', 'n', 'g', 's', '\n',
        'p', 'a', 'v', 'l', 'o', 'v', '\n',
        'p', 'a', 'w', '\n',
        'p', 'a', 'w', 'e', 'd', '\n',
        'p', 'a', 'w', 'i', 'n', 'g', '\n',
        'p', 'a', 'w', 'n', '\n',
        'p', 'a', 'w', 'n', 'b', 'r', 'o', 'k', 'e', 'r', '\n',
        'p', 'a', 'w', 'n', 'b', 'r', 'o', 'k', 'e', 'r', 's', '\n',
        'p', 'a', 'w', 'n', 'e', 'd', '\n',
        'p', 'a', 'w', 'n', 'i', 'n', 'g', '\n',
        'p', 'a', 'w', 'n', 's', '\n',
        'p', 'a', 'w', 'n', 's', 'h', 'o', 'p', '\n',
        'p', 'a', 'w', 'n', 's', 'h', 'o', 'p', 's', '\n',
        'p', 'a', 'w', 'p', 'a', 'w', '\n',
        'p', 'a', 'w', 'p', 'a', 'w', 's', '\n',
        'p', 'a', 'w', 's', '\n',
        'p', 'a', 'y', '\n',
        'p', 'a', 'y', 'a', 'b', 'l', 'e', '\n',
        'p', 'a', 'y', 'b', 'a', 'c', 'k', '\n',
        'p', 'a', 'y', 'd', 'a', 'y', '\n',
        'p', 'a', 'y', 'd', 'a', 'y', 's', '\n',
        'p', 'a', 'y', 'e', 'd', '\n',
        'p', 'a', 'y', 'e', 'e', '\n',
        'p', 'a', 'y', 'e', 'e', 's', '\n',
        'p', 'a', 'y', 'e', 'r', '\n',
        'p', 'a', 'y', 'e', 'r', 's', '\n',
        'p', 'a', 'y', 'i', 'n', 'g', '\n',
        'p', 'a', 'y', 'l', 'o', 'a', 'd', '\n',
        'p', 'a', 'y', 'l', 'o', 'a', 'd', 's', '\n',
        'p', 'a', 'y', 'm', 'a', 's', 't', 'e', 'r', '\n',
        'p', 'a', 'y', 'm', 'a', 's', 't', 'e', 'r', 's', '\n',
        'p', 'a', 'y', 'm', 'e', 'n', 't', '\n',
        'p', 'a', 'y', 'm', 'e', 'n', 't', 's', '\n',
        'p', 'a', 'y', 'p', 'h', 'o', 'n', 'e', '\n',
        'p', 'a', 'y', 'p', 'h', 'o', 'n', 'e', 's', '\n',
        'p', 'a', 'y', 'r', 'o', 'l', 'l', '\n',
        'p', 'a', 'y', 'r', 'o', 'l', 'l', 's', '\n',
        'p', 'a', 'y', 's', '\n',
        'p', 'a', 'y', 's', 'l', 'i', 'p', 's', '\n',
        'p', 'e', 'a', '\n',
        'p', 'e', 'a', 'c', 'e', '\n',
        'p', 'e', 'a', 'c', 'e', 'a', 'b', 'l', 'e', '\n',
        'p', 'e', 'a', 'c', 'e', 'a', 'b', 'l', 'y', '\n',
        'p', 'e', 'a', 'c', 'e', 'f', 'u', 'l', '\n',
        'p', 'e', 'a', 'c', 'e', 'f', 'u', 'l', 'l', 'y', '\n',
        'p', 'e', 'a', 'c', 'e', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'p', 'e', 'a', 'c', 'e', 'k', 'e', 'e', 'p', 'e', 'r', 's', '\n',
        'p', 'e', 'a', 'c', 'e', 'k', 'e', 'e', 'p', 'i', 'n', 'g', '\n',
        'p', 'e', 'a', 'c', 'e', 'm', 'a', 'k', 'e', 'r', '\n',
        'p', 'e', 'a', 'c', 'e', 'm', 'a', 'k', 'e', 'r', 's', '\n',
        'p', 'e', 'a', 'c', 'e', 'm', 'a', 'k', 'i', 'n', 'g', '\n',
        'p', 'e', 'a', 'c', 'e', 't', 'i', 'm', 'e', '\n',
        'p', 'e', 'a', 'c', 'h', '\n',
        'p', 'e', 'a', 'c', 'h', 'e', 's', '\n',
        'p', 'e', 'a', 'c', 'h', 'i', 'e', 'r', '\n',
        'p', 'e', 'a', 'c', 'h', 'i', 'e', 's', 't', '\n',
        'p', 'e', 'a', 'c', 'h', 'y', '\n',
        'p', 'e', 'a', 'c', 'o', 'c', 'k', '\n',
        'p', 'e', 'a', 'c', 'o', 'c', 'k', 's', '\n',
        'p', 'e', 'a', 'f', 'o', 'w', 'l', '\n',
        'p', 'e', 'a', 'h', 'e', 'n', 's', '\n',
        'p', 'e', 'a', 'k', '\n',
        'p', 'e', 'a', 'k', 'e', 'd', '\n',
        'p', 'e', 'a', 'k', 'i', 'n', 'e', 's', 's', '\n',
        'p', 'e', 'a', 'k', 'i', 'n', 'g', '\n',
        'p', 'e', 'a', 'k', 's', '\n',
        'p', 'e', 'a', 'k', 'y', '\n',
        'p', 'e', 'a', 'l', '\n',
        'p', 'e', 'a', 'l', 'e', 'd', '\n',
        'p', 'e', 'a', 'l', 'i', 'n', 'g', '\n',
        'p', 'e', 'a', 'l', 's', '\n',
        'p', 'e', 'a', 'n', 'u', 't', '\n',
        'p', 'e', 'a', 'n', 'u', 't', 's', '\n',
        'p', 'e', 'a', 'r', '\n',
        'p', 'e', 'a', 'r', 'l', '\n',
        'p', 'e', 'a', 'r', 'l', 's', '\n',
        'p', 'e', 'a', 'r', 'l', 'y', '\n',
        'p', 'e', 'a', 'r', 's', '\n',
        'p', 'e', 'a', 'r', 't', 'r', 'e', 'e', 's', '\n',
        'p', 'e', 'a', 's', '\n',
        'p', 'e', 'a', 's', 'a', 'n', 't', '\n',
        'p', 'e', 'a', 's', 'a', 'n', 't', 'r', 'y', '\n',
        'p', 'e', 'a', 's', 'a', 'n', 't', 's', '\n',
        'p', 'e', 'a', 't', '\n',
        'p', 'e', 'a', 't', 'l', 'a', 'n', 'd', '\n',
        'p', 'e', 'a', 't', 'l', 'a', 'n', 'd', 's', '\n',
        'p', 'e', 'a', 't', 'y', '\n',
        'p', 'e', 'b', 'b', 'l', 'e', '\n',
        'p', 'e', 'b', 'b', 'l', 'e', 'd', '\n',
        'p', 'e', 'b', 'b', 'l', 'e', 's', '\n',
        'p', 'e', 'b', 'b', 'l', 'y', '\n',
        'p', 'e', 'c', 'a', 'n', '\n',
        'p', 'e', 'c', 'c', 'a', 'r', 'y', '\n',
        'p', 'e', 'c', 'k', '\n',
        'p', 'e', 'c', 'k', 'e', 'd', '\n',
        'p', 'e', 'c', 'k', 'e', 'r', '\n',
        'p', 'e', 'c', 'k', 'e', 'r', 's', '\n',
        'p', 'e', 'c', 'k', 'i', 'n', 'g', '\n',
        'p', 'e', 'c', 'k', 'i', 's', 'h', '\n',
        'p', 'e', 'c', 'k', 's', '\n',
        'p', 'e', 'c', 't', 'i', 'n', '\n',
        'p', 'e', 'c', 't', 'o', 'r', 'a', 'l', '\n',
        'p', 'e', 'c', 't', 'o', 'r', 'a', 'l', 's', '\n',
        'p', 'e', 'c', 'u', 'l', 'i', 'a', 'r', '\n',
        'p', 'e', 'c', 'u', 'l', 'i', 'a', 'r', 'i', 't', 'i', 'e', 's', '\n',
        'p', 'e', 'c', 'u', 'l', 'i', 'a', 'r', 'i', 't', 'y', '\n',
        'p', 'e', 'c', 'u', 'l', 'i', 'a', 'r', 'l', 'y', '\n',
        'p', 'e', 'c', 'u', 'n', 'i', 'a', 'r', 'y', '\n',
        'p', 'e', 'd', 'a', 'g', 'o', 'g', 'i', 'c', '\n',
        'p', 'e', 'd', 'a', 'g', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'p', 'e', 'd', 'a', 'g', 'o', 'g', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'p', 'e', 'd', 'a', 'g', 'o', 'g', 'u', 'e', '\n',
        'p', 'e', 'd', 'a', 'g', 'o', 'g', 'y', '\n',
        'p', 'e', 'd', 'a', 'l', '\n',
        'p', 'e', 'd', 'a', 'l', 'l', 'e', 'd', '\n',
        'p', 'e', 'd', 'a', 'l', 'l', 'i', 'n', 'g', '\n',
        'p', 'e', 'd', 'a', 'l', 's', '\n',
        'p', 'e', 'd', 'a', 'n', 't', '\n',
        'p', 'e', 'd', 'a', 'n', 't', 'i', 'c', '\n',
        'p', 'e', 'd', 'a', 'n', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'p', 'e', 'd', 'a', 'n', 't', 'r', 'y', '\n',
        'p', 'e', 'd', 'a', 'n', 't', 's', '\n',
        'p', 'e', 'd', 'd', 'l', 'e', '\n',
        'p', 'e', 'd', 'd', 'l', 'e', 'd', '\n',
        'p', 'e', 'd', 'd', 'l', 'e', 'r', '\n',
        'p', 'e', 'd', 'd', 'l', 'e', 'r', 's', '\n',
        'p', 'e', 'd', 'd', 'l', 'e', 's', '\n',
        'p', 'e', 'd', 'd', 'l', 'i', 'n', 'g', '\n',
        'p', 'e', 'd', 'e', 'r', 'a', 's', 't', 's', '\n',
        'p', 'e', 'd', 'e', 's', 't', 'a', 'l', '\n',
        'p', 'e', 'd', 'e', 's', 't', 'a', 'l', 's', '\n',
        'p', 'e', 'd', 'e', 's', 't', 'r', 'i', 'a', 'n', '\n',
        'p', 'e', 'd', 'e', 's', 't', 'r', 'i', 'a', 'n', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'e', 'd', 'e', 's', 't', 'r', 'i', 'a', 'n', 'i', 's', 'e', 'd', '\n',
        'p', 'e', 'd', 'e', 's', 't', 'r', 'i', 'a', 'n', 's', '\n',
        'p', 'e', 'd', 'i', 'g', 'r', 'e', 'e', '\n',
        'p', 'e', 'd', 'i', 'g', 'r', 'e', 'e', 's', '\n',
        'p', 'e', 'd', 'i', 'm', 'e', 'n', 't', '\n',
        'p', 'e', 'd', 'i', 'm', 'e', 'n', 't', 'e', 'd', '\n',
        'p', 'e', 'd', 'i', 'm', 'e', 'n', 't', 's', '\n',
        'p', 'e', 'd', 'l', 'a', 'r', '\n',
        'p', 'e', 'd', 'l', 'a', 'r', 's', '\n',
        'p', 'e', 'd', 'o', 'l', 'o', 'g', 'y', '\n',
        'p', 'e', 'e', 'k', '\n',
        'p', 'e', 'e', 'k', 'e', 'd', '\n',
        'p', 'e', 'e', 'k', 'i', 'n', 'g', '\n',
        'p', 'e', 'e', 'k', 's', '\n',
        'p', 'e', 'e', 'l', '\n',
        'p', 'e', 'e', 'l', 'e', 'd', '\n',
        'p', 'e', 'e', 'l', 'e', 'r', '\n',
        'p', 'e', 'e', 'l', 'e', 'r', 's', '\n',
        'p', 'e', 'e', 'l', 'i', 'n', 'g', '\n',
        'p', 'e', 'e', 'l', 'i', 'n', 'g', 's', '\n',
        'p', 'e', 'e', 'l', 's', '\n',
        'p', 'e', 'e', 'p', '\n',
        'p', 'e', 'e', 'p', 'e', 'd', '\n',
        'p', 'e', 'e', 'p', 'e', 'r', '\n',
        'p', 'e', 'e', 'p', 'e', 'r', 's', '\n',
        'p', 'e', 'e', 'p', 'h', 'o', 'l', 'e', '\n',
        'p', 'e', 'e', 'p', 'i', 'n', 'g', '\n',
        'p', 'e', 'e', 'p', 's', '\n',
        'p', 'e', 'e', 'r', '\n',
        'p', 'e', 'e', 'r', 'a', 'g', 'e', '\n',
        'p', 'e', 'e', 'r', 'a', 'g', 'e', 's', '\n',
        'p', 'e', 'e', 'r', 'e', 'd', '\n',
        'p', 'e', 'e', 'r', 'i', 'n', 'g', '\n',
        'p', 'e', 'e', 'r', 'l', 'e', 's', 's', '\n',
        'p', 'e', 'e', 'r', 's', '\n',
        'p', 'e', 'e', 'v', 'i', 's', 'h', '\n',
        'p', 'e', 'e', 'v', 'i', 's', 'h', 'l', 'y', '\n',
        'p', 'e', 'e', 'v', 'i', 's', 'h', 'n', 'e', 's', 's', '\n',
        'p', 'e', 'g', '\n',
        'p', 'e', 'g', 'a', 's', 'u', 's', '\n',
        'p', 'e', 'g', 'g', 'e', 'd', '\n',
        'p', 'e', 'g', 'g', 'i', 'n', 'g', '\n',
        'p', 'e', 'g', 's', '\n',
        'p', 'e', 'j', 'o', 'r', 'a', 't', 'i', 'v', 'e', '\n',
        'p', 'e', 'j', 'o', 'r', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'p', 'e', 'j', 'o', 'r', 'a', 't', 'i', 'v', 'e', 's', '\n',
        'p', 'e', 'k', 'a', 'n', '\n',
        'p', 'e', 'k', 'i', 'n', 'g', '\n',
        'p', 'e', 'l', 'e', '\n',
        'p', 'e', 'l', 'i', 'c', 'a', 'n', '\n',
        'p', 'e', 'l', 'i', 'c', 'a', 'n', 's', '\n',
        'p', 'e', 'l', 'l', 'e', 't', '\n',
        'p', 'e', 'l', 'l', 'e', 't', 's', '\n',
        'p', 'e', 'l', 'm', 'e', 't', '\n',
        'p', 'e', 'l', 'm', 'e', 't', 's', '\n',
        'p', 'e', 'l', 't', '\n',
        'p', 'e', 'l', 't', 'e', 'd', '\n',
        'p', 'e', 'l', 't', 'i', 'n', 'g', '\n',
        'p', 'e', 'l', 't', 's', '\n',
        'p', 'e', 'l', 'v', 'i', 'c', '\n',
        'p', 'e', 'l', 'v', 'i', 's', '\n',
        'p', 'e', 'l', 'v', 'i', 's', 'e', 's', '\n',
        'p', 'e', 'n', '\n',
        'p', 'e', 'n', 'a', 'l', '\n',
        'p', 'e', 'n', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'e', 'n', 'a', 'l', 'i', 's', 'e', '\n',
        'p', 'e', 'n', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'p', 'e', 'n', 'a', 'l', 'i', 's', 'e', 's', '\n',
        'p', 'e', 'n', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'p', 'e', 'n', 'a', 'l', 't', 'i', 'e', 's', '\n',
        'p', 'e', 'n', 'a', 'l', 't', 'y', '\n',
        'p', 'e', 'n', 'a', 'n', 'c', 'e', '\n',
        'p', 'e', 'n', 'a', 'n', 'c', 'e', 's', '\n',
        'p', 'e', 'n', 'c', 'e', '\n',
        'p', 'e', 'n', 'c', 'h', 'a', 'n', 't', '\n',
        'p', 'e', 'n', 'c', 'i', 'l', '\n',
        'p', 'e', 'n', 'c', 'i', 'l', 'l', 'e', 'd', '\n',
        'p', 'e', 'n', 'c', 'i', 'l', 'l', 'i', 'n', 'g', '\n',
        'p', 'e', 'n', 'c', 'i', 'l', 's', '\n',
        'p', 'e', 'n', 'd', 'a', 'n', 't', '\n',
        'p', 'e', 'n', 'd', 'a', 'n', 't', 's', '\n',
        'p', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'p', 'e', 'n', 'd', 'u', 'l', 'o', 'u', 's', '\n',
        'p', 'e', 'n', 'd', 'u', 'l', 'u', 'm', '\n',
        'p', 'e', 'n', 'd', 'u', 'l', 'u', 'm', 's', '\n',
        'p', 'e', 'n', 'e', 't', 'r', 'a', 'b', 'l', 'e', '\n',
        'p', 'e', 'n', 'e', 't', 'r', 'a', 't', 'e', '\n',
        'p', 'e', 'n', 'e', 't', 'r', 'a', 't', 'e', 'd', '\n',
        'p', 'e', 'n', 'e', 't', 'r', 'a', 't', 'e', 's', '\n',
        'p', 'e', 'n', 'e', 't', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'p', 'e', 'n', 'e', 't', 'r', 'a', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'p', 'e', 'n', 'e', 't', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'e', 'n', 'e', 't', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'e', 'n', 'e', 't', 'r', 'a', 't', 'i', 'v', 'e', '\n',
        'p', 'e', 'n', 'g', 'u', 'i', 'n', '\n',
        'p', 'e', 'n', 'g', 'u', 'i', 'n', 's', '\n',
        'p', 'e', 'n', 'i', 'c', 'i', 'l', 'l', 'i', 'n', '\n',
        'p', 'e', 'n', 'i', 'l', 'e', '\n',
        'p', 'e', 'n', 'i', 'n', 's', 'u', 'l', 'a', '\n',
        'p', 'e', 'n', 'i', 'n', 's', 'u', 'l', 'a', 'r', '\n',
        'p', 'e', 'n', 'i', 'n', 's', 'u', 'l', 'a', 's', '\n',
        'p', 'e', 'n', 'i', 't', 'e', 'n', 'c', 'e', '\n',
        'p', 'e', 'n', 'i', 't', 'e', 'n', 't', '\n',
        'p', 'e', 'n', 'i', 't', 'e', 'n', 't', 'i', 'a', 'l', '\n',
        'p', 'e', 'n', 'i', 't', 'e', 'n', 't', 'i', 'a', 'r', 'y', '\n',
        'p', 'e', 'n', 'i', 't', 'e', 'n', 't', 'l', 'y', '\n',
        'p', 'e', 'n', 'i', 't', 'e', 'n', 't', 's', '\n',
        'p', 'e', 'n', 'k', 'n', 'i', 'f', 'e', '\n',
        'p', 'e', 'n', 'n', 'a', 'm', 'e', '\n',
        'p', 'e', 'n', 'n', 'a', 'm', 'e', 's', '\n',
        'p', 'e', 'n', 'n', 'a', 'n', 't', '\n',
        'p', 'e', 'n', 'n', 'a', 'n', 't', 's', '\n',
        'p', 'e', 'n', 'n', 'e', 'd', '\n',
        'p', 'e', 'n', 'n', 'i', 'e', 's', '\n',
        'p', 'e', 'n', 'n', 'i', 'l', 'e', 's', 's', '\n',
        'p', 'e', 'n', 'n', 'i', 'n', 'g', '\n',
        'p', 'e', 'n', 'n', 'y', '\n',
        'p', 'e', 'n', 'n', 'y', 'p', 'i', 'n', 'c', 'h', 'i', 'n', 'g', '\n',
        'p', 'e', 'n', 'o', 'l', 'o', 'g', 'y', '\n',
        'p', 'e', 'n', 's', '\n',
        'p', 'e', 'n', 's', 'i', 'o', 'n', '\n',
        'p', 'e', 'n', 's', 'i', 'o', 'n', 'a', 'b', 'l', 'e', '\n',
        'p', 'e', 'n', 's', 'i', 'o', 'n', 'e', 'd', '\n',
        'p', 'e', 'n', 's', 'i', 'o', 'n', 'e', 'r', '\n',
        'p', 'e', 'n', 's', 'i', 'o', 'n', 'e', 'r', 's', '\n',
        'p', 'e', 'n', 's', 'i', 'o', 'n', 'i', 'n', 'g', '\n',
        'p', 'e', 'n', 's', 'i', 'o', 'n', 's', '\n',
        'p', 'e', 'n', 's', 'i', 'v', 'e', '\n',
        'p', 'e', 'n', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'p', 'e', 'n', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'p', 'e', 'n', 't', '\n',
        'p', 'e', 'n', 't', 'a', 'g', 'o', 'n', '\n',
        'p', 'e', 'n', 't', 'a', 'g', 'o', 'n', 'a', 'l', '\n',
        'p', 'e', 'n', 't', 'a', 'g', 'o', 'n', 's', '\n',
        'p', 'e', 'n', 't', 'a', 'g', 'r', 'a', 'm', '\n',
        'p', 'e', 'n', 't', 'a', 'g', 'r', 'a', 'm', 's', '\n',
        'p', 'e', 'n', 't', 'a', 'm', 'e', 't', 'e', 'r', '\n',
        'p', 'e', 'n', 't', 'a', 'm', 'e', 't', 'e', 'r', 's', '\n',
        'p', 'e', 'n', 't', 'a', 's', 'y', 'l', 'l', 'a', 'b', 'i', 'c', '\n',
        'p', 'e', 'n', 't', 'a', 't', 'h', 'l', 'e', 't', 'e', '\n',
        'p', 'e', 'n', 't', 'a', 't', 'h', 'l', 'o', 'n', '\n',
        'p', 'e', 'n', 't', 'a', 't', 'o', 'n', 'i', 'c', '\n',
        'p', 'e', 'n', 't', 'e', 'c', 'o', 's', 't', 'a', 'l', '\n',
        'p', 'e', 'n', 't', 'h', 'o', 'u', 's', 'e', '\n',
        'p', 'e', 'n', 'u', 'l', 't', 'i', 'm', 'a', 't', 'e', '\n',
        'p', 'e', 'n', 'u', 'l', 't', 'i', 'm', 'a', 't', 'e', 'l', 'y', '\n',
        'p', 'e', 'n', 'u', 'm', 'b', 'r', 'a', '\n',
        'p', 'e', 'n', 'u', 'r', 'i', 'o', 'u', 's', '\n',
        'p', 'e', 'n', 'u', 'r', 'y', '\n',
        'p', 'e', 'o', 'n', 'i', 'e', 's', '\n',
        'p', 'e', 'o', 'p', 'l', 'e', '\n',
        'p', 'e', 'o', 'p', 'l', 'e', 'd', '\n',
        'p', 'e', 'o', 'p', 'l', 'e', 's', '\n',
        'p', 'e', 'p', '\n',
        'p', 'e', 'p', 'e', 'r', 'o', 'n', 'i', '\n',
        'p', 'e', 'p', 'p', 'e', 'r', '\n',
        'p', 'e', 'p', 'p', 'e', 'r', 'c', 'o', 'r', 'n', '\n',
        'p', 'e', 'p', 'p', 'e', 'r', 'c', 'o', 'r', 'n', 's', '\n',
        'p', 'e', 'p', 'p', 'e', 'r', 'e', 'd', '\n',
        'p', 'e', 'p', 'p', 'e', 'r', 'i', 'n', 'g', '\n',
        'p', 'e', 'p', 'p', 'e', 'r', 'm', 'i', 'n', 't', '\n',
        'p', 'e', 'p', 'p', 'e', 'r', 'm', 'i', 'n', 't', 's', '\n',
        'p', 'e', 'p', 'p', 'e', 'r', 's', '\n',
        'p', 'e', 'p', 'p', 'e', 'r', 'y', '\n',
        'p', 'e', 'p', 's', '\n',
        'p', 'e', 'p', 't', 'i', 'c', '\n',
        'p', 'e', 'p', 't', 'i', 'd', 'e', '\n',
        'p', 'e', 'p', 't', 'i', 'd', 'e', 's', '\n',
        'p', 'e', 'r', '\n',
        'p', 'e', 'r', 'a', 'm', 'b', 'u', 'l', 'a', 't', 'e', '\n',
        'p', 'e', 'r', 'a', 'm', 'b', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'p', 'e', 'r', 'a', 'm', 'b', 'u', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'p', 'e', 'r', 'a', 'm', 'b', 'u', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'e', 'r', 'a', 'm', 'b', 'u', 'l', 'a', 't', 'o', 'r', '\n',
        'p', 'e', 'r', 'a', 'n', 'n', 'u', 'm', '\n',
        'p', 'e', 'r', 'c', 'a', 'l', 'e', 's', '\n',
        'p', 'e', 'r', 'c', 'e', 'i', 'v', 'a', 'b', 'l', 'e', '\n',
        'p', 'e', 'r', 'c', 'e', 'i', 'v', 'e', '\n',
        'p', 'e', 'r', 'c', 'e', 'i', 'v', 'e', 'd', '\n',
        'p', 'e', 'r', 'c', 'e', 'i', 'v', 'e', 's', '\n',
        'p', 'e', 'r', 'c', 'e', 'i', 'v', 'i', 'n', 'g', '\n',
        'p', 'e', 'r', 'c', 'e', 'n', 't', '\n',
        'p', 'e', 'r', 'c', 'e', 'n', 't', 'a', 'g', 'e', '\n',
        'p', 'e', 'r', 'c', 'e', 'n', 't', 'a', 'g', 'e', 's', '\n',
        'p', 'e', 'r', 'c', 'e', 'n', 't', 'i', 'l', 'e', '\n',
        'p', 'e', 'r', 'c', 'e', 'n', 't', 'i', 'l', 'e', 's', '\n',
        'p', 'e', 'r', 'c', 'e', 'p', 't', '\n',
        'p', 'e', 'r', 'c', 'e', 'p', 't', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'p', 'e', 'r', 'c', 'e', 'p', 't', 'i', 'b', 'l', 'e', '\n',
        'p', 'e', 'r', 'c', 'e', 'p', 't', 'i', 'b', 'l', 'y', '\n',
        'p', 'e', 'r', 'c', 'e', 'p', 't', 'i', 'o', 'n', '\n',
        'p', 'e', 'r', 'c', 'e', 'p', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'e', 'r', 'c', 'e', 'p', 't', 'i', 'v', 'e', '\n',
        'p', 'e', 'r', 'c', 'e', 'p', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'p', 'e', 'r', 'c', 'e', 'p', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'p', 'e', 'r', 'c', 'e', 'p', 't', 's', '\n',
        'p', 'e', 'r', 'c', 'e', 'p', 't', 'u', 'a', 'l', '\n',
        'p', 'e', 'r', 'c', 'e', 'p', 't', 'u', 'a', 'l', 'l', 'y', '\n',
        'p', 'e', 'r', 'c', 'h', '\n',
        'p', 'e', 'r', 'c', 'h', 'a', 'n', 'c', 'e', '\n',
        'p', 'e', 'r', 'c', 'h', 'e', 'd', '\n',
        'p', 'e', 'r', 'c', 'h', 'e', 'r', '\n',
        'p', 'e', 'r', 'c', 'h', 'e', 's', '\n',
        'p', 'e', 'r', 'c', 'h', 'i', 'n', 'g', '\n',
        'p', 'e', 'r', 'c', 'h', 'l', 'o', 'r', 'a', 't', 'e', '\n',
        'p', 'e', 'r', 'c', 'i', 'p', 'i', 'e', 'n', 't', '\n',
        'p', 'e', 'r', 'c', 'o', 'l', 'a', 't', 'e', '\n',
        'p', 'e', 'r', 'c', 'o', 'l', 'a', 't', 'e', 'd', '\n',
        'p', 'e', 'r', 'c', 'o', 'l', 'a', 't', 'e', 's', '\n',
        'p', 'e', 'r', 'c', 'o', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'p', 'e', 'r', 'c', 'o', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'e', 'r', 'c', 'o', 'l', 'a', 't', 'o', 'r', '\n',
        'p', 'e', 'r', 'c', 'o', 'l', 'a', 't', 'o', 'r', 's', '\n',
        'p', 'e', 'r', 'c', 'u', 's', 's', '\n',
        'p', 'e', 'r', 'c', 'u', 's', 's', 'e', 'd', '\n',
        'p', 'e', 'r', 'c', 'u', 's', 's', 'e', 's', '\n',
        'p', 'e', 'r', 'c', 'u', 's', 's', 'i', 'n', 'g', '\n',
        'p', 'e', 'r', 'c', 'u', 's', 's', 'i', 'o', 'n', '\n',
        'p', 'e', 'r', 'c', 'u', 's', 's', 'i', 'o', 'n', 'i', 's', 't', '\n',
        'p', 'e', 'r', 'c', 'u', 's', 's', 'i', 'o', 'n', 'i', 's', 't', 's', '\n',
        'p', 'e', 'r', 'c', 'u', 's', 's', 'i', 'v', 'e', '\n',
        'p', 'e', 'r', 'c', 'u', 's', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'p', 'e', 'r', 'c', 'u', 't', 'a', 'n', 'e', 'o', 'u', 's', '\n',
        'p', 'e', 'r', 'd', 'i', 't', 'i', 'o', 'n', '\n',
        'p', 'e', 'r', 'e', 'g', 'r', 'i', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'e', 'r', 'e', 'g', 'r', 'i', 'n', 'e', '\n',
        'p', 'e', 'r', 'e', 'g', 'r', 'i', 'n', 'e', 's', '\n',
        'p', 'e', 'r', 'e', 'm', 'p', 't', 'o', 'r', 'i', 'l', 'y', '\n',
        'p', 'e', 'r', 'e', 'm', 'p', 't', 'o', 'r', 'i', 'n', 'e', 's', 's', '\n',
        'p', 'e', 'r', 'e', 'm', 'p', 't', 'o', 'r', 'y', '\n',
        'p', 'e', 'r', 'e', 'n', 'n', 'i', 'a', 'l', '\n',
        'p', 'e', 'r', 'e', 'n', 'n', 'i', 'a', 'l', 'l', 'y', '\n',
        'p', 'e', 'r', 'e', 'n', 'n', 'i', 'a', 'l', 's', '\n',
        'p', 'e', 'r', 'e', 's', 't', 'r', 'o', 'i', 'k', 'a', '\n',
        'p', 'e', 'r', 'f', 'e', 'c', 't', '\n',
        'p', 'e', 'r', 'f', 'e', 'c', 't', 'e', 'd', '\n',
        'p', 'e', 'r', 'f', 'e', 'c', 't', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'p', 'e', 'r', 'f', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'p', 'e', 'r', 'f', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'p', 'e', 'r', 'f', 'e', 'c', 't', 'i', 'o', 'n', 'i', 's', 'm', '\n',
        'p', 'e', 'r', 'f', 'e', 'c', 't', 'i', 'o', 'n', 'i', 's', 't', '\n',
        'p', 'e', 'r', 'f', 'e', 'c', 't', 'i', 'o', 'n', 'i', 's', 't', 's', '\n',
        'p', 'e', 'r', 'f', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'e', 'r', 'f', 'e', 'c', 't', 'l', 'y', '\n',
        'p', 'e', 'r', 'f', 'e', 'c', 't', 's', '\n',
        'p', 'e', 'r', 'f', 'i', 'd', 'i', 'o', 'u', 's', '\n',
        'p', 'e', 'r', 'f', 'i', 'd', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'p', 'e', 'r', 'f', 'i', 'd', 'y', '\n',
        'p', 'e', 'r', 'f', 'o', 'r', 'a', 't', 'e', '\n',
        'p', 'e', 'r', 'f', 'o', 'r', 'a', 't', 'e', 'd', '\n',
        'p', 'e', 'r', 'f', 'o', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'e', 'r', 'f', 'o', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'e', 'r', 'f', 'o', 'r', 'c', 'e', '\n',
        'p', 'e', 'r', 'f', 'o', 'r', 'm', '\n',
        'p', 'e', 'r', 'f', 'o', 'r', 'm', 'a', 'b', 'l', 'e', '\n',
        'p', 'e', 'r', 'f', 'o', 'r', 'm', 'a', 'n', 'c', 'e', '\n',
        'p', 'e', 'r', 'f', 'o', 'r', 'm', 'a', 'n', 'c', 'e', 's', '\n',
        'p', 'e', 'r', 'f', 'o', 'r', 'm', 'e', 'd', '\n',
        'p', 'e', 'r', 'f', 'o', 'r', 'm', 'e', 'r', '\n',
        'p', 'e', 'r', 'f', 'o', 'r', 'm', 'e', 'r', 's', '\n',
        'p', 'e', 'r', 'f', 'o', 'r', 'm', 'i', 'n', 'g', '\n',
        'p', 'e', 'r', 'f', 'o', 'r', 'm', 's', '\n',
        'p', 'e', 'r', 'f', 'u', 'm', 'e', '\n',
        'p', 'e', 'r', 'f', 'u', 'm', 'e', 'd', '\n',
        'p', 'e', 'r', 'f', 'u', 'm', 'e', 'r', 'y', '\n',
        'p', 'e', 'r', 'f', 'u', 'm', 'e', 's', '\n',
        'p', 'e', 'r', 'f', 'u', 'm', 'i', 'n', 'g', '\n',
        'p', 'e', 'r', 'f', 'u', 'n', 'c', 't', 'o', 'r', 'i', 'l', 'y', '\n',
        'p', 'e', 'r', 'f', 'u', 'n', 'c', 't', 'o', 'r', 'y', '\n',
        'p', 'e', 'r', 'f', 'u', 's', 'e', 'd', '\n',
        'p', 'e', 'r', 'f', 'u', 's', 'i', 'o', 'n', '\n',
        'p', 'e', 'r', 'g', 'o', 'l', 'a', '\n',
        'p', 'e', 'r', 'g', 'o', 'l', 'a', 's', '\n',
        'p', 'e', 'r', 'h', 'a', 'p', 's', '\n',
        'p', 'e', 'r', 'i', '\n',
        'p', 'e', 'r', 'i', 'a', 's', 't', 'r', 'o', 'n', '\n',
        'p', 'e', 'r', 'i', 'g', 'e', 'e', '\n',
        'p', 'e', 'r', 'i', 'g', 'l', 'a', 'c', 'i', 'a', 'l', '\n',
        'p', 'e', 'r', 'i', 'h', 'e', 'l', 'i', 'o', 'n', '\n',
        'p', 'e', 'r', 'i', 'l', '\n',
        'p', 'e', 'r', 'i', 'l', 'o', 'u', 's', '\n',
        'p', 'e', 'r', 'i', 'l', 'o', 'u', 's', 'l', 'y', '\n',
        'p', 'e', 'r', 'i', 'l', 's', '\n',
        'p', 'e', 'r', 'i', 'm', 'e', 't', 'e', 'r', '\n',
        'p', 'e', 'r', 'i', 'm', 'e', 't', 'e', 'r', 's', '\n',
        'p', 'e', 'r', 'i', 'n', 'a', 't', 'a', 'l', '\n',
        'p', 'e', 'r', 'i', 'n', 'e', 'a', 'l', '\n',
        'p', 'e', 'r', 'i', 'n', 'e', 'u', 'm', '\n',
        'p', 'e', 'r', 'i', 'o', 'd', '\n',
        'p', 'e', 'r', 'i', 'o', 'd', 'i', 'c', '\n',
        'p', 'e', 'r', 'i', 'o', 'd', 'i', 'c', 'a', 'l', '\n',
        'p', 'e', 'r', 'i', 'o', 'd', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'p', 'e', 'r', 'i', 'o', 'd', 'i', 'c', 'a', 'l', 's', '\n',
        'p', 'e', 'r', 'i', 'o', 'd', 'i', 'c', 'i', 't', 'y', '\n',
        'p', 'e', 'r', 'i', 'o', 'd', 's', '\n',
        'p', 'e', 'r', 'i', 'o', 'p', 'e', 'r', 'a', 't', 'i', 'v', 'e', '\n',
        'p', 'e', 'r', 'i', 'p', 'a', 't', 'e', 't', 'i', 'c', '\n',
        'p', 'e', 'r', 'i', 'p', 'h', 'e', 'r', 'a', 'l', '\n',
        'p', 'e', 'r', 'i', 'p', 'h', 'e', 'r', 'a', 'l', 'l', 'y', '\n',
        'p', 'e', 'r', 'i', 'p', 'h', 'e', 'r', 'a', 'l', 's', '\n',
        'p', 'e', 'r', 'i', 'p', 'h', 'e', 'r', 'i', 'e', 's', '\n',
        'p', 'e', 'r', 'i', 'p', 'h', 'e', 'r', 'y', '\n',
        'p', 'e', 'r', 'i', 'p', 'h', 'r', 'a', 's', 'i', 's', '\n',
        'p', 'e', 'r', 'i', 'p', 'h', 'r', 'a', 's', 't', 'i', 'c', '\n',
        'p', 'e', 'r', 'i', 's', 'c', 'o', 'p', 'e', '\n',
        'p', 'e', 'r', 'i', 's', 'c', 'o', 'p', 'e', 's', '\n',
        'p', 'e', 'r', 'i', 's', 'h', '\n',
        'p', 'e', 'r', 'i', 's', 'h', 'a', 'b', 'l', 'e', '\n',
        'p', 'e', 'r', 'i', 's', 'h', 'a', 'b', 'l', 'e', 's', '\n',
        'p', 'e', 'r', 'i', 's', 'h', 'e', 'd', '\n',
        'p', 'e', 'r', 'i', 's', 'h', 'e', 's', '\n',
        'p', 'e', 'r', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'p', 'e', 'r', 'i', 't', 'o', 'n', 'e', 'u', 'm', '\n',
        'p', 'e', 'r', 'j', 'u', 'r', 'e', '\n',
        'p', 'e', 'r', 'j', 'u', 'r', 'e', 'd', '\n',
        'p', 'e', 'r', 'j', 'u', 'r', 'e', 'r', '\n',
        'p', 'e', 'r', 'j', 'u', 'r', 'y', '\n',
        'p', 'e', 'r', 'k', '\n',
        'p', 'e', 'r', 'k', 'e', 'd', '\n',
        'p', 'e', 'r', 'k', 'i', 'e', 'r', '\n',
        'p', 'e', 'r', 'k', 'i', 'e', 's', 't', '\n',
        'p', 'e', 'r', 'k', 'i', 'l', 'y', '\n',
        'p', 'e', 'r', 'k', 'i', 'n', 'g', '\n',
        'p', 'e', 'r', 'k', 's', '\n',
        'p', 'e', 'r', 'k', 'y', '\n',
        'p', 'e', 'r', 'm', '\n',
        'p', 'e', 'r', 'm', 'a', 'f', 'r', 'o', 's', 't', '\n',
        'p', 'e', 'r', 'm', 'a', 'n', 'e', 'n', 'c', 'e', '\n',
        'p', 'e', 'r', 'm', 'a', 'n', 'e', 'n', 'c', 'y', '\n',
        'p', 'e', 'r', 'm', 'a', 'n', 'e', 'n', 't', '\n',
        'p', 'e', 'r', 'm', 'a', 'n', 'e', 'n', 't', 'l', 'y', '\n',
        'p', 'e', 'r', 'm', 'a', 'n', 'g', 'a', 'n', 'a', 't', 'e', '\n',
        'p', 'e', 'r', 'm', 'e', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'p', 'e', 'r', 'm', 'e', 'a', 'b', 'l', 'e', '\n',
        'p', 'e', 'r', 'm', 'e', 'a', 't', 'e', '\n',
        'p', 'e', 'r', 'm', 'e', 'a', 't', 'e', 'd', '\n',
        'p', 'e', 'r', 'm', 'e', 'a', 't', 'e', 's', '\n',
        'p', 'e', 'r', 'm', 'e', 'a', 't', 'i', 'n', 'g', '\n',
        'p', 'e', 'r', 'm', 'e', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'e', 'r', 'm', 'e', 'd', '\n',
        'p', 'e', 'r', 'm', 'i', 'n', 'g', '\n',
        'p', 'e', 'r', 'm', 'i', 's', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'p', 'e', 'r', 'm', 'i', 's', 's', 'i', 'b', 'l', 'e', '\n',
        'p', 'e', 'r', 'm', 'i', 's', 's', 'i', 'o', 'n', '\n',
        'p', 'e', 'r', 'm', 'i', 's', 's', 'i', 'o', 'n', 's', '\n',
        'p', 'e', 'r', 'm', 'i', 's', 's', 'i', 'v', 'e', '\n',
        'p', 'e', 'r', 'm', 'i', 's', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'p', 'e', 'r', 'm', 'i', 't', '\n',
        'p', 'e', 'r', 'm', 'i', 't', 's', '\n',
        'p', 'e', 'r', 'm', 'i', 't', 't', 'e', 'd', '\n',
        'p', 'e', 'r', 'm', 'i', 't', 't', 'i', 'n', 'g', '\n',
        'p', 'e', 'r', 'm', 'i', 't', 't', 'i', 'v', 'i', 't', 'y', '\n',
        'p', 'e', 'r', 'm', 's', '\n',
        'p', 'e', 'r', 'm', 'u', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'e', 'r', 'm', 'u', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'e', 'r', 'm', 'u', 't', 'e', '\n',
        'p', 'e', 'r', 'm', 'u', 't', 'e', 'd', '\n',
        'p', 'e', 'r', 'm', 'u', 't', 'e', 's', '\n',
        'p', 'e', 'r', 'm', 'u', 't', 'i', 'n', 'g', '\n',
        'p', 'e', 'r', 'n', 'i', 'c', 'i', 'o', 'u', 's', '\n',
        'p', 'e', 'r', 'n', 'i', 'c', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'p', 'e', 'r', 'o', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'e', 'r', 'o', 'x', 'i', 'd', 'a', 's', 'e', '\n',
        'p', 'e', 'r', 'o', 'x', 'i', 'd', 'e', '\n',
        'p', 'e', 'r', 'o', 'x', 'i', 'd', 'e', 's', '\n',
        'p', 'e', 'r', 'p', 'e', 'n', 'd', 'i', 'c', 'u', 'l', 'a', 'r', '\n',
        'p', 'e', 'r', 'p', 'e', 'n', 'd', 'i', 'c', 'u', 'l', 'a', 'r', 'l', 'y', '\n',
        'p', 'e', 'r', 'p', 'e', 'n', 'd', 'i', 'c', 'u', 'l', 'a', 'r', 's', '\n',
        'p', 'e', 'r', 'p', 'e', 't', 'r', 'a', 't', 'e', '\n',
        'p', 'e', 'r', 'p', 'e', 't', 'r', 'a', 't', 'e', 'd', '\n',
        'p', 'e', 'r', 'p', 'e', 't', 'r', 'a', 't', 'e', 's', '\n',
        'p', 'e', 'r', 'p', 'e', 't', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'p', 'e', 'r', 'p', 'e', 't', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'e', 'r', 'p', 'e', 't', 'r', 'a', 't', 'o', 'r', '\n',
        'p', 'e', 'r', 'p', 'e', 't', 'r', 'a', 't', 'o', 'r', 's', '\n',
        'p', 'e', 'r', 'p', 'e', 't', 'u', 'a', 'l', '\n',
        'p', 'e', 'r', 'p', 'e', 't', 'u', 'a', 'l', 'l', 'y', '\n',
        'p', 'e', 'r', 'p', 'e', 't', 'u', 'a', 't', 'e', '\n',
        'p', 'e', 'r', 'p', 'e', 't', 'u', 'a', 't', 'e', 'd', '\n',
        'p', 'e', 'r', 'p', 'e', 't', 'u', 'a', 't', 'e', 's', '\n',
        'p', 'e', 'r', 'p', 'e', 't', 'u', 'a', 't', 'i', 'n', 'g', '\n',
        'p', 'e', 'r', 'p', 'e', 't', 'u', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'e', 'r', 'p', 'e', 't', 'u', 'i', 't', 'y', '\n',
        'p', 'e', 'r', 'p', 'l', 'e', 'x', '\n',
        'p', 'e', 'r', 'p', 'l', 'e', 'x', 'e', 'd', '\n',
        'p', 'e', 'r', 'p', 'l', 'e', 'x', 'e', 'd', 'l', 'y', '\n',
        'p', 'e', 'r', 'p', 'l', 'e', 'x', 'i', 'n', 'g', '\n',
        'p', 'e', 'r', 'p', 'l', 'e', 'x', 'i', 't', 'i', 'e', 's', '\n',
        'p', 'e', 'r', 'p', 'l', 'e', 'x', 'i', 't', 'y', '\n',
        'p', 'e', 'r', 'q', 'u', 'i', 's', 'i', 't', 'e', '\n',
        'p', 'e', 'r', 'q', 'u', 'i', 's', 'i', 't', 'e', 's', '\n',
        'p', 'e', 'r', 'r', 'o', 'n', '\n',
        'p', 'e', 'r', 'r', 'y', '\n',
        'p', 'e', 'r', 's', 'e', 'c', 'u', 't', 'e', '\n',
        'p', 'e', 'r', 's', 'e', 'c', 'u', 't', 'e', 'd', '\n',
        'p', 'e', 'r', 's', 'e', 'c', 'u', 't', 'i', 'n', 'g', '\n',
        'p', 'e', 'r', 's', 'e', 'c', 'u', 't', 'i', 'o', 'n', '\n',
        'p', 'e', 'r', 's', 'e', 'c', 'u', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'e', 'r', 's', 'e', 'c', 'u', 't', 'o', 'r', '\n',
        'p', 'e', 'r', 's', 'e', 'c', 'u', 't', 'o', 'r', 's', '\n',
        'p', 'e', 'r', 's', 'e', 'v', 'e', 'r', 'a', 'n', 'c', 'e', '\n',
        'p', 'e', 'r', 's', 'e', 'v', 'e', 'r', 'e', '\n',
        'p', 'e', 'r', 's', 'e', 'v', 'e', 'r', 'e', 'd', '\n',
        'p', 'e', 'r', 's', 'e', 'v', 'e', 'r', 'e', 's', '\n',
        'p', 'e', 'r', 's', 'e', 'v', 'e', 'r', 'i', 'n', 'g', '\n',
        'p', 'e', 'r', 's', 'e', 'v', 'e', 'r', 'i', 'n', 'g', 'l', 'y', '\n',
        'p', 'e', 'r', 's', 'i', 'a', '\n',
        'p', 'e', 'r', 's', 'i', 'a', 'n', '\n',
        'p', 'e', 'r', 's', 'i', 's', 't', '\n',
        'p', 'e', 'r', 's', 'i', 's', 't', 'e', 'd', '\n',
        'p', 'e', 'r', 's', 'i', 's', 't', 'e', 'n', 'c', 'e', '\n',
        'p', 'e', 'r', 's', 'i', 's', 't', 'e', 'n', 't', '\n',
        'p', 'e', 'r', 's', 'i', 's', 't', 'e', 'n', 't', 'l', 'y', '\n',
        'p', 'e', 'r', 's', 'i', 's', 't', 'i', 'n', 'g', '\n',
        'p', 'e', 'r', 's', 'i', 's', 't', 's', '\n',
        'p', 'e', 'r', 's', 'o', 'n', '\n',
        'p', 'e', 'r', 's', 'o', 'n', 'a', '\n',
        'p', 'e', 'r', 's', 'o', 'n', 'a', 'b', 'l', 'e', '\n',
        'p', 'e', 'r', 's', 'o', 'n', 'a', 'e', '\n',
        'p', 'e', 'r', 's', 'o', 'n', 'a', 'g', 'e', '\n',
        'p', 'e', 'r', 's', 'o', 'n', 'a', 'g', 'e', 's', '\n',
        'p', 'e', 'r', 's', 'o', 'n', 'a', 'l', '\n',
        'p', 'e', 'r', 's', 'o', 'n', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'e', 'r', 's', 'o', 'n', 'a', 'l', 'i', 's', 'e', '\n',
        'p', 'e', 'r', 's', 'o', 'n', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'p', 'e', 'r', 's', 'o', 'n', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'p', 'e', 'r', 's', 'o', 'n', 'a', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'p', 'e', 'r', 's', 'o', 'n', 'a', 'l', 'i', 't', 'y', '\n',
        'p', 'e', 'r', 's', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'p', 'e', 'r', 's', 'o', 'n', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'e', 'r', 's', 'o', 'n', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'e', 'r', 's', 'o', 'n', 'i', 'f', 'i', 'e', 'd', '\n',
        'p', 'e', 'r', 's', 'o', 'n', 'i', 'f', 'i', 'e', 's', '\n',
        'p', 'e', 'r', 's', 'o', 'n', 'i', 'f', 'y', '\n',
        'p', 'e', 'r', 's', 'o', 'n', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'p', 'e', 'r', 's', 'o', 'n', 'n', 'e', 'l', '\n',
        'p', 'e', 'r', 's', 'o', 'n', 's', '\n',
        'p', 'e', 'r', 's', 'p', 'e', 'c', 't', 'i', 'v', 'e', '\n',
        'p', 'e', 'r', 's', 'p', 'e', 'c', 't', 'i', 'v', 'e', 's', '\n',
        'p', 'e', 'r', 's', 'p', 'e', 'x', '\n',
        'p', 'e', 'r', 's', 'p', 'i', 'c', 'a', 'c', 'i', 'o', 'u', 's', '\n',
        'p', 'e', 'r', 's', 'p', 'i', 'c', 'a', 'c', 'i', 't', 'y', '\n',
        'p', 'e', 'r', 's', 'p', 'i', 'c', 'u', 'i', 't', 'y', '\n',
        'p', 'e', 'r', 's', 'p', 'i', 'c', 'u', 'o', 'u', 's', '\n',
        'p', 'e', 'r', 's', 'p', 'i', 'c', 'u', 'o', 'u', 's', 'l', 'y', '\n',
        'p', 'e', 'r', 's', 'p', 'i', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'e', 'r', 's', 'p', 'i', 'r', 'e', '\n',
        'p', 'e', 'r', 's', 'p', 'i', 'r', 'i', 'n', 'g', '\n',
        'p', 'e', 'r', 's', 'u', 'a', 'd', 'e', '\n',
        'p', 'e', 'r', 's', 'u', 'a', 'd', 'e', 'd', '\n',
        'p', 'e', 'r', 's', 'u', 'a', 'd', 'e', 'r', 's', '\n',
        'p', 'e', 'r', 's', 'u', 'a', 'd', 'e', 's', '\n',
        'p', 'e', 'r', 's', 'u', 'a', 'd', 'i', 'n', 'g', '\n',
        'p', 'e', 'r', 's', 'u', 'a', 's', 'i', 'o', 'n', '\n',
        'p', 'e', 'r', 's', 'u', 'a', 's', 'i', 'o', 'n', 's', '\n',
        'p', 'e', 'r', 's', 'u', 'a', 's', 'i', 'v', 'e', '\n',
        'p', 'e', 'r', 's', 'u', 'a', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'p', 'e', 'r', 's', 'u', 'a', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'p', 'e', 'r', 't', '\n',
        'p', 'e', 'r', 't', 'a', 'i', 'n', '\n',
        'p', 'e', 'r', 't', 'a', 'i', 'n', 'e', 'd', '\n',
        'p', 'e', 'r', 't', 'a', 'i', 'n', 'i', 'n', 'g', '\n',
        'p', 'e', 'r', 't', 'a', 'i', 'n', 's', '\n',
        'p', 'e', 'r', 't', 'h', '\n',
        'p', 'e', 'r', 't', 'i', 'n', 'a', 'c', 'i', 'o', 'u', 's', '\n',
        'p', 'e', 'r', 't', 'i', 'n', 'a', 'c', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'p', 'e', 'r', 't', 'i', 'n', 'a', 'c', 'i', 't', 'y', '\n',
        'p', 'e', 'r', 't', 'i', 'n', 'e', 'n', 'c', 'e', '\n',
        'p', 'e', 'r', 't', 'i', 'n', 'e', 'n', 't', '\n',
        'p', 'e', 'r', 't', 'i', 'n', 'e', 'n', 't', 'l', 'y', '\n',
        'p', 'e', 'r', 't', 'l', 'y', '\n',
        'p', 'e', 'r', 't', 'n', 'e', 's', 's', '\n',
        'p', 'e', 'r', 't', 'u', 'r', 'b', '\n',
        'p', 'e', 'r', 't', 'u', 'r', 'b', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'e', 'r', 't', 'u', 'r', 'b', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'e', 'r', 't', 'u', 'r', 'b', 'e', 'd', '\n',
        'p', 'e', 'r', 't', 'u', 'r', 'b', 'i', 'n', 'g', '\n',
        'p', 'e', 'r', 'u', '\n',
        'p', 'e', 'r', 'u', 's', 'a', 'l', '\n',
        'p', 'e', 'r', 'u', 's', 'e', '\n',
        'p', 'e', 'r', 'u', 's', 'e', 'd', '\n',
        'p', 'e', 'r', 'u', 's', 'e', 's', '\n',
        'p', 'e', 'r', 'u', 's', 'i', 'n', 'g', '\n',
        'p', 'e', 'r', 'u', 'v', 'i', 'a', 'n', '\n',
        'p', 'e', 'r', 'v', 'a', 'd', 'e', '\n',
        'p', 'e', 'r', 'v', 'a', 'd', 'e', 'd', '\n',
        'p', 'e', 'r', 'v', 'a', 'd', 'e', 's', '\n',
        'p', 'e', 'r', 'v', 'a', 'd', 'i', 'n', 'g', '\n',
        'p', 'e', 'r', 'v', 'a', 's', 'i', 'v', 'e', '\n',
        'p', 'e', 'r', 'v', 'a', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'p', 'e', 'r', 'v', 'e', 'r', 's', 'e', '\n',
        'p', 'e', 'r', 'v', 'e', 'r', 's', 'e', 'l', 'y', '\n',
        'p', 'e', 'r', 'v', 'e', 'r', 's', 'e', 'n', 'e', 's', 's', '\n',
        'p', 'e', 'r', 'v', 'e', 'r', 's', 'i', 'o', 'n', '\n',
        'p', 'e', 'r', 'v', 'e', 'r', 's', 'i', 'o', 'n', 's', '\n',
        'p', 'e', 'r', 'v', 'e', 'r', 's', 'i', 't', 'y', '\n',
        'p', 'e', 'r', 'v', 'e', 'r', 't', '\n',
        'p', 'e', 'r', 'v', 'e', 'r', 't', 'e', 'd', '\n',
        'p', 'e', 'r', 'v', 'e', 'r', 't', 'i', 'n', 'g', '\n',
        'p', 'e', 'r', 'v', 'e', 'r', 't', 's', '\n',
        'p', 'e', 's', 'e', 't', 'a', '\n',
        'p', 'e', 's', 'e', 't', 'a', 's', '\n',
        'p', 'e', 's', 'k', 'y', '\n',
        'p', 'e', 's', 's', 'i', 'm', 'i', 's', 'm', '\n',
        'p', 'e', 's', 's', 'i', 'm', 'i', 's', 't', '\n',
        'p', 'e', 's', 's', 'i', 'm', 'i', 's', 't', 'i', 'c', '\n',
        'p', 'e', 's', 's', 'i', 'm', 'i', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'p', 'e', 's', 's', 'i', 'm', 'i', 's', 't', 's', '\n',
        'p', 'e', 's', 't', '\n',
        'p', 'e', 's', 't', 'e', 'r', '\n',
        'p', 'e', 's', 't', 'e', 'r', 'e', 'd', '\n',
        'p', 'e', 's', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'p', 'e', 's', 't', 'i', 'c', 'i', 'd', 'e', '\n',
        'p', 'e', 's', 't', 'i', 'c', 'i', 'd', 'e', 's', '\n',
        'p', 'e', 's', 't', 'i', 'l', 'e', 'n', 'c', 'e', '\n',
        'p', 'e', 's', 't', 'i', 'l', 'e', 'n', 't', '\n',
        'p', 'e', 's', 't', 'i', 'l', 'e', 'n', 't', 'i', 'a', 'l', '\n',
        'p', 'e', 's', 't', 'l', 'e', '\n',
        'p', 'e', 's', 't', 's', '\n',
        'p', 'e', 't', '\n',
        'p', 'e', 't', 'a', 'l', '\n',
        'p', 'e', 't', 'a', 'l', 's', '\n',
        'p', 'e', 't', 'a', 'r', 'd', '\n',
        'p', 'e', 't', 'e', 'r', '\n',
        'p', 'e', 't', 'e', 'r', 'e', 'd', '\n',
        'p', 'e', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'p', 'e', 't', 'e', 'r', 's', '\n',
        'p', 'e', 't', 'h', 'i', 'd', 'i', 'n', 'e', '\n',
        'p', 'e', 't', 'i', 't', '\n',
        'p', 'e', 't', 'i', 't', 'e', '\n',
        'p', 'e', 't', 'i', 't', 'i', 'o', 'n', '\n',
        'p', 'e', 't', 'i', 't', 'i', 'o', 'n', 'e', 'd', '\n',
        'p', 'e', 't', 'i', 't', 'i', 'o', 'n', 'e', 'r', '\n',
        'p', 'e', 't', 'i', 't', 'i', 'o', 'n', 'e', 'r', 's', '\n',
        'p', 'e', 't', 'i', 't', 'i', 'o', 'n', 'i', 'n', 'g', '\n',
        'p', 'e', 't', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'e', 't', 'r', 'e', 'l', '\n',
        'p', 'e', 't', 'r', 'e', 'l', 's', '\n',
        'p', 'e', 't', 'r', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'e', 't', 'r', 'i', 'f', 'i', 'e', 'd', '\n',
        'p', 'e', 't', 'r', 'i', 'f', 'i', 'e', 's', '\n',
        'p', 'e', 't', 'r', 'i', 'f', 'y', '\n',
        'p', 'e', 't', 'r', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'p', 'e', 't', 'r', 'o', 'c', 'h', 'e', 'm', 'i', 'c', 'a', 'l', '\n',
        'p', 'e', 't', 'r', 'o', 'c', 'h', 'e', 'm', 'i', 'c', 'a', 'l', 's', '\n',
        'p', 'e', 't', 'r', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', '\n',
        'p', 'e', 't', 'r', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', 'a', 'l', '\n',
        'p', 'e', 't', 'r', 'o', 'l', '\n',
        'p', 'e', 't', 'r', 'o', 'l', 'e', 'u', 'm', '\n',
        'p', 'e', 't', 'r', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'p', 'e', 't', 'r', 'o', 'l', 'o', 'g', 'y', '\n',
        'p', 'e', 't', 's', '\n',
        'p', 'e', 't', 't', 'e', 'd', '\n',
        'p', 'e', 't', 't', 'i', 'c', 'o', 'a', 't', '\n',
        'p', 'e', 't', 't', 'i', 'c', 'o', 'a', 't', 's', '\n',
        'p', 'e', 't', 't', 'i', 'e', 'r', '\n',
        'p', 'e', 't', 't', 'i', 'e', 's', 't', '\n',
        'p', 'e', 't', 't', 'i', 'f', 'o', 'g', 'g', 'e', 'r', 's', '\n',
        'p', 'e', 't', 't', 'i', 'f', 'o', 'g', 'g', 'i', 'n', 'g', '\n',
        'p', 'e', 't', 't', 'i', 'n', 'e', 's', 's', '\n',
        'p', 'e', 't', 't', 'i', 'n', 'g', '\n',
        'p', 'e', 't', 't', 'i', 's', 'h', '\n',
        'p', 'e', 't', 't', 'i', 's', 'h', 'l', 'y', '\n',
        'p', 'e', 't', 't', 'i', 's', 'h', 'n', 'e', 's', 's', '\n',
        'p', 'e', 't', 't', 'y', '\n',
        'p', 'e', 't', 'u', 'l', 'a', 'n', 'c', 'e', '\n',
        'p', 'e', 't', 'u', 'l', 'a', 'n', 't', '\n',
        'p', 'e', 't', 'u', 'l', 'a', 'n', 't', 'l', 'y', '\n',
        'p', 'e', 't', 'u', 'n', 'i', 'a', '\n',
        'p', 'e', 't', 'u', 'n', 'i', 'a', 's', '\n',
        'p', 'e', 'w', '\n',
        'p', 'e', 'w', 's', '\n',
        'p', 'e', 'w', 't', 'e', 'r', '\n',
        'p', 'h', 'a', 'l', 'a', 'n', 'x', '\n',
        'p', 'h', 'a', 'n', 't', 'a', 's', 'y', '\n',
        'p', 'h', 'a', 'n', 't', 'o', 'm', '\n',
        'p', 'h', 'a', 'n', 't', 'o', 'm', 's', '\n',
        'p', 'h', 'a', 'r', 'a', 'o', 'h', '\n',
        'p', 'h', 'a', 'r', 'm', 'a', 'c', 'e', 'u', 't', 'i', 'c', 'a', 'l', '\n',
        'p', 'h', 'a', 'r', 'm', 'a', 'c', 'e', 'u', 't', 'i', 'c', 'a', 'l', 's', '\n',
        'p', 'h', 'a', 'r', 'm', 'a', 'c', 'i', 'e', 's', '\n',
        'p', 'h', 'a', 'r', 'm', 'a', 'c', 'i', 's', 't', '\n',
        'p', 'h', 'a', 'r', 'm', 'a', 'c', 'i', 's', 't', 's', '\n',
        'p', 'h', 'a', 'r', 'm', 'a', 'c', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'p', 'h', 'a', 'r', 'm', 'a', 'c', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'p', 'h', 'a', 'r', 'm', 'a', 'c', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'p', 'h', 'a', 'r', 'm', 'a', 'c', 'o', 'l', 'o', 'g', 'y', '\n',
        'p', 'h', 'a', 'r', 'm', 'a', 'c', 'y', '\n',
        'p', 'h', 'a', 'r', 'y', 'n', 'x', '\n',
        'p', 'h', 'a', 's', 'e', '\n',
        'p', 'h', 'a', 's', 'e', 'd', '\n',
        'p', 'h', 'a', 's', 'e', 's', '\n',
        'p', 'h', 'a', 's', 'i', 'n', 'g', '\n',
        'p', 'h', 'e', 'a', 's', 'a', 'n', 't', '\n',
        'p', 'h', 'e', 'a', 's', 'a', 'n', 't', 's', '\n',
        'p', 'h', 'e', 'n', 'o', 'l', '\n',
        'p', 'h', 'e', 'n', 'o', 'l', 's', '\n',
        'p', 'h', 'e', 'n', 'o', 'm', 'e', 'n', 'a', '\n',
        'p', 'h', 'e', 'n', 'o', 'm', 'e', 'n', 'a', 'l', '\n',
        'p', 'h', 'e', 'n', 'o', 'm', 'e', 'n', 'a', 'l', 'l', 'y', '\n',
        'p', 'h', 'e', 'n', 'o', 'm', 'e', 'n', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'p', 'h', 'e', 'n', 'o', 'm', 'e', 'n', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'p', 'h', 'e', 'n', 'o', 'm', 'e', 'n', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'p', 'h', 'e', 'n', 'o', 'm', 'e', 'n', 'o', 'l', 'o', 'g', 'y', '\n',
        'p', 'h', 'e', 'n', 'o', 'm', 'e', 'n', 'o', 'n', '\n',
        'p', 'h', 'e', 'n', 'o', 't', 'y', 'p', 'e', '\n',
        'p', 'h', 'e', 'n', 'o', 't', 'y', 'p', 'e', 's', '\n',
        'p', 'h', 'e', 'n', 'y', 'l', 'a', 'l', 'a', 'n', 'i', 'n', 'e', '\n',
        'p', 'h', 'e', 'r', 'o', 'm', 'o', 'n', 'e', '\n',
        'p', 'h', 'e', 'r', 'o', 'm', 'o', 'n', 'e', 's', '\n',
        'p', 'h', 'e', 'w', '\n',
        'p', 'h', 'i', 'l', 'a', 'n', 't', 'h', 'r', 'o', 'p', 'i', 'c', '\n',
        'p', 'h', 'i', 'l', 'a', 'n', 't', 'h', 'r', 'o', 'p', 'i', 's', 't', '\n',
        'p', 'h', 'i', 'l', 'a', 'n', 't', 'h', 'r', 'o', 'p', 'i', 's', 't', 's', '\n',
        'p', 'h', 'i', 'l', 'a', 'n', 't', 'h', 'r', 'o', 'p', 'y', '\n',
        'p', 'h', 'i', 'l', 'a', 't', 'e', 'l', 'i', 'c', '\n',
        'p', 'h', 'i', 'l', 'a', 't', 'e', 'l', 'i', 's', 't', 's', '\n',
        'p', 'h', 'i', 'l', 'a', 't', 'e', 'l', 'y', '\n',
        'p', 'h', 'i', 'l', 'h', 'a', 'r', 'm', 'o', 'n', 'i', 'c', '\n',
        'p', 'h', 'i', 'l', 'i', 's', 't', 'i', 'n', 'e', '\n',
        'p', 'h', 'i', 'l', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'p', 'h', 'i', 'l', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'p', 'h', 'i', 'l', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'p', 'h', 'i', 'l', 'o', 'l', 'o', 'g', 'y', '\n',
        'p', 'h', 'i', 'l', 'o', 's', 'o', 'p', 'h', 'e', 'r', '\n',
        'p', 'h', 'i', 'l', 'o', 's', 'o', 'p', 'h', 'e', 'r', 's', '\n',
        'p', 'h', 'i', 'l', 'o', 's', 'o', 'p', 'h', 'i', 'c', '\n',
        'p', 'h', 'i', 'l', 'o', 's', 'o', 'p', 'h', 'i', 'c', 'a', 'l', '\n',
        'p', 'h', 'i', 'l', 'o', 's', 'o', 'p', 'h', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'p', 'h', 'i', 'l', 'o', 's', 'o', 'p', 'h', 'i', 'e', 's', '\n',
        'p', 'h', 'i', 'l', 'o', 's', 'o', 'p', 'h', 'i', 's', 'e', '\n',
        'p', 'h', 'i', 'l', 'o', 's', 'o', 'p', 'h', 'i', 's', 'i', 'n', 'g', '\n',
        'p', 'h', 'i', 'l', 'o', 's', 'o', 'p', 'h', 'y', '\n',
        'p', 'h', 'l', 'e', 'b', 'o', 't', 'o', 'm', 'y', '\n',
        'p', 'h', 'l', 'e', 'g', 'm', '\n',
        'p', 'h', 'l', 'e', 'g', 'm', 'a', 't', 'i', 'c', '\n',
        'p', 'h', 'l', 'e', 'g', 'm', 'a', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'p', 'h', 'l', 'o', 'g', 'i', 's', 't', 'o', 'n', '\n',
        'p', 'h', 'l', 'o', 'x', '\n',
        'p', 'h', 'o', 'b', 'i', 'a', '\n',
        'p', 'h', 'o', 'b', 'i', 'a', 's', '\n',
        'p', 'h', 'o', 'b', 'i', 'c', '\n',
        'p', 'h', 'o', 'e', 'n', 'i', 'x', '\n',
        'p', 'h', 'o', 'e', 'n', 'i', 'x', 'e', 's', '\n',
        'p', 'h', 'o', 'n', 'e', '\n',
        'p', 'h', 'o', 'n', 'e', 'd', '\n',
        'p', 'h', 'o', 'n', 'e', 'm', 'e', '\n',
        'p', 'h', 'o', 'n', 'e', 'm', 'e', 's', '\n',
        'p', 'h', 'o', 'n', 'e', 'm', 'i', 'c', '\n',
        'p', 'h', 'o', 'n', 'e', 'm', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'p', 'h', 'o', 'n', 'e', 'r', '\n',
        'p', 'h', 'o', 'n', 'e', 's', '\n',
        'p', 'h', 'o', 'n', 'e', 't', 'i', 'c', '\n',
        'p', 'h', 'o', 'n', 'e', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'p', 'h', 'o', 'n', 'e', 't', 'i', 'c', 'i', 'a', 'n', 's', '\n',
        'p', 'h', 'o', 'n', 'e', 't', 'i', 'c', 'i', 's', 't', '\n',
        'p', 'h', 'o', 'n', 'e', 't', 'i', 'c', 's', '\n',
        'p', 'h', 'o', 'n', 'e', 'y', '\n',
        'p', 'h', 'o', 'n', 'e', 'y', 's', '\n',
        'p', 'h', 'o', 'n', 'i', 'n', 'g', '\n',
        'p', 'h', 'o', 'n', 'o', 'g', 'r', 'a', 'p', 'h', '\n',
        'p', 'h', 'o', 'n', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', '\n',
        'p', 'h', 'o', 'n', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'p', 'h', 'o', 'n', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'p', 'h', 'o', 'n', 'o', 'l', 'o', 'g', 'y', '\n',
        'p', 'h', 'o', 'n', 'o', 'n', '\n',
        'p', 'h', 'o', 'n', 'y', '\n',
        'p', 'h', 'o', 'o', 'e', 'y', '\n',
        'p', 'h', 'o', 's', 'p', 'h', 'a', 't', 'a', 's', 'e', '\n',
        'p', 'h', 'o', 's', 'p', 'h', 'a', 't', 'e', '\n',
        'p', 'h', 'o', 's', 'p', 'h', 'a', 't', 'e', 's', '\n',
        'p', 'h', 'o', 's', 'p', 'h', 'a', 't', 'i', 'c', '\n',
        'p', 'h', 'o', 's', 'p', 'h', 'o', 'l', 'i', 'p', 'i', 'd', 's', '\n',
        'p', 'h', 'o', 's', 'p', 'h', 'o', 'r', '\n',
        'p', 'h', 'o', 's', 'p', 'h', 'o', 'r', 'e', 's', 'c', 'e', 'n', 'c', 'e', '\n',
        'p', 'h', 'o', 's', 'p', 'h', 'o', 'r', 'e', 's', 'c', 'e', 'n', 't', '\n',
        'p', 'h', 'o', 's', 'p', 'h', 'o', 'r', 'i', 'c', '\n',
        'p', 'h', 'o', 's', 'p', 'h', 'o', 'r', 'o', 'u', 's', '\n',
        'p', 'h', 'o', 's', 'p', 'h', 'o', 'r', 's', '\n',
        'p', 'h', 'o', 's', 'p', 'h', 'o', 'r', 'u', 's', '\n',
        'p', 'h', 'o', 't', 'o', '\n',
        'p', 'h', 'o', 't', 'o', 'c', 'e', 'l', 'l', 's', '\n',
        'p', 'h', 'o', 't', 'o', 'c', 'h', 'e', 'm', 'i', 'c', 'a', 'l', '\n',
        'p', 'h', 'o', 't', 'o', 'c', 'h', 'e', 'm', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'p', 'h', 'o', 't', 'o', 'c', 'h', 'e', 'm', 'i', 's', 't', 'r', 'y', '\n',
        'p', 'h', 'o', 't', 'o', 'c', 'o', 'p', 'i', 'e', 'd', '\n',
        'p', 'h', 'o', 't', 'o', 'c', 'o', 'p', 'i', 'e', 'r', '\n',
        'p', 'h', 'o', 't', 'o', 'c', 'o', 'p', 'i', 'e', 'r', 's', '\n',
        'p', 'h', 'o', 't', 'o', 'c', 'o', 'p', 'i', 'e', 's', '\n',
        'p', 'h', 'o', 't', 'o', 'c', 'o', 'p', 'y', '\n',
        'p', 'h', 'o', 't', 'o', 'c', 'o', 'p', 'y', 'i', 'n', 'g', '\n',
        'p', 'h', 'o', 't', 'o', 'e', 'l', 'e', 'c', 't', 'r', 'i', 'c', '\n',
        'p', 'h', 'o', 't', 'o', 'e', 'l', 'e', 'c', 't', 'r', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'p', 'h', 'o', 't', 'o', 'g', 'e', 'n', 'i', 'c', '\n',
        'p', 'h', 'o', 't', 'o', 'g', 'r', 'a', 'p', 'h', '\n',
        'p', 'h', 'o', 't', 'o', 'g', 'r', 'a', 'p', 'h', 'e', 'd', '\n',
        'p', 'h', 'o', 't', 'o', 'g', 'r', 'a', 'p', 'h', 'e', 'r', '\n',
        'p', 'h', 'o', 't', 'o', 'g', 'r', 'a', 'p', 'h', 'e', 'r', 's', '\n',
        'p', 'h', 'o', 't', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', '\n',
        'p', 'h', 'o', 't', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'p', 'h', 'o', 't', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'n', 'g', '\n',
        'p', 'h', 'o', 't', 'o', 'g', 'r', 'a', 'p', 'h', 's', '\n',
        'p', 'h', 'o', 't', 'o', 'g', 'r', 'a', 'p', 'h', 'y', '\n',
        'p', 'h', 'o', 't', 'o', 'l', 'y', 's', 'i', 's', '\n',
        'p', 'h', 'o', 't', 'o', 'l', 'y', 't', 'i', 'c', '\n',
        'p', 'h', 'o', 't', 'o', 'm', 'e', 't', 'r', 'i', 'c', '\n',
        'p', 'h', 'o', 't', 'o', 'm', 'e', 't', 'r', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'p', 'h', 'o', 't', 'o', 'm', 'e', 't', 'r', 'y', '\n',
        'p', 'h', 'o', 't', 'o', 'm', 'u', 'l', 't', 'i', 'p', 'l', 'i', 'e', 'r', '\n',
        'p', 'h', 'o', 't', 'o', 'n', '\n',
        'p', 'h', 'o', 't', 'o', 'n', 's', '\n',
        'p', 'h', 'o', 't', 'o', 'r', 'e', 'c', 'e', 'p', 't', 'o', 'r', '\n',
        'p', 'h', 'o', 't', 'o', 's', '\n',
        'p', 'h', 'o', 't', 'o', 's', 'e', 'n', 's', 'i', 't', 'i', 'v', 'e', '\n',
        'p', 'h', 'o', 't', 'o', 's', 'p', 'h', 'e', 'r', 'e', '\n',
        'p', 'h', 'o', 't', 'o', 's', 't', 'a', 't', '\n',
        'p', 'h', 'o', 't', 'o', 's', 'y', 'n', 't', 'h', 'e', 's', 'i', 's', '\n',
        'p', 'h', 'o', 't', 'o', 's', 'y', 'n', 't', 'h', 'e', 's', 'i', 's', 'i', 'n', 'g', '\n',
        'p', 'h', 'o', 't', 'o', 's', 'y', 'n', 't', 'h', 'e', 't', 'i', 'c', '\n',
        'p', 'h', 'o', 't', 'o', 's', 'y', 'n', 't', 'h', 'e', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'p', 'h', 'o', 't', 'o', 't', 'y', 'p', 'e', 's', 'e', 't', 't', 'e', 'r', '\n',
        'p', 'h', 'o', 't', 'o', 't', 'y', 'p', 'e', 's', 'e', 't', 't', 'i', 'n', 'g', '\n',
        'p', 'h', 'o', 't', 'o', 'v', 'o', 'l', 't', 'a', 'i', 'c', '\n',
        'p', 'h', 'r', 'a', 's', 'a', 'l', '\n',
        'p', 'h', 'r', 'a', 's', 'e', '\n',
        'p', 'h', 'r', 'a', 's', 'e', 'b', 'o', 'o', 'k', '\n',
        'p', 'h', 'r', 'a', 's', 'e', 'd', '\n',
        'p', 'h', 'r', 'a', 's', 'e', 'o', 'l', 'o', 'g', 'y', '\n',
        'p', 'h', 'r', 'a', 's', 'e', 's', '\n',
        'p', 'h', 'r', 'a', 's', 'i', 'n', 'g', '\n',
        'p', 'h', 'r', 'e', 'n', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'p', 'h', 'r', 'e', 'n', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'p', 'h', 'r', 'e', 'n', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'p', 'h', 'r', 'e', 'n', 'o', 'l', 'o', 'g', 'y', '\n',
        'p', 'h', 'y', 'l', 'a', '\n',
        'p', 'h', 'y', 'l', 'a', 'c', 't', 'e', 'r', 'y', '\n',
        'p', 'h', 'y', 'l', 'o', 'g', 'e', 'n', 'e', 't', 'i', 'c', '\n',
        'p', 'h', 'y', 'l', 'o', 'g', 'e', 'n', 'y', '\n',
        'p', 'h', 'y', 'l', 'u', 'm', '\n',
        'p', 'h', 'y', 's', 'i', 'c', '\n',
        'p', 'h', 'y', 's', 'i', 'c', 'a', 'l', '\n',
        'p', 'h', 'y', 's', 'i', 'c', 'a', 'l', 'i', 't', 'y', '\n',
        'p', 'h', 'y', 's', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'p', 'h', 'y', 's', 'i', 'c', 'i', 'a', 'n', '\n',
        'p', 'h', 'y', 's', 'i', 'c', 'i', 'a', 'n', 's', '\n',
        'p', 'h', 'y', 's', 'i', 'c', 'i', 's', 't', '\n',
        'p', 'h', 'y', 's', 'i', 'c', 'i', 's', 't', 's', '\n',
        'p', 'h', 'y', 's', 'i', 'c', 's', '\n',
        'p', 'h', 'y', 's', 'i', 'o', '\n',
        'p', 'h', 'y', 's', 'i', 'o', 'g', 'n', 'o', 'm', 'i', 'e', 's', '\n',
        'p', 'h', 'y', 's', 'i', 'o', 'g', 'n', 'o', 'm', 'y', '\n',
        'p', 'h', 'y', 's', 'i', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'p', 'h', 'y', 's', 'i', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'p', 'h', 'y', 's', 'i', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'p', 'h', 'y', 's', 'i', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'p', 'h', 'y', 's', 'i', 'o', 'l', 'o', 'g', 'y', '\n',
        'p', 'h', 'y', 's', 'i', 'o', 't', 'h', 'e', 'r', 'a', 'p', 'i', 's', 't', '\n',
        'p', 'h', 'y', 's', 'i', 'o', 't', 'h', 'e', 'r', 'a', 'p', 'i', 's', 't', 's', '\n',
        'p', 'h', 'y', 's', 'i', 'o', 't', 'h', 'e', 'r', 'a', 'p', 'y', '\n',
        'p', 'h', 'y', 's', 'i', 'q', 'u', 'e', '\n',
        'p', 'h', 'y', 't', 'o', 'p', 'l', 'a', 'n', 'k', 't', 'o', 'n', '\n',
        'p', 'i', '\n',
        'p', 'i', 'a', 'n', 'i', 's', 's', 'i', 'm', 'o', '\n',
        'p', 'i', 'a', 'n', 'i', 's', 't', '\n',
        'p', 'i', 'a', 'n', 'i', 's', 't', 'i', 'c', '\n',
        'p', 'i', 'a', 'n', 'i', 's', 't', 's', '\n',
        'p', 'i', 'a', 'n', 'o', '\n',
        'p', 'i', 'a', 'n', 'o', 'f', 'o', 'r', 't', 'e', '\n',
        'p', 'i', 'a', 'n', 'o', 'l', 'a', '\n',
        'p', 'i', 'a', 'z', 'z', 'a', '\n',
        'p', 'i', 'a', 'z', 'z', 'a', 's', '\n',
        'p', 'i', 'c', 'a', '\n',
        'p', 'i', 'c', 'a', 'r', 'e', 's', 'q', 'u', 'e', '\n',
        'p', 'i', 'c', 'a', 's', 's', 'o', '\n',
        'p', 'i', 'c', 'c', 'o', 'l', 'o', '\n',
        'p', 'i', 'c', 'k', '\n',
        'p', 'i', 'c', 'k', 'a', 'x', 'e', '\n',
        'p', 'i', 'c', 'k', 'a', 'x', 'e', 's', '\n',
        'p', 'i', 'c', 'k', 'e', 'd', '\n',
        'p', 'i', 'c', 'k', 'e', 'r', '\n',
        'p', 'i', 'c', 'k', 'e', 'r', 'e', 'l', '\n',
        'p', 'i', 'c', 'k', 'e', 'r', 'e', 'l', 's', '\n',
        'p', 'i', 'c', 'k', 'e', 'r', 's', '\n',
        'p', 'i', 'c', 'k', 'e', 't', '\n',
        'p', 'i', 'c', 'k', 'e', 't', 'e', 'd', '\n',
        'p', 'i', 'c', 'k', 'e', 't', 'i', 'n', 'g', '\n',
        'p', 'i', 'c', 'k', 'e', 't', 's', '\n',
        'p', 'i', 'c', 'k', 'i', 'n', 'g', '\n',
        'p', 'i', 'c', 'k', 'i', 'n', 'g', 's', '\n',
        'p', 'i', 'c', 'k', 'l', 'e', '\n',
        'p', 'i', 'c', 'k', 'l', 'e', 'd', '\n',
        'p', 'i', 'c', 'k', 'l', 'e', 's', '\n',
        'p', 'i', 'c', 'k', 'l', 'i', 'n', 'g', '\n',
        'p', 'i', 'c', 'k', 'p', 'o', 'c', 'k', 'e', 't', '\n',
        'p', 'i', 'c', 'k', 'p', 'o', 'c', 'k', 'e', 't', 'i', 'n', 'g', '\n',
        'p', 'i', 'c', 'k', 'p', 'o', 'c', 'k', 'e', 't', 's', '\n',
        'p', 'i', 'c', 'k', 's', '\n',
        'p', 'i', 'c', 'k', 'u', 'p', '\n',
        'p', 'i', 'c', 'k', 'u', 'p', 's', '\n',
        'p', 'i', 'c', 'n', 'i', 'c', '\n',
        'p', 'i', 'c', 'n', 'i', 'c', 'k', 'e', 'd', '\n',
        'p', 'i', 'c', 'n', 'i', 'c', 'k', 'e', 'r', 's', '\n',
        'p', 'i', 'c', 'n', 'i', 'c', 'k', 'i', 'n', 'g', '\n',
        'p', 'i', 'c', 'n', 'i', 'c', 's', '\n',
        'p', 'i', 'c', 'o', 's', 'e', 'c', 'o', 'n', 'd', 's', '\n',
        'p', 'i', 'c', 't', 'o', 'g', 'r', 'a', 'm', '\n',
        'p', 'i', 'c', 't', 'o', 'g', 'r', 'a', 'm', 's', '\n',
        'p', 'i', 'c', 't', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', '\n',
        'p', 'i', 'c', 't', 'o', 'r', 'i', 'a', 'l', '\n',
        'p', 'i', 'c', 't', 'o', 'r', 'i', 'a', 'l', 'l', 'y', '\n',
        'p', 'i', 'c', 't', 'u', 'r', 'a', 'l', '\n',
        'p', 'i', 'c', 't', 'u', 'r', 'e', '\n',
        'p', 'i', 'c', 't', 'u', 'r', 'e', 'd', '\n',
        'p', 'i', 'c', 't', 'u', 'r', 'e', 's', '\n',
        'p', 'i', 'c', 't', 'u', 'r', 'e', 's', 'q', 'u', 'e', '\n',
        'p', 'i', 'c', 't', 'u', 'r', 'e', 's', 'q', 'u', 'e', 'l', 'y', '\n',
        'p', 'i', 'c', 't', 'u', 'r', 'e', 's', 'q', 'u', 'e', 'n', 'e', 's', 's', '\n',
        'p', 'i', 'c', 't', 'u', 'r', 'i', 'n', 'g', '\n',
        'p', 'i', 'd', 'g', 'i', 'n', '\n',
        'p', 'i', 'e', '\n',
        'p', 'i', 'e', 'b', 'a', 'l', 'd', '\n',
        'p', 'i', 'e', 'c', 'e', '\n',
        'p', 'i', 'e', 'c', 'e', 'd', '\n',
        'p', 'i', 'e', 'c', 'e', 'm', 'e', 'a', 'l', '\n',
        'p', 'i', 'e', 'c', 'e', 's', '\n',
        'p', 'i', 'e', 'c', 'e', 'w', 'i', 's', 'e', '\n',
        'p', 'i', 'e', 'c', 'e', 'w', 'o', 'r', 'k', '\n',
        'p', 'i', 'e', 'c', 'i', 'n', 'g', '\n',
        'p', 'i', 'e', 'd', '\n',
        'p', 'i', 'e', 'r', '\n',
        'p', 'i', 'e', 'r', 'c', 'e', '\n',
        'p', 'i', 'e', 'r', 'c', 'e', 'd', '\n',
        'p', 'i', 'e', 'r', 'c', 'e', 'r', '\n',
        'p', 'i', 'e', 'r', 'c', 'e', 'r', 's', '\n',
        'p', 'i', 'e', 'r', 'c', 'e', 's', '\n',
        'p', 'i', 'e', 'r', 'c', 'i', 'n', 'g', '\n',
        'p', 'i', 'e', 'r', 'c', 'i', 'n', 'g', 'l', 'y', '\n',
        'p', 'i', 'e', 'r', 's', '\n',
        'p', 'i', 'e', 's', '\n',
        'p', 'i', 'e', 't', 'a', '\n',
        'p', 'i', 'e', 't', 'y', '\n',
        'p', 'i', 'e', 'z', 'o', 'e', 'l', 'e', 'c', 't', 'r', 'i', 'c', '\n',
        'p', 'i', 'f', 'f', 'l', 'e', '\n',
        'p', 'i', 'g', '\n',
        'p', 'i', 'g', 'e', 'o', 'n', '\n',
        'p', 'i', 'g', 'e', 'o', 'n', 's', '\n',
        'p', 'i', 'g', 'g', 'e', 'r', 'y', '\n',
        'p', 'i', 'g', 'g', 'i', 's', 'h', '\n',
        'p', 'i', 'g', 'g', 'y', '\n',
        'p', 'i', 'g', 'g', 'y', 'b', 'a', 'c', 'k', '\n',
        'p', 'i', 'g', 'l', 'e', 't', '\n',
        'p', 'i', 'g', 'l', 'e', 't', 's', '\n',
        'p', 'i', 'g', 'm', 'e', 'n', 't', '\n',
        'p', 'i', 'g', 'm', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'i', 'g', 'm', 'e', 'n', 't', 'e', 'd', '\n',
        'p', 'i', 'g', 'm', 'e', 'n', 't', 's', '\n',
        'p', 'i', 'g', 's', '\n',
        'p', 'i', 'g', 's', 't', 'i', 'e', 's', '\n',
        'p', 'i', 'g', 's', 't', 'y', '\n',
        'p', 'i', 'g', 't', 'a', 'i', 'l', '\n',
        'p', 'i', 'g', 't', 'a', 'i', 'l', 'e', 'd', '\n',
        'p', 'i', 'g', 't', 'a', 'i', 'l', 's', '\n',
        'p', 'i', 'k', 'e', '\n',
        'p', 'i', 'k', 'e', 'm', 'e', 'n', '\n',
        'p', 'i', 'k', 'e', 's', '\n',
        'p', 'i', 'k', 'e', 's', 't', 'a', 'f', 'f', '\n',
        'p', 'i', 'l', 'a', 's', 't', 'e', 'r', '\n',
        'p', 'i', 'l', 'a', 's', 't', 'e', 'r', 's', '\n',
        'p', 'i', 'l', 'c', 'h', 'a', 'r', 'd', '\n',
        'p', 'i', 'l', 'c', 'h', 'a', 'r', 'd', 's', '\n',
        'p', 'i', 'l', 'e', '\n',
        'p', 'i', 'l', 'e', 'd', '\n',
        'p', 'i', 'l', 'e', 's', '\n',
        'p', 'i', 'l', 'e', 'u', 'p', '\n',
        'p', 'i', 'l', 'f', 'e', 'r', '\n',
        'p', 'i', 'l', 'f', 'e', 'r', 'e', 'd', '\n',
        'p', 'i', 'l', 'f', 'e', 'r', 'i', 'n', 'g', '\n',
        'p', 'i', 'l', 'g', 'r', 'i', 'm', '\n',
        'p', 'i', 'l', 'g', 'r', 'i', 'm', 'a', 'g', 'e', '\n',
        'p', 'i', 'l', 'g', 'r', 'i', 'm', 'a', 'g', 'e', 's', '\n',
        'p', 'i', 'l', 'g', 'r', 'i', 'm', 's', '\n',
        'p', 'i', 'l', 'i', 'n', 'g', '\n',
        'p', 'i', 'l', 'l', '\n',
        'p', 'i', 'l', 'l', 'a', 'g', 'e', '\n',
        'p', 'i', 'l', 'l', 'a', 'g', 'e', 'd', '\n',
        'p', 'i', 'l', 'l', 'a', 'g', 'e', 's', '\n',
        'p', 'i', 'l', 'l', 'a', 'g', 'i', 'n', 'g', '\n',
        'p', 'i', 'l', 'l', 'a', 'r', '\n',
        'p', 'i', 'l', 'l', 'a', 'r', 'e', 'd', '\n',
        'p', 'i', 'l', 'l', 'a', 'r', 's', '\n',
        'p', 'i', 'l', 'l', 'b', 'o', 'x', '\n',
        'p', 'i', 'l', 'l', 'i', 'o', 'n', '\n',
        'p', 'i', 'l', 'l', 'o', 'r', 'i', 'e', 'd', '\n',
        'p', 'i', 'l', 'l', 'o', 'r', 'i', 'e', 's', '\n',
        'p', 'i', 'l', 'l', 'o', 'r', 'y', '\n',
        'p', 'i', 'l', 'l', 'o', 'w', '\n',
        'p', 'i', 'l', 'l', 'o', 'w', 'c', 'a', 's', 'e', '\n',
        'p', 'i', 'l', 'l', 'o', 'w', 'c', 'a', 's', 'e', 's', '\n',
        'p', 'i', 'l', 'l', 'o', 'w', 'e', 'd', '\n',
        'p', 'i', 'l', 'l', 'o', 'w', 's', '\n',
        'p', 'i', 'l', 'l', 's', '\n',
        'p', 'i', 'l', 'o', 't', '\n',
        'p', 'i', 'l', 'o', 't', 'e', 'd', '\n',
        'p', 'i', 'l', 'o', 't', 'i', 'n', 'g', '\n',
        'p', 'i', 'l', 'o', 't', 's', '\n',
        'p', 'i', 'm', 'p', '\n',
        'p', 'i', 'm', 'p', 'e', 'r', 'n', 'e', 'l', '\n',
        'p', 'i', 'm', 'p', 'i', 'n', 'g', '\n',
        'p', 'i', 'm', 'p', 'l', 'e', '\n',
        'p', 'i', 'm', 'p', 'l', 'e', 'd', '\n',
        'p', 'i', 'm', 'p', 'l', 'e', 's', '\n',
        'p', 'i', 'm', 'p', 'l', 'y', '\n',
        'p', 'i', 'm', 'p', 's', '\n',
        'p', 'i', 'n', '\n',
        'p', 'i', 'n', 'a', 'f', 'o', 'r', 'e', '\n',
        'p', 'i', 'n', 'a', 'f', 'o', 'r', 'e', 's', '\n',
        'p', 'i', 'n', 'b', 'a', 'l', 'l', '\n',
        'p', 'i', 'n', 'c', 'e', 'r', '\n',
        'p', 'i', 'n', 'c', 'e', 'r', 'e', 'd', '\n',
        'p', 'i', 'n', 'c', 'e', 'r', 's', '\n',
        'p', 'i', 'n', 'c', 'h', '\n',
        'p', 'i', 'n', 'c', 'h', 'e', 'd', '\n',
        'p', 'i', 'n', 'c', 'h', 'e', 'r', '\n',
        'p', 'i', 'n', 'c', 'h', 'e', 's', '\n',
        'p', 'i', 'n', 'c', 'h', 'i', 'n', 'g', '\n',
        'p', 'i', 'n', 'c', 'u', 's', 'h', 'i', 'o', 'n', '\n',
        'p', 'i', 'n', 'c', 'u', 's', 'h', 'i', 'o', 'n', 's', '\n',
        'p', 'i', 'n', 'e', '\n',
        'p', 'i', 'n', 'e', 'a', 'l', '\n',
        'p', 'i', 'n', 'e', 'a', 'p', 'p', 'l', 'e', '\n',
        'p', 'i', 'n', 'e', 'a', 'p', 'p', 'l', 'e', 's', '\n',
        'p', 'i', 'n', 'e', 'd', '\n',
        'p', 'i', 'n', 'e', 's', '\n',
        'p', 'i', 'n', 'g', '\n',
        'p', 'i', 'n', 'g', 'p', 'o', 'n', 'g', '\n',
        'p', 'i', 'n', 'g', 's', '\n',
        'p', 'i', 'n', 'h', 'e', 'a', 'd', '\n',
        'p', 'i', 'n', 'h', 'e', 'a', 'd', 's', '\n',
        'p', 'i', 'n', 'h', 'o', 'l', 'e', '\n',
        'p', 'i', 'n', 'h', 'o', 'l', 'e', 's', '\n',
        'p', 'i', 'n', 'i', 'n', 'g', '\n',
        'p', 'i', 'n', 'i', 'o', 'n', '\n',
        'p', 'i', 'n', 'i', 'o', 'n', 'e', 'd', '\n',
        'p', 'i', 'n', 'i', 'o', 'n', 's', '\n',
        'p', 'i', 'n', 'k', '\n',
        'p', 'i', 'n', 'k', 'e', 'd', '\n',
        'p', 'i', 'n', 'k', 'e', 'r', '\n',
        'p', 'i', 'n', 'k', 'i', 'e', '\n',
        'p', 'i', 'n', 'k', 'i', 'e', 's', '\n',
        'p', 'i', 'n', 'k', 'i', 'n', 'g', '\n',
        'p', 'i', 'n', 'k', 'i', 's', 'h', '\n',
        'p', 'i', 'n', 'k', 'n', 'e', 's', 's', '\n',
        'p', 'i', 'n', 'k', 's', '\n',
        'p', 'i', 'n', 'k', 'y', '\n',
        'p', 'i', 'n', 'n', 'a', 'c', 'l', 'e', '\n',
        'p', 'i', 'n', 'n', 'a', 'c', 'l', 'e', 'd', '\n',
        'p', 'i', 'n', 'n', 'a', 'c', 'l', 'e', 's', '\n',
        'p', 'i', 'n', 'n', 'e', 'd', '\n',
        'p', 'i', 'n', 'n', 'i', 'n', 'g', '\n',
        'p', 'i', 'n', 'p', 'o', 'i', 'n', 't', '\n',
        'p', 'i', 'n', 'p', 'o', 'i', 'n', 't', 'e', 'd', '\n',
        'p', 'i', 'n', 'p', 'o', 'i', 'n', 't', 'i', 'n', 'g', '\n',
        'p', 'i', 'n', 'p', 'o', 'i', 'n', 't', 's', '\n',
        'p', 'i', 'n', 'p', 'r', 'i', 'c', 'k', '\n',
        'p', 'i', 'n', 'p', 'r', 'i', 'c', 'k', 's', '\n',
        'p', 'i', 'n', 's', '\n',
        'p', 'i', 'n', 's', 't', 'r', 'i', 'p', 'e', '\n',
        'p', 'i', 'n', 's', 't', 'r', 'i', 'p', 'e', 'd', '\n',
        'p', 'i', 'n', 's', 't', 'r', 'i', 'p', 'e', 's', '\n',
        'p', 'i', 'n', 't', '\n',
        'p', 'i', 'n', 't', 's', '\n',
        'p', 'i', 'n', 't', 's', 'i', 'z', 'e', 'd', '\n',
        'p', 'i', 'n', 'u', 'p', '\n',
        'p', 'i', 'n', 'u', 'p', 's', '\n',
        'p', 'i', 'n', 'y', '\n',
        'p', 'i', 'o', 'n', '\n',
        'p', 'i', 'o', 'n', 'e', 'e', 'r', '\n',
        'p', 'i', 'o', 'n', 'e', 'e', 'r', 'e', 'd', '\n',
        'p', 'i', 'o', 'n', 'e', 'e', 'r', 'i', 'n', 'g', '\n',
        'p', 'i', 'o', 'n', 'e', 'e', 'r', 's', '\n',
        'p', 'i', 'o', 'n', 's', '\n',
        'p', 'i', 'o', 'u', 's', '\n',
        'p', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'p', 'i', 'p', '\n',
        'p', 'i', 'p', 'e', '\n',
        'p', 'i', 'p', 'e', 'd', '\n',
        'p', 'i', 'p', 'e', 'l', 'i', 'n', 'e', '\n',
        'p', 'i', 'p', 'e', 'l', 'i', 'n', 'e', 's', '\n',
        'p', 'i', 'p', 'e', 'r', '\n',
        'p', 'i', 'p', 'e', 'r', 's', '\n',
        'p', 'i', 'p', 'e', 's', '\n',
        'p', 'i', 'p', 'e', 't', 't', 'e', '\n',
        'p', 'i', 'p', 'e', 't', 't', 'e', 's', '\n',
        'p', 'i', 'p', 'e', 'w', 'o', 'r', 'k', '\n',
        'p', 'i', 'p', 'i', 'n', 'g', '\n',
        'p', 'i', 'p', 'i', 'n', 'g', 's', '\n',
        'p', 'i', 'p', 'i', 't', '\n',
        'p', 'i', 'p', 'i', 't', 's', '\n',
        'p', 'i', 'p', 'p', 'e', 'd', '\n',
        'p', 'i', 'p', 'p', 'i', 'n', '\n',
        'p', 'i', 'p', 'p', 'i', 'n', 'g', '\n',
        'p', 'i', 'p', 's', '\n',
        'p', 'i', 'q', 'u', 'a', 'n', 'c', 'y', '\n',
        'p', 'i', 'q', 'u', 'a', 'n', 't', '\n',
        'p', 'i', 'q', 'u', 'e', '\n',
        'p', 'i', 'q', 'u', 'e', 'd', '\n',
        'p', 'i', 'r', 'a', 'c', 'i', 'e', 's', '\n',
        'p', 'i', 'r', 'a', 'c', 'y', '\n',
        'p', 'i', 'r', 'a', 'n', 'h', 'a', '\n',
        'p', 'i', 'r', 'a', 'n', 'h', 'a', 's', '\n',
        'p', 'i', 'r', 'a', 't', 'e', '\n',
        'p', 'i', 'r', 'a', 't', 'e', 'd', '\n',
        'p', 'i', 'r', 'a', 't', 'e', 's', '\n',
        'p', 'i', 'r', 'a', 't', 'i', 'c', 'a', 'l', '\n',
        'p', 'i', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'p', 'i', 'r', 'o', 'u', 'e', 't', 't', 'e', '\n',
        'p', 'i', 'r', 'o', 'u', 'e', 't', 't', 'e', 'd', '\n',
        'p', 'i', 'r', 'o', 'u', 'e', 't', 't', 'e', 's', '\n',
        'p', 'i', 'r', 'o', 'u', 'e', 't', 't', 'i', 'n', 'g', '\n',
        'p', 'i', 's', 'a', '\n',
        'p', 'i', 's', 't', 'o', 'l', '\n',
        'p', 'i', 's', 't', 'o', 'l', 's', '\n',
        'p', 'i', 's', 't', 'o', 'n', '\n',
        'p', 'i', 's', 't', 'o', 'n', 's', '\n',
        'p', 'i', 't', '\n',
        'p', 'i', 't', 'b', 'u', 'l', 'l', '\n',
        'p', 'i', 't', 'c', 'h', '\n',
        'p', 'i', 't', 'c', 'h', 'd', 'a', 'r', 'k', '\n',
        'p', 'i', 't', 'c', 'h', 'e', 'd', '\n',
        'p', 'i', 't', 'c', 'h', 'e', 'r', '\n',
        'p', 'i', 't', 'c', 'h', 'e', 'r', 's', '\n',
        'p', 'i', 't', 'c', 'h', 'e', 's', '\n',
        'p', 'i', 't', 'c', 'h', 'f', 'o', 'r', 'k', '\n',
        'p', 'i', 't', 'c', 'h', 'f', 'o', 'r', 'k', 's', '\n',
        'p', 'i', 't', 'c', 'h', 'i', 'n', 'g', '\n',
        'p', 'i', 't', 'e', 'o', 'u', 's', '\n',
        'p', 'i', 't', 'e', 'o', 'u', 's', 'l', 'y', '\n',
        'p', 'i', 't', 'f', 'a', 'l', 'l', '\n',
        'p', 'i', 't', 'f', 'a', 'l', 'l', 's', '\n',
        'p', 'i', 't', 'h', '\n',
        'p', 'i', 't', 'h', 'e', 'a', 'd', '\n',
        'p', 'i', 't', 'h', 'i', 'e', 'r', '\n',
        'p', 'i', 't', 'h', 'i', 'e', 's', 't', '\n',
        'p', 'i', 't', 'h', 'i', 'l', 'y', '\n',
        'p', 'i', 't', 'h', 's', '\n',
        'p', 'i', 't', 'h', 'y', '\n',
        'p', 'i', 't', 'i', 'a', 'b', 'l', 'e', '\n',
        'p', 'i', 't', 'i', 'a', 'b', 'l', 'y', '\n',
        'p', 'i', 't', 'i', 'e', 'd', '\n',
        'p', 'i', 't', 'i', 'e', 's', '\n',
        'p', 'i', 't', 'i', 'f', 'u', 'l', '\n',
        'p', 'i', 't', 'i', 'f', 'u', 'l', 'l', 'y', '\n',
        'p', 'i', 't', 'i', 'l', 'e', 's', 's', '\n',
        'p', 'i', 't', 'i', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'p', 'i', 't', 'o', 'n', '\n',
        'p', 'i', 't', 'o', 'n', 's', '\n',
        'p', 'i', 't', 's', '\n',
        'p', 'i', 't', 't', 'a', 'n', 'c', 'e', '\n',
        'p', 'i', 't', 't', 'e', 'd', '\n',
        'p', 'i', 't', 't', 'i', 'n', 'g', '\n',
        'p', 'i', 't', 'u', 'i', 't', 'a', 'r', 'y', '\n',
        'p', 'i', 't', 'y', '\n',
        'p', 'i', 't', 'y', 'i', 'n', 'g', '\n',
        'p', 'i', 't', 'y', 'i', 'n', 'g', 'l', 'y', '\n',
        'p', 'i', 'v', 'o', 't', '\n',
        'p', 'i', 'v', 'o', 't', 'a', 'l', '\n',
        'p', 'i', 'v', 'o', 't', 'e', 'd', '\n',
        'p', 'i', 'v', 'o', 't', 'i', 'n', 'g', '\n',
        'p', 'i', 'v', 'o', 't', 's', '\n',
        'p', 'i', 'x', 'e', 'l', '\n',
        'p', 'i', 'x', 'e', 'l', 's', '\n',
        'p', 'i', 'x', 'i', 'e', '\n',
        'p', 'i', 'x', 'i', 'e', 's', '\n',
        'p', 'i', 'z', 'a', 'z', 'z', '\n',
        'p', 'i', 'z', 'z', 'a', '\n',
        'p', 'i', 'z', 'z', 'a', 's', '\n',
        'p', 'i', 'z', 'z', 'e', 'r', 'i', 'a', '\n',
        'p', 'i', 'z', 'z', 'e', 'r', 'i', 'a', 's', '\n',
        'p', 'i', 'z', 'z', 'i', 'c', 'a', 't', 'o', '\n',
        'p', 'l', 'a', 'c', 'a', 'r', 'd', '\n',
        'p', 'l', 'a', 'c', 'a', 'r', 'd', 's', '\n',
        'p', 'l', 'a', 'c', 'a', 't', 'e', '\n',
        'p', 'l', 'a', 'c', 'a', 't', 'e', 'd', '\n',
        'p', 'l', 'a', 'c', 'a', 't', 'e', 's', '\n',
        'p', 'l', 'a', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'p', 'l', 'a', 'c', 'a', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'p', 'l', 'a', 'c', 'a', 't', 'o', 'r', 'y', '\n',
        'p', 'l', 'a', 'c', 'e', '\n',
        'p', 'l', 'a', 'c', 'e', 'b', 'o', '\n',
        'p', 'l', 'a', 'c', 'e', 'd', '\n',
        'p', 'l', 'a', 'c', 'e', 'h', 'o', 'l', 'd', 'e', 'r', '\n',
        'p', 'l', 'a', 'c', 'e', 'm', 'e', 'n', '\n',
        'p', 'l', 'a', 'c', 'e', 'm', 'e', 'n', 't', '\n',
        'p', 'l', 'a', 'c', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'p', 'l', 'a', 'c', 'e', 'n', 't', 'a', '\n',
        'p', 'l', 'a', 'c', 'e', 'n', 't', 'a', 'e', '\n',
        'p', 'l', 'a', 'c', 'e', 'n', 't', 'a', 'l', '\n',
        'p', 'l', 'a', 'c', 'e', 'n', 't', 'a', 's', '\n',
        'p', 'l', 'a', 'c', 'e', 'r', '\n',
        'p', 'l', 'a', 'c', 'e', 'r', 's', '\n',
        'p', 'l', 'a', 'c', 'e', 's', '\n',
        'p', 'l', 'a', 'c', 'i', 'd', '\n',
        'p', 'l', 'a', 'c', 'i', 'd', 'i', 't', 'y', '\n',
        'p', 'l', 'a', 'c', 'i', 'd', 'l', 'y', '\n',
        'p', 'l', 'a', 'c', 'i', 'n', 'g', '\n',
        'p', 'l', 'a', 'c', 'i', 'n', 'g', 's', '\n',
        'p', 'l', 'a', 'g', 'i', 'a', 'r', 'i', 's', 'e', '\n',
        'p', 'l', 'a', 'g', 'i', 'a', 'r', 'i', 's', 'e', 'd', '\n',
        'p', 'l', 'a', 'g', 'i', 'a', 'r', 'i', 's', 'i', 'n', 'g', '\n',
        'p', 'l', 'a', 'g', 'i', 'a', 'r', 'i', 's', 'm', '\n',
        'p', 'l', 'a', 'g', 'i', 'a', 'r', 'i', 's', 't', '\n',
        'p', 'l', 'a', 'g', 'i', 'a', 'r', 'i', 's', 't', 's', '\n',
        'p', 'l', 'a', 'g', 'u', 'e', '\n',
        'p', 'l', 'a', 'g', 'u', 'e', 'd', '\n',
        'p', 'l', 'a', 'g', 'u', 'e', 's', '\n',
        'p', 'l', 'a', 'g', 'u', 'i', 'n', 'g', '\n',
        'p', 'l', 'a', 'i', 'c', 'e', '\n',
        'p', 'l', 'a', 'i', 'd', '\n',
        'p', 'l', 'a', 'i', 'd', 's', '\n',
        'p', 'l', 'a', 'i', 'n', '\n',
        'p', 'l', 'a', 'i', 'n', 'e', 's', 't', '\n',
        'p', 'l', 'a', 'i', 'n', 'l', 'y', '\n',
        'p', 'l', 'a', 'i', 'n', 'n', 'e', 's', 's', '\n',
        'p', 'l', 'a', 'i', 'n', 's', '\n',
        'p', 'l', 'a', 'i', 'n', 't', '\n',
        'p', 'l', 'a', 'i', 'n', 't', 'i', 'f', 'f', '\n',
        'p', 'l', 'a', 'i', 'n', 't', 'i', 'f', 'f', 's', '\n',
        'p', 'l', 'a', 'i', 'n', 't', 'i', 'v', 'e', '\n',
        'p', 'l', 'a', 'i', 'n', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'p', 'l', 'a', 'i', 't', '\n',
        'p', 'l', 'a', 'i', 't', 'e', 'd', '\n',
        'p', 'l', 'a', 'i', 't', 'i', 'n', 'g', '\n',
        'p', 'l', 'a', 'i', 't', 's', '\n',
        'p', 'l', 'a', 'n', '\n',
        'p', 'l', 'a', 'n', 'a', 'r', '\n',
        'p', 'l', 'a', 'n', 'e', '\n',
        'p', 'l', 'a', 'n', 'e', 'd', '\n',
        'p', 'l', 'a', 'n', 'e', 's', '\n',
        'p', 'l', 'a', 'n', 'e', 't', '\n',
        'p', 'l', 'a', 'n', 'e', 't', 'a', 'r', 'i', 'u', 'm', '\n',
        'p', 'l', 'a', 'n', 'e', 't', 'a', 'r', 'y', '\n',
        'p', 'l', 'a', 'n', 'e', 't', 'e', 's', 'i', 'm', 'a', 'l', 's', '\n',
        'p', 'l', 'a', 'n', 'e', 't', 'o', 'i', 'd', 's', '\n',
        'p', 'l', 'a', 'n', 'e', 't', 's', '\n',
        'p', 'l', 'a', 'n', 'g', 'e', 'n', 't', '\n',
        'p', 'l', 'a', 'n', 'i', 'n', 'g', '\n',
        'p', 'l', 'a', 'n', 'k', '\n',
        'p', 'l', 'a', 'n', 'k', 'i', 'n', 'g', '\n',
        'p', 'l', 'a', 'n', 'k', 's', '\n',
        'p', 'l', 'a', 'n', 'k', 't', 'o', 'n', '\n',
        'p', 'l', 'a', 'n', 'k', 't', 'o', 'n', 'i', 'c', '\n',
        'p', 'l', 'a', 'n', 'n', 'e', 'd', '\n',
        'p', 'l', 'a', 'n', 'n', 'e', 'r', '\n',
        'p', 'l', 'a', 'n', 'n', 'e', 'r', 's', '\n',
        'p', 'l', 'a', 'n', 'n', 'i', 'n', 'g', '\n',
        'p', 'l', 'a', 'n', 's', '\n',
        'p', 'l', 'a', 'n', 't', '\n',
        'p', 'l', 'a', 'n', 't', 'a', 'i', 'n', '\n',
        'p', 'l', 'a', 'n', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'l', 'a', 'n', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'l', 'a', 'n', 't', 'e', 'd', '\n',
        'p', 'l', 'a', 'n', 't', 'e', 'r', '\n',
        'p', 'l', 'a', 'n', 't', 'e', 'r', 's', '\n',
        'p', 'l', 'a', 'n', 't', 'i', 'n', 'g', '\n',
        'p', 'l', 'a', 'n', 't', 'i', 'n', 'g', 's', '\n',
        'p', 'l', 'a', 'n', 't', 's', '\n',
        'p', 'l', 'a', 'q', 'u', 'e', '\n',
        'p', 'l', 'a', 'q', 'u', 'e', 's', '\n',
        'p', 'l', 'a', 's', 'm', '\n',
        'p', 'l', 'a', 's', 'm', 'a', '\n',
        'p', 'l', 'a', 's', 'm', 'a', 's', '\n',
        'p', 'l', 'a', 's', 'm', 'i', 'd', '\n',
        'p', 'l', 'a', 's', 'm', 'i', 'd', 's', '\n',
        'p', 'l', 'a', 's', 't', 'e', 'r', '\n',
        'p', 'l', 'a', 's', 't', 'e', 'r', 'b', 'o', 'a', 'r', 'd', '\n',
        'p', 'l', 'a', 's', 't', 'e', 'r', 'e', 'd', '\n',
        'p', 'l', 'a', 's', 't', 'e', 'r', 'e', 'r', '\n',
        'p', 'l', 'a', 's', 't', 'e', 'r', 'e', 'r', 's', '\n',
        'p', 'l', 'a', 's', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'p', 'l', 'a', 's', 't', 'e', 'r', 's', '\n',
        'p', 'l', 'a', 's', 't', 'e', 'r', 'w', 'o', 'r', 'k', '\n',
        'p', 'l', 'a', 's', 't', 'i', 'c', '\n',
        'p', 'l', 'a', 's', 't', 'i', 'c', 'i', 's', 'e', 'd', '\n',
        'p', 'l', 'a', 's', 't', 'i', 'c', 'i', 's', 'e', 'r', 's', '\n',
        'p', 'l', 'a', 's', 't', 'i', 'c', 'i', 't', 'y', '\n',
        'p', 'l', 'a', 's', 't', 'i', 'c', 's', '\n',
        'p', 'l', 'a', 't', 'e', '\n',
        'p', 'l', 'a', 't', 'e', 'a', 'u', '\n',
        'p', 'l', 'a', 't', 'e', 'a', 'u', 's', '\n',
        'p', 'l', 'a', 't', 'e', 'a', 'u', 'x', '\n',
        'p', 'l', 'a', 't', 'e', 'd', '\n',
        'p', 'l', 'a', 't', 'e', 'f', 'u', 'l', '\n',
        'p', 'l', 'a', 't', 'e', 'f', 'u', 'l', 's', '\n',
        'p', 'l', 'a', 't', 'e', 'l', 'e', 't', '\n',
        'p', 'l', 'a', 't', 'e', 'l', 'e', 't', 's', '\n',
        'p', 'l', 'a', 't', 'e', 'n', '\n',
        'p', 'l', 'a', 't', 'e', 'n', 's', '\n',
        'p', 'l', 'a', 't', 'e', 's', '\n',
        'p', 'l', 'a', 't', 'f', 'o', 'r', 'm', '\n',
        'p', 'l', 'a', 't', 'f', 'o', 'r', 'm', 's', '\n',
        'p', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'p', 'l', 'a', 't', 'i', 'n', 'u', 'm', '\n',
        'p', 'l', 'a', 't', 'i', 't', 'u', 'd', 'e', '\n',
        'p', 'l', 'a', 't', 'i', 't', 'u', 'd', 'e', 's', '\n',
        'p', 'l', 'a', 't', 'i', 't', 'u', 'd', 'i', 'n', 'o', 'u', 's', '\n',
        'p', 'l', 'a', 't', 'o', '\n',
        'p', 'l', 'a', 't', 'o', 'n', 'i', 'c', '\n',
        'p', 'l', 'a', 't', 'o', 'o', 'n', '\n',
        'p', 'l', 'a', 't', 'o', 'o', 'n', 's', '\n',
        'p', 'l', 'a', 't', 't', 'e', 'r', '\n',
        'p', 'l', 'a', 't', 't', 'e', 'r', 's', '\n',
        'p', 'l', 'a', 't', 'y', 'p', 'u', 's', '\n',
        'p', 'l', 'a', 't', 'y', 'p', 'u', 's', 'e', 's', '\n',
        'p', 'l', 'a', 'u', 'd', 'i', 't', 's', '\n',
        'p', 'l', 'a', 'u', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'p', 'l', 'a', 'u', 's', 'i', 'b', 'l', 'e', '\n',
        'p', 'l', 'a', 'u', 's', 'i', 'b', 'l', 'y', '\n',
        'p', 'l', 'a', 'y', '\n',
        'p', 'l', 'a', 'y', 'a', 'b', 'l', 'e', '\n',
        'p', 'l', 'a', 'y', 'b', 'a', 'c', 'k', '\n',
        'p', 'l', 'a', 'y', 'b', 'o', 'y', '\n',
        'p', 'l', 'a', 'y', 'b', 'o', 'y', 's', '\n',
        'p', 'l', 'a', 'y', 'e', 'd', '\n',
        'p', 'l', 'a', 'y', 'e', 'r', '\n',
        'p', 'l', 'a', 'y', 'e', 'r', 's', '\n',
        'p', 'l', 'a', 'y', 'f', 'e', 'l', 'l', 'o', 'w', '\n',
        'p', 'l', 'a', 'y', 'f', 'e', 'l', 'l', 'o', 'w', 's', '\n',
        'p', 'l', 'a', 'y', 'f', 'u', 'l', '\n',
        'p', 'l', 'a', 'y', 'f', 'u', 'l', 'l', 'y', '\n',
        'p', 'l', 'a', 'y', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'p', 'l', 'a', 'y', 'g', 'r', 'o', 'u', 'n', 'd', '\n',
        'p', 'l', 'a', 'y', 'g', 'r', 'o', 'u', 'n', 'd', 's', '\n',
        'p', 'l', 'a', 'y', 'g', 'r', 'o', 'u', 'p', '\n',
        'p', 'l', 'a', 'y', 'g', 'r', 'o', 'u', 'p', 's', '\n',
        'p', 'l', 'a', 'y', 'h', 'o', 'u', 's', 'e', '\n',
        'p', 'l', 'a', 'y', 'i', 'n', 'g', '\n',
        'p', 'l', 'a', 'y', 'i', 'n', 'g', 's', '\n',
        'p', 'l', 'a', 'y', 'm', 'a', 't', 'e', '\n',
        'p', 'l', 'a', 'y', 'm', 'a', 't', 'e', 's', '\n',
        'p', 'l', 'a', 'y', 'r', 'o', 'o', 'm', '\n',
        'p', 'l', 'a', 'y', 's', '\n',
        'p', 'l', 'a', 'y', 't', 'h', 'i', 'n', 'g', '\n',
        'p', 'l', 'a', 'y', 't', 'h', 'i', 'n', 'g', 's', '\n',
        'p', 'l', 'a', 'y', 't', 'i', 'm', 'e', '\n',
        'p', 'l', 'a', 'y', 'w', 'r', 'i', 'g', 'h', 't', '\n',
        'p', 'l', 'a', 'y', 'w', 'r', 'i', 'g', 'h', 't', 's', '\n',
        'p', 'l', 'a', 'z', 'a', '\n',
        'p', 'l', 'a', 'z', 'a', 's', '\n',
        'p', 'l', 'e', 'a', '\n',
        'p', 'l', 'e', 'a', 'd', '\n',
        'p', 'l', 'e', 'a', 'd', 'e', 'd', '\n',
        'p', 'l', 'e', 'a', 'd', 'i', 'n', 'g', '\n',
        'p', 'l', 'e', 'a', 'd', 'i', 'n', 'g', 'l', 'y', '\n',
        'p', 'l', 'e', 'a', 'd', 'i', 'n', 'g', 's', '\n',
        'p', 'l', 'e', 'a', 'd', 's', '\n',
        'p', 'l', 'e', 'a', 's', '\n',
        'p', 'l', 'e', 'a', 's', 'a', 'n', 't', '\n',
        'p', 'l', 'e', 'a', 's', 'a', 'n', 't', 'e', 'r', '\n',
        'p', 'l', 'e', 'a', 's', 'a', 'n', 't', 'e', 's', 't', '\n',
        'p', 'l', 'e', 'a', 's', 'a', 'n', 't', 'l', 'y', '\n',
        'p', 'l', 'e', 'a', 's', 'a', 'n', 't', 'n', 'e', 's', 's', '\n',
        'p', 'l', 'e', 'a', 's', 'a', 'n', 't', 'r', 'i', 'e', 's', '\n',
        'p', 'l', 'e', 'a', 's', 'a', 'n', 't', 'r', 'y', '\n',
        'p', 'l', 'e', 'a', 's', 'e', '\n',
        'p', 'l', 'e', 'a', 's', 'e', 'd', '\n',
        'p', 'l', 'e', 'a', 's', 'e', 's', '\n',
        'p', 'l', 'e', 'a', 's', 'i', 'n', 'g', '\n',
        'p', 'l', 'e', 'a', 's', 'i', 'n', 'g', 'l', 'y', '\n',
        'p', 'l', 'e', 'a', 's', 'u', 'r', 'a', 'b', 'l', 'e', '\n',
        'p', 'l', 'e', 'a', 's', 'u', 'r', 'a', 'b', 'l', 'y', '\n',
        'p', 'l', 'e', 'a', 's', 'u', 'r', 'e', '\n',
        'p', 'l', 'e', 'a', 's', 'u', 'r', 'e', 's', '\n',
        'p', 'l', 'e', 'a', 't', '\n',
        'p', 'l', 'e', 'a', 't', 'e', 'd', '\n',
        'p', 'l', 'e', 'a', 't', 's', '\n',
        'p', 'l', 'e', 'b', '\n',
        'p', 'l', 'e', 'b', 'e', 'i', 'a', 'n', '\n',
        'p', 'l', 'e', 'b', 'i', 's', 'c', 'i', 't', 'e', '\n',
        'p', 'l', 'e', 'b', 's', '\n',
        'p', 'l', 'e', 'c', 't', 'r', 'u', 'm', '\n',
        'p', 'l', 'e', 'c', 't', 'r', 'u', 'm', 's', '\n',
        'p', 'l', 'e', 'd', 'g', 'e', '\n',
        'p', 'l', 'e', 'd', 'g', 'e', 'd', '\n',
        'p', 'l', 'e', 'd', 'g', 'e', 's', '\n',
        'p', 'l', 'e', 'd', 'g', 'i', 'n', 'g', '\n',
        'p', 'l', 'e', 'n', 'a', 'r', 'y', '\n',
        'p', 'l', 'e', 'n', 'i', 'p', 'o', 't', 'e', 'n', 't', 'i', 'a', 'r', 'y', '\n',
        'p', 'l', 'e', 'n', 'i', 't', 'u', 'd', 'e', '\n',
        'p', 'l', 'e', 'n', 't', 'e', 'o', 'u', 's', '\n',
        'p', 'l', 'e', 'n', 't', 'e', 'o', 'u', 's', 'l', 'y', '\n',
        'p', 'l', 'e', 'n', 't', 'i', 'f', 'u', 'l', '\n',
        'p', 'l', 'e', 'n', 't', 'i', 'f', 'u', 'l', 'l', 'y', '\n',
        'p', 'l', 'e', 'n', 't', 'y', '\n',
        'p', 'l', 'e', 'n', 'u', 'm', '\n',
        'p', 'l', 'e', 't', 'h', 'o', 'r', 'a', '\n',
        'p', 'l', 'e', 'u', 'r', 'a', '\n',
        'p', 'l', 'e', 'u', 'r', 'a', 'l', '\n',
        'p', 'l', 'e', 'u', 'r', 'i', 's', 'y', '\n',
        'p', 'l', 'e', 'x', 'u', 's', '\n',
        'p', 'l', 'i', 'a', 'b', 'l', 'e', '\n',
        'p', 'l', 'i', 'a', 'n', 't', '\n',
        'p', 'l', 'i', 'e', 'd', '\n',
        'p', 'l', 'i', 'e', 'r', 's', '\n',
        'p', 'l', 'i', 'e', 's', '\n',
        'p', 'l', 'i', 'g', 'h', 't', '\n',
        'p', 'l', 'i', 'g', 'h', 't', 's', '\n',
        'p', 'l', 'i', 'm', 's', 'o', 'l', 'l', 's', '\n',
        'p', 'l', 'i', 'n', 't', 'h', '\n',
        'p', 'l', 'i', 'n', 't', 'h', 's', '\n',
        'p', 'l', 'o', 'd', '\n',
        'p', 'l', 'o', 'd', 'd', 'e', 'd', '\n',
        'p', 'l', 'o', 'd', 'd', 'e', 'r', '\n',
        'p', 'l', 'o', 'd', 'd', 'i', 'n', 'g', '\n',
        'p', 'l', 'o', 'd', 's', '\n',
        'p', 'l', 'o', 'p', '\n',
        'p', 'l', 'o', 'p', 'p', 'e', 'd', '\n',
        'p', 'l', 'o', 'p', 'p', 'i', 'n', 'g', '\n',
        'p', 'l', 'o', 'p', 's', '\n',
        'p', 'l', 'o', 's', 'i', 'v', 'e', '\n',
        'p', 'l', 'o', 't', '\n',
        'p', 'l', 'o', 't', 's', '\n',
        'p', 'l', 'o', 't', 't', 'e', 'd', '\n',
        'p', 'l', 'o', 't', 't', 'e', 'r', '\n',
        'p', 'l', 'o', 't', 't', 'e', 'r', 's', '\n',
        'p', 'l', 'o', 't', 't', 'i', 'n', 'g', '\n',
        'p', 'l', 'o', 'u', 'g', 'h', '\n',
        'p', 'l', 'o', 'u', 'g', 'h', 'e', 'd', '\n',
        'p', 'l', 'o', 'u', 'g', 'h', 'e', 'r', 's', '\n',
        'p', 'l', 'o', 'u', 'g', 'h', 'i', 'n', 'g', '\n',
        'p', 'l', 'o', 'u', 'g', 'h', 'm', 'a', 'n', '\n',
        'p', 'l', 'o', 'u', 'g', 'h', 'm', 'e', 'n', '\n',
        'p', 'l', 'o', 'u', 'g', 'h', 's', '\n',
        'p', 'l', 'o', 'u', 'g', 'h', 's', 'h', 'a', 'r', 'e', '\n',
        'p', 'l', 'o', 'u', 'g', 'h', 's', 'h', 'a', 'r', 'e', 's', '\n',
        'p', 'l', 'o', 'v', 'e', 'r', '\n',
        'p', 'l', 'o', 'v', 'e', 'r', 's', '\n',
        'p', 'l', 'o', 'y', '\n',
        'p', 'l', 'o', 'y', 's', '\n',
        'p', 'l', 'u', 'c', 'k', '\n',
        'p', 'l', 'u', 'c', 'k', 'e', 'd', '\n',
        'p', 'l', 'u', 'c', 'k', 'e', 'r', '\n',
        'p', 'l', 'u', 'c', 'k', 'i', 'e', 'r', '\n',
        'p', 'l', 'u', 'c', 'k', 'i', 'e', 's', 't', '\n',
        'p', 'l', 'u', 'c', 'k', 'i', 'n', 'g', '\n',
        'p', 'l', 'u', 'c', 'k', 's', '\n',
        'p', 'l', 'u', 'c', 'k', 'y', '\n',
        'p', 'l', 'u', 'g', '\n',
        'p', 'l', 'u', 'g', 'g', 'e', 'd', '\n',
        'p', 'l', 'u', 'g', 'g', 'i', 'n', 'g', '\n',
        'p', 'l', 'u', 'g', 'h', 'o', 'l', 'e', '\n',
        'p', 'l', 'u', 'g', 's', '\n',
        'p', 'l', 'u', 'm', '\n',
        'p', 'l', 'u', 'm', 'a', 'g', 'e', '\n',
        'p', 'l', 'u', 'm', 'a', 'g', 'e', 's', '\n',
        'p', 'l', 'u', 'm', 'b', '\n',
        'p', 'l', 'u', 'm', 'b', 'a', 'g', 'o', '\n',
        'p', 'l', 'u', 'm', 'b', 'e', 'd', '\n',
        'p', 'l', 'u', 'm', 'b', 'e', 'r', '\n',
        'p', 'l', 'u', 'm', 'b', 'e', 'r', 's', '\n',
        'p', 'l', 'u', 'm', 'b', 'i', 'n', 'g', '\n',
        'p', 'l', 'u', 'm', 'b', 's', '\n',
        'p', 'l', 'u', 'm', 'e', '\n',
        'p', 'l', 'u', 'm', 'e', 'd', '\n',
        'p', 'l', 'u', 'm', 'e', 's', '\n',
        'p', 'l', 'u', 'm', 'i', 'n', 'g', '\n',
        'p', 'l', 'u', 'm', 'm', 'e', 't', '\n',
        'p', 'l', 'u', 'm', 'm', 'e', 't', 'e', 'd', '\n',
        'p', 'l', 'u', 'm', 'm', 'e', 't', 'i', 'n', 'g', '\n',
        'p', 'l', 'u', 'm', 'm', 'e', 't', 's', '\n',
        'p', 'l', 'u', 'm', 'm', 'y', '\n',
        'p', 'l', 'u', 'm', 'p', '\n',
        'p', 'l', 'u', 'm', 'p', 'e', 'd', '\n',
        'p', 'l', 'u', 'm', 'p', 'e', 'r', '\n',
        'p', 'l', 'u', 'm', 'p', 'i', 'n', 'g', '\n',
        'p', 'l', 'u', 'm', 'p', 'n', 'e', 's', 's', '\n',
        'p', 'l', 'u', 'm', 's', '\n',
        'p', 'l', 'u', 'm', 't', 'r', 'e', 'e', '\n',
        'p', 'l', 'u', 'm', 'y', '\n',
        'p', 'l', 'u', 'n', 'd', 'e', 'r', '\n',
        'p', 'l', 'u', 'n', 'd', 'e', 'r', 'e', 'd', '\n',
        'p', 'l', 'u', 'n', 'd', 'e', 'r', 'e', 'r', 's', '\n',
        'p', 'l', 'u', 'n', 'd', 'e', 'r', 'i', 'n', 'g', '\n',
        'p', 'l', 'u', 'n', 'd', 'e', 'r', 's', '\n',
        'p', 'l', 'u', 'n', 'g', 'e', '\n',
        'p', 'l', 'u', 'n', 'g', 'e', 'd', '\n',
        'p', 'l', 'u', 'n', 'g', 'e', 'r', '\n',
        'p', 'l', 'u', 'n', 'g', 'e', 'r', 's', '\n',
        'p', 'l', 'u', 'n', 'g', 'e', 's', '\n',
        'p', 'l', 'u', 'n', 'g', 'i', 'n', 'g', '\n',
        'p', 'l', 'u', 'p', 'e', 'r', 'f', 'e', 'c', 't', '\n',
        'p', 'l', 'u', 'r', 'a', 'l', '\n',
        'p', 'l', 'u', 'r', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'l', 'u', 'r', 'a', 'l', 'i', 's', 'e', '\n',
        'p', 'l', 'u', 'r', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'p', 'l', 'u', 'r', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'p', 'l', 'u', 'r', 'a', 'l', 'i', 's', 'm', '\n',
        'p', 'l', 'u', 'r', 'a', 'l', 'i', 's', 't', '\n',
        'p', 'l', 'u', 'r', 'a', 'l', 'i', 's', 't', 'i', 'c', '\n',
        'p', 'l', 'u', 'r', 'a', 'l', 'i', 's', 't', 's', '\n',
        'p', 'l', 'u', 'r', 'a', 'l', 'i', 't', 'y', '\n',
        'p', 'l', 'u', 'r', 'a', 'l', 's', '\n',
        'p', 'l', 'u', 's', '\n',
        'p', 'l', 'u', 's', 'e', 's', '\n',
        'p', 'l', 'u', 's', 'h', '\n',
        'p', 'l', 'u', 's', 'h', 'y', '\n',
        'p', 'l', 'u', 't', 'o', '\n',
        'p', 'l', 'u', 't', 'o', 'c', 'r', 'a', 'c', 'y', '\n',
        'p', 'l', 'u', 't', 'o', 'c', 'r', 'a', 't', 's', '\n',
        'p', 'l', 'u', 't', 'o', 'n', 'i', 'c', '\n',
        'p', 'l', 'u', 't', 'o', 'n', 'i', 'u', 'm', '\n',
        'p', 'l', 'y', '\n',
        'p', 'l', 'y', 'i', 'n', 'g', '\n',
        'p', 'l', 'y', 'w', 'o', 'o', 'd', '\n',
        'p', 'n', 'e', 'u', 'm', 'a', 't', 'i', 'c', '\n',
        'p', 'n', 'e', 'u', 'm', 'a', 't', 'i', 'c', 's', '\n',
        'p', 'n', 'e', 'u', 'm', 'o', 'n', 'i', 'a', '\n',
        'p', 'o', 'a', 'c', 'h', '\n',
        'p', 'o', 'a', 'c', 'h', 'e', 'd', '\n',
        'p', 'o', 'a', 'c', 'h', 'e', 'r', '\n',
        'p', 'o', 'a', 'c', 'h', 'e', 'r', 's', '\n',
        'p', 'o', 'a', 'c', 'h', 'e', 's', '\n',
        'p', 'o', 'a', 'c', 'h', 'i', 'n', 'g', '\n',
        'p', 'o', 'c', 'k', '\n',
        'p', 'o', 'c', 'k', 'e', 'd', '\n',
        'p', 'o', 'c', 'k', 'e', 't', '\n',
        'p', 'o', 'c', 'k', 'e', 't', 'b', 'o', 'o', 'k', '\n',
        'p', 'o', 'c', 'k', 'e', 't', 'e', 'd', '\n',
        'p', 'o', 'c', 'k', 'e', 't', 'f', 'u', 'l', '\n',
        'p', 'o', 'c', 'k', 'e', 't', 'i', 'n', 'g', '\n',
        'p', 'o', 'c', 'k', 'e', 't', 's', '\n',
        'p', 'o', 'c', 'k', 'm', 'a', 'r', 'k', 'e', 'd', '\n',
        'p', 'o', 'c', 'k', 's', '\n',
        'p', 'o', 'd', '\n',
        'p', 'o', 'd', 'd', 'e', 'd', '\n',
        'p', 'o', 'd', 'g', 'y', '\n',
        'p', 'o', 'd', 'i', 'a', '\n',
        'p', 'o', 'd', 'i', 'u', 'm', '\n',
        'p', 'o', 'd', 'i', 'u', 'm', 's', '\n',
        'p', 'o', 'd', 's', '\n',
        'p', 'o', 'e', 'm', '\n',
        'p', 'o', 'e', 'm', 's', '\n',
        'p', 'o', 'e', 't', '\n',
        'p', 'o', 'e', 't', 'e', 's', 's', '\n',
        'p', 'o', 'e', 't', 'i', 'c', '\n',
        'p', 'o', 'e', 't', 'i', 'c', 'a', 'l', '\n',
        'p', 'o', 'e', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'p', 'o', 'e', 't', 'i', 'c', 's', '\n',
        'p', 'o', 'e', 't', 'i', 's', 'e', '\n',
        'p', 'o', 'e', 't', 'r', 'y', '\n',
        'p', 'o', 'e', 't', 's', '\n',
        'p', 'o', 'g', 'o', '\n',
        'p', 'o', 'g', 'r', 'o', 'm', '\n',
        'p', 'o', 'g', 'r', 'o', 'm', 's', '\n',
        'p', 'o', 'i', 'g', 'n', 'a', 'n', 'c', 'y', '\n',
        'p', 'o', 'i', 'g', 'n', 'a', 'n', 't', '\n',
        'p', 'o', 'i', 'g', 'n', 'a', 'n', 't', 'l', 'y', '\n',
        'p', 'o', 'i', 'k', 'i', 'l', 'o', 't', 'h', 'e', 'r', 'm', 'i', 'c', '\n',
        'p', 'o', 'i', 'n', 's', 'e', 't', 't', 'i', 'a', 's', '\n',
        'p', 'o', 'i', 'n', 't', '\n',
        'p', 'o', 'i', 'n', 't', 'b', 'l', 'a', 'n', 'k', '\n',
        'p', 'o', 'i', 'n', 't', 'e', 'd', '\n',
        'p', 'o', 'i', 'n', 't', 'e', 'd', 'l', 'y', '\n',
        'p', 'o', 'i', 'n', 't', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'p', 'o', 'i', 'n', 't', 'e', 'r', '\n',
        'p', 'o', 'i', 'n', 't', 'e', 'r', 's', '\n',
        'p', 'o', 'i', 'n', 't', 'i', 'l', 'l', 'i', 's', 'm', '\n',
        'p', 'o', 'i', 'n', 't', 'i', 'l', 'l', 'i', 's', 't', '\n',
        'p', 'o', 'i', 'n', 't', 'i', 'n', 'g', '\n',
        'p', 'o', 'i', 'n', 't', 'l', 'e', 's', 's', '\n',
        'p', 'o', 'i', 'n', 't', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'p', 'o', 'i', 'n', 't', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'p', 'o', 'i', 'n', 't', 's', '\n',
        'p', 'o', 'i', 'n', 't', 'y', '\n',
        'p', 'o', 'i', 's', 'e', '\n',
        'p', 'o', 'i', 's', 'e', 'd', '\n',
        'p', 'o', 'i', 's', 'e', 's', '\n',
        'p', 'o', 'i', 's', 'i', 'n', 'g', '\n',
        'p', 'o', 'i', 's', 'o', 'n', '\n',
        'p', 'o', 'i', 's', 'o', 'n', 'e', 'd', '\n',
        'p', 'o', 'i', 's', 'o', 'n', 'e', 'r', '\n',
        'p', 'o', 'i', 's', 'o', 'n', 'i', 'n', 'g', '\n',
        'p', 'o', 'i', 's', 'o', 'n', 'i', 'n', 'g', 's', '\n',
        'p', 'o', 'i', 's', 'o', 'n', 'o', 'u', 's', '\n',
        'p', 'o', 'i', 's', 'o', 'n', 's', '\n',
        'p', 'o', 'k', 'e', '\n',
        'p', 'o', 'k', 'e', 'd', '\n',
        'p', 'o', 'k', 'e', 'r', '\n',
        'p', 'o', 'k', 'e', 'r', 'f', 'a', 'c', 'e', 'd', '\n',
        'p', 'o', 'k', 'e', 'r', 's', '\n',
        'p', 'o', 'k', 'e', 's', '\n',
        'p', 'o', 'k', 'i', 'n', 'g', '\n',
        'p', 'o', 'k', 'y', '\n',
        'p', 'o', 'l', 'a', 'n', 'd', '\n',
        'p', 'o', 'l', 'a', 'r', '\n',
        'p', 'o', 'l', 'a', 'r', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'o', 'l', 'a', 'r', 'i', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'o', 'l', 'a', 'r', 'i', 's', 'e', '\n',
        'p', 'o', 'l', 'a', 'r', 'i', 's', 'e', 'd', '\n',
        'p', 'o', 'l', 'a', 'r', 'i', 's', 'i', 'n', 'g', '\n',
        'p', 'o', 'l', 'a', 'r', 'i', 't', 'i', 'e', 's', '\n',
        'p', 'o', 'l', 'a', 'r', 'i', 't', 'y', '\n',
        'p', 'o', 'l', 'd', 'e', 'r', '\n',
        'p', 'o', 'l', 'e', '\n',
        'p', 'o', 'l', 'e', 'c', 'a', 't', '\n',
        'p', 'o', 'l', 'e', 'c', 'a', 't', 's', '\n',
        'p', 'o', 'l', 'e', 'd', '\n',
        'p', 'o', 'l', 'e', 'm', 'i', 'c', '\n',
        'p', 'o', 'l', 'e', 'm', 'i', 'c', 'a', 'l', '\n',
        'p', 'o', 'l', 'e', 'm', 'i', 'c', 'i', 's', 't', '\n',
        'p', 'o', 'l', 'e', 'm', 'i', 'c', 's', '\n',
        'p', 'o', 'l', 'e', 's', '\n',
        'p', 'o', 'l', 'e', 's', 't', 'a', 'r', '\n',
        'p', 'o', 'l', 'e', 'v', 'a', 'u', 'l', 't', 'i', 'n', 'g', '\n',
        'p', 'o', 'l', 'e', 'w', 'a', 'r', 'd', '\n',
        'p', 'o', 'l', 'e', 'w', 'a', 'r', 'd', 's', '\n',
        'p', 'o', 'l', 'i', 'c', 'e', '\n',
        'p', 'o', 'l', 'i', 'c', 'e', 'd', '\n',
        'p', 'o', 'l', 'i', 'c', 'e', 'm', 'a', 'n', '\n',
        'p', 'o', 'l', 'i', 'c', 'e', 'm', 'e', 'n', '\n',
        'p', 'o', 'l', 'i', 'c', 'e', 's', '\n',
        'p', 'o', 'l', 'i', 'c', 'e', 'w', 'o', 'm', 'a', 'n', '\n',
        'p', 'o', 'l', 'i', 'c', 'e', 'w', 'o', 'm', 'e', 'n', '\n',
        'p', 'o', 'l', 'i', 'c', 'i', 'e', 's', '\n',
        'p', 'o', 'l', 'i', 'c', 'i', 'n', 'g', '\n',
        'p', 'o', 'l', 'i', 'c', 'y', '\n',
        'p', 'o', 'l', 'i', 'c', 'y', 'h', 'o', 'l', 'd', 'e', 'r', '\n',
        'p', 'o', 'l', 'i', 'c', 'y', 'h', 'o', 'l', 'd', 'e', 'r', 's', '\n',
        'p', 'o', 'l', 'i', 'o', '\n',
        'p', 'o', 'l', 'i', 'o', 'm', 'y', 'e', 'l', 'i', 't', 'i', 's', '\n',
        'p', 'o', 'l', 'i', 's', 'h', '\n',
        'p', 'o', 'l', 'i', 's', 'h', 'e', 'd', '\n',
        'p', 'o', 'l', 'i', 's', 'h', 'e', 'r', '\n',
        'p', 'o', 'l', 'i', 's', 'h', 'e', 'r', 's', '\n',
        'p', 'o', 'l', 'i', 's', 'h', 'e', 's', '\n',
        'p', 'o', 'l', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'p', 'o', 'l', 'i', 's', 'h', 'i', 'n', 'g', 's', '\n',
        'p', 'o', 'l', 'i', 't', 'b', 'u', 'r', 'o', '\n',
        'p', 'o', 'l', 'i', 't', 'e', '\n',
        'p', 'o', 'l', 'i', 't', 'e', 'l', 'y', '\n',
        'p', 'o', 'l', 'i', 't', 'e', 'n', 'e', 's', 's', '\n',
        'p', 'o', 'l', 'i', 't', 'e', 'r', '\n',
        'p', 'o', 'l', 'i', 't', 'e', 's', 's', 'e', '\n',
        'p', 'o', 'l', 'i', 't', 'e', 's', 't', '\n',
        'p', 'o', 'l', 'i', 't', 'i', 'c', '\n',
        'p', 'o', 'l', 'i', 't', 'i', 'c', 'a', 'l', '\n',
        'p', 'o', 'l', 'i', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'p', 'o', 'l', 'i', 't', 'i', 'c', 'i', 'a', 'n', '\n',
        'p', 'o', 'l', 'i', 't', 'i', 'c', 'i', 'a', 'n', 's', '\n',
        'p', 'o', 'l', 'i', 't', 'i', 'c', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'o', 'l', 'i', 't', 'i', 'c', 'i', 's', 'e', '\n',
        'p', 'o', 'l', 'i', 't', 'i', 'c', 'i', 's', 'e', 'd', '\n',
        'p', 'o', 'l', 'i', 't', 'i', 'c', 'i', 's', 'i', 'n', 'g', '\n',
        'p', 'o', 'l', 'i', 't', 'i', 'c', 'k', 'i', 'n', 'g', '\n',
        'p', 'o', 'l', 'i', 't', 'i', 'c', 's', '\n',
        'p', 'o', 'l', 'i', 't', 'y', '\n',
        'p', 'o', 'l', 'k', 'a', '\n',
        'p', 'o', 'l', 'k', 'a', 's', '\n',
        'p', 'o', 'l', 'l', '\n',
        'p', 'o', 'l', 'l', 'a', 'r', 'd', 'e', 'd', '\n',
        'p', 'o', 'l', 'l', 'e', 'd', '\n',
        'p', 'o', 'l', 'l', 'e', 'n', '\n',
        'p', 'o', 'l', 'l', 'e', 'n', 's', '\n',
        'p', 'o', 'l', 'l', 'i', 'n', 'a', 't', 'e', '\n',
        'p', 'o', 'l', 'l', 'i', 'n', 'a', 't', 'e', 'd', '\n',
        'p', 'o', 'l', 'l', 'i', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'p', 'o', 'l', 'l', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'o', 'l', 'l', 'i', 'n', 'a', 't', 'o', 'r', '\n',
        'p', 'o', 'l', 'l', 'i', 'n', 'a', 't', 'o', 'r', 's', '\n',
        'p', 'o', 'l', 'l', 'i', 'n', 'g', '\n',
        'p', 'o', 'l', 'l', 's', '\n',
        'p', 'o', 'l', 'l', 's', 't', 'e', 'r', '\n',
        'p', 'o', 'l', 'l', 's', 't', 'e', 'r', 's', '\n',
        'p', 'o', 'l', 'l', 'u', 't', 'a', 'n', 't', '\n',
        'p', 'o', 'l', 'l', 'u', 't', 'a', 'n', 't', 's', '\n',
        'p', 'o', 'l', 'l', 'u', 't', 'e', '\n',
        'p', 'o', 'l', 'l', 'u', 't', 'e', 'd', '\n',
        'p', 'o', 'l', 'l', 'u', 't', 'e', 'r', '\n',
        'p', 'o', 'l', 'l', 'u', 't', 'e', 'r', 's', '\n',
        'p', 'o', 'l', 'l', 'u', 't', 'e', 's', '\n',
        'p', 'o', 'l', 'l', 'u', 't', 'i', 'n', 'g', '\n',
        'p', 'o', 'l', 'l', 'u', 't', 'i', 'o', 'n', '\n',
        'p', 'o', 'l', 'l', 'u', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'o', 'l', 'o', '\n',
        'p', 'o', 'l', 'o', 'n', 'a', 'i', 's', 'e', '\n',
        'p', 'o', 'l', 'o', 'n', 'a', 'i', 's', 'e', 's', '\n',
        'p', 'o', 'l', 'o', 'n', 'e', 'c', 'k', '\n',
        'p', 'o', 'l', 'o', 'n', 'i', 'e', 's', '\n',
        'p', 'o', 'l', 'o', 'n', 'i', 'u', 'm', '\n',
        'p', 'o', 'l', 'o', 'n', 'y', '\n',
        'p', 'o', 'l', 't', 'e', 'r', 'g', 'e', 'i', 's', 't', '\n',
        'p', 'o', 'l', 't', 'e', 'r', 'g', 'e', 'i', 's', 't', 's', '\n',
        'p', 'o', 'l', 't', 'r', 'o', 'o', 'n', '\n',
        'p', 'o', 'l', 'y', 'a', 'n', 'd', 'r', 'y', '\n',
        'p', 'o', 'l', 'y', 'a', 't', 'o', 'm', 'i', 'c', '\n',
        'p', 'o', 'l', 'y', 'c', 'a', 'r', 'b', 'o', 'n', 'a', 't', 'e', '\n',
        'p', 'o', 'l', 'y', 'c', 'h', 'r', 'o', 'm', 'a', 't', 'i', 'c', '\n',
        'p', 'o', 'l', 'y', 'c', 'h', 'r', 'o', 'm', 'e', '\n',
        'p', 'o', 'l', 'y', 'c', 'o', 't', 't', 'o', 'n', '\n',
        'p', 'o', 'l', 'y', 'c', 'r', 'y', 's', 't', 'a', 'l', 'l', 'i', 'n', 'e', '\n',
        'p', 'o', 'l', 'y', 'c', 'y', 'c', 'l', 'i', 'c', '\n',
        'p', 'o', 'l', 'y', 'e', 's', 't', 'e', 'r', '\n',
        'p', 'o', 'l', 'y', 'e', 's', 't', 'e', 'r', 's', '\n',
        'p', 'o', 'l', 'y', 'e', 't', 'h', 'y', 'l', 'e', 'n', 'e', '\n',
        'p', 'o', 'l', 'y', 'g', 'a', 'm', 'o', 'u', 's', '\n',
        'p', 'o', 'l', 'y', 'g', 'a', 'm', 'y', '\n',
        'p', 'o', 'l', 'y', 'g', 'l', 'o', 't', '\n',
        'p', 'o', 'l', 'y', 'g', 'l', 'o', 't', 's', '\n',
        'p', 'o', 'l', 'y', 'g', 'o', 'n', '\n',
        'p', 'o', 'l', 'y', 'g', 'o', 'n', 'a', 'l', '\n',
        'p', 'o', 'l', 'y', 'g', 'o', 'n', 's', '\n',
        'p', 'o', 'l', 'y', 'g', 'r', 'a', 'p', 'h', '\n',
        'p', 'o', 'l', 'y', 'g', 'y', 'n', 'o', 'u', 's', '\n',
        'p', 'o', 'l', 'y', 'g', 'y', 'n', 'y', '\n',
        'p', 'o', 'l', 'y', 'h', 'e', 'd', 'r', 'a', '\n',
        'p', 'o', 'l', 'y', 'h', 'e', 'd', 'r', 'a', 'l', '\n',
        'p', 'o', 'l', 'y', 'h', 'e', 'd', 'r', 'o', 'n', '\n',
        'p', 'o', 'l', 'y', 'm', 'a', 't', 'h', '\n',
        'p', 'o', 'l', 'y', 'm', 'e', 'r', '\n',
        'p', 'o', 'l', 'y', 'm', 'e', 'r', 'a', 's', 'e', '\n',
        'p', 'o', 'l', 'y', 'm', 'e', 'r', 'a', 's', 'e', 's', '\n',
        'p', 'o', 'l', 'y', 'm', 'e', 'r', 'i', 'c', '\n',
        'p', 'o', 'l', 'y', 'm', 'e', 'r', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'o', 'l', 'y', 'm', 'e', 'r', 'i', 's', 'e', 'd', '\n',
        'p', 'o', 'l', 'y', 'm', 'e', 'r', 's', '\n',
        'p', 'o', 'l', 'y', 'm', 'o', 'r', 'p', 'h', 'i', 'c', '\n',
        'p', 'o', 'l', 'y', 'm', 'o', 'r', 'p', 'h', 'i', 's', 'm', '\n',
        'p', 'o', 'l', 'y', 'm', 'o', 'r', 'p', 'h', 'i', 's', 'm', 's', '\n',
        'p', 'o', 'l', 'y', 'm', 'o', 'r', 'p', 'h', 'o', 'u', 's', '\n',
        'p', 'o', 'l', 'y', 'n', 'o', 'm', 'i', 'a', 'l', '\n',
        'p', 'o', 'l', 'y', 'n', 'o', 'm', 'i', 'a', 'l', 'l', 'y', '\n',
        'p', 'o', 'l', 'y', 'n', 'o', 'm', 'i', 'a', 'l', 's', '\n',
        'p', 'o', 'l', 'y', 'p', '\n',
        'p', 'o', 'l', 'y', 'p', 'e', 'p', 't', 'i', 'd', 'e', '\n',
        'p', 'o', 'l', 'y', 'p', 'e', 'p', 't', 'i', 'd', 'e', 's', '\n',
        'p', 'o', 'l', 'y', 'p', 'h', 'o', 'n', 'i', 'c', '\n',
        'p', 'o', 'l', 'y', 'p', 'h', 'o', 'n', 'y', '\n',
        'p', 'o', 'l', 'y', 'p', 'r', 'o', 'p', 'y', 'l', 'e', 'n', 'e', '\n',
        'p', 'o', 'l', 'y', 'p', 's', '\n',
        'p', 'o', 'l', 'y', 's', 'a', 'c', 'c', 'h', 'a', 'r', 'i', 'd', 'e', '\n',
        'p', 'o', 'l', 'y', 's', 'a', 'c', 'c', 'h', 'a', 'r', 'i', 'd', 'e', 's', '\n',
        'p', 'o', 'l', 'y', 's', 't', 'y', 'r', 'e', 'n', 'e', '\n',
        'p', 'o', 'l', 'y', 's', 'y', 'l', 'l', 'a', 'b', 'i', 'c', '\n',
        'p', 'o', 'l', 'y', 's', 'y', 'l', 'l', 'a', 'b', 'l', 'e', '\n',
        'p', 'o', 'l', 'y', 's', 'y', 'l', 'l', 'a', 'b', 'l', 'e', 's', '\n',
        'p', 'o', 'l', 'y', 't', 'e', 'c', 'h', 'n', 'i', 'c', '\n',
        'p', 'o', 'l', 'y', 't', 'e', 'c', 'h', 'n', 'i', 'c', 's', '\n',
        'p', 'o', 'l', 'y', 't', 'h', 'e', 'i', 's', 'm', '\n',
        'p', 'o', 'l', 'y', 't', 'h', 'e', 'i', 's', 't', '\n',
        'p', 'o', 'l', 'y', 't', 'h', 'e', 'i', 's', 't', 'i', 'c', '\n',
        'p', 'o', 'l', 'y', 't', 'h', 'e', 'i', 's', 't', 's', '\n',
        'p', 'o', 'l', 'y', 't', 'h', 'e', 'n', 'e', '\n',
        'p', 'o', 'l', 'y', 't', 'o', 'p', 'e', 's', '\n',
        'p', 'o', 'l', 'y', 'u', 'n', 's', 'a', 't', 'u', 'r', 'a', 't', 'e', 'd', '\n',
        'p', 'o', 'l', 'y', 'u', 'n', 's', 'a', 't', 'u', 'r', 'a', 't', 'e', 's', '\n',
        'p', 'o', 'l', 'y', 'u', 'r', 'e', 't', 'h', 'a', 'n', 'e', '\n',
        'p', 'o', 'm', 'a', 'd', 'e', '\n',
        'p', 'o', 'm', 'a', 'd', 'e', 's', '\n',
        'p', 'o', 'm', 'e', 'g', 'r', 'a', 'n', 'a', 't', 'e', '\n',
        'p', 'o', 'm', 'e', 'g', 'r', 'a', 'n', 'a', 't', 'e', 's', '\n',
        'p', 'o', 'm', 'e', 'l', 'o', '\n',
        'p', 'o', 'm', 'p', '\n',
        'p', 'o', 'm', 'p', 'a', 'd', 'o', 'u', 'r', '\n',
        'p', 'o', 'm', 'p', 'e', 'i', 'i', '\n',
        'p', 'o', 'm', 'p', 'e', 'y', '\n',
        'p', 'o', 'm', 'p', 'o', 's', 'i', 't', 'y', '\n',
        'p', 'o', 'm', 'p', 'o', 'u', 's', '\n',
        'p', 'o', 'm', 'p', 'o', 'u', 's', 'l', 'y', '\n',
        'p', 'o', 'm', 'p', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'p', 'o', 'n', 'c', 'e', '\n',
        'p', 'o', 'n', 'c', 'h', 'o', '\n',
        'p', 'o', 'n', 'd', '\n',
        'p', 'o', 'n', 'd', 'e', 'r', '\n',
        'p', 'o', 'n', 'd', 'e', 'r', 'e', 'd', '\n',
        'p', 'o', 'n', 'd', 'e', 'r', 'i', 'n', 'g', '\n',
        'p', 'o', 'n', 'd', 'e', 'r', 'o', 'u', 's', '\n',
        'p', 'o', 'n', 'd', 'e', 'r', 'o', 'u', 's', 'l', 'y', '\n',
        'p', 'o', 'n', 'd', 'e', 'r', 's', '\n',
        'p', 'o', 'n', 'd', 's', '\n',
        'p', 'o', 'n', 'i', 'e', 's', '\n',
        'p', 'o', 'n', 't', 'i', 'f', 'f', '\n',
        'p', 'o', 'n', 't', 'i', 'f', 'f', 's', '\n',
        'p', 'o', 'n', 't', 'i', 'f', 'i', 'c', 'a', 'l', '\n',
        'p', 'o', 'n', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', '\n',
        'p', 'o', 'n', 't', 'i', 'f', 'i', 'c', 'a', 't', 'e', 'd', '\n',
        'p', 'o', 'n', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'p', 'o', 'n', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'o', 'n', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'o', 'n', 't', 'o', 'o', 'n', '\n',
        'p', 'o', 'n', 't', 'o', 'o', 'n', 's', '\n',
        'p', 'o', 'n', 'y', '\n',
        'p', 'o', 'n', 'y', 't', 'a', 'i', 'l', '\n',
        'p', 'o', 'o', 'c', 'h', '\n',
        'p', 'o', 'o', 'c', 'h', 'e', 's', '\n',
        'p', 'o', 'o', 'd', 'l', 'e', '\n',
        'p', 'o', 'o', 'd', 'l', 'e', 's', '\n',
        'p', 'o', 'o', 'f', '\n',
        'p', 'o', 'o', 'h', '\n',
        'p', 'o', 'o', 'l', '\n',
        'p', 'o', 'o', 'l', 'e', 'd', '\n',
        'p', 'o', 'o', 'l', 'i', 'n', 'g', '\n',
        'p', 'o', 'o', 'l', 's', '\n',
        'p', 'o', 'o', 'l', 's', 'i', 'd', 'e', '\n',
        'p', 'o', 'o', 'p', '\n',
        'p', 'o', 'o', 'r', '\n',
        'p', 'o', 'o', 'r', 'e', 'r', '\n',
        'p', 'o', 'o', 'r', 'e', 's', 't', '\n',
        'p', 'o', 'o', 'r', 'l', 'y', '\n',
        'p', 'o', 'o', 'r', 'n', 'e', 's', 's', '\n',
        'p', 'o', 'o', 'r', 's', 'p', 'i', 'r', 'i', 't', 'e', 'd', '\n',
        'p', 'o', 'p', '\n',
        'p', 'o', 'p', 'c', 'o', 'r', 'n', '\n',
        'p', 'o', 'p', 'e', '\n',
        'p', 'o', 'p', 'e', 's', '\n',
        'p', 'o', 'p', 'e', 'y', 'e', 'd', '\n',
        'p', 'o', 'p', 'l', 'a', 'r', '\n',
        'p', 'o', 'p', 'l', 'a', 'r', 's', '\n',
        'p', 'o', 'p', 'm', 'u', 's', 'i', 'c', '\n',
        'p', 'o', 'p', 'p', 'e', 'd', '\n',
        'p', 'o', 'p', 'p', 'e', 'r', '\n',
        'p', 'o', 'p', 'p', 'e', 't', '\n',
        'p', 'o', 'p', 'p', 'i', 'e', 's', '\n',
        'p', 'o', 'p', 'p', 'i', 'n', 'g', '\n',
        'p', 'o', 'p', 'p', 'y', '\n',
        'p', 'o', 'p', 'p', 'y', 'c', 'o', 'c', 'k', '\n',
        'p', 'o', 'p', 's', '\n',
        'p', 'o', 'p', 'u', 'l', 'a', 'c', 'e', '\n',
        'p', 'o', 'p', 'u', 'l', 'a', 'r', '\n',
        'p', 'o', 'p', 'u', 'l', 'a', 'r', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'o', 'p', 'u', 'l', 'a', 'r', 'i', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'o', 'p', 'u', 'l', 'a', 'r', 'i', 's', 'e', '\n',
        'p', 'o', 'p', 'u', 'l', 'a', 'r', 'i', 's', 'e', 'd', '\n',
        'p', 'o', 'p', 'u', 'l', 'a', 'r', 'i', 's', 'i', 'n', 'g', '\n',
        'p', 'o', 'p', 'u', 'l', 'a', 'r', 'i', 't', 'y', '\n',
        'p', 'o', 'p', 'u', 'l', 'a', 'r', 'l', 'y', '\n',
        'p', 'o', 'p', 'u', 'l', 'a', 't', 'e', '\n',
        'p', 'o', 'p', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'p', 'o', 'p', 'u', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'p', 'o', 'p', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'o', 'p', 'u', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'o', 'p', 'u', 'l', 'i', 's', 'm', '\n',
        'p', 'o', 'p', 'u', 'l', 'i', 's', 't', '\n',
        'p', 'o', 'p', 'u', 'l', 'i', 's', 't', 's', '\n',
        'p', 'o', 'p', 'u', 'l', 'o', 'u', 's', '\n',
        'p', 'o', 'p', 'u', 'p', '\n',
        'p', 'o', 'r', 'c', 'e', 'l', 'a', 'i', 'n', '\n',
        'p', 'o', 'r', 'c', 'h', '\n',
        'p', 'o', 'r', 'c', 'h', 'e', 's', '\n',
        'p', 'o', 'r', 'c', 'i', 'n', 'e', '\n',
        'p', 'o', 'r', 'c', 'u', 'p', 'i', 'n', 'e', '\n',
        'p', 'o', 'r', 'c', 'u', 'p', 'i', 'n', 'e', 's', '\n',
        'p', 'o', 'r', 'e', '\n',
        'p', 'o', 'r', 'e', 'd', '\n',
        'p', 'o', 'r', 'e', 's', '\n',
        'p', 'o', 'r', 'i', 'n', 'g', '\n',
        'p', 'o', 'r', 'k', '\n',
        'p', 'o', 'r', 'k', 'c', 'h', 'o', 'p', '\n',
        'p', 'o', 'r', 'k', 'e', 'r', '\n',
        'p', 'o', 'r', 'k', 'y', '\n',
        'p', 'o', 'r', 'n', '\n',
        'p', 'o', 'r', 'n', 'o', '\n',
        'p', 'o', 'r', 'n', 'o', 'g', 'r', 'a', 'p', 'h', 'e', 'r', '\n',
        'p', 'o', 'r', 'n', 'o', 'g', 'r', 'a', 'p', 'h', 'e', 'r', 's', '\n',
        'p', 'o', 'r', 'n', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', '\n',
        'p', 'o', 'r', 'n', 'o', 'g', 'r', 'a', 'p', 'h', 'y', '\n',
        'p', 'o', 'r', 'n', 's', '\n',
        'p', 'o', 'r', 'o', 's', 'i', 't', 'y', '\n',
        'p', 'o', 'r', 'o', 'u', 's', '\n',
        'p', 'o', 'r', 'p', 'h', 'y', 'r', 'i', 't', 'i', 'c', '\n',
        'p', 'o', 'r', 'p', 'h', 'y', 'r', 'y', '\n',
        'p', 'o', 'r', 'p', 'o', 'i', 's', 'e', '\n',
        'p', 'o', 'r', 'p', 'o', 'i', 's', 'e', 's', '\n',
        'p', 'o', 'r', 'r', 'i', 'd', 'g', 'e', '\n',
        'p', 'o', 'r', 't', '\n',
        'p', 'o', 'r', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'p', 'o', 'r', 't', 'a', 'b', 'l', 'e', '\n',
        'p', 'o', 'r', 't', 'a', 'b', 'l', 'e', 's', '\n',
        'p', 'o', 'r', 't', 'a', 'g', 'e', '\n',
        'p', 'o', 'r', 't', 'a', 'l', '\n',
        'p', 'o', 'r', 't', 'a', 'l', 's', '\n',
        'p', 'o', 'r', 't', 'c', 'u', 'l', 'l', 'i', 's', '\n',
        'p', 'o', 'r', 't', 'c', 'u', 'l', 'l', 'i', 's', 'e', 's', '\n',
        'p', 'o', 'r', 't', 'e', 'd', '\n',
        'p', 'o', 'r', 't', 'e', 'n', 'd', '\n',
        'p', 'o', 'r', 't', 'e', 'n', 'd', 'e', 'd', '\n',
        'p', 'o', 'r', 't', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'p', 'o', 'r', 't', 'e', 'n', 'd', 's', '\n',
        'p', 'o', 'r', 't', 'e', 'n', 't', '\n',
        'p', 'o', 'r', 't', 'e', 'n', 't', 'o', 'u', 's', '\n',
        'p', 'o', 'r', 't', 'e', 'n', 't', 'o', 'u', 's', 'l', 'y', '\n',
        'p', 'o', 'r', 't', 'e', 'n', 't', 's', '\n',
        'p', 'o', 'r', 't', 'e', 'r', '\n',
        'p', 'o', 'r', 't', 'e', 'r', 'a', 'g', 'e', '\n',
        'p', 'o', 'r', 't', 'e', 'r', 's', '\n',
        'p', 'o', 'r', 't', 'f', 'o', 'l', 'i', 'o', '\n',
        'p', 'o', 'r', 't', 'h', 'o', 'l', 'e', '\n',
        'p', 'o', 'r', 't', 'h', 'o', 'l', 'e', 's', '\n',
        'p', 'o', 'r', 't', 'i', 'c', 'o', '\n',
        'p', 'o', 'r', 't', 'i', 'n', 'g', '\n',
        'p', 'o', 'r', 't', 'i', 'o', 'n', '\n',
        'p', 'o', 'r', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'o', 'r', 't', 'l', 'y', '\n',
        'p', 'o', 'r', 't', 'm', 'a', 'n', 't', 'e', 'a', 'u', '\n',
        'p', 'o', 'r', 't', 'm', 'a', 'n', 't', 'e', 'a', 'u', 's', '\n',
        'p', 'o', 'r', 't', 'r', 'a', 'i', 't', '\n',
        'p', 'o', 'r', 't', 'r', 'a', 'i', 't', 'i', 's', 't', '\n',
        'p', 'o', 'r', 't', 'r', 'a', 'i', 't', 's', '\n',
        'p', 'o', 'r', 't', 'r', 'a', 'i', 't', 'u', 'r', 'e', '\n',
        'p', 'o', 'r', 't', 'r', 'a', 'y', '\n',
        'p', 'o', 'r', 't', 'r', 'a', 'y', 'a', 'l', '\n',
        'p', 'o', 'r', 't', 'r', 'a', 'y', 'a', 'l', 's', '\n',
        'p', 'o', 'r', 't', 'r', 'a', 'y', 'e', 'd', '\n',
        'p', 'o', 'r', 't', 'r', 'a', 'y', 'i', 'n', 'g', '\n',
        'p', 'o', 'r', 't', 'r', 'a', 'y', 's', '\n',
        'p', 'o', 'r', 't', 's', '\n',
        'p', 'o', 'r', 't', 'u', 'g', 'a', 'l', '\n',
        'p', 'o', 's', 'e', '\n',
        'p', 'o', 's', 'e', 'd', '\n',
        'p', 'o', 's', 'e', 'i', 'd', 'o', 'n', '\n',
        'p', 'o', 's', 'e', 'r', '\n',
        'p', 'o', 's', 'e', 'r', 's', '\n',
        'p', 'o', 's', 'e', 's', '\n',
        'p', 'o', 's', 'e', 'u', 'r', '\n',
        'p', 'o', 's', 'e', 'u', 'r', 's', '\n',
        'p', 'o', 's', 'h', '\n',
        'p', 'o', 's', 'i', 'e', 's', '\n',
        'p', 'o', 's', 'i', 'n', 'g', '\n',
        'p', 'o', 's', 'i', 't', '\n',
        'p', 'o', 's', 'i', 't', 'e', 'd', '\n',
        'p', 'o', 's', 'i', 't', 'i', 'n', 'g', '\n',
        'p', 'o', 's', 'i', 't', 'i', 'o', 'n', '\n',
        'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'a', 'b', 'l', 'e', '\n',
        'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'e', 'd', '\n',
        'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'i', 'n', 'g', '\n',
        'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'o', 's', 'i', 't', 'i', 'v', 'e', '\n',
        'p', 'o', 's', 'i', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'p', 'o', 's', 'i', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'p', 'o', 's', 'i', 't', 'i', 'v', 'e', 's', '\n',
        'p', 'o', 's', 'i', 't', 'i', 'v', 'i', 's', 'm', '\n',
        'p', 'o', 's', 'i', 't', 'i', 'v', 'i', 's', 't', '\n',
        'p', 'o', 's', 'i', 't', 'i', 'v', 'i', 's', 't', 's', '\n',
        'p', 'o', 's', 'i', 't', 'i', 'v', 'i', 't', 'y', '\n',
        'p', 'o', 's', 'i', 't', 'r', 'o', 'n', '\n',
        'p', 'o', 's', 'i', 't', 'r', 'o', 'n', 's', '\n',
        'p', 'o', 's', 'i', 't', 's', '\n',
        'p', 'o', 's', 's', 'e', '\n',
        'p', 'o', 's', 's', 'e', 's', 's', '\n',
        'p', 'o', 's', 's', 'e', 's', 's', 'e', 'd', '\n',
        'p', 'o', 's', 's', 'e', 's', 's', 'e', 's', '\n',
        'p', 'o', 's', 's', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'p', 'o', 's', 's', 'e', 's', 's', 'i', 'o', 'n', '\n',
        'p', 'o', 's', 's', 'e', 's', 's', 'i', 'o', 'n', 's', '\n',
        'p', 'o', 's', 's', 'e', 's', 's', 'i', 'v', 'e', '\n',
        'p', 'o', 's', 's', 'e', 's', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'p', 'o', 's', 's', 'e', 's', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'p', 'o', 's', 's', 'e', 's', 's', 'i', 'v', 'e', 's', '\n',
        'p', 'o', 's', 's', 'e', 's', 's', 'o', 'r', '\n',
        'p', 'o', 's', 's', 'e', 's', 's', 'o', 'r', 's', '\n',
        'p', 'o', 's', 's', 'i', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'p', 'o', 's', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'p', 'o', 's', 's', 'i', 'b', 'l', 'e', '\n',
        'p', 'o', 's', 's', 'i', 'b', 'l', 'e', 's', '\n',
        'p', 'o', 's', 's', 'i', 'b', 'l', 'y', '\n',
        'p', 'o', 's', 's', 'u', 'm', '\n',
        'p', 'o', 's', 's', 'u', 'm', 's', '\n',
        'p', 'o', 's', 't', '\n',
        'p', 'o', 's', 't', 'a', 'g', 'e', '\n',
        'p', 'o', 's', 't', 'a', 'l', '\n',
        'p', 'o', 's', 't', 'b', 'a', 'g', '\n',
        'p', 'o', 's', 't', 'b', 'o', 'x', '\n',
        'p', 'o', 's', 't', 'b', 'o', 'x', 'e', 's', '\n',
        'p', 'o', 's', 't', 'c', 'a', 'r', 'd', '\n',
        'p', 'o', 's', 't', 'c', 'a', 'r', 'd', 's', '\n',
        'p', 'o', 's', 't', 'c', 'o', 'd', 'e', '\n',
        'p', 'o', 's', 't', 'c', 'o', 'd', 'e', 's', '\n',
        'p', 'o', 's', 't', 'd', 'a', 't', 'e', 'd', '\n',
        'p', 'o', 's', 't', 'e', 'd', '\n',
        'p', 'o', 's', 't', 'e', 'r', '\n',
        'p', 'o', 's', 't', 'e', 'r', 'i', 'o', 'r', '\n',
        'p', 'o', 's', 't', 'e', 'r', 'i', 'o', 'r', 's', '\n',
        'p', 'o', 's', 't', 'e', 'r', 'i', 't', 'y', '\n',
        'p', 'o', 's', 't', 'e', 'r', 's', '\n',
        'p', 'o', 's', 't', 'f', 'i', 'x', 'e', 's', '\n',
        'p', 'o', 's', 't', 'g', 'r', 'a', 'd', 'u', 'a', 't', 'e', '\n',
        'p', 'o', 's', 't', 'g', 'r', 'a', 'd', 'u', 'a', 't', 'e', 's', '\n',
        'p', 'o', 's', 't', 'h', 'u', 'm', 'o', 'u', 's', '\n',
        'p', 'o', 's', 't', 'h', 'u', 'm', 'o', 'u', 's', 'l', 'y', '\n',
        'p', 'o', 's', 't', 'i', 'l', 'i', 'o', 'n', '\n',
        'p', 'o', 's', 't', 'i', 'l', 'i', 'o', 'n', 's', '\n',
        'p', 'o', 's', 't', 'i', 'l', 'l', 'i', 'o', 'n', '\n',
        'p', 'o', 's', 't', 'i', 'n', 'g', '\n',
        'p', 'o', 's', 't', 'i', 'n', 'g', 's', '\n',
        'p', 'o', 's', 't', 'l', 'u', 'd', 'e', '\n',
        'p', 'o', 's', 't', 'm', 'a', 'n', '\n',
        'p', 'o', 's', 't', 'm', 'a', 'r', 'k', '\n',
        'p', 'o', 's', 't', 'm', 'a', 'r', 'k', 'e', 'd', '\n',
        'p', 'o', 's', 't', 'm', 'a', 'r', 'k', 's', '\n',
        'p', 'o', 's', 't', 'm', 'a', 's', 't', 'e', 'r', '\n',
        'p', 'o', 's', 't', 'm', 'a', 's', 't', 'e', 'r', 's', '\n',
        'p', 'o', 's', 't', 'm', 'e', 'n', '\n',
        'p', 'o', 's', 't', 'm', 'i', 's', 't', 'r', 'e', 's', 's', '\n',
        'p', 'o', 's', 't', 'm', 'o', 'd', 'e', 'r', 'n', '\n',
        'p', 'o', 's', 't', 'm', 'o', 'd', 'e', 'r', 'n', 'i', 's', 'm', '\n',
        'p', 'o', 's', 't', 'm', 'o', 'd', 'e', 'r', 'n', 'i', 's', 't', '\n',
        'p', 'o', 's', 't', 'm', 'o', 'r', 't', 'e', 'm', '\n',
        'p', 'o', 's', 't', 'm', 'o', 'r', 't', 'e', 'm', 's', '\n',
        'p', 'o', 's', 't', 'n', 'a', 't', 'a', 'l', '\n',
        'p', 'o', 's', 't', 'o', 'p', 'e', 'r', 'a', 't', 'i', 'v', 'e', '\n',
        'p', 'o', 's', 't', 'o', 'p', 'e', 'r', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'p', 'o', 's', 't', 'p', 'o', 'n', 'e', '\n',
        'p', 'o', 's', 't', 'p', 'o', 'n', 'e', 'd', '\n',
        'p', 'o', 's', 't', 'p', 'o', 'n', 'e', 'm', 'e', 'n', 't', '\n',
        'p', 'o', 's', 't', 'p', 'o', 'n', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'p', 'o', 's', 't', 'p', 'o', 'n', 'e', 's', '\n',
        'p', 'o', 's', 't', 'p', 'o', 'n', 'i', 'n', 'g', '\n',
        'p', 'o', 's', 't', 's', '\n',
        'p', 'o', 's', 't', 's', 'c', 'r', 'i', 'p', 't', '\n',
        'p', 'o', 's', 't', 's', 'c', 'r', 'i', 'p', 't', 's', '\n',
        'p', 'o', 's', 't', 'u', 'l', 'a', 't', 'e', '\n',
        'p', 'o', 's', 't', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'p', 'o', 's', 't', 'u', 'l', 'a', 't', 'e', 's', '\n',
        'p', 'o', 's', 't', 'u', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'p', 'o', 's', 't', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'o', 's', 't', 'u', 'r', 'a', 'l', '\n',
        'p', 'o', 's', 't', 'u', 'r', 'e', '\n',
        'p', 'o', 's', 't', 'u', 'r', 'e', 'd', '\n',
        'p', 'o', 's', 't', 'u', 'r', 'e', 's', '\n',
        'p', 'o', 's', 't', 'u', 'r', 'i', 'n', 'g', '\n',
        'p', 'o', 's', 't', 'u', 'r', 'i', 'n', 'g', 's', '\n',
        'p', 'o', 's', 'y', '\n',
        'p', 'o', 't', '\n',
        'p', 'o', 't', 'a', 'b', 'l', 'e', '\n',
        'p', 'o', 't', 'a', 's', 'h', '\n',
        'p', 'o', 't', 'a', 's', 's', 'i', 'u', 'm', '\n',
        'p', 'o', 't', 'a', 't', 'o', '\n',
        'p', 'o', 't', 'b', 'e', 'l', 'l', 'i', 'e', 'd', '\n',
        'p', 'o', 't', 'c', 'h', '\n',
        'p', 'o', 't', 'e', 'n', 'c', 'i', 'e', 's', '\n',
        'p', 'o', 't', 'e', 'n', 'c', 'y', '\n',
        'p', 'o', 't', 'e', 'n', 't', '\n',
        'p', 'o', 't', 'e', 'n', 't', 'a', 't', 'e', '\n',
        'p', 'o', 't', 'e', 'n', 't', 'a', 't', 'e', 's', '\n',
        'p', 'o', 't', 'e', 'n', 't', 'i', 'a', 'l', '\n',
        'p', 'o', 't', 'e', 'n', 't', 'i', 'a', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'p', 'o', 't', 'e', 'n', 't', 'i', 'a', 'l', 'i', 't', 'y', '\n',
        'p', 'o', 't', 'e', 'n', 't', 'i', 'a', 'l', 'l', 'y', '\n',
        'p', 'o', 't', 'e', 'n', 't', 'i', 'a', 'l', 's', '\n',
        'p', 'o', 't', 'e', 'n', 't', 'i', 'o', 'm', 'e', 't', 'e', 'r', '\n',
        'p', 'o', 't', 'e', 'n', 't', 'i', 'o', 'm', 'e', 't', 'e', 'r', 's', '\n',
        'p', 'o', 't', 'e', 'n', 't', 'l', 'y', '\n',
        'p', 'o', 't', 'h', 'o', 'l', 'e', '\n',
        'p', 'o', 't', 'h', 'o', 'l', 'e', 's', '\n',
        'p', 'o', 't', 'i', 'o', 'n', '\n',
        'p', 'o', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'o', 't', 'p', 'o', 'u', 'r', 'r', 'i', '\n',
        'p', 'o', 't', 's', '\n',
        'p', 'o', 't', 's', 'h', 'e', 'r', 'd', 's', '\n',
        'p', 'o', 't', 's', 'h', 'o', 't', '\n',
        'p', 'o', 't', 's', 'h', 'o', 't', 's', '\n',
        'p', 'o', 't', 't', 'a', 'g', 'e', '\n',
        'p', 'o', 't', 't', 'e', 'd', '\n',
        'p', 'o', 't', 't', 'e', 'r', '\n',
        'p', 'o', 't', 't', 'e', 'r', 'e', 'd', '\n',
        'p', 'o', 't', 't', 'e', 'r', 'i', 'e', 's', '\n',
        'p', 'o', 't', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'p', 'o', 't', 't', 'e', 'r', 's', '\n',
        'p', 'o', 't', 't', 'e', 'r', 'y', '\n',
        'p', 'o', 't', 't', 'i', 'e', 's', '\n',
        'p', 'o', 't', 't', 'i', 'n', 'g', '\n',
        'p', 'o', 't', 't', 'y', '\n',
        'p', 'o', 'u', 'c', 'h', '\n',
        'p', 'o', 'u', 'c', 'h', 'e', 's', '\n',
        'p', 'o', 'u', 'f', 'f', 'e', '\n',
        'p', 'o', 'u', 'f', 'f', 'e', 's', '\n',
        'p', 'o', 'u', 'l', 't', '\n',
        'p', 'o', 'u', 'l', 't', 'e', 'r', 'e', 'r', '\n',
        'p', 'o', 'u', 'l', 't', 'i', 'c', 'e', '\n',
        'p', 'o', 'u', 'l', 't', 'r', 'y', '\n',
        'p', 'o', 'u', 'n', 'c', 'e', '\n',
        'p', 'o', 'u', 'n', 'c', 'e', 'd', '\n',
        'p', 'o', 'u', 'n', 'c', 'e', 's', '\n',
        'p', 'o', 'u', 'n', 'c', 'i', 'n', 'g', '\n',
        'p', 'o', 'u', 'n', 'd', '\n',
        'p', 'o', 'u', 'n', 'd', 'a', 'g', 'e', '\n',
        'p', 'o', 'u', 'n', 'd', 'e', 'd', '\n',
        'p', 'o', 'u', 'n', 'd', 'i', 'n', 'g', '\n',
        'p', 'o', 'u', 'n', 'd', 's', '\n',
        'p', 'o', 'u', 'r', '\n',
        'p', 'o', 'u', 'r', 'a', 'b', 'l', 'e', '\n',
        'p', 'o', 'u', 'r', 'e', 'd', '\n',
        'p', 'o', 'u', 'r', 'i', 'n', 'g', '\n',
        'p', 'o', 'u', 'r', 's', '\n',
        'p', 'o', 'u', 't', '\n',
        'p', 'o', 'u', 't', 'e', 'd', '\n',
        'p', 'o', 'u', 't', 'e', 'r', '\n',
        'p', 'o', 'u', 't', 'i', 'n', 'g', '\n',
        'p', 'o', 'u', 't', 's', '\n',
        'p', 'o', 'v', 'e', 'r', 't', 'y', '\n',
        'p', 'o', 'v', 'e', 'r', 't', 'y', 's', 't', 'r', 'i', 'c', 'k', 'e', 'n', '\n',
        'p', 'o', 'w', 'd', 'e', 'r', '\n',
        'p', 'o', 'w', 'd', 'e', 'r', 'e', 'd', '\n',
        'p', 'o', 'w', 'd', 'e', 'r', 'i', 'n', 'g', '\n',
        'p', 'o', 'w', 'd', 'e', 'r', 's', '\n',
        'p', 'o', 'w', 'd', 'e', 'r', 'y', '\n',
        'p', 'o', 'w', 'e', 'r', '\n',
        'p', 'o', 'w', 'e', 'r', 'b', 'o', 'a', 't', '\n',
        'p', 'o', 'w', 'e', 'r', 'b', 'o', 'a', 't', 's', '\n',
        'p', 'o', 'w', 'e', 'r', 'e', 'd', '\n',
        'p', 'o', 'w', 'e', 'r', 'f', 'u', 'l', '\n',
        'p', 'o', 'w', 'e', 'r', 'f', 'u', 'l', 'l', 'y', '\n',
        'p', 'o', 'w', 'e', 'r', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'p', 'o', 'w', 'e', 'r', 'h', 'o', 'u', 's', 'e', '\n',
        'p', 'o', 'w', 'e', 'r', 'h', 'o', 'u', 's', 'e', 's', '\n',
        'p', 'o', 'w', 'e', 'r', 'i', 'n', 'g', '\n',
        'p', 'o', 'w', 'e', 'r', 'l', 'e', 's', 's', '\n',
        'p', 'o', 'w', 'e', 'r', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'p', 'o', 'w', 'e', 'r', 's', '\n',
        'p', 'o', 'w', 'e', 'r', 's', 'h', 'a', 'r', 'i', 'n', 'g', '\n',
        'p', 'o', 'x', '\n',
        'p', 'r', 'a', 'c', 't', 'i', 'c', 'a', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'p', 'r', 'a', 'c', 't', 'i', 'c', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'p', 'r', 'a', 'c', 't', 'i', 'c', 'a', 'b', 'l', 'e', '\n',
        'p', 'r', 'a', 'c', 't', 'i', 'c', 'a', 'l', '\n',
        'p', 'r', 'a', 'c', 't', 'i', 'c', 'a', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'p', 'r', 'a', 'c', 't', 'i', 'c', 'a', 'l', 'i', 't', 'y', '\n',
        'p', 'r', 'a', 'c', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'p', 'r', 'a', 'c', 't', 'i', 'c', 'a', 'l', 's', '\n',
        'p', 'r', 'a', 'c', 't', 'i', 'c', 'e', '\n',
        'p', 'r', 'a', 'c', 't', 'i', 'c', 'e', 's', '\n',
        'p', 'r', 'a', 'c', 't', 'i', 's', 'e', '\n',
        'p', 'r', 'a', 'c', 't', 'i', 's', 'e', 'd', '\n',
        'p', 'r', 'a', 'c', 't', 'i', 's', 'e', 's', '\n',
        'p', 'r', 'a', 'c', 't', 'i', 's', 'i', 'n', 'g', '\n',
        'p', 'r', 'a', 'c', 't', 'i', 't', 'i', 'o', 'n', 'e', 'r', '\n',
        'p', 'r', 'a', 'c', 't', 'i', 't', 'i', 'o', 'n', 'e', 'r', 's', '\n',
        'p', 'r', 'a', 'g', 'm', 'a', 't', 'i', 'c', '\n',
        'p', 'r', 'a', 'g', 'm', 'a', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'p', 'r', 'a', 'g', 'm', 'a', 't', 'i', 'c', 's', '\n',
        'p', 'r', 'a', 'g', 'm', 'a', 't', 'i', 's', 'm', '\n',
        'p', 'r', 'a', 'g', 'm', 'a', 't', 'i', 's', 't', '\n',
        'p', 'r', 'a', 'g', 'm', 'a', 't', 'i', 's', 't', 's', '\n',
        'p', 'r', 'a', 'g', 'u', 'e', '\n',
        'p', 'r', 'a', 'i', 'r', 'i', 'e', '\n',
        'p', 'r', 'a', 'i', 'r', 'i', 'e', 's', '\n',
        'p', 'r', 'a', 'i', 's', 'e', '\n',
        'p', 'r', 'a', 'i', 's', 'e', 'd', '\n',
        'p', 'r', 'a', 'i', 's', 'e', 's', '\n',
        'p', 'r', 'a', 'i', 's', 'e', 'w', 'o', 'r', 't', 'h', 'y', '\n',
        'p', 'r', 'a', 'i', 's', 'i', 'n', 'g', '\n',
        'p', 'r', 'a', 'l', 'i', 'n', 'e', '\n',
        'p', 'r', 'a', 'm', '\n',
        'p', 'r', 'a', 'm', 's', '\n',
        'p', 'r', 'a', 'n', 'c', 'e', '\n',
        'p', 'r', 'a', 'n', 'c', 'e', 'd', '\n',
        'p', 'r', 'a', 'n', 'c', 'e', 'r', '\n',
        'p', 'r', 'a', 'n', 'c', 'i', 'n', 'g', '\n',
        'p', 'r', 'a', 'n', 'g', '\n',
        'p', 'r', 'a', 'n', 'k', '\n',
        'p', 'r', 'a', 'n', 'k', 's', '\n',
        'p', 'r', 'a', 'n', 'k', 's', 't', 'e', 'r', '\n',
        'p', 'r', 'a', 'n', 'k', 's', 't', 'e', 'r', 's', '\n',
        'p', 'r', 'a', 't', '\n',
        'p', 'r', 'a', 't', 't', 'l', 'e', '\n',
        'p', 'r', 'a', 't', 't', 'l', 'e', 'd', '\n',
        'p', 'r', 'a', 't', 't', 'l', 'e', 'r', '\n',
        'p', 'r', 'a', 't', 't', 'l', 'i', 'n', 'g', '\n',
        'p', 'r', 'a', 'w', 'n', '\n',
        'p', 'r', 'a', 'w', 'n', 's', '\n',
        'p', 'r', 'a', 'y', '\n',
        'p', 'r', 'a', 'y', 'e', 'd', '\n',
        'p', 'r', 'a', 'y', 'e', 'r', '\n',
        'p', 'r', 'a', 'y', 'e', 'r', 'b', 'o', 'o', 'k', '\n',
        'p', 'r', 'a', 'y', 'e', 'r', 'f', 'u', 'l', '\n',
        'p', 'r', 'a', 'y', 'e', 'r', 'f', 'u', 'l', 'l', 'y', '\n',
        'p', 'r', 'a', 'y', 'e', 'r', 's', '\n',
        'p', 'r', 'a', 'y', 'i', 'n', 'g', '\n',
        'p', 'r', 'a', 'y', 's', '\n',
        'p', 'r', 'e', '\n',
        'p', 'r', 'e', 'a', 'c', 'h', '\n',
        'p', 'r', 'e', 'a', 'c', 'h', 'e', 'd', '\n',
        'p', 'r', 'e', 'a', 'c', 'h', 'e', 'r', '\n',
        'p', 'r', 'e', 'a', 'c', 'h', 'e', 'r', 's', '\n',
        'p', 'r', 'e', 'a', 'c', 'h', 'e', 's', '\n',
        'p', 'r', 'e', 'a', 'c', 'h', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 'a', 'c', 'h', 'i', 'n', 'g', 's', '\n',
        'p', 'r', 'e', 'a', 'd', 'o', 'l', 'e', 's', 'c', 'e', 'n', 't', '\n',
        'p', 'r', 'e', 'a', 'l', 'l', 'o', 'c', 'a', 't', 'e', '\n',
        'p', 'r', 'e', 'a', 'm', 'b', 'l', 'e', '\n',
        'p', 'r', 'e', 'a', 'm', 'b', 'l', 'e', 's', '\n',
        'p', 'r', 'e', 'a', 'm', 'p', '\n',
        'p', 'r', 'e', 'a', 'm', 'p', 'l', 'i', 'f', 'i', 'e', 'r', '\n',
        'p', 'r', 'e', 'a', 'r', 'r', 'a', 'n', 'g', 'e', 'd', '\n',
        'p', 'r', 'e', 'a', 'u', 't', 'h', 'o', 'r', 'i', 's', 'e', '\n',
        'p', 'r', 'e', 'b', 'e', 'n', 'd', '\n',
        'p', 'r', 'e', 'b', 'e', 'n', 'd', 'a', 'r', 'y', '\n',
        'p', 'r', 'e', 'c', 'a', 'r', 'i', 'o', 'u', 's', '\n',
        'p', 'r', 'e', 'c', 'a', 'r', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'p', 'r', 'e', 'c', 'a', 'r', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'p', 'r', 'e', 'c', 'a', 'u', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'e', 'c', 'a', 'u', 't', 'i', 'o', 'n', 'a', 'r', 'y', '\n',
        'p', 'r', 'e', 'c', 'a', 'u', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'e', 'c', 'e', 'd', 'e', '\n',
        'p', 'r', 'e', 'c', 'e', 'd', 'e', 'd', '\n',
        'p', 'r', 'e', 'c', 'e', 'd', 'e', 'n', 'c', 'e', '\n',
        'p', 'r', 'e', 'c', 'e', 'd', 'e', 'n', 'c', 'e', 's', '\n',
        'p', 'r', 'e', 'c', 'e', 'd', 'e', 'n', 't', '\n',
        'p', 'r', 'e', 'c', 'e', 'd', 'e', 'n', 't', 's', '\n',
        'p', 'r', 'e', 'c', 'e', 'd', 'e', 's', '\n',
        'p', 'r', 'e', 'c', 'e', 'd', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 'c', 'e', 'p', 't', '\n',
        'p', 'r', 'e', 'c', 'e', 'p', 't', 's', '\n',
        'p', 'r', 'e', 'c', 'e', 's', 's', '\n',
        'p', 'r', 'e', 'c', 'e', 's', 's', 'e', 'd', '\n',
        'p', 'r', 'e', 'c', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 'c', 'e', 's', 's', 'i', 'o', 'n', '\n',
        'p', 'r', 'e', 'c', 'i', 'n', 'c', 't', '\n',
        'p', 'r', 'e', 'c', 'i', 'n', 'c', 't', 's', '\n',
        'p', 'r', 'e', 'c', 'i', 'o', 'u', 's', '\n',
        'p', 'r', 'e', 'c', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'p', 'r', 'e', 'c', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'p', 'r', 'e', 'c', 'i', 'p', 'i', 'c', 'e', '\n',
        'p', 'r', 'e', 'c', 'i', 'p', 'i', 'c', 'e', 's', '\n',
        'p', 'r', 'e', 'c', 'i', 'p', 'i', 't', 'a', 't', 'e', '\n',
        'p', 'r', 'e', 'c', 'i', 'p', 'i', 't', 'a', 't', 'e', 'd', '\n',
        'p', 'r', 'e', 'c', 'i', 'p', 'i', 't', 'a', 't', 'e', 'l', 'y', '\n',
        'p', 'r', 'e', 'c', 'i', 'p', 'i', 't', 'a', 't', 'e', 's', '\n',
        'p', 'r', 'e', 'c', 'i', 'p', 'i', 't', 'a', 't', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 'c', 'i', 'p', 'i', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'e', 'c', 'i', 'p', 'i', 't', 'o', 'u', 's', '\n',
        'p', 'r', 'e', 'c', 'i', 'p', 'i', 't', 'o', 'u', 's', 'l', 'y', '\n',
        'p', 'r', 'e', 'c', 'i', 's', '\n',
        'p', 'r', 'e', 'c', 'i', 's', 'e', '\n',
        'p', 'r', 'e', 'c', 'i', 's', 'e', 'l', 'y', '\n',
        'p', 'r', 'e', 'c', 'i', 's', 'e', 'n', 'e', 's', 's', '\n',
        'p', 'r', 'e', 'c', 'i', 's', 'i', 'o', 'n', '\n',
        'p', 'r', 'e', 'c', 'i', 's', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'e', 'c', 'l', 'i', 'n', 'i', 'c', 'a', 'l', '\n',
        'p', 'r', 'e', 'c', 'l', 'u', 'd', 'e', '\n',
        'p', 'r', 'e', 'c', 'l', 'u', 'd', 'e', 'd', '\n',
        'p', 'r', 'e', 'c', 'l', 'u', 'd', 'e', 's', '\n',
        'p', 'r', 'e', 'c', 'l', 'u', 'd', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 'c', 'o', 'c', 'i', 'o', 'u', 's', '\n',
        'p', 'r', 'e', 'c', 'o', 'c', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'p', 'r', 'e', 'c', 'o', 'c', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'p', 'r', 'e', 'c', 'o', 'c', 'i', 't', 'y', '\n',
        'p', 'r', 'e', 'c', 'o', 'g', 'n', 'i', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'e', 'c', 'o', 'g', 'n', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'e', 'c', 'o', 'm', 'p', 'u', 't', 'e', 'd', '\n',
        'p', 'r', 'e', 'c', 'o', 'n', 'c', 'e', 'i', 'v', 'e', 'd', '\n',
        'p', 'r', 'e', 'c', 'o', 'n', 'c', 'e', 'p', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'e', 'c', 'o', 'n', 'c', 'e', 'p', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'e', 'c', 'o', 'n', 'd', 'i', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'e', 'c', 'o', 'n', 'd', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'e', 'c', 'o', 'o', 'k', 'e', 'd', '\n',
        'p', 'r', 'e', 'c', 'u', 'r', 's', 'o', 'r', '\n',
        'p', 'r', 'e', 'c', 'u', 'r', 's', 'o', 'r', 's', '\n',
        'p', 'r', 'e', 'd', 'a', 't', 'e', '\n',
        'p', 'r', 'e', 'd', 'a', 't', 'e', 'd', '\n',
        'p', 'r', 'e', 'd', 'a', 't', 'e', 's', '\n',
        'p', 'r', 'e', 'd', 'a', 't', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 'd', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'e', 'd', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'e', 'd', 'a', 't', 'o', 'r', '\n',
        'p', 'r', 'e', 'd', 'a', 't', 'o', 'r', 's', '\n',
        'p', 'r', 'e', 'd', 'a', 't', 'o', 'r', 'y', '\n',
        'p', 'r', 'e', 'd', 'e', 'c', 'e', 'a', 's', 'e', 'd', '\n',
        'p', 'r', 'e', 'd', 'e', 'c', 'e', 's', 's', 'o', 'r', '\n',
        'p', 'r', 'e', 'd', 'e', 'c', 'e', 's', 's', 'o', 'r', 's', '\n',
        'p', 'r', 'e', 'd', 'e', 'c', 'l', 'a', 'r', 'e', 'd', '\n',
        'p', 'r', 'e', 'd', 'e', 'f', 'i', 'n', 'e', '\n',
        'p', 'r', 'e', 'd', 'e', 'f', 'i', 'n', 'e', 'd', '\n',
        'p', 'r', 'e', 'd', 'e', 'f', 'i', 'n', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 'd', 'e', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'e', 'd', 'e', 's', 't', 'i', 'n', 'e', 'd', '\n',
        'p', 'r', 'e', 'd', 'e', 't', 'e', 'r', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'e', 'd', 'e', 't', 'e', 'r', 'm', 'i', 'n', 'e', '\n',
        'p', 'r', 'e', 'd', 'e', 't', 'e', 'r', 'm', 'i', 'n', 'e', 'd', '\n',
        'p', 'r', 'e', 'd', 'e', 't', 'e', 'r', 'm', 'i', 'n', 'e', 's', '\n',
        'p', 'r', 'e', 'd', 'i', 'c', 'a', 'm', 'e', 'n', 't', '\n',
        'p', 'r', 'e', 'd', 'i', 'c', 'a', 'm', 'e', 'n', 't', 's', '\n',
        'p', 'r', 'e', 'd', 'i', 'c', 'a', 't', 'e', '\n',
        'p', 'r', 'e', 'd', 'i', 'c', 'a', 't', 'e', 'd', '\n',
        'p', 'r', 'e', 'd', 'i', 'c', 'a', 't', 'e', 's', '\n',
        'p', 'r', 'e', 'd', 'i', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 'd', 'i', 'c', 'a', 't', 'i', 'v', 'e', '\n',
        'p', 'r', 'e', 'd', 'i', 'c', 't', '\n',
        'p', 'r', 'e', 'd', 'i', 'c', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'p', 'r', 'e', 'd', 'i', 'c', 't', 'a', 'b', 'l', 'e', '\n',
        'p', 'r', 'e', 'd', 'i', 'c', 't', 'a', 'b', 'l', 'y', '\n',
        'p', 'r', 'e', 'd', 'i', 'c', 't', 'e', 'd', '\n',
        'p', 'r', 'e', 'd', 'i', 'c', 't', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 'd', 'i', 'c', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'e', 'd', 'i', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'e', 'd', 'i', 'c', 't', 'i', 'v', 'e', '\n',
        'p', 'r', 'e', 'd', 'i', 'c', 't', 'o', 'r', '\n',
        'p', 'r', 'e', 'd', 'i', 'c', 't', 'o', 'r', 's', '\n',
        'p', 'r', 'e', 'd', 'i', 'c', 't', 's', '\n',
        'p', 'r', 'e', 'd', 'i', 'l', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'e', 'd', 'i', 'l', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'e', 'd', 'i', 's', 'p', 'o', 's', 'e', '\n',
        'p', 'r', 'e', 'd', 'i', 's', 'p', 'o', 's', 'e', 'd', '\n',
        'p', 'r', 'e', 'd', 'i', 's', 'p', 'o', 's', 'e', 's', '\n',
        'p', 'r', 'e', 'd', 'i', 's', 'p', 'o', 's', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 'd', 'i', 's', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'e', 'd', 'i', 's', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'e', 'd', 'o', 'm', 'i', 'n', 'a', 'n', 'c', 'e', '\n',
        'p', 'r', 'e', 'd', 'o', 'm', 'i', 'n', 'a', 'n', 't', '\n',
        'p', 'r', 'e', 'd', 'o', 'm', 'i', 'n', 'a', 'n', 't', 'l', 'y', '\n',
        'p', 'r', 'e', 'd', 'o', 'm', 'i', 'n', 'a', 't', 'e', '\n',
        'p', 'r', 'e', 'd', 'o', 'm', 'i', 'n', 'a', 't', 'e', 'd', '\n',
        'p', 'r', 'e', 'd', 'o', 'm', 'i', 'n', 'a', 't', 'e', 's', '\n',
        'p', 'r', 'e', 'd', 'o', 'm', 'i', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 'e', 'n', '\n',
        'p', 'r', 'e', 'e', 'n', 'e', 'd', '\n',
        'p', 'r', 'e', 'e', 'n', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 'e', 'n', 's', '\n',
        'p', 'r', 'e', 'f', 'a', 'b', '\n',
        'p', 'r', 'e', 'f', 'a', 'b', 'r', 'i', 'c', 'a', 't', 'e', 'd', '\n',
        'p', 'r', 'e', 'f', 'a', 'b', 'r', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'e', 'f', 'a', 'b', 's', '\n',
        'p', 'r', 'e', 'f', 'a', 'c', 'e', '\n',
        'p', 'r', 'e', 'f', 'a', 'c', 'e', 'd', '\n',
        'p', 'r', 'e', 'f', 'a', 'c', 'e', 's', '\n',
        'p', 'r', 'e', 'f', 'a', 'c', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 'f', 'a', 't', 'o', 'r', 'y', '\n',
        'p', 'r', 'e', 'f', 'e', 'c', 't', '\n',
        'p', 'r', 'e', 'f', 'e', 'c', 't', 's', '\n',
        'p', 'r', 'e', 'f', 'e', 'c', 't', 'u', 'r', 'e', '\n',
        'p', 'r', 'e', 'f', 'e', 'r', '\n',
        'p', 'r', 'e', 'f', 'e', 'r', 'a', 'b', 'l', 'e', '\n',
        'p', 'r', 'e', 'f', 'e', 'r', 'a', 'b', 'l', 'y', '\n',
        'p', 'r', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'e', '\n',
        'p', 'r', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 's', '\n',
        'p', 'r', 'e', 'f', 'e', 'r', 'e', 'n', 't', 'i', 'a', 'l', '\n',
        'p', 'r', 'e', 'f', 'e', 'r', 'e', 'n', 't', 'i', 'a', 'l', 'l', 'y', '\n',
        'p', 'r', 'e', 'f', 'e', 'r', 'm', 'e', 'n', 't', '\n',
        'p', 'r', 'e', 'f', 'e', 'r', 'r', 'e', 'd', '\n',
        'p', 'r', 'e', 'f', 'e', 'r', 'r', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 'f', 'e', 'r', 's', '\n',
        'p', 'r', 'e', 'f', 'i', 'g', 'u', 'r', 'e', 'd', '\n',
        'p', 'r', 'e', 'f', 'i', 'x', '\n',
        'p', 'r', 'e', 'f', 'i', 'x', 'e', 'd', '\n',
        'p', 'r', 'e', 'f', 'i', 'x', 'e', 's', '\n',
        'p', 'r', 'e', 'f', 'i', 'x', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 'g', 'n', 'a', 'n', 'c', 'i', 'e', 's', '\n',
        'p', 'r', 'e', 'g', 'n', 'a', 'n', 'c', 'y', '\n',
        'p', 'r', 'e', 'g', 'n', 'a', 'n', 't', '\n',
        'p', 'r', 'e', 'h', 'e', 'a', 't', '\n',
        'p', 'r', 'e', 'h', 'e', 'a', 't', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 'h', 'e', 'n', 's', 'i', 'l', 'e', '\n',
        'p', 'r', 'e', 'h', 'i', 's', 't', 'o', 'r', 'i', 'c', '\n',
        'p', 'r', 'e', 'h', 'i', 's', 't', 'o', 'r', 'y', '\n',
        'p', 'r', 'e', 'j', 'u', 'd', 'g', 'e', '\n',
        'p', 'r', 'e', 'j', 'u', 'd', 'g', 'e', 'd', '\n',
        'p', 'r', 'e', 'j', 'u', 'd', 'g', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 'j', 'u', 'd', 'i', 'c', 'e', '\n',
        'p', 'r', 'e', 'j', 'u', 'd', 'i', 'c', 'e', 'd', '\n',
        'p', 'r', 'e', 'j', 'u', 'd', 'i', 'c', 'e', 's', '\n',
        'p', 'r', 'e', 'j', 'u', 'd', 'i', 'c', 'i', 'a', 'l', '\n',
        'p', 'r', 'e', 'j', 'u', 'd', 'i', 'c', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 'l', 'a', 't', 'e', '\n',
        'p', 'r', 'e', 'l', 'a', 't', 'e', 's', '\n',
        'p', 'r', 'e', 'l', 'i', 'm', 'i', 'n', 'a', 'r', 'i', 'e', 's', '\n',
        'p', 'r', 'e', 'l', 'i', 'm', 'i', 'n', 'a', 'r', 'i', 'l', 'y', '\n',
        'p', 'r', 'e', 'l', 'i', 'm', 'i', 'n', 'a', 'r', 'y', '\n',
        'p', 'r', 'e', 'l', 'u', 'd', 'e', '\n',
        'p', 'r', 'e', 'l', 'u', 'd', 'e', 's', '\n',
        'p', 'r', 'e', 'm', 'a', 't', 'u', 'r', 'e', '\n',
        'p', 'r', 'e', 'm', 'a', 't', 'u', 'r', 'e', 'l', 'y', '\n',
        'p', 'r', 'e', 'm', 'a', 't', 'u', 'r', 'e', 'n', 'e', 's', 's', '\n',
        'p', 'r', 'e', 'm', 'a', 't', 'u', 'r', 'i', 't', 'y', '\n',
        'p', 'r', 'e', 'm', 'e', 'd', 'i', 't', 'a', 't', 'e', '\n',
        'p', 'r', 'e', 'm', 'e', 'd', 'i', 't', 'a', 't', 'e', 'd', '\n',
        'p', 'r', 'e', 'm', 'e', 'd', 'i', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'e', 'm', 'e', 'n', 's', 't', 'r', 'u', 'a', 'l', '\n',
        'p', 'r', 'e', 'm', 'i', 'e', 'r', '\n',
        'p', 'r', 'e', 'm', 'i', 'e', 'r', 'e', '\n',
        'p', 'r', 'e', 'm', 'i', 'e', 'r', 'e', 'd', '\n',
        'p', 'r', 'e', 'm', 'i', 'e', 'r', 'e', 's', '\n',
        'p', 'r', 'e', 'm', 'i', 'e', 'r', 's', '\n',
        'p', 'r', 'e', 'm', 'i', 'e', 'r', 's', 'h', 'i', 'p', '\n',
        'p', 'r', 'e', 'm', 'i', 's', 'e', '\n',
        'p', 'r', 'e', 'm', 'i', 's', 'e', 'd', '\n',
        'p', 'r', 'e', 'm', 'i', 's', 'e', 's', '\n',
        'p', 'r', 'e', 'm', 'i', 's', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 'm', 'i', 's', 's', '\n',
        'p', 'r', 'e', 'm', 'i', 's', 's', 'e', 's', '\n',
        'p', 'r', 'e', 'm', 'i', 'u', 'm', '\n',
        'p', 'r', 'e', 'm', 'i', 'u', 'm', 's', '\n',
        'p', 'r', 'e', 'm', 'o', 'l', 'a', 'r', '\n',
        'p', 'r', 'e', 'm', 'o', 'l', 'a', 'r', 's', '\n',
        'p', 'r', 'e', 'm', 'o', 'n', 'i', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'e', 'm', 'o', 'n', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'e', 'n', 'a', 't', 'a', 'l', '\n',
        'p', 'r', 'e', 'o', 'c', 'c', 'u', 'p', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'e', 'o', 'c', 'c', 'u', 'p', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'e', 'o', 'c', 'c', 'u', 'p', 'i', 'e', 'd', '\n',
        'p', 'r', 'e', 'o', 'c', 'c', 'u', 'p', 'y', '\n',
        'p', 'r', 'e', 'o', 'c', 'c', 'u', 'p', 'y', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 'o', 'r', 'd', 'a', 'i', 'n', 'e', 'd', '\n',
        'p', 'r', 'e', 'p', '\n',
        'p', 'r', 'e', 'p', 'a', 'i', 'd', '\n',
        'p', 'r', 'e', 'p', 'a', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'e', 'p', 'a', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'e', 'p', 'a', 'r', 'a', 't', 'i', 'v', 'e', '\n',
        'p', 'r', 'e', 'p', 'a', 'r', 'a', 't', 'o', 'r', 'y', '\n',
        'p', 'r', 'e', 'p', 'a', 'r', 'e', '\n',
        'p', 'r', 'e', 'p', 'a', 'r', 'e', 'd', '\n',
        'p', 'r', 'e', 'p', 'a', 'r', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'p', 'r', 'e', 'p', 'a', 'r', 'e', 'r', '\n',
        'p', 'r', 'e', 'p', 'a', 'r', 'e', 'r', 's', '\n',
        'p', 'r', 'e', 'p', 'a', 'r', 'e', 's', '\n',
        'p', 'r', 'e', 'p', 'a', 'r', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 'p', 'a', 'y', 'm', 'e', 'n', 't', '\n',
        'p', 'r', 'e', 'p', 'a', 'y', 's', '\n',
        'p', 'r', 'e', 'p', 'l', 'a', 'n', 'n', 'e', 'd', '\n',
        'p', 'r', 'e', 'p', 'o', 'n', 'd', 'e', 'r', 'a', 'n', 'c', 'e', '\n',
        'p', 'r', 'e', 'p', 'o', 'n', 'd', 'e', 'r', 'a', 'n', 't', '\n',
        'p', 'r', 'e', 'p', 'o', 'n', 'd', 'e', 'r', 'a', 'n', 't', 'l', 'y', '\n',
        'p', 'r', 'e', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'e', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'p', 'r', 'e', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'e', 'p', 'o', 's', 't', 'e', 'r', 'o', 'u', 's', '\n',
        'p', 'r', 'e', 'p', 'o', 's', 't', 'e', 'r', 'o', 'u', 's', 'l', 'y', '\n',
        'p', 'r', 'e', 'p', 's', '\n',
        'p', 'r', 'e', 'r', 'o', 'g', 'a', 't', 'i', 'v', 'e', '\n',
        'p', 'r', 'e', 'r', 'o', 'g', 'a', 't', 'i', 'v', 'e', 's', '\n',
        'p', 'r', 'e', 's', 'b', 'y', 't', 'e', 'r', 'y', '\n',
        'p', 'r', 'e', 's', 'c', 'h', 'o', 'o', 'l', '\n',
        'p', 'r', 'e', 's', 'c', 'r', 'i', 'b', 'e', '\n',
        'p', 'r', 'e', 's', 'c', 'r', 'i', 'b', 'e', 'd', '\n',
        'p', 'r', 'e', 's', 'c', 'r', 'i', 'b', 'e', 's', '\n',
        'p', 'r', 'e', 's', 'c', 'r', 'i', 'b', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'v', 'e', '\n',
        'p', 'r', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'p', 'r', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'v', 'i', 's', 'm', '\n',
        'p', 'r', 'e', 's', 'c', 'r', 'i', 'p', 't', 'i', 'v', 'i', 's', 't', '\n',
        'p', 'r', 'e', 's', 'e', 'l', 'e', 'c', 't', '\n',
        'p', 'r', 'e', 's', 'e', 'l', 'e', 'c', 't', 'e', 'd', '\n',
        'p', 'r', 'e', 's', 'e', 'l', 'e', 'c', 't', 's', '\n',
        'p', 'r', 'e', 's', 'e', 'n', 'c', 'e', '\n',
        'p', 'r', 'e', 's', 'e', 'n', 'c', 'e', 's', '\n',
        'p', 'r', 'e', 's', 'e', 'n', 't', '\n',
        'p', 'r', 'e', 's', 'e', 'n', 't', 'a', 'b', 'l', 'e', '\n',
        'p', 'r', 'e', 's', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'e', 's', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'p', 'r', 'e', 's', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'e', 's', 'e', 'n', 't', 'e', 'd', '\n',
        'p', 'r', 'e', 's', 'e', 'n', 't', 'e', 'r', '\n',
        'p', 'r', 'e', 's', 'e', 'n', 't', 'e', 'r', 's', '\n',
        'p', 'r', 'e', 's', 'e', 'n', 't', 'i', 'm', 'e', 'n', 't', '\n',
        'p', 'r', 'e', 's', 'e', 'n', 't', 'i', 'm', 'e', 'n', 't', 's', '\n',
        'p', 'r', 'e', 's', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 's', 'e', 'n', 't', 'l', 'y', '\n',
        'p', 'r', 'e', 's', 'e', 'n', 't', 's', '\n',
        'p', 'r', 'e', 's', 'e', 'r', 'v', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'e', 's', 'e', 'r', 'v', 'a', 't', 'i', 'o', 'n', 'i', 's', 't', 's', '\n',
        'p', 'r', 'e', 's', 'e', 'r', 'v', 'a', 't', 'i', 'v', 'e', '\n',
        'p', 'r', 'e', 's', 'e', 'r', 'v', 'a', 't', 'i', 'v', 'e', 's', '\n',
        'p', 'r', 'e', 's', 'e', 'r', 'v', 'e', '\n',
        'p', 'r', 'e', 's', 'e', 'r', 'v', 'e', 'd', '\n',
        'p', 'r', 'e', 's', 'e', 'r', 'v', 'e', 'r', '\n',
        'p', 'r', 'e', 's', 'e', 'r', 'v', 'e', 's', '\n',
        'p', 'r', 'e', 's', 'e', 'r', 'v', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 's', 'e', 't', '\n',
        'p', 'r', 'e', 's', 'e', 't', 's', '\n',
        'p', 'r', 'e', 's', 'e', 't', 't', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 's', 'i', 'd', 'e', '\n',
        'p', 'r', 'e', 's', 'i', 'd', 'e', 'd', '\n',
        'p', 'r', 'e', 's', 'i', 'd', 'e', 'n', 'c', 'i', 'e', 's', '\n',
        'p', 'r', 'e', 's', 'i', 'd', 'e', 'n', 'c', 'y', '\n',
        'p', 'r', 'e', 's', 'i', 'd', 'e', 'n', 't', '\n',
        'p', 'r', 'e', 's', 'i', 'd', 'e', 'n', 't', 'i', 'a', 'l', '\n',
        'p', 'r', 'e', 's', 'i', 'd', 'e', 'n', 't', 's', '\n',
        'p', 'r', 'e', 's', 'i', 'd', 'e', 's', '\n',
        'p', 'r', 'e', 's', 'i', 'd', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 's', 'i', 'd', 'i', 'u', 'm', '\n',
        'p', 'r', 'e', 's', 's', '\n',
        'p', 'r', 'e', 's', 's', 'e', 'd', '\n',
        'p', 'r', 'e', 's', 's', 'e', 's', '\n',
        'p', 'r', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 's', 's', 'i', 'n', 'g', 'l', 'y', '\n',
        'p', 'r', 'e', 's', 's', 'i', 'n', 'g', 's', '\n',
        'p', 'r', 'e', 's', 's', 'm', 'a', 'n', '\n',
        'p', 'r', 'e', 's', 's', 'm', 'e', 'n', '\n',
        'p', 'r', 'e', 's', 's', 'u', 'p', '\n',
        'p', 'r', 'e', 's', 's', 'u', 'p', 's', '\n',
        'p', 'r', 'e', 's', 's', 'u', 'r', 'e', '\n',
        'p', 'r', 'e', 's', 's', 'u', 'r', 'e', 'c', 'o', 'o', 'k', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 's', 's', 'u', 'r', 'e', 'd', '\n',
        'p', 'r', 'e', 's', 's', 'u', 'r', 'e', 's', '\n',
        'p', 'r', 'e', 's', 's', 'u', 'r', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 's', 's', 'u', 'r', 'i', 's', 'e', '\n',
        'p', 'r', 'e', 's', 's', 'u', 'r', 'i', 's', 'e', 'd', '\n',
        'p', 'r', 'e', 's', 's', 'u', 'r', 'i', 's', 'e', 's', '\n',
        'p', 'r', 'e', 's', 's', 'u', 'r', 'i', 's', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 's', 't', 'i', 'd', 'i', 'g', 'i', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'e', 's', 't', 'i', 'd', 'i', 'g', 'i', 't', 'a', 't', 'o', 'r', '\n',
        'p', 'r', 'e', 's', 't', 'i', 'd', 'i', 'g', 'i', 't', 'a', 't', 'o', 'r', 'i', 'a', 'l', '\n',
        'p', 'r', 'e', 's', 't', 'i', 'g', 'e', '\n',
        'p', 'r', 'e', 's', 't', 'i', 'g', 'i', 'o', 'u', 's', '\n',
        'p', 'r', 'e', 's', 't', 'o', '\n',
        'p', 'r', 'e', 's', 'u', 'm', 'a', 'b', 'l', 'e', '\n',
        'p', 'r', 'e', 's', 'u', 'm', 'a', 'b', 'l', 'y', '\n',
        'p', 'r', 'e', 's', 'u', 'm', 'e', '\n',
        'p', 'r', 'e', 's', 'u', 'm', 'e', 'd', '\n',
        'p', 'r', 'e', 's', 'u', 'm', 'e', 's', '\n',
        'p', 'r', 'e', 's', 'u', 'm', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 's', 'u', 'm', 'p', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'e', 's', 'u', 'm', 'p', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'e', 's', 'u', 'm', 'p', 't', 'i', 'v', 'e', '\n',
        'p', 'r', 'e', 's', 'u', 'm', 'p', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'p', 'r', 'e', 's', 'u', 'm', 'p', 't', 'u', 'o', 'u', 's', '\n',
        'p', 'r', 'e', 's', 'u', 'm', 'p', 't', 'u', 'o', 'u', 's', 'l', 'y', '\n',
        'p', 'r', 'e', 's', 'u', 'm', 'p', 't', 'u', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'p', 'r', 'e', 's', 'u', 'p', 'p', 'o', 's', 'e', '\n',
        'p', 'r', 'e', 's', 'u', 'p', 'p', 'o', 's', 'e', 'd', '\n',
        'p', 'r', 'e', 's', 'u', 'p', 'p', 'o', 's', 'e', 's', '\n',
        'p', 'r', 'e', 's', 'u', 'p', 'p', 'o', 's', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 's', 'u', 'p', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'e', 's', 'u', 'p', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'e', 't', 'e', 'n', 'c', 'e', '\n',
        'p', 'r', 'e', 't', 'e', 'n', 'c', 'e', 's', '\n',
        'p', 'r', 'e', 't', 'e', 'n', 'd', '\n',
        'p', 'r', 'e', 't', 'e', 'n', 'd', 'e', 'd', '\n',
        'p', 'r', 'e', 't', 'e', 'n', 'd', 'e', 'r', '\n',
        'p', 'r', 'e', 't', 'e', 'n', 'd', 'e', 'r', 's', '\n',
        'p', 'r', 'e', 't', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 't', 'e', 'n', 'd', 's', '\n',
        'p', 'r', 'e', 't', 'e', 'n', 's', 'i', 'o', 'n', '\n',
        'p', 'r', 'e', 't', 'e', 'n', 's', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'e', 't', 'e', 'n', 't', 'i', 'o', 'u', 's', '\n',
        'p', 'r', 'e', 't', 'e', 'n', 't', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'p', 'r', 'e', 't', 'e', 'n', 't', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'p', 'r', 'e', 't', 'e', 'r', 'i', 't', 'e', '\n',
        'p', 'r', 'e', 't', 'e', 'r', 'n', 'a', 't', 'u', 'r', 'a', 'l', '\n',
        'p', 'r', 'e', 't', 'e', 'r', 'n', 'a', 't', 'u', 'r', 'a', 'l', 'l', 'y', '\n',
        'p', 'r', 'e', 't', 'e', 'x', 't', '\n',
        'p', 'r', 'e', 't', 'e', 'x', 't', 's', '\n',
        'p', 'r', 'e', 't', 'o', 'r', '\n',
        'p', 'r', 'e', 't', 'o', 'r', 'i', 'a', '\n',
        'p', 'r', 'e', 't', 'r', 'e', 'a', 't', 'e', 'd', '\n',
        'p', 'r', 'e', 't', 'r', 'e', 'a', 't', 'm', 'e', 'n', 't', '\n',
        'p', 'r', 'e', 't', 'r', 'e', 'a', 't', 'm', 'e', 'n', 't', 's', '\n',
        'p', 'r', 'e', 't', 't', 'i', 'e', 'r', '\n',
        'p', 'r', 'e', 't', 't', 'i', 'e', 's', 't', '\n',
        'p', 'r', 'e', 't', 't', 'i', 'f', 'y', '\n',
        'p', 'r', 'e', 't', 't', 'i', 'l', 'y', '\n',
        'p', 'r', 'e', 't', 't', 'i', 'n', 'e', 's', 's', '\n',
        'p', 'r', 'e', 't', 't', 'y', '\n',
        'p', 'r', 'e', 'v', 'a', 'i', 'l', '\n',
        'p', 'r', 'e', 'v', 'a', 'i', 'l', 'e', 'd', '\n',
        'p', 'r', 'e', 'v', 'a', 'i', 'l', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 'v', 'a', 'i', 'l', 's', '\n',
        'p', 'r', 'e', 'v', 'a', 'l', 'e', 'n', 'c', 'e', '\n',
        'p', 'r', 'e', 'v', 'a', 'l', 'e', 'n', 't', '\n',
        'p', 'r', 'e', 'v', 'a', 'l', 'e', 'n', 't', 'l', 'y', '\n',
        'p', 'r', 'e', 'v', 'a', 'r', 'i', 'c', 'a', 't', 'e', '\n',
        'p', 'r', 'e', 'v', 'a', 'r', 'i', 'c', 'a', 't', 'e', 'd', '\n',
        'p', 'r', 'e', 'v', 'a', 'r', 'i', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 'v', 'a', 'r', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'e', 'v', 'e', 'n', 't', '\n',
        'p', 'r', 'e', 'v', 'e', 'n', 't', 'a', 'b', 'l', 'e', '\n',
        'p', 'r', 'e', 'v', 'e', 'n', 't', 'e', 'd', '\n',
        'p', 'r', 'e', 'v', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 'v', 'e', 'n', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'e', 'v', 'e', 'n', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'e', 'v', 'e', 'n', 't', 'i', 'v', 'e', '\n',
        'p', 'r', 'e', 'v', 'e', 'n', 't', 's', '\n',
        'p', 'r', 'e', 'v', 'i', 'e', 'w', '\n',
        'p', 'r', 'e', 'v', 'i', 'e', 'w', 'e', 'd', '\n',
        'p', 'r', 'e', 'v', 'i', 'e', 'w', 'e', 'r', '\n',
        'p', 'r', 'e', 'v', 'i', 'e', 'w', 'e', 'r', 's', '\n',
        'p', 'r', 'e', 'v', 'i', 'e', 'w', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 'v', 'i', 'e', 'w', 's', '\n',
        'p', 'r', 'e', 'v', 'i', 'o', 'u', 's', '\n',
        'p', 'r', 'e', 'v', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'p', 'r', 'e', 'v', 'u', 'e', '\n',
        'p', 'r', 'e', 'v', 'u', 'e', 's', '\n',
        'p', 'r', 'e', 'y', '\n',
        'p', 'r', 'e', 'y', 'e', 'd', '\n',
        'p', 'r', 'e', 'y', 'i', 'n', 'g', '\n',
        'p', 'r', 'e', 'y', 's', '\n',
        'p', 'r', 'i', 'a', 'p', 'i', 'c', '\n',
        'p', 'r', 'i', 'c', 'e', '\n',
        'p', 'r', 'i', 'c', 'e', 'd', '\n',
        'p', 'r', 'i', 'c', 'e', 'l', 'e', 's', 's', '\n',
        'p', 'r', 'i', 'c', 'e', 's', '\n',
        'p', 'r', 'i', 'c', 'e', 'w', 'a', 'r', '\n',
        'p', 'r', 'i', 'c', 'e', 'y', '\n',
        'p', 'r', 'i', 'c', 'i', 'e', 'r', '\n',
        'p', 'r', 'i', 'c', 'i', 'n', 'g', '\n',
        'p', 'r', 'i', 'c', 'k', '\n',
        'p', 'r', 'i', 'c', 'k', 'e', 'd', '\n',
        'p', 'r', 'i', 'c', 'k', 'i', 'n', 'g', '\n',
        'p', 'r', 'i', 'c', 'k', 'l', 'e', '\n',
        'p', 'r', 'i', 'c', 'k', 'l', 'e', 'd', '\n',
        'p', 'r', 'i', 'c', 'k', 'l', 'e', 's', '\n',
        'p', 'r', 'i', 'c', 'k', 'l', 'i', 'e', 'r', '\n',
        'p', 'r', 'i', 'c', 'k', 'l', 'i', 'e', 's', 't', '\n',
        'p', 'r', 'i', 'c', 'k', 'l', 'i', 'n', 'e', 's', 's', '\n',
        'p', 'r', 'i', 'c', 'k', 'l', 'i', 'n', 'g', '\n',
        'p', 'r', 'i', 'c', 'k', 'l', 'y', '\n',
        'p', 'r', 'i', 'c', 'k', 's', '\n',
        'p', 'r', 'i', 'c', 'y', '\n',
        'p', 'r', 'i', 'd', 'e', '\n',
        'p', 'r', 'i', 'd', 'e', 'd', '\n',
        'p', 'r', 'i', 'd', 'e', 's', '\n',
        'p', 'r', 'i', 'e', 'd', '\n',
        'p', 'r', 'i', 'e', 's', '\n',
        'p', 'r', 'i', 'e', 's', 't', '\n',
        'p', 'r', 'i', 'e', 's', 't', 'e', 's', 's', '\n',
        'p', 'r', 'i', 'e', 's', 't', 'e', 's', 's', 'e', 's', '\n',
        'p', 'r', 'i', 'e', 's', 't', 'h', 'o', 'o', 'd', '\n',
        'p', 'r', 'i', 'e', 's', 't', 'l', 'y', '\n',
        'p', 'r', 'i', 'e', 's', 't', 's', '\n',
        'p', 'r', 'i', 'g', '\n',
        'p', 'r', 'i', 'g', 'g', 'i', 's', 'h', '\n',
        'p', 'r', 'i', 'g', 'g', 'i', 's', 'h', 'l', 'y', '\n',
        'p', 'r', 'i', 'g', 'g', 'i', 's', 'h', 'n', 'e', 's', 's', '\n',
        'p', 'r', 'i', 'm', '\n',
        'p', 'r', 'i', 'm', 'a', 'c', 'y', '\n',
        'p', 'r', 'i', 'm', 'a', 'e', 'v', 'a', 'l', '\n',
        'p', 'r', 'i', 'm', 'a', 'l', '\n',
        'p', 'r', 'i', 'm', 'a', 'r', 'i', 'e', 's', '\n',
        'p', 'r', 'i', 'm', 'a', 'r', 'i', 'l', 'y', '\n',
        'p', 'r', 'i', 'm', 'a', 'r', 'y', '\n',
        'p', 'r', 'i', 'm', 'a', 't', 'e', '\n',
        'p', 'r', 'i', 'm', 'a', 't', 'e', 's', '\n',
        'p', 'r', 'i', 'm', 'e', '\n',
        'p', 'r', 'i', 'm', 'e', 'd', '\n',
        'p', 'r', 'i', 'm', 'e', 'n', 'e', 's', 's', '\n',
        'p', 'r', 'i', 'm', 'e', 'r', '\n',
        'p', 'r', 'i', 'm', 'e', 'r', 's', '\n',
        'p', 'r', 'i', 'm', 'e', 's', '\n',
        'p', 'r', 'i', 'm', 'e', 't', 'i', 'm', 'e', '\n',
        'p', 'r', 'i', 'm', 'e', 'v', 'a', 'l', '\n',
        'p', 'r', 'i', 'm', 'i', 'n', 'g', '\n',
        'p', 'r', 'i', 'm', 'i', 't', 'i', 'v', 'e', '\n',
        'p', 'r', 'i', 'm', 'i', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'p', 'r', 'i', 'm', 'i', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'p', 'r', 'i', 'm', 'i', 't', 'i', 'v', 'e', 's', '\n',
        'p', 'r', 'i', 'm', 'l', 'y', '\n',
        'p', 'r', 'i', 'm', 'n', 'e', 's', 's', '\n',
        'p', 'r', 'i', 'm', 'o', 'g', 'e', 'n', 'i', 't', 'u', 'r', 'e', '\n',
        'p', 'r', 'i', 'm', 'o', 'r', 'd', 'i', 'a', 'l', '\n',
        'p', 'r', 'i', 'm', 'r', 'o', 's', 'e', '\n',
        'p', 'r', 'i', 'm', 'r', 'o', 's', 'e', 's', '\n',
        'p', 'r', 'i', 'm', 'u', 's', '\n',
        'p', 'r', 'i', 'n', 'c', 'e', '\n',
        'p', 'r', 'i', 'n', 'c', 'e', 'l', 'i', 'n', 'g', 's', '\n',
        'p', 'r', 'i', 'n', 'c', 'e', 'l', 'y', '\n',
        'p', 'r', 'i', 'n', 'c', 'e', 's', '\n',
        'p', 'r', 'i', 'n', 'c', 'e', 's', 's', '\n',
        'p', 'r', 'i', 'n', 'c', 'e', 's', 's', 'e', 's', '\n',
        'p', 'r', 'i', 'n', 'c', 'i', 'p', 'a', 'l', '\n',
        'p', 'r', 'i', 'n', 'c', 'i', 'p', 'a', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'p', 'r', 'i', 'n', 'c', 'i', 'p', 'a', 'l', 'i', 't', 'y', '\n',
        'p', 'r', 'i', 'n', 'c', 'i', 'p', 'a', 'l', 'l', 'y', '\n',
        'p', 'r', 'i', 'n', 'c', 'i', 'p', 'a', 'l', 's', '\n',
        'p', 'r', 'i', 'n', 'c', 'i', 'p', 'l', 'e', '\n',
        'p', 'r', 'i', 'n', 'c', 'i', 'p', 'l', 'e', 'd', '\n',
        'p', 'r', 'i', 'n', 'c', 'i', 'p', 'l', 'e', 's', '\n',
        'p', 'r', 'i', 'n', 't', '\n',
        'p', 'r', 'i', 'n', 't', 'a', 'b', 'l', 'e', '\n',
        'p', 'r', 'i', 'n', 't', 'e', 'd', '\n',
        'p', 'r', 'i', 'n', 't', 'e', 'r', '\n',
        'p', 'r', 'i', 'n', 't', 'e', 'r', 's', '\n',
        'p', 'r', 'i', 'n', 't', 'i', 'n', 'g', '\n',
        'p', 'r', 'i', 'n', 't', 'i', 'n', 'g', 's', '\n',
        'p', 'r', 'i', 'n', 't', 'm', 'a', 'k', 'e', 'r', 's', '\n',
        'p', 'r', 'i', 'n', 't', 'm', 'a', 'k', 'i', 'n', 'g', '\n',
        'p', 'r', 'i', 'n', 't', 'o', 'u', 't', '\n',
        'p', 'r', 'i', 'n', 't', 'o', 'u', 't', 's', '\n',
        'p', 'r', 'i', 'n', 't', 's', '\n',
        'p', 'r', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'i', 'o', 'r', '\n',
        'p', 'r', 'i', 'o', 'r', 'i', 'e', 's', '\n',
        'p', 'r', 'i', 'o', 'r', 'i', 't', 'i', 'e', 's', '\n',
        'p', 'r', 'i', 'o', 'r', 'i', 't', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'i', 'o', 'r', 'i', 't', 'i', 's', 'e', '\n',
        'p', 'r', 'i', 'o', 'r', 'i', 't', 'i', 's', 'e', 'd', '\n',
        'p', 'r', 'i', 'o', 'r', 'i', 't', 'i', 's', 'e', 's', '\n',
        'p', 'r', 'i', 'o', 'r', 'i', 't', 'i', 's', 'i', 'n', 'g', '\n',
        'p', 'r', 'i', 'o', 'r', 'i', 't', 'y', '\n',
        'p', 'r', 'i', 'o', 'r', 's', '\n',
        'p', 'r', 'i', 'o', 'r', 'y', '\n',
        'p', 'r', 'i', 's', 'e', '\n',
        'p', 'r', 'i', 's', 'e', 'd', '\n',
        'p', 'r', 'i', 's', 'e', 's', '\n',
        'p', 'r', 'i', 's', 'i', 'n', 'g', '\n',
        'p', 'r', 'i', 's', 'm', '\n',
        'p', 'r', 'i', 's', 'm', 'a', 't', 'i', 'c', '\n',
        'p', 'r', 'i', 's', 'm', 's', '\n',
        'p', 'r', 'i', 's', 'o', 'n', '\n',
        'p', 'r', 'i', 's', 'o', 'n', 'e', 'r', '\n',
        'p', 'r', 'i', 's', 'o', 'n', 'e', 'r', 's', '\n',
        'p', 'r', 'i', 's', 'o', 'n', 's', '\n',
        'p', 'r', 'i', 's', 's', 'y', '\n',
        'p', 'r', 'i', 's', 't', 'i', 'n', 'e', '\n',
        'p', 'r', 'i', 'v', 'a', 'c', 'y', '\n',
        'p', 'r', 'i', 'v', 'a', 't', 'e', '\n',
        'p', 'r', 'i', 'v', 'a', 't', 'e', 'e', 'r', '\n',
        'p', 'r', 'i', 'v', 'a', 't', 'e', 'e', 'r', 's', '\n',
        'p', 'r', 'i', 'v', 'a', 't', 'e', 'l', 'y', '\n',
        'p', 'r', 'i', 'v', 'a', 't', 'e', 's', '\n',
        'p', 'r', 'i', 'v', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'i', 'v', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'i', 'v', 'a', 't', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'i', 'v', 'a', 't', 'i', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'i', 'v', 'a', 't', 'i', 's', 'e', '\n',
        'p', 'r', 'i', 'v', 'a', 't', 'i', 's', 'e', 'd', '\n',
        'p', 'r', 'i', 'v', 'a', 't', 'i', 's', 'e', 's', '\n',
        'p', 'r', 'i', 'v', 'a', 't', 'i', 's', 'i', 'n', 'g', '\n',
        'p', 'r', 'i', 'v', 'e', 't', '\n',
        'p', 'r', 'i', 'v', 'i', 'l', 'e', 'g', 'e', '\n',
        'p', 'r', 'i', 'v', 'i', 'l', 'e', 'g', 'e', 'd', '\n',
        'p', 'r', 'i', 'v', 'i', 'l', 'e', 'g', 'e', 's', '\n',
        'p', 'r', 'i', 'v', 'i', 'l', 'e', 'g', 'i', 'n', 'g', '\n',
        'p', 'r', 'i', 'v', 'y', '\n',
        'p', 'r', 'i', 'z', 'e', '\n',
        'p', 'r', 'i', 'z', 'e', 'd', '\n',
        'p', 'r', 'i', 'z', 'e', 'r', '\n',
        'p', 'r', 'i', 'z', 'e', 's', '\n',
        'p', 'r', 'i', 'z', 'e', 'w', 'i', 'n', 'n', 'e', 'r', '\n',
        'p', 'r', 'i', 'z', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', '\n',
        'p', 'r', 'o', 'a', 'c', 't', 'i', 'v', 'e', '\n',
        'p', 'r', 'o', 'b', 'a', 'b', 'i', 'l', 'i', 's', 't', '\n',
        'p', 'r', 'o', 'b', 'a', 'b', 'i', 'l', 'i', 's', 't', 'i', 'c', '\n',
        'p', 'r', 'o', 'b', 'a', 'b', 'i', 'l', 'i', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'p', 'r', 'o', 'b', 'a', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'p', 'r', 'o', 'b', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'p', 'r', 'o', 'b', 'a', 'b', 'l', 'e', '\n',
        'p', 'r', 'o', 'b', 'a', 'b', 'l', 'y', '\n',
        'p', 'r', 'o', 'b', 'a', 't', 'e', '\n',
        'p', 'r', 'o', 'b', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'o', 'b', 'a', 't', 'i', 'o', 'n', 'a', 'r', 'y', '\n',
        'p', 'r', 'o', 'b', 'a', 't', 'i', 'v', 'e', '\n',
        'p', 'r', 'o', 'b', 'e', '\n',
        'p', 'r', 'o', 'b', 'e', 'd', '\n',
        'p', 'r', 'o', 'b', 'e', 'r', '\n',
        'p', 'r', 'o', 'b', 'e', 's', '\n',
        'p', 'r', 'o', 'b', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'b', 'i', 't', 'y', '\n',
        'p', 'r', 'o', 'b', 'l', 'e', 'm', '\n',
        'p', 'r', 'o', 'b', 'l', 'e', 'm', 'a', 't', 'i', 'c', '\n',
        'p', 'r', 'o', 'b', 'l', 'e', 'm', 'a', 't', 'i', 'c', 'a', 'l', '\n',
        'p', 'r', 'o', 'b', 'l', 'e', 'm', 'a', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'p', 'r', 'o', 'b', 'l', 'e', 'm', 's', '\n',
        'p', 'r', 'o', 'b', 'o', 's', 'c', 'i', 's', '\n',
        'p', 'r', 'o', 'c', 'e', 'd', 'u', 'r', 'a', 'l', '\n',
        'p', 'r', 'o', 'c', 'e', 'd', 'u', 'r', 'a', 'l', 'l', 'y', '\n',
        'p', 'r', 'o', 'c', 'e', 'd', 'u', 'r', 'e', '\n',
        'p', 'r', 'o', 'c', 'e', 'd', 'u', 'r', 'e', 's', '\n',
        'p', 'r', 'o', 'c', 'e', 'e', 'd', '\n',
        'p', 'r', 'o', 'c', 'e', 'e', 'd', 'e', 'd', '\n',
        'p', 'r', 'o', 'c', 'e', 'e', 'd', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'c', 'e', 'e', 'd', 'i', 'n', 'g', 's', '\n',
        'p', 'r', 'o', 'c', 'e', 'e', 'd', 's', '\n',
        'p', 'r', 'o', 'c', 'e', 's', 's', '\n',
        'p', 'r', 'o', 'c', 'e', 's', 's', 'a', 'b', 'l', 'e', '\n',
        'p', 'r', 'o', 'c', 'e', 's', 's', 'e', 'd', '\n',
        'p', 'r', 'o', 'c', 'e', 's', 's', 'e', 's', '\n',
        'p', 'r', 'o', 'c', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'c', 'e', 's', 's', 'i', 'o', 'n', '\n',
        'p', 'r', 'o', 'c', 'e', 's', 's', 'i', 'o', 'n', 'a', 'l', '\n',
        'p', 'r', 'o', 'c', 'e', 's', 's', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'o', 'c', 'e', 's', 's', 'o', 'r', '\n',
        'p', 'r', 'o', 'c', 'e', 's', 's', 'o', 'r', 's', '\n',
        'p', 'r', 'o', 'c', 'l', 'a', 'i', 'm', '\n',
        'p', 'r', 'o', 'c', 'l', 'a', 'i', 'm', 'e', 'd', '\n',
        'p', 'r', 'o', 'c', 'l', 'a', 'i', 'm', 'e', 'r', 's', '\n',
        'p', 'r', 'o', 'c', 'l', 'a', 'i', 'm', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'c', 'l', 'a', 'i', 'm', 's', '\n',
        'p', 'r', 'o', 'c', 'l', 'a', 'm', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'o', 'c', 'l', 'a', 'm', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'o', 'c', 'l', 'i', 'v', 'i', 't', 'i', 'e', 's', '\n',
        'p', 'r', 'o', 'c', 'l', 'i', 'v', 'i', 't', 'y', '\n',
        'p', 'r', 'o', 'c', 'r', 'a', 's', 't', 'i', 'n', 'a', 't', 'e', '\n',
        'p', 'r', 'o', 'c', 'r', 'a', 's', 't', 'i', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'c', 'r', 'a', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'o', 'c', 'r', 'a', 's', 't', 'i', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'o', 'c', 'r', 'a', 's', 't', 'i', 'n', 'a', 't', 'o', 'r', '\n',
        'p', 'r', 'o', 'c', 'r', 'a', 's', 't', 'i', 'n', 'a', 't', 'o', 'r', 's', '\n',
        'p', 'r', 'o', 'c', 'r', 'e', 'a', 't', 'e', '\n',
        'p', 'r', 'o', 'c', 'r', 'e', 'a', 't', 'e', 'd', '\n',
        'p', 'r', 'o', 'c', 'r', 'e', 'a', 't', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'c', 'r', 'e', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'o', 'c', 'r', 'e', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'p', 'r', 'o', 'c', 'r', 'e', 'a', 't', 'i', 'v', 'e', '\n',
        'p', 'r', 'o', 'c', 'r', 'e', 'a', 't', 'o', 'r', 'y', '\n',
        'p', 'r', 'o', 'c', 't', 'o', 'r', '\n',
        'p', 'r', 'o', 'c', 't', 'o', 'r', 'i', 'a', 'l', '\n',
        'p', 'r', 'o', 'c', 't', 'o', 'r', 's', '\n',
        'p', 'r', 'o', 'c', 'u', 'r', 'a', 'b', 'l', 'e', '\n',
        'p', 'r', 'o', 'c', 'u', 'r', 'e', '\n',
        'p', 'r', 'o', 'c', 'u', 'r', 'e', 'd', '\n',
        'p', 'r', 'o', 'c', 'u', 'r', 'e', 'm', 'e', 'n', 't', '\n',
        'p', 'r', 'o', 'c', 'u', 'r', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'p', 'r', 'o', 'c', 'u', 'r', 'e', 's', '\n',
        'p', 'r', 'o', 'c', 'u', 'r', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'd', '\n',
        'p', 'r', 'o', 'd', 'd', 'e', 'd', '\n',
        'p', 'r', 'o', 'd', 'd', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'd', 'e', 'o', '\n',
        'p', 'r', 'o', 'd', 'i', 'g', 'a', 'l', '\n',
        'p', 'r', 'o', 'd', 'i', 'g', 'a', 'l', 'i', 't', 'y', '\n',
        'p', 'r', 'o', 'd', 'i', 'g', 'a', 'l', 'l', 'y', '\n',
        'p', 'r', 'o', 'd', 'i', 'g', 'i', 'e', 's', '\n',
        'p', 'r', 'o', 'd', 'i', 'g', 'i', 'o', 'u', 's', '\n',
        'p', 'r', 'o', 'd', 'i', 'g', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'p', 'r', 'o', 'd', 'i', 'g', 'y', '\n',
        'p', 'r', 'o', 'd', 's', '\n',
        'p', 'r', 'o', 'd', 'u', 'c', 'e', '\n',
        'p', 'r', 'o', 'd', 'u', 'c', 'e', 'd', '\n',
        'p', 'r', 'o', 'd', 'u', 'c', 'e', 'r', '\n',
        'p', 'r', 'o', 'd', 'u', 'c', 'e', 'r', 's', '\n',
        'p', 'r', 'o', 'd', 'u', 'c', 'e', 's', '\n',
        'p', 'r', 'o', 'd', 'u', 'c', 'i', 'b', 'l', 'e', '\n',
        'p', 'r', 'o', 'd', 'u', 'c', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'd', 'u', 'c', 't', '\n',
        'p', 'r', 'o', 'd', 'u', 'c', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'o', 'd', 'u', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'o', 'd', 'u', 'c', 't', 'i', 'v', 'e', '\n',
        'p', 'r', 'o', 'd', 'u', 'c', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'p', 'r', 'o', 'd', 'u', 'c', 't', 'i', 'v', 'i', 't', 'y', '\n',
        'p', 'r', 'o', 'd', 'u', 'c', 't', 's', '\n',
        'p', 'r', 'o', 'f', 'a', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'o', 'f', 'a', 'n', 'e', '\n',
        'p', 'r', 'o', 'f', 'a', 'n', 'e', 'd', '\n',
        'p', 'r', 'o', 'f', 'a', 'n', 'e', 'l', 'y', '\n',
        'p', 'r', 'o', 'f', 'a', 'n', 'e', 'n', 'e', 's', 's', '\n',
        'p', 'r', 'o', 'f', 'a', 'n', 'i', 't', 'i', 'e', 's', '\n',
        'p', 'r', 'o', 'f', 'a', 'n', 'i', 't', 'y', '\n',
        'p', 'r', 'o', 'f', 'e', 's', 's', '\n',
        'p', 'r', 'o', 'f', 'e', 's', 's', 'e', 'd', '\n',
        'p', 'r', 'o', 'f', 'e', 's', 's', 'e', 'd', 'l', 'y', '\n',
        'p', 'r', 'o', 'f', 'e', 's', 's', 'e', 's', '\n',
        'p', 'r', 'o', 'f', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'f', 'e', 's', 's', 'i', 'o', 'n', '\n',
        'p', 'r', 'o', 'f', 'e', 's', 's', 'i', 'o', 'n', 'a', 'l', '\n',
        'p', 'r', 'o', 'f', 'e', 's', 's', 'i', 'o', 'n', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'o', 'f', 'e', 's', 's', 'i', 'o', 'n', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'p', 'r', 'o', 'f', 'e', 's', 's', 'i', 'o', 'n', 'a', 'l', 'i', 's', 'm', '\n',
        'p', 'r', 'o', 'f', 'e', 's', 's', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'p', 'r', 'o', 'f', 'e', 's', 's', 'i', 'o', 'n', 'a', 'l', 's', '\n',
        'p', 'r', 'o', 'f', 'e', 's', 's', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'o', 'f', 'e', 's', 's', 'o', 'r', '\n',
        'p', 'r', 'o', 'f', 'e', 's', 's', 'o', 'r', 'i', 'a', 'l', '\n',
        'p', 'r', 'o', 'f', 'e', 's', 's', 'o', 'r', 's', '\n',
        'p', 'r', 'o', 'f', 'e', 's', 's', 'o', 'r', 's', 'h', 'i', 'p', '\n',
        'p', 'r', 'o', 'f', 'e', 's', 's', 'o', 'r', 's', 'h', 'i', 'p', 's', '\n',
        'p', 'r', 'o', 'f', 'f', 'e', 'r', '\n',
        'p', 'r', 'o', 'f', 'f', 'e', 'r', 'e', 'd', '\n',
        'p', 'r', 'o', 'f', 'f', 'e', 'r', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'f', 'f', 'e', 'r', 's', '\n',
        'p', 'r', 'o', 'f', 'i', 'c', 'i', 'e', 'n', 'c', 'i', 'e', 's', '\n',
        'p', 'r', 'o', 'f', 'i', 'c', 'i', 'e', 'n', 'c', 'y', '\n',
        'p', 'r', 'o', 'f', 'i', 'c', 'i', 'e', 'n', 't', '\n',
        'p', 'r', 'o', 'f', 'i', 'c', 'i', 'e', 'n', 't', 'l', 'y', '\n',
        'p', 'r', 'o', 'f', 'i', 'l', 'e', '\n',
        'p', 'r', 'o', 'f', 'i', 'l', 'e', 'd', '\n',
        'p', 'r', 'o', 'f', 'i', 'l', 'e', 's', '\n',
        'p', 'r', 'o', 'f', 'i', 'l', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'f', 'i', 't', '\n',
        'p', 'r', 'o', 'f', 'i', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'p', 'r', 'o', 'f', 'i', 't', 'a', 'b', 'l', 'e', '\n',
        'p', 'r', 'o', 'f', 'i', 't', 'a', 'b', 'l', 'y', '\n',
        'p', 'r', 'o', 'f', 'i', 't', 'e', 'd', '\n',
        'p', 'r', 'o', 'f', 'i', 't', 'e', 'e', 'r', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'f', 'i', 't', 'e', 'e', 'r', 's', '\n',
        'p', 'r', 'o', 'f', 'i', 't', 'e', 'r', 'o', 'l', 'e', 's', '\n',
        'p', 'r', 'o', 'f', 'i', 't', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'f', 'i', 't', 'l', 'e', 's', 's', '\n',
        'p', 'r', 'o', 'f', 'i', 't', 's', '\n',
        'p', 'r', 'o', 'f', 'i', 't', 't', 'a', 'k', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'f', 'l', 'i', 'g', 'a', 'c', 'y', '\n',
        'p', 'r', 'o', 'f', 'l', 'i', 'g', 'a', 't', 'e', '\n',
        'p', 'r', 'o', 'f', 'l', 'i', 'g', 'a', 't', 'e', 'l', 'y', '\n',
        'p', 'r', 'o', 'f', 'o', 'r', 'm', 'a', '\n',
        'p', 'r', 'o', 'f', 'o', 'r', 'm', 'a', 's', '\n',
        'p', 'r', 'o', 'f', 'o', 'u', 'n', 'd', '\n',
        'p', 'r', 'o', 'f', 'o', 'u', 'n', 'd', 'e', 'r', '\n',
        'p', 'r', 'o', 'f', 'o', 'u', 'n', 'd', 'e', 's', 't', '\n',
        'p', 'r', 'o', 'f', 'o', 'u', 'n', 'd', 'l', 'y', '\n',
        'p', 'r', 'o', 'f', 'u', 'n', 'd', 'i', 't', 'y', '\n',
        'p', 'r', 'o', 'f', 'u', 's', 'e', '\n',
        'p', 'r', 'o', 'f', 'u', 's', 'e', 'l', 'y', '\n',
        'p', 'r', 'o', 'f', 'u', 's', 'e', 'n', 'e', 's', 's', '\n',
        'p', 'r', 'o', 'f', 'u', 's', 'i', 'o', 'n', '\n',
        'p', 'r', 'o', 'g', 'e', 'n', 'i', 't', 'o', 'r', '\n',
        'p', 'r', 'o', 'g', 'e', 'n', 'i', 't', 'o', 'r', 's', '\n',
        'p', 'r', 'o', 'g', 'e', 'n', 'y', '\n',
        'p', 'r', 'o', 'g', 'e', 's', 't', 'e', 'r', 'o', 'n', 'e', '\n',
        'p', 'r', 'o', 'g', 'n', 'o', 's', 'e', 's', '\n',
        'p', 'r', 'o', 'g', 'n', 'o', 's', 'i', 's', '\n',
        'p', 'r', 'o', 'g', 'n', 'o', 's', 't', 'i', 'c', 'a', 't', 'e', '\n',
        'p', 'r', 'o', 'g', 'n', 'o', 's', 't', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'o', 'g', 'n', 'o', 's', 't', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'o', 'g', 'r', 'a', 'm', '\n',
        'p', 'r', 'o', 'g', 'r', 'a', 'm', 'm', 'a', 'b', 'l', 'e', '\n',
        'p', 'r', 'o', 'g', 'r', 'a', 'm', 'm', 'a', 't', 'i', 'c', '\n',
        'p', 'r', 'o', 'g', 'r', 'a', 'm', 'm', 'e', '\n',
        'p', 'r', 'o', 'g', 'r', 'a', 'm', 'm', 'e', 'd', '\n',
        'p', 'r', 'o', 'g', 'r', 'a', 'm', 'm', 'e', 'r', '\n',
        'p', 'r', 'o', 'g', 'r', 'a', 'm', 'm', 'e', 'r', 's', '\n',
        'p', 'r', 'o', 'g', 'r', 'a', 'm', 'm', 'e', 's', '\n',
        'p', 'r', 'o', 'g', 'r', 'a', 'm', 'm', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'g', 'r', 'a', 'm', 's', '\n',
        'p', 'r', 'o', 'g', 'r', 'e', 's', 's', '\n',
        'p', 'r', 'o', 'g', 'r', 'e', 's', 's', 'e', 'd', '\n',
        'p', 'r', 'o', 'g', 'r', 'e', 's', 's', 'e', 's', '\n',
        'p', 'r', 'o', 'g', 'r', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'g', 'r', 'e', 's', 's', 'i', 'o', 'n', '\n',
        'p', 'r', 'o', 'g', 'r', 'e', 's', 's', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'o', 'g', 'r', 'e', 's', 's', 'i', 'v', 'e', '\n',
        'p', 'r', 'o', 'g', 'r', 'e', 's', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'p', 'r', 'o', 'g', 'r', 'e', 's', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'p', 'r', 'o', 'g', 'r', 'e', 's', 's', 'i', 'v', 'e', 's', '\n',
        'p', 'r', 'o', 'h', 'i', 'b', 'i', 't', '\n',
        'p', 'r', 'o', 'h', 'i', 'b', 'i', 't', 'e', 'd', '\n',
        'p', 'r', 'o', 'h', 'i', 'b', 'i', 't', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'h', 'i', 'b', 'i', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'o', 'h', 'i', 'b', 'i', 't', 'i', 'o', 'n', 'i', 's', 't', '\n',
        'p', 'r', 'o', 'h', 'i', 'b', 'i', 't', 'i', 'o', 'n', 'i', 's', 't', 's', '\n',
        'p', 'r', 'o', 'h', 'i', 'b', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'o', 'h', 'i', 'b', 'i', 't', 'i', 'v', 'e', '\n',
        'p', 'r', 'o', 'h', 'i', 'b', 'i', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'p', 'r', 'o', 'h', 'i', 'b', 'i', 't', 's', '\n',
        'p', 'r', 'o', 'j', 'e', 'c', 't', '\n',
        'p', 'r', 'o', 'j', 'e', 'c', 't', 'e', 'd', '\n',
        'p', 'r', 'o', 'j', 'e', 'c', 't', 'i', 'l', 'e', '\n',
        'p', 'r', 'o', 'j', 'e', 'c', 't', 'i', 'l', 'e', 's', '\n',
        'p', 'r', 'o', 'j', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'j', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'o', 'j', 'e', 'c', 't', 'i', 'o', 'n', 'i', 's', 't', '\n',
        'p', 'r', 'o', 'j', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'o', 'j', 'e', 'c', 't', 'i', 'v', 'e', '\n',
        'p', 'r', 'o', 'j', 'e', 'c', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'p', 'r', 'o', 'j', 'e', 'c', 't', 'o', 'r', '\n',
        'p', 'r', 'o', 'j', 'e', 'c', 't', 'o', 'r', 's', '\n',
        'p', 'r', 'o', 'j', 'e', 'c', 't', 's', '\n',
        'p', 'r', 'o', 'k', 'a', 'r', 'y', 'o', 't', 'e', 's', '\n',
        'p', 'r', 'o', 'l', 'a', 'c', 't', 'i', 'n', '\n',
        'p', 'r', 'o', 'l', 'a', 'p', 's', 'e', '\n',
        'p', 'r', 'o', 'l', 'a', 'p', 's', 'e', 'd', '\n',
        'p', 'r', 'o', 'l', 'e', 't', 'a', 'r', 'i', 'a', 'n', '\n',
        'p', 'r', 'o', 'l', 'e', 't', 'a', 'r', 'i', 'a', 'n', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'o', 'l', 'e', 't', 'a', 'r', 'i', 'a', 'n', 's', '\n',
        'p', 'r', 'o', 'l', 'e', 't', 'a', 'r', 'i', 'a', 't', '\n',
        'p', 'r', 'o', 'l', 'i', 'f', 'e', 'r', 'a', 't', 'e', '\n',
        'p', 'r', 'o', 'l', 'i', 'f', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'p', 'r', 'o', 'l', 'i', 'f', 'e', 'r', 'a', 't', 'e', 's', '\n',
        'p', 'r', 'o', 'l', 'i', 'f', 'e', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'l', 'i', 'f', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'o', 'l', 'i', 'f', 'e', 'r', 'a', 't', 'i', 'v', 'e', '\n',
        'p', 'r', 'o', 'l', 'i', 'f', 'i', 'c', '\n',
        'p', 'r', 'o', 'l', 'i', 'f', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'p', 'r', 'o', 'l', 'i', 'x', '\n',
        'p', 'r', 'o', 'l', 'o', 'g', 'u', 'e', '\n',
        'p', 'r', 'o', 'l', 'o', 'g', 'u', 'e', 's', '\n',
        'p', 'r', 'o', 'l', 'o', 'n', 'g', '\n',
        'p', 'r', 'o', 'l', 'o', 'n', 'g', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'o', 'l', 'o', 'n', 'g', 'e', 'd', '\n',
        'p', 'r', 'o', 'l', 'o', 'n', 'g', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'l', 'o', 'n', 'g', 's', '\n',
        'p', 'r', 'o', 'm', 'e', 'n', 'a', 'd', 'e', '\n',
        'p', 'r', 'o', 'm', 'e', 'n', 'a', 'd', 'e', 'd', '\n',
        'p', 'r', 'o', 'm', 'e', 'n', 'a', 'd', 'e', 'r', '\n',
        'p', 'r', 'o', 'm', 'e', 'n', 'a', 'd', 'e', 'r', 's', '\n',
        'p', 'r', 'o', 'm', 'e', 'n', 'a', 'd', 'e', 's', '\n',
        'p', 'r', 'o', 'm', 'i', 'n', 'e', 'n', 'c', 'e', '\n',
        'p', 'r', 'o', 'm', 'i', 'n', 'e', 'n', 'c', 'e', 's', '\n',
        'p', 'r', 'o', 'm', 'i', 'n', 'e', 'n', 't', '\n',
        'p', 'r', 'o', 'm', 'i', 'n', 'e', 'n', 't', 'l', 'y', '\n',
        'p', 'r', 'o', 'm', 'i', 's', 'c', 'u', 'i', 't', 'y', '\n',
        'p', 'r', 'o', 'm', 'i', 's', 'c', 'u', 'o', 'u', 's', '\n',
        'p', 'r', 'o', 'm', 'i', 's', 'c', 'u', 'o', 'u', 's', 'l', 'y', '\n',
        'p', 'r', 'o', 'm', 'i', 's', 'e', '\n',
        'p', 'r', 'o', 'm', 'i', 's', 'e', 'd', '\n',
        'p', 'r', 'o', 'm', 'i', 's', 'e', 's', '\n',
        'p', 'r', 'o', 'm', 'i', 's', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'm', 'i', 's', 'i', 'n', 'g', 'l', 'y', '\n',
        'p', 'r', 'o', 'm', 'i', 's', 's', 'o', 'r', 'y', '\n',
        'p', 'r', 'o', 'm', 'o', 'n', 't', 'o', 'r', 'i', 'e', 's', '\n',
        'p', 'r', 'o', 'm', 'o', 'n', 't', 'o', 'r', 'y', '\n',
        'p', 'r', 'o', 'm', 'o', 't', 'a', 'b', 'l', 'e', '\n',
        'p', 'r', 'o', 'm', 'o', 't', 'e', '\n',
        'p', 'r', 'o', 'm', 'o', 't', 'e', 'd', '\n',
        'p', 'r', 'o', 'm', 'o', 't', 'e', 'r', '\n',
        'p', 'r', 'o', 'm', 'o', 't', 'e', 'r', 's', '\n',
        'p', 'r', 'o', 'm', 'o', 't', 'e', 's', '\n',
        'p', 'r', 'o', 'm', 'o', 't', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'm', 'o', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'o', 'm', 'o', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'p', 'r', 'o', 'm', 'o', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'o', 'm', 'p', 't', '\n',
        'p', 'r', 'o', 'm', 'p', 't', 'e', 'd', '\n',
        'p', 'r', 'o', 'm', 'p', 't', 'e', 'r', '\n',
        'p', 'r', 'o', 'm', 'p', 't', 'e', 'r', 's', '\n',
        'p', 'r', 'o', 'm', 'p', 't', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'm', 'p', 't', 'i', 'n', 'g', 's', '\n',
        'p', 'r', 'o', 'm', 'p', 't', 'i', 't', 'u', 'd', 'e', '\n',
        'p', 'r', 'o', 'm', 'p', 't', 'l', 'y', '\n',
        'p', 'r', 'o', 'm', 'p', 't', 'n', 'e', 's', 's', '\n',
        'p', 'r', 'o', 'm', 'p', 't', 's', '\n',
        'p', 'r', 'o', 'm', 'u', 'l', 'g', 'a', 't', 'e', '\n',
        'p', 'r', 'o', 'm', 'u', 'l', 'g', 'a', 't', 'e', 'd', '\n',
        'p', 'r', 'o', 'm', 'u', 'l', 'g', 'a', 't', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'm', 'u', 'l', 'g', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'o', 'm', 'u', 'l', 'g', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'o', 'n', 'e', '\n',
        'p', 'r', 'o', 'n', 'e', 'n', 'e', 's', 's', '\n',
        'p', 'r', 'o', 'n', 'g', '\n',
        'p', 'r', 'o', 'n', 'g', 's', '\n',
        'p', 'r', 'o', 'n', 'o', 'm', 'i', 'n', 'a', 'l', '\n',
        'p', 'r', 'o', 'n', 'o', 'u', 'n', '\n',
        'p', 'r', 'o', 'n', 'o', 'u', 'n', 'c', 'e', '\n',
        'p', 'r', 'o', 'n', 'o', 'u', 'n', 'c', 'e', 'a', 'b', 'l', 'e', '\n',
        'p', 'r', 'o', 'n', 'o', 'u', 'n', 'c', 'e', 'd', '\n',
        'p', 'r', 'o', 'n', 'o', 'u', 'n', 'c', 'e', 'd', 'l', 'y', '\n',
        'p', 'r', 'o', 'n', 'o', 'u', 'n', 'c', 'e', 'm', 'e', 'n', 't', '\n',
        'p', 'r', 'o', 'n', 'o', 'u', 'n', 'c', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'p', 'r', 'o', 'n', 'o', 'u', 'n', 'c', 'e', 's', '\n',
        'p', 'r', 'o', 'n', 'o', 'u', 'n', 'c', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'n', 'o', 'u', 'n', 's', '\n',
        'p', 'r', 'o', 'n', 't', 'o', '\n',
        'p', 'r', 'o', 'n', 'u', 'n', 'c', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'o', 'n', 'u', 'n', 'c', 'i', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'o', 'o', 'f', '\n',
        'p', 'r', 'o', 'o', 'f', 'e', 'd', '\n',
        'p', 'r', 'o', 'o', 'f', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'o', 'f', 'r', 'e', 'a', 'd', '\n',
        'p', 'r', 'o', 'o', 'f', 'r', 'e', 'a', 'd', 'e', 'r', '\n',
        'p', 'r', 'o', 'o', 'f', 'r', 'e', 'a', 'd', 'e', 'r', 's', '\n',
        'p', 'r', 'o', 'o', 'f', 'r', 'e', 'a', 'd', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'o', 'f', 'r', 'e', 'a', 'd', 's', '\n',
        'p', 'r', 'o', 'o', 'f', 's', '\n',
        'p', 'r', 'o', 'p', '\n',
        'p', 'r', 'o', 'p', 'a', 'g', 'a', 'n', 'd', 'a', '\n',
        'p', 'r', 'o', 'p', 'a', 'g', 'a', 'n', 'd', 'i', 's', 't', '\n',
        'p', 'r', 'o', 'p', 'a', 'g', 'a', 'n', 'd', 'i', 's', 't', 's', '\n',
        'p', 'r', 'o', 'p', 'a', 'g', 'a', 't', 'e', '\n',
        'p', 'r', 'o', 'p', 'a', 'g', 'a', 't', 'e', 'd', '\n',
        'p', 'r', 'o', 'p', 'a', 'g', 'a', 't', 'e', 's', '\n',
        'p', 'r', 'o', 'p', 'a', 'g', 'a', 't', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'p', 'a', 'g', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'o', 'p', 'a', 'g', 'a', 't', 'o', 'r', '\n',
        'p', 'r', 'o', 'p', 'a', 'g', 'a', 't', 'o', 'r', 's', '\n',
        'p', 'r', 'o', 'p', 'a', 'n', 'e', '\n',
        'p', 'r', 'o', 'p', 'e', 'l', '\n',
        'p', 'r', 'o', 'p', 'e', 'l', 'l', 'a', 'n', 't', '\n',
        'p', 'r', 'o', 'p', 'e', 'l', 'l', 'a', 'n', 't', 's', '\n',
        'p', 'r', 'o', 'p', 'e', 'l', 'l', 'e', 'd', '\n',
        'p', 'r', 'o', 'p', 'e', 'l', 'l', 'e', 'r', '\n',
        'p', 'r', 'o', 'p', 'e', 'l', 'l', 'e', 'r', 's', '\n',
        'p', 'r', 'o', 'p', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'p', 'e', 'l', 's', '\n',
        'p', 'r', 'o', 'p', 'e', 'n', 's', 'i', 't', 'i', 'e', 's', '\n',
        'p', 'r', 'o', 'p', 'e', 'n', 's', 'i', 't', 'y', '\n',
        'p', 'r', 'o', 'p', 'e', 'r', '\n',
        'p', 'r', 'o', 'p', 'e', 'r', 'l', 'y', '\n',
        'p', 'r', 'o', 'p', 'e', 'r', 't', 'i', 'e', 'd', '\n',
        'p', 'r', 'o', 'p', 'e', 'r', 't', 'i', 'e', 's', '\n',
        'p', 'r', 'o', 'p', 'e', 'r', 't', 'y', '\n',
        'p', 'r', 'o', 'p', 'h', 'e', 'c', 'i', 'e', 's', '\n',
        'p', 'r', 'o', 'p', 'h', 'e', 'c', 'y', '\n',
        'p', 'r', 'o', 'p', 'h', 'e', 's', 'i', 'e', 'd', '\n',
        'p', 'r', 'o', 'p', 'h', 'e', 's', 'i', 'e', 's', '\n',
        'p', 'r', 'o', 'p', 'h', 'e', 's', 'y', '\n',
        'p', 'r', 'o', 'p', 'h', 'e', 's', 'y', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'p', 'h', 'e', 't', '\n',
        'p', 'r', 'o', 'p', 'h', 'e', 't', 'e', 's', 's', '\n',
        'p', 'r', 'o', 'p', 'h', 'e', 't', 'i', 'c', '\n',
        'p', 'r', 'o', 'p', 'h', 'e', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'p', 'r', 'o', 'p', 'h', 'e', 't', 's', '\n',
        'p', 'r', 'o', 'p', 'h', 'y', 'l', 'a', 'c', 't', 'i', 'c', '\n',
        'p', 'r', 'o', 'p', 'h', 'y', 'l', 'a', 'c', 't', 'i', 'c', 's', '\n',
        'p', 'r', 'o', 'p', 'h', 'y', 'l', 'a', 'x', 'i', 's', '\n',
        'p', 'r', 'o', 'p', 'i', 'n', 'q', 'u', 'i', 't', 'y', '\n',
        'p', 'r', 'o', 'p', 'i', 'o', 'n', 'a', 't', 'e', '\n',
        'p', 'r', 'o', 'p', 'i', 't', 'i', 'a', 't', 'e', '\n',
        'p', 'r', 'o', 'p', 'i', 't', 'i', 'a', 't', 'e', 'd', '\n',
        'p', 'r', 'o', 'p', 'i', 't', 'i', 'a', 't', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'p', 'i', 't', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'o', 'p', 'i', 't', 'i', 'a', 't', 'o', 'r', 'y', '\n',
        'p', 'r', 'o', 'p', 'i', 't', 'i', 'o', 'u', 's', '\n',
        'p', 'r', 'o', 'p', 'o', 'n', 'e', 'n', 't', '\n',
        'p', 'r', 'o', 'p', 'o', 'n', 'e', 'n', 't', 's', '\n',
        'p', 'r', 'o', 'p', 'o', 'r', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'o', 'p', 'o', 'r', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'p', 'r', 'o', 'p', 'o', 'r', 't', 'i', 'o', 'n', 'a', 'l', 'i', 't', 'y', '\n',
        'p', 'r', 'o', 'p', 'o', 'r', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'p', 'r', 'o', 'p', 'o', 'r', 't', 'i', 'o', 'n', 'a', 't', 'e', '\n',
        'p', 'r', 'o', 'p', 'o', 'r', 't', 'i', 'o', 'n', 'a', 't', 'e', 'l', 'y', '\n',
        'p', 'r', 'o', 'p', 'o', 'r', 't', 'i', 'o', 'n', 'e', 'd', '\n',
        'p', 'r', 'o', 'p', 'o', 'r', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'o', 'p', 'o', 's', 'a', 'l', '\n',
        'p', 'r', 'o', 'p', 'o', 's', 'a', 'l', 's', '\n',
        'p', 'r', 'o', 'p', 'o', 's', 'e', '\n',
        'p', 'r', 'o', 'p', 'o', 's', 'e', 'd', '\n',
        'p', 'r', 'o', 'p', 'o', 's', 'e', 'r', '\n',
        'p', 'r', 'o', 'p', 'o', 's', 'e', 'r', 's', '\n',
        'p', 'r', 'o', 'p', 'o', 's', 'e', 's', '\n',
        'p', 'r', 'o', 'p', 'o', 's', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'o', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'p', 'r', 'o', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'e', 'd', '\n',
        'p', 'r', 'o', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'o', 'p', 'o', 'u', 'n', 'd', '\n',
        'p', 'r', 'o', 'p', 'o', 'u', 'n', 'd', 'e', 'd', '\n',
        'p', 'r', 'o', 'p', 'o', 'u', 'n', 'd', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'p', 'p', 'e', 'd', '\n',
        'p', 'r', 'o', 'p', 'p', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'p', 'r', 'i', 'e', 't', 'a', 'r', 'y', '\n',
        'p', 'r', 'o', 'p', 'r', 'i', 'e', 't', 'i', 'e', 's', '\n',
        'p', 'r', 'o', 'p', 'r', 'i', 'e', 't', 'o', 'r', '\n',
        'p', 'r', 'o', 'p', 'r', 'i', 'e', 't', 'o', 'r', 'i', 'a', 'l', '\n',
        'p', 'r', 'o', 'p', 'r', 'i', 'e', 't', 'o', 'r', 'i', 'a', 'l', 'l', 'y', '\n',
        'p', 'r', 'o', 'p', 'r', 'i', 'e', 't', 'o', 'r', 's', '\n',
        'p', 'r', 'o', 'p', 'r', 'i', 'e', 't', 'o', 'r', 's', 'h', 'i', 'p', '\n',
        'p', 'r', 'o', 'p', 'r', 'i', 'e', 't', 'r', 'e', 's', 's', '\n',
        'p', 'r', 'o', 'p', 'r', 'i', 'e', 't', 'y', '\n',
        'p', 'r', 'o', 'p', 'r', 'i', 'o', 'c', 'e', 'p', 't', 'i', 'v', 'e', '\n',
        'p', 'r', 'o', 'p', 's', '\n',
        'p', 'r', 'o', 'p', 'u', 'l', 's', 'i', 'o', 'n', '\n',
        'p', 'r', 'o', 'p', 'u', 'l', 's', 'i', 'v', 'e', '\n',
        'p', 'r', 'o', 'p', 'y', 'l', 'e', 'n', 'e', '\n',
        'p', 'r', 'o', 's', '\n',
        'p', 'r', 'o', 's', 'a', 'i', 'c', '\n',
        'p', 'r', 'o', 's', 'a', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'p', 'r', 'o', 's', 'a', 'i', 's', 't', '\n',
        'p', 'r', 'o', 's', 'c', 'e', 'n', 'i', 'u', 'm', '\n',
        'p', 'r', 'o', 's', 'c', 'r', 'i', 'b', 'e', '\n',
        'p', 'r', 'o', 's', 'c', 'r', 'i', 'b', 'e', 'd', '\n',
        'p', 'r', 'o', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'o', 's', 'c', 'r', 'i', 'p', 't', 'i', 'v', 'e', '\n',
        'p', 'r', 'o', 's', 'e', '\n',
        'p', 'r', 'o', 's', 'e', 'c', 'u', 't', 'a', 'b', 'l', 'e', '\n',
        'p', 'r', 'o', 's', 'e', 'c', 'u', 't', 'e', '\n',
        'p', 'r', 'o', 's', 'e', 'c', 'u', 't', 'e', 'd', '\n',
        'p', 'r', 'o', 's', 'e', 'c', 'u', 't', 'e', 's', '\n',
        'p', 'r', 'o', 's', 'e', 'c', 'u', 't', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 's', 'e', 'c', 'u', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'o', 's', 'e', 'c', 'u', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'o', 's', 'e', 'c', 'u', 't', 'o', 'r', '\n',
        'p', 'r', 'o', 's', 'e', 'c', 'u', 't', 'o', 'r', 'i', 'a', 'l', '\n',
        'p', 'r', 'o', 's', 'e', 'c', 'u', 't', 'o', 'r', 's', '\n',
        'p', 'r', 'o', 's', 'e', 'l', 'y', 't', 'i', 's', 'e', '\n',
        'p', 'r', 'o', 's', 'e', 'l', 'y', 't', 'i', 's', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 's', 'o', 'd', 'i', 'c', '\n',
        'p', 'r', 'o', 's', 'o', 'd', 'y', '\n',
        'p', 'r', 'o', 's', 'p', 'e', 'c', 't', '\n',
        'p', 'r', 'o', 's', 'p', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 's', 'p', 'e', 'c', 't', 'i', 'v', 'e', '\n',
        'p', 'r', 'o', 's', 'p', 'e', 'c', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'p', 'r', 'o', 's', 'p', 'e', 'c', 't', 'o', 'r', '\n',
        'p', 'r', 'o', 's', 'p', 'e', 'c', 't', 'o', 'r', 's', '\n',
        'p', 'r', 'o', 's', 'p', 'e', 'c', 't', 's', '\n',
        'p', 'r', 'o', 's', 'p', 'e', 'c', 't', 'u', 's', '\n',
        'p', 'r', 'o', 's', 'p', 'e', 'c', 't', 'u', 's', 'e', 's', '\n',
        'p', 'r', 'o', 's', 'p', 'e', 'r', '\n',
        'p', 'r', 'o', 's', 'p', 'e', 'r', 'e', 'd', '\n',
        'p', 'r', 'o', 's', 'p', 'e', 'r', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 's', 'p', 'e', 'r', 'i', 't', 'y', '\n',
        'p', 'r', 'o', 's', 'p', 'e', 'r', 'o', 'u', 's', '\n',
        'p', 'r', 'o', 's', 'p', 'e', 'r', 'o', 'u', 's', 'l', 'y', '\n',
        'p', 'r', 'o', 's', 'p', 'e', 'r', 's', '\n',
        'p', 'r', 'o', 's', 't', 'a', 'g', 'l', 'a', 'n', 'd', 'i', 'n', '\n',
        'p', 'r', 'o', 's', 't', 'a', 'g', 'l', 'a', 'n', 'd', 'i', 'n', 's', '\n',
        'p', 'r', 'o', 's', 't', 'a', 't', 'e', '\n',
        'p', 'r', 'o', 's', 't', 'a', 't', 'e', 's', '\n',
        'p', 'r', 'o', 's', 't', 'a', 't', 'i', 'c', '\n',
        'p', 'r', 'o', 's', 't', 'h', 'e', 's', 'i', 's', '\n',
        'p', 'r', 'o', 's', 't', 'h', 'e', 't', 'i', 'c', '\n',
        'p', 'r', 'o', 's', 't', 'i', 't', 'u', 't', 'e', '\n',
        'p', 'r', 'o', 's', 't', 'i', 't', 'u', 't', 'e', 'd', '\n',
        'p', 'r', 'o', 's', 't', 'i', 't', 'u', 't', 'e', 's', '\n',
        'p', 'r', 'o', 's', 't', 'i', 't', 'u', 't', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 's', 't', 'i', 't', 'u', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'o', 's', 't', 'r', 'a', 't', 'e', '\n',
        'p', 'r', 'o', 's', 't', 'r', 'a', 't', 'e', 'd', '\n',
        'p', 'r', 'o', 's', 't', 'r', 'a', 't', 'e', 's', '\n',
        'p', 'r', 'o', 's', 't', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 's', 't', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'o', 't', 'a', 'c', 't', 'i', 'n', 'i', 'u', 'm', '\n',
        'p', 'r', 'o', 't', 'a', 'g', 'o', 'n', 'i', 's', 't', '\n',
        'p', 'r', 'o', 't', 'a', 'g', 'o', 'n', 'i', 's', 't', 's', '\n',
        'p', 'r', 'o', 't', 'e', 'a', '\n',
        'p', 'r', 'o', 't', 'e', 'a', 'n', '\n',
        'p', 'r', 'o', 't', 'e', 'a', 's', '\n',
        'p', 'r', 'o', 't', 'e', 'a', 's', 'e', '\n',
        'p', 'r', 'o', 't', 'e', 'c', 't', '\n',
        'p', 'r', 'o', 't', 'e', 'c', 't', 'e', 'd', '\n',
        'p', 'r', 'o', 't', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 't', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'o', 't', 'e', 'c', 't', 'i', 'o', 'n', 'i', 's', 'm', '\n',
        'p', 'r', 'o', 't', 'e', 'c', 't', 'i', 'o', 'n', 'i', 's', 't', '\n',
        'p', 'r', 'o', 't', 'e', 'c', 't', 'i', 'o', 'n', 'i', 's', 't', 's', '\n',
        'p', 'r', 'o', 't', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'o', 't', 'e', 'c', 't', 'i', 'v', 'e', '\n',
        'p', 'r', 'o', 't', 'e', 'c', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'p', 'r', 'o', 't', 'e', 'c', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'p', 'r', 'o', 't', 'e', 'c', 't', 'o', 'r', '\n',
        'p', 'r', 'o', 't', 'e', 'c', 't', 'o', 'r', 'a', 't', 'e', '\n',
        'p', 'r', 'o', 't', 'e', 'c', 't', 'o', 'r', 'a', 't', 'e', 's', '\n',
        'p', 'r', 'o', 't', 'e', 'c', 't', 'o', 'r', 's', '\n',
        'p', 'r', 'o', 't', 'e', 'c', 't', 's', '\n',
        'p', 'r', 'o', 't', 'e', 'g', 'e', '\n',
        'p', 'r', 'o', 't', 'e', 'g', 'e', 'e', '\n',
        'p', 'r', 'o', 't', 'e', 'g', 'e', 'e', 's', '\n',
        'p', 'r', 'o', 't', 'e', 'g', 'e', 's', '\n',
        'p', 'r', 'o', 't', 'e', 'i', 'n', '\n',
        'p', 'r', 'o', 't', 'e', 'i', 'n', 's', '\n',
        'p', 'r', 'o', 't', 'e', 's', 't', '\n',
        'p', 'r', 'o', 't', 'e', 's', 't', 'a', 'n', 't', '\n',
        'p', 'r', 'o', 't', 'e', 's', 't', 'a', 'n', 't', 'i', 's', 'm', '\n',
        'p', 'r', 'o', 't', 'e', 's', 't', 'a', 'n', 't', 's', '\n',
        'p', 'r', 'o', 't', 'e', 's', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'o', 't', 'e', 's', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'o', 't', 'e', 's', 't', 'e', 'd', '\n',
        'p', 'r', 'o', 't', 'e', 's', 't', 'e', 'r', '\n',
        'p', 'r', 'o', 't', 'e', 's', 't', 'e', 'r', 's', '\n',
        'p', 'r', 'o', 't', 'e', 's', 't', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 't', 'e', 's', 't', 'o', 'r', '\n',
        'p', 'r', 'o', 't', 'e', 's', 't', 'o', 'r', 's', '\n',
        'p', 'r', 'o', 't', 'e', 's', 't', 's', '\n',
        'p', 'r', 'o', 't', 'i', 's', 't', 's', '\n',
        'p', 'r', 'o', 't', 'o', 'c', 'o', 'l', '\n',
        'p', 'r', 'o', 't', 'o', 'c', 'o', 'l', 's', '\n',
        'p', 'r', 'o', 't', 'o', 'n', '\n',
        'p', 'r', 'o', 't', 'o', 'n', 's', '\n',
        'p', 'r', 'o', 't', 'o', 'p', 'l', 'a', 's', 'm', '\n',
        'p', 'r', 'o', 't', 'o', 'p', 'l', 'a', 's', 'm', 'i', 'c', '\n',
        'p', 'r', 'o', 't', 'o', 't', 'y', 'p', 'e', '\n',
        'p', 'r', 'o', 't', 'o', 't', 'y', 'p', 'e', 'd', '\n',
        'p', 'r', 'o', 't', 'o', 't', 'y', 'p', 'e', 's', '\n',
        'p', 'r', 'o', 't', 'o', 't', 'y', 'p', 'i', 'c', 'a', 'l', '\n',
        'p', 'r', 'o', 't', 'o', 't', 'y', 'p', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 't', 'o', 'z', 'o', 'a', '\n',
        'p', 'r', 'o', 't', 'o', 'z', 'o', 'a', 'n', '\n',
        'p', 'r', 'o', 't', 'o', 'z', 'o', 'a', 'n', 's', '\n',
        'p', 'r', 'o', 't', 'r', 'a', 'c', 't', '\n',
        'p', 'r', 'o', 't', 'r', 'a', 'c', 't', 'e', 'd', '\n',
        'p', 'r', 'o', 't', 'r', 'a', 'c', 't', 'o', 'r', '\n',
        'p', 'r', 'o', 't', 'r', 'a', 'c', 't', 'o', 'r', 's', '\n',
        'p', 'r', 'o', 't', 'r', 'u', 'd', 'e', '\n',
        'p', 'r', 'o', 't', 'r', 'u', 'd', 'e', 'd', '\n',
        'p', 'r', 'o', 't', 'r', 'u', 'd', 'e', 's', '\n',
        'p', 'r', 'o', 't', 'r', 'u', 'd', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 't', 'r', 'u', 's', 'i', 'o', 'n', '\n',
        'p', 'r', 'o', 't', 'r', 'u', 's', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'o', 't', 'r', 'u', 's', 'i', 'v', 'e', '\n',
        'p', 'r', 'o', 't', 'u', 'b', 'e', 'r', 'a', 'n', 'c', 'e', '\n',
        'p', 'r', 'o', 't', 'u', 'b', 'e', 'r', 'a', 'n', 'c', 'e', 's', '\n',
        'p', 'r', 'o', 'u', 'd', '\n',
        'p', 'r', 'o', 'u', 'd', 'e', 'r', '\n',
        'p', 'r', 'o', 'u', 'd', 'e', 's', 't', '\n',
        'p', 'r', 'o', 'u', 'd', 'l', 'y', '\n',
        'p', 'r', 'o', 'v', 'a', 'b', 'l', 'e', '\n',
        'p', 'r', 'o', 'v', 'a', 'b', 'l', 'y', '\n',
        'p', 'r', 'o', 'v', 'e', '\n',
        'p', 'r', 'o', 'v', 'e', 'd', '\n',
        'p', 'r', 'o', 'v', 'e', 'n', '\n',
        'p', 'r', 'o', 'v', 'e', 'n', 'a', 'n', 'c', 'e', '\n',
        'p', 'r', 'o', 'v', 'e', 'n', 'c', 'e', '\n',
        'p', 'r', 'o', 'v', 'e', 'r', 'b', '\n',
        'p', 'r', 'o', 'v', 'e', 'r', 'b', 'i', 'a', 'l', '\n',
        'p', 'r', 'o', 'v', 'e', 'r', 'b', 'i', 'a', 'l', 'l', 'y', '\n',
        'p', 'r', 'o', 'v', 'e', 'r', 'b', 's', '\n',
        'p', 'r', 'o', 'v', 'e', 's', '\n',
        'p', 'r', 'o', 'v', 'i', 'd', 'a', 'b', 'l', 'e', '\n',
        'p', 'r', 'o', 'v', 'i', 'd', 'e', '\n',
        'p', 'r', 'o', 'v', 'i', 'd', 'e', 'd', '\n',
        'p', 'r', 'o', 'v', 'i', 'd', 'e', 'n', 'c', 'e', '\n',
        'p', 'r', 'o', 'v', 'i', 'd', 'e', 'n', 't', '\n',
        'p', 'r', 'o', 'v', 'i', 'd', 'e', 'n', 't', 'i', 'a', 'l', '\n',
        'p', 'r', 'o', 'v', 'i', 'd', 'e', 'n', 't', 'i', 'a', 'l', 'l', 'y', '\n',
        'p', 'r', 'o', 'v', 'i', 'd', 'e', 'r', '\n',
        'p', 'r', 'o', 'v', 'i', 'd', 'e', 'r', 's', '\n',
        'p', 'r', 'o', 'v', 'i', 'd', 'e', 's', '\n',
        'p', 'r', 'o', 'v', 'i', 'd', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'v', 'i', 'n', 'c', 'e', '\n',
        'p', 'r', 'o', 'v', 'i', 'n', 'c', 'e', 's', '\n',
        'p', 'r', 'o', 'v', 'i', 'n', 'c', 'i', 'a', 'l', '\n',
        'p', 'r', 'o', 'v', 'i', 'n', 'c', 'i', 'a', 'l', 'i', 's', 'm', '\n',
        'p', 'r', 'o', 'v', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'v', 'i', 's', 'i', 'o', 'n', '\n',
        'p', 'r', 'o', 'v', 'i', 's', 'i', 'o', 'n', 'a', 'l', '\n',
        'p', 'r', 'o', 'v', 'i', 's', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'p', 'r', 'o', 'v', 'i', 's', 'i', 'o', 'n', 'e', 'd', '\n',
        'p', 'r', 'o', 'v', 'i', 's', 'i', 'o', 'n', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'v', 'i', 's', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'o', 'v', 'o', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'r', 'o', 'v', 'o', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'r', 'o', 'v', 'o', 'c', 'a', 't', 'i', 'v', 'e', '\n',
        'p', 'r', 'o', 'v', 'o', 'c', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'p', 'r', 'o', 'v', 'o', 'k', 'e', '\n',
        'p', 'r', 'o', 'v', 'o', 'k', 'e', 'd', '\n',
        'p', 'r', 'o', 'v', 'o', 'k', 'e', 'r', '\n',
        'p', 'r', 'o', 'v', 'o', 'k', 'e', 's', '\n',
        'p', 'r', 'o', 'v', 'o', 'k', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'v', 'o', 'k', 'i', 'n', 'g', 'l', 'y', '\n',
        'p', 'r', 'o', 'v', 'o', 's', 't', '\n',
        'p', 'r', 'o', 'w', '\n',
        'p', 'r', 'o', 'w', 'e', 's', 's', '\n',
        'p', 'r', 'o', 'w', 'l', '\n',
        'p', 'r', 'o', 'w', 'l', 'e', 'd', '\n',
        'p', 'r', 'o', 'w', 'l', 'e', 'r', '\n',
        'p', 'r', 'o', 'w', 'l', 'e', 'r', 's', '\n',
        'p', 'r', 'o', 'w', 'l', 'i', 'n', 'g', '\n',
        'p', 'r', 'o', 'w', 'l', 's', '\n',
        'p', 'r', 'o', 'w', 's', '\n',
        'p', 'r', 'o', 'x', 'i', 'e', 's', '\n',
        'p', 'r', 'o', 'x', 'i', 'm', 'a', 'l', '\n',
        'p', 'r', 'o', 'x', 'i', 'm', 'a', 'l', 'l', 'y', '\n',
        'p', 'r', 'o', 'x', 'i', 'm', 'a', 't', 'e', '\n',
        'p', 'r', 'o', 'x', 'i', 'm', 'a', 't', 'e', 'l', 'y', '\n',
        'p', 'r', 'o', 'x', 'i', 'm', 'i', 't', 'y', '\n',
        'p', 'r', 'o', 'x', 'i', 'm', 'o', '\n',
        'p', 'r', 'o', 'x', 'y', '\n',
        'p', 'r', 'u', 'd', 'e', '\n',
        'p', 'r', 'u', 'd', 'e', 'n', 'c', 'e', '\n',
        'p', 'r', 'u', 'd', 'e', 'n', 't', '\n',
        'p', 'r', 'u', 'd', 'e', 'n', 't', 'i', 'a', 'l', '\n',
        'p', 'r', 'u', 'd', 'e', 'n', 't', 'l', 'y', '\n',
        'p', 'r', 'u', 'd', 'e', 'r', 'y', '\n',
        'p', 'r', 'u', 'd', 'i', 's', 'h', '\n',
        'p', 'r', 'u', 'd', 'i', 's', 'h', 'n', 'e', 's', 's', '\n',
        'p', 'r', 'u', 'n', 'e', '\n',
        'p', 'r', 'u', 'n', 'e', 'd', '\n',
        'p', 'r', 'u', 'n', 'e', 'r', 's', '\n',
        'p', 'r', 'u', 'n', 'e', 's', '\n',
        'p', 'r', 'u', 'n', 'i', 'n', 'g', '\n',
        'p', 'r', 'u', 'n', 'i', 'n', 'g', 's', '\n',
        'p', 'r', 'u', 'r', 'i', 'e', 'n', 'c', 'e', '\n',
        'p', 'r', 'u', 'r', 'i', 'e', 'n', 't', '\n',
        'p', 'r', 'u', 'r', 'i', 't', 'u', 's', '\n',
        'p', 'r', 'u', 's', 's', 'i', 'a', '\n',
        'p', 'r', 'u', 's', 's', 'i', 'a', 'n', '\n',
        'p', 'r', 'u', 's', 's', 'i', 'c', '\n',
        'p', 'r', 'y', '\n',
        'p', 'r', 'y', 'i', 'n', 'g', '\n',
        'p', 'r', 'y', 'i', 'n', 'g', 's', '\n',
        'p', 's', 'a', 'l', 'm', '\n',
        'p', 's', 'a', 'l', 'm', 'i', 's', 't', '\n',
        'p', 's', 'a', 'l', 'm', 'o', 'd', 'y', '\n',
        'p', 's', 'a', 'l', 'm', 's', '\n',
        'p', 's', 'a', 'l', 't', 'e', 'r', '\n',
        'p', 's', 'a', 'l', 't', 'e', 'r', 's', '\n',
        'p', 's', 'a', 'l', 't', 'e', 'r', 'y', '\n',
        'p', 's', 'e', 'p', 'h', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'p', 's', 'e', 'u', 'd', 'o', '\n',
        'p', 's', 'e', 'u', 'd', 'o', 'n', 'y', 'm', '\n',
        'p', 's', 'e', 'u', 'd', 'o', 'n', 'y', 'm', 'o', 'u', 's', '\n',
        'p', 's', 'e', 'u', 'd', 'o', 'n', 'y', 'm', 's', '\n',
        'p', 's', 'e', 'u', 'd', 'o', 'p', 'o', 'd', '\n',
        'p', 's', 'o', 'r', 'i', 'a', 's', 'i', 's', '\n',
        'p', 's', 'y', 'c', 'h', 'e', '\n',
        'p', 's', 'y', 'c', 'h', 'e', 'd', 'e', 'l', 'i', 'a', '\n',
        'p', 's', 'y', 'c', 'h', 'e', 'd', 'e', 'l', 'i', 'c', '\n',
        'p', 's', 'y', 'c', 'h', 'i', 'a', 't', 'r', 'i', 'c', '\n',
        'p', 's', 'y', 'c', 'h', 'i', 'a', 't', 'r', 'i', 's', 't', '\n',
        'p', 's', 'y', 'c', 'h', 'i', 'a', 't', 'r', 'i', 's', 't', 's', '\n',
        'p', 's', 'y', 'c', 'h', 'i', 'a', 't', 'r', 'y', '\n',
        'p', 's', 'y', 'c', 'h', 'i', 'c', '\n',
        'p', 's', 'y', 'c', 'h', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'p', 's', 'y', 'c', 'h', 'i', 'c', 's', '\n',
        'p', 's', 'y', 'c', 'h', 'o', '\n',
        'p', 's', 'y', 'c', 'h', 'o', 'a', 'n', 'a', 'l', 'y', 's', 'e', '\n',
        'p', 's', 'y', 'c', 'h', 'o', 'a', 'n', 'a', 'l', 'y', 's', 'i', 's', '\n',
        'p', 's', 'y', 'c', 'h', 'o', 'a', 'n', 'a', 'l', 'y', 's', 't', '\n',
        'p', 's', 'y', 'c', 'h', 'o', 'a', 'n', 'a', 'l', 'y', 's', 't', 's', '\n',
        'p', 's', 'y', 'c', 'h', 'o', 'a', 'n', 'a', 'l', 'y', 't', 'i', 'c', '\n',
        'p', 's', 'y', 'c', 'h', 'o', 'k', 'i', 'n', 'e', 's', 'i', 's', '\n',
        'p', 's', 'y', 'c', 'h', 'o', 'k', 'i', 'n', 'e', 't', 'i', 'c', '\n',
        'p', 's', 'y', 'c', 'h', 'o', 'l', 'i', 'n', 'g', 'u', 'i', 's', 't', 'i', 'c', '\n',
        'p', 's', 'y', 'c', 'h', 'o', 'l', 'i', 'n', 'g', 'u', 'i', 's', 't', 'i', 'c', 's', '\n',
        'p', 's', 'y', 'c', 'h', 'o', 'l', 'i', 'n', 'g', 'u', 'i', 's', 't', 's', '\n',
        'p', 's', 'y', 'c', 'h', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'p', 's', 'y', 'c', 'h', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'p', 's', 'y', 'c', 'h', 'o', 'l', 'o', 'g', 'i', 'e', 's', '\n',
        'p', 's', 'y', 'c', 'h', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'p', 's', 'y', 'c', 'h', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'p', 's', 'y', 'c', 'h', 'o', 'l', 'o', 'g', 'y', '\n',
        'p', 's', 'y', 'c', 'h', 'o', 'm', 'e', 't', 'r', 'i', 'c', '\n',
        'p', 's', 'y', 'c', 'h', 'o', 'p', 'a', 't', 'h', '\n',
        'p', 's', 'y', 'c', 'h', 'o', 'p', 'a', 't', 'h', 'i', 'c', '\n',
        'p', 's', 'y', 'c', 'h', 'o', 'p', 'a', 't', 'h', 'o', 'l', 'o', 'g', 'y', '\n',
        'p', 's', 'y', 'c', 'h', 'o', 'p', 'a', 't', 'h', 's', '\n',
        'p', 's', 'y', 'c', 'h', 'o', 's', 'e', 's', '\n',
        'p', 's', 'y', 'c', 'h', 'o', 's', 'i', 's', '\n',
        'p', 's', 'y', 'c', 'h', 'o', 's', 'o', 'c', 'i', 'a', 'l', '\n',
        'p', 's', 'y', 'c', 'h', 'o', 's', 'o', 'm', 'a', 't', 'i', 'c', '\n',
        'p', 's', 'y', 'c', 'h', 'o', 't', 'h', 'e', 'r', 'a', 'p', 'i', 's', 't', '\n',
        'p', 's', 'y', 'c', 'h', 'o', 't', 'h', 'e', 'r', 'a', 'p', 'i', 's', 't', 's', '\n',
        'p', 's', 'y', 'c', 'h', 'o', 't', 'h', 'e', 'r', 'a', 'p', 'y', '\n',
        'p', 's', 'y', 'c', 'h', 'o', 't', 'i', 'c', '\n',
        'p', 's', 'y', 'c', 'h', 'o', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'p', 's', 'y', 'c', 'h', 'o', 't', 'i', 'c', 's', '\n',
        'p', 't', 'a', 'r', 'm', 'i', 'g', 'a', 'n', '\n',
        'p', 't', 'a', 'r', 'm', 'i', 'g', 'a', 'n', 's', '\n',
        'p', 't', 'e', 'r', 'o', 'd', 'a', 'c', 't', 'y', 'l', '\n',
        'p', 't', 'e', 'r', 'o', 's', 'a', 'u', 'r', 's', '\n',
        'p', 't', 'o', 'l', 'e', 'm', 'y', '\n',
        'p', 'u', 'b', '\n',
        'p', 'u', 'b', 'e', 'r', 't', 'y', '\n',
        'p', 'u', 'b', 'e', 's', 'c', 'e', 'n', 't', '\n',
        'p', 'u', 'b', 'i', 'c', '\n',
        'p', 'u', 'b', 'l', 'i', 'c', '\n',
        'p', 'u', 'b', 'l', 'i', 'c', 'a', 'n', '\n',
        'p', 'u', 'b', 'l', 'i', 'c', 'a', 'n', 's', '\n',
        'p', 'u', 'b', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'u', 'b', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'u', 'b', 'l', 'i', 'c', 'i', 's', 'e', '\n',
        'p', 'u', 'b', 'l', 'i', 'c', 'i', 's', 'e', 'd', '\n',
        'p', 'u', 'b', 'l', 'i', 'c', 'i', 's', 'e', 's', '\n',
        'p', 'u', 'b', 'l', 'i', 'c', 'i', 's', 'i', 'n', 'g', '\n',
        'p', 'u', 'b', 'l', 'i', 'c', 'i', 's', 't', '\n',
        'p', 'u', 'b', 'l', 'i', 'c', 'i', 's', 't', 's', '\n',
        'p', 'u', 'b', 'l', 'i', 'c', 'i', 't', 'y', '\n',
        'p', 'u', 'b', 'l', 'i', 'c', 'l', 'y', '\n',
        'p', 'u', 'b', 'l', 'i', 's', 'h', '\n',
        'p', 'u', 'b', 'l', 'i', 's', 'h', 'a', 'b', 'l', 'e', '\n',
        'p', 'u', 'b', 'l', 'i', 's', 'h', 'e', 'd', '\n',
        'p', 'u', 'b', 'l', 'i', 's', 'h', 'e', 'r', '\n',
        'p', 'u', 'b', 'l', 'i', 's', 'h', 'e', 'r', 's', '\n',
        'p', 'u', 'b', 'l', 'i', 's', 'h', 'e', 's', '\n',
        'p', 'u', 'b', 'l', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'p', 'u', 'b', 's', '\n',
        'p', 'u', 'd', 'd', 'i', 'n', 'g', '\n',
        'p', 'u', 'd', 'd', 'i', 'n', 'g', 's', '\n',
        'p', 'u', 'd', 'd', 'l', 'e', '\n',
        'p', 'u', 'd', 'd', 'l', 'e', 's', '\n',
        'p', 'u', 'e', 'r', 'i', 'l', 'e', '\n',
        'p', 'u', 'e', 'r', 'i', 'l', 'i', 't', 'y', '\n',
        'p', 'u', 'e', 'r', 'p', 'e', 'r', 'a', 'l', '\n',
        'p', 'u', 'f', 'f', '\n',
        'p', 'u', 'f', 'f', 'b', 'a', 'l', 'l', 's', '\n',
        'p', 'u', 'f', 'f', 'e', 'd', '\n',
        'p', 'u', 'f', 'f', 'e', 'r', '\n',
        'p', 'u', 'f', 'f', 'i', 'n', '\n',
        'p', 'u', 'f', 'f', 'i', 'n', 'e', 's', 's', '\n',
        'p', 'u', 'f', 'f', 'i', 'n', 'g', '\n',
        'p', 'u', 'f', 'f', 'i', 'n', 's', '\n',
        'p', 'u', 'f', 'f', 's', '\n',
        'p', 'u', 'f', 'f', 'y', '\n',
        'p', 'u', 'g', '\n',
        'p', 'u', 'g', 'i', 'l', 'i', 's', 't', '\n',
        'p', 'u', 'g', 'i', 'l', 'i', 's', 't', 'i', 'c', '\n',
        'p', 'u', 'g', 'n', 'a', 'c', 'i', 'o', 'u', 's', '\n',
        'p', 'u', 'g', 'n', 'a', 'c', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'p', 'u', 'g', 'n', 'a', 'c', 'i', 't', 'y', '\n',
        'p', 'u', 'g', 's', '\n',
        'p', 'u', 'i', 's', 's', 'a', 'n', 't', '\n',
        'p', 'u', 'k', 'e', '\n',
        'p', 'u', 'k', 'i', 'n', 'g', '\n',
        'p', 'u', 'l', 'c', 'h', 'r', 'i', 't', 'u', 'd', 'e', '\n',
        'p', 'u', 'l', 'i', 'n', 'g', '\n',
        'p', 'u', 'l', 'l', '\n',
        'p', 'u', 'l', 'l', 'e', 'd', '\n',
        'p', 'u', 'l', 'l', 'e', 'r', '\n',
        'p', 'u', 'l', 'l', 'e', 't', 's', '\n',
        'p', 'u', 'l', 'l', 'e', 'y', '\n',
        'p', 'u', 'l', 'l', 'e', 'y', 's', '\n',
        'p', 'u', 'l', 'l', 'i', 'n', 'g', '\n',
        'p', 'u', 'l', 'l', 'o', 'v', 'e', 'r', '\n',
        'p', 'u', 'l', 'l', 'o', 'v', 'e', 'r', 's', '\n',
        'p', 'u', 'l', 'l', 's', '\n',
        'p', 'u', 'l', 'm', 'o', 'n', 'a', 'r', 'y', '\n',
        'p', 'u', 'l', 'p', '\n',
        'p', 'u', 'l', 'p', 'e', 'd', '\n',
        'p', 'u', 'l', 'p', 'i', 'n', 'g', '\n',
        'p', 'u', 'l', 'p', 'i', 't', '\n',
        'p', 'u', 'l', 'p', 'i', 't', 's', '\n',
        'p', 'u', 'l', 'p', 's', '\n',
        'p', 'u', 'l', 'p', 'y', '\n',
        'p', 'u', 'l', 's', 'a', 'r', '\n',
        'p', 'u', 'l', 's', 'a', 'r', 's', '\n',
        'p', 'u', 'l', 's', 'a', 't', 'e', '\n',
        'p', 'u', 'l', 's', 'a', 't', 'e', 'd', '\n',
        'p', 'u', 'l', 's', 'a', 't', 'e', 's', '\n',
        'p', 'u', 'l', 's', 'a', 't', 'i', 'n', 'g', '\n',
        'p', 'u', 'l', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'u', 'l', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'u', 'l', 's', 'e', '\n',
        'p', 'u', 'l', 's', 'e', 'd', '\n',
        'p', 'u', 'l', 's', 'e', 's', '\n',
        'p', 'u', 'l', 's', 'i', 'n', 'g', '\n',
        'p', 'u', 'l', 'v', 'e', 'r', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'u', 'l', 'v', 'e', 'r', 'i', 's', 'e', '\n',
        'p', 'u', 'l', 'v', 'e', 'r', 'i', 's', 'e', 'd', '\n',
        'p', 'u', 'l', 'v', 'e', 'r', 'i', 's', 'i', 'n', 'g', '\n',
        'p', 'u', 'm', 'a', '\n',
        'p', 'u', 'm', 'a', 's', '\n',
        'p', 'u', 'm', 'i', 'c', 'e', '\n',
        'p', 'u', 'm', 'm', 'e', 'l', '\n',
        'p', 'u', 'm', 'm', 'e', 'l', 'l', 'e', 'd', '\n',
        'p', 'u', 'm', 'm', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'p', 'u', 'm', 'm', 'e', 'l', 's', '\n',
        'p', 'u', 'm', 'p', '\n',
        'p', 'u', 'm', 'p', 'e', 'd', '\n',
        'p', 'u', 'm', 'p', 'i', 'n', 'g', '\n',
        'p', 'u', 'm', 'p', 'k', 'i', 'n', '\n',
        'p', 'u', 'm', 'p', 'k', 'i', 'n', 's', '\n',
        'p', 'u', 'm', 'p', 's', '\n',
        'p', 'u', 'n', '\n',
        'p', 'u', 'n', 'c', 'h', '\n',
        'p', 'u', 'n', 'c', 'h', 'a', 'b', 'l', 'e', '\n',
        'p', 'u', 'n', 'c', 'h', 'b', 'o', 'w', 'l', '\n',
        'p', 'u', 'n', 'c', 'h', 'c', 'a', 'r', 'd', '\n',
        'p', 'u', 'n', 'c', 'h', 'e', 'd', '\n',
        'p', 'u', 'n', 'c', 'h', 'e', 'r', '\n',
        'p', 'u', 'n', 'c', 'h', 'e', 's', '\n',
        'p', 'u', 'n', 'c', 'h', 'i', 'n', 'g', '\n',
        'p', 'u', 'n', 'c', 'h', 'l', 'i', 'n', 'e', '\n',
        'p', 'u', 'n', 'c', 'h', 'l', 'i', 'n', 'e', 's', '\n',
        'p', 'u', 'n', 'c', 'h', 'y', '\n',
        'p', 'u', 'n', 'c', 't', 'a', 't', 'e', '\n',
        'p', 'u', 'n', 'c', 't', 'i', 'l', 'i', 'o', 'u', 's', '\n',
        'p', 'u', 'n', 'c', 't', 'i', 'l', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'p', 'u', 'n', 'c', 't', 'u', 'a', 'l', '\n',
        'p', 'u', 'n', 'c', 't', 'u', 'a', 'l', 'i', 't', 'y', '\n',
        'p', 'u', 'n', 'c', 't', 'u', 'a', 'l', 'l', 'y', '\n',
        'p', 'u', 'n', 'c', 't', 'u', 'a', 't', 'e', '\n',
        'p', 'u', 'n', 'c', 't', 'u', 'a', 't', 'e', 'd', '\n',
        'p', 'u', 'n', 'c', 't', 'u', 'a', 't', 'e', 's', '\n',
        'p', 'u', 'n', 'c', 't', 'u', 'a', 't', 'i', 'n', 'g', '\n',
        'p', 'u', 'n', 'c', 't', 'u', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'u', 'n', 'c', 't', 'u', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'p', 'u', 'n', 'c', 't', 'u', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'p', 'u', 'n', 'c', 't', 'u', 'r', 'e', '\n',
        'p', 'u', 'n', 'c', 't', 'u', 'r', 'e', 'd', '\n',
        'p', 'u', 'n', 'c', 't', 'u', 'r', 'e', 's', '\n',
        'p', 'u', 'n', 'c', 't', 'u', 'r', 'i', 'n', 'g', '\n',
        'p', 'u', 'n', 'd', 'i', 't', '\n',
        'p', 'u', 'n', 'd', 'i', 't', 's', '\n',
        'p', 'u', 'n', 'g', 'e', 'n', 'c', 'y', '\n',
        'p', 'u', 'n', 'g', 'e', 'n', 't', '\n',
        'p', 'u', 'n', 'g', 'e', 'n', 't', 'l', 'y', '\n',
        'p', 'u', 'n', 'i', 'e', 'r', '\n',
        'p', 'u', 'n', 'i', 'e', 's', 't', '\n',
        'p', 'u', 'n', 'i', 's', 'h', '\n',
        'p', 'u', 'n', 'i', 's', 'h', 'a', 'b', 'l', 'e', '\n',
        'p', 'u', 'n', 'i', 's', 'h', 'e', 'd', '\n',
        'p', 'u', 'n', 'i', 's', 'h', 'e', 's', '\n',
        'p', 'u', 'n', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'p', 'u', 'n', 'i', 's', 'h', 'm', 'e', 'n', 't', '\n',
        'p', 'u', 'n', 'i', 's', 'h', 'm', 'e', 'n', 't', 's', '\n',
        'p', 'u', 'n', 'i', 't', 'i', 'v', 'e', '\n',
        'p', 'u', 'n', 'i', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'p', 'u', 'n', 'k', '\n',
        'p', 'u', 'n', 'k', 's', '\n',
        'p', 'u', 'n', 'k', 'y', '\n',
        'p', 'u', 'n', 'n', 'e', 'd', '\n',
        'p', 'u', 'n', 'n', 'e', 't', '\n',
        'p', 'u', 'n', 'n', 'i', 'n', 'g', '\n',
        'p', 'u', 'n', 's', '\n',
        'p', 'u', 'n', 's', 't', 'e', 'r', '\n',
        'p', 'u', 'n', 't', '\n',
        'p', 'u', 'n', 't', 'e', 'd', '\n',
        'p', 'u', 'n', 't', 'e', 'r', '\n',
        'p', 'u', 'n', 't', 'e', 'r', 's', '\n',
        'p', 'u', 'n', 't', 'i', 'n', 'g', '\n',
        'p', 'u', 'n', 't', 's', '\n',
        'p', 'u', 'n', 'y', '\n',
        'p', 'u', 'p', '\n',
        'p', 'u', 'p', 'a', '\n',
        'p', 'u', 'p', 'a', 'e', '\n',
        'p', 'u', 'p', 'a', 'l', '\n',
        'p', 'u', 'p', 'a', 't', 'e', 'd', '\n',
        'p', 'u', 'p', 'a', 't', 'e', 's', '\n',
        'p', 'u', 'p', 'a', 't', 'i', 'n', 'g', '\n',
        'p', 'u', 'p', 'i', 'l', '\n',
        'p', 'u', 'p', 'i', 'l', 'l', 'a', 'g', 'e', '\n',
        'p', 'u', 'p', 'i', 'l', 's', '\n',
        'p', 'u', 'p', 'p', 'e', 't', '\n',
        'p', 'u', 'p', 'p', 'e', 't', 'e', 'e', 'r', '\n',
        'p', 'u', 'p', 'p', 'e', 't', 'r', 'y', '\n',
        'p', 'u', 'p', 'p', 'e', 't', 's', '\n',
        'p', 'u', 'p', 'p', 'i', 'e', 's', '\n',
        'p', 'u', 'p', 'p', 'y', '\n',
        'p', 'u', 'p', 'p', 'y', 'h', 'o', 'o', 'd', '\n',
        'p', 'u', 'p', 's', '\n',
        'p', 'u', 'r', 'b', 'l', 'i', 'n', 'd', '\n',
        'p', 'u', 'r', 'c', 'h', 'a', 's', 'a', 'b', 'l', 'e', '\n',
        'p', 'u', 'r', 'c', 'h', 'a', 's', 'e', '\n',
        'p', 'u', 'r', 'c', 'h', 'a', 's', 'e', 'd', '\n',
        'p', 'u', 'r', 'c', 'h', 'a', 's', 'e', 'r', '\n',
        'p', 'u', 'r', 'c', 'h', 'a', 's', 'e', 'r', 's', '\n',
        'p', 'u', 'r', 'c', 'h', 'a', 's', 'e', 's', '\n',
        'p', 'u', 'r', 'c', 'h', 'a', 's', 'i', 'n', 'g', '\n',
        'p', 'u', 'r', 'd', 'a', 'h', '\n',
        'p', 'u', 'r', 'e', '\n',
        'p', 'u', 'r', 'e', 'e', '\n',
        'p', 'u', 'r', 'e', 'e', 's', '\n',
        'p', 'u', 'r', 'e', 'l', 'y', '\n',
        'p', 'u', 'r', 'e', 'n', 'e', 's', 's', '\n',
        'p', 'u', 'r', 'e', 'r', '\n',
        'p', 'u', 'r', 'e', 's', 't', '\n',
        'p', 'u', 'r', 'g', 'a', 't', 'i', 'v', 'e', '\n',
        'p', 'u', 'r', 'g', 'a', 't', 'o', 'r', 'i', 'a', 'l', '\n',
        'p', 'u', 'r', 'g', 'a', 't', 'o', 'r', 'y', '\n',
        'p', 'u', 'r', 'g', 'e', '\n',
        'p', 'u', 'r', 'g', 'e', 'd', '\n',
        'p', 'u', 'r', 'g', 'e', 's', '\n',
        'p', 'u', 'r', 'g', 'i', 'n', 'g', '\n',
        'p', 'u', 'r', 'g', 'i', 'n', 'g', 's', '\n',
        'p', 'u', 'r', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'p', 'u', 'r', 'i', 'f', 'i', 'e', 'd', '\n',
        'p', 'u', 'r', 'i', 'f', 'i', 'e', 'r', '\n',
        'p', 'u', 'r', 'i', 'f', 'i', 'e', 's', '\n',
        'p', 'u', 'r', 'i', 'f', 'y', '\n',
        'p', 'u', 'r', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'p', 'u', 'r', 'i', 'm', 's', '\n',
        'p', 'u', 'r', 'i', 'n', 'e', 's', '\n',
        'p', 'u', 'r', 'i', 's', 't', '\n',
        'p', 'u', 'r', 'i', 's', 't', 's', '\n',
        'p', 'u', 'r', 'i', 't', 'a', 'n', '\n',
        'p', 'u', 'r', 'i', 't', 'a', 'n', 'i', 'c', 'a', 'l', '\n',
        'p', 'u', 'r', 'i', 't', 'a', 'n', 'i', 's', 'm', '\n',
        'p', 'u', 'r', 'i', 't', 'a', 'n', 's', '\n',
        'p', 'u', 'r', 'i', 't', 'i', 'e', 's', '\n',
        'p', 'u', 'r', 'i', 't', 'y', '\n',
        'p', 'u', 'r', 'l', '\n',
        'p', 'u', 'r', 'l', 'i', 'e', 'u', 's', '\n',
        'p', 'u', 'r', 'l', 'i', 'n', 'g', '\n',
        'p', 'u', 'r', 'l', 'i', 'n', 's', '\n',
        'p', 'u', 'r', 'l', 'o', 'i', 'n', '\n',
        'p', 'u', 'r', 'l', 'o', 'i', 'n', 'e', 'd', '\n',
        'p', 'u', 'r', 'l', 's', '\n',
        'p', 'u', 'r', 'p', 'l', 'e', '\n',
        'p', 'u', 'r', 'p', 'l', 'e', 's', '\n',
        'p', 'u', 'r', 'p', 'l', 'i', 's', 'h', '\n',
        'p', 'u', 'r', 'p', 'o', 'r', 't', '\n',
        'p', 'u', 'r', 'p', 'o', 'r', 't', 'e', 'd', '\n',
        'p', 'u', 'r', 'p', 'o', 'r', 't', 'e', 'd', 'l', 'y', '\n',
        'p', 'u', 'r', 'p', 'o', 'r', 't', 'i', 'n', 'g', '\n',
        'p', 'u', 'r', 'p', 'o', 'r', 't', 's', '\n',
        'p', 'u', 'r', 'p', 'o', 's', 'e', '\n',
        'p', 'u', 'r', 'p', 'o', 's', 'e', 'd', '\n',
        'p', 'u', 'r', 'p', 'o', 's', 'e', 'f', 'u', 'l', '\n',
        'p', 'u', 'r', 'p', 'o', 's', 'e', 'f', 'u', 'l', 'l', 'y', '\n',
        'p', 'u', 'r', 'p', 'o', 's', 'e', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'p', 'u', 'r', 'p', 'o', 's', 'e', 'l', 'e', 's', 's', '\n',
        'p', 'u', 'r', 'p', 'o', 's', 'e', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'p', 'u', 'r', 'p', 'o', 's', 'e', 'l', 'y', '\n',
        'p', 'u', 'r', 'p', 'o', 's', 'e', 's', '\n',
        'p', 'u', 'r', 'p', 'o', 's', 'i', 'n', 'g', '\n',
        'p', 'u', 'r', 'p', 'o', 's', 'i', 'v', 'e', '\n',
        'p', 'u', 'r', 'r', '\n',
        'p', 'u', 'r', 'r', 'e', 'd', '\n',
        'p', 'u', 'r', 'r', 'i', 'n', 'g', '\n',
        'p', 'u', 'r', 'r', 's', '\n',
        'p', 'u', 'r', 's', 'e', '\n',
        'p', 'u', 'r', 's', 'e', 'd', '\n',
        'p', 'u', 'r', 's', 'e', 'r', '\n',
        'p', 'u', 'r', 's', 'e', 's', '\n',
        'p', 'u', 'r', 's', 'i', 'n', 'g', '\n',
        'p', 'u', 'r', 's', 'u', 'a', 'n', 'c', 'e', '\n',
        'p', 'u', 'r', 's', 'u', 'a', 'n', 't', '\n',
        'p', 'u', 'r', 's', 'u', 'e', '\n',
        'p', 'u', 'r', 's', 'u', 'e', 'd', '\n',
        'p', 'u', 'r', 's', 'u', 'e', 'r', '\n',
        'p', 'u', 'r', 's', 'u', 'e', 'r', 's', '\n',
        'p', 'u', 'r', 's', 'u', 'e', 's', '\n',
        'p', 'u', 'r', 's', 'u', 'i', 'n', 'g', '\n',
        'p', 'u', 'r', 's', 'u', 'i', 't', '\n',
        'p', 'u', 'r', 's', 'u', 'i', 't', 's', '\n',
        'p', 'u', 'r', 'v', 'e', 'y', '\n',
        'p', 'u', 'r', 'v', 'e', 'y', 'a', 'n', 'c', 'e', '\n',
        'p', 'u', 'r', 'v', 'e', 'y', 'e', 'd', '\n',
        'p', 'u', 'r', 'v', 'e', 'y', 'i', 'n', 'g', '\n',
        'p', 'u', 'r', 'v', 'e', 'y', 'o', 'r', '\n',
        'p', 'u', 'r', 'v', 'e', 'y', 'o', 'r', 's', '\n',
        'p', 'u', 'r', 'v', 'i', 'e', 'w', '\n',
        'p', 'u', 's', '\n',
        'p', 'u', 's', 'h', '\n',
        'p', 'u', 's', 'h', 'a', 'b', 'l', 'e', '\n',
        'p', 'u', 's', 'h', 'e', 'd', '\n',
        'p', 'u', 's', 'h', 'e', 'r', '\n',
        'p', 'u', 's', 'h', 'e', 'r', 's', '\n',
        'p', 'u', 's', 'h', 'e', 's', '\n',
        'p', 'u', 's', 'h', 'i', 'e', 'r', '\n',
        'p', 'u', 's', 'h', 'i', 'n', 'g', '\n',
        'p', 'u', 's', 'h', 'o', 'v', 'e', 'r', 's', '\n',
        'p', 'u', 's', 'h', 'u', 'p', 's', '\n',
        'p', 'u', 's', 'h', 'y', '\n',
        'p', 'u', 's', 's', '\n',
        'p', 'u', 's', 's', 'y', '\n',
        'p', 'u', 's', 's', 'y', 'c', 'a', 't', '\n',
        'p', 'u', 's', 's', 'y', 'f', 'o', 'o', 't', 'i', 'n', 'g', '\n',
        'p', 'u', 's', 't', 'u', 'l', 'a', 'r', '\n',
        'p', 'u', 's', 't', 'u', 'l', 'e', '\n',
        'p', 'u', 's', 't', 'u', 'l', 'e', 's', '\n',
        'p', 'u', 't', '\n',
        'p', 'u', 't', 'a', 't', 'i', 'v', 'e', '\n',
        'p', 'u', 't', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'p', 'u', 't', 'p', 'u', 't', '\n',
        'p', 'u', 't', 'r', 'e', 'f', 'a', 'c', 't', 'i', 'o', 'n', '\n',
        'p', 'u', 't', 'r', 'e', 'f', 'y', '\n',
        'p', 'u', 't', 'r', 'e', 'f', 'y', 'i', 'n', 'g', '\n',
        'p', 'u', 't', 'r', 'e', 's', 'c', 'e', 'n', 't', '\n',
        'p', 'u', 't', 'r', 'i', 'd', '\n',
        'p', 'u', 't', 'r', 'i', 'd', 'i', 't', 'y', '\n',
        'p', 'u', 't', 's', '\n',
        'p', 'u', 't', 's', 'c', 'h', '\n',
        'p', 'u', 't', 't', '\n',
        'p', 'u', 't', 't', 'e', 'd', '\n',
        'p', 'u', 't', 't', 'e', 'r', '\n',
        'p', 'u', 't', 't', 'e', 'r', 's', '\n',
        'p', 'u', 't', 't', 'i', '\n',
        'p', 'u', 't', 't', 'i', 'n', 'g', '\n',
        'p', 'u', 't', 't', 's', '\n',
        'p', 'u', 't', 't', 'y', '\n',
        'p', 'u', 'z', 'z', 'l', 'e', '\n',
        'p', 'u', 'z', 'z', 'l', 'e', 'd', '\n',
        'p', 'u', 'z', 'z', 'l', 'e', 'm', 'e', 'n', 't', '\n',
        'p', 'u', 'z', 'z', 'l', 'e', 'r', '\n',
        'p', 'u', 'z', 'z', 'l', 'e', 's', '\n',
        'p', 'u', 'z', 'z', 'l', 'i', 'n', 'g', '\n',
        'p', 'u', 'z', 'z', 'l', 'i', 'n', 'g', 'l', 'y', '\n',
        'p', 'y', 'g', 'm', 'i', 'e', 's', '\n',
        'p', 'y', 'g', 'm', 'y', '\n',
        'p', 'y', 'j', 'a', 'm', 'a', '\n',
        'p', 'y', 'j', 'a', 'm', 'a', 's', '\n',
        'p', 'y', 'l', 'o', 'n', '\n',
        'p', 'y', 'l', 'o', 'n', 's', '\n',
        'p', 'y', 'r', 'a', 'c', 'a', 'n', 't', 'h', 'a', '\n',
        'p', 'y', 'r', 'a', 'm', 'i', 'd', '\n',
        'p', 'y', 'r', 'a', 'm', 'i', 'd', 'a', 'l', '\n',
        'p', 'y', 'r', 'a', 'm', 'i', 'd', 's', '\n',
        'p', 'y', 'r', 'e', '\n',
        'p', 'y', 'r', 'e', 's', '\n',
        'p', 'y', 'r', 'i', 'd', 'i', 'n', 'e', '\n',
        'p', 'y', 'r', 'i', 't', 'e', '\n',
        'p', 'y', 'r', 'i', 't', 'e', 's', '\n',
        'p', 'y', 'r', 'o', 'l', 'y', 's', 'e', '\n',
        'p', 'y', 'r', 'o', 'l', 'y', 's', 'i', 's', '\n',
        'p', 'y', 'r', 'o', 'm', 'a', 'n', 'i', 'a', 'c', '\n',
        'p', 'y', 'r', 'o', 'm', 'a', 'n', 'i', 'a', 'c', 's', '\n',
        'p', 'y', 'r', 'o', 't', 'e', 'c', 'h', 'n', 'i', 'c', '\n',
        'p', 'y', 'r', 'o', 't', 'e', 'c', 'h', 'n', 'i', 'c', 's', '\n',
        'p', 'y', 'r', 'o', 'x', 'e', 'n', 'e', '\n',
        'p', 'y', 'r', 'o', 'x', 'e', 'n', 'e', 's', '\n',
        'p', 'y', 't', 'h', 'o', 'n', '\n',
        'p', 'y', 't', 'h', 'o', 'n', 's', '\n',
        'q', 'a', 't', 'a', 'r', '\n',
        'q', 'u', 'a', '\n',
        'q', 'u', 'a', 'c', 'k', '\n',
        'q', 'u', 'a', 'c', 'k', 'e', 'd', '\n',
        'q', 'u', 'a', 'c', 'k', 'i', 'n', 'g', '\n',
        'q', 'u', 'a', 'c', 'k', 'i', 's', 'h', '\n',
        'q', 'u', 'a', 'c', 'k', 's', '\n',
        'q', 'u', 'a', 'd', 'r', 'a', 'n', 'g', 'l', 'e', '\n',
        'q', 'u', 'a', 'd', 'r', 'a', 'n', 'g', 'l', 'e', 's', '\n',
        'q', 'u', 'a', 'd', 'r', 'a', 'n', 'g', 'u', 'l', 'a', 'r', '\n',
        'q', 'u', 'a', 'd', 'r', 'a', 'n', 't', '\n',
        'q', 'u', 'a', 'd', 'r', 'a', 'n', 't', 's', '\n',
        'q', 'u', 'a', 'd', 'r', 'a', 't', 'i', 'c', '\n',
        'q', 'u', 'a', 'd', 'r', 'a', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'q', 'u', 'a', 'd', 'r', 'a', 't', 'i', 'c', 's', '\n',
        'q', 'u', 'a', 'd', 'r', 'a', 't', 'u', 'r', 'e', '\n',
        'q', 'u', 'a', 'd', 'r', 'a', 't', 'u', 'r', 'e', 's', '\n',
        'q', 'u', 'a', 'd', 'r', 'i', 'l', 'a', 't', 'e', 'r', 'a', 'l', '\n',
        'q', 'u', 'a', 'd', 'r', 'i', 'l', 'a', 't', 'e', 'r', 'a', 'l', 's', '\n',
        'q', 'u', 'a', 'd', 'r', 'i', 'l', 'l', 'e', '\n',
        'q', 'u', 'a', 'd', 'r', 'i', 'l', 'l', 'e', 's', '\n',
        'q', 'u', 'a', 'd', 'r', 'i', 'p', 'a', 'r', 't', 'i', 't', 'e', '\n',
        'q', 'u', 'a', 'd', 'r', 'o', 'p', 'h', 'o', 'n', 'i', 'c', '\n',
        'q', 'u', 'a', 'd', 'r', 'u', 'p', 'e', 'd', '\n',
        'q', 'u', 'a', 'd', 'r', 'u', 'p', 'e', 'd', 's', '\n',
        'q', 'u', 'a', 'd', 'r', 'u', 'p', 'l', 'e', '\n',
        'q', 'u', 'a', 'd', 'r', 'u', 'p', 'l', 'e', 'd', '\n',
        'q', 'u', 'a', 'd', 'r', 'u', 'p', 'l', 'e', 's', '\n',
        'q', 'u', 'a', 'd', 'r', 'u', 'p', 'l', 'e', 't', 's', '\n',
        'q', 'u', 'a', 'd', 'r', 'u', 'p', 'l', 'i', 'c', 'a', 't', 'e', '\n',
        'q', 'u', 'a', 'd', 'r', 'u', 'p', 'l', 'i', 'n', 'g', '\n',
        'q', 'u', 'a', 'd', 'r', 'u', 'p', 'l', 'y', '\n',
        'q', 'u', 'a', 'd', 'r', 'u', 'p', 'o', 'l', 'e', '\n',
        'q', 'u', 'a', 'f', 'f', '\n',
        'q', 'u', 'a', 'f', 'f', 'e', 'd', '\n',
        'q', 'u', 'a', 'f', 'f', 'i', 'n', 'g', '\n',
        'q', 'u', 'a', 'g', 'g', 'a', '\n',
        'q', 'u', 'a', 'g', 'g', 'a', 's', '\n',
        'q', 'u', 'a', 'g', 'm', 'i', 'r', 'e', '\n',
        'q', 'u', 'a', 'g', 'm', 'i', 'r', 'e', 's', '\n',
        'q', 'u', 'a', 'i', 'l', '\n',
        'q', 'u', 'a', 'i', 'l', 'e', 'd', '\n',
        'q', 'u', 'a', 'i', 'l', 's', '\n',
        'q', 'u', 'a', 'i', 'n', 't', '\n',
        'q', 'u', 'a', 'i', 'n', 't', 'e', 'r', '\n',
        'q', 'u', 'a', 'i', 'n', 't', 'l', 'y', '\n',
        'q', 'u', 'a', 'i', 'n', 't', 'n', 'e', 's', 's', '\n',
        'q', 'u', 'a', 'k', 'e', '\n',
        'q', 'u', 'a', 'k', 'e', 'd', '\n',
        'q', 'u', 'a', 'k', 'e', 'r', '\n',
        'q', 'u', 'a', 'k', 'e', 'r', 's', '\n',
        'q', 'u', 'a', 'k', 'e', 's', '\n',
        'q', 'u', 'a', 'k', 'i', 'n', 'g', '\n',
        'q', 'u', 'a', 'l', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'q', 'u', 'a', 'l', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'q', 'u', 'a', 'l', 'i', 'f', 'i', 'e', 'd', '\n',
        'q', 'u', 'a', 'l', 'i', 'f', 'i', 'e', 'r', '\n',
        'q', 'u', 'a', 'l', 'i', 'f', 'i', 'e', 'r', 's', '\n',
        'q', 'u', 'a', 'l', 'i', 'f', 'i', 'e', 's', '\n',
        'q', 'u', 'a', 'l', 'i', 'f', 'y', '\n',
        'q', 'u', 'a', 'l', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'q', 'u', 'a', 'l', 'i', 't', 'a', 't', 'i', 'v', 'e', '\n',
        'q', 'u', 'a', 'l', 'i', 't', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'q', 'u', 'a', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'q', 'u', 'a', 'l', 'i', 't', 'y', '\n',
        'q', 'u', 'a', 'l', 'm', '\n',
        'q', 'u', 'a', 'l', 'm', 's', '\n',
        'q', 'u', 'a', 'n', 't', 'i', 'f', 'i', 'a', 'b', 'l', 'e', '\n',
        'q', 'u', 'a', 'n', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'q', 'u', 'a', 'n', 't', 'i', 'f', 'i', 'e', 'd', '\n',
        'q', 'u', 'a', 'n', 't', 'i', 'f', 'i', 'e', 'r', '\n',
        'q', 'u', 'a', 'n', 't', 'i', 'f', 'i', 'e', 'r', 's', '\n',
        'q', 'u', 'a', 'n', 't', 'i', 'f', 'i', 'e', 's', '\n',
        'q', 'u', 'a', 'n', 't', 'i', 'f', 'y', '\n',
        'q', 'u', 'a', 'n', 't', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'q', 'u', 'a', 'n', 't', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'q', 'u', 'a', 'n', 't', 'i', 's', 'e', '\n',
        'q', 'u', 'a', 'n', 't', 'i', 's', 'e', 'd', '\n',
        'q', 'u', 'a', 'n', 't', 'i', 't', 'a', 't', 'i', 'v', 'e', '\n',
        'q', 'u', 'a', 'n', 't', 'i', 't', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'q', 'u', 'a', 'n', 't', 'i', 't', 'i', 'e', 's', '\n',
        'q', 'u', 'a', 'n', 't', 'i', 't', 'y', '\n',
        'q', 'u', 'a', 'n', 't', 'u', 'm', '\n',
        'q', 'u', 'a', 'r', 'a', 'n', 't', 'i', 'n', 'e', '\n',
        'q', 'u', 'a', 'r', 'a', 'n', 't', 'i', 'n', 'e', 'd', '\n',
        'q', 'u', 'a', 'r', 'k', '\n',
        'q', 'u', 'a', 'r', 'k', 's', '\n',
        'q', 'u', 'a', 'r', 'r', 'e', 'l', '\n',
        'q', 'u', 'a', 'r', 'r', 'e', 'l', 'l', 'e', 'd', '\n',
        'q', 'u', 'a', 'r', 'r', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'q', 'u', 'a', 'r', 'r', 'e', 'l', 's', '\n',
        'q', 'u', 'a', 'r', 'r', 'e', 'l', 's', 'o', 'm', 'e', '\n',
        'q', 'u', 'a', 'r', 'r', 'i', 'e', 'd', '\n',
        'q', 'u', 'a', 'r', 'r', 'i', 'e', 's', '\n',
        'q', 'u', 'a', 'r', 'r', 'y', '\n',
        'q', 'u', 'a', 'r', 'r', 'y', 'i', 'n', 'g', '\n',
        'q', 'u', 'a', 'r', 'r', 'y', 'm', 'e', 'n', '\n',
        'q', 'u', 'a', 'r', 't', '\n',
        'q', 'u', 'a', 'r', 't', 'e', 'r', '\n',
        'q', 'u', 'a', 'r', 't', 'e', 'r', 'b', 'a', 'c', 'k', '\n',
        'q', 'u', 'a', 'r', 't', 'e', 'r', 'e', 'd', '\n',
        'q', 'u', 'a', 'r', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'q', 'u', 'a', 'r', 't', 'e', 'r', 'l', 'y', '\n',
        'q', 'u', 'a', 'r', 't', 'e', 'r', 'm', 'a', 's', 't', 'e', 'r', '\n',
        'q', 'u', 'a', 'r', 't', 'e', 'r', 's', '\n',
        'q', 'u', 'a', 'r', 't', 'e', 'r', 's', 't', 'a', 'f', 'f', '\n',
        'q', 'u', 'a', 'r', 't', 'e', 'r', 's', 't', 'a', 'f', 'f', 's', '\n',
        'q', 'u', 'a', 'r', 't', 'e', 't', '\n',
        'q', 'u', 'a', 'r', 't', 'e', 't', 's', '\n',
        'q', 'u', 'a', 'r', 't', 'i', 'c', '\n',
        'q', 'u', 'a', 'r', 't', 'i', 'c', 's', '\n',
        'q', 'u', 'a', 'r', 't', 'i', 'l', 'e', '\n',
        'q', 'u', 'a', 'r', 't', 'i', 'l', 'e', 's', '\n',
        'q', 'u', 'a', 'r', 't', 'o', '\n',
        'q', 'u', 'a', 'r', 't', 's', '\n',
        'q', 'u', 'a', 'r', 't', 'z', '\n',
        'q', 'u', 'a', 'r', 't', 'z', 'i', 't', 'e', '\n',
        'q', 'u', 'a', 's', 'a', 'r', '\n',
        'q', 'u', 'a', 's', 'a', 'r', 's', '\n',
        'q', 'u', 'a', 's', 'h', '\n',
        'q', 'u', 'a', 's', 'h', 'e', 'd', '\n',
        'q', 'u', 'a', 's', 'h', 'i', 'n', 'g', '\n',
        'q', 'u', 'a', 's', 'i', '\n',
        'q', 'u', 'a', 's', 'i', 'l', 'i', 'n', 'e', 'a', 'r', '\n',
        'q', 'u', 'a', 't', 'e', 'r', 'n', 'a', 'r', 'y', '\n',
        'q', 'u', 'a', 't', 'e', 'r', 'n', 'i', 'o', 'n', '\n',
        'q', 'u', 'a', 't', 'e', 'r', 'n', 'i', 'o', 'n', 's', '\n',
        'q', 'u', 'a', 't', 'r', 'a', 'i', 'n', '\n',
        'q', 'u', 'a', 't', 'r', 'a', 'i', 'n', 's', '\n',
        'q', 'u', 'a', 'v', 'e', 'r', '\n',
        'q', 'u', 'a', 'v', 'e', 'r', 'e', 'd', '\n',
        'q', 'u', 'a', 'v', 'e', 'r', 'i', 'n', 'g', '\n',
        'q', 'u', 'a', 'v', 'e', 'r', 's', '\n',
        'q', 'u', 'a', 'y', '\n',
        'q', 'u', 'a', 'y', 's', '\n',
        'q', 'u', 'a', 'y', 's', 'i', 'd', 'e', '\n',
        'q', 'u', 'e', 'a', 's', 'i', 'n', 'e', 's', 's', '\n',
        'q', 'u', 'e', 'a', 's', 'y', '\n',
        'q', 'u', 'e', 'b', 'e', 'c', '\n',
        'q', 'u', 'e', 'e', 'n', '\n',
        'q', 'u', 'e', 'e', 'n', 'l', 'y', '\n',
        'q', 'u', 'e', 'e', 'n', 's', '\n',
        'q', 'u', 'e', 'e', 'r', '\n',
        'q', 'u', 'e', 'e', 'r', 'e', 's', 't', '\n',
        'q', 'u', 'e', 'e', 'r', 'l', 'y', '\n',
        'q', 'u', 'e', 'l', 'l', '\n',
        'q', 'u', 'e', 'l', 'l', 'e', 'd', '\n',
        'q', 'u', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'q', 'u', 'e', 'l', 'l', 's', '\n',
        'q', 'u', 'e', 'n', 'c', 'h', '\n',
        'q', 'u', 'e', 'n', 'c', 'h', 'e', 'd', '\n',
        'q', 'u', 'e', 'n', 'c', 'h', 'e', 'r', '\n',
        'q', 'u', 'e', 'n', 'c', 'h', 'e', 'r', 's', '\n',
        'q', 'u', 'e', 'n', 'c', 'h', 'e', 's', '\n',
        'q', 'u', 'e', 'n', 'c', 'h', 'i', 'n', 'g', '\n',
        'q', 'u', 'e', 'r', 'i', 'e', 'd', '\n',
        'q', 'u', 'e', 'r', 'i', 'e', 's', '\n',
        'q', 'u', 'e', 'r', 'n', '\n',
        'q', 'u', 'e', 'r', 'u', 'l', 'o', 'u', 's', '\n',
        'q', 'u', 'e', 'r', 'u', 'l', 'o', 'u', 's', 'l', 'y', '\n',
        'q', 'u', 'e', 'r', 'u', 'l', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'q', 'u', 'e', 'r', 'y', '\n',
        'q', 'u', 'e', 'r', 'y', 'i', 'n', 'g', '\n',
        'q', 'u', 'e', 's', 't', '\n',
        'q', 'u', 'e', 's', 't', 'i', 'n', 'g', '\n',
        'q', 'u', 'e', 's', 't', 'i', 'o', 'n', '\n',
        'q', 'u', 'e', 's', 't', 'i', 'o', 'n', 'a', 'b', 'l', 'e', '\n',
        'q', 'u', 'e', 's', 't', 'i', 'o', 'n', 'a', 'b', 'l', 'y', '\n',
        'q', 'u', 'e', 's', 't', 'i', 'o', 'n', 'e', 'd', '\n',
        'q', 'u', 'e', 's', 't', 'i', 'o', 'n', 'e', 'r', '\n',
        'q', 'u', 'e', 's', 't', 'i', 'o', 'n', 'e', 'r', 's', '\n',
        'q', 'u', 'e', 's', 't', 'i', 'o', 'n', 'i', 'n', 'g', '\n',
        'q', 'u', 'e', 's', 't', 'i', 'o', 'n', 'i', 'n', 'g', 'l', 'y', '\n',
        'q', 'u', 'e', 's', 't', 'i', 'o', 'n', 'i', 'n', 'g', 's', '\n',
        'q', 'u', 'e', 's', 't', 'i', 'o', 'n', 'n', 'a', 'i', 'r', 'e', '\n',
        'q', 'u', 'e', 's', 't', 'i', 'o', 'n', 'n', 'a', 'i', 'r', 'e', 's', '\n',
        'q', 'u', 'e', 's', 't', 'i', 'o', 'n', 's', '\n',
        'q', 'u', 'e', 's', 't', 's', '\n',
        'q', 'u', 'e', 'u', 'e', '\n',
        'q', 'u', 'e', 'u', 'e', 'd', '\n',
        'q', 'u', 'e', 'u', 'e', 'i', 'n', 'g', '\n',
        'q', 'u', 'e', 'u', 'e', 's', '\n',
        'q', 'u', 'e', 'u', 'i', 'n', 'g', '\n',
        'q', 'u', 'i', 'b', 'b', 'l', 'e', '\n',
        'q', 'u', 'i', 'b', 'b', 'l', 'e', 's', '\n',
        'q', 'u', 'i', 'b', 'b', 'l', 'i', 'n', 'g', '\n',
        'q', 'u', 'i', 'c', 'h', 'e', '\n',
        'q', 'u', 'i', 'c', 'h', 'e', 's', '\n',
        'q', 'u', 'i', 'c', 'k', '\n',
        'q', 'u', 'i', 'c', 'k', 'e', 'n', '\n',
        'q', 'u', 'i', 'c', 'k', 'e', 'n', 'e', 'd', '\n',
        'q', 'u', 'i', 'c', 'k', 'e', 'n', 'i', 'n', 'g', '\n',
        'q', 'u', 'i', 'c', 'k', 'e', 'n', 's', '\n',
        'q', 'u', 'i', 'c', 'k', 'e', 'r', '\n',
        'q', 'u', 'i', 'c', 'k', 'e', 's', 't', '\n',
        'q', 'u', 'i', 'c', 'k', 'l', 'i', 'm', 'e', '\n',
        'q', 'u', 'i', 'c', 'k', 'l', 'y', '\n',
        'q', 'u', 'i', 'c', 'k', 'n', 'e', 's', 's', '\n',
        'q', 'u', 'i', 'c', 'k', 's', 'a', 'n', 'd', '\n',
        'q', 'u', 'i', 'c', 'k', 's', 'a', 'n', 'd', 's', '\n',
        'q', 'u', 'i', 'c', 'k', 's', 'i', 'l', 'v', 'e', 'r', '\n',
        'q', 'u', 'i', 'c', 'k', 'w', 'i', 't', 't', 'e', 'd', '\n',
        'q', 'u', 'i', 'd', '\n',
        'q', 'u', 'i', 'd', 's', '\n',
        'q', 'u', 'i', 'e', 's', 'c', 'e', '\n',
        'q', 'u', 'i', 'e', 's', 'c', 'e', 'd', '\n',
        'q', 'u', 'i', 'e', 's', 'c', 'e', 'n', 'c', 'e', '\n',
        'q', 'u', 'i', 'e', 's', 'c', 'e', 'n', 't', '\n',
        'q', 'u', 'i', 'e', 't', '\n',
        'q', 'u', 'i', 'e', 't', 'e', 'd', '\n',
        'q', 'u', 'i', 'e', 't', 'e', 'n', '\n',
        'q', 'u', 'i', 'e', 't', 'e', 'n', 'e', 'd', '\n',
        'q', 'u', 'i', 'e', 't', 'e', 'n', 'i', 'n', 'g', '\n',
        'q', 'u', 'i', 'e', 't', 'e', 'n', 's', '\n',
        'q', 'u', 'i', 'e', 't', 'e', 'r', '\n',
        'q', 'u', 'i', 'e', 't', 'e', 's', 't', '\n',
        'q', 'u', 'i', 'e', 't', 'i', 'n', 'g', '\n',
        'q', 'u', 'i', 'e', 't', 'l', 'y', '\n',
        'q', 'u', 'i', 'e', 't', 'n', 'e', 's', 's', '\n',
        'q', 'u', 'i', 'e', 't', 's', '\n',
        'q', 'u', 'i', 'e', 't', 'u', 's', '\n',
        'q', 'u', 'i', 'f', 'f', '\n',
        'q', 'u', 'i', 'l', 'l', '\n',
        'q', 'u', 'i', 'l', 'l', 's', '\n',
        'q', 'u', 'i', 'l', 't', '\n',
        'q', 'u', 'i', 'l', 't', 'e', 'd', '\n',
        'q', 'u', 'i', 'l', 't', 'i', 'n', 'g', '\n',
        'q', 'u', 'i', 'l', 't', 's', '\n',
        'q', 'u', 'i', 'n', 'c', 'e', '\n',
        'q', 'u', 'i', 'n', 'c', 'e', 'n', 't', 'e', 'n', 'a', 'r', 'y', '\n',
        'q', 'u', 'i', 'n', 'c', 'e', 's', '\n',
        'q', 'u', 'i', 'n', 'i', 'n', 'e', '\n',
        'q', 'u', 'i', 'n', 'q', 'u', 'e', 'n', 'n', 'i', 'a', 'l', '\n',
        'q', 'u', 'i', 'n', 't', 'e', 's', 's', 'e', 'n', 'c', 'e', '\n',
        'q', 'u', 'i', 'n', 't', 'e', 's', 's', 'e', 'n', 't', 'i', 'a', 'l', '\n',
        'q', 'u', 'i', 'n', 't', 'e', 's', 's', 'e', 'n', 't', 'i', 'a', 'l', 'l', 'y', '\n',
        'q', 'u', 'i', 'n', 't', 'e', 't', '\n',
        'q', 'u', 'i', 'n', 't', 'e', 't', 's', '\n',
        'q', 'u', 'i', 'n', 't', 'i', 'c', '\n',
        'q', 'u', 'i', 'n', 't', 'i', 'l', 'l', 'i', 'o', 'n', '\n',
        'q', 'u', 'i', 'n', 't', 'u', 'p', 'l', 'e', '\n',
        'q', 'u', 'i', 'p', '\n',
        'q', 'u', 'i', 'p', 'p', 'e', 'd', '\n',
        'q', 'u', 'i', 'p', 'p', 'e', 'r', '\n',
        'q', 'u', 'i', 'p', 's', '\n',
        'q', 'u', 'i', 'r', 'e', '\n',
        'q', 'u', 'i', 'r', 'k', '\n',
        'q', 'u', 'i', 'r', 'k', 'i', 'e', 'r', '\n',
        'q', 'u', 'i', 'r', 'k', 'i', 'e', 's', 't', '\n',
        'q', 'u', 'i', 'r', 'k', 'i', 'n', 'e', 's', 's', '\n',
        'q', 'u', 'i', 'r', 'k', 's', '\n',
        'q', 'u', 'i', 'r', 'k', 'y', '\n',
        'q', 'u', 'i', 's', 'l', 'i', 'n', 'g', '\n',
        'q', 'u', 'i', 't', '\n',
        'q', 'u', 'i', 't', 'e', '\n',
        'q', 'u', 'i', 't', 's', '\n',
        'q', 'u', 'i', 't', 't', 'e', 'd', '\n',
        'q', 'u', 'i', 't', 't', 'e', 'r', '\n',
        'q', 'u', 'i', 't', 't', 'i', 'n', 'g', '\n',
        'q', 'u', 'i', 'v', 'e', 'r', '\n',
        'q', 'u', 'i', 'v', 'e', 'r', 'e', 'd', '\n',
        'q', 'u', 'i', 'v', 'e', 'r', 'i', 'n', 'g', '\n',
        'q', 'u', 'i', 'v', 'e', 'r', 'i', 'n', 'g', 'l', 'y', '\n',
        'q', 'u', 'i', 'v', 'e', 'r', 's', '\n',
        'q', 'u', 'i', 'x', 'o', 't', 'i', 'c', '\n',
        'q', 'u', 'i', 'z', '\n',
        'q', 'u', 'i', 'z', 'z', 'e', 'd', '\n',
        'q', 'u', 'i', 'z', 'z', 'e', 's', '\n',
        'q', 'u', 'i', 'z', 'z', 'i', 'c', 'a', 'l', '\n',
        'q', 'u', 'i', 'z', 'z', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'q', 'u', 'i', 'z', 'z', 'i', 'n', 'g', '\n',
        'q', 'u', 'o', 'i', 'n', 's', '\n',
        'q', 'u', 'o', 'i', 't', 's', '\n',
        'q', 'u', 'o', 'n', 'd', 'a', 'm', '\n',
        'q', 'u', 'o', 'r', 'a', 't', 'e', '\n',
        'q', 'u', 'o', 'r', 'u', 'm', '\n',
        'q', 'u', 'o', 't', 'a', '\n',
        'q', 'u', 'o', 't', 'a', 'b', 'l', 'e', '\n',
        'q', 'u', 'o', 't', 'a', 's', '\n',
        'q', 'u', 'o', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'q', 'u', 'o', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'q', 'u', 'o', 't', 'e', '\n',
        'q', 'u', 'o', 't', 'e', 'd', '\n',
        'q', 'u', 'o', 't', 'e', 'r', '\n',
        'q', 'u', 'o', 't', 'e', 's', '\n',
        'q', 'u', 'o', 't', 'i', 'd', 'i', 'a', 'n', '\n',
        'q', 'u', 'o', 't', 'i', 'e', 'n', 't', '\n',
        'q', 'u', 'o', 't', 'i', 'e', 'n', 't', 's', '\n',
        'q', 'u', 'o', 't', 'i', 'n', 'g', '\n',
        'q', 'u', 'o', 'v', 'a', 'd', 'i', 's', '\n',
        'r', 'a', 'b', 'a', 't', '\n',
        'r', 'a', 'b', 'a', 't', 's', '\n',
        'r', 'a', 'b', 'b', 'i', '\n',
        'r', 'a', 'b', 'b', 'i', 's', '\n',
        'r', 'a', 'b', 'b', 'i', 't', '\n',
        'r', 'a', 'b', 'b', 'i', 't', 'i', 'n', 'g', '\n',
        'r', 'a', 'b', 'b', 'i', 't', 's', '\n',
        'r', 'a', 'b', 'b', 'l', 'e', '\n',
        'r', 'a', 'b', 'i', 'd', '\n',
        'r', 'a', 'b', 'i', 'd', 'l', 'y', '\n',
        'r', 'a', 'b', 'i', 'e', 's', '\n',
        'r', 'a', 'c', 'c', 'o', 'o', 'n', '\n',
        'r', 'a', 'c', 'c', 'o', 'o', 'n', 's', '\n',
        'r', 'a', 'c', 'e', '\n',
        'r', 'a', 'c', 'e', 'c', 'o', 'u', 'r', 's', 'e', '\n',
        'r', 'a', 'c', 'e', 'c', 'o', 'u', 'r', 's', 'e', 's', '\n',
        'r', 'a', 'c', 'e', 'd', '\n',
        'r', 'a', 'c', 'e', 'g', 'o', 'e', 'r', 's', '\n',
        'r', 'a', 'c', 'e', 'h', 'o', 'r', 's', 'e', '\n',
        'r', 'a', 'c', 'e', 'h', 'o', 'r', 's', 'e', 's', '\n',
        'r', 'a', 'c', 'e', 'r', '\n',
        'r', 'a', 'c', 'e', 'r', 's', '\n',
        'r', 'a', 'c', 'e', 's', '\n',
        'r', 'a', 'c', 'e', 't', 'r', 'a', 'c', 'k', '\n',
        'r', 'a', 'c', 'h', 'i', 's', '\n',
        'r', 'a', 'c', 'i', 'a', 'l', '\n',
        'r', 'a', 'c', 'i', 'a', 'l', 'i', 's', 'm', '\n',
        'r', 'a', 'c', 'i', 'a', 'l', 'i', 's', 't', '\n',
        'r', 'a', 'c', 'i', 'a', 'l', 'i', 's', 't', 's', '\n',
        'r', 'a', 'c', 'i', 'a', 'l', 'l', 'y', '\n',
        'r', 'a', 'c', 'i', 'e', 'r', '\n',
        'r', 'a', 'c', 'i', 'e', 's', 't', '\n',
        'r', 'a', 'c', 'i', 'l', 'y', '\n',
        'r', 'a', 'c', 'i', 'n', 'g', '\n',
        'r', 'a', 'c', 'i', 'n', 'g', 's', '\n',
        'r', 'a', 'c', 'i', 's', 'm', '\n',
        'r', 'a', 'c', 'i', 's', 't', '\n',
        'r', 'a', 'c', 'i', 's', 't', 's', '\n',
        'r', 'a', 'c', 'k', '\n',
        'r', 'a', 'c', 'k', 'e', 'd', '\n',
        'r', 'a', 'c', 'k', 'e', 't', '\n',
        'r', 'a', 'c', 'k', 'e', 't', 'e', 'e', 'r', 'i', 'n', 'g', '\n',
        'r', 'a', 'c', 'k', 'e', 't', 's', '\n',
        'r', 'a', 'c', 'k', 'i', 'n', 'g', '\n',
        'r', 'a', 'c', 'k', 's', '\n',
        'r', 'a', 'c', 'o', 'n', 't', 'e', 'u', 'r', '\n',
        'r', 'a', 'c', 'o', 'o', 'n', '\n',
        'r', 'a', 'c', 'q', 'u', 'e', 't', '\n',
        'r', 'a', 'c', 'q', 'u', 'e', 't', 's', '\n',
        'r', 'a', 'c', 'y', '\n',
        'r', 'a', 'd', '\n',
        'r', 'a', 'd', 'a', 'r', '\n',
        'r', 'a', 'd', 'a', 'r', 's', '\n',
        'r', 'a', 'd', 'i', 'a', 'l', '\n',
        'r', 'a', 'd', 'i', 'a', 'l', 'l', 'y', '\n',
        'r', 'a', 'd', 'i', 'a', 'l', 's', '\n',
        'r', 'a', 'd', 'i', 'a', 'n', '\n',
        'r', 'a', 'd', 'i', 'a', 'n', 'c', 'e', '\n',
        'r', 'a', 'd', 'i', 'a', 'n', 'c', 'y', '\n',
        'r', 'a', 'd', 'i', 'a', 'n', 's', '\n',
        'r', 'a', 'd', 'i', 'a', 'n', 't', '\n',
        'r', 'a', 'd', 'i', 'a', 'n', 't', 'l', 'y', '\n',
        'r', 'a', 'd', 'i', 'a', 't', 'e', '\n',
        'r', 'a', 'd', 'i', 'a', 't', 'e', 'd', '\n',
        'r', 'a', 'd', 'i', 'a', 't', 'e', 's', '\n',
        'r', 'a', 'd', 'i', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'a', 'd', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'a', 'd', 'i', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'a', 'd', 'i', 'a', 't', 'i', 'v', 'e', '\n',
        'r', 'a', 'd', 'i', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'r', 'a', 'd', 'i', 'a', 't', 'o', 'r', '\n',
        'r', 'a', 'd', 'i', 'a', 't', 'o', 'r', 's', '\n',
        'r', 'a', 'd', 'i', 'c', 'a', 'l', '\n',
        'r', 'a', 'd', 'i', 'c', 'a', 'l', 'i', 's', 'm', '\n',
        'r', 'a', 'd', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'r', 'a', 'd', 'i', 'c', 'a', 'l', 's', '\n',
        'r', 'a', 'd', 'i', 'c', 'e', 's', '\n',
        'r', 'a', 'd', 'i', 'i', '\n',
        'r', 'a', 'd', 'i', 'o', '\n',
        'r', 'a', 'd', 'i', 'o', 'a', 'c', 't', 'i', 'v', 'e', '\n',
        'r', 'a', 'd', 'i', 'o', 'a', 'c', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'r', 'a', 'd', 'i', 'o', 'a', 'c', 't', 'i', 'v', 'i', 't', 'y', '\n',
        'r', 'a', 'd', 'i', 'o', 'a', 's', 't', 'r', 'o', 'n', 'o', 'm', 'i', 'c', 'a', 'l', '\n',
        'r', 'a', 'd', 'i', 'o', 'c', 'a', 'r', 'b', 'o', 'n', '\n',
        'r', 'a', 'd', 'i', 'o', 'e', 'd', '\n',
        'r', 'a', 'd', 'i', 'o', 'g', 'a', 'l', 'a', 'x', 'i', 'e', 's', '\n',
        'r', 'a', 'd', 'i', 'o', 'g', 'a', 'l', 'a', 'x', 'y', '\n',
        'r', 'a', 'd', 'i', 'o', 'g', 'r', 'a', 'm', '\n',
        'r', 'a', 'd', 'i', 'o', 'g', 'r', 'a', 'p', 'h', '\n',
        'r', 'a', 'd', 'i', 'o', 'g', 'r', 'a', 'p', 'h', 'e', 'r', '\n',
        'r', 'a', 'd', 'i', 'o', 'g', 'r', 'a', 'p', 'h', 'e', 'r', 's', '\n',
        'r', 'a', 'd', 'i', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', '\n',
        'r', 'a', 'd', 'i', 'o', 'g', 'r', 'a', 'p', 'h', 's', '\n',
        'r', 'a', 'd', 'i', 'o', 'g', 'r', 'a', 'p', 'h', 'y', '\n',
        'r', 'a', 'd', 'i', 'o', 'i', 'n', 'g', '\n',
        'r', 'a', 'd', 'i', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'r', 'a', 'd', 'i', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'r', 'a', 'd', 'i', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'r', 'a', 'd', 'i', 'o', 'l', 'o', 'g', 'y', '\n',
        'r', 'a', 'd', 'i', 'o', 'm', 'e', 't', 'r', 'i', 'c', '\n',
        'r', 'a', 'd', 'i', 'o', 'n', 'u', 'c', 'l', 'i', 'd', 'e', '\n',
        'r', 'a', 'd', 'i', 'o', 's', '\n',
        'r', 'a', 'd', 'i', 'o', 't', 'h', 'e', 'r', 'a', 'p', 'y', '\n',
        'r', 'a', 'd', 'i', 's', 'h', '\n',
        'r', 'a', 'd', 'i', 's', 'h', 'e', 's', '\n',
        'r', 'a', 'd', 'i', 'u', 'm', '\n',
        'r', 'a', 'd', 'i', 'u', 's', '\n',
        'r', 'a', 'd', 'i', 'x', '\n',
        'r', 'a', 'd', 'o', 'n', '\n',
        'r', 'a', 'f', 'f', 'i', 'a', '\n',
        'r', 'a', 'f', 'f', 'l', 'e', '\n',
        'r', 'a', 'f', 'f', 'l', 'e', 'd', '\n',
        'r', 'a', 'f', 'f', 'l', 'e', 's', '\n',
        'r', 'a', 'f', 't', '\n',
        'r', 'a', 'f', 't', 'e', 'r', '\n',
        'r', 'a', 'f', 't', 'e', 'r', 's', '\n',
        'r', 'a', 'f', 't', 'i', 'n', 'g', '\n',
        'r', 'a', 'f', 't', 'm', 'a', 'n', '\n',
        'r', 'a', 'f', 't', 's', '\n',
        'r', 'a', 'f', 't', 's', 'm', 'a', 'n', '\n',
        'r', 'a', 'g', '\n',
        'r', 'a', 'g', 'a', 'm', 'u', 'f', 'f', 'i', 'n', '\n',
        'r', 'a', 'g', 'a', 'm', 'u', 'f', 'f', 'i', 'n', 's', '\n',
        'r', 'a', 'g', 'b', 'a', 'g', '\n',
        'r', 'a', 'g', 'e', '\n',
        'r', 'a', 'g', 'e', 'd', '\n',
        'r', 'a', 'g', 'e', 's', '\n',
        'r', 'a', 'g', 'g', 'e', 'd', '\n',
        'r', 'a', 'g', 'g', 'e', 'd', 'l', 'y', '\n',
        'r', 'a', 'g', 'i', 'n', 'g', '\n',
        'r', 'a', 'g', 'o', 'u', 't', '\n',
        'r', 'a', 'g', 's', '\n',
        'r', 'a', 'g', 's', 't', 'o', 'r', 'i', 'c', 'h', 'e', 's', '\n',
        'r', 'a', 'g', 't', 'i', 'm', 'e', '\n',
        'r', 'a', 'g', 'w', 'o', 'r', 't', '\n',
        'r', 'a', 'i', 'd', '\n',
        'r', 'a', 'i', 'd', 'e', 'd', '\n',
        'r', 'a', 'i', 'd', 'e', 'r', '\n',
        'r', 'a', 'i', 'd', 'e', 'r', 's', '\n',
        'r', 'a', 'i', 'd', 'i', 'n', 'g', '\n',
        'r', 'a', 'i', 'd', 's', '\n',
        'r', 'a', 'i', 'l', '\n',
        'r', 'a', 'i', 'l', 'e', 'd', '\n',
        'r', 'a', 'i', 'l', 'e', 's', '\n',
        'r', 'a', 'i', 'l', 'i', 'n', 'g', '\n',
        'r', 'a', 'i', 'l', 'i', 'n', 'g', 's', '\n',
        'r', 'a', 'i', 'l', 'l', 'e', 'r', 'y', '\n',
        'r', 'a', 'i', 'l', 'r', 'o', 'a', 'd', '\n',
        'r', 'a', 'i', 'l', 's', '\n',
        'r', 'a', 'i', 'l', 'w', 'a', 'y', '\n',
        'r', 'a', 'i', 'l', 'w', 'a', 'y', 'm', 'a', 'n', '\n',
        'r', 'a', 'i', 'l', 'w', 'a', 'y', 'm', 'e', 'n', '\n',
        'r', 'a', 'i', 'l', 'w', 'a', 'y', 's', '\n',
        'r', 'a', 'i', 'm', 'e', 'n', 't', '\n',
        'r', 'a', 'i', 'n', '\n',
        'r', 'a', 'i', 'n', 'b', 'o', 'w', '\n',
        'r', 'a', 'i', 'n', 'b', 'o', 'w', 's', '\n',
        'r', 'a', 'i', 'n', 'c', 'l', 'o', 'u', 'd', '\n',
        'r', 'a', 'i', 'n', 'c', 'l', 'o', 'u', 'd', 's', '\n',
        'r', 'a', 'i', 'n', 'c', 'o', 'a', 't', '\n',
        'r', 'a', 'i', 'n', 'c', 'o', 'a', 't', 's', '\n',
        'r', 'a', 'i', 'n', 'd', 'r', 'o', 'p', '\n',
        'r', 'a', 'i', 'n', 'd', 'r', 'o', 'p', 's', '\n',
        'r', 'a', 'i', 'n', 'e', 'd', '\n',
        'r', 'a', 'i', 'n', 'f', 'a', 'l', 'l', '\n',
        'r', 'a', 'i', 'n', 'f', 'o', 'r', 'e', 's', 't', '\n',
        'r', 'a', 'i', 'n', 'f', 'o', 'r', 'e', 's', 't', 's', '\n',
        'r', 'a', 'i', 'n', 'i', 'e', 'r', '\n',
        'r', 'a', 'i', 'n', 'i', 'e', 's', 't', '\n',
        'r', 'a', 'i', 'n', 'i', 'n', 'g', '\n',
        'r', 'a', 'i', 'n', 'l', 'e', 's', 's', '\n',
        'r', 'a', 'i', 'n', 'o', 'u', 't', '\n',
        'r', 'a', 'i', 'n', 's', '\n',
        'r', 'a', 'i', 'n', 's', 't', 'o', 'r', 'm', '\n',
        'r', 'a', 'i', 'n', 's', 't', 'o', 'r', 'm', 's', '\n',
        'r', 'a', 'i', 'n', 's', 'w', 'e', 'p', 't', '\n',
        'r', 'a', 'i', 'n', 'w', 'a', 't', 'e', 'r', '\n',
        'r', 'a', 'i', 'n', 'y', '\n',
        'r', 'a', 'i', 's', 'e', '\n',
        'r', 'a', 'i', 's', 'e', 'd', '\n',
        'r', 'a', 'i', 's', 'e', 'r', '\n',
        'r', 'a', 'i', 's', 'e', 's', '\n',
        'r', 'a', 'i', 's', 'i', 'n', '\n',
        'r', 'a', 'i', 's', 'i', 'n', 'g', '\n',
        'r', 'a', 'i', 's', 'i', 'n', 's', '\n',
        'r', 'a', 'j', '\n',
        'r', 'a', 'j', 'a', 'h', '\n',
        'r', 'a', 'k', 'e', '\n',
        'r', 'a', 'k', 'e', 'd', '\n',
        'r', 'a', 'k', 'e', 's', '\n',
        'r', 'a', 'k', 'i', 'n', 'g', '\n',
        'r', 'a', 'k', 'i', 's', 'h', '\n',
        'r', 'a', 'l', 'l', 'i', 'e', 'd', '\n',
        'r', 'a', 'l', 'l', 'i', 'e', 's', '\n',
        'r', 'a', 'l', 'l', 'y', '\n',
        'r', 'a', 'l', 'l', 'y', 'i', 'n', 'g', '\n',
        'r', 'a', 'm', '\n',
        'r', 'a', 'm', 'b', 'l', 'e', '\n',
        'r', 'a', 'm', 'b', 'l', 'e', 'd', '\n',
        'r', 'a', 'm', 'b', 'l', 'e', 'r', '\n',
        'r', 'a', 'm', 'b', 'l', 'e', 'r', 's', '\n',
        'r', 'a', 'm', 'b', 'l', 'e', 's', '\n',
        'r', 'a', 'm', 'b', 'l', 'i', 'n', 'g', '\n',
        'r', 'a', 'm', 'b', 'l', 'i', 'n', 'g', 's', '\n',
        'r', 'a', 'm', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'a', 'm', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'a', 'm', 'i', 'f', 'i', 'e', 'd', '\n',
        'r', 'a', 'm', 'i', 'f', 'i', 'e', 's', '\n',
        'r', 'a', 'm', 'i', 'f', 'y', '\n',
        'r', 'a', 'm', 'm', 'e', 'd', '\n',
        'r', 'a', 'm', 'm', 'e', 'r', '\n',
        'r', 'a', 'm', 'm', 'i', 'n', 'g', '\n',
        'r', 'a', 'm', 'p', '\n',
        'r', 'a', 'm', 'p', 'a', 'g', 'e', '\n',
        'r', 'a', 'm', 'p', 'a', 'g', 'e', 'd', '\n',
        'r', 'a', 'm', 'p', 'a', 'g', 'e', 's', '\n',
        'r', 'a', 'm', 'p', 'a', 'g', 'i', 'n', 'g', '\n',
        'r', 'a', 'm', 'p', 'a', 'n', 't', '\n',
        'r', 'a', 'm', 'p', 'a', 'n', 't', 'l', 'y', '\n',
        'r', 'a', 'm', 'p', 'a', 'r', 't', '\n',
        'r', 'a', 'm', 'p', 'a', 'r', 't', 's', '\n',
        'r', 'a', 'm', 'p', 'e', 'd', '\n',
        'r', 'a', 'm', 'p', 'i', 'n', 'g', '\n',
        'r', 'a', 'm', 'p', 's', '\n',
        'r', 'a', 'm', 'r', 'o', 'd', '\n',
        'r', 'a', 'm', 's', '\n',
        'r', 'a', 'm', 's', 'h', 'a', 'c', 'k', 'l', 'e', '\n',
        'r', 'a', 'n', '\n',
        'r', 'a', 'n', 'c', 'h', '\n',
        'r', 'a', 'n', 'c', 'h', 'e', 'r', '\n',
        'r', 'a', 'n', 'c', 'h', 'e', 'r', 's', '\n',
        'r', 'a', 'n', 'c', 'h', 'e', 's', '\n',
        'r', 'a', 'n', 'c', 'h', 'i', 'n', 'g', '\n',
        'r', 'a', 'n', 'c', 'i', 'd', '\n',
        'r', 'a', 'n', 'c', 'o', 'r', 'o', 'u', 's', '\n',
        'r', 'a', 'n', 'c', 'o', 'u', 'r', '\n',
        'r', 'a', 'n', 'd', '\n',
        'r', 'a', 'n', 'd', 'o', 'm', '\n',
        'r', 'a', 'n', 'd', 'o', 'm', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'a', 'n', 'd', 'o', 'm', 'i', 's', 'e', '\n',
        'r', 'a', 'n', 'd', 'o', 'm', 'i', 's', 'e', 'd', '\n',
        'r', 'a', 'n', 'd', 'o', 'm', 'i', 's', 'i', 'n', 'g', '\n',
        'r', 'a', 'n', 'd', 'o', 'm', 'l', 'y', '\n',
        'r', 'a', 'n', 'd', 'o', 'm', 'n', 'e', 's', 's', '\n',
        'r', 'a', 'n', 'd', 's', '\n',
        'r', 'a', 'n', 'd', 'y', '\n',
        'r', 'a', 'n', 'g', '\n',
        'r', 'a', 'n', 'g', 'e', '\n',
        'r', 'a', 'n', 'g', 'e', 'd', '\n',
        'r', 'a', 'n', 'g', 'e', 'r', '\n',
        'r', 'a', 'n', 'g', 'e', 'r', 's', '\n',
        'r', 'a', 'n', 'g', 'e', 's', '\n',
        'r', 'a', 'n', 'g', 'i', 'n', 'g', '\n',
        'r', 'a', 'n', 'g', 'y', '\n',
        'r', 'a', 'n', 'i', '\n',
        'r', 'a', 'n', 'i', 's', '\n',
        'r', 'a', 'n', 'k', '\n',
        'r', 'a', 'n', 'k', 'e', 'd', '\n',
        'r', 'a', 'n', 'k', 'e', 'r', '\n',
        'r', 'a', 'n', 'k', 'e', 'r', 's', '\n',
        'r', 'a', 'n', 'k', 'e', 's', 't', '\n',
        'r', 'a', 'n', 'k', 'i', 'n', 'g', '\n',
        'r', 'a', 'n', 'k', 'i', 'n', 'g', 's', '\n',
        'r', 'a', 'n', 'k', 'l', 'e', '\n',
        'r', 'a', 'n', 'k', 'l', 'e', 'd', '\n',
        'r', 'a', 'n', 'k', 'l', 'e', 's', '\n',
        'r', 'a', 'n', 'k', 'l', 'i', 'n', 'g', '\n',
        'r', 'a', 'n', 'k', 'n', 'e', 's', 's', '\n',
        'r', 'a', 'n', 'k', 's', '\n',
        'r', 'a', 'n', 's', 'a', 'c', 'k', '\n',
        'r', 'a', 'n', 's', 'a', 'c', 'k', 'e', 'd', '\n',
        'r', 'a', 'n', 's', 'a', 'c', 'k', 'i', 'n', 'g', '\n',
        'r', 'a', 'n', 's', 'o', 'm', '\n',
        'r', 'a', 'n', 's', 'o', 'm', 'e', 'd', '\n',
        'r', 'a', 'n', 's', 'o', 'm', 'i', 'n', 'g', '\n',
        'r', 'a', 'n', 's', 'o', 'm', 's', '\n',
        'r', 'a', 'n', 't', '\n',
        'r', 'a', 'n', 't', 'e', 'd', '\n',
        'r', 'a', 'n', 't', 'e', 'r', '\n',
        'r', 'a', 'n', 't', 'e', 'r', 's', '\n',
        'r', 'a', 'n', 't', 'i', 'n', 'g', '\n',
        'r', 'a', 'n', 't', 'i', 'n', 'g', 's', '\n',
        'r', 'a', 'n', 't', 's', '\n',
        'r', 'a', 'p', '\n',
        'r', 'a', 'p', 'a', 'c', 'i', 'o', 'u', 's', '\n',
        'r', 'a', 'p', 'a', 'c', 'i', 't', 'y', '\n',
        'r', 'a', 'p', 'e', '\n',
        'r', 'a', 'p', 'e', 'd', '\n',
        'r', 'a', 'p', 'e', 's', '\n',
        'r', 'a', 'p', 'e', 's', 'e', 'e', 'd', '\n',
        'r', 'a', 'p', 'i', 'd', '\n',
        'r', 'a', 'p', 'i', 'd', 'i', 't', 'y', '\n',
        'r', 'a', 'p', 'i', 'd', 'l', 'y', '\n',
        'r', 'a', 'p', 'i', 'd', 's', '\n',
        'r', 'a', 'p', 'i', 'e', 'r', '\n',
        'r', 'a', 'p', 'i', 'e', 'r', 's', '\n',
        'r', 'a', 'p', 'i', 'n', 'e', '\n',
        'r', 'a', 'p', 'i', 'n', 'g', '\n',
        'r', 'a', 'p', 'i', 's', 't', '\n',
        'r', 'a', 'p', 'i', 's', 't', 's', '\n',
        'r', 'a', 'p', 'p', 'e', 'd', '\n',
        'r', 'a', 'p', 'p', 'i', 'n', 'g', '\n',
        'r', 'a', 'p', 'p', 'o', 'r', 't', '\n',
        'r', 'a', 'p', 'p', 'o', 'r', 't', 'e', 'u', 'r', '\n',
        'r', 'a', 'p', 'p', 'o', 'r', 't', 'e', 'u', 'r', 's', '\n',
        'r', 'a', 'p', 'p', 'o', 'r', 't', 's', '\n',
        'r', 'a', 'p', 'p', 'r', 'o', 'c', 'h', 'e', 'm', 'e', 'n', 't', '\n',
        'r', 'a', 'p', 's', '\n',
        'r', 'a', 'p', 't', '\n',
        'r', 'a', 'p', 't', 'o', 'r', '\n',
        'r', 'a', 'p', 't', 'o', 'r', 's', '\n',
        'r', 'a', 'p', 't', 'u', 'r', 'e', '\n',
        'r', 'a', 'p', 't', 'u', 'r', 'e', 's', '\n',
        'r', 'a', 'p', 't', 'u', 'r', 'o', 'u', 's', '\n',
        'r', 'a', 'p', 't', 'u', 'r', 'o', 'u', 's', 'l', 'y', '\n',
        'r', 'a', 'r', 'e', '\n',
        'r', 'a', 'r', 'e', 'b', 'i', 't', '\n',
        'r', 'a', 'r', 'e', 'f', 'a', 'c', 't', 'i', 'o', 'n', '\n',
        'r', 'a', 'r', 'e', 'f', 'a', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'a', 'r', 'e', 'f', 'i', 'e', 'd', '\n',
        'r', 'a', 'r', 'e', 'l', 'y', '\n',
        'r', 'a', 'r', 'e', 'n', 'e', 's', 's', '\n',
        'r', 'a', 'r', 'e', 'r', '\n',
        'r', 'a', 'r', 'e', 's', 't', '\n',
        'r', 'a', 'r', 'i', 'n', 'g', '\n',
        'r', 'a', 'r', 'i', 't', 'i', 'e', 's', '\n',
        'r', 'a', 'r', 'i', 't', 'y', '\n',
        'r', 'a', 's', 'c', 'a', 'l', '\n',
        'r', 'a', 's', 'c', 'a', 'l', 'l', 'y', '\n',
        'r', 'a', 's', 'c', 'a', 'l', 's', '\n',
        'r', 'a', 's', 'e', 'd', '\n',
        'r', 'a', 's', 'h', '\n',
        'r', 'a', 's', 'h', 'e', 'r', '\n',
        'r', 'a', 's', 'h', 'e', 'r', 's', '\n',
        'r', 'a', 's', 'h', 'e', 's', '\n',
        'r', 'a', 's', 'h', 'e', 's', 't', '\n',
        'r', 'a', 's', 'h', 'l', 'y', '\n',
        'r', 'a', 's', 'h', 'n', 'e', 's', 's', '\n',
        'r', 'a', 's', 'i', 'n', 'g', '\n',
        'r', 'a', 's', 'p', '\n',
        'r', 'a', 's', 'p', 'b', 'e', 'r', 'r', 'i', 'e', 's', '\n',
        'r', 'a', 's', 'p', 'b', 'e', 'r', 'r', 'y', '\n',
        'r', 'a', 's', 'p', 'e', 'd', '\n',
        'r', 'a', 's', 'p', 'e', 'r', '\n',
        'r', 'a', 's', 'p', 'i', 'n', 'g', '\n',
        'r', 'a', 's', 'p', 's', '\n',
        'r', 'a', 's', 'p', 'y', '\n',
        'r', 'a', 's', 't', 'e', 'r', '\n',
        'r', 'a', 's', 't', 'e', 'r', 's', '\n',
        'r', 'a', 't', '\n',
        'r', 'a', 't', 'a', 't', 'o', 'u', 'i', 'l', 'l', 'e', '\n',
        'r', 'a', 't', 'e', '\n',
        'r', 'a', 't', 'e', 'd', '\n',
        'r', 'a', 't', 'e', 'p', 'a', 'y', 'e', 'r', '\n',
        'r', 'a', 't', 'e', 'p', 'a', 'y', 'e', 'r', 's', '\n',
        'r', 'a', 't', 'e', 'r', '\n',
        'r', 'a', 't', 'e', 's', '\n',
        'r', 'a', 't', 'h', 'e', 'r', '\n',
        'r', 'a', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'a', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'a', 't', 'i', 'f', 'i', 'e', 'd', '\n',
        'r', 'a', 't', 'i', 'f', 'i', 'e', 'r', '\n',
        'r', 'a', 't', 'i', 'f', 'i', 'e', 's', '\n',
        'r', 'a', 't', 'i', 'f', 'y', '\n',
        'r', 'a', 't', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'r', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'a', 't', 'i', 'n', 'g', 's', '\n',
        'r', 'a', 't', 'i', 'o', '\n',
        'r', 'a', 't', 'i', 'o', 'c', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'r', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'e', '\n',
        'r', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'e', 's', '\n',
        'r', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 'e', '\n',
        'r', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'r', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'r', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 'm', '\n',
        'r', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 't', '\n',
        'r', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 't', 'i', 'c', '\n',
        'r', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 't', 's', '\n',
        'r', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'r', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 't', 'y', '\n',
        'r', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'r', 'a', 't', 'i', 'o', 'n', 'e', 'd', '\n',
        'r', 'a', 't', 'i', 'o', 'n', 'i', 'n', 'g', '\n',
        'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'a', 't', 'i', 'o', 's', '\n',
        'r', 'a', 't', 'l', 'i', 'k', 'e', '\n',
        'r', 'a', 't', 'r', 'a', 'c', 'e', '\n',
        'r', 'a', 't', 's', '\n',
        'r', 'a', 't', 't', 'i', 'e', 'r', '\n',
        'r', 'a', 't', 't', 'l', 'e', '\n',
        'r', 'a', 't', 't', 'l', 'e', 'd', '\n',
        'r', 'a', 't', 't', 'l', 'e', 'r', '\n',
        'r', 'a', 't', 't', 'l', 'e', 's', '\n',
        'r', 'a', 't', 't', 'l', 'e', 's', 'n', 'a', 'k', 'e', '\n',
        'r', 'a', 't', 't', 'l', 'e', 's', 'n', 'a', 'k', 'e', 's', '\n',
        'r', 'a', 't', 't', 'l', 'i', 'n', 'g', '\n',
        'r', 'a', 't', 't', 'y', '\n',
        'r', 'a', 'u', 'c', 'o', 'u', 's', '\n',
        'r', 'a', 'u', 'c', 'o', 'u', 's', 'l', 'y', '\n',
        'r', 'a', 'v', 'a', 'g', 'e', '\n',
        'r', 'a', 'v', 'a', 'g', 'e', 'd', '\n',
        'r', 'a', 'v', 'a', 'g', 'e', 's', '\n',
        'r', 'a', 'v', 'a', 'g', 'i', 'n', 'g', '\n',
        'r', 'a', 'v', 'e', '\n',
        'r', 'a', 'v', 'e', 'd', '\n',
        'r', 'a', 'v', 'e', 'l', '\n',
        'r', 'a', 'v', 'e', 'l', 'l', 'e', 'd', '\n',
        'r', 'a', 'v', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'r', 'a', 'v', 'e', 'l', 's', '\n',
        'r', 'a', 'v', 'e', 'n', '\n',
        'r', 'a', 'v', 'e', 'n', 'i', 'n', 'g', '\n',
        'r', 'a', 'v', 'e', 'n', 'o', 'u', 's', '\n',
        'r', 'a', 'v', 'e', 'n', 'o', 'u', 's', 'l', 'y', '\n',
        'r', 'a', 'v', 'e', 'n', 's', '\n',
        'r', 'a', 'v', 'e', 'r', '\n',
        'r', 'a', 'v', 'e', 'r', 's', '\n',
        'r', 'a', 'v', 'e', 's', '\n',
        'r', 'a', 'v', 'i', 'n', 'e', '\n',
        'r', 'a', 'v', 'i', 'n', 'e', 's', '\n',
        'r', 'a', 'v', 'i', 'n', 'g', '\n',
        'r', 'a', 'v', 'i', 'n', 'g', 'l', 'y', '\n',
        'r', 'a', 'v', 'i', 'n', 'g', 's', '\n',
        'r', 'a', 'v', 'i', 'o', 'l', 'i', '\n',
        'r', 'a', 'v', 'i', 's', 'h', '\n',
        'r', 'a', 'v', 'i', 's', 'h', 'e', 'd', '\n',
        'r', 'a', 'v', 'i', 's', 'h', 'e', 'r', '\n',
        'r', 'a', 'v', 'i', 's', 'h', 'e', 's', '\n',
        'r', 'a', 'v', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'r', 'a', 'v', 'i', 's', 'h', 'i', 'n', 'g', 'l', 'y', '\n',
        'r', 'a', 'w', '\n',
        'r', 'a', 'w', 'e', 's', 't', '\n',
        'r', 'a', 'w', 'n', 'e', 's', 's', '\n',
        'r', 'a', 'y', '\n',
        'r', 'a', 'y', 'e', 'd', '\n',
        'r', 'a', 'y', 'o', 'n', '\n',
        'r', 'a', 'y', 's', '\n',
        'r', 'a', 'z', 'e', '\n',
        'r', 'a', 'z', 'e', 'd', '\n',
        'r', 'a', 'z', 'e', 's', '\n',
        'r', 'a', 'z', 'i', 'n', 'g', '\n',
        'r', 'a', 'z', 'o', 'r', '\n',
        'r', 'a', 'z', 'o', 'r', 'b', 'i', 'l', 'l', 's', '\n',
        'r', 'a', 'z', 'o', 'r', 'b', 'l', 'a', 'd', 'e', 's', '\n',
        'r', 'a', 'z', 'o', 'r', 'i', 'n', 'g', '\n',
        'r', 'a', 'z', 'o', 'r', 's', '\n',
        'r', 'a', 'z', 'o', 'r', 's', 'h', 'a', 'r', 'p', '\n',
        'r', 'a', 'z', 'z', 'm', 'a', 't', 'a', 'z', 'z', '\n',
        'r', 'e', '\n',
        'r', 'e', 'a', 'b', 's', 'o', 'r', 'b', '\n',
        'r', 'e', 'a', 'b', 's', 'o', 'r', 'b', 'e', 'd', '\n',
        'r', 'e', 'a', 'b', 's', 'o', 'r', 'p', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'a', 'c', 'c', 'e', 'p', 't', '\n',
        'r', 'e', 'a', 'c', 'c', 'e', 's', 's', 'e', 'd', '\n',
        'r', 'e', 'a', 'c', 'h', '\n',
        'r', 'e', 'a', 'c', 'h', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'a', 'c', 'h', 'e', 'd', '\n',
        'r', 'e', 'a', 'c', 'h', 'e', 's', '\n',
        'r', 'e', 'a', 'c', 'h', 'i', 'e', 'v', 'e', 'd', '\n',
        'r', 'e', 'a', 'c', 'h', 'i', 'n', 'g', '\n',
        'r', 'e', 'a', 'c', 'q', 'u', 'a', 'i', 'n', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'a', 'c', 'q', 'u', 'i', 'r', 'e', 'd', '\n',
        'r', 'e', 'a', 'c', 'q', 'u', 'i', 's', 'i', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'a', 'c', 't', '\n',
        'r', 'e', 'a', 'c', 't', 'a', 'n', 't', '\n',
        'r', 'e', 'a', 'c', 't', 'a', 'n', 't', 's', '\n',
        'r', 'e', 'a', 'c', 't', 'e', 'd', '\n',
        'r', 'e', 'a', 'c', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'a', 'c', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'a', 'c', 't', 'i', 'o', 'n', 'a', 'r', 'i', 'e', 's', '\n',
        'r', 'e', 'a', 'c', 't', 'i', 'o', 'n', 'a', 'r', 'y', '\n',
        'r', 'e', 'a', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'a', 'c', 't', 'i', 'v', 'a', 't', 'e', '\n',
        'r', 'e', 'a', 'c', 't', 'i', 'v', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 'a', 'c', 't', 'i', 'v', 'a', 't', 'e', 's', '\n',
        'r', 'e', 'a', 'c', 't', 'i', 'v', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'a', 'c', 't', 'i', 'v', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'a', 'c', 't', 'i', 'v', 'e', '\n',
        'r', 'e', 'a', 'c', 't', 'i', 'v', 'i', 't', 'i', 'e', 's', '\n',
        'r', 'e', 'a', 'c', 't', 'i', 'v', 'i', 't', 'y', '\n',
        'r', 'e', 'a', 'c', 't', 'o', 'r', '\n',
        'r', 'e', 'a', 'c', 't', 'o', 'r', 's', '\n',
        'r', 'e', 'a', 'c', 't', 's', '\n',
        'r', 'e', 'a', 'd', '\n',
        'r', 'e', 'a', 'd', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'r', 'e', 'a', 'd', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'a', 'd', 'a', 'b', 'l', 'y', '\n',
        'r', 'e', 'a', 'd', 'a', 'p', 't', '\n',
        'r', 'e', 'a', 'd', 'e', 'r', '\n',
        'r', 'e', 'a', 'd', 'e', 'r', 's', '\n',
        'r', 'e', 'a', 'd', 'e', 'r', 's', 'h', 'i', 'p', '\n',
        'r', 'e', 'a', 'd', 'e', 'r', 's', 'h', 'i', 'p', 's', '\n',
        'r', 'e', 'a', 'd', 'i', 'e', 'd', '\n',
        'r', 'e', 'a', 'd', 'i', 'e', 'r', '\n',
        'r', 'e', 'a', 'd', 'i', 'e', 's', '\n',
        'r', 'e', 'a', 'd', 'i', 'e', 's', 't', '\n',
        'r', 'e', 'a', 'd', 'i', 'l', 'y', '\n',
        'r', 'e', 'a', 'd', 'i', 'n', 'e', 's', 's', '\n',
        'r', 'e', 'a', 'd', 'i', 'n', 'g', '\n',
        'r', 'e', 'a', 'd', 'i', 'n', 'g', 's', '\n',
        'r', 'e', 'a', 'd', 'j', 'u', 's', 't', '\n',
        'r', 'e', 'a', 'd', 'j', 'u', 's', 't', 'e', 'd', '\n',
        'r', 'e', 'a', 'd', 'j', 'u', 's', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'a', 'd', 'j', 'u', 's', 't', 'm', 'e', 'n', 't', '\n',
        'r', 'e', 'a', 'd', 'j', 'u', 's', 't', 'm', 'e', 'n', 't', 's', '\n',
        'r', 'e', 'a', 'd', 'm', 'i', 's', 's', 'i', 'o', 'n', '\n',
        'r', 'e', 'a', 'd', 'm', 'i', 't', '\n',
        'r', 'e', 'a', 'd', 'm', 'i', 't', 's', '\n',
        'r', 'e', 'a', 'd', 'm', 'i', 't', 't', 'e', 'd', '\n',
        'r', 'e', 'a', 'd', 's', '\n',
        'r', 'e', 'a', 'd', 'y', '\n',
        'r', 'e', 'a', 'd', 'y', 'i', 'n', 'g', '\n',
        'r', 'e', 'a', 'd', 'y', 'm', 'a', 'd', 'e', '\n',
        'r', 'e', 'a', 'f', 'f', 'i', 'r', 'm', '\n',
        'r', 'e', 'a', 'f', 'f', 'i', 'r', 'm', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'a', 'f', 'f', 'i', 'r', 'm', 'e', 'd', '\n',
        'r', 'e', 'a', 'f', 'f', 'i', 'r', 'm', 'i', 'n', 'g', '\n',
        'r', 'e', 'a', 'f', 'f', 'i', 'r', 'm', 's', '\n',
        'r', 'e', 'a', 'f', 'f', 'o', 'r', 'e', 's', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'a', 'g', 'e', 'n', 't', '\n',
        'r', 'e', 'a', 'g', 'e', 'n', 't', 's', '\n',
        'r', 'e', 'a', 'l', '\n',
        'r', 'e', 'a', 'l', 'i', 'g', 'n', '\n',
        'r', 'e', 'a', 'l', 'i', 'g', 'n', 'e', 'd', '\n',
        'r', 'e', 'a', 'l', 'i', 'g', 'n', 'i', 'n', 'g', '\n',
        'r', 'e', 'a', 'l', 'i', 'g', 'n', 'm', 'e', 'n', 't', '\n',
        'r', 'e', 'a', 'l', 'i', 'g', 'n', 'm', 'e', 'n', 't', 's', '\n',
        'r', 'e', 'a', 'l', 'i', 'g', 'n', 's', '\n',
        'r', 'e', 'a', 'l', 'i', 's', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'a', 'l', 'i', 's', 'e', '\n',
        'r', 'e', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'r', 'e', 'a', 'l', 'i', 's', 'e', 's', '\n',
        'r', 'e', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'r', 'e', 'a', 'l', 'i', 's', 'm', '\n',
        'r', 'e', 'a', 'l', 'i', 's', 't', '\n',
        'r', 'e', 'a', 'l', 'i', 's', 't', 'i', 'c', '\n',
        'r', 'e', 'a', 'l', 'i', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'r', 'e', 'a', 'l', 'i', 's', 't', 's', '\n',
        'r', 'e', 'a', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'r', 'e', 'a', 'l', 'i', 't', 'y', '\n',
        'r', 'e', 'a', 'l', 'l', 'i', 'f', 'e', '\n',
        'r', 'e', 'a', 'l', 'l', 'o', 'c', 'a', 't', 'e', '\n',
        'r', 'e', 'a', 'l', 'l', 'o', 'c', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 'a', 'l', 'l', 'o', 'c', 'a', 't', 'e', 's', '\n',
        'r', 'e', 'a', 'l', 'l', 'o', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'a', 'l', 'l', 'o', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'a', 'l', 'l', 'y', '\n',
        'r', 'e', 'a', 'l', 'm', '\n',
        'r', 'e', 'a', 'l', 'm', 's', '\n',
        'r', 'e', 'a', 'l', 'n', 'e', 's', 's', '\n',
        'r', 'e', 'a', 'l', 'p', 'o', 'l', 'i', 't', 'i', 'k', '\n',
        'r', 'e', 'a', 'l', 's', '\n',
        'r', 'e', 'a', 'l', 't', 'y', '\n',
        'r', 'e', 'a', 'm', '\n',
        'r', 'e', 'a', 'm', 's', '\n',
        'r', 'e', 'a', 'n', 'i', 'm', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 'a', 'n', 'i', 'm', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'a', 'p', '\n',
        'r', 'e', 'a', 'p', 'e', 'd', '\n',
        'r', 'e', 'a', 'p', 'e', 'r', '\n',
        'r', 'e', 'a', 'p', 'e', 'r', 's', '\n',
        'r', 'e', 'a', 'p', 'i', 'n', 'g', '\n',
        'r', 'e', 'a', 'p', 'p', 'e', 'a', 'r', '\n',
        'r', 'e', 'a', 'p', 'p', 'e', 'a', 'r', 'a', 'n', 'c', 'e', '\n',
        'r', 'e', 'a', 'p', 'p', 'e', 'a', 'r', 'e', 'd', '\n',
        'r', 'e', 'a', 'p', 'p', 'e', 'a', 'r', 'i', 'n', 'g', '\n',
        'r', 'e', 'a', 'p', 'p', 'e', 'a', 'r', 's', '\n',
        'r', 'e', 'a', 'p', 'p', 'l', 'i', 'e', 'd', '\n',
        'r', 'e', 'a', 'p', 'p', 'l', 'y', '\n',
        'r', 'e', 'a', 'p', 'p', 'l', 'y', 'i', 'n', 'g', '\n',
        'r', 'e', 'a', 'p', 'p', 'o', 'i', 'n', 't', '\n',
        'r', 'e', 'a', 'p', 'p', 'o', 'i', 'n', 't', 'e', 'd', '\n',
        'r', 'e', 'a', 'p', 'p', 'o', 'i', 'n', 't', 'm', 'e', 'n', 't', '\n',
        'r', 'e', 'a', 'p', 'p', 'r', 'a', 'i', 's', 'a', 'l', '\n',
        'r', 'e', 'a', 'p', 'p', 'r', 'a', 'i', 's', 'e', 'd', '\n',
        'r', 'e', 'a', 'p', 'p', 'r', 'a', 'i', 's', 'i', 'n', 'g', '\n',
        'r', 'e', 'a', 'p', 's', '\n',
        'r', 'e', 'a', 'r', '\n',
        'r', 'e', 'a', 'r', 'e', 'd', '\n',
        'r', 'e', 'a', 'r', 'e', 'r', '\n',
        'r', 'e', 'a', 'r', 'g', 'u', 'a', 'r', 'd', '\n',
        'r', 'e', 'a', 'r', 'i', 'n', 'g', '\n',
        'r', 'e', 'a', 'r', 'm', '\n',
        'r', 'e', 'a', 'r', 'm', 'a', 'm', 'e', 'n', 't', '\n',
        'r', 'e', 'a', 'r', 'm', 'e', 'd', '\n',
        'r', 'e', 'a', 'r', 'm', 'i', 'n', 'g', '\n',
        'r', 'e', 'a', 'r', 'm', 's', '\n',
        'r', 'e', 'a', 'r', 'r', 'a', 'n', 'g', 'e', '\n',
        'r', 'e', 'a', 'r', 'r', 'a', 'n', 'g', 'e', 'd', '\n',
        'r', 'e', 'a', 'r', 'r', 'a', 'n', 'g', 'e', 'm', 'e', 'n', 't', '\n',
        'r', 'e', 'a', 'r', 'r', 'a', 'n', 'g', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'r', 'e', 'a', 'r', 'r', 'a', 'n', 'g', 'e', 's', '\n',
        'r', 'e', 'a', 'r', 'r', 'a', 'n', 'g', 'i', 'n', 'g', '\n',
        'r', 'e', 'a', 'r', 's', '\n',
        'r', 'e', 'a', 'r', 'v', 'i', 'e', 'w', '\n',
        'r', 'e', 'a', 'r', 'w', 'a', 'r', 'd', '\n',
        'r', 'e', 'a', 's', 'o', 'n', '\n',
        'r', 'e', 'a', 's', 'o', 'n', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'a', 's', 'o', 'n', 'a', 'b', 'l', 'e', 'n', 'e', 's', 's', '\n',
        'r', 'e', 'a', 's', 'o', 'n', 'a', 'b', 'l', 'y', '\n',
        'r', 'e', 'a', 's', 'o', 'n', 'e', 'd', '\n',
        'r', 'e', 'a', 's', 'o', 'n', 'e', 'r', '\n',
        'r', 'e', 'a', 's', 'o', 'n', 'e', 'r', 's', '\n',
        'r', 'e', 'a', 's', 'o', 'n', 'i', 'n', 'g', '\n',
        'r', 'e', 'a', 's', 'o', 'n', 'l', 'e', 's', 's', '\n',
        'r', 'e', 'a', 's', 'o', 'n', 's', '\n',
        'r', 'e', 'a', 's', 's', 'e', 'm', 'b', 'l', 'e', '\n',
        'r', 'e', 'a', 's', 's', 'e', 'm', 'b', 'l', 'e', 'd', '\n',
        'r', 'e', 'a', 's', 's', 'e', 'm', 'b', 'l', 'i', 'n', 'g', '\n',
        'r', 'e', 'a', 's', 's', 'e', 'm', 'b', 'l', 'y', '\n',
        'r', 'e', 'a', 's', 's', 'e', 'r', 't', '\n',
        'r', 'e', 'a', 's', 's', 'e', 'r', 't', 'e', 'd', '\n',
        'r', 'e', 'a', 's', 's', 'e', 'r', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'a', 's', 's', 'e', 'r', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'a', 's', 's', 'e', 'r', 't', 's', '\n',
        'r', 'e', 'a', 's', 's', 'e', 's', 's', '\n',
        'r', 'e', 'a', 's', 's', 'e', 's', 's', 'e', 'd', '\n',
        'r', 'e', 'a', 's', 's', 'e', 's', 's', 'm', 'e', 'n', 't', '\n',
        'r', 'e', 'a', 's', 's', 'e', 's', 's', 'm', 'e', 'n', 't', 's', '\n',
        'r', 'e', 'a', 's', 's', 'i', 'g', 'n', '\n',
        'r', 'e', 'a', 's', 's', 'i', 'g', 'n', 'e', 'd', '\n',
        'r', 'e', 'a', 's', 's', 'i', 'g', 'n', 'i', 'n', 'g', '\n',
        'r', 'e', 'a', 's', 's', 'i', 'g', 'n', 'm', 'e', 'n', 't', '\n',
        'r', 'e', 'a', 's', 's', 'i', 'g', 'n', 's', '\n',
        'r', 'e', 'a', 's', 's', 'u', 'm', 'e', '\n',
        'r', 'e', 'a', 's', 's', 'u', 'm', 'i', 'n', 'g', '\n',
        'r', 'e', 'a', 's', 's', 'u', 'r', 'a', 'n', 'c', 'e', '\n',
        'r', 'e', 'a', 's', 's', 'u', 'r', 'a', 'n', 'c', 'e', 's', '\n',
        'r', 'e', 'a', 's', 's', 'u', 'r', 'e', '\n',
        'r', 'e', 'a', 's', 's', 'u', 'r', 'e', 'd', '\n',
        'r', 'e', 'a', 's', 's', 'u', 'r', 'e', 's', '\n',
        'r', 'e', 'a', 's', 's', 'u', 'r', 'i', 'n', 'g', '\n',
        'r', 'e', 'a', 's', 's', 'u', 'r', 'i', 'n', 'g', 'l', 'y', '\n',
        'r', 'e', 'a', 't', 't', 'a', 'c', 'h', 'm', 'e', 'n', 't', '\n',
        'r', 'e', 'a', 't', 't', 'e', 'm', 'p', 't', '\n',
        'r', 'e', 'a', 'w', 'a', 'k', 'e', 'n', '\n',
        'r', 'e', 'a', 'w', 'a', 'k', 'e', 'n', 'e', 'd', '\n',
        'r', 'e', 'a', 'w', 'a', 'k', 'e', 'n', 'i', 'n', 'g', '\n',
        'r', 'e', 'b', 'a', 'l', 'a', 'n', 'c', 'e', 'd', '\n',
        'r', 'e', 'b', 'a', 't', 'e', '\n',
        'r', 'e', 'b', 'a', 't', 'e', 's', '\n',
        'r', 'e', 'b', 'e', 'l', '\n',
        'r', 'e', 'b', 'e', 'l', 'l', 'e', 'd', '\n',
        'r', 'e', 'b', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'r', 'e', 'b', 'e', 'l', 'l', 'i', 'o', 'n', '\n',
        'r', 'e', 'b', 'e', 'l', 'l', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'b', 'e', 'l', 'l', 'i', 'o', 'u', 's', '\n',
        'r', 'e', 'b', 'e', 'l', 'l', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'r', 'e', 'b', 'e', 'l', 'l', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'r', 'e', 'b', 'e', 'l', 's', '\n',
        'r', 'e', 'b', 'i', 'n', 'd', '\n',
        'r', 'e', 'b', 'i', 'r', 't', 'h', '\n',
        'r', 'e', 'b', 'i', 'r', 't', 'h', 's', '\n',
        'r', 'e', 'b', 'o', 'o', 'k', '\n',
        'r', 'e', 'b', 'o', 'o', 't', '\n',
        'r', 'e', 'b', 'o', 'o', 't', 'e', 'd', '\n',
        'r', 'e', 'b', 'o', 'r', 'n', '\n',
        'r', 'e', 'b', 'o', 'u', 'n', 'd', '\n',
        'r', 'e', 'b', 'o', 'u', 'n', 'd', 'e', 'd', '\n',
        'r', 'e', 'b', 'o', 'u', 'n', 'd', 'i', 'n', 'g', '\n',
        'r', 'e', 'b', 'o', 'u', 'n', 'd', 's', '\n',
        'r', 'e', 'b', 'u', 'f', 'f', '\n',
        'r', 'e', 'b', 'u', 'f', 'f', 'e', 'd', '\n',
        'r', 'e', 'b', 'u', 'f', 'f', 'i', 'n', 'g', '\n',
        'r', 'e', 'b', 'u', 'f', 'f', 's', '\n',
        'r', 'e', 'b', 'u', 'i', 'l', 'd', '\n',
        'r', 'e', 'b', 'u', 'i', 'l', 'd', 'i', 'n', 'g', '\n',
        'r', 'e', 'b', 'u', 'i', 'l', 'd', 's', '\n',
        'r', 'e', 'b', 'u', 'i', 'l', 't', '\n',
        'r', 'e', 'b', 'u', 'k', 'e', '\n',
        'r', 'e', 'b', 'u', 'k', 'e', 'd', '\n',
        'r', 'e', 'b', 'u', 'k', 'e', 's', '\n',
        'r', 'e', 'b', 'u', 'k', 'i', 'n', 'g', '\n',
        'r', 'e', 'b', 'u', 'r', 'i', 'a', 'l', '\n',
        'r', 'e', 'b', 'u', 'r', 'i', 'e', 'd', '\n',
        'r', 'e', 'b', 'u', 'r', 'y', '\n',
        'r', 'e', 'b', 'u', 's', '\n',
        'r', 'e', 'b', 'u', 't', '\n',
        'r', 'e', 'b', 'u', 't', 't', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'b', 'u', 't', 't', 'a', 'l', '\n',
        'r', 'e', 'b', 'u', 't', 't', 'a', 'l', 's', '\n',
        'r', 'e', 'b', 'u', 't', 't', 'e', 'd', '\n',
        'r', 'e', 'b', 'u', 't', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'a', 'l', 'c', 'i', 't', 'r', 'a', 'n', 'c', 'e', '\n',
        'r', 'e', 'c', 'a', 'l', 'c', 'i', 't', 'r', 'a', 'n', 't', '\n',
        'r', 'e', 'c', 'a', 'l', 'c', 'u', 'l', 'a', 't', 'e', '\n',
        'r', 'e', 'c', 'a', 'l', 'c', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 'c', 'a', 'l', 'c', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'c', 'a', 'l', 'i', 'b', 'r', 'a', 't', 'e', '\n',
        'r', 'e', 'c', 'a', 'l', 'i', 'b', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'a', 'l', 'i', 'b', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'c', 'a', 'l', 'l', '\n',
        'r', 'e', 'c', 'a', 'l', 'l', 'e', 'd', '\n',
        'r', 'e', 'c', 'a', 'l', 'l', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'a', 'l', 'l', 's', '\n',
        'r', 'e', 'c', 'a', 'n', 't', '\n',
        'r', 'e', 'c', 'a', 'n', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'c', 'a', 'n', 't', 'e', 'd', '\n',
        'r', 'e', 'c', 'a', 'n', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'a', 'n', 't', 's', '\n',
        'r', 'e', 'c', 'a', 'p', '\n',
        'r', 'e', 'c', 'a', 'p', 'i', 't', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'c', 'a', 'p', 'i', 't', 'u', 'l', 'a', 't', 'e', '\n',
        'r', 'e', 'c', 'a', 'p', 'i', 't', 'u', 'l', 'a', 't', 'e', 's', '\n',
        'r', 'e', 'c', 'a', 'p', 'i', 't', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'c', 'a', 'p', 'p', 'e', 'd', '\n',
        'r', 'e', 'c', 'a', 'p', 's', '\n',
        'r', 'e', 'c', 'a', 'p', 't', 'u', 'r', 'e', '\n',
        'r', 'e', 'c', 'a', 'p', 't', 'u', 'r', 'e', 'd', '\n',
        'r', 'e', 'c', 'a', 'p', 't', 'u', 'r', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'a', 's', 't', '\n',
        'r', 'e', 'c', 'a', 's', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'a', 's', 't', 's', '\n',
        'r', 'e', 'c', 'e', 'd', 'e', '\n',
        'r', 'e', 'c', 'e', 'd', 'e', 'd', '\n',
        'r', 'e', 'c', 'e', 'd', 'e', 's', '\n',
        'r', 'e', 'c', 'e', 'd', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'e', 'i', 'p', 't', '\n',
        'r', 'e', 'c', 'e', 'i', 'p', 't', 'e', 'd', '\n',
        'r', 'e', 'c', 'e', 'i', 'p', 't', 's', '\n',
        'r', 'e', 'c', 'e', 'i', 'v', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'c', 'e', 'i', 'v', 'e', '\n',
        'r', 'e', 'c', 'e', 'i', 'v', 'e', 'd', '\n',
        'r', 'e', 'c', 'e', 'i', 'v', 'e', 'r', '\n',
        'r', 'e', 'c', 'e', 'i', 'v', 'e', 'r', 's', '\n',
        'r', 'e', 'c', 'e', 'i', 'v', 'e', 'r', 's', 'h', 'i', 'p', '\n',
        'r', 'e', 'c', 'e', 'i', 'v', 'e', 's', '\n',
        'r', 'e', 'c', 'e', 'i', 'v', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'e', 'n', 'c', 'y', '\n',
        'r', 'e', 'c', 'e', 'n', 's', 'i', 'o', 'n', '\n',
        'r', 'e', 'c', 'e', 'n', 't', '\n',
        'r', 'e', 'c', 'e', 'n', 't', 'l', 'y', '\n',
        'r', 'e', 'c', 'e', 'p', 't', 'a', 'c', 'l', 'e', '\n',
        'r', 'e', 'c', 'e', 'p', 't', 'a', 'c', 'l', 'e', 's', '\n',
        'r', 'e', 'c', 'e', 'p', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'c', 'e', 'p', 't', 'i', 'o', 'n', 'i', 's', 't', '\n',
        'r', 'e', 'c', 'e', 'p', 't', 'i', 'o', 'n', 'i', 's', 't', 's', '\n',
        'r', 'e', 'c', 'e', 'p', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'c', 'e', 'p', 't', 'i', 'v', 'e', '\n',
        'r', 'e', 'c', 'e', 'p', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'r', 'e', 'c', 'e', 'p', 't', 'i', 'v', 'i', 't', 'y', '\n',
        'r', 'e', 'c', 'e', 'p', 't', 'o', 'r', '\n',
        'r', 'e', 'c', 'e', 'p', 't', 'o', 'r', 's', '\n',
        'r', 'e', 'c', 'e', 's', 's', '\n',
        'r', 'e', 'c', 'e', 's', 's', 'e', 'd', '\n',
        'r', 'e', 'c', 'e', 's', 's', 'e', 's', '\n',
        'r', 'e', 'c', 'e', 's', 's', 'i', 'o', 'n', '\n',
        'r', 'e', 'c', 'e', 's', 's', 'i', 'o', 'n', 'a', 'l', '\n',
        'r', 'e', 'c', 'e', 's', 's', 'i', 'o', 'n', 'a', 'r', 'y', '\n',
        'r', 'e', 'c', 'e', 's', 's', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'c', 'e', 's', 's', 'i', 'v', 'e', '\n',
        'r', 'e', 'c', 'h', 'a', 'r', 'g', 'e', '\n',
        'r', 'e', 'c', 'h', 'a', 'r', 'g', 'e', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'c', 'h', 'a', 'r', 'g', 'e', 'd', '\n',
        'r', 'e', 'c', 'h', 'a', 'r', 'g', 'e', 'r', '\n',
        'r', 'e', 'c', 'h', 'a', 'r', 'g', 'e', 's', '\n',
        'r', 'e', 'c', 'h', 'a', 'r', 'g', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'h', 'e', 'c', 'k', '\n',
        'r', 'e', 'c', 'h', 'e', 'c', 'k', 'e', 'd', '\n',
        'r', 'e', 'c', 'h', 'e', 'c', 'k', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'i', 'd', 'i', 'v', 'i', 's', 'm', '\n',
        'r', 'e', 'c', 'i', 'd', 'i', 'v', 'i', 's', 't', '\n',
        'r', 'e', 'c', 'i', 'd', 'i', 'v', 'i', 's', 't', 's', '\n',
        'r', 'e', 'c', 'i', 'p', 'e', '\n',
        'r', 'e', 'c', 'i', 'p', 'e', 's', '\n',
        'r', 'e', 'c', 'i', 'p', 'i', 'e', 'n', 't', '\n',
        'r', 'e', 'c', 'i', 'p', 'i', 'e', 'n', 't', 's', '\n',
        'r', 'e', 'c', 'i', 'p', 'r', 'o', 'c', 'a', 'l', '\n',
        'r', 'e', 'c', 'i', 'p', 'r', 'o', 'c', 'a', 'l', 'l', 'y', '\n',
        'r', 'e', 'c', 'i', 'p', 'r', 'o', 'c', 'a', 'l', 's', '\n',
        'r', 'e', 'c', 'i', 'p', 'r', 'o', 'c', 'a', 't', 'e', '\n',
        'r', 'e', 'c', 'i', 'p', 'r', 'o', 'c', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 'c', 'i', 'p', 'r', 'o', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'i', 'p', 'r', 'o', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'c', 'i', 'p', 'r', 'o', 'c', 'i', 't', 'y', '\n',
        'r', 'e', 'c', 'i', 'r', 'c', 'u', 'l', 'a', 't', 'e', '\n',
        'r', 'e', 'c', 'i', 'r', 'c', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 'c', 'i', 'r', 'c', 'u', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'i', 'r', 'c', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'c', 'i', 't', 'a', 'l', '\n',
        'r', 'e', 'c', 'i', 't', 'a', 'l', 's', '\n',
        'r', 'e', 'c', 'i', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'c', 'i', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'c', 'i', 't', 'a', 't', 'i', 'v', 'e', '\n',
        'r', 'e', 'c', 'i', 't', 'a', 't', 'i', 'v', 'e', 's', '\n',
        'r', 'e', 'c', 'i', 't', 'e', '\n',
        'r', 'e', 'c', 'i', 't', 'e', 'd', '\n',
        'r', 'e', 'c', 'i', 't', 'e', 's', '\n',
        'r', 'e', 'c', 'i', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'k', 'l', 'e', 's', 's', '\n',
        'r', 'e', 'c', 'k', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'r', 'e', 'c', 'k', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'r', 'e', 'c', 'k', 'o', 'n', '\n',
        'r', 'e', 'c', 'k', 'o', 'n', 'e', 'd', '\n',
        'r', 'e', 'c', 'k', 'o', 'n', 'e', 'r', '\n',
        'r', 'e', 'c', 'k', 'o', 'n', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'k', 'o', 'n', 's', '\n',
        'r', 'e', 'c', 'l', 'a', 'i', 'm', '\n',
        'r', 'e', 'c', 'l', 'a', 'i', 'm', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'c', 'l', 'a', 'i', 'm', 'e', 'd', '\n',
        'r', 'e', 'c', 'l', 'a', 'i', 'm', 'e', 'r', '\n',
        'r', 'e', 'c', 'l', 'a', 'i', 'm', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'l', 'a', 'i', 'm', 's', '\n',
        'r', 'e', 'c', 'l', 'a', 'm', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'c', 'l', 'a', 'm', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'c', 'l', 'a', 's', 's', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'c', 'l', 'a', 's', 's', 'i', 'f', 'i', 'e', 'd', '\n',
        'r', 'e', 'c', 'l', 'a', 's', 's', 'i', 'f', 'i', 'e', 's', '\n',
        'r', 'e', 'c', 'l', 'a', 's', 's', 'i', 'f', 'y', '\n',
        'r', 'e', 'c', 'l', 'a', 's', 's', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'l', 'i', 'n', 'e', '\n',
        'r', 'e', 'c', 'l', 'i', 'n', 'e', 'd', '\n',
        'r', 'e', 'c', 'l', 'i', 'n', 'e', 'r', '\n',
        'r', 'e', 'c', 'l', 'i', 'n', 'e', 's', '\n',
        'r', 'e', 'c', 'l', 'i', 'n', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'l', 'o', 't', 'h', 'e', '\n',
        'r', 'e', 'c', 'l', 'u', 's', 'e', '\n',
        'r', 'e', 'c', 'l', 'u', 's', 'e', 's', '\n',
        'r', 'e', 'c', 'l', 'u', 's', 'i', 'v', 'e', '\n',
        'r', 'e', 'c', 'o', 'd', 'e', '\n',
        'r', 'e', 'c', 'o', 'd', 'e', 'd', '\n',
        'r', 'e', 'c', 'o', 'd', 'e', 's', '\n',
        'r', 'e', 'c', 'o', 'd', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'o', 'g', 'n', 'i', 's', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'c', 'o', 'g', 'n', 'i', 's', 'a', 'b', 'l', 'y', '\n',
        'r', 'e', 'c', 'o', 'g', 'n', 'i', 's', 'a', 'n', 'c', 'e', 's', '\n',
        'r', 'e', 'c', 'o', 'g', 'n', 'i', 's', 'e', '\n',
        'r', 'e', 'c', 'o', 'g', 'n', 'i', 's', 'e', 'd', '\n',
        'r', 'e', 'c', 'o', 'g', 'n', 'i', 's', 'e', 'r', '\n',
        'r', 'e', 'c', 'o', 'g', 'n', 'i', 's', 'e', 'r', 's', '\n',
        'r', 'e', 'c', 'o', 'g', 'n', 'i', 's', 'e', 's', '\n',
        'r', 'e', 'c', 'o', 'g', 'n', 'i', 's', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'o', 'g', 'n', 'i', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'c', 'o', 'g', 'n', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'c', 'o', 'i', 'l', '\n',
        'r', 'e', 'c', 'o', 'i', 'l', 'e', 'd', '\n',
        'r', 'e', 'c', 'o', 'i', 'l', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'o', 'i', 'l', 's', '\n',
        'r', 'e', 'c', 'o', 'l', 'l', 'e', 'c', 't', '\n',
        'r', 'e', 'c', 'o', 'l', 'l', 'e', 'c', 't', 'e', 'd', '\n',
        'r', 'e', 'c', 'o', 'l', 'l', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'o', 'l', 'l', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'c', 'o', 'l', 'l', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'c', 'o', 'l', 'l', 'e', 'c', 't', 's', '\n',
        'r', 'e', 'c', 'o', 'm', 'b', 'i', 'n', 'a', 'n', 't', '\n',
        'r', 'e', 'c', 'o', 'm', 'b', 'i', 'n', 'a', 'n', 't', 's', '\n',
        'r', 'e', 'c', 'o', 'm', 'b', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'c', 'o', 'm', 'b', 'i', 'n', 'e', '\n',
        'r', 'e', 'c', 'o', 'm', 'b', 'i', 'n', 'e', 'd', '\n',
        'r', 'e', 'c', 'o', 'm', 'b', 'i', 'n', 'e', 's', '\n',
        'r', 'e', 'c', 'o', 'm', 'b', 'i', 'n', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'o', 'm', 'm', 'e', 'n', 'c', 'e', '\n',
        'r', 'e', 'c', 'o', 'm', 'm', 'e', 'n', 'c', 'e', 'd', '\n',
        'r', 'e', 'c', 'o', 'm', 'm', 'e', 'n', 'c', 'e', 'm', 'e', 'n', 't', '\n',
        'r', 'e', 'c', 'o', 'm', 'm', 'e', 'n', 'c', 'e', 's', '\n',
        'r', 'e', 'c', 'o', 'm', 'm', 'e', 'n', 'c', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'o', 'm', 'm', 'e', 'n', 'd', '\n',
        'r', 'e', 'c', 'o', 'm', 'm', 'e', 'n', 'd', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'c', 'o', 'm', 'm', 'e', 'n', 'd', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'c', 'o', 'm', 'm', 'e', 'n', 'd', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'c', 'o', 'm', 'm', 'e', 'n', 'd', 'e', 'd', '\n',
        'r', 'e', 'c', 'o', 'm', 'm', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'o', 'm', 'm', 'e', 'n', 'd', 's', '\n',
        'r', 'e', 'c', 'o', 'm', 'm', 'i', 's', 's', 'i', 'o', 'n', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'o', 'm', 'p', 'e', 'n', 's', 'e', '\n',
        'r', 'e', 'c', 'o', 'm', 'p', 'e', 'n', 's', 'e', 'd', '\n',
        'r', 'e', 'c', 'o', 'm', 'p', 'e', 'n', 's', 'e', 's', '\n',
        'r', 'e', 'c', 'o', 'm', 'p', 'i', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'c', 'o', 'm', 'p', 'i', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'c', 'o', 'm', 'p', 'i', 'l', 'e', '\n',
        'r', 'e', 'c', 'o', 'm', 'p', 'i', 'l', 'e', 'd', '\n',
        'r', 'e', 'c', 'o', 'm', 'p', 'i', 'l', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'o', 'm', 'p', 'u', 't', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'c', 'o', 'm', 'p', 'u', 't', 'e', '\n',
        'r', 'e', 'c', 'o', 'm', 'p', 'u', 't', 'e', 'd', '\n',
        'r', 'e', 'c', 'o', 'm', 'p', 'u', 't', 'e', 's', '\n',
        'r', 'e', 'c', 'o', 'm', 'p', 'u', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'o', 'n', 'c', 'i', 'l', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'c', 'o', 'n', 'c', 'i', 'l', 'e', '\n',
        'r', 'e', 'c', 'o', 'n', 'c', 'i', 'l', 'e', 'd', '\n',
        'r', 'e', 'c', 'o', 'n', 'c', 'i', 'l', 'e', 'm', 'e', 'n', 't', '\n',
        'r', 'e', 'c', 'o', 'n', 'c', 'i', 'l', 'e', 's', '\n',
        'r', 'e', 'c', 'o', 'n', 'c', 'i', 'l', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'c', 'o', 'n', 'c', 'i', 'l', 'i', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'c', 'o', 'n', 'c', 'i', 'l', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'o', 'n', 'd', 'i', 't', 'e', '\n',
        'r', 'e', 'c', 'o', 'n', 'd', 'i', 't', 'i', 'o', 'n', 'e', 'd', '\n',
        'r', 'e', 'c', 'o', 'n', 'd', 'i', 't', 'i', 'o', 'n', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'c', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'c', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'c', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'e', '\n',
        'r', 'e', 'c', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'e', 'd', '\n',
        'r', 'e', 'c', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'e', 's', '\n',
        'r', 'e', 'c', 'o', 'n', 'f', 'i', 'g', 'u', 'r', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'o', 'n', 'n', 'a', 'i', 's', 's', 'a', 'n', 'c', 'e', '\n',
        'r', 'e', 'c', 'o', 'n', 'n', 'e', 'c', 't', '\n',
        'r', 'e', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'e', 'd', '\n',
        'r', 'e', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'c', 'o', 'n', 'n', 'o', 'i', 't', 'r', 'e', '\n',
        'r', 'e', 'c', 'o', 'n', 'n', 'o', 'i', 't', 'r', 'e', 'd', '\n',
        'r', 'e', 'c', 'o', 'n', 'n', 'o', 'i', 't', 'r', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'o', 'n', 'q', 'u', 'e', 'r', '\n',
        'r', 'e', 'c', 'o', 'n', 'q', 'u', 'e', 's', 't', '\n',
        'r', 'e', 'c', 'o', 'n', 's', 'i', 'd', 'e', 'r', '\n',
        'r', 'e', 'c', 'o', 'n', 's', 'i', 'd', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'c', 'o', 'n', 's', 'i', 'd', 'e', 'r', 'e', 'd', '\n',
        'r', 'e', 'c', 'o', 'n', 's', 'i', 'd', 'e', 'r', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'o', 'n', 's', 'i', 'd', 'e', 'r', 's', '\n',
        'r', 'e', 'c', 'o', 'n', 's', 't', 'i', 't', 'u', 't', 'e', '\n',
        'r', 'e', 'c', 'o', 'n', 's', 't', 'i', 't', 'u', 't', 'e', 'd', '\n',
        'r', 'e', 'c', 'o', 'n', 's', 't', 'i', 't', 'u', 't', 'e', 's', '\n',
        'r', 'e', 'c', 'o', 'n', 's', 't', 'i', 't', 'u', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'o', 'n', 's', 't', 'i', 't', 'u', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'c', 'o', 'n', 's', 't', 'r', 'u', 'c', 't', '\n',
        'r', 'e', 'c', 'o', 'n', 's', 't', 'r', 'u', 'c', 't', 'e', 'd', '\n',
        'r', 'e', 'c', 'o', 'n', 's', 't', 'r', 'u', 'c', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'o', 'n', 's', 't', 'r', 'u', 'c', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'c', 'o', 'n', 's', 't', 'r', 'u', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'c', 'o', 'n', 's', 't', 'r', 'u', 'c', 't', 's', '\n',
        'r', 'e', 'c', 'o', 'n', 's', 'u', 'l', 't', '\n',
        'r', 'e', 'c', 'o', 'n', 's', 'u', 'l', 't', 'e', 'd', '\n',
        'r', 'e', 'c', 'o', 'n', 's', 'u', 'l', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'o', 'n', 't', 'r', 'i', 'b', 'u', 't', 'e', '\n',
        'r', 'e', 'c', 'o', 'n', 'v', 'e', 'n', 'e', '\n',
        'r', 'e', 'c', 'o', 'n', 'v', 'e', 'n', 'e', 'd', '\n',
        'r', 'e', 'c', 'o', 'n', 'v', 'e', 'n', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'o', 'n', 'v', 'e', 'r', 's', 'i', 'o', 'n', '\n',
        'r', 'e', 'c', 'o', 'n', 'v', 'e', 'r', 't', '\n',
        'r', 'e', 'c', 'o', 'n', 'v', 'e', 'r', 't', 'e', 'd', '\n',
        'r', 'e', 'c', 'o', 'p', 'i', 'e', 'd', '\n',
        'r', 'e', 'c', 'o', 'p', 'y', '\n',
        'r', 'e', 'c', 'o', 'r', 'd', '\n',
        'r', 'e', 'c', 'o', 'r', 'd', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'c', 'o', 'r', 'd', 'b', 'r', 'e', 'a', 'k', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'o', 'r', 'd', 'e', 'd', '\n',
        'r', 'e', 'c', 'o', 'r', 'd', 'e', 'r', '\n',
        'r', 'e', 'c', 'o', 'r', 'd', 'e', 'r', 's', '\n',
        'r', 'e', 'c', 'o', 'r', 'd', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'o', 'r', 'd', 'i', 'n', 'g', 's', '\n',
        'r', 'e', 'c', 'o', 'r', 'd', 'i', 's', 't', '\n',
        'r', 'e', 'c', 'o', 'r', 'd', 'i', 's', 't', 's', '\n',
        'r', 'e', 'c', 'o', 'r', 'd', 's', '\n',
        'r', 'e', 'c', 'o', 'u', 'n', 't', '\n',
        'r', 'e', 'c', 'o', 'u', 'n', 't', 'e', 'd', '\n',
        'r', 'e', 'c', 'o', 'u', 'n', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'o', 'u', 'n', 't', 's', '\n',
        'r', 'e', 'c', 'o', 'u', 'p', '\n',
        'r', 'e', 'c', 'o', 'u', 'p', 'e', 'd', '\n',
        'r', 'e', 'c', 'o', 'u', 'p', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'o', 'u', 'p', 'l', 'e', '\n',
        'r', 'e', 'c', 'o', 'u', 'p', 's', '\n',
        'r', 'e', 'c', 'o', 'u', 'r', 's', 'e', '\n',
        'r', 'e', 'c', 'o', 'v', 'e', 'r', '\n',
        'r', 'e', 'c', 'o', 'v', 'e', 'r', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'r', 'e', 'c', 'o', 'v', 'e', 'r', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'c', 'o', 'v', 'e', 'r', 'e', 'd', '\n',
        'r', 'e', 'c', 'o', 'v', 'e', 'r', 'i', 'e', 's', '\n',
        'r', 'e', 'c', 'o', 'v', 'e', 'r', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'o', 'v', 'e', 'r', 's', '\n',
        'r', 'e', 'c', 'o', 'v', 'e', 'r', 'y', '\n',
        'r', 'e', 'c', 'r', 'e', 'a', 't', 'e', '\n',
        'r', 'e', 'c', 'r', 'e', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 'c', 'r', 'e', 'a', 't', 'e', 's', '\n',
        'r', 'e', 'c', 'r', 'e', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'r', 'e', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'c', 'r', 'e', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'r', 'e', 'c', 'r', 'e', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'c', 'r', 'i', 'm', 'i', 'n', 'a', 't', 'e', '\n',
        'r', 'e', 'c', 'r', 'i', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'c', 'r', 'i', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'c', 'r', 'u', 'i', 't', '\n',
        'r', 'e', 'c', 'r', 'u', 'i', 't', 'e', 'd', '\n',
        'r', 'e', 'c', 'r', 'u', 'i', 't', 'e', 'r', '\n',
        'r', 'e', 'c', 'r', 'u', 'i', 't', 'e', 'r', 's', '\n',
        'r', 'e', 'c', 'r', 'u', 'i', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'r', 'u', 'i', 't', 'm', 'e', 'n', 't', '\n',
        'r', 'e', 'c', 'r', 'u', 'i', 't', 's', '\n',
        'r', 'e', 'c', 'r', 'y', 's', 't', 'a', 'l', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'c', 't', 'a', 'l', '\n',
        'r', 'e', 'c', 't', 'a', 'n', 'g', 'l', 'e', '\n',
        'r', 'e', 'c', 't', 'a', 'n', 'g', 'l', 'e', 's', '\n',
        'r', 'e', 'c', 't', 'a', 'n', 'g', 'u', 'l', 'a', 'r', '\n',
        'r', 'e', 'c', 't', 'i', 'f', 'i', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'c', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'c', 't', 'i', 'f', 'i', 'e', 'd', '\n',
        'r', 'e', 'c', 't', 'i', 'f', 'i', 'e', 'r', '\n',
        'r', 'e', 'c', 't', 'i', 'f', 'i', 'e', 's', '\n',
        'r', 'e', 'c', 't', 'i', 'f', 'y', '\n',
        'r', 'e', 'c', 't', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 't', 'i', 'l', 'i', 'n', 'e', 'a', 'r', '\n',
        'r', 'e', 'c', 't', 'i', 't', 'u', 'd', 'e', '\n',
        'r', 'e', 'c', 't', 'o', '\n',
        'r', 'e', 'c', 't', 'o', 'r', '\n',
        'r', 'e', 'c', 't', 'o', 'r', 's', '\n',
        'r', 'e', 'c', 't', 'o', 'r', 'y', '\n',
        'r', 'e', 'c', 't', 'r', 'i', 'x', '\n',
        'r', 'e', 'c', 't', 'u', 'm', '\n',
        'r', 'e', 'c', 't', 'u', 'm', 's', '\n',
        'r', 'e', 'c', 'u', 'm', 'b', 'e', 'n', 't', '\n',
        'r', 'e', 'c', 'u', 'p', 'e', 'r', 'a', 't', 'e', '\n',
        'r', 'e', 'c', 'u', 'p', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 'c', 'u', 'p', 'e', 'r', 'a', 't', 'e', 's', '\n',
        'r', 'e', 'c', 'u', 'p', 'e', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'u', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'c', 'u', 'p', 'e', 'r', 'a', 't', 'i', 'v', 'e', '\n',
        'r', 'e', 'c', 'u', 'r', '\n',
        'r', 'e', 'c', 'u', 'r', 'e', 'd', '\n',
        'r', 'e', 'c', 'u', 'r', 'e', 's', '\n',
        'r', 'e', 'c', 'u', 'r', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'u', 'r', 'r', 'e', 'd', '\n',
        'r', 'e', 'c', 'u', 'r', 'r', 'e', 'n', 'c', 'e', '\n',
        'r', 'e', 'c', 'u', 'r', 'r', 'e', 'n', 'c', 'e', 's', '\n',
        'r', 'e', 'c', 'u', 'r', 'r', 'e', 'n', 't', '\n',
        'r', 'e', 'c', 'u', 'r', 'r', 'e', 'n', 't', 'l', 'y', '\n',
        'r', 'e', 'c', 'u', 'r', 'r', 'i', 'n', 'g', '\n',
        'r', 'e', 'c', 'u', 'r', 's', '\n',
        'r', 'e', 'c', 'u', 'r', 's', 'i', 'o', 'n', '\n',
        'r', 'e', 'c', 'u', 'r', 's', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'c', 'u', 'r', 's', 'i', 'v', 'e', '\n',
        'r', 'e', 'c', 'u', 'r', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'r', 'e', 'c', 'y', 'c', 'l', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'c', 'y', 'c', 'l', 'e', '\n',
        'r', 'e', 'c', 'y', 'c', 'l', 'e', 'd', '\n',
        'r', 'e', 'c', 'y', 'c', 'l', 'e', 'r', 's', '\n',
        'r', 'e', 'c', 'y', 'c', 'l', 'e', 's', '\n',
        'r', 'e', 'c', 'y', 'c', 'l', 'i', 'n', 'g', '\n',
        'r', 'e', 'd', '\n',
        'r', 'e', 'd', 'a', 'c', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'd', 'b', 'l', 'o', 'o', 'd', 'e', 'd', '\n',
        'r', 'e', 'd', 'b', 'r', 'e', 'a', 's', 't', '\n',
        'r', 'e', 'd', 'c', 'o', 'a', 't', 's', '\n',
        'r', 'e', 'd', 'c', 'r', 'o', 's', 's', '\n',
        'r', 'e', 'd', 'd', 'e', 'n', '\n',
        'r', 'e', 'd', 'd', 'e', 'n', 'e', 'd', '\n',
        'r', 'e', 'd', 'd', 'e', 'n', 'i', 'n', 'g', '\n',
        'r', 'e', 'd', 'd', 'e', 'n', 's', '\n',
        'r', 'e', 'd', 'd', 'e', 'r', '\n',
        'r', 'e', 'd', 'd', 'e', 's', 't', '\n',
        'r', 'e', 'd', 'd', 'i', 's', 'h', '\n',
        'r', 'e', 'd', 'e', 'c', 'l', 'a', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'd', 'e', 'c', 'o', 'r', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 'd', 'e', 'c', 'o', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'd', 'e', 'c', 'o', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'd', 'e', 'd', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'd', 'e', 'e', 'm', '\n',
        'r', 'e', 'd', 'e', 'e', 'm', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'd', 'e', 'e', 'm', 'e', 'd', '\n',
        'r', 'e', 'd', 'e', 'e', 'm', 'e', 'r', '\n',
        'r', 'e', 'd', 'e', 'e', 'm', 'i', 'n', 'g', '\n',
        'r', 'e', 'd', 'e', 'e', 'm', 's', '\n',
        'r', 'e', 'd', 'e', 'f', 'i', 'n', 'e', '\n',
        'r', 'e', 'd', 'e', 'f', 'i', 'n', 'e', 'd', '\n',
        'r', 'e', 'd', 'e', 'f', 'i', 'n', 'e', 'r', '\n',
        'r', 'e', 'd', 'e', 'f', 'i', 'n', 'e', 's', '\n',
        'r', 'e', 'd', 'e', 'f', 'i', 'n', 'i', 'n', 'g', '\n',
        'r', 'e', 'd', 'e', 'f', 'i', 'n', 'i', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'd', 'e', 'f', 'i', 'n', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'd', 'e', 'l', 'i', 'v', 'e', 'r', '\n',
        'r', 'e', 'd', 'e', 'l', 'i', 'v', 'e', 'r', 'y', '\n',
        'r', 'e', 'd', 'e', 'm', 'p', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'd', 'e', 'm', 'p', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'd', 'e', 'm', 'p', 't', 'i', 'v', 'e', '\n',
        'r', 'e', 'd', 'e', 'p', 'l', 'o', 'y', '\n',
        'r', 'e', 'd', 'e', 'p', 'l', 'o', 'y', 'e', 'd', '\n',
        'r', 'e', 'd', 'e', 'p', 'l', 'o', 'y', 'i', 'n', 'g', '\n',
        'r', 'e', 'd', 'e', 'p', 'l', 'o', 'y', 'm', 'e', 'n', 't', '\n',
        'r', 'e', 'd', 'e', 'p', 'o', 's', 'i', 't', 'e', 'd', '\n',
        'r', 'e', 'd', 'e', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'd', 'e', 's', 'i', 'g', 'n', '\n',
        'r', 'e', 'd', 'e', 's', 'i', 'g', 'n', 'e', 'd', '\n',
        'r', 'e', 'd', 'e', 's', 'i', 'g', 'n', 'i', 'n', 'g', '\n',
        'r', 'e', 'd', 'e', 's', 'i', 'g', 'n', 's', '\n',
        'r', 'e', 'd', 'e', 'v', 'e', 'l', 'o', 'p', '\n',
        'r', 'e', 'd', 'e', 'v', 'e', 'l', 'o', 'p', 'e', 'd', '\n',
        'r', 'e', 'd', 'e', 'v', 'e', 'l', 'o', 'p', 'i', 'n', 'g', '\n',
        'r', 'e', 'd', 'e', 'v', 'e', 'l', 'o', 'p', 'm', 'e', 'n', 't', '\n',
        'r', 'e', 'd', 'f', 'a', 'c', 'e', 'd', '\n',
        'r', 'e', 'd', 'h', 'a', 'n', 'd', 'e', 'd', '\n',
        'r', 'e', 'd', 'h', 'e', 'a', 'd', '\n',
        'r', 'e', 'd', 'h', 'e', 'a', 'd', 'e', 'd', '\n',
        'r', 'e', 'd', 'h', 'e', 'a', 'd', 's', '\n',
        'r', 'e', 'd', 'i', 'a', 'l', '\n',
        'r', 'e', 'd', 'i', 'a', 'l', 'l', 'i', 'n', 'g', '\n',
        'r', 'e', 'd', 'i', 'r', 'e', 'c', 't', '\n',
        'r', 'e', 'd', 'i', 'r', 'e', 'c', 't', 'e', 'd', '\n',
        'r', 'e', 'd', 'i', 'r', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'd', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'd', 'i', 'r', 'e', 'c', 't', 's', '\n',
        'r', 'e', 'd', 'i', 's', 'c', 'o', 'v', 'e', 'r', '\n',
        'r', 'e', 'd', 'i', 's', 'c', 'o', 'v', 'e', 'r', 'e', 'd', '\n',
        'r', 'e', 'd', 'i', 's', 'c', 'o', 'v', 'e', 'r', 'i', 'e', 's', '\n',
        'r', 'e', 'd', 'i', 's', 'c', 'o', 'v', 'e', 'r', 'i', 'n', 'g', '\n',
        'r', 'e', 'd', 'i', 's', 'c', 'o', 'v', 'e', 'r', 's', '\n',
        'r', 'e', 'd', 'i', 's', 'c', 'o', 'v', 'e', 'r', 'y', '\n',
        'r', 'e', 'd', 'i', 's', 'c', 'u', 's', 's', 'e', 'd', '\n',
        'r', 'e', 'd', 'i', 's', 'p', 'l', 'a', 'y', '\n',
        'r', 'e', 'd', 'i', 's', 'p', 'l', 'a', 'y', 'e', 'd', '\n',
        'r', 'e', 'd', 'i', 's', 't', 'r', 'i', 'b', 'u', 't', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'd', 'i', 's', 't', 'r', 'i', 'b', 'u', 't', 'e', '\n',
        'r', 'e', 'd', 'i', 's', 't', 'r', 'i', 'b', 'u', 't', 'e', 'd', '\n',
        'r', 'e', 'd', 'i', 's', 't', 'r', 'i', 'b', 'u', 't', 'e', 's', '\n',
        'r', 'e', 'd', 'i', 's', 't', 'r', 'i', 'b', 'u', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'd', 'i', 's', 't', 'r', 'i', 'b', 'u', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'd', 'i', 's', 't', 'r', 'i', 'b', 'u', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'd', 'i', 's', 't', 'r', 'i', 'b', 'u', 't', 'i', 'v', 'e', '\n',
        'r', 'e', 'd', 'n', 'e', 'c', 'k', '\n',
        'r', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'r', 'e', 'd', 'o', '\n',
        'r', 'e', 'd', 'o', 'i', 'n', 'g', '\n',
        'r', 'e', 'd', 'o', 'l', 'e', 'n', 't', '\n',
        'r', 'e', 'd', 'o', 'n', 'e', '\n',
        'r', 'e', 'd', 'o', 'u', 'b', 'l', 'e', '\n',
        'r', 'e', 'd', 'o', 'u', 'b', 'l', 'e', 'd', '\n',
        'r', 'e', 'd', 'o', 'u', 'b', 'l', 'i', 'n', 'g', '\n',
        'r', 'e', 'd', 'o', 'u', 'b', 't', '\n',
        'r', 'e', 'd', 'o', 'u', 'b', 't', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'd', 'o', 'u', 'b', 't', 's', '\n',
        'r', 'e', 'd', 'o', 'u', 'n', 'd', '\n',
        'r', 'e', 'd', 'o', 'u', 'n', 'd', 'e', 'd', '\n',
        'r', 'e', 'd', 'o', 'x', '\n',
        'r', 'e', 'd', 'r', 'a', 'f', 't', '\n',
        'r', 'e', 'd', 'r', 'a', 'f', 't', 'e', 'd', '\n',
        'r', 'e', 'd', 'r', 'a', 'f', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'd', 'r', 'a', 'w', '\n',
        'r', 'e', 'd', 'r', 'a', 'w', 'i', 'n', 'g', '\n',
        'r', 'e', 'd', 'r', 'a', 'w', 'n', '\n',
        'r', 'e', 'd', 'r', 'a', 'w', 's', '\n',
        'r', 'e', 'd', 'r', 'e', 's', 's', '\n',
        'r', 'e', 'd', 'r', 'e', 's', 's', 'e', 'd', '\n',
        'r', 'e', 'd', 'r', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'r', 'e', 'd', 's', '\n',
        'r', 'e', 'd', 's', 'e', 'a', '\n',
        'r', 'e', 'd', 's', 'h', 'i', 'f', 't', '\n',
        'r', 'e', 'd', 's', 'h', 'i', 'f', 't', 's', '\n',
        'r', 'e', 'd', 's', 't', 'a', 'r', 't', 's', '\n',
        'r', 'e', 'd', 't', 'a', 'p', 'e', '\n',
        'r', 'e', 'd', 'u', 'c', 'e', '\n',
        'r', 'e', 'd', 'u', 'c', 'e', 'd', '\n',
        'r', 'e', 'd', 'u', 'c', 'e', 'r', '\n',
        'r', 'e', 'd', 'u', 'c', 'e', 'r', 's', '\n',
        'r', 'e', 'd', 'u', 'c', 'e', 's', '\n',
        'r', 'e', 'd', 'u', 'c', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'r', 'e', 'd', 'u', 'c', 'i', 'b', 'l', 'e', '\n',
        'r', 'e', 'd', 'u', 'c', 'i', 'n', 'g', '\n',
        'r', 'e', 'd', 'u', 'c', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'd', 'u', 'c', 't', 'i', 'o', 'n', 'i', 's', 'm', '\n',
        'r', 'e', 'd', 'u', 'c', 't', 'i', 'o', 'n', 'i', 's', 't', '\n',
        'r', 'e', 'd', 'u', 'c', 't', 'i', 'o', 'n', 'i', 's', 't', 's', '\n',
        'r', 'e', 'd', 'u', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'd', 'u', 'c', 't', 'i', 'v', 'e', '\n',
        'r', 'e', 'd', 'u', 'n', 'd', 'a', 'n', 'c', 'i', 'e', 's', '\n',
        'r', 'e', 'd', 'u', 'n', 'd', 'a', 'n', 'c', 'y', '\n',
        'r', 'e', 'd', 'u', 'n', 'd', 'a', 'n', 't', '\n',
        'r', 'e', 'd', 'u', 'n', 'd', 'a', 'n', 't', 'l', 'y', '\n',
        'r', 'e', 'd', 'w', 'o', 'o', 'd', '\n',
        'r', 'e', 'e', 'd', '\n',
        'r', 'e', 'e', 'd', 's', '\n',
        'r', 'e', 'e', 'f', '\n',
        'r', 'e', 'e', 'f', 'e', 'd', '\n',
        'r', 'e', 'e', 'f', 'i', 'n', 'g', '\n',
        'r', 'e', 'e', 'f', 's', '\n',
        'r', 'e', 'e', 'k', '\n',
        'r', 'e', 'e', 'k', 'e', 'd', '\n',
        'r', 'e', 'e', 'k', 'i', 'n', 'g', '\n',
        'r', 'e', 'e', 'k', 's', '\n',
        'r', 'e', 'e', 'l', '\n',
        'r', 'e', 'e', 'l', 'e', 'c', 't', 's', '\n',
        'r', 'e', 'e', 'l', 'e', 'd', '\n',
        'r', 'e', 'e', 'l', 'i', 'n', 'g', '\n',
        'r', 'e', 'e', 'l', 's', '\n',
        'r', 'e', 'f', '\n',
        'r', 'e', 'f', 'e', 'r', '\n',
        'r', 'e', 'f', 'e', 'r', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'f', 'e', 'r', 'e', 'e', '\n',
        'r', 'e', 'f', 'e', 'r', 'e', 'e', 'd', '\n',
        'r', 'e', 'f', 'e', 'r', 'e', 'e', 'i', 'n', 'g', '\n',
        'r', 'e', 'f', 'e', 'r', 'e', 'e', 's', '\n',
        'r', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'e', '\n',
        'r', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 'd', '\n',
        'r', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 'r', '\n',
        'r', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 's', '\n',
        'r', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'i', 'n', 'g', '\n',
        'r', 'e', 'f', 'e', 'r', 'e', 'n', 'd', 'a', '\n',
        'r', 'e', 'f', 'e', 'r', 'e', 'n', 'd', 'u', 'm', '\n',
        'r', 'e', 'f', 'e', 'r', 'e', 'n', 'd', 'u', 'm', 's', '\n',
        'r', 'e', 'f', 'e', 'r', 'e', 'n', 't', '\n',
        'r', 'e', 'f', 'e', 'r', 'e', 'n', 't', 'i', 'a', 'l', '\n',
        'r', 'e', 'f', 'e', 'r', 'e', 'n', 't', 'i', 'a', 'l', 'l', 'y', '\n',
        'r', 'e', 'f', 'e', 'r', 'e', 'n', 't', 's', '\n',
        'r', 'e', 'f', 'e', 'r', 'r', 'a', 'l', '\n',
        'r', 'e', 'f', 'e', 'r', 'r', 'a', 'l', 's', '\n',
        'r', 'e', 'f', 'e', 'r', 'r', 'e', 'd', '\n',
        'r', 'e', 'f', 'e', 'r', 'r', 'i', 'n', 'g', '\n',
        'r', 'e', 'f', 'e', 'r', 's', '\n',
        'r', 'e', 'f', 'i', 'l', 'e', '\n',
        'r', 'e', 'f', 'i', 'l', 'e', 'd', '\n',
        'r', 'e', 'f', 'i', 'l', 'i', 'n', 'g', '\n',
        'r', 'e', 'f', 'i', 'l', 'l', '\n',
        'r', 'e', 'f', 'i', 'l', 'l', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'f', 'i', 'l', 'l', 'e', 'd', '\n',
        'r', 'e', 'f', 'i', 'l', 'l', 'i', 'n', 'g', '\n',
        'r', 'e', 'f', 'i', 'l', 'l', 'i', 'n', 'g', 's', '\n',
        'r', 'e', 'f', 'i', 'l', 'l', 's', '\n',
        'r', 'e', 'f', 'i', 'n', 'a', 'n', 'c', 'e', '\n',
        'r', 'e', 'f', 'i', 'n', 'a', 'n', 'c', 'e', 'd', '\n',
        'r', 'e', 'f', 'i', 'n', 'a', 'n', 'c', 'i', 'n', 'g', '\n',
        'r', 'e', 'f', 'i', 'n', 'e', '\n',
        'r', 'e', 'f', 'i', 'n', 'e', 'd', '\n',
        'r', 'e', 'f', 'i', 'n', 'e', 'm', 'e', 'n', 't', '\n',
        'r', 'e', 'f', 'i', 'n', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'r', 'e', 'f', 'i', 'n', 'e', 'r', '\n',
        'r', 'e', 'f', 'i', 'n', 'e', 'r', 'i', 'e', 's', '\n',
        'r', 'e', 'f', 'i', 'n', 'e', 'r', 's', '\n',
        'r', 'e', 'f', 'i', 'n', 'e', 'r', 'y', '\n',
        'r', 'e', 'f', 'i', 'n', 'e', 's', '\n',
        'r', 'e', 'f', 'i', 'n', 'i', 'n', 'g', '\n',
        'r', 'e', 'f', 'i', 'n', 'i', 's', 'h', '\n',
        'r', 'e', 'f', 'i', 't', '\n',
        'r', 'e', 'f', 'i', 't', 's', '\n',
        'r', 'e', 'f', 'i', 't', 't', 'e', 'd', '\n',
        'r', 'e', 'f', 'i', 't', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'f', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'f', 'l', 'e', 'c', 't', '\n',
        'r', 'e', 'f', 'l', 'e', 'c', 't', 'a', 'n', 'c', 'e', '\n',
        'r', 'e', 'f', 'l', 'e', 'c', 't', 'e', 'd', '\n',
        'r', 'e', 'f', 'l', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'f', 'l', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'f', 'l', 'e', 'c', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'r', 'e', 'f', 'l', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'f', 'l', 'e', 'c', 't', 'i', 'v', 'e', '\n',
        'r', 'e', 'f', 'l', 'e', 'c', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'r', 'e', 'f', 'l', 'e', 'c', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'r', 'e', 'f', 'l', 'e', 'c', 't', 'i', 'v', 'i', 't', 'y', '\n',
        'r', 'e', 'f', 'l', 'e', 'c', 't', 'o', 'r', '\n',
        'r', 'e', 'f', 'l', 'e', 'c', 't', 'o', 'r', 's', '\n',
        'r', 'e', 'f', 'l', 'e', 'c', 't', 's', '\n',
        'r', 'e', 'f', 'l', 'e', 'x', '\n',
        'r', 'e', 'f', 'l', 'e', 'x', 'e', 's', '\n',
        'r', 'e', 'f', 'l', 'e', 'x', 'i', 'o', 'n', '\n',
        'r', 'e', 'f', 'l', 'e', 'x', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'f', 'l', 'e', 'x', 'i', 'v', 'e', '\n',
        'r', 'e', 'f', 'l', 'e', 'x', 'i', 'v', 'e', 'l', 'y', '\n',
        'r', 'e', 'f', 'l', 'e', 'x', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'r', 'e', 'f', 'l', 'e', 'x', 'i', 'v', 'i', 't', 'y', '\n',
        'r', 'e', 'f', 'l', 'e', 'x', 'o', 'l', 'o', 'g', 'y', '\n',
        'r', 'e', 'f', 'l', 'o', 'a', 't', '\n',
        'r', 'e', 'f', 'l', 'o', 'o', 'r', 'i', 'n', 'g', '\n',
        'r', 'e', 'f', 'l', 'u', 'x', '\n',
        'r', 'e', 'f', 'l', 'u', 'x', 'e', 'd', '\n',
        'r', 'e', 'f', 'l', 'u', 'x', 'i', 'n', 'g', '\n',
        'r', 'e', 'f', 'o', 'c', 'u', 's', '\n',
        'r', 'e', 'f', 'o', 'c', 'u', 's', 'e', 'd', '\n',
        'r', 'e', 'f', 'o', 'c', 'u', 's', 'e', 's', '\n',
        'r', 'e', 'f', 'o', 'c', 'u', 's', 'i', 'n', 'g', '\n',
        'r', 'e', 'f', 'o', 'c', 'u', 's', 's', 'e', 'd', '\n',
        'r', 'e', 'f', 'o', 'c', 'u', 's', 's', 'e', 's', '\n',
        'r', 'e', 'f', 'o', 'c', 'u', 's', 's', 'i', 'n', 'g', '\n',
        'r', 'e', 'f', 'o', 'l', 'd', 'e', 'd', '\n',
        'r', 'e', 'f', 'o', 'l', 'd', 'i', 'n', 'g', '\n',
        'r', 'e', 'f', 'o', 'r', 'e', 's', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'f', 'o', 'r', 'm', '\n',
        'r', 'e', 'f', 'o', 'r', 'm', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'f', 'o', 'r', 'm', 'a', 't', '\n',
        'r', 'e', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'v', 'e', '\n',
        'r', 'e', 'f', 'o', 'r', 'm', 'a', 't', 't', 'e', 'd', '\n',
        'r', 'e', 'f', 'o', 'r', 'm', 'a', 't', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'f', 'o', 'r', 'm', 'e', 'd', '\n',
        'r', 'e', 'f', 'o', 'r', 'm', 'e', 'r', '\n',
        'r', 'e', 'f', 'o', 'r', 'm', 'e', 'r', 's', '\n',
        'r', 'e', 'f', 'o', 'r', 'm', 'i', 'n', 'g', '\n',
        'r', 'e', 'f', 'o', 'r', 'm', 'i', 's', 't', '\n',
        'r', 'e', 'f', 'o', 'r', 'm', 'i', 's', 't', 's', '\n',
        'r', 'e', 'f', 'o', 'r', 'm', 's', '\n',
        'r', 'e', 'f', 'o', 'r', 'm', 'u', 'l', 'a', 't', 'e', '\n',
        'r', 'e', 'f', 'o', 'r', 'm', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 'f', 'o', 'r', 'm', 'u', 'l', 'a', 't', 'e', 's', '\n',
        'r', 'e', 'f', 'o', 'r', 'm', 'u', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'f', 'o', 'r', 'm', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'f', 'o', 'r', 'm', 'u', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'f', 'r', 'a', 'c', 't', '\n',
        'r', 'e', 'f', 'r', 'a', 'c', 't', 'e', 'd', '\n',
        'r', 'e', 'f', 'r', 'a', 'c', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'f', 'r', 'a', 'c', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'f', 'r', 'a', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'f', 'r', 'a', 'c', 't', 'i', 'v', 'e', '\n',
        'r', 'e', 'f', 'r', 'a', 'c', 't', 'o', 'r', 's', '\n',
        'r', 'e', 'f', 'r', 'a', 'c', 't', 'o', 'r', 'y', '\n',
        'r', 'e', 'f', 'r', 'a', 'c', 't', 's', '\n',
        'r', 'e', 'f', 'r', 'a', 'i', 'n', '\n',
        'r', 'e', 'f', 'r', 'a', 'i', 'n', 'e', 'd', '\n',
        'r', 'e', 'f', 'r', 'a', 'i', 'n', 'i', 'n', 'g', '\n',
        'r', 'e', 'f', 'r', 'a', 'i', 'n', 's', '\n',
        'r', 'e', 'f', 'r', 'e', 'e', 'z', 'e', '\n',
        'r', 'e', 'f', 'r', 'e', 's', 'h', '\n',
        'r', 'e', 'f', 'r', 'e', 's', 'h', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'f', 'r', 'e', 's', 'h', 'e', 'd', '\n',
        'r', 'e', 'f', 'r', 'e', 's', 'h', 'e', 'r', '\n',
        'r', 'e', 'f', 'r', 'e', 's', 'h', 'e', 's', '\n',
        'r', 'e', 'f', 'r', 'e', 's', 'h', 'i', 'n', 'g', '\n',
        'r', 'e', 'f', 'r', 'e', 's', 'h', 'i', 'n', 'g', 'l', 'y', '\n',
        'r', 'e', 'f', 'r', 'e', 's', 'h', 'm', 'e', 'n', 't', '\n',
        'r', 'e', 'f', 'r', 'e', 's', 'h', 'm', 'e', 'n', 't', 's', '\n',
        'r', 'e', 'f', 'r', 'i', 'g', 'e', 'r', 'a', 'n', 't', '\n',
        'r', 'e', 'f', 'r', 'i', 'g', 'e', 'r', 'a', 'n', 't', 's', '\n',
        'r', 'e', 'f', 'r', 'i', 'g', 'e', 'r', 'a', 't', 'e', '\n',
        'r', 'e', 'f', 'r', 'i', 'g', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 'f', 'r', 'i', 'g', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'f', 'r', 'i', 'g', 'e', 'r', 'a', 't', 'o', 'r', '\n',
        'r', 'e', 'f', 'r', 'i', 'g', 'e', 'r', 'a', 't', 'o', 'r', 's', '\n',
        'r', 'e', 'f', 's', '\n',
        'r', 'e', 'f', 'u', 'e', 'l', '\n',
        'r', 'e', 'f', 'u', 'e', 'l', 'l', 'e', 'd', '\n',
        'r', 'e', 'f', 'u', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'r', 'e', 'f', 'u', 'e', 'l', 's', '\n',
        'r', 'e', 'f', 'u', 'g', 'e', '\n',
        'r', 'e', 'f', 'u', 'g', 'e', 'e', '\n',
        'r', 'e', 'f', 'u', 'g', 'e', 'e', 's', '\n',
        'r', 'e', 'f', 'u', 'g', 'e', 's', '\n',
        'r', 'e', 'f', 'u', 'n', 'd', '\n',
        'r', 'e', 'f', 'u', 'n', 'd', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'f', 'u', 'n', 'd', 'e', 'd', '\n',
        'r', 'e', 'f', 'u', 'n', 'd', 'i', 'n', 'g', '\n',
        'r', 'e', 'f', 'u', 'n', 'd', 's', '\n',
        'r', 'e', 'f', 'u', 'r', 'b', 'i', 's', 'h', '\n',
        'r', 'e', 'f', 'u', 'r', 'b', 'i', 's', 'h', 'e', 'd', '\n',
        'r', 'e', 'f', 'u', 'r', 'b', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'r', 'e', 'f', 'u', 'r', 'b', 'i', 's', 'h', 'm', 'e', 'n', 't', '\n',
        'r', 'e', 'f', 'u', 'r', 'b', 'i', 's', 'h', 'm', 'e', 'n', 't', 's', '\n',
        'r', 'e', 'f', 'u', 's', 'a', 'l', '\n',
        'r', 'e', 'f', 'u', 's', 'a', 'l', 's', '\n',
        'r', 'e', 'f', 'u', 's', 'e', '\n',
        'r', 'e', 'f', 'u', 's', 'e', 'd', '\n',
        'r', 'e', 'f', 'u', 's', 'e', 'n', 'i', 'k', 's', '\n',
        'r', 'e', 'f', 'u', 's', 'e', 's', '\n',
        'r', 'e', 'f', 'u', 's', 'i', 'n', 'g', '\n',
        'r', 'e', 'f', 'u', 't', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'f', 'u', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'f', 'u', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'f', 'u', 't', 'e', '\n',
        'r', 'e', 'f', 'u', 't', 'e', 'd', '\n',
        'r', 'e', 'f', 'u', 't', 'e', 's', '\n',
        'r', 'e', 'f', 'u', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'g', 'a', 'i', 'n', '\n',
        'r', 'e', 'g', 'a', 'i', 'n', 'e', 'd', '\n',
        'r', 'e', 'g', 'a', 'i', 'n', 'i', 'n', 'g', '\n',
        'r', 'e', 'g', 'a', 'i', 'n', 's', '\n',
        'r', 'e', 'g', 'a', 'l', '\n',
        'r', 'e', 'g', 'a', 'l', 'e', '\n',
        'r', 'e', 'g', 'a', 'l', 'e', 'd', '\n',
        'r', 'e', 'g', 'a', 'l', 'e', 's', '\n',
        'r', 'e', 'g', 'a', 'l', 'i', 'a', '\n',
        'r', 'e', 'g', 'a', 'l', 'i', 'n', 'g', '\n',
        'r', 'e', 'g', 'a', 'l', 'i', 't', 'y', '\n',
        'r', 'e', 'g', 'a', 'l', 'l', 'y', '\n',
        'r', 'e', 'g', 'a', 'r', 'd', '\n',
        'r', 'e', 'g', 'a', 'r', 'd', 'e', 'd', '\n',
        'r', 'e', 'g', 'a', 'r', 'd', 'i', 'n', 'g', '\n',
        'r', 'e', 'g', 'a', 'r', 'd', 'l', 'e', 's', 's', '\n',
        'r', 'e', 'g', 'a', 'r', 'd', 's', '\n',
        'r', 'e', 'g', 'a', 't', 't', 'a', '\n',
        'r', 'e', 'g', 'a', 't', 't', 'a', 's', '\n',
        'r', 'e', 'g', 'e', 'l', 'a', 't', 'e', '\n',
        'r', 'e', 'g', 'e', 'n', 'c', 'y', '\n',
        'r', 'e', 'g', 'e', 'n', 'e', 'r', 'a', 't', 'e', '\n',
        'r', 'e', 'g', 'e', 'n', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 'g', 'e', 'n', 'e', 'r', 'a', 't', 'e', 's', '\n',
        'r', 'e', 'g', 'e', 'n', 'e', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'g', 'e', 'n', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'g', 'e', 'n', 'e', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'g', 'e', 'n', 'e', 'r', 'a', 't', 'i', 'v', 'e', '\n',
        'r', 'e', 'g', 'e', 'n', 't', '\n',
        'r', 'e', 'g', 'e', 'n', 't', 's', '\n',
        'r', 'e', 'g', 'g', 'a', 'e', '\n',
        'r', 'e', 'g', 'i', 'c', 'i', 'd', 'e', '\n',
        'r', 'e', 'g', 'i', 'm', 'e', '\n',
        'r', 'e', 'g', 'i', 'm', 'e', 'n', '\n',
        'r', 'e', 'g', 'i', 'm', 'e', 'n', 's', '\n',
        'r', 'e', 'g', 'i', 'm', 'e', 'n', 't', '\n',
        'r', 'e', 'g', 'i', 'm', 'e', 'n', 't', 'a', 'l', '\n',
        'r', 'e', 'g', 'i', 'm', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'g', 'i', 'm', 'e', 'n', 't', 'e', 'd', '\n',
        'r', 'e', 'g', 'i', 'm', 'e', 'n', 't', 's', '\n',
        'r', 'e', 'g', 'i', 'm', 'e', 's', '\n',
        'r', 'e', 'g', 'i', 'n', 'a', '\n',
        'r', 'e', 'g', 'i', 'n', 'a', 's', '\n',
        'r', 'e', 'g', 'i', 'o', 'n', '\n',
        'r', 'e', 'g', 'i', 'o', 'n', 'a', 'l', '\n',
        'r', 'e', 'g', 'i', 'o', 'n', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'g', 'i', 'o', 'n', 'a', 'l', 'i', 's', 'm', '\n',
        'r', 'e', 'g', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'r', 'e', 'g', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'g', 'i', 's', 't', 'e', 'r', '\n',
        'r', 'e', 'g', 'i', 's', 't', 'e', 'r', 'e', 'd', '\n',
        'r', 'e', 'g', 'i', 's', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'r', 'e', 'g', 'i', 's', 't', 'e', 'r', 's', '\n',
        'r', 'e', 'g', 'i', 's', 't', 'r', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'g', 'i', 's', 't', 'r', 'a', 'r', '\n',
        'r', 'e', 'g', 'i', 's', 't', 'r', 'a', 'r', 's', '\n',
        'r', 'e', 'g', 'i', 's', 't', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'g', 'i', 's', 't', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'g', 'i', 's', 't', 'r', 'i', 'e', 's', '\n',
        'r', 'e', 'g', 'i', 's', 't', 'r', 'y', '\n',
        'r', 'e', 'g', 'r', 'a', 'd', 'i', 'n', 'g', '\n',
        'r', 'e', 'g', 'r', 'e', 's', 's', '\n',
        'r', 'e', 'g', 'r', 'e', 's', 's', 'e', 'd', '\n',
        'r', 'e', 'g', 'r', 'e', 's', 's', 'e', 's', '\n',
        'r', 'e', 'g', 'r', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'r', 'e', 'g', 'r', 'e', 's', 's', 'i', 'o', 'n', '\n',
        'r', 'e', 'g', 'r', 'e', 's', 's', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'g', 'r', 'e', 's', 's', 'i', 'v', 'e', '\n',
        'r', 'e', 'g', 'r', 'e', 't', '\n',
        'r', 'e', 'g', 'r', 'e', 't', 'f', 'u', 'l', '\n',
        'r', 'e', 'g', 'r', 'e', 't', 'f', 'u', 'l', 'l', 'y', '\n',
        'r', 'e', 'g', 'r', 'e', 't', 's', '\n',
        'r', 'e', 'g', 'r', 'e', 't', 't', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'g', 'r', 'e', 't', 't', 'a', 'b', 'l', 'y', '\n',
        'r', 'e', 'g', 'r', 'e', 't', 't', 'e', 'd', '\n',
        'r', 'e', 'g', 'r', 'e', 't', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'g', 'r', 'o', 'u', 'p', '\n',
        'r', 'e', 'g', 'r', 'o', 'u', 'p', 'e', 'd', '\n',
        'r', 'e', 'g', 'r', 'o', 'u', 'p', 'i', 'n', 'g', '\n',
        'r', 'e', 'g', 'r', 'o', 'w', '\n',
        'r', 'e', 'g', 'r', 'o', 'w', 't', 'h', '\n',
        'r', 'e', 'g', 'u', 'l', 'a', 'r', '\n',
        'r', 'e', 'g', 'u', 'l', 'a', 'r', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'g', 'u', 'l', 'a', 'r', 'i', 's', 'e', '\n',
        'r', 'e', 'g', 'u', 'l', 'a', 'r', 'i', 's', 'e', 'd', '\n',
        'r', 'e', 'g', 'u', 'l', 'a', 'r', 'i', 't', 'i', 'e', 's', '\n',
        'r', 'e', 'g', 'u', 'l', 'a', 'r', 'i', 't', 'y', '\n',
        'r', 'e', 'g', 'u', 'l', 'a', 'r', 'l', 'y', '\n',
        'r', 'e', 'g', 'u', 'l', 'a', 'r', 's', '\n',
        'r', 'e', 'g', 'u', 'l', 'a', 't', 'e', '\n',
        'r', 'e', 'g', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 'g', 'u', 'l', 'a', 't', 'e', 's', '\n',
        'r', 'e', 'g', 'u', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'g', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'g', 'u', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'g', 'u', 'l', 'a', 't', 'i', 'v', 'e', '\n',
        'r', 'e', 'g', 'u', 'l', 'a', 't', 'o', 'r', '\n',
        'r', 'e', 'g', 'u', 'l', 'a', 't', 'o', 'r', 's', '\n',
        'r', 'e', 'g', 'u', 'l', 'a', 't', 'o', 'r', 'y', '\n',
        'r', 'e', 'g', 'u', 'r', 'g', 'i', 't', 'a', 't', 'e', '\n',
        'r', 'e', 'g', 'u', 'r', 'g', 'i', 't', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 'g', 'u', 'r', 'g', 'i', 't', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'g', 'u', 'r', 'g', 'i', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'h', 'a', 'b', 'i', 'l', 'i', 't', 'a', 't', 'e', '\n',
        'r', 'e', 'h', 'a', 'b', 'i', 'l', 'i', 't', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 'h', 'a', 'b', 'i', 'l', 'i', 't', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'h', 'a', 'b', 'i', 'l', 'i', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'h', 'a', 's', 'h', '\n',
        'r', 'e', 'h', 'a', 's', 'h', 'e', 'd', '\n',
        'r', 'e', 'h', 'a', 's', 'h', 'e', 's', '\n',
        'r', 'e', 'h', 'a', 's', 'h', 'i', 'n', 'g', '\n',
        'r', 'e', 'h', 'e', 'a', 'r', 'd', '\n',
        'r', 'e', 'h', 'e', 'a', 'r', 'i', 'n', 'g', '\n',
        'r', 'e', 'h', 'e', 'a', 'r', 's', '\n',
        'r', 'e', 'h', 'e', 'a', 'r', 's', 'a', 'l', '\n',
        'r', 'e', 'h', 'e', 'a', 'r', 's', 'a', 'l', 's', '\n',
        'r', 'e', 'h', 'e', 'a', 'r', 's', 'e', '\n',
        'r', 'e', 'h', 'e', 'a', 'r', 's', 'e', 'd', '\n',
        'r', 'e', 'h', 'e', 'a', 'r', 's', 'e', 's', '\n',
        'r', 'e', 'h', 'e', 'a', 'r', 's', 'i', 'n', 'g', '\n',
        'r', 'e', 'h', 'e', 'a', 't', '\n',
        'r', 'e', 'h', 'e', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 'h', 'e', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'h', 'e', 'a', 't', 's', '\n',
        'r', 'e', 'h', 'o', 'u', 's', 'e', '\n',
        'r', 'e', 'h', 'o', 'u', 's', 'e', 'd', '\n',
        'r', 'e', 'h', 'o', 'u', 's', 'i', 'n', 'g', '\n',
        'r', 'e', 'h', 'y', 'd', 'r', 'a', 't', 'e', '\n',
        'r', 'e', 'i', 'c', 'h', '\n',
        'r', 'e', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'i', 'f', 'y', '\n',
        'r', 'e', 'i', 'g', 'n', '\n',
        'r', 'e', 'i', 'g', 'n', 'e', 'd', '\n',
        'r', 'e', 'i', 'g', 'n', 'i', 'n', 'g', '\n',
        'r', 'e', 'i', 'g', 'n', 's', '\n',
        'r', 'e', 'i', 'm', 'b', 'u', 'r', 's', 'e', '\n',
        'r', 'e', 'i', 'm', 'b', 'u', 'r', 's', 'e', 'd', '\n',
        'r', 'e', 'i', 'm', 'b', 'u', 'r', 's', 'e', 'm', 'e', 'n', 't', '\n',
        'r', 'e', 'i', 'm', 'b', 'u', 'r', 's', 'e', 's', '\n',
        'r', 'e', 'i', 'm', 'b', 'u', 'r', 's', 'i', 'n', 'g', '\n',
        'r', 'e', 'i', 'm', 'p', 'l', 'e', 'm', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'i', 'm', 'p', 'l', 'e', 'm', 'e', 'n', 't', 'e', 'd', '\n',
        'r', 'e', 'i', 'm', 'p', 'l', 'e', 'm', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'i', 'm', 'p', 'o', 'r', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'i', 'm', 'p', 'o', 's', 'e', '\n',
        'r', 'e', 'i', 'm', 'p', 'o', 's', 'e', 'd', '\n',
        'r', 'e', 'i', 'n', '\n',
        'r', 'e', 'i', 'n', 'c', 'a', 'r', 'n', 'a', 't', 'e', '\n',
        'r', 'e', 'i', 'n', 'c', 'a', 'r', 'n', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 'i', 'n', 'c', 'a', 'r', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'i', 'n', 'c', 'a', 'r', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'i', 'n', 'c', 'a', 'r', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'i', 'n', 'd', 'e', 'e', 'r', '\n',
        'r', 'e', 'i', 'n', 'e', 'd', '\n',
        'r', 'e', 'i', 'n', 'f', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'i', 'n', 'f', 'o', 'r', 'c', 'e', '\n',
        'r', 'e', 'i', 'n', 'f', 'o', 'r', 'c', 'e', 'd', '\n',
        'r', 'e', 'i', 'n', 'f', 'o', 'r', 'c', 'e', 'm', 'e', 'n', 't', '\n',
        'r', 'e', 'i', 'n', 'f', 'o', 'r', 'c', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'r', 'e', 'i', 'n', 'f', 'o', 'r', 'c', 'e', 's', '\n',
        'r', 'e', 'i', 'n', 'f', 'o', 'r', 'c', 'i', 'n', 'g', '\n',
        'r', 'e', 'i', 'n', 'i', 'n', 'g', '\n',
        'r', 'e', 'i', 'n', 'i', 't', 'i', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'i', 'n', 'i', 't', 'i', 'a', 'l', 'i', 's', 'e', '\n',
        'r', 'e', 'i', 'n', 'i', 't', 'i', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'r', 'e', 'i', 'n', 'i', 't', 'i', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'r', 'e', 'i', 'n', 's', '\n',
        'r', 'e', 'i', 'n', 's', 'e', 'r', 't', '\n',
        'r', 'e', 'i', 'n', 's', 'e', 'r', 't', 'e', 'd', '\n',
        'r', 'e', 'i', 'n', 's', 't', 'a', 'l', 'l', '\n',
        'r', 'e', 'i', 'n', 's', 't', 'a', 'l', 'l', 'e', 'd', '\n',
        'r', 'e', 'i', 'n', 's', 't', 'a', 'l', 'l', 'i', 'n', 'g', '\n',
        'r', 'e', 'i', 'n', 's', 't', 'a', 't', 'e', '\n',
        'r', 'e', 'i', 'n', 's', 't', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 'i', 'n', 's', 't', 'a', 't', 'e', 'm', 'e', 'n', 't', '\n',
        'r', 'e', 'i', 'n', 's', 't', 'a', 't', 'e', 's', '\n',
        'r', 'e', 'i', 'n', 's', 't', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'i', 'n', 's', 'u', 'r', 'a', 'n', 'c', 'e', '\n',
        'r', 'e', 'i', 'n', 't', 'e', 'g', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'i', 'n', 't', 'e', 'r', 'p', 'r', 'e', 't', '\n',
        'r', 'e', 'i', 'n', 't', 'e', 'r', 'p', 'r', 'e', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'i', 'n', 't', 'e', 'r', 'p', 'r', 'e', 't', 'e', 'd', '\n',
        'r', 'e', 'i', 'n', 't', 'e', 'r', 'p', 'r', 'e', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'i', 'n', 't', 'r', 'o', 'd', 'u', 'c', 'e', '\n',
        'r', 'e', 'i', 'n', 't', 'r', 'o', 'd', 'u', 'c', 'e', 'd', '\n',
        'r', 'e', 'i', 'n', 't', 'r', 'o', 'd', 'u', 'c', 'e', 's', '\n',
        'r', 'e', 'i', 'n', 't', 'r', 'o', 'd', 'u', 'c', 'i', 'n', 'g', '\n',
        'r', 'e', 'i', 'n', 't', 'r', 'o', 'd', 'u', 'c', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'i', 'n', 't', 'r', 'o', 'd', 'u', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'i', 'n', 'v', 'e', 'n', 't', '\n',
        'r', 'e', 'i', 'n', 'v', 'e', 'n', 't', 'e', 'd', '\n',
        'r', 'e', 'i', 'n', 'v', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'i', 'n', 'v', 'e', 'n', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'i', 'n', 'v', 'e', 'n', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'i', 'n', 'v', 'e', 'n', 't', 's', '\n',
        'r', 'e', 'i', 'n', 'v', 'e', 's', 't', '\n',
        'r', 'e', 'i', 'n', 'v', 'e', 's', 't', 'e', 'd', '\n',
        'r', 'e', 'i', 'n', 'v', 'e', 's', 't', 'i', 'g', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'i', 'n', 'v', 'e', 's', 't', 'm', 'e', 'n', 't', '\n',
        'r', 'e', 'i', 'n', 'v', 'i', 'g', 'o', 'r', 'a', 't', 'e', '\n',
        'r', 'e', 'i', 'n', 'v', 'i', 'g', 'o', 'r', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 'i', 's', 's', 'u', 'e', '\n',
        'r', 'e', 'i', 's', 's', 'u', 'e', 'd', '\n',
        'r', 'e', 'i', 's', 's', 'u', 'e', 's', '\n',
        'r', 'e', 'i', 's', 's', 'u', 'i', 'n', 'g', '\n',
        'r', 'e', 'i', 't', 'e', 'r', 'a', 't', 'e', '\n',
        'r', 'e', 'i', 't', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 'i', 't', 'e', 'r', 'a', 't', 'e', 's', '\n',
        'r', 'e', 'i', 't', 'e', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'i', 't', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'j', 'e', 'c', 't', '\n',
        'r', 'e', 'j', 'e', 'c', 't', 'e', 'd', '\n',
        'r', 'e', 'j', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'j', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'j', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'j', 'e', 'c', 't', 's', '\n',
        'r', 'e', 'j', 'o', 'i', 'c', 'e', '\n',
        'r', 'e', 'j', 'o', 'i', 'c', 'e', 'd', '\n',
        'r', 'e', 'j', 'o', 'i', 'c', 'e', 's', '\n',
        'r', 'e', 'j', 'o', 'i', 'c', 'i', 'n', 'g', '\n',
        'r', 'e', 'j', 'o', 'i', 'c', 'i', 'n', 'g', 's', '\n',
        'r', 'e', 'j', 'o', 'i', 'n', '\n',
        'r', 'e', 'j', 'o', 'i', 'n', 'd', 'e', 'r', '\n',
        'r', 'e', 'j', 'o', 'i', 'n', 'd', 'e', 'r', 's', '\n',
        'r', 'e', 'j', 'o', 'i', 'n', 'e', 'd', '\n',
        'r', 'e', 'j', 'o', 'i', 'n', 'i', 'n', 'g', '\n',
        'r', 'e', 'j', 'o', 'i', 'n', 's', '\n',
        'r', 'e', 'j', 'u', 's', 't', 'i', 'f', 'i', 'e', 'd', '\n',
        'r', 'e', 'j', 'u', 'v', 'e', 'n', 'a', 't', 'e', '\n',
        'r', 'e', 'j', 'u', 'v', 'e', 'n', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 'j', 'u', 'v', 'e', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'j', 'u', 'v', 'e', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'j', 'u', 'v', 'e', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'j', 'u', 'v', 'e', 'n', 'a', 't', 'o', 'r', 'y', '\n',
        'r', 'e', 'k', 'i', 'n', 'd', 'l', 'e', '\n',
        'r', 'e', 'k', 'i', 'n', 'd', 'l', 'e', 'd', '\n',
        'r', 'e', 'l', 'a', 'b', 'e', 'l', '\n',
        'r', 'e', 'l', 'a', 'b', 'e', 'l', 'l', 'e', 'd', '\n',
        'r', 'e', 'l', 'a', 'b', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'r', 'e', 'l', 'a', 'b', 'e', 'l', 'l', 'i', 'n', 'g', 's', '\n',
        'r', 'e', 'l', 'a', 'i', 'd', '\n',
        'r', 'e', 'l', 'a', 'p', 's', 'e', '\n',
        'r', 'e', 'l', 'a', 'p', 's', 'e', 'd', '\n',
        'r', 'e', 'l', 'a', 'p', 's', 'e', 's', '\n',
        'r', 'e', 'l', 'a', 'p', 's', 'i', 'n', 'g', '\n',
        'r', 'e', 'l', 'a', 't', 'e', '\n',
        'r', 'e', 'l', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 'l', 'a', 't', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'r', 'e', 'l', 'a', 't', 'e', 's', '\n',
        'r', 'e', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'l', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'r', 'e', 'l', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'r', 'e', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'l', 'a', 't', 'i', 'o', 'n', 's', 'h', 'i', 'p', '\n',
        'r', 'e', 'l', 'a', 't', 'i', 'o', 'n', 's', 'h', 'i', 'p', 's', '\n',
        'r', 'e', 'l', 'a', 't', 'i', 'v', 'e', '\n',
        'r', 'e', 'l', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'r', 'e', 'l', 'a', 't', 'i', 'v', 'e', 's', '\n',
        'r', 'e', 'l', 'a', 't', 'i', 'v', 'i', 's', 'm', '\n',
        'r', 'e', 'l', 'a', 't', 'i', 'v', 'i', 's', 't', '\n',
        'r', 'e', 'l', 'a', 't', 'i', 'v', 'i', 's', 't', 'i', 'c', '\n',
        'r', 'e', 'l', 'a', 't', 'i', 'v', 'i', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'r', 'e', 'l', 'a', 't', 'i', 'v', 'i', 's', 't', 's', '\n',
        'r', 'e', 'l', 'a', 't', 'i', 'v', 'i', 't', 'y', '\n',
        'r', 'e', 'l', 'a', 't', 'o', 'r', '\n',
        'r', 'e', 'l', 'a', 'u', 'n', 'c', 'h', '\n',
        'r', 'e', 'l', 'a', 'u', 'n', 'c', 'h', 'e', 'd', '\n',
        'r', 'e', 'l', 'a', 'u', 'n', 'c', 'h', 'i', 'n', 'g', '\n',
        'r', 'e', 'l', 'a', 'x', '\n',
        'r', 'e', 'l', 'a', 'x', 'a', 'n', 't', '\n',
        'r', 'e', 'l', 'a', 'x', 'a', 'n', 't', 's', '\n',
        'r', 'e', 'l', 'a', 'x', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'l', 'a', 'x', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'l', 'a', 'x', 'e', 'd', '\n',
        'r', 'e', 'l', 'a', 'x', 'e', 's', '\n',
        'r', 'e', 'l', 'a', 'x', 'i', 'n', 'g', '\n',
        'r', 'e', 'l', 'a', 'x', 'i', 'n', 'g', 'l', 'y', '\n',
        'r', 'e', 'l', 'a', 'y', '\n',
        'r', 'e', 'l', 'a', 'y', 'e', 'd', '\n',
        'r', 'e', 'l', 'a', 'y', 'i', 'n', 'g', '\n',
        'r', 'e', 'l', 'a', 'y', 's', '\n',
        'r', 'e', 'l', 'e', 'a', 'r', 'n', '\n',
        'r', 'e', 'l', 'e', 'a', 'r', 'n', 'i', 'n', 'g', '\n',
        'r', 'e', 'l', 'e', 'a', 's', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'l', 'e', 'a', 's', 'e', '\n',
        'r', 'e', 'l', 'e', 'a', 's', 'e', 'd', '\n',
        'r', 'e', 'l', 'e', 'a', 's', 'e', 's', '\n',
        'r', 'e', 'l', 'e', 'a', 's', 'i', 'n', 'g', '\n',
        'r', 'e', 'l', 'e', 'g', 'a', 't', 'e', '\n',
        'r', 'e', 'l', 'e', 'g', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 'l', 'e', 'g', 'a', 't', 'e', 's', '\n',
        'r', 'e', 'l', 'e', 'g', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'l', 'e', 'g', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'l', 'e', 'n', 't', '\n',
        'r', 'e', 'l', 'e', 'n', 't', 'e', 'd', '\n',
        'r', 'e', 'l', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'l', 'e', 'n', 't', 'l', 'e', 's', 's', '\n',
        'r', 'e', 'l', 'e', 'n', 't', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'r', 'e', 'l', 'e', 'n', 't', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'r', 'e', 'l', 'e', 'n', 't', 's', '\n',
        'r', 'e', 'l', 'e', 'v', 'a', 'n', 'c', 'e', '\n',
        'r', 'e', 'l', 'e', 'v', 'a', 'n', 'c', 'y', '\n',
        'r', 'e', 'l', 'e', 'v', 'a', 'n', 't', '\n',
        'r', 'e', 'l', 'e', 'v', 'a', 'n', 't', 'l', 'y', '\n',
        'r', 'e', 'l', 'i', 'a', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'r', 'e', 'l', 'i', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'r', 'e', 'l', 'i', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'l', 'i', 'a', 'b', 'l', 'y', '\n',
        'r', 'e', 'l', 'i', 'a', 'n', 'c', 'e', '\n',
        'r', 'e', 'l', 'i', 'a', 'n', 't', '\n',
        'r', 'e', 'l', 'i', 'c', '\n',
        'r', 'e', 'l', 'i', 'c', 's', '\n',
        'r', 'e', 'l', 'i', 'c', 't', '\n',
        'r', 'e', 'l', 'i', 'c', 't', 's', '\n',
        'r', 'e', 'l', 'i', 'e', 'd', '\n',
        'r', 'e', 'l', 'i', 'e', 'f', '\n',
        'r', 'e', 'l', 'i', 'e', 'f', 's', '\n',
        'r', 'e', 'l', 'i', 'e', 's', '\n',
        'r', 'e', 'l', 'i', 'e', 'v', 'e', '\n',
        'r', 'e', 'l', 'i', 'e', 'v', 'e', 'd', '\n',
        'r', 'e', 'l', 'i', 'e', 'v', 'e', 's', '\n',
        'r', 'e', 'l', 'i', 'e', 'v', 'i', 'n', 'g', '\n',
        'r', 'e', 'l', 'i', 'g', 'h', 't', '\n',
        'r', 'e', 'l', 'i', 'g', 'h', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'l', 'i', 'g', 'i', 'o', 'n', '\n',
        'r', 'e', 'l', 'i', 'g', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'l', 'i', 'g', 'i', 'o', 's', 'i', 't', 'y', '\n',
        'r', 'e', 'l', 'i', 'g', 'i', 'o', 'u', 's', '\n',
        'r', 'e', 'l', 'i', 'g', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'r', 'e', 'l', 'i', 'g', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'r', 'e', 'l', 'i', 'n', 'e', 'd', '\n',
        'r', 'e', 'l', 'i', 'n', 'k', '\n',
        'r', 'e', 'l', 'i', 'n', 'k', 'e', 'd', '\n',
        'r', 'e', 'l', 'i', 'n', 'k', 'i', 'n', 'g', '\n',
        'r', 'e', 'l', 'i', 'n', 'q', 'u', 'i', 's', 'h', '\n',
        'r', 'e', 'l', 'i', 'n', 'q', 'u', 'i', 's', 'h', 'e', 'd', '\n',
        'r', 'e', 'l', 'i', 'n', 'q', 'u', 'i', 's', 'h', 'e', 's', '\n',
        'r', 'e', 'l', 'i', 'n', 'q', 'u', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'r', 'e', 'l', 'i', 'q', 'u', 'a', 'r', 'i', 'e', 's', '\n',
        'r', 'e', 'l', 'i', 'q', 'u', 'a', 'r', 'y', '\n',
        'r', 'e', 'l', 'i', 's', 'h', '\n',
        'r', 'e', 'l', 'i', 's', 'h', 'e', 'd', '\n',
        'r', 'e', 'l', 'i', 's', 'h', 'e', 's', '\n',
        'r', 'e', 'l', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'r', 'e', 'l', 'i', 't', '\n',
        'r', 'e', 'l', 'i', 'v', 'e', '\n',
        'r', 'e', 'l', 'i', 'v', 'e', 'd', '\n',
        'r', 'e', 'l', 'i', 'v', 'e', 's', '\n',
        'r', 'e', 'l', 'i', 'v', 'i', 'n', 'g', '\n',
        'r', 'e', 'l', 'o', 'a', 'd', '\n',
        'r', 'e', 'l', 'o', 'a', 'd', 'e', 'd', '\n',
        'r', 'e', 'l', 'o', 'a', 'd', 'i', 'n', 'g', '\n',
        'r', 'e', 'l', 'o', 'a', 'd', 's', '\n',
        'r', 'e', 'l', 'o', 'c', 'a', 't', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'l', 'o', 'c', 'a', 't', 'e', '\n',
        'r', 'e', 'l', 'o', 'c', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 'l', 'o', 'c', 'a', 't', 'e', 's', '\n',
        'r', 'e', 'l', 'o', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'l', 'o', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'l', 'o', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'l', 'o', 'c', 'k', 'e', 'd', '\n',
        'r', 'e', 'l', 'u', 'c', 't', 'a', 'n', 'c', 'e', '\n',
        'r', 'e', 'l', 'u', 'c', 't', 'a', 'n', 't', '\n',
        'r', 'e', 'l', 'u', 'c', 't', 'a', 'n', 't', 'l', 'y', '\n',
        'r', 'e', 'l', 'y', '\n',
        'r', 'e', 'l', 'y', 'i', 'n', 'g', '\n',
        'r', 'e', 'm', '\n',
        'r', 'e', 'm', 'a', 'd', 'e', '\n',
        'r', 'e', 'm', 'a', 'i', 'n', '\n',
        'r', 'e', 'm', 'a', 'i', 'n', 'd', 'e', 'r', '\n',
        'r', 'e', 'm', 'a', 'i', 'n', 'd', 'e', 'r', 'e', 'd', '\n',
        'r', 'e', 'm', 'a', 'i', 'n', 'd', 'e', 'r', 'i', 'n', 'g', '\n',
        'r', 'e', 'm', 'a', 'i', 'n', 'd', 'e', 'r', 's', '\n',
        'r', 'e', 'm', 'a', 'i', 'n', 'e', 'd', '\n',
        'r', 'e', 'm', 'a', 'i', 'n', 'i', 'n', 'g', '\n',
        'r', 'e', 'm', 'a', 'i', 'n', 's', '\n',
        'r', 'e', 'm', 'a', 'k', 'e', '\n',
        'r', 'e', 'm', 'a', 'k', 'e', 's', '\n',
        'r', 'e', 'm', 'a', 'k', 'i', 'n', 'g', '\n',
        'r', 'e', 'm', 'a', 'n', 'd', '\n',
        'r', 'e', 'm', 'a', 'n', 'd', 'e', 'd', '\n',
        'r', 'e', 'm', 'a', 'n', 'd', 's', '\n',
        'r', 'e', 'm', 'a', 'p', '\n',
        'r', 'e', 'm', 'a', 'p', 's', '\n',
        'r', 'e', 'm', 'a', 'r', 'k', '\n',
        'r', 'e', 'm', 'a', 'r', 'k', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'm', 'a', 'r', 'k', 'a', 'b', 'l', 'y', '\n',
        'r', 'e', 'm', 'a', 'r', 'k', 'e', 'd', '\n',
        'r', 'e', 'm', 'a', 'r', 'k', 'i', 'n', 'g', '\n',
        'r', 'e', 'm', 'a', 'r', 'k', 's', '\n',
        'r', 'e', 'm', 'a', 'r', 'r', 'i', 'a', 'g', 'e', '\n',
        'r', 'e', 'm', 'a', 'r', 'r', 'i', 'e', 'd', '\n',
        'r', 'e', 'm', 'a', 'r', 'r', 'y', '\n',
        'r', 'e', 'm', 'a', 's', 't', 'e', 'r', '\n',
        'r', 'e', 'm', 'a', 's', 't', 'e', 'r', 'e', 'd', '\n',
        'r', 'e', 'm', 'a', 's', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'r', 'e', 'm', 'a', 's', 't', 'e', 'r', 's', '\n',
        'r', 'e', 'm', 'a', 't', 'c', 'h', '\n',
        'r', 'e', 'm', 'a', 't', 'c', 'h', 'i', 'n', 'g', '\n',
        'r', 'e', 'm', 'a', 't', 'e', 'r', 'i', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'r', 'e', 'm', 'e', 'd', 'i', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'm', 'e', 'd', 'i', 'a', 'l', '\n',
        'r', 'e', 'm', 'e', 'd', 'i', 'e', 'd', '\n',
        'r', 'e', 'm', 'e', 'd', 'i', 'e', 's', '\n',
        'r', 'e', 'm', 'e', 'd', 'y', '\n',
        'r', 'e', 'm', 'e', 'd', 'y', 'i', 'n', 'g', '\n',
        'r', 'e', 'm', 'e', 'm', 'b', 'e', 'r', '\n',
        'r', 'e', 'm', 'e', 'm', 'b', 'e', 'r', 'e', 'd', '\n',
        'r', 'e', 'm', 'e', 'm', 'b', 'e', 'r', 'i', 'n', 'g', '\n',
        'r', 'e', 'm', 'e', 'm', 'b', 'e', 'r', 's', '\n',
        'r', 'e', 'm', 'e', 'm', 'b', 'r', 'a', 'n', 'c', 'e', '\n',
        'r', 'e', 'm', 'e', 'm', 'b', 'r', 'a', 'n', 'c', 'e', 's', '\n',
        'r', 'e', 'm', 'i', 'n', 'd', '\n',
        'r', 'e', 'm', 'i', 'n', 'd', 'e', 'd', '\n',
        'r', 'e', 'm', 'i', 'n', 'd', 'e', 'r', '\n',
        'r', 'e', 'm', 'i', 'n', 'd', 'e', 'r', 's', '\n',
        'r', 'e', 'm', 'i', 'n', 'd', 'i', 'n', 'g', '\n',
        'r', 'e', 'm', 'i', 'n', 'd', 's', '\n',
        'r', 'e', 'm', 'i', 'n', 'i', 's', 'c', 'e', '\n',
        'r', 'e', 'm', 'i', 'n', 'i', 's', 'c', 'e', 'd', '\n',
        'r', 'e', 'm', 'i', 'n', 'i', 's', 'c', 'e', 'n', 'c', 'e', '\n',
        'r', 'e', 'm', 'i', 'n', 'i', 's', 'c', 'e', 'n', 'c', 'e', 's', '\n',
        'r', 'e', 'm', 'i', 'n', 'i', 's', 'c', 'e', 'n', 't', '\n',
        'r', 'e', 'm', 'i', 'n', 'i', 's', 'c', 'e', 'n', 't', 'l', 'y', '\n',
        'r', 'e', 'm', 'i', 'n', 'i', 's', 'c', 'e', 's', '\n',
        'r', 'e', 'm', 'i', 'n', 'i', 's', 'c', 'i', 'n', 'g', '\n',
        'r', 'e', 'm', 'i', 's', 's', '\n',
        'r', 'e', 'm', 'i', 's', 's', 'i', 'o', 'n', '\n',
        'r', 'e', 'm', 'i', 's', 's', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'm', 'i', 't', '\n',
        'r', 'e', 'm', 'i', 't', 's', '\n',
        'r', 'e', 'm', 'i', 't', 't', 'a', 'l', '\n',
        'r', 'e', 'm', 'i', 't', 't', 'a', 'n', 'c', 'e', '\n',
        'r', 'e', 'm', 'i', 't', 't', 'a', 'n', 'c', 'e', 's', '\n',
        'r', 'e', 'm', 'i', 't', 't', 'e', 'd', '\n',
        'r', 'e', 'm', 'i', 't', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'm', 'i', 'x', '\n',
        'r', 'e', 'm', 'i', 'x', 'e', 'd', '\n',
        'r', 'e', 'm', 'i', 'x', 'e', 's', '\n',
        'r', 'e', 'm', 'n', 'a', 'n', 't', '\n',
        'r', 'e', 'm', 'n', 'a', 'n', 't', 's', '\n',
        'r', 'e', 'm', 'o', 'd', 'e', 'l', '\n',
        'r', 'e', 'm', 'o', 'd', 'e', 'l', 'l', 'e', 'd', '\n',
        'r', 'e', 'm', 'o', 'd', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'r', 'e', 'm', 'o', 'n', 's', 't', 'r', 'a', 'n', 'c', 'e', '\n',
        'r', 'e', 'm', 'o', 'n', 's', 't', 'r', 'a', 't', 'e', '\n',
        'r', 'e', 'm', 'o', 'n', 's', 't', 'r', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 'm', 'o', 'n', 's', 't', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'm', 'o', 'n', 's', 't', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'm', 'o', 'n', 's', 't', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'm', 'o', 'r', 's', 'e', '\n',
        'r', 'e', 'm', 'o', 'r', 's', 'e', 'f', 'u', 'l', '\n',
        'r', 'e', 'm', 'o', 'r', 's', 'e', 'f', 'u', 'l', 'l', 'y', '\n',
        'r', 'e', 'm', 'o', 'r', 's', 'e', 'l', 'e', 's', 's', '\n',
        'r', 'e', 'm', 'o', 'r', 's', 'e', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'r', 'e', 'm', 'o', 't', 'e', '\n',
        'r', 'e', 'm', 'o', 't', 'e', 'l', 'y', '\n',
        'r', 'e', 'm', 'o', 't', 'e', 'n', 'e', 's', 's', '\n',
        'r', 'e', 'm', 'o', 't', 'e', 'r', '\n',
        'r', 'e', 'm', 'o', 't', 'e', 's', 't', '\n',
        'r', 'e', 'm', 'o', 'u', 'l', 'd', '\n',
        'r', 'e', 'm', 'o', 'u', 'n', 't', '\n',
        'r', 'e', 'm', 'o', 'u', 'n', 't', 'e', 'd', '\n',
        'r', 'e', 'm', 'o', 'u', 'n', 't', 's', '\n',
        'r', 'e', 'm', 'o', 'v', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'm', 'o', 'v', 'a', 'l', '\n',
        'r', 'e', 'm', 'o', 'v', 'a', 'l', 's', '\n',
        'r', 'e', 'm', 'o', 'v', 'e', '\n',
        'r', 'e', 'm', 'o', 'v', 'e', 'd', '\n',
        'r', 'e', 'm', 'o', 'v', 'e', 'r', '\n',
        'r', 'e', 'm', 'o', 'v', 'e', 'r', 's', '\n',
        'r', 'e', 'm', 'o', 'v', 'e', 's', '\n',
        'r', 'e', 'm', 'o', 'v', 'i', 'n', 'g', '\n',
        'r', 'e', 'm', 'u', 'n', 'e', 'r', 'a', 't', 'e', '\n',
        'r', 'e', 'm', 'u', 'n', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 'm', 'u', 'n', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'm', 'u', 'n', 'e', 'r', 'a', 't', 'i', 'v', 'e', '\n',
        'r', 'e', 'm', 'u', 's', '\n',
        'r', 'e', 'n', 'a', 'i', 's', 's', 'a', 'n', 'c', 'e', '\n',
        'r', 'e', 'n', 'a', 'l', '\n',
        'r', 'e', 'n', 'a', 'm', 'e', '\n',
        'r', 'e', 'n', 'a', 'm', 'e', 'd', '\n',
        'r', 'e', 'n', 'a', 'm', 'e', 's', '\n',
        'r', 'e', 'n', 'a', 'm', 'i', 'n', 'g', '\n',
        'r', 'e', 'n', 'd', 'e', 'r', '\n',
        'r', 'e', 'n', 'd', 'e', 'r', 'e', 'd', '\n',
        'r', 'e', 'n', 'd', 'e', 'r', 'i', 'n', 'g', '\n',
        'r', 'e', 'n', 'd', 'e', 'r', 'i', 'n', 'g', 's', '\n',
        'r', 'e', 'n', 'd', 'e', 'r', 's', '\n',
        'r', 'e', 'n', 'd', 'e', 'z', 'v', 'o', 'u', 's', '\n',
        'r', 'e', 'n', 'd', 'e', 'z', 'v', 'o', 'u', 's', 'e', 'd', '\n',
        'r', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'r', 'e', 'n', 'd', 'i', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'n', 'd', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'n', 'd', 's', '\n',
        'r', 'e', 'n', 'e', 'g', 'a', 'd', 'e', '\n',
        'r', 'e', 'n', 'e', 'g', 'a', 'd', 'e', 's', '\n',
        'r', 'e', 'n', 'e', 'g', 'e', '\n',
        'r', 'e', 'n', 'e', 'g', 'e', 'd', '\n',
        'r', 'e', 'n', 'e', 'g', 'i', 'n', 'g', '\n',
        'r', 'e', 'n', 'e', 'g', 'o', 't', 'i', 'a', 't', 'e', '\n',
        'r', 'e', 'n', 'e', 'g', 'o', 't', 'i', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 'n', 'e', 'g', 'o', 't', 'i', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'n', 'e', 'g', 'o', 't', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'n', 'e', 'w', '\n',
        'r', 'e', 'n', 'e', 'w', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'n', 'e', 'w', 'a', 'l', '\n',
        'r', 'e', 'n', 'e', 'w', 'a', 'l', 's', '\n',
        'r', 'e', 'n', 'e', 'w', 'e', 'd', '\n',
        'r', 'e', 'n', 'e', 'w', 'i', 'n', 'g', '\n',
        'r', 'e', 'n', 'e', 'w', 's', '\n',
        'r', 'e', 'n', 'o', 'r', 'm', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'n', 'o', 'u', 'n', 'c', 'e', '\n',
        'r', 'e', 'n', 'o', 'u', 'n', 'c', 'e', 'd', '\n',
        'r', 'e', 'n', 'o', 'u', 'n', 'c', 'e', 'm', 'e', 'n', 't', '\n',
        'r', 'e', 'n', 'o', 'u', 'n', 'c', 'e', 's', '\n',
        'r', 'e', 'n', 'o', 'u', 'n', 'c', 'i', 'n', 'g', '\n',
        'r', 'e', 'n', 'o', 'v', 'a', 't', 'e', '\n',
        'r', 'e', 'n', 'o', 'v', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 'n', 'o', 'v', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'n', 'o', 'v', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'n', 'o', 'v', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'n', 'o', 'w', 'n', '\n',
        'r', 'e', 'n', 'o', 'w', 'n', 'e', 'd', '\n',
        'r', 'e', 'n', 't', '\n',
        'r', 'e', 'n', 't', 'a', 'l', '\n',
        'r', 'e', 'n', 't', 'a', 'l', 's', '\n',
        'r', 'e', 'n', 't', 'e', 'd', '\n',
        'r', 'e', 'n', 't', 'e', 'r', '\n',
        'r', 'e', 'n', 't', 'e', 'r', 's', '\n',
        'r', 'e', 'n', 't', 'i', 'e', 'r', 's', '\n',
        'r', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'n', 't', 's', '\n',
        'r', 'e', 'n', 'u', 'm', 'b', 'e', 'r', '\n',
        'r', 'e', 'n', 'u', 'm', 'b', 'e', 'r', 'e', 'd', '\n',
        'r', 'e', 'n', 'u', 'm', 'b', 'e', 'r', 'i', 'n', 'g', '\n',
        'r', 'e', 'n', 'u', 'n', 'c', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'n', 'u', 'n', 'c', 'i', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'o', 'c', 'c', 'u', 'p', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'o', 'c', 'c', 'u', 'p', 'i', 'e', 'd', '\n',
        'r', 'e', 'o', 'c', 'c', 'u', 'p', 'y', '\n',
        'r', 'e', 'o', 'c', 'c', 'u', 'p', 'y', 'i', 'n', 'g', '\n',
        'r', 'e', 'o', 'c', 'c', 'u', 'r', '\n',
        'r', 'e', 'o', 'p', 'e', 'n', '\n',
        'r', 'e', 'o', 'p', 'e', 'n', 'e', 'd', '\n',
        'r', 'e', 'o', 'p', 'e', 'n', 'i', 'n', 'g', '\n',
        'r', 'e', 'o', 'p', 'e', 'n', 's', '\n',
        'r', 'e', 'o', 'r', 'd', 'e', 'r', '\n',
        'r', 'e', 'o', 'r', 'd', 'e', 'r', 'e', 'd', '\n',
        'r', 'e', 'o', 'r', 'd', 'e', 'r', 'i', 'n', 'g', '\n',
        'r', 'e', 'o', 'r', 'd', 'e', 'r', 's', '\n',
        'r', 'e', 'o', 'r', 'g', 'a', 'n', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'o', 'r', 'g', 'a', 'n', 'i', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'o', 'r', 'g', 'a', 'n', 'i', 's', 'e', '\n',
        'r', 'e', 'o', 'r', 'g', 'a', 'n', 'i', 's', 'e', 'd', '\n',
        'r', 'e', 'o', 'r', 'g', 'a', 'n', 'i', 's', 'e', 's', '\n',
        'r', 'e', 'o', 'r', 'g', 'a', 'n', 'i', 's', 'i', 'n', 'g', '\n',
        'r', 'e', 'o', 'r', 'i', 'e', 'n', 't', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 'o', 'r', 'i', 'e', 'n', 't', 'a', 't', 'e', 's', '\n',
        'r', 'e', 'o', 'r', 'i', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'p', '\n',
        'r', 'e', 'p', 'a', 'c', 'k', '\n',
        'r', 'e', 'p', 'a', 'c', 'k', 'a', 'g', 'e', '\n',
        'r', 'e', 'p', 'a', 'c', 'k', 'a', 'g', 'e', 'd', '\n',
        'r', 'e', 'p', 'a', 'c', 'k', 'e', 'd', '\n',
        'r', 'e', 'p', 'a', 'c', 'k', 'i', 'n', 'g', '\n',
        'r', 'e', 'p', 'a', 'i', 'd', '\n',
        'r', 'e', 'p', 'a', 'i', 'n', 't', '\n',
        'r', 'e', 'p', 'a', 'i', 'n', 't', 'e', 'd', '\n',
        'r', 'e', 'p', 'a', 'i', 'n', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'p', 'a', 'i', 'r', '\n',
        'r', 'e', 'p', 'a', 'i', 'r', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'p', 'a', 'i', 'r', 'e', 'd', '\n',
        'r', 'e', 'p', 'a', 'i', 'r', 'e', 'r', '\n',
        'r', 'e', 'p', 'a', 'i', 'r', 'e', 'r', 's', '\n',
        'r', 'e', 'p', 'a', 'i', 'r', 'i', 'n', 'g', '\n',
        'r', 'e', 'p', 'a', 'i', 'r', 'm', 'a', 'n', '\n',
        'r', 'e', 'p', 'a', 'i', 'r', 's', '\n',
        'r', 'e', 'p', 'a', 'p', 'e', 'r', '\n',
        'r', 'e', 'p', 'a', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'p', 'a', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'p', 'a', 'r', 't', 'e', 'e', '\n',
        'r', 'e', 'p', 'a', 'r', 't', 'i', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'p', 'a', 'r', 't', 'i', 't', 'i', 'o', 'n', 'e', 'd', '\n',
        'r', 'e', 'p', 'a', 'r', 't', 'i', 't', 'i', 'o', 'n', 'i', 'n', 'g', '\n',
        'r', 'e', 'p', 'a', 's', 't', '\n',
        'r', 'e', 'p', 'a', 's', 't', 's', '\n',
        'r', 'e', 'p', 'a', 't', 'r', 'i', 'a', 't', 'e', '\n',
        'r', 'e', 'p', 'a', 't', 'r', 'i', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 'p', 'a', 't', 'r', 'i', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'p', 'a', 't', 'r', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'p', 'a', 't', 'r', 'i', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'p', 'a', 'y', '\n',
        'r', 'e', 'p', 'a', 'y', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'p', 'a', 'y', 'i', 'n', 'g', '\n',
        'r', 'e', 'p', 'a', 'y', 'm', 'e', 'n', 't', '\n',
        'r', 'e', 'p', 'a', 'y', 'm', 'e', 'n', 't', 's', '\n',
        'r', 'e', 'p', 'a', 'y', 's', '\n',
        'r', 'e', 'p', 'e', 'a', 'l', '\n',
        'r', 'e', 'p', 'e', 'a', 'l', 'e', 'd', '\n',
        'r', 'e', 'p', 'e', 'a', 'l', 'i', 'n', 'g', '\n',
        'r', 'e', 'p', 'e', 'a', 'l', 's', '\n',
        'r', 'e', 'p', 'e', 'a', 't', '\n',
        'r', 'e', 'p', 'e', 'a', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'r', 'e', 'p', 'e', 'a', 't', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'p', 'e', 'a', 't', 'a', 'b', 'l', 'y', '\n',
        'r', 'e', 'p', 'e', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 'p', 'e', 'a', 't', 'e', 'd', 'l', 'y', '\n',
        'r', 'e', 'p', 'e', 'a', 't', 'e', 'r', '\n',
        'r', 'e', 'p', 'e', 'a', 't', 'e', 'r', 's', '\n',
        'r', 'e', 'p', 'e', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'p', 'e', 'a', 't', 's', '\n',
        'r', 'e', 'p', 'e', 'l', '\n',
        'r', 'e', 'p', 'e', 'l', 'l', 'e', 'd', '\n',
        'r', 'e', 'p', 'e', 'l', 'l', 'e', 'n', 't', '\n',
        'r', 'e', 'p', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'r', 'e', 'p', 'e', 'l', 'l', 'i', 'n', 'g', 'l', 'y', '\n',
        'r', 'e', 'p', 'e', 'l', 's', '\n',
        'r', 'e', 'p', 'e', 'n', 't', '\n',
        'r', 'e', 'p', 'e', 'n', 't', 'a', 'n', 'c', 'e', '\n',
        'r', 'e', 'p', 'e', 'n', 't', 'a', 'n', 't', '\n',
        'r', 'e', 'p', 'e', 'n', 't', 'a', 'n', 't', 'l', 'y', '\n',
        'r', 'e', 'p', 'e', 'n', 't', 'e', 'd', '\n',
        'r', 'e', 'p', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'p', 'e', 'n', 't', 's', '\n',
        'r', 'e', 'p', 'e', 'r', 'c', 'u', 's', 's', 'i', 'o', 'n', '\n',
        'r', 'e', 'p', 'e', 'r', 'c', 'u', 's', 's', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'p', 'e', 'r', 't', 'o', 'i', 'r', 'e', '\n',
        'r', 'e', 'p', 'e', 'r', 't', 'o', 'i', 'r', 'e', 's', '\n',
        'r', 'e', 'p', 'e', 'r', 't', 'o', 'r', 'y', '\n',
        'r', 'e', 'p', 'e', 't', 'i', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'p', 'e', 't', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'p', 'e', 't', 'i', 't', 'i', 'o', 'u', 's', '\n',
        'r', 'e', 'p', 'e', 't', 'i', 't', 'i', 'v', 'e', '\n',
        'r', 'e', 'p', 'e', 't', 'i', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'r', 'e', 'p', 'e', 't', 'i', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'r', 'e', 'p', 'h', 'r', 'a', 's', 'e', '\n',
        'r', 'e', 'p', 'h', 'r', 'a', 's', 'e', 'd', '\n',
        'r', 'e', 'p', 'h', 'r', 'a', 's', 'e', 's', '\n',
        'r', 'e', 'p', 'h', 'r', 'a', 's', 'i', 'n', 'g', '\n',
        'r', 'e', 'p', 'i', 'n', 'e', '\n',
        'r', 'e', 'p', 'i', 'n', 'e', 'd', '\n',
        'r', 'e', 'p', 'i', 'n', 'i', 'n', 'g', '\n',
        'r', 'e', 'p', 'l', 'a', 'c', 'e', '\n',
        'r', 'e', 'p', 'l', 'a', 'c', 'e', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'p', 'l', 'a', 'c', 'e', 'd', '\n',
        'r', 'e', 'p', 'l', 'a', 'c', 'e', 'm', 'e', 'n', 't', '\n',
        'r', 'e', 'p', 'l', 'a', 'c', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'r', 'e', 'p', 'l', 'a', 'c', 'e', 's', '\n',
        'r', 'e', 'p', 'l', 'a', 'c', 'i', 'n', 'g', '\n',
        'r', 'e', 'p', 'l', 'a', 'n', 'n', 'i', 'n', 'g', '\n',
        'r', 'e', 'p', 'l', 'a', 'n', 't', '\n',
        'r', 'e', 'p', 'l', 'a', 'n', 't', 'e', 'd', '\n',
        'r', 'e', 'p', 'l', 'a', 'n', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'p', 'l', 'a', 'y', '\n',
        'r', 'e', 'p', 'l', 'a', 'y', 'e', 'd', '\n',
        'r', 'e', 'p', 'l', 'a', 'y', 'i', 'n', 'g', '\n',
        'r', 'e', 'p', 'l', 'a', 'y', 's', '\n',
        'r', 'e', 'p', 'l', 'e', 'n', 'i', 's', 'h', '\n',
        'r', 'e', 'p', 'l', 'e', 'n', 'i', 's', 'h', 'e', 'd', '\n',
        'r', 'e', 'p', 'l', 'e', 'n', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'r', 'e', 'p', 'l', 'e', 'n', 'i', 's', 'h', 'm', 'e', 'n', 't', '\n',
        'r', 'e', 'p', 'l', 'e', 't', 'e', '\n',
        'r', 'e', 'p', 'l', 'i', 'c', 'a', '\n',
        'r', 'e', 'p', 'l', 'i', 'c', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'p', 'l', 'i', 'c', 'a', 's', '\n',
        'r', 'e', 'p', 'l', 'i', 'c', 'a', 't', 'e', '\n',
        'r', 'e', 'p', 'l', 'i', 'c', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 'p', 'l', 'i', 'c', 'a', 't', 'e', 's', '\n',
        'r', 'e', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'p', 'l', 'i', 'c', 'a', 't', 'o', 'r', '\n',
        'r', 'e', 'p', 'l', 'i', 'c', 'a', 't', 'o', 'r', 's', '\n',
        'r', 'e', 'p', 'l', 'i', 'e', 'd', '\n',
        'r', 'e', 'p', 'l', 'i', 'e', 'r', '\n',
        'r', 'e', 'p', 'l', 'i', 'e', 'r', 's', '\n',
        'r', 'e', 'p', 'l', 'i', 'e', 's', '\n',
        'r', 'e', 'p', 'l', 'o', 't', 't', 'e', 'd', '\n',
        'r', 'e', 'p', 'l', 'u', 'g', '\n',
        'r', 'e', 'p', 'l', 'u', 'g', 'g', 'e', 'd', '\n',
        'r', 'e', 'p', 'l', 'u', 'g', 'g', 'i', 'n', 'g', '\n',
        'r', 'e', 'p', 'l', 'y', '\n',
        'r', 'e', 'p', 'l', 'y', 'i', 'n', 'g', '\n',
        'r', 'e', 'p', 'o', 'p', 'u', 'l', 'a', 't', 'e', '\n',
        'r', 'e', 'p', 'o', 'p', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 'p', 'o', 'r', 't', '\n',
        'r', 'e', 'p', 'o', 'r', 't', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'p', 'o', 'r', 't', 'a', 'g', 'e', '\n',
        'r', 'e', 'p', 'o', 'r', 't', 'e', 'd', '\n',
        'r', 'e', 'p', 'o', 'r', 't', 'e', 'd', 'l', 'y', '\n',
        'r', 'e', 'p', 'o', 'r', 't', 'e', 'r', '\n',
        'r', 'e', 'p', 'o', 'r', 't', 'e', 'r', 's', '\n',
        'r', 'e', 'p', 'o', 'r', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'p', 'o', 'r', 't', 's', '\n',
        'r', 'e', 'p', 'o', 's', 'e', '\n',
        'r', 'e', 'p', 'o', 's', 'e', 'd', '\n',
        'r', 'e', 'p', 'o', 's', 'e', 's', '\n',
        'r', 'e', 'p', 'o', 's', 'i', 'n', 'g', '\n',
        'r', 'e', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'e', 'd', '\n',
        'r', 'e', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 'i', 'n', 'g', '\n',
        'r', 'e', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'p', 'o', 's', 'i', 't', 'o', 'r', 'i', 'e', 's', '\n',
        'r', 'e', 'p', 'o', 's', 'i', 't', 'o', 'r', 'y', '\n',
        'r', 'e', 'p', 'o', 's', 's', 'e', 's', 's', '\n',
        'r', 'e', 'p', 'o', 's', 's', 'e', 's', 's', 'e', 'd', '\n',
        'r', 'e', 'p', 'o', 's', 's', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'r', 'e', 'p', 'o', 's', 's', 'e', 's', 's', 'i', 'o', 'n', '\n',
        'r', 'e', 'p', 'o', 's', 's', 'e', 's', 's', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'p', 'r', 'e', 'h', 'e', 'n', 'd', '\n',
        'r', 'e', 'p', 'r', 'e', 'h', 'e', 'n', 's', 'i', 'b', 'l', 'e', '\n',
        'r', 'e', 'p', 'r', 'e', 's', 'e', 'n', 't', '\n',
        'r', 'e', 'p', 'r', 'e', 's', 'e', 'n', 't', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'p', 'r', 'e', 's', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'p', 'r', 'e', 's', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'r', 'e', 'p', 'r', 'e', 's', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'p', 'r', 'e', 's', 'e', 'n', 't', 'a', 't', 'i', 'v', 'e', '\n',
        'r', 'e', 'p', 'r', 'e', 's', 'e', 'n', 't', 'a', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'r', 'e', 'p', 'r', 'e', 's', 'e', 'n', 't', 'a', 't', 'i', 'v', 'e', 's', '\n',
        'r', 'e', 'p', 'r', 'e', 's', 'e', 'n', 't', 'e', 'd', '\n',
        'r', 'e', 'p', 'r', 'e', 's', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'p', 'r', 'e', 's', 'e', 'n', 't', 's', '\n',
        'r', 'e', 'p', 'r', 'e', 's', 's', '\n',
        'r', 'e', 'p', 'r', 'e', 's', 's', 'e', 'd', '\n',
        'r', 'e', 'p', 'r', 'e', 's', 's', 'e', 's', '\n',
        'r', 'e', 'p', 'r', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'r', 'e', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', '\n',
        'r', 'e', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'p', 'r', 'e', 's', 's', 'i', 'v', 'e', '\n',
        'r', 'e', 'p', 'r', 'e', 's', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'r', 'e', 'p', 'r', 'i', 'e', 'v', 'e', '\n',
        'r', 'e', 'p', 'r', 'i', 'e', 'v', 'e', 'd', '\n',
        'r', 'e', 'p', 'r', 'i', 'm', 'a', 'n', 'd', '\n',
        'r', 'e', 'p', 'r', 'i', 'm', 'a', 'n', 'd', 'e', 'd', '\n',
        'r', 'e', 'p', 'r', 'i', 'm', 'a', 'n', 'd', 'i', 'n', 'g', '\n',
        'r', 'e', 'p', 'r', 'i', 'm', 'a', 'n', 'd', 's', '\n',
        'r', 'e', 'p', 'r', 'i', 'n', 't', '\n',
        'r', 'e', 'p', 'r', 'i', 'n', 't', 'e', 'd', '\n',
        'r', 'e', 'p', 'r', 'i', 'n', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'p', 'r', 'i', 'n', 't', 's', '\n',
        'r', 'e', 'p', 'r', 'i', 's', 'a', 'l', '\n',
        'r', 'e', 'p', 'r', 'i', 's', 'a', 'l', 's', '\n',
        'r', 'e', 'p', 'r', 'i', 's', 'e', '\n',
        'r', 'e', 'p', 'r', 'o', 'a', 'c', 'h', '\n',
        'r', 'e', 'p', 'r', 'o', 'a', 'c', 'h', 'e', 'd', '\n',
        'r', 'e', 'p', 'r', 'o', 'a', 'c', 'h', 'e', 's', '\n',
        'r', 'e', 'p', 'r', 'o', 'a', 'c', 'h', 'f', 'u', 'l', '\n',
        'r', 'e', 'p', 'r', 'o', 'a', 'c', 'h', 'f', 'u', 'l', 'l', 'y', '\n',
        'r', 'e', 'p', 'r', 'o', 'a', 'c', 'h', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'r', 'e', 'p', 'r', 'o', 'a', 'c', 'h', 'i', 'n', 'g', '\n',
        'r', 'e', 'p', 'r', 'o', 'b', 'a', 't', 'e', '\n',
        'r', 'e', 'p', 'r', 'o', 'b', 'a', 't', 'e', 's', '\n',
        'r', 'e', 'p', 'r', 'o', 'c', 'e', 's', 's', '\n',
        'r', 'e', 'p', 'r', 'o', 'c', 'e', 's', 's', 'e', 'd', '\n',
        'r', 'e', 'p', 'r', 'o', 'c', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'r', 'e', 'p', 'r', 'o', 'd', 'u', 'c', 'e', '\n',
        'r', 'e', 'p', 'r', 'o', 'd', 'u', 'c', 'e', 'd', '\n',
        'r', 'e', 'p', 'r', 'o', 'd', 'u', 'c', 'e', 's', '\n',
        'r', 'e', 'p', 'r', 'o', 'd', 'u', 'c', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'r', 'e', 'p', 'r', 'o', 'd', 'u', 'c', 'i', 'b', 'l', 'e', '\n',
        'r', 'e', 'p', 'r', 'o', 'd', 'u', 'c', 'i', 'b', 'l', 'y', '\n',
        'r', 'e', 'p', 'r', 'o', 'd', 'u', 'c', 'i', 'n', 'g', '\n',
        'r', 'e', 'p', 'r', 'o', 'd', 'u', 'c', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'p', 'r', 'o', 'd', 'u', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'p', 'r', 'o', 'd', 'u', 'c', 't', 'i', 'v', 'e', '\n',
        'r', 'e', 'p', 'r', 'o', 'd', 'u', 'c', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'r', 'e', 'p', 'r', 'o', 'g', 'r', 'a', 'm', '\n',
        'r', 'e', 'p', 'r', 'o', 'g', 'r', 'a', 'm', 'm', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'p', 'r', 'o', 'g', 'r', 'a', 'm', 'm', 'e', '\n',
        'r', 'e', 'p', 'r', 'o', 'g', 'r', 'a', 'm', 'm', 'e', 'd', '\n',
        'r', 'e', 'p', 'r', 'o', 'g', 'r', 'a', 'm', 'm', 'i', 'n', 'g', '\n',
        'r', 'e', 'p', 'r', 'o', 'j', 'e', 'c', 't', 'e', 'd', '\n',
        'r', 'e', 'p', 'r', 'o', 'o', 'f', '\n',
        'r', 'e', 'p', 'r', 'o', 'o', 'f', 's', '\n',
        'r', 'e', 'p', 'r', 'o', 'v', 'e', '\n',
        'r', 'e', 'p', 'r', 'o', 'v', 'e', 'd', '\n',
        'r', 'e', 'p', 'r', 'o', 'v', 'i', 'n', 'g', 'l', 'y', '\n',
        'r', 'e', 'p', 's', '\n',
        'r', 'e', 'p', 't', 'i', 'l', 'e', '\n',
        'r', 'e', 'p', 't', 'i', 'l', 'e', 's', '\n',
        'r', 'e', 'p', 't', 'i', 'l', 'i', 'a', 'n', '\n',
        'r', 'e', 'p', 't', 'i', 'l', 'i', 'a', 'n', 's', '\n',
        'r', 'e', 'p', 'u', 'b', 'l', 'i', 'c', '\n',
        'r', 'e', 'p', 'u', 'b', 'l', 'i', 'c', 'a', 'n', '\n',
        'r', 'e', 'p', 'u', 'b', 'l', 'i', 'c', 'a', 'n', 'i', 's', 'm', '\n',
        'r', 'e', 'p', 'u', 'b', 'l', 'i', 'c', 'a', 'n', 's', '\n',
        'r', 'e', 'p', 'u', 'b', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'p', 'u', 'b', 'l', 'i', 'c', 's', '\n',
        'r', 'e', 'p', 'u', 'b', 'l', 'i', 's', 'h', '\n',
        'r', 'e', 'p', 'u', 'b', 'l', 'i', 's', 'h', 'e', 'd', '\n',
        'r', 'e', 'p', 'u', 'b', 'l', 'i', 's', 'h', 'e', 's', '\n',
        'r', 'e', 'p', 'u', 'b', 'l', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'r', 'e', 'p', 'u', 'd', 'i', 'a', 't', 'e', '\n',
        'r', 'e', 'p', 'u', 'd', 'i', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 'p', 'u', 'd', 'i', 'a', 't', 'e', 's', '\n',
        'r', 'e', 'p', 'u', 'd', 'i', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'p', 'u', 'd', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'p', 'u', 'g', 'n', 'a', 'n', 'c', 'e', '\n',
        'r', 'e', 'p', 'u', 'g', 'n', 'a', 'n', 't', '\n',
        'r', 'e', 'p', 'u', 'l', 's', 'e', '\n',
        'r', 'e', 'p', 'u', 'l', 's', 'e', 'd', '\n',
        'r', 'e', 'p', 'u', 'l', 's', 'i', 'n', 'g', '\n',
        'r', 'e', 'p', 'u', 'l', 's', 'i', 'o', 'n', '\n',
        'r', 'e', 'p', 'u', 'l', 's', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'p', 'u', 'l', 's', 'i', 'v', 'e', '\n',
        'r', 'e', 'p', 'u', 'l', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'r', 'e', 'p', 'u', 'l', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'r', 'e', 'p', 'u', 'r', 'c', 'h', 'a', 's', 'e', '\n',
        'r', 'e', 'p', 'u', 't', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'p', 'u', 't', 'a', 'b', 'l', 'y', '\n',
        'r', 'e', 'p', 'u', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'p', 'u', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'p', 'u', 't', 'e', '\n',
        'r', 'e', 'p', 'u', 't', 'e', 'd', '\n',
        'r', 'e', 'p', 'u', 't', 'e', 'd', 'l', 'y', '\n',
        'r', 'e', 'p', 'u', 't', 'e', 's', '\n',
        'r', 'e', 'q', 'u', 'e', 's', 't', '\n',
        'r', 'e', 'q', 'u', 'e', 's', 't', 'e', 'd', '\n',
        'r', 'e', 'q', 'u', 'e', 's', 't', 'e', 'r', '\n',
        'r', 'e', 'q', 'u', 'e', 's', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'q', 'u', 'e', 's', 't', 's', '\n',
        'r', 'e', 'q', 'u', 'i', 'e', 'm', '\n',
        'r', 'e', 'q', 'u', 'i', 'e', 'm', 's', '\n',
        'r', 'e', 'q', 'u', 'i', 'r', 'e', '\n',
        'r', 'e', 'q', 'u', 'i', 'r', 'e', 'd', '\n',
        'r', 'e', 'q', 'u', 'i', 'r', 'e', 'm', 'e', 'n', 't', '\n',
        'r', 'e', 'q', 'u', 'i', 'r', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'r', 'e', 'q', 'u', 'i', 'r', 'e', 's', '\n',
        'r', 'e', 'q', 'u', 'i', 'r', 'i', 'n', 'g', '\n',
        'r', 'e', 'q', 'u', 'i', 's', 'i', 't', 'e', '\n',
        'r', 'e', 'q', 'u', 'i', 's', 'i', 't', 'e', 's', '\n',
        'r', 'e', 'q', 'u', 'i', 's', 'i', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'q', 'u', 'i', 's', 'i', 't', 'i', 'o', 'n', 'e', 'd', '\n',
        'r', 'e', 'q', 'u', 'i', 's', 'i', 't', 'i', 'o', 'n', 'i', 'n', 'g', '\n',
        'r', 'e', 'q', 'u', 'i', 's', 'i', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'q', 'u', 'i', 't', 'a', 'l', '\n',
        'r', 'e', 'q', 'u', 'i', 't', 'e', '\n',
        'r', 'e', 'q', 'u', 'i', 't', 'e', 'd', '\n',
        'r', 'e', 'r', 'a', 'n', '\n',
        'r', 'e', 'r', 'e', 'a', 'd', '\n',
        'r', 'e', 'r', 'e', 'a', 'd', 'i', 'n', 'g', '\n',
        'r', 'e', 'r', 'e', 'a', 'd', 's', '\n',
        'r', 'e', 'r', 'e', 'g', 'i', 's', 't', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'r', 'o', 'l', 'l', 'e', 'd', '\n',
        'r', 'e', 'r', 'o', 'u', 't', 'e', '\n',
        'r', 'e', 'r', 'o', 'u', 't', 'e', 'd', '\n',
        'r', 'e', 'r', 'o', 'u', 't', 'e', 'i', 'n', 'g', '\n',
        'r', 'e', 'r', 'o', 'u', 't', 'e', 's', '\n',
        'r', 'e', 'r', 'o', 'u', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'r', 'u', 'n', '\n',
        'r', 'e', 'r', 'u', 'n', 'n', 'i', 'n', 'g', '\n',
        'r', 'e', 'r', 'u', 'n', 's', '\n',
        'r', 'e', 's', 'a', 'l', 'e', '\n',
        'r', 'e', 's', 'c', 'a', 'l', 'e', '\n',
        'r', 'e', 's', 'c', 'a', 'l', 'e', 'd', '\n',
        'r', 'e', 's', 'c', 'a', 'l', 'e', 's', '\n',
        'r', 'e', 's', 'c', 'a', 'l', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 'c', 'a', 'n', '\n',
        'r', 'e', 's', 'c', 'a', 'n', 'n', 'e', 'd', '\n',
        'r', 'e', 's', 'c', 'a', 'n', 'n', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 'c', 'a', 'n', 's', '\n',
        'r', 'e', 's', 'c', 'h', 'e', 'd', 'u', 'l', 'e', '\n',
        'r', 'e', 's', 'c', 'h', 'e', 'd', 'u', 'l', 'e', 'd', '\n',
        'r', 'e', 's', 'c', 'h', 'e', 'd', 'u', 'l', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 'c', 'i', 'n', 'd', '\n',
        'r', 'e', 's', 'c', 'i', 'n', 'd', 'e', 'd', '\n',
        'r', 'e', 's', 'c', 'i', 'n', 'd', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 'c', 'u', 'e', '\n',
        'r', 'e', 's', 'c', 'u', 'e', 'd', '\n',
        'r', 'e', 's', 'c', 'u', 'e', 'r', '\n',
        'r', 'e', 's', 'c', 'u', 'e', 'r', 's', '\n',
        'r', 'e', 's', 'c', 'u', 'e', 's', '\n',
        'r', 'e', 's', 'c', 'u', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 'e', 'a', '\n',
        'r', 'e', 's', 'e', 'a', 'l', 'e', 'd', '\n',
        'r', 'e', 's', 'e', 'a', 'r', 'c', 'h', '\n',
        'r', 'e', 's', 'e', 'a', 'r', 'c', 'h', 'e', 'd', '\n',
        'r', 'e', 's', 'e', 'a', 'r', 'c', 'h', 'e', 'r', '\n',
        'r', 'e', 's', 'e', 'a', 'r', 'c', 'h', 'e', 'r', 's', '\n',
        'r', 'e', 's', 'e', 'a', 'r', 'c', 'h', 'e', 's', '\n',
        'r', 'e', 's', 'e', 'a', 'r', 'c', 'h', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 'e', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 's', 'e', 'e', 'd', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 'e', 'l', 'e', 'c', 't', '\n',
        'r', 'e', 's', 'e', 'l', 'e', 'c', 't', 'e', 'd', '\n',
        'r', 'e', 's', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 's', 'e', 'l', 'l', '\n',
        'r', 'e', 's', 'e', 'l', 'l', 'e', 'r', '\n',
        'r', 'e', 's', 'e', 'l', 'l', 'e', 'r', 's', '\n',
        'r', 'e', 's', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 'e', 'm', 'b', 'l', 'a', 'n', 'c', 'e', '\n',
        'r', 'e', 's', 'e', 'm', 'b', 'l', 'a', 'n', 'c', 'e', 's', '\n',
        'r', 'e', 's', 'e', 'm', 'b', 'l', 'e', '\n',
        'r', 'e', 's', 'e', 'm', 'b', 'l', 'e', 'd', '\n',
        'r', 'e', 's', 'e', 'm', 'b', 'l', 'e', 's', '\n',
        'r', 'e', 's', 'e', 'm', 'b', 'l', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 'e', 'n', 'd', '\n',
        'r', 'e', 's', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 'e', 'n', 't', '\n',
        'r', 'e', 's', 'e', 'n', 't', 'e', 'd', '\n',
        'r', 'e', 's', 'e', 'n', 't', 'f', 'u', 'l', '\n',
        'r', 'e', 's', 'e', 'n', 't', 'f', 'u', 'l', 'l', 'y', '\n',
        'r', 'e', 's', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 'e', 'n', 't', 'm', 'e', 'n', 't', '\n',
        'r', 'e', 's', 'e', 'n', 't', 'm', 'e', 'n', 't', 's', '\n',
        'r', 'e', 's', 'e', 'n', 't', 's', '\n',
        'r', 'e', 's', 'e', 'r', 'v', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 's', 'e', 'r', 'v', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 's', 'e', 'r', 'v', 'e', '\n',
        'r', 'e', 's', 'e', 'r', 'v', 'e', 'd', '\n',
        'r', 'e', 's', 'e', 'r', 'v', 'e', 'r', '\n',
        'r', 'e', 's', 'e', 'r', 'v', 'e', 's', '\n',
        'r', 'e', 's', 'e', 'r', 'v', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 'e', 'r', 'v', 'i', 's', 't', 's', '\n',
        'r', 'e', 's', 'e', 'r', 'v', 'o', 'i', 'r', '\n',
        'r', 'e', 's', 'e', 'r', 'v', 'o', 'i', 'r', 's', '\n',
        'r', 'e', 's', 'e', 't', '\n',
        'r', 'e', 's', 'e', 't', 's', '\n',
        'r', 'e', 's', 'e', 't', 't', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 's', 'e', 't', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 'e', 't', 't', 'l', 'e', '\n',
        'r', 'e', 's', 'e', 't', 't', 'l', 'e', 'd', '\n',
        'r', 'e', 's', 'e', 't', 't', 'l', 'e', 'm', 'e', 'n', 't', '\n',
        'r', 'e', 's', 'e', 't', 't', 'l', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 'h', 'a', 'p', 'e', '\n',
        'r', 'e', 's', 'h', 'a', 'p', 'e', 'd', '\n',
        'r', 'e', 's', 'h', 'a', 'p', 'e', 's', '\n',
        'r', 'e', 's', 'h', 'a', 'p', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 'h', 'a', 'r', 'p', 'e', 'n', '\n',
        'r', 'e', 's', 'h', 'a', 'r', 'p', 'e', 'n', 'e', 'd', '\n',
        'r', 'e', 's', 'h', 'a', 'r', 'p', 'e', 'n', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 'h', 'o', 'w', '\n',
        'r', 'e', 's', 'h', 'o', 'w', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 'h', 'u', 'f', 'f', 'l', 'e', '\n',
        'r', 'e', 's', 'h', 'u', 'f', 'f', 'l', 'e', 'd', '\n',
        'r', 'e', 's', 'h', 'u', 'f', 'f', 'l', 'e', 's', '\n',
        'r', 'e', 's', 'h', 'u', 'f', 'f', 'l', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 'i', 'd', 'e', '\n',
        'r', 'e', 's', 'i', 'd', 'e', 'd', '\n',
        'r', 'e', 's', 'i', 'd', 'e', 'n', 'c', 'e', '\n',
        'r', 'e', 's', 'i', 'd', 'e', 'n', 'c', 'e', 's', '\n',
        'r', 'e', 's', 'i', 'd', 'e', 'n', 'c', 'y', '\n',
        'r', 'e', 's', 'i', 'd', 'e', 'n', 't', '\n',
        'r', 'e', 's', 'i', 'd', 'e', 'n', 't', 'i', 'a', 'l', '\n',
        'r', 'e', 's', 'i', 'd', 'e', 'n', 't', 's', '\n',
        'r', 'e', 's', 'i', 'd', 'e', 's', '\n',
        'r', 'e', 's', 'i', 'd', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 'i', 'd', 'u', 'a', 'l', '\n',
        'r', 'e', 's', 'i', 'd', 'u', 'a', 'l', 's', '\n',
        'r', 'e', 's', 'i', 'd', 'u', 'a', 'r', 'y', '\n',
        'r', 'e', 's', 'i', 'd', 'u', 'e', '\n',
        'r', 'e', 's', 'i', 'd', 'u', 'e', 's', '\n',
        'r', 'e', 's', 'i', 'd', 'u', 'u', 'm', '\n',
        'r', 'e', 's', 'i', 'g', 'n', '\n',
        'r', 'e', 's', 'i', 'g', 'n', 'a', 'l', '\n',
        'r', 'e', 's', 'i', 'g', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 's', 'i', 'g', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 's', 'i', 'g', 'n', 'e', 'd', '\n',
        'r', 'e', 's', 'i', 'g', 'n', 'e', 'd', 'l', 'y', '\n',
        'r', 'e', 's', 'i', 'g', 'n', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 'i', 'g', 'n', 's', '\n',
        'r', 'e', 's', 'i', 'l', 'i', 'e', 'n', 'c', 'e', '\n',
        'r', 'e', 's', 'i', 'l', 'i', 'e', 'n', 't', '\n',
        'r', 'e', 's', 'i', 'n', '\n',
        'r', 'e', 's', 'i', 'n', 'o', 'u', 's', '\n',
        'r', 'e', 's', 'i', 'n', 's', '\n',
        'r', 'e', 's', 'i', 'n', 'y', '\n',
        'r', 'e', 's', 'i', 's', 't', '\n',
        'r', 'e', 's', 'i', 's', 't', 'a', 'n', 'c', 'e', '\n',
        'r', 'e', 's', 'i', 's', 't', 'a', 'n', 'c', 'e', 's', '\n',
        'r', 'e', 's', 'i', 's', 't', 'a', 'n', 't', '\n',
        'r', 'e', 's', 'i', 's', 't', 'e', 'd', '\n',
        'r', 'e', 's', 'i', 's', 't', 'i', 'b', 'l', 'e', '\n',
        'r', 'e', 's', 'i', 's', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 'i', 's', 't', 'i', 'v', 'e', '\n',
        'r', 'e', 's', 'i', 's', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'r', 'e', 's', 'i', 's', 't', 'i', 'v', 'i', 't', 'y', '\n',
        'r', 'e', 's', 'i', 's', 't', 'o', 'r', '\n',
        'r', 'e', 's', 'i', 's', 't', 'o', 'r', 's', '\n',
        'r', 'e', 's', 'i', 's', 't', 's', '\n',
        'r', 'e', 's', 'i', 't', '\n',
        'r', 'e', 's', 'i', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 'i', 't', 's', '\n',
        'r', 'e', 's', 'i', 'z', 'e', '\n',
        'r', 'e', 's', 'i', 'z', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 'o', 'l', 'd', '\n',
        'r', 'e', 's', 'o', 'l', 'u', 't', 'e', '\n',
        'r', 'e', 's', 'o', 'l', 'u', 't', 'e', 'l', 'y', '\n',
        'r', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 's', 'o', 'l', 'u', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 's', 'o', 'l', 'v', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'r', 'e', 's', 'o', 'l', 'v', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 's', 'o', 'l', 'v', 'e', '\n',
        'r', 'e', 's', 'o', 'l', 'v', 'e', 'd', '\n',
        'r', 'e', 's', 'o', 'l', 'v', 'e', 'n', 't', '\n',
        'r', 'e', 's', 'o', 'l', 'v', 'e', 'r', '\n',
        'r', 'e', 's', 'o', 'l', 'v', 'e', 'r', 's', '\n',
        'r', 'e', 's', 'o', 'l', 'v', 'e', 's', '\n',
        'r', 'e', 's', 'o', 'l', 'v', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 'o', 'n', 'a', 'n', 'c', 'e', '\n',
        'r', 'e', 's', 'o', 'n', 'a', 'n', 'c', 'e', 's', '\n',
        'r', 'e', 's', 'o', 'n', 'a', 'n', 't', '\n',
        'r', 'e', 's', 'o', 'n', 'a', 'n', 't', 'l', 'y', '\n',
        'r', 'e', 's', 'o', 'n', 'a', 't', 'e', '\n',
        'r', 'e', 's', 'o', 'n', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 's', 'o', 'n', 'a', 't', 'e', 's', '\n',
        'r', 'e', 's', 'o', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 'o', 'n', 'a', 't', 'o', 'r', '\n',
        'r', 'e', 's', 'o', 'n', 'a', 't', 'o', 'r', 's', '\n',
        'r', 'e', 's', 'o', 'r', 't', '\n',
        'r', 'e', 's', 'o', 'r', 't', 'e', 'd', '\n',
        'r', 'e', 's', 'o', 'r', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 'o', 'r', 't', 's', '\n',
        'r', 'e', 's', 'o', 'u', 'n', 'd', '\n',
        'r', 'e', 's', 'o', 'u', 'n', 'd', 'e', 'd', '\n',
        'r', 'e', 's', 'o', 'u', 'n', 'd', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 'l', 'y', '\n',
        'r', 'e', 's', 'o', 'u', 'n', 'd', 's', '\n',
        'r', 'e', 's', 'o', 'u', 'r', 'c', 'e', '\n',
        'r', 'e', 's', 'o', 'u', 'r', 'c', 'e', 'd', '\n',
        'r', 'e', 's', 'o', 'u', 'r', 'c', 'e', 'f', 'u', 'l', '\n',
        'r', 'e', 's', 'o', 'u', 'r', 'c', 'e', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'r', 'e', 's', 'o', 'u', 'r', 'c', 'e', 's', '\n',
        'r', 'e', 's', 'o', 'u', 'r', 'c', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 'p', 'e', 'c', 'i', 'f', 'i', 'e', 'd', '\n',
        'r', 'e', 's', 'p', 'e', 'c', 'i', 'f', 'y', '\n',
        'r', 'e', 's', 'p', 'e', 'c', 't', '\n',
        'r', 'e', 's', 'p', 'e', 'c', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'r', 'e', 's', 'p', 'e', 'c', 't', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 's', 'p', 'e', 'c', 't', 'a', 'b', 'l', 'y', '\n',
        'r', 'e', 's', 'p', 'e', 'c', 't', 'e', 'd', '\n',
        'r', 'e', 's', 'p', 'e', 'c', 't', 'f', 'u', 'l', '\n',
        'r', 'e', 's', 'p', 'e', 'c', 't', 'f', 'u', 'l', 'l', 'y', '\n',
        'r', 'e', 's', 'p', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 'p', 'e', 'c', 't', 'i', 'v', 'e', '\n',
        'r', 'e', 's', 'p', 'e', 'c', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'r', 'e', 's', 'p', 'e', 'c', 't', 's', '\n',
        'r', 'e', 's', 'p', 'i', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 's', 'p', 'i', 'r', 'a', 't', 'o', 'r', '\n',
        'r', 'e', 's', 'p', 'i', 'r', 'a', 't', 'o', 'r', 's', '\n',
        'r', 'e', 's', 'p', 'i', 'r', 'a', 't', 'o', 'r', 'y', '\n',
        'r', 'e', 's', 'p', 'i', 'r', 'e', '\n',
        'r', 'e', 's', 'p', 'i', 'r', 'e', 'd', '\n',
        'r', 'e', 's', 'p', 'i', 't', 'e', '\n',
        'r', 'e', 's', 'p', 'l', 'e', 'n', 'd', 'e', 'n', 't', '\n',
        'r', 'e', 's', 'p', 'o', 'n', 'd', '\n',
        'r', 'e', 's', 'p', 'o', 'n', 'd', 'e', 'd', '\n',
        'r', 'e', 's', 'p', 'o', 'n', 'd', 'e', 'n', 't', '\n',
        'r', 'e', 's', 'p', 'o', 'n', 'd', 'e', 'n', 't', 's', '\n',
        'r', 'e', 's', 'p', 'o', 'n', 'd', 'e', 'r', '\n',
        'r', 'e', 's', 'p', 'o', 'n', 'd', 'e', 'r', 's', '\n',
        'r', 'e', 's', 'p', 'o', 'n', 'd', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 'p', 'o', 'n', 'd', 's', '\n',
        'r', 'e', 's', 'p', 'o', 'n', 's', 'e', '\n',
        'r', 'e', 's', 'p', 'o', 'n', 's', 'e', 's', '\n',
        'r', 'e', 's', 'p', 'o', 'n', 's', 'i', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'r', 'e', 's', 'p', 'o', 'n', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'r', 'e', 's', 'p', 'o', 'n', 's', 'i', 'b', 'l', 'e', '\n',
        'r', 'e', 's', 'p', 'o', 'n', 's', 'i', 'b', 'l', 'y', '\n',
        'r', 'e', 's', 'p', 'o', 'n', 's', 'i', 'v', 'e', '\n',
        'r', 'e', 's', 'p', 'o', 'n', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'r', 'e', 's', 'p', 'o', 'n', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'r', 'e', 's', 'p', 'r', 'a', 'y', '\n',
        'r', 'e', 's', 'p', 'r', 'a', 'y', 'e', 'd', '\n',
        'r', 'e', 's', 'p', 'r', 'a', 'y', 's', '\n',
        'r', 'e', 's', 't', '\n',
        'r', 'e', 's', 't', 'a', 'r', 't', '\n',
        'r', 'e', 's', 't', 'a', 'r', 't', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 's', 't', 'a', 'r', 't', 'e', 'd', '\n',
        'r', 'e', 's', 't', 'a', 'r', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 't', 'a', 'r', 't', 's', '\n',
        'r', 'e', 's', 't', 'a', 't', 'e', '\n',
        'r', 'e', 's', 't', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 's', 't', 'a', 't', 'e', 'm', 'e', 'n', 't', '\n',
        'r', 'e', 's', 't', 'a', 't', 'e', 's', '\n',
        'r', 'e', 's', 't', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 't', 'a', 'u', 'r', 'a', 'n', 't', '\n',
        'r', 'e', 's', 't', 'a', 'u', 'r', 'a', 'n', 't', 's', '\n',
        'r', 'e', 's', 't', 'a', 'u', 'r', 'a', 't', 'e', 'u', 'r', '\n',
        'r', 'e', 's', 't', 'a', 'u', 'r', 'a', 't', 'e', 'u', 'r', 's', '\n',
        'r', 'e', 's', 't', 'e', 'd', '\n',
        'r', 'e', 's', 't', 'f', 'u', 'l', '\n',
        'r', 'e', 's', 't', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'r', 'e', 's', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 't', 'i', 't', 'u', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 's', 't', 'i', 'v', 'e', '\n',
        'r', 'e', 's', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'r', 'e', 's', 't', 'l', 'e', 's', 's', '\n',
        'r', 'e', 's', 't', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'r', 'e', 's', 't', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'r', 'e', 's', 't', 'o', 'c', 'k', '\n',
        'r', 'e', 's', 't', 'o', 'c', 'k', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 't', 'o', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 's', 't', 'o', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 's', 't', 'o', 'r', 'a', 't', 'i', 'v', 'e', '\n',
        'r', 'e', 's', 't', 'o', 'r', 'e', '\n',
        'r', 'e', 's', 't', 'o', 'r', 'e', 'd', '\n',
        'r', 'e', 's', 't', 'o', 'r', 'e', 'r', '\n',
        'r', 'e', 's', 't', 'o', 'r', 'e', 'r', 's', '\n',
        'r', 'e', 's', 't', 'o', 'r', 'e', 's', '\n',
        'r', 'e', 's', 't', 'o', 'r', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 't', 'r', 'a', 'i', 'n', '\n',
        'r', 'e', 's', 't', 'r', 'a', 'i', 'n', 'e', 'd', '\n',
        'r', 'e', 's', 't', 'r', 'a', 'i', 'n', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 't', 'r', 'a', 'i', 'n', 's', '\n',
        'r', 'e', 's', 't', 'r', 'a', 'i', 'n', 't', '\n',
        'r', 'e', 's', 't', 'r', 'a', 'i', 'n', 't', 's', '\n',
        'r', 'e', 's', 't', 'r', 'i', 'c', 't', '\n',
        'r', 'e', 's', 't', 'r', 'i', 'c', 't', 'e', 'd', '\n',
        'r', 'e', 's', 't', 'r', 'i', 'c', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 't', 'r', 'i', 'c', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 's', 't', 'r', 'i', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 's', 't', 'r', 'i', 'c', 't', 'i', 'v', 'e', '\n',
        'r', 'e', 's', 't', 'r', 'i', 'c', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'r', 'e', 's', 't', 'r', 'i', 'c', 't', 's', '\n',
        'r', 'e', 's', 't', 'r', 'o', 'o', 'm', '\n',
        'r', 'e', 's', 't', 'r', 'u', 'c', 't', 'u', 'r', 'e', '\n',
        'r', 'e', 's', 't', 'r', 'u', 'c', 't', 'u', 'r', 'e', 'd', '\n',
        'r', 'e', 's', 't', 'r', 'u', 'c', 't', 'u', 'r', 'e', 's', '\n',
        'r', 'e', 's', 't', 'r', 'u', 'c', 't', 'u', 'r', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 't', 's', '\n',
        'r', 'e', 's', 't', 'y', 'l', 'e', 'd', '\n',
        'r', 'e', 's', 'u', 'b', 'm', 'i', 's', 's', 'i', 'o', 'n', '\n',
        'r', 'e', 's', 'u', 'b', 'm', 'i', 's', 's', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 's', 'u', 'b', 'm', 'i', 't', '\n',
        'r', 'e', 's', 'u', 'b', 'm', 'i', 't', 's', '\n',
        'r', 'e', 's', 'u', 'b', 'm', 'i', 't', 't', 'e', 'd', '\n',
        'r', 'e', 's', 'u', 'b', 'm', 'i', 't', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 'u', 'b', 's', 't', 'i', 't', 'u', 't', 'e', '\n',
        'r', 'e', 's', 'u', 'l', 't', '\n',
        'r', 'e', 's', 'u', 'l', 't', 'a', 'n', 't', '\n',
        'r', 'e', 's', 'u', 'l', 't', 'e', 'd', '\n',
        'r', 'e', 's', 'u', 'l', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 'u', 'l', 't', 's', '\n',
        'r', 'e', 's', 'u', 'm', 'e', '\n',
        'r', 'e', 's', 'u', 'm', 'e', 'd', '\n',
        'r', 'e', 's', 'u', 'm', 'e', 's', '\n',
        'r', 'e', 's', 'u', 'm', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 'u', 'm', 'p', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 's', 'u', 'p', 'p', 'l', 'y', '\n',
        'r', 'e', 's', 'u', 'r', 'f', 'a', 'c', 'e', '\n',
        'r', 'e', 's', 'u', 'r', 'f', 'a', 'c', 'e', 'd', '\n',
        'r', 'e', 's', 'u', 'r', 'f', 'a', 'c', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 'u', 'r', 'g', 'e', 'n', 'c', 'e', '\n',
        'r', 'e', 's', 'u', 'r', 'g', 'e', 'n', 't', '\n',
        'r', 'e', 's', 'u', 'r', 'r', 'e', 'c', 't', '\n',
        'r', 'e', 's', 'u', 'r', 'r', 'e', 'c', 't', 'e', 'd', '\n',
        'r', 'e', 's', 'u', 'r', 'r', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 'u', 'r', 'r', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 's', 'u', 'r', 'r', 'e', 'c', 't', 's', '\n',
        'r', 'e', 's', 'u', 's', 'c', 'i', 't', 'a', 't', 'e', '\n',
        'r', 'e', 's', 'u', 's', 'c', 'i', 't', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 's', 'u', 's', 'c', 'i', 't', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 's', 'u', 's', 'c', 'i', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 't', 'a', 'i', 'l', '\n',
        'r', 'e', 't', 'a', 'i', 'l', 'e', 'd', '\n',
        'r', 'e', 't', 'a', 'i', 'l', 'e', 'r', '\n',
        'r', 'e', 't', 'a', 'i', 'l', 'e', 'r', 's', '\n',
        'r', 'e', 't', 'a', 'i', 'l', 'i', 'n', 'g', '\n',
        'r', 'e', 't', 'a', 'i', 'l', 's', '\n',
        'r', 'e', 't', 'a', 'i', 'n', '\n',
        'r', 'e', 't', 'a', 'i', 'n', 'e', 'd', '\n',
        'r', 'e', 't', 'a', 'i', 'n', 'e', 'r', '\n',
        'r', 'e', 't', 'a', 'i', 'n', 'e', 'r', 's', '\n',
        'r', 'e', 't', 'a', 'i', 'n', 'i', 'n', 'g', '\n',
        'r', 'e', 't', 'a', 'i', 'n', 's', '\n',
        'r', 'e', 't', 'a', 'k', 'e', '\n',
        'r', 'e', 't', 'a', 'k', 'e', 'n', '\n',
        'r', 'e', 't', 'a', 'k', 'e', 's', '\n',
        'r', 'e', 't', 'a', 'k', 'i', 'n', 'g', '\n',
        'r', 'e', 't', 'a', 'l', 'i', 'a', 't', 'e', '\n',
        'r', 'e', 't', 'a', 'l', 'i', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 't', 'a', 'l', 'i', 'a', 't', 'e', 's', '\n',
        'r', 'e', 't', 'a', 'l', 'i', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 't', 'a', 'l', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 't', 'a', 'l', 'i', 'a', 't', 'o', 'r', 'y', '\n',
        'r', 'e', 't', 'a', 'r', 'd', '\n',
        'r', 'e', 't', 'a', 'r', 'd', 'a', 'n', 't', '\n',
        'r', 'e', 't', 'a', 'r', 'd', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 't', 'a', 'r', 'd', 'e', 'd', '\n',
        'r', 'e', 't', 'a', 'r', 'd', 'i', 'n', 'g', '\n',
        'r', 'e', 't', 'a', 'r', 'd', 's', '\n',
        'r', 'e', 't', 'c', 'h', '\n',
        'r', 'e', 't', 'c', 'h', 'e', 'd', '\n',
        'r', 'e', 't', 'c', 'h', 'i', 'n', 'g', '\n',
        'r', 'e', 't', 'e', 'l', 'l', '\n',
        'r', 'e', 't', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'r', 'e', 't', 'e', 'n', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 't', 'e', 'n', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 't', 'e', 'n', 't', 'i', 'v', 'e', '\n',
        'r', 'e', 't', 'e', 'n', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'r', 'e', 't', 'e', 'n', 't', 'i', 'v', 'i', 't', 'y', '\n',
        'r', 'e', 't', 'e', 's', 't', '\n',
        'r', 'e', 't', 'e', 's', 't', 'e', 'd', '\n',
        'r', 'e', 't', 'e', 's', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 't', 'e', 's', 't', 's', '\n',
        'r', 'e', 't', 'h', 'i', 'n', 'k', '\n',
        'r', 'e', 't', 'h', 'i', 'n', 'k', 'i', 'n', 'g', '\n',
        'r', 'e', 't', 'h', 'o', 'u', 'g', 'h', 't', '\n',
        'r', 'e', 't', 'i', 'c', 'e', 'n', 'c', 'e', '\n',
        'r', 'e', 't', 'i', 'c', 'e', 'n', 't', '\n',
        'r', 'e', 't', 'i', 'c', 'u', 'l', 'a', 'r', '\n',
        'r', 'e', 't', 'i', 'c', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 't', 'i', 'c', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 't', 'i', 'c', 'u', 'l', 'e', '\n',
        'r', 'e', 't', 'i', 'c', 'u', 'l', 'e', 's', '\n',
        'r', 'e', 't', 'i', 'c', 'u', 'l', 'u', 'm', '\n',
        'r', 'e', 't', 'i', 'e', 'd', '\n',
        'r', 'e', 't', 'i', 'n', 'a', '\n',
        'r', 'e', 't', 'i', 'n', 'a', 'l', '\n',
        'r', 'e', 't', 'i', 'n', 'a', 's', '\n',
        'r', 'e', 't', 'i', 'n', 'i', 't', 'i', 's', '\n',
        'r', 'e', 't', 'i', 'n', 'u', 'e', '\n',
        'r', 'e', 't', 'i', 'n', 'u', 'e', 's', '\n',
        'r', 'e', 't', 'i', 'r', 'e', '\n',
        'r', 'e', 't', 'i', 'r', 'e', 'd', '\n',
        'r', 'e', 't', 'i', 'r', 'e', 'e', '\n',
        'r', 'e', 't', 'i', 'r', 'e', 'm', 'e', 'n', 't', '\n',
        'r', 'e', 't', 'i', 'r', 'e', 'm', 'e', 'n', 't', 's', '\n',
        'r', 'e', 't', 'i', 'r', 'e', 's', '\n',
        'r', 'e', 't', 'i', 'r', 'i', 'n', 'g', '\n',
        'r', 'e', 't', 'i', 't', 'l', 'e', '\n',
        'r', 'e', 't', 'i', 't', 'l', 'e', 'd', '\n',
        'r', 'e', 't', 'i', 't', 'l', 'i', 'n', 'g', '\n',
        'r', 'e', 't', 'o', 'l', 'd', '\n',
        'r', 'e', 't', 'o', 'o', 'k', '\n',
        'r', 'e', 't', 'o', 'r', 't', '\n',
        'r', 'e', 't', 'o', 'r', 't', 'e', 'd', '\n',
        'r', 'e', 't', 'o', 'r', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 't', 'o', 'r', 't', 's', '\n',
        'r', 'e', 't', 'o', 'u', 'c', 'h', '\n',
        'r', 'e', 't', 'o', 'u', 'c', 'h', 'e', 'd', '\n',
        'r', 'e', 't', 'o', 'u', 'c', 'h', 'i', 'n', 'g', '\n',
        'r', 'e', 't', 'r', 'a', 'c', 'e', '\n',
        'r', 'e', 't', 'r', 'a', 'c', 'e', 'd', '\n',
        'r', 'e', 't', 'r', 'a', 'c', 'e', 's', '\n',
        'r', 'e', 't', 'r', 'a', 'c', 'i', 'n', 'g', '\n',
        'r', 'e', 't', 'r', 'a', 'c', 't', '\n',
        'r', 'e', 't', 'r', 'a', 'c', 't', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 't', 'r', 'a', 'c', 't', 'e', 'd', '\n',
        'r', 'e', 't', 'r', 'a', 'c', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 't', 'r', 'a', 'c', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 't', 'r', 'a', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 't', 'r', 'a', 'c', 't', 's', '\n',
        'r', 'e', 't', 'r', 'a', 'i', 'n', '\n',
        'r', 'e', 't', 'r', 'a', 'i', 'n', 'e', 'd', '\n',
        'r', 'e', 't', 'r', 'a', 'i', 'n', 'i', 'n', 'g', '\n',
        'r', 'e', 't', 'r', 'a', 'l', '\n',
        'r', 'e', 't', 'r', 'a', 'n', 's', 'm', 'i', 's', 's', 'i', 'o', 'n', '\n',
        'r', 'e', 't', 'r', 'a', 'n', 's', 'm', 'i', 's', 's', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 't', 'r', 'a', 'n', 's', 'm', 'i', 't', '\n',
        'r', 'e', 't', 'r', 'a', 'n', 's', 'm', 'i', 't', 's', '\n',
        'r', 'e', 't', 'r', 'a', 'n', 's', 'm', 'i', 't', 't', 'e', 'd', '\n',
        'r', 'e', 't', 'r', 'a', 'n', 's', 'm', 'i', 't', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 't', 'r', 'e', 'a', 'd', '\n',
        'r', 'e', 't', 'r', 'e', 'a', 'd', 's', '\n',
        'r', 'e', 't', 'r', 'e', 'a', 't', '\n',
        'r', 'e', 't', 'r', 'e', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 't', 'r', 'e', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 't', 'r', 'e', 'a', 't', 's', '\n',
        'r', 'e', 't', 'r', 'e', 'n', 'c', 'h', '\n',
        'r', 'e', 't', 'r', 'e', 'n', 'c', 'h', 'm', 'e', 'n', 't', '\n',
        'r', 'e', 't', 'r', 'i', 'a', 'l', '\n',
        'r', 'e', 't', 'r', 'i', 'b', 'u', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 't', 'r', 'i', 'b', 'u', 't', 'i', 'v', 'e', '\n',
        'r', 'e', 't', 'r', 'i', 'e', 'd', '\n',
        'r', 'e', 't', 'r', 'i', 'e', 's', '\n',
        'r', 'e', 't', 'r', 'i', 'e', 'v', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 't', 'r', 'i', 'e', 'v', 'a', 'l', '\n',
        'r', 'e', 't', 'r', 'i', 'e', 'v', 'a', 'l', 's', '\n',
        'r', 'e', 't', 'r', 'i', 'e', 'v', 'e', '\n',
        'r', 'e', 't', 'r', 'i', 'e', 'v', 'e', 'd', '\n',
        'r', 'e', 't', 'r', 'i', 'e', 'v', 'e', 'r', '\n',
        'r', 'e', 't', 'r', 'i', 'e', 'v', 'e', 'r', 's', '\n',
        'r', 'e', 't', 'r', 'i', 'e', 'v', 'e', 's', '\n',
        'r', 'e', 't', 'r', 'i', 'e', 'v', 'i', 'n', 'g', '\n',
        'r', 'e', 't', 'r', 'o', '\n',
        'r', 'e', 't', 'r', 'o', 'a', 'c', 't', 'i', 'v', 'e', '\n',
        'r', 'e', 't', 'r', 'o', 'a', 'c', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'r', 'e', 't', 'r', 'o', 'f', 'i', 't', '\n',
        'r', 'e', 't', 'r', 'o', 'f', 'i', 't', 't', 'e', 'd', '\n',
        'r', 'e', 't', 'r', 'o', 'f', 'i', 't', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 't', 'r', 'o', 'g', 'r', 'a', 'd', 'e', '\n',
        'r', 'e', 't', 'r', 'o', 'g', 'r', 'e', 's', 's', 'i', 'v', 'e', '\n',
        'r', 'e', 't', 'r', 'o', 's', 'p', 'e', 'c', 't', '\n',
        'r', 'e', 't', 'r', 'o', 's', 'p', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 't', 'r', 'o', 's', 'p', 'e', 'c', 't', 'i', 'v', 'e', '\n',
        'r', 'e', 't', 'r', 'o', 's', 'p', 'e', 'c', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'r', 'e', 't', 'r', 'o', 's', 'p', 'e', 'c', 't', 'i', 'v', 'e', 's', '\n',
        'r', 'e', 't', 'r', 'o', 'v', 'i', 'r', 'u', 's', 'e', 's', '\n',
        'r', 'e', 't', 'r', 'y', '\n',
        'r', 'e', 't', 'r', 'y', 'i', 'n', 'g', '\n',
        'r', 'e', 't', 's', 'i', 'n', 'a', '\n',
        'r', 'e', 't', 't', 'e', 'd', '\n',
        'r', 'e', 't', 'u', 'n', 'e', '\n',
        'r', 'e', 't', 'u', 'n', 'i', 'n', 'g', '\n',
        'r', 'e', 't', 'u', 'r', 'n', '\n',
        'r', 'e', 't', 'u', 'r', 'n', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 't', 'u', 'r', 'n', 'e', 'd', '\n',
        'r', 'e', 't', 'u', 'r', 'n', 'e', 'e', 's', '\n',
        'r', 'e', 't', 'u', 'r', 'n', 'i', 'n', 'g', '\n',
        'r', 'e', 't', 'u', 'r', 'n', 's', '\n',
        'r', 'e', 't', 'y', 'p', 'e', '\n',
        'r', 'e', 't', 'y', 'p', 'e', 'd', '\n',
        'r', 'e', 't', 'y', 'p', 'e', 's', '\n',
        'r', 'e', 't', 'y', 'p', 'i', 'n', 'g', '\n',
        'r', 'e', 'u', 'n', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'u', 'n', 'i', 'f', 'i', 'e', 'd', '\n',
        'r', 'e', 'u', 'n', 'i', 'f', 'y', '\n',
        'r', 'e', 'u', 'n', 'i', 'o', 'n', '\n',
        'r', 'e', 'u', 'n', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'u', 'n', 'i', 't', 'e', '\n',
        'r', 'e', 'u', 'n', 'i', 't', 'e', 'd', '\n',
        'r', 'e', 'u', 'n', 'i', 't', 'e', 's', '\n',
        'r', 'e', 'u', 'n', 'i', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'u', 's', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'u', 's', 'e', '\n',
        'r', 'e', 'u', 's', 'e', 'd', '\n',
        'r', 'e', 'u', 's', 'e', 's', '\n',
        'r', 'e', 'u', 's', 'i', 'n', 'g', '\n',
        'r', 'e', 'v', '\n',
        'r', 'e', 'v', 'a', 'l', 'u', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'v', 'a', 'l', 'u', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'v', 'a', 'l', 'u', 'e', '\n',
        'r', 'e', 'v', 'a', 'l', 'u', 'e', 'd', '\n',
        'r', 'e', 'v', 'a', 'l', 'u', 'e', 's', '\n',
        'r', 'e', 'v', 'a', 'm', 'p', '\n',
        'r', 'e', 'v', 'a', 'm', 'p', 'e', 'd', '\n',
        'r', 'e', 'v', 'a', 'm', 'p', 'i', 'n', 'g', '\n',
        'r', 'e', 'v', 'a', 'm', 'p', 's', '\n',
        'r', 'e', 'v', 'a', 'n', 'c', 'h', 'i', 's', 't', '\n',
        'r', 'e', 'v', 'e', 'a', 'l', '\n',
        'r', 'e', 'v', 'e', 'a', 'l', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'v', 'e', 'a', 'l', 'e', 'd', '\n',
        'r', 'e', 'v', 'e', 'a', 'l', 'i', 'n', 'g', '\n',
        'r', 'e', 'v', 'e', 'a', 'l', 'i', 'n', 'g', 'l', 'y', '\n',
        'r', 'e', 'v', 'e', 'a', 'l', 's', '\n',
        'r', 'e', 'v', 'e', 'i', 'l', 'l', 'e', '\n',
        'r', 'e', 'v', 'e', 'l', '\n',
        'r', 'e', 'v', 'e', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'v', 'e', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'v', 'e', 'l', 'a', 't', 'o', 'r', 'y', '\n',
        'r', 'e', 'v', 'e', 'l', 'l', 'e', 'd', '\n',
        'r', 'e', 'v', 'e', 'l', 'l', 'e', 'r', '\n',
        'r', 'e', 'v', 'e', 'l', 'l', 'e', 'r', 's', '\n',
        'r', 'e', 'v', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'r', 'e', 'v', 'e', 'l', 'r', 'i', 'e', 's', '\n',
        'r', 'e', 'v', 'e', 'l', 'r', 'y', '\n',
        'r', 'e', 'v', 'e', 'l', 's', '\n',
        'r', 'e', 'v', 'e', 'n', 'a', 'n', 't', '\n',
        'r', 'e', 'v', 'e', 'n', 'g', 'e', '\n',
        'r', 'e', 'v', 'e', 'n', 'g', 'e', 'd', '\n',
        'r', 'e', 'v', 'e', 'n', 'g', 'e', 'f', 'u', 'l', '\n',
        'r', 'e', 'v', 'e', 'n', 'g', 'e', 's', '\n',
        'r', 'e', 'v', 'e', 'n', 'g', 'i', 'n', 'g', '\n',
        'r', 'e', 'v', 'e', 'n', 'u', 'e', '\n',
        'r', 'e', 'v', 'e', 'n', 'u', 'e', 's', '\n',
        'r', 'e', 'v', 'e', 'r', 'b', 'e', 'r', 'a', 'n', 't', '\n',
        'r', 'e', 'v', 'e', 'r', 'b', 'e', 'r', 'a', 't', 'e', '\n',
        'r', 'e', 'v', 'e', 'r', 'b', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'r', 'e', 'v', 'e', 'r', 'b', 'e', 'r', 'a', 't', 'e', 's', '\n',
        'r', 'e', 'v', 'e', 'r', 'b', 'e', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'v', 'e', 'r', 'b', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'v', 'e', 'r', 'b', 'e', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'v', 'e', 'r', 'e', '\n',
        'r', 'e', 'v', 'e', 'r', 'e', 'd', '\n',
        'r', 'e', 'v', 'e', 'r', 'e', 'n', 'c', 'e', '\n',
        'r', 'e', 'v', 'e', 'r', 'e', 'n', 'd', '\n',
        'r', 'e', 'v', 'e', 'r', 'e', 'n', 't', '\n',
        'r', 'e', 'v', 'e', 'r', 'e', 'n', 't', 'i', 'a', 'l', '\n',
        'r', 'e', 'v', 'e', 'r', 'e', 'n', 't', 'i', 'a', 'l', 'l', 'y', '\n',
        'r', 'e', 'v', 'e', 'r', 'e', 'n', 't', 'l', 'y', '\n',
        'r', 'e', 'v', 'e', 'r', 'e', 's', '\n',
        'r', 'e', 'v', 'e', 'r', 'i', 'e', '\n',
        'r', 'e', 'v', 'e', 'r', 'i', 'e', 's', '\n',
        'r', 'e', 'v', 'e', 'r', 'i', 'n', 'g', '\n',
        'r', 'e', 'v', 'e', 'r', 's', 'a', 'l', '\n',
        'r', 'e', 'v', 'e', 'r', 's', 'a', 'l', 's', '\n',
        'r', 'e', 'v', 'e', 'r', 's', 'e', '\n',
        'r', 'e', 'v', 'e', 'r', 's', 'e', 'd', '\n',
        'r', 'e', 'v', 'e', 'r', 's', 'e', 'r', '\n',
        'r', 'e', 'v', 'e', 'r', 's', 'e', 's', '\n',
        'r', 'e', 'v', 'e', 'r', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'r', 'e', 'v', 'e', 'r', 's', 'i', 'b', 'l', 'e', '\n',
        'r', 'e', 'v', 'e', 'r', 's', 'i', 'b', 'l', 'y', '\n',
        'r', 'e', 'v', 'e', 'r', 's', 'i', 'n', 'g', '\n',
        'r', 'e', 'v', 'e', 'r', 's', 'i', 'o', 'n', '\n',
        'r', 'e', 'v', 'e', 'r', 't', '\n',
        'r', 'e', 'v', 'e', 'r', 't', 'e', 'd', '\n',
        'r', 'e', 'v', 'e', 'r', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'v', 'e', 'r', 't', 's', '\n',
        'r', 'e', 'v', 'i', 'e', 'w', '\n',
        'r', 'e', 'v', 'i', 'e', 'w', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'v', 'i', 'e', 'w', 'e', 'd', '\n',
        'r', 'e', 'v', 'i', 'e', 'w', 'e', 'r', '\n',
        'r', 'e', 'v', 'i', 'e', 'w', 'e', 'r', 's', '\n',
        'r', 'e', 'v', 'i', 'e', 'w', 'i', 'n', 'g', '\n',
        'r', 'e', 'v', 'i', 'e', 'w', 's', '\n',
        'r', 'e', 'v', 'i', 'l', 'e', '\n',
        'r', 'e', 'v', 'i', 'l', 'e', 'd', '\n',
        'r', 'e', 'v', 'i', 'l', 'i', 'n', 'g', '\n',
        'r', 'e', 'v', 'i', 's', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'v', 'i', 's', 'a', 'l', '\n',
        'r', 'e', 'v', 'i', 's', 'e', '\n',
        'r', 'e', 'v', 'i', 's', 'e', 'd', '\n',
        'r', 'e', 'v', 'i', 's', 'e', 'r', '\n',
        'r', 'e', 'v', 'i', 's', 'e', 's', '\n',
        'r', 'e', 'v', 'i', 's', 'i', 'n', 'g', '\n',
        'r', 'e', 'v', 'i', 's', 'i', 'o', 'n', '\n',
        'r', 'e', 'v', 'i', 's', 'i', 'o', 'n', 'a', 'r', 'y', '\n',
        'r', 'e', 'v', 'i', 's', 'i', 'o', 'n', 'i', 's', 'm', '\n',
        'r', 'e', 'v', 'i', 's', 'i', 'o', 'n', 'i', 's', 't', '\n',
        'r', 'e', 'v', 'i', 's', 'i', 'o', 'n', 'i', 's', 't', 's', '\n',
        'r', 'e', 'v', 'i', 's', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'v', 'i', 's', 'i', 't', '\n',
        'r', 'e', 'v', 'i', 's', 'i', 't', 'e', 'd', '\n',
        'r', 'e', 'v', 'i', 's', 'i', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'v', 'i', 's', 'i', 't', 's', '\n',
        'r', 'e', 'v', 'i', 't', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'v', 'i', 't', 'a', 'l', 'i', 's', 'e', '\n',
        'r', 'e', 'v', 'i', 't', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'r', 'e', 'v', 'i', 't', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'r', 'e', 'v', 'i', 'v', 'a', 'l', '\n',
        'r', 'e', 'v', 'i', 'v', 'a', 'l', 'i', 's', 'm', '\n',
        'r', 'e', 'v', 'i', 'v', 'a', 'l', 'i', 's', 't', '\n',
        'r', 'e', 'v', 'i', 'v', 'a', 'l', 'i', 's', 't', 's', '\n',
        'r', 'e', 'v', 'i', 'v', 'a', 'l', 's', '\n',
        'r', 'e', 'v', 'i', 'v', 'e', '\n',
        'r', 'e', 'v', 'i', 'v', 'e', 'd', '\n',
        'r', 'e', 'v', 'i', 'v', 'e', 'r', '\n',
        'r', 'e', 'v', 'i', 'v', 'e', 's', '\n',
        'r', 'e', 'v', 'i', 'v', 'i', 'f', 'y', '\n',
        'r', 'e', 'v', 'i', 'v', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'r', 'e', 'v', 'i', 'v', 'i', 'n', 'g', '\n',
        'r', 'e', 'v', 'o', 'c', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'v', 'o', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'v', 'o', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'v', 'o', 'k', 'e', '\n',
        'r', 'e', 'v', 'o', 'k', 'e', 'd', '\n',
        'r', 'e', 'v', 'o', 'k', 'e', 'r', '\n',
        'r', 'e', 'v', 'o', 'k', 'e', 'r', 's', '\n',
        'r', 'e', 'v', 'o', 'k', 'e', 's', '\n',
        'r', 'e', 'v', 'o', 'k', 'i', 'n', 'g', '\n',
        'r', 'e', 'v', 'o', 'l', 't', '\n',
        'r', 'e', 'v', 'o', 'l', 't', 'e', 'd', '\n',
        'r', 'e', 'v', 'o', 'l', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'v', 'o', 'l', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'r', 'e', 'v', 'o', 'l', 't', 's', '\n',
        'r', 'e', 'v', 'o', 'l', 'u', 't', 'i', 'o', 'n', '\n',
        'r', 'e', 'v', 'o', 'l', 'u', 't', 'i', 'o', 'n', 'a', 'r', 'i', 'e', 's', '\n',
        'r', 'e', 'v', 'o', 'l', 'u', 't', 'i', 'o', 'n', 'a', 'r', 'y', '\n',
        'r', 'e', 'v', 'o', 'l', 'u', 't', 'i', 'o', 'n', 'i', 's', 'e', '\n',
        'r', 'e', 'v', 'o', 'l', 'u', 't', 'i', 'o', 'n', 'i', 's', 'e', 'd', '\n',
        'r', 'e', 'v', 'o', 'l', 'u', 't', 'i', 'o', 'n', 'i', 's', 'e', 's', '\n',
        'r', 'e', 'v', 'o', 'l', 'u', 't', 'i', 'o', 'n', 'i', 's', 'i', 'n', 'g', '\n',
        'r', 'e', 'v', 'o', 'l', 'u', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'e', 'v', 'o', 'l', 'v', 'e', '\n',
        'r', 'e', 'v', 'o', 'l', 'v', 'e', 'd', '\n',
        'r', 'e', 'v', 'o', 'l', 'v', 'e', 'r', '\n',
        'r', 'e', 'v', 'o', 'l', 'v', 'e', 'r', 's', '\n',
        'r', 'e', 'v', 'o', 'l', 'v', 'e', 's', '\n',
        'r', 'e', 'v', 'o', 'l', 'v', 'i', 'n', 'g', '\n',
        'r', 'e', 'v', 's', '\n',
        'r', 'e', 'v', 'u', 'e', '\n',
        'r', 'e', 'v', 'u', 'e', 's', '\n',
        'r', 'e', 'v', 'u', 'l', 's', 'i', 'o', 'n', '\n',
        'r', 'e', 'v', 'v', 'e', 'd', '\n',
        'r', 'e', 'v', 'v', 'i', 'n', 'g', '\n',
        'r', 'e', 'w', 'a', 'r', 'd', '\n',
        'r', 'e', 'w', 'a', 'r', 'd', 'e', 'd', '\n',
        'r', 'e', 'w', 'a', 'r', 'd', 'i', 'n', 'g', '\n',
        'r', 'e', 'w', 'a', 'r', 'd', 's', '\n',
        'r', 'e', 'w', 'e', 'i', 'g', 'h', 'e', 'd', '\n',
        'r', 'e', 'w', 'i', 'n', 'd', '\n',
        'r', 'e', 'w', 'i', 'n', 'd', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'w', 'i', 'n', 'd', 'i', 'n', 'g', '\n',
        'r', 'e', 'w', 'i', 'n', 'd', 's', '\n',
        'r', 'e', 'w', 'i', 'r', 'e', '\n',
        'r', 'e', 'w', 'i', 'r', 'e', 'd', '\n',
        'r', 'e', 'w', 'i', 'r', 'i', 'n', 'g', '\n',
        'r', 'e', 'w', 'o', 'r', 'd', '\n',
        'r', 'e', 'w', 'o', 'r', 'd', 'e', 'd', '\n',
        'r', 'e', 'w', 'o', 'r', 'd', 'i', 'n', 'g', '\n',
        'r', 'e', 'w', 'o', 'r', 'd', 'i', 'n', 'g', 's', '\n',
        'r', 'e', 'w', 'o', 'r', 'k', '\n',
        'r', 'e', 'w', 'o', 'r', 'k', 'e', 'd', '\n',
        'r', 'e', 'w', 'o', 'r', 'k', 'i', 'n', 'g', '\n',
        'r', 'e', 'w', 'o', 'r', 'k', 's', '\n',
        'r', 'e', 'w', 'o', 'u', 'n', 'd', '\n',
        'r', 'e', 'w', 'r', 'a', 'p', '\n',
        'r', 'e', 'w', 'r', 'i', 't', 'a', 'b', 'l', 'e', '\n',
        'r', 'e', 'w', 'r', 'i', 't', 'e', '\n',
        'r', 'e', 'w', 'r', 'i', 't', 'e', 's', '\n',
        'r', 'e', 'w', 'r', 'i', 't', 'i', 'n', 'g', '\n',
        'r', 'e', 'w', 'r', 'i', 't', 'i', 'n', 'g', 's', '\n',
        'r', 'e', 'w', 'r', 'i', 't', 't', 'e', 'n', '\n',
        'r', 'e', 'w', 'r', 'o', 't', 'e', '\n',
        'r', 'h', 'a', 'p', 's', 'o', 'd', 'i', 'c', '\n',
        'r', 'h', 'a', 'p', 's', 'o', 'd', 'i', 'c', 'a', 'l', '\n',
        'r', 'h', 'a', 'p', 's', 'o', 'd', 'i', 'e', 's', '\n',
        'r', 'h', 'a', 'p', 's', 'o', 'd', 'y', '\n',
        'r', 'h', 'e', 'a', '\n',
        'r', 'h', 'e', 'i', 'n', '\n',
        'r', 'h', 'e', 'n', 'i', 'u', 'm', '\n',
        'r', 'h', 'e', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'r', 'h', 'e', 'o', 'l', 'o', 'g', 'y', '\n',
        'r', 'h', 'e', 'o', 's', 't', 'a', 't', '\n',
        'r', 'h', 'e', 's', 'u', 's', '\n',
        'r', 'h', 'e', 't', 'o', 'r', 'i', 'c', '\n',
        'r', 'h', 'e', 't', 'o', 'r', 'i', 'c', 'a', 'l', '\n',
        'r', 'h', 'e', 't', 'o', 'r', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'r', 'h', 'e', 't', 'o', 'r', 'i', 'c', 'i', 'a', 'n', '\n',
        'r', 'h', 'e', 't', 'o', 'r', 'i', 'c', 'i', 'a', 'n', 's', '\n',
        'r', 'h', 'e', 'u', 'm', 'a', 't', 'i', 'c', '\n',
        'r', 'h', 'e', 'u', 'm', 'a', 't', 'i', 'c', 's', '\n',
        'r', 'h', 'e', 'u', 'm', 'a', 't', 'i', 's', 'm', '\n',
        'r', 'h', 'e', 'u', 'm', 'a', 't', 'o', 'i', 'd', '\n',
        'r', 'h', 'e', 'u', 'm', 'a', 't', 'o', 'l', 'o', 'g', 'y', '\n',
        'r', 'h', 'i', 'n', 'e', '\n',
        'r', 'h', 'i', 'n', 'e', 's', 't', 'o', 'n', 'e', '\n',
        'r', 'h', 'i', 'n', 'i', 't', 'i', 's', '\n',
        'r', 'h', 'i', 'n', 'o', '\n',
        'r', 'h', 'i', 'n', 'o', 'c', 'e', 'r', 'o', 's', '\n',
        'r', 'h', 'i', 'n', 'o', 'c', 'e', 'r', 'o', 's', 'e', 's', '\n',
        'r', 'h', 'i', 'z', 'o', 'm', 'e', '\n',
        'r', 'h', 'o', '\n',
        'r', 'h', 'o', 'd', 'e', 's', 'i', 'a', '\n',
        'r', 'h', 'o', 'd', 'i', 'u', 'm', '\n',
        'r', 'h', 'o', 'd', 'o', 'd', 'e', 'n', 'd', 'r', 'o', 'n', '\n',
        'r', 'h', 'o', 'd', 'o', 'd', 'e', 'n', 'd', 'r', 'o', 'n', 's', '\n',
        'r', 'h', 'o', 'm', 'b', 'i', 'c', '\n',
        'r', 'h', 'o', 'm', 'b', 'o', 'i', 'd', 's', '\n',
        'r', 'h', 'o', 'm', 'b', 'u', 's', '\n',
        'r', 'h', 'o', 'm', 'b', 'u', 's', 'e', 's', '\n',
        'r', 'h', 'u', 'b', 'a', 'r', 'b', '\n',
        'r', 'h', 'u', 'm', 'b', 'a', 's', '\n',
        'r', 'h', 'y', 'm', 'e', '\n',
        'r', 'h', 'y', 'm', 'e', 'd', '\n',
        'r', 'h', 'y', 'm', 'e', 'r', '\n',
        'r', 'h', 'y', 'm', 'e', 's', '\n',
        'r', 'h', 'y', 'm', 'i', 'n', 'g', '\n',
        'r', 'h', 'y', 't', 'h', 'm', '\n',
        'r', 'h', 'y', 't', 'h', 'm', 'i', 'c', '\n',
        'r', 'h', 'y', 't', 'h', 'm', 'i', 'c', 'a', 'l', '\n',
        'r', 'h', 'y', 't', 'h', 'm', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'r', 'h', 'y', 't', 'h', 'm', 's', '\n',
        'r', 'i', 'a', '\n',
        'r', 'i', 'a', 'l', '\n',
        'r', 'i', 'a', 'l', 's', '\n',
        'r', 'i', 'a', 'l', 't', 'o', '\n',
        'r', 'i', 'b', '\n',
        'r', 'i', 'b', 'a', 'l', 'd', '\n',
        'r', 'i', 'b', 'a', 'l', 'd', 'r', 'y', '\n',
        'r', 'i', 'b', 'b', 'e', 'd', '\n',
        'r', 'i', 'b', 'b', 'i', 'n', 'g', '\n',
        'r', 'i', 'b', 'b', 'o', 'n', '\n',
        'r', 'i', 'b', 'b', 'o', 'n', 's', '\n',
        'r', 'i', 'b', 'c', 'a', 'g', 'e', '\n',
        'r', 'i', 'b', 'o', 'f', 'l', 'a', 'v', 'i', 'n', '\n',
        'r', 'i', 'b', 'o', 'n', 'u', 'c', 'l', 'e', 'i', 'c', '\n',
        'r', 'i', 'b', 'o', 's', 'o', 'm', 'a', 'l', '\n',
        'r', 'i', 'b', 'o', 's', 'o', 'm', 'e', '\n',
        'r', 'i', 'b', 'o', 's', 'o', 'm', 'e', 's', '\n',
        'r', 'i', 'b', 's', '\n',
        'r', 'i', 'c', 'e', '\n',
        'r', 'i', 'c', 'h', '\n',
        'r', 'i', 'c', 'h', 'e', 'r', '\n',
        'r', 'i', 'c', 'h', 'e', 's', '\n',
        'r', 'i', 'c', 'h', 'e', 's', 't', '\n',
        'r', 'i', 'c', 'h', 'l', 'y', '\n',
        'r', 'i', 'c', 'h', 'n', 'e', 's', 's', '\n',
        'r', 'i', 'c', 'k', '\n',
        'r', 'i', 'c', 'k', 'e', 't', 's', '\n',
        'r', 'i', 'c', 'k', 'e', 't', 'y', '\n',
        'r', 'i', 'c', 'k', 'i', 'n', 'g', '\n',
        'r', 'i', 'c', 'k', 's', '\n',
        'r', 'i', 'c', 'k', 's', 'h', 'a', '\n',
        'r', 'i', 'c', 'k', 's', 'h', 'a', 's', '\n',
        'r', 'i', 'c', 'k', 's', 'h', 'a', 'w', '\n',
        'r', 'i', 'c', 'k', 's', 'h', 'a', 'w', 's', '\n',
        'r', 'i', 'c', 'o', 'c', 'h', 'e', 't', '\n',
        'r', 'i', 'c', 'o', 'c', 'h', 'e', 't', 'e', 'd', '\n',
        'r', 'i', 'c', 'o', 'c', 'h', 'e', 't', 'i', 'n', 'g', '\n',
        'r', 'i', 'd', '\n',
        'r', 'i', 'd', 'd', 'a', 'n', 'c', 'e', '\n',
        'r', 'i', 'd', 'd', 'e', 'n', '\n',
        'r', 'i', 'd', 'd', 'i', 'n', 'g', '\n',
        'r', 'i', 'd', 'd', 'l', 'e', '\n',
        'r', 'i', 'd', 'd', 'l', 'e', 'd', '\n',
        'r', 'i', 'd', 'd', 'l', 'e', 's', '\n',
        'r', 'i', 'd', 'd', 'l', 'i', 'n', 'g', '\n',
        'r', 'i', 'd', 'e', '\n',
        'r', 'i', 'd', 'e', 'r', '\n',
        'r', 'i', 'd', 'e', 'r', 's', '\n',
        'r', 'i', 'd', 'e', 's', '\n',
        'r', 'i', 'd', 'g', 'e', '\n',
        'r', 'i', 'd', 'g', 'e', 'd', '\n',
        'r', 'i', 'd', 'g', 'e', 's', '\n',
        'r', 'i', 'd', 'i', 'c', 'u', 'l', 'e', '\n',
        'r', 'i', 'd', 'i', 'c', 'u', 'l', 'e', 'd', '\n',
        'r', 'i', 'd', 'i', 'c', 'u', 'l', 'e', 's', '\n',
        'r', 'i', 'd', 'i', 'c', 'u', 'l', 'i', 'n', 'g', '\n',
        'r', 'i', 'd', 'i', 'c', 'u', 'l', 'o', 'u', 's', '\n',
        'r', 'i', 'd', 'i', 'c', 'u', 'l', 'o', 'u', 's', 'l', 'y', '\n',
        'r', 'i', 'd', 'i', 'c', 'u', 'l', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'r', 'i', 'd', 'i', 'n', 'g', '\n',
        'r', 'i', 'd', 'i', 'n', 'g', 's', '\n',
        'r', 'i', 'd', 's', '\n',
        'r', 'i', 'f', 'e', '\n',
        'r', 'i', 'f', 'f', '\n',
        'r', 'i', 'f', 'f', 'l', 'e', '\n',
        'r', 'i', 'f', 'f', 'l', 'e', 'd', '\n',
        'r', 'i', 'f', 'f', 's', '\n',
        'r', 'i', 'f', 'l', 'e', '\n',
        'r', 'i', 'f', 'l', 'e', 'd', '\n',
        'r', 'i', 'f', 'l', 'e', 'm', 'a', 'n', '\n',
        'r', 'i', 'f', 'l', 'e', 'm', 'e', 'n', '\n',
        'r', 'i', 'f', 'l', 'e', 's', '\n',
        'r', 'i', 'f', 'l', 'i', 'n', 'g', '\n',
        'r', 'i', 'f', 'l', 'i', 'n', 'g', 's', '\n',
        'r', 'i', 'f', 't', '\n',
        'r', 'i', 'f', 't', 'i', 'n', 'g', '\n',
        'r', 'i', 'f', 't', 's', '\n',
        'r', 'i', 'g', '\n',
        'r', 'i', 'g', 'g', 'e', 'd', '\n',
        'r', 'i', 'g', 'g', 'e', 'r', '\n',
        'r', 'i', 'g', 'g', 'e', 'r', 's', '\n',
        'r', 'i', 'g', 'g', 'i', 'n', 'g', '\n',
        'r', 'i', 'g', 'h', 't', '\n',
        'r', 'i', 'g', 'h', 't', 'e', 'd', '\n',
        'r', 'i', 'g', 'h', 't', 'e', 'n', '\n',
        'r', 'i', 'g', 'h', 't', 'e', 'o', 'u', 's', '\n',
        'r', 'i', 'g', 'h', 't', 'e', 'o', 'u', 's', 'l', 'y', '\n',
        'r', 'i', 'g', 'h', 't', 'e', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'r', 'i', 'g', 'h', 't', 'e', 'r', '\n',
        'r', 'i', 'g', 'h', 't', 'f', 'u', 'l', '\n',
        'r', 'i', 'g', 'h', 't', 'f', 'u', 'l', 'l', 'y', '\n',
        'r', 'i', 'g', 'h', 't', 'h', 'a', 'n', 'd', '\n',
        'r', 'i', 'g', 'h', 't', 'h', 'a', 'n', 'd', 'e', 'd', '\n',
        'r', 'i', 'g', 'h', 't', 'h', 'a', 'n', 'd', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'r', 'i', 'g', 'h', 't', 'h', 'a', 'n', 'd', 'e', 'r', '\n',
        'r', 'i', 'g', 'h', 't', 'h', 'a', 'n', 'd', 'e', 'r', 's', '\n',
        'r', 'i', 'g', 'h', 't', 'i', 'n', 'g', '\n',
        'r', 'i', 'g', 'h', 't', 'i', 's', 't', '\n',
        'r', 'i', 'g', 'h', 't', 'l', 'y', '\n',
        'r', 'i', 'g', 'h', 't', 'm', 'i', 'n', 'd', 'e', 'd', '\n',
        'r', 'i', 'g', 'h', 't', 'm', 'o', 's', 't', '\n',
        'r', 'i', 'g', 'h', 't', 'n', 'e', 's', 's', '\n',
        'r', 'i', 'g', 'h', 't', 's', '\n',
        'r', 'i', 'g', 'h', 't', 't', 'h', 'i', 'n', 'k', 'i', 'n', 'g', '\n',
        'r', 'i', 'g', 'h', 't', 'w', 'a', 'r', 'd', '\n',
        'r', 'i', 'g', 'h', 't', 'w', 'a', 'r', 'd', 's', '\n',
        'r', 'i', 'g', 'h', 't', 'w', 'i', 'n', 'g', '\n',
        'r', 'i', 'g', 'h', 't', 'w', 'i', 'n', 'g', 'e', 'r', '\n',
        'r', 'i', 'g', 'h', 't', 'w', 'i', 'n', 'g', 'e', 'r', 's', '\n',
        'r', 'i', 'g', 'i', 'd', '\n',
        'r', 'i', 'g', 'i', 'd', 'i', 'f', 'i', 'e', 's', '\n',
        'r', 'i', 'g', 'i', 'd', 'i', 'f', 'y', '\n',
        'r', 'i', 'g', 'i', 'd', 'i', 't', 'i', 'e', 's', '\n',
        'r', 'i', 'g', 'i', 'd', 'i', 't', 'y', '\n',
        'r', 'i', 'g', 'i', 'd', 'l', 'y', '\n',
        'r', 'i', 'g', 'm', 'a', 'r', 'o', 'l', 'e', '\n',
        'r', 'i', 'g', 'o', 'r', '\n',
        'r', 'i', 'g', 'o', 'r', 'o', 'u', 's', '\n',
        'r', 'i', 'g', 'o', 'r', 'o', 'u', 's', 'l', 'y', '\n',
        'r', 'i', 'g', 'o', 'u', 'r', '\n',
        'r', 'i', 'g', 'o', 'u', 'r', 's', '\n',
        'r', 'i', 'g', 's', '\n',
        'r', 'i', 'l', 'e', '\n',
        'r', 'i', 'l', 'e', 'd', '\n',
        'r', 'i', 'l', 'e', 's', '\n',
        'r', 'i', 'l', 'i', 'n', 'g', '\n',
        'r', 'i', 'l', 'l', '\n',
        'r', 'i', 'l', 'l', 's', '\n',
        'r', 'i', 'm', '\n',
        'r', 'i', 'm', 'e', '\n',
        'r', 'i', 'm', 'l', 'e', 's', 's', '\n',
        'r', 'i', 'm', 'm', 'e', 'd', '\n',
        'r', 'i', 'm', 's', '\n',
        'r', 'i', 'n', 'd', '\n',
        'r', 'i', 'n', 'd', 's', '\n',
        'r', 'i', 'n', 'g', '\n',
        'r', 'i', 'n', 'g', 'e', 'd', '\n',
        'r', 'i', 'n', 'g', 'e', 'r', '\n',
        'r', 'i', 'n', 'g', 'e', 'r', 's', '\n',
        'r', 'i', 'n', 'g', 'i', 'n', 'g', '\n',
        'r', 'i', 'n', 'g', 'i', 'n', 'g', 'l', 'y', '\n',
        'r', 'i', 'n', 'g', 'l', 'e', 'a', 'd', 'e', 'r', '\n',
        'r', 'i', 'n', 'g', 'l', 'e', 'a', 'd', 'e', 'r', 's', '\n',
        'r', 'i', 'n', 'g', 'l', 'e', 's', 's', '\n',
        'r', 'i', 'n', 'g', 'l', 'e', 't', '\n',
        'r', 'i', 'n', 'g', 'l', 'e', 't', 's', '\n',
        'r', 'i', 'n', 'g', 'm', 'a', 's', 't', 'e', 'r', '\n',
        'r', 'i', 'n', 'g', 's', '\n',
        'r', 'i', 'n', 'g', 's', 'i', 'd', 'e', '\n',
        'r', 'i', 'n', 'g', 'w', 'o', 'r', 'm', '\n',
        'r', 'i', 'n', 'k', '\n',
        'r', 'i', 'n', 'k', 's', '\n',
        'r', 'i', 'n', 's', 'e', '\n',
        'r', 'i', 'n', 's', 'e', 'd', '\n',
        'r', 'i', 'n', 's', 'e', 's', '\n',
        'r', 'i', 'n', 's', 'i', 'n', 'g', '\n',
        'r', 'i', 'o', 't', '\n',
        'r', 'i', 'o', 't', 'e', 'd', '\n',
        'r', 'i', 'o', 't', 'e', 'r', '\n',
        'r', 'i', 'o', 't', 'e', 'r', 's', '\n',
        'r', 'i', 'o', 't', 'i', 'n', 'g', '\n',
        'r', 'i', 'o', 't', 'o', 'u', 's', '\n',
        'r', 'i', 'o', 't', 'o', 'u', 's', 'l', 'y', '\n',
        'r', 'i', 'o', 't', 's', '\n',
        'r', 'i', 'p', '\n',
        'r', 'i', 'p', 'c', 'o', 'r', 'd', '\n',
        'r', 'i', 'p', 'e', '\n',
        'r', 'i', 'p', 'e', 'l', 'y', '\n',
        'r', 'i', 'p', 'e', 'n', '\n',
        'r', 'i', 'p', 'e', 'n', 'e', 'd', '\n',
        'r', 'i', 'p', 'e', 'n', 'e', 's', 's', '\n',
        'r', 'i', 'p', 'e', 'n', 'i', 'n', 'g', '\n',
        'r', 'i', 'p', 'e', 'n', 's', '\n',
        'r', 'i', 'p', 'e', 'r', '\n',
        'r', 'i', 'p', 'e', 's', 't', '\n',
        'r', 'i', 'p', 'i', 'n', 'g', '\n',
        'r', 'i', 'p', 'o', 'f', 'f', '\n',
        'r', 'i', 'p', 'o', 's', 't', 'e', '\n',
        'r', 'i', 'p', 'o', 's', 't', 'e', 'd', '\n',
        'r', 'i', 'p', 'o', 's', 't', 'e', 's', '\n',
        'r', 'i', 'p', 'p', 'e', 'd', '\n',
        'r', 'i', 'p', 'p', 'e', 'r', '\n',
        'r', 'i', 'p', 'p', 'e', 'r', 's', '\n',
        'r', 'i', 'p', 'p', 'i', 'n', 'g', '\n',
        'r', 'i', 'p', 'p', 'l', 'e', '\n',
        'r', 'i', 'p', 'p', 'l', 'e', 'd', '\n',
        'r', 'i', 'p', 'p', 'l', 'e', 's', '\n',
        'r', 'i', 'p', 'p', 'l', 'i', 'n', 'g', '\n',
        'r', 'i', 'p', 's', '\n',
        'r', 'i', 'p', 's', 't', 'o', 'p', '\n',
        'r', 'i', 's', 'e', '\n',
        'r', 'i', 's', 'e', 'n', '\n',
        'r', 'i', 's', 'e', 'r', '\n',
        'r', 'i', 's', 'e', 'r', 's', '\n',
        'r', 'i', 's', 'e', 's', '\n',
        'r', 'i', 's', 'i', 'b', 'l', 'e', '\n',
        'r', 'i', 's', 'i', 'n', 'g', '\n',
        'r', 'i', 's', 'i', 'n', 'g', 's', '\n',
        'r', 'i', 's', 'k', '\n',
        'r', 'i', 's', 'k', 'e', 'd', '\n',
        'r', 'i', 's', 'k', 'i', 'e', 'r', '\n',
        'r', 'i', 's', 'k', 'i', 'e', 's', 't', '\n',
        'r', 'i', 's', 'k', 'i', 'n', 'e', 's', 's', '\n',
        'r', 'i', 's', 'k', 'i', 'n', 'g', '\n',
        'r', 'i', 's', 'k', 's', '\n',
        'r', 'i', 's', 'k', 'y', '\n',
        'r', 'i', 's', 'o', 't', 't', 'o', '\n',
        'r', 'i', 's', 'q', 'u', 'e', '\n',
        'r', 'i', 's', 's', 'o', 'l', 'e', '\n',
        'r', 'i', 's', 's', 'o', 'l', 'e', 's', '\n',
        'r', 'i', 't', 'e', '\n',
        'r', 'i', 't', 'e', 's', '\n',
        'r', 'i', 't', 'u', 'a', 'l', '\n',
        'r', 'i', 't', 'u', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'r', 'i', 't', 'u', 'a', 'l', 'i', 's', 't', 'i', 'c', '\n',
        'r', 'i', 't', 'u', 'a', 'l', 'i', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'r', 'i', 't', 'u', 'a', 'l', 'l', 'y', '\n',
        'r', 'i', 't', 'u', 'a', 'l', 's', '\n',
        'r', 'i', 'v', 'a', 'l', '\n',
        'r', 'i', 'v', 'a', 'l', 'l', 'e', 'd', '\n',
        'r', 'i', 'v', 'a', 'l', 'l', 'i', 'n', 'g', '\n',
        'r', 'i', 'v', 'a', 'l', 'r', 'i', 'e', 's', '\n',
        'r', 'i', 'v', 'a', 'l', 'r', 'y', '\n',
        'r', 'i', 'v', 'a', 'l', 's', '\n',
        'r', 'i', 'v', 'e', 'n', '\n',
        'r', 'i', 'v', 'e', 'r', '\n',
        'r', 'i', 'v', 'e', 'r', 'i', 'n', 'e', '\n',
        'r', 'i', 'v', 'e', 'r', 's', '\n',
        'r', 'i', 'v', 'e', 'r', 's', 'i', 'd', 'e', '\n',
        'r', 'i', 'v', 'e', 't', '\n',
        'r', 'i', 'v', 'e', 't', 'e', 'd', '\n',
        'r', 'i', 'v', 'e', 't', 'e', 'r', '\n',
        'r', 'i', 'v', 'e', 't', 'i', 'n', 'g', '\n',
        'r', 'i', 'v', 'e', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'r', 'i', 'v', 'e', 't', 's', '\n',
        'r', 'i', 'v', 'i', 'e', 'r', 'a', '\n',
        'r', 'i', 'v', 'u', 'l', 'e', 't', '\n',
        'r', 'i', 'v', 'u', 'l', 'e', 't', 's', '\n',
        'r', 'o', 'a', 'c', 'h', '\n',
        'r', 'o', 'a', 'c', 'h', 'e', 's', '\n',
        'r', 'o', 'a', 'd', '\n',
        'r', 'o', 'a', 'd', 'b', 'l', 'o', 'c', 'k', '\n',
        'r', 'o', 'a', 'd', 'b', 'l', 'o', 'c', 'k', 's', '\n',
        'r', 'o', 'a', 'd', 'h', 'o', 'u', 's', 'e', '\n',
        'r', 'o', 'a', 'd', 'm', 'a', 'p', '\n',
        'r', 'o', 'a', 'd', 's', '\n',
        'r', 'o', 'a', 'd', 's', 'h', 'o', 'w', '\n',
        'r', 'o', 'a', 'd', 's', 'h', 'o', 'w', 's', '\n',
        'r', 'o', 'a', 'd', 's', 'i', 'd', 'e', '\n',
        'r', 'o', 'a', 'd', 's', 'i', 'd', 'e', 's', '\n',
        'r', 'o', 'a', 'd', 's', 'i', 'g', 'n', 's', '\n',
        'r', 'o', 'a', 'd', 's', 't', 'e', 'r', '\n',
        'r', 'o', 'a', 'd', 's', 'w', 'e', 'e', 'p', 'e', 'r', 's', '\n',
        'r', 'o', 'a', 'd', 'w', 'a', 'y', '\n',
        'r', 'o', 'a', 'd', 'w', 'a', 'y', 's', '\n',
        'r', 'o', 'a', 'd', 'w', 'o', 'r', 'k', 's', '\n',
        'r', 'o', 'a', 'd', 'w', 'o', 'r', 't', 'h', 'y', '\n',
        'r', 'o', 'a', 'm', '\n',
        'r', 'o', 'a', 'm', 'e', 'd', '\n',
        'r', 'o', 'a', 'm', 'e', 'r', '\n',
        'r', 'o', 'a', 'm', 'i', 'n', 'g', '\n',
        'r', 'o', 'a', 'm', 's', '\n',
        'r', 'o', 'a', 'n', '\n',
        'r', 'o', 'a', 'r', '\n',
        'r', 'o', 'a', 'r', 'e', 'd', '\n',
        'r', 'o', 'a', 'r', 'e', 'r', '\n',
        'r', 'o', 'a', 'r', 'i', 'n', 'g', '\n',
        'r', 'o', 'a', 'r', 's', '\n',
        'r', 'o', 'a', 's', 't', '\n',
        'r', 'o', 'a', 's', 't', 'e', 'd', '\n',
        'r', 'o', 'a', 's', 't', 'e', 'r', '\n',
        'r', 'o', 'a', 's', 't', 'i', 'n', 'g', '\n',
        'r', 'o', 'a', 's', 't', 's', '\n',
        'r', 'o', 'b', '\n',
        'r', 'o', 'b', 'b', 'e', 'd', '\n',
        'r', 'o', 'b', 'b', 'e', 'r', '\n',
        'r', 'o', 'b', 'b', 'e', 'r', 'i', 'e', 's', '\n',
        'r', 'o', 'b', 'b', 'e', 'r', 's', '\n',
        'r', 'o', 'b', 'b', 'e', 'r', 'y', '\n',
        'r', 'o', 'b', 'b', 'i', 'n', 'g', '\n',
        'r', 'o', 'b', 'e', '\n',
        'r', 'o', 'b', 'e', 'd', '\n',
        'r', 'o', 'b', 'e', 's', '\n',
        'r', 'o', 'b', 'i', 'n', '\n',
        'r', 'o', 'b', 'i', 'n', 's', '\n',
        'r', 'o', 'b', 'o', 't', '\n',
        'r', 'o', 'b', 'o', 't', 'i', 'c', '\n',
        'r', 'o', 'b', 'o', 't', 'i', 'c', 's', '\n',
        'r', 'o', 'b', 'o', 't', 's', '\n',
        'r', 'o', 'b', 's', '\n',
        'r', 'o', 'b', 'u', 's', 't', '\n',
        'r', 'o', 'b', 'u', 's', 't', 'l', 'y', '\n',
        'r', 'o', 'b', 'u', 's', 't', 'n', 'e', 's', 's', '\n',
        'r', 'o', 'c', '\n',
        'r', 'o', 'c', 'k', '\n',
        'r', 'o', 'c', 'k', 'b', 'o', 't', 't', 'o', 'm', '\n',
        'r', 'o', 'c', 'k', 'e', 'd', '\n',
        'r', 'o', 'c', 'k', 'e', 'r', '\n',
        'r', 'o', 'c', 'k', 'e', 'r', 's', '\n',
        'r', 'o', 'c', 'k', 'e', 'r', 'y', '\n',
        'r', 'o', 'c', 'k', 'e', 't', '\n',
        'r', 'o', 'c', 'k', 'e', 't', 'e', 'd', '\n',
        'r', 'o', 'c', 'k', 'e', 't', 'i', 'n', 'g', '\n',
        'r', 'o', 'c', 'k', 'e', 't', 'r', 'y', '\n',
        'r', 'o', 'c', 'k', 'e', 't', 's', '\n',
        'r', 'o', 'c', 'k', 'f', 'a', 'l', 'l', '\n',
        'r', 'o', 'c', 'k', 'f', 'a', 'l', 'l', 's', '\n',
        'r', 'o', 'c', 'k', 'i', 'e', 'r', '\n',
        'r', 'o', 'c', 'k', 'i', 'e', 's', 't', '\n',
        'r', 'o', 'c', 'k', 'i', 'n', 'g', '\n',
        'r', 'o', 'c', 'k', 's', '\n',
        'r', 'o', 'c', 'k', 's', 'o', 'l', 'i', 'd', '\n',
        'r', 'o', 'c', 'k', 'y', '\n',
        'r', 'o', 'c', 'o', 'c', 'o', '\n',
        'r', 'o', 'c', 's', '\n',
        'r', 'o', 'd', '\n',
        'r', 'o', 'd', 'e', '\n',
        'r', 'o', 'd', 'e', 'n', 't', '\n',
        'r', 'o', 'd', 'e', 'n', 't', 's', '\n',
        'r', 'o', 'd', 'e', 'o', '\n',
        'r', 'o', 'd', 'e', 'o', 's', '\n',
        'r', 'o', 'd', 's', '\n',
        'r', 'o', 'e', '\n',
        'r', 'o', 'e', 'b', 'u', 'c', 'k', '\n',
        'r', 'o', 'e', 'n', 't', 'g', 'e', 'n', '\n',
        'r', 'o', 'e', 's', '\n',
        'r', 'o', 'g', 'u', 'e', '\n',
        'r', 'o', 'g', 'u', 'e', 'r', 'y', '\n',
        'r', 'o', 'g', 'u', 'e', 's', '\n',
        'r', 'o', 'g', 'u', 'i', 's', 'h', '\n',
        'r', 'o', 'g', 'u', 'i', 's', 'h', 'l', 'y', '\n',
        'r', 'o', 'g', 'u', 'i', 's', 'h', 'n', 'e', 's', 's', '\n',
        'r', 'o', 'i', 's', 't', 'e', 'r', '\n',
        'r', 'o', 'i', 's', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'r', 'o', 'l', 'e', '\n',
        'r', 'o', 'l', 'e', 's', '\n',
        'r', 'o', 'l', 'l', '\n',
        'r', 'o', 'l', 'l', 'c', 'a', 'l', 'l', '\n',
        'r', 'o', 'l', 'l', 'e', 'd', '\n',
        'r', 'o', 'l', 'l', 'e', 'r', '\n',
        'r', 'o', 'l', 'l', 'e', 'r', 'c', 'o', 'a', 's', 't', 'e', 'r', '\n',
        'r', 'o', 'l', 'l', 'e', 'r', 's', '\n',
        'r', 'o', 'l', 'l', 'e', 'r', 's', 'k', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'o', 'l', 'l', 'i', 'c', 'k', 'i', 'n', 'g', '\n',
        'r', 'o', 'l', 'l', 'i', 'n', 'g', '\n',
        'r', 'o', 'l', 'l', 's', '\n',
        'r', 'o', 'l', 'y', 'p', 'o', 'l', 'y', '\n',
        'r', 'o', 'm', '\n',
        'r', 'o', 'm', 'a', 'n', '\n',
        'r', 'o', 'm', 'a', 'n', 'c', 'e', '\n',
        'r', 'o', 'm', 'a', 'n', 'c', 'e', 'd', '\n',
        'r', 'o', 'm', 'a', 'n', 'c', 'e', 'r', '\n',
        'r', 'o', 'm', 'a', 'n', 'c', 'e', 's', '\n',
        'r', 'o', 'm', 'a', 'n', 'c', 'i', 'n', 'g', '\n',
        'r', 'o', 'm', 'a', 'n', 's', '\n',
        'r', 'o', 'm', 'a', 'n', 't', 'i', 'c', '\n',
        'r', 'o', 'm', 'a', 'n', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'r', 'o', 'm', 'a', 'n', 't', 'i', 'c', 'i', 's', 'e', 'd', '\n',
        'r', 'o', 'm', 'a', 'n', 't', 'i', 'c', 'i', 's', 'e', 's', '\n',
        'r', 'o', 'm', 'a', 'n', 't', 'i', 'c', 'i', 's', 'i', 'n', 'g', '\n',
        'r', 'o', 'm', 'a', 'n', 't', 'i', 'c', 'i', 's', 'm', '\n',
        'r', 'o', 'm', 'a', 'n', 't', 'i', 'c', 's', '\n',
        'r', 'o', 'm', 'a', 'n', 'y', '\n',
        'r', 'o', 'm', 'e', '\n',
        'r', 'o', 'm', 'm', 'e', 'l', '\n',
        'r', 'o', 'm', 'p', '\n',
        'r', 'o', 'm', 'p', 'e', 'd', '\n',
        'r', 'o', 'm', 'p', 'e', 'r', '\n',
        'r', 'o', 'm', 'p', 'i', 'n', 'g', '\n',
        'r', 'o', 'm', 'p', 's', '\n',
        'r', 'o', 'm', 'u', 'l', 'u', 's', '\n',
        'r', 'o', 'n', 'd', 'a', 'v', 'e', 'l', '\n',
        'r', 'o', 'o', '\n',
        'r', 'o', 'o', 'f', '\n',
        'r', 'o', 'o', 'f', 'e', 'd', '\n',
        'r', 'o', 'o', 'f', 'e', 'r', '\n',
        'r', 'o', 'o', 'f', 'g', 'a', 'r', 'd', 'e', 'n', '\n',
        'r', 'o', 'o', 'f', 'i', 'n', 'g', '\n',
        'r', 'o', 'o', 'f', 'i', 'n', 'g', 's', '\n',
        'r', 'o', 'o', 'f', 'l', 'e', 's', 's', '\n',
        'r', 'o', 'o', 'f', 's', '\n',
        'r', 'o', 'o', 'f', 't', 'o', 'p', '\n',
        'r', 'o', 'o', 'f', 't', 'o', 'p', 's', '\n',
        'r', 'o', 'o', 'i', 'b', 'o', 's', '\n',
        'r', 'o', 'o', 'k', '\n',
        'r', 'o', 'o', 'k', 'e', 'r', 'i', 'e', 's', '\n',
        'r', 'o', 'o', 'k', 'e', 'r', 'y', '\n',
        'r', 'o', 'o', 'k', 'i', 'e', 's', '\n',
        'r', 'o', 'o', 'k', 's', '\n',
        'r', 'o', 'o', 'm', '\n',
        'r', 'o', 'o', 'm', 'f', 'u', 'l', '\n',
        'r', 'o', 'o', 'm', 'i', 'e', 'r', '\n',
        'r', 'o', 'o', 'm', 'i', 'e', 's', 't', '\n',
        'r', 'o', 'o', 'm', 'm', 'a', 't', 'e', '\n',
        'r', 'o', 'o', 'm', 's', '\n',
        'r', 'o', 'o', 'm', 'y', '\n',
        'r', 'o', 'o', 's', 't', '\n',
        'r', 'o', 'o', 's', 't', 'e', 'd', '\n',
        'r', 'o', 'o', 's', 't', 'e', 'r', '\n',
        'r', 'o', 'o', 's', 't', 'e', 'r', 's', '\n',
        'r', 'o', 'o', 's', 't', 'i', 'n', 'g', '\n',
        'r', 'o', 'o', 's', 't', 's', '\n',
        'r', 'o', 'o', 't', '\n',
        'r', 'o', 'o', 't', 'e', 'd', '\n',
        'r', 'o', 'o', 't', 'i', 'n', 'g', '\n',
        'r', 'o', 'o', 't', 'i', 'n', 'g', 's', '\n',
        'r', 'o', 'o', 't', 'l', 'e', 's', 's', '\n',
        'r', 'o', 'o', 't', 's', '\n',
        'r', 'o', 'p', 'e', '\n',
        'r', 'o', 'p', 'e', 'd', '\n',
        'r', 'o', 'p', 'e', 's', '\n',
        'r', 'o', 'p', 'i', 'n', 'g', '\n',
        'r', 'o', 's', 'a', 'r', 'i', 'e', 's', '\n',
        'r', 'o', 's', 'a', 'r', 'y', '\n',
        'r', 'o', 's', 'e', '\n',
        'r', 'o', 's', 'e', 'b', 'u', 'd', '\n',
        'r', 'o', 's', 'e', 'b', 'u', 'd', 's', '\n',
        'r', 'o', 's', 'e', 'b', 'u', 's', 'h', '\n',
        'r', 'o', 's', 'e', 'm', 'a', 'r', 'y', '\n',
        'r', 'o', 's', 'e', 's', '\n',
        'r', 'o', 's', 'e', 't', 't', 'e', '\n',
        'r', 'o', 's', 'e', 't', 't', 'e', 's', '\n',
        'r', 'o', 's', 'e', 'w', 'o', 'o', 'd', '\n',
        'r', 'o', 's', 'i', 'e', 'r', '\n',
        'r', 'o', 's', 'i', 'e', 's', 't', '\n',
        'r', 'o', 's', 'i', 'l', 'y', '\n',
        'r', 'o', 's', 'i', 'n', '\n',
        'r', 'o', 's', 't', 'e', 'r', '\n',
        'r', 'o', 's', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'r', 'o', 's', 't', 'e', 'r', 's', '\n',
        'r', 'o', 's', 't', 'r', 'u', 'm', '\n',
        'r', 'o', 's', 't', 'r', 'u', 'm', 's', '\n',
        'r', 'o', 's', 'y', '\n',
        'r', 'o', 't', '\n',
        'r', 'o', 't', 'a', '\n',
        'r', 'o', 't', 'a', 'r', 'y', '\n',
        'r', 'o', 't', 'a', 's', '\n',
        'r', 'o', 't', 'a', 't', 'a', 'b', 'l', 'e', '\n',
        'r', 'o', 't', 'a', 't', 'e', '\n',
        'r', 'o', 't', 'a', 't', 'e', 'd', '\n',
        'r', 'o', 't', 'a', 't', 'e', 's', '\n',
        'r', 'o', 't', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'o', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'o', 't', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'r', 'o', 't', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'r', 'o', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'o', 't', 'a', 't', 'o', 'r', '\n',
        'r', 'o', 't', 'a', 't', 'o', 'r', 's', '\n',
        'r', 'o', 't', 'a', 't', 'o', 'r', 'y', '\n',
        'r', 'o', 't', 'e', '\n',
        'r', 'o', 't', 'o', 'r', '\n',
        'r', 'o', 't', 'o', 'r', 's', '\n',
        'r', 'o', 't', 's', '\n',
        'r', 'o', 't', 't', 'e', 'd', '\n',
        'r', 'o', 't', 't', 'e', 'n', '\n',
        'r', 'o', 't', 't', 'e', 'n', 'l', 'y', '\n',
        'r', 'o', 't', 't', 'e', 'n', 'n', 'e', 's', 's', '\n',
        'r', 'o', 't', 't', 'e', 'r', '\n',
        'r', 'o', 't', 't', 'i', 'n', 'g', '\n',
        'r', 'o', 't', 'u', 'n', 'd', '\n',
        'r', 'o', 't', 'u', 'n', 'd', 'a', '\n',
        'r', 'o', 't', 'u', 'n', 'd', 'i', 't', 'y', '\n',
        'r', 'o', 'u', 'b', 'l', 'e', '\n',
        'r', 'o', 'u', 'b', 'l', 'e', 's', '\n',
        'r', 'o', 'u', 'g', 'e', '\n',
        'r', 'o', 'u', 'g', 'e', 'd', '\n',
        'r', 'o', 'u', 'g', 'e', 's', '\n',
        'r', 'o', 'u', 'g', 'h', '\n',
        'r', 'o', 'u', 'g', 'h', 'a', 'g', 'e', '\n',
        'r', 'o', 'u', 'g', 'h', 'e', 'd', '\n',
        'r', 'o', 'u', 'g', 'h', 'e', 'n', '\n',
        'r', 'o', 'u', 'g', 'h', 'e', 'n', 'e', 'd', '\n',
        'r', 'o', 'u', 'g', 'h', 'e', 'n', 's', '\n',
        'r', 'o', 'u', 'g', 'h', 'e', 'r', '\n',
        'r', 'o', 'u', 'g', 'h', 'e', 's', 't', '\n',
        'r', 'o', 'u', 'g', 'h', 'i', 'e', '\n',
        'r', 'o', 'u', 'g', 'h', 'i', 'n', 'g', '\n',
        'r', 'o', 'u', 'g', 'h', 'l', 'y', '\n',
        'r', 'o', 'u', 'g', 'h', 'n', 'e', 's', 's', '\n',
        'r', 'o', 'u', 'g', 'h', 's', '\n',
        'r', 'o', 'u', 'g', 'h', 's', 'h', 'o', 'd', '\n',
        'r', 'o', 'u', 'l', 'e', 't', 't', 'e', '\n',
        'r', 'o', 'u', 'n', 'd', '\n',
        'r', 'o', 'u', 'n', 'd', 'a', 'b', 'o', 'u', 't', '\n',
        'r', 'o', 'u', 'n', 'd', 'a', 'b', 'o', 'u', 't', 's', '\n',
        'r', 'o', 'u', 'n', 'd', 'e', 'd', '\n',
        'r', 'o', 'u', 'n', 'd', 'e', 'l', '\n',
        'r', 'o', 'u', 'n', 'd', 'e', 'l', 's', '\n',
        'r', 'o', 'u', 'n', 'd', 'e', 'r', '\n',
        'r', 'o', 'u', 'n', 'd', 'e', 'r', 's', '\n',
        'r', 'o', 'u', 'n', 'd', 'e', 's', 't', '\n',
        'r', 'o', 'u', 'n', 'd', 'h', 'o', 'u', 's', 'e', '\n',
        'r', 'o', 'u', 'n', 'd', 'i', 'n', 'g', '\n',
        'r', 'o', 'u', 'n', 'd', 'i', 's', 'h', '\n',
        'r', 'o', 'u', 'n', 'd', 'l', 'y', '\n',
        'r', 'o', 'u', 'n', 'd', 'n', 'e', 's', 's', '\n',
        'r', 'o', 'u', 'n', 'd', 's', '\n',
        'r', 'o', 'u', 'n', 'd', 't', 'h', 'e', 'c', 'l', 'o', 'c', 'k', '\n',
        'r', 'o', 'u', 'n', 'd', 'u', 'p', '\n',
        'r', 'o', 'u', 'n', 'd', 'u', 'p', 's', '\n',
        'r', 'o', 'u', 's', 'e', '\n',
        'r', 'o', 'u', 's', 'e', 'd', '\n',
        'r', 'o', 'u', 's', 'e', 's', '\n',
        'r', 'o', 'u', 's', 'i', 'n', 'g', '\n',
        'r', 'o', 'u', 't', '\n',
        'r', 'o', 'u', 't', 'e', '\n',
        'r', 'o', 'u', 't', 'e', 'd', '\n',
        'r', 'o', 'u', 't', 'e', 'i', 'n', 'g', '\n',
        'r', 'o', 'u', 't', 'e', 'r', '\n',
        'r', 'o', 'u', 't', 'e', 'r', 's', '\n',
        'r', 'o', 'u', 't', 'e', 's', '\n',
        'r', 'o', 'u', 't', 'i', 'n', 'e', '\n',
        'r', 'o', 'u', 't', 'i', 'n', 'e', 'l', 'y', '\n',
        'r', 'o', 'u', 't', 'i', 'n', 'e', 's', '\n',
        'r', 'o', 'u', 't', 'i', 'n', 'g', '\n',
        'r', 'o', 'u', 't', 's', '\n',
        'r', 'o', 'v', 'e', '\n',
        'r', 'o', 'v', 'e', 'd', '\n',
        'r', 'o', 'v', 'e', 'r', '\n',
        'r', 'o', 'v', 'e', 'r', 's', '\n',
        'r', 'o', 'v', 'e', 's', '\n',
        'r', 'o', 'v', 'i', 'n', 'g', '\n',
        'r', 'o', 'v', 'i', 'n', 'g', 's', '\n',
        'r', 'o', 'w', '\n',
        'r', 'o', 'w', 'b', 'o', 'a', 't', '\n',
        'r', 'o', 'w', 'b', 'o', 'a', 't', 's', '\n',
        'r', 'o', 'w', 'd', 'i', 'e', 'r', '\n',
        'r', 'o', 'w', 'd', 'i', 'e', 's', 't', '\n',
        'r', 'o', 'w', 'd', 'i', 'l', 'y', '\n',
        'r', 'o', 'w', 'd', 'i', 'n', 'e', 's', 's', '\n',
        'r', 'o', 'w', 'd', 'y', '\n',
        'r', 'o', 'w', 'd', 'y', 'i', 's', 'm', '\n',
        'r', 'o', 'w', 'e', 'd', '\n',
        'r', 'o', 'w', 'e', 'r', '\n',
        'r', 'o', 'w', 'e', 'r', 's', '\n',
        'r', 'o', 'w', 'i', 'n', 'g', '\n',
        'r', 'o', 'w', 's', '\n',
        'r', 'o', 'y', 'a', 'l', '\n',
        'r', 'o', 'y', 'a', 'l', 'i', 's', 't', '\n',
        'r', 'o', 'y', 'a', 'l', 'i', 's', 't', 's', '\n',
        'r', 'o', 'y', 'a', 'l', 'l', 'y', '\n',
        'r', 'o', 'y', 'a', 'l', 's', '\n',
        'r', 'o', 'y', 'a', 'l', 't', 'i', 'e', 's', '\n',
        'r', 'o', 'y', 'a', 'l', 't', 'y', '\n',
        'r', 'u', 'a', 'n', 'd', 'a', '\n',
        'r', 'u', 'b', '\n',
        'r', 'u', 'b', 'b', 'e', 'd', '\n',
        'r', 'u', 'b', 'b', 'e', 'r', '\n',
        'r', 'u', 'b', 'b', 'e', 'r', 'i', 's', 'e', 'd', '\n',
        'r', 'u', 'b', 'b', 'e', 'r', 's', '\n',
        'r', 'u', 'b', 'b', 'e', 'r', 's', 't', 'a', 'm', 'p', '\n',
        'r', 'u', 'b', 'b', 'e', 'r', 's', 't', 'a', 'm', 'p', 'e', 'd', '\n',
        'r', 'u', 'b', 'b', 'e', 'r', 's', 't', 'a', 'm', 'p', 'i', 'n', 'g', '\n',
        'r', 'u', 'b', 'b', 'e', 'r', 'y', '\n',
        'r', 'u', 'b', 'b', 'i', 'n', 'g', '\n',
        'r', 'u', 'b', 'b', 'i', 'n', 'g', 's', '\n',
        'r', 'u', 'b', 'b', 'i', 's', 'h', '\n',
        'r', 'u', 'b', 'b', 'i', 's', 'h', 'e', 'd', '\n',
        'r', 'u', 'b', 'b', 'i', 's', 'h', 'e', 's', '\n',
        'r', 'u', 'b', 'b', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'r', 'u', 'b', 'b', 'i', 's', 'h', 'y', '\n',
        'r', 'u', 'b', 'b', 'l', 'e', '\n',
        'r', 'u', 'b', 'b', 'l', 'e', 's', '\n',
        'r', 'u', 'b', 'e', 'l', 'l', 'a', '\n',
        'r', 'u', 'b', 'i', 'c', 'o', 'n', '\n',
        'r', 'u', 'b', 'i', 'c', 'u', 'n', 'd', '\n',
        'r', 'u', 'b', 'i', 'd', 'i', 'u', 'm', '\n',
        'r', 'u', 'b', 'i', 'e', 's', '\n',
        'r', 'u', 'b', 'r', 'i', 'c', '\n',
        'r', 'u', 'b', 's', '\n',
        'r', 'u', 'b', 'y', '\n',
        'r', 'u', 'c', 'k', '\n',
        'r', 'u', 'c', 'k', 's', '\n',
        'r', 'u', 'c', 'k', 's', 'a', 'c', 'k', '\n',
        'r', 'u', 'c', 'k', 's', 'a', 'c', 'k', 's', '\n',
        'r', 'u', 'c', 't', 'i', 'o', 'n', '\n',
        'r', 'u', 'c', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'u', 'd', 'd', 'e', 'r', '\n',
        'r', 'u', 'd', 'd', 'e', 'r', 'l', 'e', 's', 's', '\n',
        'r', 'u', 'd', 'd', 'e', 'r', 's', '\n',
        'r', 'u', 'd', 'd', 'i', 'n', 'e', 's', 's', '\n',
        'r', 'u', 'd', 'd', 'y', '\n',
        'r', 'u', 'd', 'e', '\n',
        'r', 'u', 'd', 'e', 'l', 'y', '\n',
        'r', 'u', 'd', 'e', 'n', 'e', 's', 's', '\n',
        'r', 'u', 'd', 'e', 'r', '\n',
        'r', 'u', 'd', 'e', 's', 't', '\n',
        'r', 'u', 'd', 'i', 'm', 'e', 'n', 't', 'a', 'r', 'y', '\n',
        'r', 'u', 'd', 'i', 'm', 'e', 'n', 't', 's', '\n',
        'r', 'u', 'e', '\n',
        'r', 'u', 'e', 'f', 'u', 'l', '\n',
        'r', 'u', 'e', 'f', 'u', 'l', 'l', 'y', '\n',
        'r', 'u', 'e', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'r', 'u', 'e', 's', '\n',
        'r', 'u', 'f', 'f', '\n',
        'r', 'u', 'f', 'f', 'i', 'a', 'n', '\n',
        'r', 'u', 'f', 'f', 'i', 'a', 'n', 's', '\n',
        'r', 'u', 'f', 'f', 'l', 'e', '\n',
        'r', 'u', 'f', 'f', 'l', 'e', 'd', '\n',
        'r', 'u', 'f', 'f', 'l', 'e', 's', '\n',
        'r', 'u', 'f', 'f', 'l', 'i', 'n', 'g', '\n',
        'r', 'u', 'f', 'f', 's', '\n',
        'r', 'u', 'g', '\n',
        'r', 'u', 'g', 'b', 'y', '\n',
        'r', 'u', 'g', 'g', 'e', 'd', '\n',
        'r', 'u', 'g', 'g', 'e', 'd', 'l', 'y', '\n',
        'r', 'u', 'g', 'g', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'r', 'u', 'g', 's', '\n',
        'r', 'u', 'i', 'n', '\n',
        'r', 'u', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'u', 'i', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'u', 'i', 'n', 'e', 'd', '\n',
        'r', 'u', 'i', 'n', 'e', 'r', '\n',
        'r', 'u', 'i', 'n', 'i', 'n', 'g', '\n',
        'r', 'u', 'i', 'n', 'o', 'u', 's', '\n',
        'r', 'u', 'i', 'n', 'o', 'u', 's', 'l', 'y', '\n',
        'r', 'u', 'i', 'n', 's', '\n',
        'r', 'u', 'l', 'e', '\n',
        'r', 'u', 'l', 'e', 'b', 'o', 'o', 'k', '\n',
        'r', 'u', 'l', 'e', 'b', 'o', 'o', 'k', 's', '\n',
        'r', 'u', 'l', 'e', 'd', '\n',
        'r', 'u', 'l', 'e', 'r', '\n',
        'r', 'u', 'l', 'e', 'r', 's', '\n',
        'r', 'u', 'l', 'e', 's', '\n',
        'r', 'u', 'l', 'i', 'n', 'g', '\n',
        'r', 'u', 'l', 'i', 'n', 'g', 's', '\n',
        'r', 'u', 'm', '\n',
        'r', 'u', 'm', 'a', 'n', 'i', 'a', '\n',
        'r', 'u', 'm', 'b', 'a', '\n',
        'r', 'u', 'm', 'b', 'a', 's', '\n',
        'r', 'u', 'm', 'b', 'l', 'e', '\n',
        'r', 'u', 'm', 'b', 'l', 'e', 'd', '\n',
        'r', 'u', 'm', 'b', 'l', 'e', 's', '\n',
        'r', 'u', 'm', 'b', 'l', 'i', 'n', 'g', '\n',
        'r', 'u', 'm', 'b', 'l', 'i', 'n', 'g', 's', '\n',
        'r', 'u', 'm', 'b', 'u', 's', 't', 'i', 'o', 'u', 's', '\n',
        'r', 'u', 'm', 'e', 'n', '\n',
        'r', 'u', 'm', 'i', 'n', 'a', 'n', 't', '\n',
        'r', 'u', 'm', 'i', 'n', 'a', 'n', 't', 's', '\n',
        'r', 'u', 'm', 'i', 'n', 'a', 't', 'e', '\n',
        'r', 'u', 'm', 'i', 'n', 'a', 't', 'e', 'd', '\n',
        'r', 'u', 'm', 'i', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'r', 'u', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'r', 'u', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'r', 'u', 'm', 'i', 'n', 'a', 't', 'i', 'v', 'e', '\n',
        'r', 'u', 'm', 'i', 'n', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'r', 'u', 'm', 'm', 'a', 'g', 'e', '\n',
        'r', 'u', 'm', 'm', 'a', 'g', 'e', 'd', '\n',
        'r', 'u', 'm', 'm', 'a', 'g', 'e', 's', '\n',
        'r', 'u', 'm', 'm', 'a', 'g', 'i', 'n', 'g', '\n',
        'r', 'u', 'm', 'm', 'y', '\n',
        'r', 'u', 'm', 'o', 'u', 'r', '\n',
        'r', 'u', 'm', 'o', 'u', 'r', 'e', 'd', '\n',
        'r', 'u', 'm', 'o', 'u', 'r', 's', '\n',
        'r', 'u', 'm', 'p', '\n',
        'r', 'u', 'm', 'p', 'l', 'e', '\n',
        'r', 'u', 'm', 'p', 'l', 'e', 'd', '\n',
        'r', 'u', 'm', 'p', 'l', 'i', 'n', 'g', '\n',
        'r', 'u', 'm', 'p', 's', '\n',
        'r', 'u', 'm', 'p', 'u', 's', '\n',
        'r', 'u', 'm', 'p', 'u', 's', 'e', 's', '\n',
        'r', 'u', 'n', '\n',
        'r', 'u', 'n', 'a', 'w', 'a', 'y', '\n',
        'r', 'u', 'n', 'd', 'o', 'w', 'n', '\n',
        'r', 'u', 'n', 'e', '\n',
        'r', 'u', 'n', 'e', 's', '\n',
        'r', 'u', 'n', 'g', '\n',
        'r', 'u', 'n', 'g', 's', '\n',
        'r', 'u', 'n', 'n', 'a', 'b', 'l', 'e', '\n',
        'r', 'u', 'n', 'n', 'e', 'r', '\n',
        'r', 'u', 'n', 'n', 'e', 'r', 's', '\n',
        'r', 'u', 'n', 'n', 'e', 'r', 's', 'u', 'p', '\n',
        'r', 'u', 'n', 'n', 'e', 'r', 'u', 'p', '\n',
        'r', 'u', 'n', 'n', 'i', 'e', 'r', '\n',
        'r', 'u', 'n', 'n', 'i', 'e', 's', 't', '\n',
        'r', 'u', 'n', 'n', 'i', 'n', 'g', '\n',
        'r', 'u', 'n', 'n', 'y', '\n',
        'r', 'u', 'n', 'o', 'f', 't', 'h', 'e', 'm', 'i', 'l', 'l', '\n',
        'r', 'u', 'n', 's', '\n',
        'r', 'u', 'n', 't', '\n',
        'r', 'u', 'n', 't', 's', '\n',
        'r', 'u', 'n', 'w', 'a', 'y', '\n',
        'r', 'u', 'n', 'w', 'a', 'y', 's', '\n',
        'r', 'u', 'p', 'e', 'e', '\n',
        'r', 'u', 'p', 'e', 'e', 's', '\n',
        'r', 'u', 'p', 'e', 'r', 't', '\n',
        'r', 'u', 'p', 't', 'u', 'r', 'e', '\n',
        'r', 'u', 'p', 't', 'u', 'r', 'e', 'd', '\n',
        'r', 'u', 'p', 't', 'u', 'r', 'e', 's', '\n',
        'r', 'u', 'p', 't', 'u', 'r', 'i', 'n', 'g', '\n',
        'r', 'u', 'r', 'a', 'l', '\n',
        'r', 'u', 'r', 'a', 'l', 'i', 's', 't', '\n',
        'r', 'u', 'r', 'a', 'l', 'l', 'y', '\n',
        'r', 'u', 's', 'e', '\n',
        'r', 'u', 's', 'h', '\n',
        'r', 'u', 's', 'h', 'e', 'd', '\n',
        'r', 'u', 's', 'h', 'e', 's', '\n',
        'r', 'u', 's', 'h', 'h', 'o', 'u', 'r', '\n',
        'r', 'u', 's', 'h', 'i', 'e', 'r', '\n',
        'r', 'u', 's', 'h', 'i', 'n', 'g', '\n',
        'r', 'u', 's', 'k', '\n',
        'r', 'u', 's', 'k', 's', '\n',
        'r', 'u', 's', 's', 'e', 't', '\n',
        'r', 'u', 's', 's', 'i', 'a', '\n',
        'r', 'u', 's', 's', 'i', 'a', 'n', '\n',
        'r', 'u', 's', 't', '\n',
        'r', 'u', 's', 't', 'e', 'd', '\n',
        'r', 'u', 's', 't', 'i', 'c', '\n',
        'r', 'u', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'r', 'u', 's', 't', 'i', 'c', 'a', 't', 'e', '\n',
        'r', 'u', 's', 't', 'i', 'c', 'a', 't', 'e', 'd', '\n',
        'r', 'u', 's', 't', 'i', 'c', 'i', 't', 'y', '\n',
        'r', 'u', 's', 't', 'i', 'c', 's', '\n',
        'r', 'u', 's', 't', 'i', 'e', 'r', '\n',
        'r', 'u', 's', 't', 'i', 'e', 's', 't', '\n',
        'r', 'u', 's', 't', 'i', 'n', 'e', 's', 's', '\n',
        'r', 'u', 's', 't', 'i', 'n', 'g', '\n',
        'r', 'u', 's', 't', 'l', 'e', '\n',
        'r', 'u', 's', 't', 'l', 'e', 'd', '\n',
        'r', 'u', 's', 't', 'l', 'e', 'r', '\n',
        'r', 'u', 's', 't', 'l', 'e', 'r', 's', '\n',
        'r', 'u', 's', 't', 'l', 'e', 's', '\n',
        'r', 'u', 's', 't', 'l', 'i', 'n', 'g', '\n',
        'r', 'u', 's', 't', 'p', 'r', 'o', 'o', 'f', '\n',
        'r', 'u', 's', 't', 's', '\n',
        'r', 'u', 's', 't', 'y', '\n',
        'r', 'u', 't', '\n',
        'r', 'u', 't', 'h', '\n',
        'r', 'u', 't', 'h', 'l', 'e', 's', 's', '\n',
        'r', 'u', 't', 'h', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'r', 'u', 't', 'h', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'r', 'u', 't', 's', '\n',
        'r', 'u', 't', 't', 'e', 'd', '\n',
        'r', 'w', 'a', 'n', 'd', 'a', '\n',
        'r', 'y', 'e', '\n',
        's', 'a', 'b', 'b', 'a', 't', '\n',
        's', 'a', 'b', 'b', 'a', 't', 'h', '\n',
        's', 'a', 'b', 'b', 'a', 't', 'h', 's', '\n',
        's', 'a', 'b', 'b', 'a', 't', 'i', 'c', 'a', 'l', '\n',
        's', 'a', 'b', 'b', 'a', 't', 'i', 'c', 'a', 'l', 's', '\n',
        's', 'a', 'b', 'e', 'r', '\n',
        's', 'a', 'b', 'l', 'e', '\n',
        's', 'a', 'b', 'l', 'e', 's', '\n',
        's', 'a', 'b', 'o', 't', 'a', 'g', 'e', '\n',
        's', 'a', 'b', 'o', 't', 'a', 'g', 'e', 'd', '\n',
        's', 'a', 'b', 'o', 't', 'a', 'g', 'e', 's', '\n',
        's', 'a', 'b', 'o', 't', 'a', 'g', 'i', 'n', 'g', '\n',
        's', 'a', 'b', 'o', 't', 'e', 'u', 'r', '\n',
        's', 'a', 'b', 'o', 't', 'e', 'u', 'r', 's', '\n',
        's', 'a', 'b', 'r', 'a', '\n',
        's', 'a', 'b', 'r', 'a', 's', '\n',
        's', 'a', 'b', 'r', 'e', '\n',
        's', 'a', 'b', 'r', 'e', 's', '\n',
        's', 'a', 'b', 'r', 'e', 't', 'o', 'o', 't', 'h', 'e', 'd', '\n',
        's', 'a', 'c', '\n',
        's', 'a', 'c', 'c', 'h', 'a', 'r', 'i', 'd', 'e', 's', '\n',
        's', 'a', 'c', 'c', 'h', 'a', 'r', 'i', 'n', '\n',
        's', 'a', 'c', 'c', 'h', 'a', 'r', 'i', 'n', 'e', '\n',
        's', 'a', 'c', 'e', 'r', 'd', 'o', 't', 'a', 'l', '\n',
        's', 'a', 'c', 'h', 'e', 't', '\n',
        's', 'a', 'c', 'h', 'e', 't', 's', '\n',
        's', 'a', 'c', 'k', '\n',
        's', 'a', 'c', 'k', 'c', 'l', 'o', 't', 'h', '\n',
        's', 'a', 'c', 'k', 'e', 'd', '\n',
        's', 'a', 'c', 'k', 'f', 'u', 'l', '\n',
        's', 'a', 'c', 'k', 'f', 'u', 'l', 's', '\n',
        's', 'a', 'c', 'k', 'i', 'n', 'g', '\n',
        's', 'a', 'c', 'k', 's', '\n',
        's', 'a', 'c', 'r', 'a', 'l', '\n',
        's', 'a', 'c', 'r', 'a', 'm', 'e', 'n', 't', '\n',
        's', 'a', 'c', 'r', 'a', 'm', 'e', 'n', 't', 'a', 'l', '\n',
        's', 'a', 'c', 'r', 'a', 'm', 'e', 'n', 't', 's', '\n',
        's', 'a', 'c', 'r', 'e', 'd', '\n',
        's', 'a', 'c', 'r', 'e', 'd', 'l', 'y', '\n',
        's', 'a', 'c', 'r', 'e', 'd', 'n', 'e', 's', 's', '\n',
        's', 'a', 'c', 'r', 'i', 'f', 'i', 'c', 'e', '\n',
        's', 'a', 'c', 'r', 'i', 'f', 'i', 'c', 'e', 'd', '\n',
        's', 'a', 'c', 'r', 'i', 'f', 'i', 'c', 'e', 's', '\n',
        's', 'a', 'c', 'r', 'i', 'f', 'i', 'c', 'i', 'a', 'l', '\n',
        's', 'a', 'c', 'r', 'i', 'f', 'i', 'c', 'i', 'n', 'g', '\n',
        's', 'a', 'c', 'r', 'i', 'l', 'e', 'g', 'e', '\n',
        's', 'a', 'c', 'r', 'i', 'l', 'e', 'g', 'i', 'o', 'u', 's', '\n',
        's', 'a', 'c', 'r', 'i', 's', 't', 'y', '\n',
        's', 'a', 'c', 'r', 'o', 's', 'a', 'n', 'c', 't', '\n',
        's', 'a', 'c', 'r', 'u', 'm', '\n',
        's', 'a', 'c', 's', '\n',
        's', 'a', 'd', '\n',
        's', 'a', 'd', 'd', 'e', 'n', '\n',
        's', 'a', 'd', 'd', 'e', 'n', 'e', 'd', '\n',
        's', 'a', 'd', 'd', 'e', 'n', 'i', 'n', 'g', '\n',
        's', 'a', 'd', 'd', 'e', 'n', 's', '\n',
        's', 'a', 'd', 'd', 'e', 'r', '\n',
        's', 'a', 'd', 'd', 'e', 's', 't', '\n',
        's', 'a', 'd', 'd', 'l', 'e', '\n',
        's', 'a', 'd', 'd', 'l', 'e', 'b', 'a', 'g', '\n',
        's', 'a', 'd', 'd', 'l', 'e', 'b', 'a', 'g', 's', '\n',
        's', 'a', 'd', 'd', 'l', 'e', 'd', '\n',
        's', 'a', 'd', 'd', 'l', 'e', 'r', '\n',
        's', 'a', 'd', 'd', 'l', 'e', 'r', 's', '\n',
        's', 'a', 'd', 'd', 'l', 'e', 's', '\n',
        's', 'a', 'd', 'd', 'l', 'i', 'n', 'g', '\n',
        's', 'a', 'd', 'i', 's', 'm', '\n',
        's', 'a', 'd', 'i', 's', 't', '\n',
        's', 'a', 'd', 'i', 's', 't', 'i', 'c', '\n',
        's', 'a', 'd', 'i', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 'a', 'd', 'i', 's', 't', 's', '\n',
        's', 'a', 'd', 'l', 'y', '\n',
        's', 'a', 'd', 'n', 'e', 's', 's', '\n',
        's', 'a', 'd', 'o', 'm', 'a', 's', 'o', 'c', 'h', 'i', 's', 'm', '\n',
        's', 'a', 'd', 'o', 'm', 'a', 's', 'o', 'c', 'h', 'i', 's', 't', 'i', 'c', '\n',
        's', 'a', 'd', 's', 'a', 'c', 'k', '\n',
        's', 'a', 'f', 'a', 'r', 'i', '\n',
        's', 'a', 'f', 'a', 'r', 'i', 's', '\n',
        's', 'a', 'f', 'e', '\n',
        's', 'a', 'f', 'e', 'g', 'u', 'a', 'r', 'd', '\n',
        's', 'a', 'f', 'e', 'g', 'u', 'a', 'r', 'd', 'e', 'd', '\n',
        's', 'a', 'f', 'e', 'g', 'u', 'a', 'r', 'd', 'i', 'n', 'g', '\n',
        's', 'a', 'f', 'e', 'g', 'u', 'a', 'r', 'd', 's', '\n',
        's', 'a', 'f', 'e', 'l', 'y', '\n',
        's', 'a', 'f', 'e', 'n', 'e', 's', 's', '\n',
        's', 'a', 'f', 'e', 'r', '\n',
        's', 'a', 'f', 'e', 's', '\n',
        's', 'a', 'f', 'e', 's', 't', '\n',
        's', 'a', 'f', 'e', 't', 'i', 'e', 's', '\n',
        's', 'a', 'f', 'e', 't', 'y', '\n',
        's', 'a', 'f', 'f', 'r', 'o', 'n', '\n',
        's', 'a', 'g', '\n',
        's', 'a', 'g', 'a', '\n',
        's', 'a', 'g', 'a', 'c', 'i', 'o', 'u', 's', '\n',
        's', 'a', 'g', 'a', 'c', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        's', 'a', 'g', 'a', 'c', 'i', 't', 'y', '\n',
        's', 'a', 'g', 'a', 's', '\n',
        's', 'a', 'g', 'e', '\n',
        's', 'a', 'g', 'e', 'l', 'y', '\n',
        's', 'a', 'g', 'e', 's', '\n',
        's', 'a', 'g', 'e', 's', 't', '\n',
        's', 'a', 'g', 'g', 'e', 'd', '\n',
        's', 'a', 'g', 'g', 'i', 'n', 'g', '\n',
        's', 'a', 'g', 'o', '\n',
        's', 'a', 'g', 's', '\n',
        's', 'a', 'h', 'a', 'r', 'a', '\n',
        's', 'a', 'h', 'i', 'b', '\n',
        's', 'a', 'i', 'd', '\n',
        's', 'a', 'i', 'g', 'o', 'n', '\n',
        's', 'a', 'i', 'l', '\n',
        's', 'a', 'i', 'l', 'c', 'l', 'o', 't', 'h', '\n',
        's', 'a', 'i', 'l', 'e', 'd', '\n',
        's', 'a', 'i', 'l', 'e', 'r', '\n',
        's', 'a', 'i', 'l', 'i', 'n', 'g', '\n',
        's', 'a', 'i', 'l', 'i', 'n', 'g', 's', '\n',
        's', 'a', 'i', 'l', 'm', 'a', 'k', 'e', 'r', '\n',
        's', 'a', 'i', 'l', 'o', 'r', '\n',
        's', 'a', 'i', 'l', 'o', 'r', 's', '\n',
        's', 'a', 'i', 'l', 's', '\n',
        's', 'a', 'i', 'n', 't', '\n',
        's', 'a', 'i', 'n', 't', 'e', 'd', '\n',
        's', 'a', 'i', 'n', 't', 'h', 'o', 'o', 'd', '\n',
        's', 'a', 'i', 'n', 't', 'l', 'i', 'e', 'r', '\n',
        's', 'a', 'i', 'n', 't', 'l', 'i', 'e', 's', 't', '\n',
        's', 'a', 'i', 'n', 't', 'l', 'i', 'n', 'e', 's', 's', '\n',
        's', 'a', 'i', 'n', 't', 'l', 'y', '\n',
        's', 'a', 'i', 'n', 't', 's', '\n',
        's', 'a', 'i', 'p', 'a', 'n', '\n',
        's', 'a', 'k', 'e', '\n',
        's', 'a', 'k', 'e', 's', '\n',
        's', 'a', 'k', 'i', '\n',
        's', 'a', 'l', 'a', 'a', 'm', '\n',
        's', 'a', 'l', 'a', 'c', 'i', 'o', 'u', 's', '\n',
        's', 'a', 'l', 'a', 'd', '\n',
        's', 'a', 'l', 'a', 'd', 's', '\n',
        's', 'a', 'l', 'a', 'm', 'a', 'n', 'd', 'e', 'r', '\n',
        's', 'a', 'l', 'a', 'm', 'a', 'n', 'd', 'e', 'r', 's', '\n',
        's', 'a', 'l', 'a', 'm', 'i', '\n',
        's', 'a', 'l', 'a', 'm', 'i', 's', '\n',
        's', 'a', 'l', 'a', 'r', 'i', 'e', 'd', '\n',
        's', 'a', 'l', 'a', 'r', 'i', 'e', 's', '\n',
        's', 'a', 'l', 'a', 'r', 'y', '\n',
        's', 'a', 'l', 'e', '\n',
        's', 'a', 'l', 'e', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        's', 'a', 'l', 'e', 'a', 'b', 'l', 'e', '\n',
        's', 'a', 'l', 'e', 'm', '\n',
        's', 'a', 'l', 'e', 's', '\n',
        's', 'a', 'l', 'e', 's', 'g', 'i', 'r', 'l', '\n',
        's', 'a', 'l', 'e', 's', 'm', 'a', 'n', '\n',
        's', 'a', 'l', 'e', 's', 'm', 'a', 'n', 's', 'h', 'i', 'p', '\n',
        's', 'a', 'l', 'e', 's', 'm', 'e', 'n', '\n',
        's', 'a', 'l', 'e', 's', 'p', 'e', 'o', 'p', 'l', 'e', '\n',
        's', 'a', 'l', 'e', 's', 'p', 'e', 'r', 's', 'o', 'n', '\n',
        's', 'a', 'l', 'e', 's', 'w', 'o', 'm', 'a', 'n', '\n',
        's', 'a', 'l', 'i', 'c', 'y', 'l', 'i', 'c', '\n',
        's', 'a', 'l', 'i', 'e', 'n', 'c', 'e', '\n',
        's', 'a', 'l', 'i', 'e', 'n', 't', '\n',
        's', 'a', 'l', 'i', 'n', 'e', '\n',
        's', 'a', 'l', 'i', 'n', 'i', 't', 'y', '\n',
        's', 'a', 'l', 'i', 'v', 'a', '\n',
        's', 'a', 'l', 'i', 'v', 'a', 'r', 'y', '\n',
        's', 'a', 'l', 'i', 'v', 'a', 's', '\n',
        's', 'a', 'l', 'i', 'v', 'a', 't', 'e', '\n',
        's', 'a', 'l', 'i', 'v', 'a', 't', 'i', 'n', 'g', '\n',
        's', 'a', 'l', 'i', 'v', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'a', 'l', 'i', 'v', 'a', 't', 'i', 'o', 'n', 's', '\n',
        's', 'a', 'l', 'l', 'i', 'e', 'd', '\n',
        's', 'a', 'l', 'l', 'i', 'e', 's', '\n',
        's', 'a', 'l', 'l', 'o', 'w', '\n',
        's', 'a', 'l', 'l', 'y', '\n',
        's', 'a', 'l', 'l', 'y', 'i', 'n', 'g', '\n',
        's', 'a', 'l', 'm', 'o', 'n', '\n',
        's', 'a', 'l', 'm', 'o', 'n', 'e', 'l', 'l', 'a', '\n',
        's', 'a', 'l', 'm', 'o', 'n', 's', '\n',
        's', 'a', 'l', 'o', 'm', 'e', '\n',
        's', 'a', 'l', 'o', 'n', '\n',
        's', 'a', 'l', 'o', 'n', 's', '\n',
        's', 'a', 'l', 'o', 'o', 'n', '\n',
        's', 'a', 'l', 'o', 'o', 'n', 's', '\n',
        's', 'a', 'l', 's', 'a', '\n',
        's', 'a', 'l', 't', '\n',
        's', 'a', 'l', 't', 'e', 'd', '\n',
        's', 'a', 'l', 't', 'i', 'e', 'r', '\n',
        's', 'a', 'l', 't', 'i', 'e', 's', 't', '\n',
        's', 'a', 'l', 't', 'i', 'n', 'e', 's', 's', '\n',
        's', 'a', 'l', 't', 'p', 'e', 't', 'r', 'e', '\n',
        's', 'a', 'l', 't', 's', '\n',
        's', 'a', 'l', 't', 'w', 'a', 't', 'e', 'r', '\n',
        's', 'a', 'l', 't', 'y', '\n',
        's', 'a', 'l', 'u', 'b', 'r', 'i', 'o', 'u', 's', '\n',
        's', 'a', 'l', 'u', 'b', 'r', 'i', 't', 'y', '\n',
        's', 'a', 'l', 'u', 't', 'a', 'r', 'y', '\n',
        's', 'a', 'l', 'u', 't', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'a', 'l', 'u', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        's', 'a', 'l', 'u', 't', 'e', '\n',
        's', 'a', 'l', 'u', 't', 'e', 'd', '\n',
        's', 'a', 'l', 'u', 't', 'e', 's', '\n',
        's', 'a', 'l', 'u', 't', 'i', 'n', 'g', '\n',
        's', 'a', 'l', 'v', 'a', 'g', 'e', '\n',
        's', 'a', 'l', 'v', 'a', 'g', 'e', 'a', 'b', 'l', 'e', '\n',
        's', 'a', 'l', 'v', 'a', 'g', 'e', 'd', '\n',
        's', 'a', 'l', 'v', 'a', 'g', 'e', 'r', '\n',
        's', 'a', 'l', 'v', 'a', 'g', 'e', 's', '\n',
        's', 'a', 'l', 'v', 'a', 'g', 'i', 'n', 'g', '\n',
        's', 'a', 'l', 'v', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'a', 'l', 'v', 'e', '\n',
        's', 'a', 'l', 'v', 'e', 'd', '\n',
        's', 'a', 'l', 'v', 'e', 'r', '\n',
        's', 'a', 'l', 'v', 'e', 'r', 's', '\n',
        's', 'a', 'l', 'v', 'i', 'n', 'g', '\n',
        's', 'a', 'l', 'v', 'o', '\n',
        's', 'a', 'm', '\n',
        's', 'a', 'm', 'b', 'a', '\n',
        's', 'a', 'm', 'b', 'a', 's', '\n',
        's', 'a', 'm', 'e', '\n',
        's', 'a', 'm', 'e', 'n', 'e', 's', 's', '\n',
        's', 'a', 'm', 'i', 'z', 'd', 'a', 't', '\n',
        's', 'a', 'm', 'o', 'a', '\n',
        's', 'a', 'm', 'o', 's', 'a', 's', '\n',
        's', 'a', 'm', 'o', 'v', 'a', 'r', '\n',
        's', 'a', 'm', 'p', 'a', 'n', '\n',
        's', 'a', 'm', 'p', 'l', 'e', '\n',
        's', 'a', 'm', 'p', 'l', 'e', 'd', '\n',
        's', 'a', 'm', 'p', 'l', 'e', 'r', '\n',
        's', 'a', 'm', 'p', 'l', 'e', 'r', 's', '\n',
        's', 'a', 'm', 'p', 'l', 'e', 's', '\n',
        's', 'a', 'm', 'p', 'l', 'i', 'n', 'g', '\n',
        's', 'a', 'm', 'p', 'l', 'i', 'n', 'g', 's', '\n',
        's', 'a', 'm', 'u', 'r', 'a', 'i', '\n',
        's', 'a', 'n', '\n',
        's', 'a', 'n', 'a', 't', 'o', 'r', 'i', 'u', 'm', '\n',
        's', 'a', 'n', 'c', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'a', 'n', 'c', 't', 'i', 'f', 'i', 'e', 'd', '\n',
        's', 'a', 'n', 'c', 't', 'i', 'f', 'i', 'e', 's', '\n',
        's', 'a', 'n', 'c', 't', 'i', 'f', 'y', '\n',
        's', 'a', 'n', 'c', 't', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        's', 'a', 'n', 'c', 't', 'i', 'm', 'o', 'n', 'i', 'o', 'u', 's', '\n',
        's', 'a', 'n', 'c', 't', 'i', 'o', 'n', '\n',
        's', 'a', 'n', 'c', 't', 'i', 'o', 'n', 'e', 'd', '\n',
        's', 'a', 'n', 'c', 't', 'i', 'o', 'n', 'i', 'n', 'g', '\n',
        's', 'a', 'n', 'c', 't', 'i', 'o', 'n', 's', '\n',
        's', 'a', 'n', 'c', 't', 'i', 't', 'y', '\n',
        's', 'a', 'n', 'c', 't', 'u', 'a', 'r', 'i', 'e', 's', '\n',
        's', 'a', 'n', 'c', 't', 'u', 'a', 'r', 'y', '\n',
        's', 'a', 'n', 'c', 't', 'u', 'm', '\n',
        's', 'a', 'n', 'd', '\n',
        's', 'a', 'n', 'd', 'a', 'l', '\n',
        's', 'a', 'n', 'd', 'a', 'l', 'l', 'e', 'd', '\n',
        's', 'a', 'n', 'd', 'a', 'l', 's', '\n',
        's', 'a', 'n', 'd', 'a', 'l', 'w', 'o', 'o', 'd', '\n',
        's', 'a', 'n', 'd', 'b', 'a', 'g', '\n',
        's', 'a', 'n', 'd', 'b', 'a', 'g', 'g', 'e', 'd', '\n',
        's', 'a', 'n', 'd', 'b', 'a', 'g', 's', '\n',
        's', 'a', 'n', 'd', 'b', 'a', 'n', 'k', '\n',
        's', 'a', 'n', 'd', 'b', 'a', 'n', 'k', 's', '\n',
        's', 'a', 'n', 'd', 'c', 'a', 's', 't', 'l', 'e', '\n',
        's', 'a', 'n', 'd', 'c', 'a', 's', 't', 'l', 'e', 's', '\n',
        's', 'a', 'n', 'd', 'd', 'u', 'n', 'e', '\n',
        's', 'a', 'n', 'd', 'e', 'd', '\n',
        's', 'a', 'n', 'd', 'e', 'r', '\n',
        's', 'a', 'n', 'd', 'i', 'e', 'r', '\n',
        's', 'a', 'n', 'd', 'i', 'e', 's', 't', '\n',
        's', 'a', 'n', 'd', 'i', 'n', 'g', '\n',
        's', 'a', 'n', 'd', 'm', 'a', 'n', '\n',
        's', 'a', 'n', 'd', 'p', 'a', 'p', 'e', 'r', '\n',
        's', 'a', 'n', 'd', 'p', 'a', 'p', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'a', 'n', 'd', 'p', 'i', 'p', 'e', 'r', '\n',
        's', 'a', 'n', 'd', 'p', 'i', 'p', 'e', 'r', 's', '\n',
        's', 'a', 'n', 'd', 'p', 'i', 't', '\n',
        's', 'a', 'n', 'd', 's', '\n',
        's', 'a', 'n', 'd', 's', 't', 'o', 'n', 'e', '\n',
        's', 'a', 'n', 'd', 's', 't', 'o', 'n', 'e', 's', '\n',
        's', 'a', 'n', 'd', 'w', 'i', 'c', 'h', '\n',
        's', 'a', 'n', 'd', 'w', 'i', 'c', 'h', 'e', 'd', '\n',
        's', 'a', 'n', 'd', 'w', 'i', 'c', 'h', 'e', 's', '\n',
        's', 'a', 'n', 'd', 'w', 'i', 'c', 'h', 'i', 'n', 'g', '\n',
        's', 'a', 'n', 'd', 'y', '\n',
        's', 'a', 'n', 'e', '\n',
        's', 'a', 'n', 'e', 'l', 'y', '\n',
        's', 'a', 'n', 'e', 'r', '\n',
        's', 'a', 'n', 'e', 's', 't', '\n',
        's', 'a', 'n', 'g', '\n',
        's', 'a', 'n', 'g', 'u', 'i', 'n', 'e', '\n',
        's', 'a', 'n', 'i', 't', 'a', 'r', 'y', '\n',
        's', 'a', 'n', 'i', 't', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'a', 'n', 'i', 't', 'i', 's', 'e', '\n',
        's', 'a', 'n', 'i', 't', 'i', 's', 'e', 'd', '\n',
        's', 'a', 'n', 'i', 't', 'i', 's', 'e', 'r', '\n',
        's', 'a', 'n', 'i', 't', 'i', 's', 'e', 'r', 's', '\n',
        's', 'a', 'n', 'i', 't', 'y', '\n',
        's', 'a', 'n', 'k', '\n',
        's', 'a', 'n', 's', 'e', 'r', 'i', 'f', '\n',
        's', 'a', 'n', 's', 'k', 'r', 'i', 't', '\n',
        's', 'a', 'n', 't', 'i', 'a', 'g', 'o', '\n',
        's', 'a', 'p', '\n',
        's', 'a', 'p', 'i', 'e', 'n', 't', '\n',
        's', 'a', 'p', 'l', 'i', 'n', 'g', '\n',
        's', 'a', 'p', 'l', 'i', 'n', 'g', 's', '\n',
        's', 'a', 'p', 'p', 'e', 'd', '\n',
        's', 'a', 'p', 'p', 'e', 'r', '\n',
        's', 'a', 'p', 'p', 'e', 'r', 's', '\n',
        's', 'a', 'p', 'p', 'h', 'i', 'r', 'e', '\n',
        's', 'a', 'p', 'p', 'h', 'i', 'r', 'e', 's', '\n',
        's', 'a', 'p', 'p', 'i', 'n', 'g', '\n',
        's', 'a', 'p', 's', '\n',
        's', 'a', 'r', 'c', 'a', 's', 'm', '\n',
        's', 'a', 'r', 'c', 'a', 's', 'm', 's', '\n',
        's', 'a', 'r', 'c', 'a', 's', 't', 'i', 'c', '\n',
        's', 'a', 'r', 'c', 'a', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 'a', 'r', 'c', 'o', 'm', 'a', '\n',
        's', 'a', 'r', 'c', 'o', 'p', 'h', 'a', 'g', 'i', '\n',
        's', 'a', 'r', 'c', 'o', 'p', 'h', 'a', 'g', 'u', 's', '\n',
        's', 'a', 'r', 'd', 'i', 'n', 'e', '\n',
        's', 'a', 'r', 'd', 'i', 'n', 'e', 's', '\n',
        's', 'a', 'r', 'd', 'i', 'n', 'i', 'a', '\n',
        's', 'a', 'r', 'd', 'o', 'n', 'i', 'c', '\n',
        's', 'a', 'r', 'd', 'o', 'n', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 'a', 'r', 'g', 'e', '\n',
        's', 'a', 'r', 'i', '\n',
        's', 'a', 'r', 'i', 's', '\n',
        's', 'a', 'r', 'o', 'n', 'g', '\n',
        's', 'a', 'r', 't', 'o', 'r', 'i', 'a', 'l', '\n',
        's', 'a', 'r', 't', 'o', 'r', 'i', 'a', 'l', 'l', 'y', '\n',
        's', 'a', 's', 'h', '\n',
        's', 'a', 's', 'h', 'e', 's', '\n',
        's', 'a', 't', '\n',
        's', 'a', 't', 'a', 'n', '\n',
        's', 'a', 't', 'a', 'n', 'i', 'c', '\n',
        's', 'a', 't', 'a', 'n', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 'a', 't', 'a', 'n', 'i', 's', 'm', '\n',
        's', 'a', 't', 'c', 'h', 'e', 'l', '\n',
        's', 'a', 't', 'c', 'h', 'e', 'l', 's', '\n',
        's', 'a', 't', 'e', 'd', '\n',
        's', 'a', 't', 'e', 'l', 'l', 'i', 't', 'e', '\n',
        's', 'a', 't', 'e', 'l', 'l', 'i', 't', 'e', 's', '\n',
        's', 'a', 't', 'i', 'a', 't', 'e', '\n',
        's', 'a', 't', 'i', 'a', 't', 'e', 'd', '\n',
        's', 'a', 't', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'a', 't', 'i', 'n', '\n',
        's', 'a', 't', 'i', 'n', 'g', '\n',
        's', 'a', 't', 'i', 'n', 's', '\n',
        's', 'a', 't', 'i', 'n', 'w', 'o', 'o', 'd', '\n',
        's', 'a', 't', 'i', 'n', 'y', '\n',
        's', 'a', 't', 'i', 'r', 'e', '\n',
        's', 'a', 't', 'i', 'r', 'e', 's', '\n',
        's', 'a', 't', 'i', 'r', 'i', 'c', '\n',
        's', 'a', 't', 'i', 'r', 'i', 'c', 'a', 'l', '\n',
        's', 'a', 't', 'i', 'r', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 'a', 't', 'i', 'r', 'i', 's', 'e', '\n',
        's', 'a', 't', 'i', 'r', 'i', 's', 'e', 'd', '\n',
        's', 'a', 't', 'i', 'r', 'i', 's', 'e', 's', '\n',
        's', 'a', 't', 'i', 'r', 'i', 's', 'i', 'n', 'g', '\n',
        's', 'a', 't', 'i', 'r', 'i', 's', 't', '\n',
        's', 'a', 't', 'i', 'r', 'i', 's', 't', 's', '\n',
        's', 'a', 't', 'i', 's', 'f', 'a', 'c', 't', 'i', 'o', 'n', '\n',
        's', 'a', 't', 'i', 's', 'f', 'a', 'c', 't', 'i', 'o', 'n', 's', '\n',
        's', 'a', 't', 'i', 's', 'f', 'a', 'c', 't', 'o', 'r', 'i', 'l', 'y', '\n',
        's', 'a', 't', 'i', 's', 'f', 'a', 'c', 't', 'o', 'r', 'y', '\n',
        's', 'a', 't', 'i', 's', 'f', 'i', 'a', 'b', 'l', 'e', '\n',
        's', 'a', 't', 'i', 's', 'f', 'i', 'e', 'd', '\n',
        's', 'a', 't', 'i', 's', 'f', 'i', 'e', 's', '\n',
        's', 'a', 't', 'i', 's', 'f', 'y', '\n',
        's', 'a', 't', 'i', 's', 'f', 'y', 'i', 'n', 'g', '\n',
        's', 'a', 't', 'i', 's', 'f', 'y', 'i', 'n', 'g', 'l', 'y', '\n',
        's', 'a', 't', 'r', 'a', 'p', '\n',
        's', 'a', 't', 'r', 'a', 'p', 's', '\n',
        's', 'a', 't', 's', 'u', 'm', 'a', 's', '\n',
        's', 'a', 't', 'u', 'r', 'a', 't', 'e', '\n',
        's', 'a', 't', 'u', 'r', 'a', 't', 'e', 'd', '\n',
        's', 'a', 't', 'u', 'r', 'a', 't', 'e', 's', '\n',
        's', 'a', 't', 'u', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        's', 'a', 't', 'u', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'a', 't', 'u', 'r', 'd', 'a', 'y', '\n',
        's', 'a', 't', 'u', 'r', 'n', '\n',
        's', 'a', 't', 'u', 'r', 'n', 'a', 'l', 'i', 'a', '\n',
        's', 'a', 't', 'u', 'r', 'n', 'i', 'n', 'e', '\n',
        's', 'a', 't', 'y', 'r', '\n',
        's', 'a', 't', 'y', 'r', 'i', 'c', '\n',
        's', 'a', 't', 'y', 'r', 's', '\n',
        's', 'a', 'u', 'c', 'e', '\n',
        's', 'a', 'u', 'c', 'e', 'p', 'a', 'n', '\n',
        's', 'a', 'u', 'c', 'e', 'p', 'a', 'n', 's', '\n',
        's', 'a', 'u', 'c', 'e', 'r', '\n',
        's', 'a', 'u', 'c', 'e', 'r', 's', '\n',
        's', 'a', 'u', 'c', 'e', 's', '\n',
        's', 'a', 'u', 'c', 'i', 'e', 'r', '\n',
        's', 'a', 'u', 'c', 'i', 'e', 's', 't', '\n',
        's', 'a', 'u', 'c', 'i', 'l', 'y', '\n',
        's', 'a', 'u', 'c', 'i', 'n', 'e', 's', 's', '\n',
        's', 'a', 'u', 'c', 'y', '\n',
        's', 'a', 'u', 'd', 'i', '\n',
        's', 'a', 'u', 'd', 'i', 's', '\n',
        's', 'a', 'u', 'e', 'r', 'k', 'r', 'a', 'u', 't', '\n',
        's', 'a', 'u', 'n', 'a', '\n',
        's', 'a', 'u', 'n', 'a', 's', '\n',
        's', 'a', 'u', 'n', 't', 'e', 'r', '\n',
        's', 'a', 'u', 'n', 't', 'e', 'r', 'e', 'd', '\n',
        's', 'a', 'u', 'n', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'a', 'u', 'n', 't', 'e', 'r', 's', '\n',
        's', 'a', 'u', 's', 'a', 'g', 'e', '\n',
        's', 'a', 'u', 's', 'a', 'g', 'e', 's', '\n',
        's', 'a', 'u', 't', 'e', '\n',
        's', 'a', 'v', 'a', 'g', 'e', '\n',
        's', 'a', 'v', 'a', 'g', 'e', 'd', '\n',
        's', 'a', 'v', 'a', 'g', 'e', 'l', 'y', '\n',
        's', 'a', 'v', 'a', 'g', 'e', 'r', 'y', '\n',
        's', 'a', 'v', 'a', 'g', 'e', 's', '\n',
        's', 'a', 'v', 'a', 'g', 'i', 'n', 'g', '\n',
        's', 'a', 'v', 'a', 'n', 'n', 'a', '\n',
        's', 'a', 'v', 'a', 'n', 'n', 'a', 'h', '\n',
        's', 'a', 'v', 'a', 'n', 't', '\n',
        's', 'a', 'v', 'a', 'n', 't', 's', '\n',
        's', 'a', 'v', 'e', '\n',
        's', 'a', 'v', 'e', 'd', '\n',
        's', 'a', 'v', 'e', 'l', 'o', 'y', '\n',
        's', 'a', 'v', 'e', 'r', '\n',
        's', 'a', 'v', 'e', 'r', 's', '\n',
        's', 'a', 'v', 'e', 's', '\n',
        's', 'a', 'v', 'i', 'n', 'g', '\n',
        's', 'a', 'v', 'i', 'n', 'g', 's', '\n',
        's', 'a', 'v', 'i', 'o', 'u', 'r', '\n',
        's', 'a', 'v', 'i', 'o', 'u', 'r', 's', '\n',
        's', 'a', 'v', 'o', 'u', 'r', '\n',
        's', 'a', 'v', 'o', 'u', 'r', 'e', 'd', '\n',
        's', 'a', 'v', 'o', 'u', 'r', 'i', 'n', 'g', '\n',
        's', 'a', 'v', 'o', 'u', 'r', 's', '\n',
        's', 'a', 'v', 'o', 'u', 'r', 'y', '\n',
        's', 'a', 'v', 'v', 'y', '\n',
        's', 'a', 'w', '\n',
        's', 'a', 'w', 'd', 'u', 's', 't', '\n',
        's', 'a', 'w', 'e', 'd', '\n',
        's', 'a', 'w', 'i', 'n', 'g', '\n',
        's', 'a', 'w', 'm', 'i', 'l', 'l', '\n',
        's', 'a', 'w', 'm', 'i', 'l', 'l', 's', '\n',
        's', 'a', 'w', 'n', '\n',
        's', 'a', 'w', 's', '\n',
        's', 'a', 'w', 't', 'o', 'o', 't', 'h', '\n',
        's', 'a', 'w', 'y', 'e', 'r', '\n',
        's', 'a', 'w', 'y', 'e', 'r', 's', '\n',
        's', 'a', 'x', 'o', 'n', '\n',
        's', 'a', 'x', 'o', 'n', 's', '\n',
        's', 'a', 'x', 'o', 'n', 'y', '\n',
        's', 'a', 'x', 'o', 'p', 'h', 'o', 'n', 'e', '\n',
        's', 'a', 'x', 'o', 'p', 'h', 'o', 'n', 'e', 's', '\n',
        's', 'a', 'x', 'o', 'p', 'h', 'o', 'n', 'i', 's', 't', '\n',
        's', 'a', 'y', '\n',
        's', 'a', 'y', 'i', 'n', 'g', '\n',
        's', 'a', 'y', 'i', 'n', 'g', 's', '\n',
        's', 'a', 'y', 's', '\n',
        's', 'c', 'a', 'b', '\n',
        's', 'c', 'a', 'b', 'b', 'a', 'r', 'd', '\n',
        's', 'c', 'a', 'b', 'b', 'a', 'r', 'd', 's', '\n',
        's', 'c', 'a', 'b', 'b', 'e', 'd', '\n',
        's', 'c', 'a', 'b', 'b', 'y', '\n',
        's', 'c', 'a', 'b', 'i', 'e', 's', '\n',
        's', 'c', 'a', 'b', 's', '\n',
        's', 'c', 'a', 'f', 'f', 'o', 'l', 'd', '\n',
        's', 'c', 'a', 'f', 'f', 'o', 'l', 'd', 'i', 'n', 'g', '\n',
        's', 'c', 'a', 'f', 'f', 'o', 'l', 'd', 's', '\n',
        's', 'c', 'a', 'l', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        's', 'c', 'a', 'l', 'a', 'b', 'l', 'e', '\n',
        's', 'c', 'a', 'l', 'a', 'r', '\n',
        's', 'c', 'a', 'l', 'a', 'r', 's', '\n',
        's', 'c', 'a', 'l', 'd', '\n',
        's', 'c', 'a', 'l', 'd', 'e', 'd', '\n',
        's', 'c', 'a', 'l', 'd', 'i', 'n', 'g', '\n',
        's', 'c', 'a', 'l', 'd', 's', '\n',
        's', 'c', 'a', 'l', 'e', '\n',
        's', 'c', 'a', 'l', 'e', 'd', '\n',
        's', 'c', 'a', 'l', 'e', 'n', 'e', '\n',
        's', 'c', 'a', 'l', 'e', 's', '\n',
        's', 'c', 'a', 'l', 'i', 'n', 'g', '\n',
        's', 'c', 'a', 'l', 'l', 'o', 'p', '\n',
        's', 'c', 'a', 'l', 'l', 'o', 'p', 'e', 'd', '\n',
        's', 'c', 'a', 'l', 'l', 'o', 'p', 's', '\n',
        's', 'c', 'a', 'l', 'p', '\n',
        's', 'c', 'a', 'l', 'p', 'e', 'd', '\n',
        's', 'c', 'a', 'l', 'p', 'e', 'l', '\n',
        's', 'c', 'a', 'l', 'p', 'e', 'l', 's', '\n',
        's', 'c', 'a', 'l', 'p', 'i', 'n', 'g', '\n',
        's', 'c', 'a', 'l', 'p', 's', '\n',
        's', 'c', 'a', 'l', 'y', '\n',
        's', 'c', 'a', 'm', '\n',
        's', 'c', 'a', 'm', 'p', '\n',
        's', 'c', 'a', 'm', 'p', 'e', 'd', '\n',
        's', 'c', 'a', 'm', 'p', 'e', 'r', '\n',
        's', 'c', 'a', 'm', 'p', 'e', 'r', 'e', 'd', '\n',
        's', 'c', 'a', 'm', 'p', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'c', 'a', 'm', 'p', 'i', '\n',
        's', 'c', 'a', 'm', 's', '\n',
        's', 'c', 'a', 'n', '\n',
        's', 'c', 'a', 'n', 'd', 'a', 'l', '\n',
        's', 'c', 'a', 'n', 'd', 'a', 'l', 'i', 's', 'e', '\n',
        's', 'c', 'a', 'n', 'd', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        's', 'c', 'a', 'n', 'd', 'a', 'l', 'o', 'u', 's', '\n',
        's', 'c', 'a', 'n', 'd', 'a', 'l', 'o', 'u', 's', 'l', 'y', '\n',
        's', 'c', 'a', 'n', 'd', 'a', 'l', 's', '\n',
        's', 'c', 'a', 'n', 'n', 'e', 'd', '\n',
        's', 'c', 'a', 'n', 'n', 'e', 'r', '\n',
        's', 'c', 'a', 'n', 'n', 'e', 'r', 's', '\n',
        's', 'c', 'a', 'n', 'n', 'i', 'n', 'g', '\n',
        's', 'c', 'a', 'n', 's', '\n',
        's', 'c', 'a', 'n', 's', 'i', 'o', 'n', '\n',
        's', 'c', 'a', 'n', 't', '\n',
        's', 'c', 'a', 'n', 't', 'i', 'e', 'r', '\n',
        's', 'c', 'a', 'n', 't', 'i', 'e', 's', 't', '\n',
        's', 'c', 'a', 'n', 't', 'i', 'l', 'y', '\n',
        's', 'c', 'a', 'n', 't', 'i', 'n', 'e', 's', 's', '\n',
        's', 'c', 'a', 'n', 't', 'y', '\n',
        's', 'c', 'a', 'p', 'e', '\n',
        's', 'c', 'a', 'p', 'e', 'g', 'o', 'a', 't', '\n',
        's', 'c', 'a', 'p', 'e', 'g', 'o', 'a', 't', 's', '\n',
        's', 'c', 'a', 'p', 'u', 'l', 'a', '\n',
        's', 'c', 'a', 'r', '\n',
        's', 'c', 'a', 'r', 'a', 'b', '\n',
        's', 'c', 'a', 'r', 'c', 'e', '\n',
        's', 'c', 'a', 'r', 'c', 'e', 'l', 'y', '\n',
        's', 'c', 'a', 'r', 'c', 'e', 'n', 'e', 's', 's', '\n',
        's', 'c', 'a', 'r', 'c', 'e', 'r', '\n',
        's', 'c', 'a', 'r', 'c', 'e', 's', 't', '\n',
        's', 'c', 'a', 'r', 'c', 'i', 't', 'i', 'e', 's', '\n',
        's', 'c', 'a', 'r', 'c', 'i', 't', 'y', '\n',
        's', 'c', 'a', 'r', 'e', '\n',
        's', 'c', 'a', 'r', 'e', 'c', 'r', 'o', 'w', '\n',
        's', 'c', 'a', 'r', 'e', 'c', 'r', 'o', 'w', 's', '\n',
        's', 'c', 'a', 'r', 'e', 'd', '\n',
        's', 'c', 'a', 'r', 'e', 'm', 'o', 'n', 'g', 'e', 'r', '\n',
        's', 'c', 'a', 'r', 'e', 'm', 'o', 'n', 'g', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'c', 'a', 'r', 'e', 's', '\n',
        's', 'c', 'a', 'r', 'f', '\n',
        's', 'c', 'a', 'r', 'f', 's', '\n',
        's', 'c', 'a', 'r', 'i', 'e', 'r', '\n',
        's', 'c', 'a', 'r', 'i', 'e', 's', 't', '\n',
        's', 'c', 'a', 'r', 'i', 'f', 'i', 'e', 'd', '\n',
        's', 'c', 'a', 'r', 'i', 'f', 'y', '\n',
        's', 'c', 'a', 'r', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        's', 'c', 'a', 'r', 'i', 'l', 'y', '\n',
        's', 'c', 'a', 'r', 'i', 'n', 'g', '\n',
        's', 'c', 'a', 'r', 'l', 'e', 't', '\n',
        's', 'c', 'a', 'r', 'l', 'e', 't', 's', '\n',
        's', 'c', 'a', 'r', 'p', '\n',
        's', 'c', 'a', 'r', 'r', 'e', 'd', '\n',
        's', 'c', 'a', 'r', 'r', 'i', 'n', 'g', '\n',
        's', 'c', 'a', 'r', 's', '\n',
        's', 'c', 'a', 'r', 'v', 'e', 's', '\n',
        's', 'c', 'a', 'r', 'y', '\n',
        's', 'c', 'a', 't', '\n',
        's', 'c', 'a', 't', 'h', 'e', '\n',
        's', 'c', 'a', 't', 'h', 'e', 'd', '\n',
        's', 'c', 'a', 't', 'h', 'i', 'n', 'g', '\n',
        's', 'c', 'a', 't', 'h', 'i', 'n', 'g', 'l', 'y', '\n',
        's', 'c', 'a', 't', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        's', 'c', 'a', 't', 't', 'e', 'r', '\n',
        's', 'c', 'a', 't', 't', 'e', 'r', 'e', 'd', '\n',
        's', 'c', 'a', 't', 't', 'e', 'r', 'e', 'r', '\n',
        's', 'c', 'a', 't', 't', 'e', 'r', 'e', 'r', 's', '\n',
        's', 'c', 'a', 't', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'c', 'a', 't', 't', 'e', 'r', 'i', 'n', 'g', 's', '\n',
        's', 'c', 'a', 't', 't', 'e', 'r', 's', '\n',
        's', 'c', 'a', 'v', 'e', 'n', 'g', 'e', '\n',
        's', 'c', 'a', 'v', 'e', 'n', 'g', 'e', 'd', '\n',
        's', 'c', 'a', 'v', 'e', 'n', 'g', 'e', 'r', '\n',
        's', 'c', 'a', 'v', 'e', 'n', 'g', 'e', 'r', 's', '\n',
        's', 'c', 'a', 'v', 'e', 'n', 'g', 'i', 'n', 'g', '\n',
        's', 'c', 'e', 'n', 'a', 'r', 'i', 'o', '\n',
        's', 'c', 'e', 'n', 'e', '\n',
        's', 'c', 'e', 'n', 'e', 'r', 'y', '\n',
        's', 'c', 'e', 'n', 'e', 's', '\n',
        's', 'c', 'e', 'n', 'i', 'c', '\n',
        's', 'c', 'e', 'n', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 'c', 'e', 'n', 't', '\n',
        's', 'c', 'e', 'n', 't', 'e', 'd', '\n',
        's', 'c', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        's', 'c', 'e', 'n', 't', 'l', 'e', 's', 's', '\n',
        's', 'c', 'e', 'n', 't', 's', '\n',
        's', 'c', 'e', 'p', 't', 'i', 'c', '\n',
        's', 'c', 'e', 'p', 't', 'i', 'c', 'a', 'l', '\n',
        's', 'c', 'e', 'p', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 'c', 'e', 'p', 't', 'i', 'c', 'i', 's', 'm', '\n',
        's', 'c', 'e', 'p', 't', 'i', 'c', 's', '\n',
        's', 'c', 'e', 'p', 't', 'r', 'e', '\n',
        's', 'c', 'e', 'p', 't', 'r', 'e', 'd', '\n',
        's', 'c', 'e', 'p', 't', 'r', 'e', 's', '\n',
        's', 'c', 'h', 'e', 'd', 'u', 'l', 'e', '\n',
        's', 'c', 'h', 'e', 'd', 'u', 'l', 'e', 'd', '\n',
        's', 'c', 'h', 'e', 'd', 'u', 'l', 'e', 'r', '\n',
        's', 'c', 'h', 'e', 'd', 'u', 'l', 'e', 'r', 's', '\n',
        's', 'c', 'h', 'e', 'd', 'u', 'l', 'e', 's', '\n',
        's', 'c', 'h', 'e', 'd', 'u', 'l', 'i', 'n', 'g', '\n',
        's', 'c', 'h', 'e', 'm', 'a', '\n',
        's', 'c', 'h', 'e', 'm', 'a', 's', '\n',
        's', 'c', 'h', 'e', 'm', 'a', 't', 'a', '\n',
        's', 'c', 'h', 'e', 'm', 'a', 't', 'i', 'c', '\n',
        's', 'c', 'h', 'e', 'm', 'a', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 'c', 'h', 'e', 'm', 'a', 't', 'i', 'c', 's', '\n',
        's', 'c', 'h', 'e', 'm', 'e', '\n',
        's', 'c', 'h', 'e', 'm', 'e', 'd', '\n',
        's', 'c', 'h', 'e', 'm', 'e', 'r', '\n',
        's', 'c', 'h', 'e', 'm', 'e', 's', '\n',
        's', 'c', 'h', 'e', 'm', 'i', 'n', 'g', '\n',
        's', 'c', 'h', 'e', 'r', 'z', 'i', '\n',
        's', 'c', 'h', 'e', 'r', 'z', 'o', '\n',
        's', 'c', 'h', 'i', 's', 'm', '\n',
        's', 'c', 'h', 'i', 's', 'm', 'a', 't', 'i', 'c', '\n',
        's', 'c', 'h', 'i', 's', 'm', 'a', 't', 'i', 'c', 's', '\n',
        's', 'c', 'h', 'i', 's', 'm', 's', '\n',
        's', 'c', 'h', 'i', 's', 't', '\n',
        's', 'c', 'h', 'i', 's', 't', 'o', 's', 'o', 'm', 'i', 'a', 's', 'i', 's', '\n',
        's', 'c', 'h', 'i', 's', 't', 's', '\n',
        's', 'c', 'h', 'i', 'z', 'o', 'i', 'd', '\n',
        's', 'c', 'h', 'i', 'z', 'o', 'p', 'h', 'r', 'e', 'n', 'i', 'a', '\n',
        's', 'c', 'h', 'i', 'z', 'o', 'p', 'h', 'r', 'e', 'n', 'i', 'c', '\n',
        's', 'c', 'h', 'i', 'z', 'o', 'p', 'h', 'r', 'e', 'n', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 'c', 'h', 'i', 'z', 'o', 'p', 'h', 'r', 'e', 'n', 'i', 'c', 's', '\n',
        's', 'c', 'h', 'm', 'a', 'l', 'z', '\n',
        's', 'c', 'h', 'n', 'a', 'p', 'p', 's', '\n',
        's', 'c', 'h', 'o', 'l', 'a', 'r', '\n',
        's', 'c', 'h', 'o', 'l', 'a', 'r', 'l', 'y', '\n',
        's', 'c', 'h', 'o', 'l', 'a', 'r', 's', '\n',
        's', 'c', 'h', 'o', 'l', 'a', 'r', 's', 'h', 'i', 'p', '\n',
        's', 'c', 'h', 'o', 'l', 'a', 'r', 's', 'h', 'i', 'p', 's', '\n',
        's', 'c', 'h', 'o', 'l', 'a', 's', 't', 'i', 'c', '\n',
        's', 'c', 'h', 'o', 'l', 'a', 's', 't', 'i', 'c', 'i', 's', 'm', '\n',
        's', 'c', 'h', 'o', 'o', 'l', '\n',
        's', 'c', 'h', 'o', 'o', 'l', 'b', 'o', 'y', '\n',
        's', 'c', 'h', 'o', 'o', 'l', 'b', 'o', 'y', 's', '\n',
        's', 'c', 'h', 'o', 'o', 'l', 'c', 'h', 'i', 'l', 'd', '\n',
        's', 'c', 'h', 'o', 'o', 'l', 'c', 'h', 'i', 'l', 'd', 'r', 'e', 'n', '\n',
        's', 'c', 'h', 'o', 'o', 'l', 'd', 'a', 'y', 's', '\n',
        's', 'c', 'h', 'o', 'o', 'l', 'e', 'd', '\n',
        's', 'c', 'h', 'o', 'o', 'l', 'g', 'i', 'r', 'l', '\n',
        's', 'c', 'h', 'o', 'o', 'l', 'g', 'i', 'r', 'l', 's', '\n',
        's', 'c', 'h', 'o', 'o', 'l', 'h', 'o', 'u', 's', 'e', '\n',
        's', 'c', 'h', 'o', 'o', 'l', 'i', 'n', 'g', '\n',
        's', 'c', 'h', 'o', 'o', 'l', 'm', 'a', 's', 't', 'e', 'r', '\n',
        's', 'c', 'h', 'o', 'o', 'l', 'm', 'a', 's', 't', 'e', 'r', 's', '\n',
        's', 'c', 'h', 'o', 'o', 'l', 'm', 'a', 't', 'e', 's', '\n',
        's', 'c', 'h', 'o', 'o', 'l', 'm', 'i', 's', 't', 'r', 'e', 's', 's', '\n',
        's', 'c', 'h', 'o', 'o', 'l', 'r', 'o', 'o', 'm', '\n',
        's', 'c', 'h', 'o', 'o', 'l', 's', '\n',
        's', 'c', 'h', 'o', 'o', 'l', 't', 'e', 'a', 'c', 'h', 'e', 'r', '\n',
        's', 'c', 'h', 'o', 'o', 'l', 't', 'e', 'a', 'c', 'h', 'e', 'r', 's', '\n',
        's', 'c', 'h', 'o', 'o', 'n', 'e', 'r', '\n',
        's', 'c', 'h', 'o', 'o', 'n', 'e', 'r', 's', '\n',
        's', 'c', 'h', 'w', 'a', '\n',
        's', 'c', 'h', 'w', 'a', 's', '\n',
        's', 'c', 'i', 'a', 't', 'i', 'c', 'a', '\n',
        's', 'c', 'i', 'e', 'n', 'c', 'e', '\n',
        's', 'c', 'i', 'e', 'n', 'c', 'e', 's', '\n',
        's', 'c', 'i', 'e', 'n', 't', 'i', 'f', 'i', 'c', '\n',
        's', 'c', 'i', 'e', 'n', 't', 'i', 'f', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 'c', 'i', 'e', 'n', 't', 'i', 's', 't', '\n',
        's', 'c', 'i', 'e', 'n', 't', 'i', 's', 't', 's', '\n',
        's', 'c', 'i', 'f', 'i', '\n',
        's', 'c', 'i', 'm', 'i', 't', 'a', 'r', '\n',
        's', 'c', 'i', 'm', 'i', 't', 'a', 'r', 's', '\n',
        's', 'c', 'i', 'n', 't', 'i', 'g', 'r', 'a', 'p', 'h', 'y', '\n',
        's', 'c', 'i', 'n', 't', 'i', 'l', 'l', 'a', 't', 'e', '\n',
        's', 'c', 'i', 'n', 't', 'i', 'l', 'l', 'a', 't', 'e', 'd', '\n',
        's', 'c', 'i', 'n', 't', 'i', 'l', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        's', 'c', 'i', 'n', 't', 'i', 'l', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'c', 'i', 'n', 't', 'i', 'l', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        's', 'c', 'i', 'n', 't', 'i', 'l', 'l', 'a', 't', 'o', 'r', '\n',
        's', 'c', 'i', 'n', 't', 'i', 'l', 'l', 'a', 't', 'o', 'r', 's', '\n',
        's', 'c', 'i', 's', 's', 'o', 'r', '\n',
        's', 'c', 'i', 's', 's', 'o', 'r', 'e', 'd', '\n',
        's', 'c', 'i', 's', 's', 'o', 'r', 's', '\n',
        's', 'c', 'l', 'e', 'r', 'o', 's', 'i', 's', '\n',
        's', 'c', 'o', 'f', 'f', '\n',
        's', 'c', 'o', 'f', 'f', 'e', 'd', '\n',
        's', 'c', 'o', 'f', 'f', 'i', 'n', 'g', '\n',
        's', 'c', 'o', 'l', 'd', '\n',
        's', 'c', 'o', 'l', 'd', 'e', 'd', '\n',
        's', 'c', 'o', 'l', 'd', 'e', 'r', '\n',
        's', 'c', 'o', 'l', 'd', 'i', 'n', 'g', '\n',
        's', 'c', 'o', 'l', 'd', 's', '\n',
        's', 'c', 'o', 'n', 'e', '\n',
        's', 'c', 'o', 'n', 'e', 's', '\n',
        's', 'c', 'o', 'o', 'p', '\n',
        's', 'c', 'o', 'o', 'p', 'e', 'd', '\n',
        's', 'c', 'o', 'o', 'p', 'e', 'r', '\n',
        's', 'c', 'o', 'o', 'p', 'f', 'u', 'l', '\n',
        's', 'c', 'o', 'o', 'p', 'i', 'n', 'g', '\n',
        's', 'c', 'o', 'o', 'p', 's', '\n',
        's', 'c', 'o', 'o', 't', '\n',
        's', 'c', 'o', 'o', 't', 'e', 'r', '\n',
        's', 'c', 'o', 'o', 't', 'e', 'r', 's', '\n',
        's', 'c', 'o', 'o', 't', 'i', 'n', 'g', '\n',
        's', 'c', 'o', 'o', 't', 's', '\n',
        's', 'c', 'o', 'p', 'e', '\n',
        's', 'c', 'o', 'p', 'e', 's', '\n',
        's', 'c', 'o', 'r', 'c', 'h', '\n',
        's', 'c', 'o', 'r', 'c', 'h', 'e', 'd', '\n',
        's', 'c', 'o', 'r', 'c', 'h', 'e', 'r', '\n',
        's', 'c', 'o', 'r', 'c', 'h', 'e', 's', '\n',
        's', 'c', 'o', 'r', 'c', 'h', 'i', 'n', 'g', '\n',
        's', 'c', 'o', 'r', 'e', '\n',
        's', 'c', 'o', 'r', 'e', 'b', 'o', 'a', 'r', 'd', '\n',
        's', 'c', 'o', 'r', 'e', 'b', 'o', 'a', 'r', 'd', 's', '\n',
        's', 'c', 'o', 'r', 'e', 'c', 'a', 'r', 'd', '\n',
        's', 'c', 'o', 'r', 'e', 'c', 'a', 'r', 'd', 's', '\n',
        's', 'c', 'o', 'r', 'e', 'd', '\n',
        's', 'c', 'o', 'r', 'e', 'l', 'e', 's', 's', '\n',
        's', 'c', 'o', 'r', 'e', 'l', 'i', 'n', 'e', '\n',
        's', 'c', 'o', 'r', 'e', 'r', '\n',
        's', 'c', 'o', 'r', 'e', 'r', 's', '\n',
        's', 'c', 'o', 'r', 'e', 's', '\n',
        's', 'c', 'o', 'r', 'i', 'n', 'g', '\n',
        's', 'c', 'o', 'r', 'n', '\n',
        's', 'c', 'o', 'r', 'n', 'e', 'd', '\n',
        's', 'c', 'o', 'r', 'n', 'f', 'u', 'l', '\n',
        's', 'c', 'o', 'r', 'n', 'f', 'u', 'l', 'l', 'y', '\n',
        's', 'c', 'o', 'r', 'n', 'i', 'n', 'g', '\n',
        's', 'c', 'o', 'r', 'n', 's', '\n',
        's', 'c', 'o', 'r', 'p', 'i', 'o', 'n', '\n',
        's', 'c', 'o', 'r', 'p', 'i', 'o', 'n', 's', '\n',
        's', 'c', 'o', 't', '\n',
        's', 'c', 'o', 't', 'c', 'h', '\n',
        's', 'c', 'o', 't', 'c', 'h', 'e', 'd', '\n',
        's', 'c', 'o', 't', 'c', 'h', 'e', 's', '\n',
        's', 'c', 'o', 't', 'f', 'r', 'e', 'e', '\n',
        's', 'c', 'o', 't', 'l', 'a', 'n', 'd', '\n',
        's', 'c', 'o', 't', 's', '\n',
        's', 'c', 'o', 't', 's', 'm', 'a', 'n', '\n',
        's', 'c', 'o', 't', 't', 'i', 's', 'h', '\n',
        's', 'c', 'o', 'u', 'n', 'd', 'r', 'e', 'l', '\n',
        's', 'c', 'o', 'u', 'n', 'd', 'r', 'e', 'l', 's', '\n',
        's', 'c', 'o', 'u', 'r', '\n',
        's', 'c', 'o', 'u', 'r', 'e', 'd', '\n',
        's', 'c', 'o', 'u', 'r', 'g', 'e', '\n',
        's', 'c', 'o', 'u', 'r', 'g', 'e', 'd', '\n',
        's', 'c', 'o', 'u', 'r', 'g', 'e', 's', '\n',
        's', 'c', 'o', 'u', 'r', 'g', 'i', 'n', 'g', '\n',
        's', 'c', 'o', 'u', 'r', 'i', 'n', 'g', '\n',
        's', 'c', 'o', 'u', 'r', 's', '\n',
        's', 'c', 'o', 'u', 't', '\n',
        's', 'c', 'o', 'u', 't', 'e', 'd', '\n',
        's', 'c', 'o', 'u', 't', 'i', 'n', 'g', '\n',
        's', 'c', 'o', 'u', 't', 'm', 'a', 's', 't', 'e', 'r', '\n',
        's', 'c', 'o', 'u', 't', 'm', 'a', 's', 't', 'e', 'r', 's', '\n',
        's', 'c', 'o', 'u', 't', 's', '\n',
        's', 'c', 'o', 'w', 'l', '\n',
        's', 'c', 'o', 'w', 'l', 'e', 'd', '\n',
        's', 'c', 'o', 'w', 'l', 'i', 'n', 'g', '\n',
        's', 'c', 'o', 'w', 'l', 's', '\n',
        's', 'c', 'r', 'a', 'b', 'b', 'l', 'e', '\n',
        's', 'c', 'r', 'a', 'b', 'b', 'l', 'e', 'd', '\n',
        's', 'c', 'r', 'a', 'b', 'b', 'l', 'i', 'n', 'g', '\n',
        's', 'c', 'r', 'a', 'm', '\n',
        's', 'c', 'r', 'a', 'm', 'b', 'l', 'e', '\n',
        's', 'c', 'r', 'a', 'm', 'b', 'l', 'e', 'd', '\n',
        's', 'c', 'r', 'a', 'm', 'b', 'l', 'e', 'r', '\n',
        's', 'c', 'r', 'a', 'm', 'b', 'l', 'e', 'r', 's', '\n',
        's', 'c', 'r', 'a', 'm', 'b', 'l', 'e', 's', '\n',
        's', 'c', 'r', 'a', 'm', 'b', 'l', 'i', 'n', 'g', '\n',
        's', 'c', 'r', 'a', 'm', 's', '\n',
        's', 'c', 'r', 'a', 'p', '\n',
        's', 'c', 'r', 'a', 'p', 'b', 'o', 'o', 'k', '\n',
        's', 'c', 'r', 'a', 'p', 'b', 'o', 'o', 'k', 's', '\n',
        's', 'c', 'r', 'a', 'p', 'e', '\n',
        's', 'c', 'r', 'a', 'p', 'e', 'd', '\n',
        's', 'c', 'r', 'a', 'p', 'e', 'r', '\n',
        's', 'c', 'r', 'a', 'p', 'e', 'r', 's', '\n',
        's', 'c', 'r', 'a', 'p', 'e', 's', '\n',
        's', 'c', 'r', 'a', 'p', 'i', 'e', '\n',
        's', 'c', 'r', 'a', 'p', 'i', 'n', 'g', '\n',
        's', 'c', 'r', 'a', 'p', 'i', 'n', 'g', 's', '\n',
        's', 'c', 'r', 'a', 'p', 'p', 'e', 'd', '\n',
        's', 'c', 'r', 'a', 'p', 'p', 'i', 'e', 'r', '\n',
        's', 'c', 'r', 'a', 'p', 'p', 'i', 'e', 's', 't', '\n',
        's', 'c', 'r', 'a', 'p', 'p', 'i', 'n', 'g', '\n',
        's', 'c', 'r', 'a', 'p', 'p', 'y', '\n',
        's', 'c', 'r', 'a', 'p', 's', '\n',
        's', 'c', 'r', 'a', 'p', 'y', 'a', 'r', 'd', '\n',
        's', 'c', 'r', 'a', 'p', 'y', 'a', 'r', 'd', 's', '\n',
        's', 'c', 'r', 'a', 't', 'c', 'h', '\n',
        's', 'c', 'r', 'a', 't', 'c', 'h', 'e', 'd', '\n',
        's', 'c', 'r', 'a', 't', 'c', 'h', 'e', 's', '\n',
        's', 'c', 'r', 'a', 't', 'c', 'h', 'i', 'e', 'r', '\n',
        's', 'c', 'r', 'a', 't', 'c', 'h', 'i', 'e', 's', 't', '\n',
        's', 'c', 'r', 'a', 't', 'c', 'h', 'i', 'n', 'e', 's', 's', '\n',
        's', 'c', 'r', 'a', 't', 'c', 'h', 'i', 'n', 'g', '\n',
        's', 'c', 'r', 'a', 't', 'c', 'h', 'i', 'n', 'g', 's', '\n',
        's', 'c', 'r', 'a', 't', 'c', 'h', 'y', '\n',
        's', 'c', 'r', 'a', 'w', 'l', '\n',
        's', 'c', 'r', 'a', 'w', 'l', 'e', 'd', '\n',
        's', 'c', 'r', 'a', 'w', 'l', 'i', 'n', 'g', '\n',
        's', 'c', 'r', 'a', 'w', 'l', 's', '\n',
        's', 'c', 'r', 'a', 'w', 'n', 'i', 'e', 'r', '\n',
        's', 'c', 'r', 'a', 'w', 'n', 'i', 'e', 's', 't', '\n',
        's', 'c', 'r', 'a', 'w', 'n', 'y', '\n',
        's', 'c', 'r', 'e', 'a', 'm', '\n',
        's', 'c', 'r', 'e', 'a', 'm', 'e', 'd', '\n',
        's', 'c', 'r', 'e', 'a', 'm', 'e', 'r', '\n',
        's', 'c', 'r', 'e', 'a', 'm', 'e', 'r', 's', '\n',
        's', 'c', 'r', 'e', 'a', 'm', 'i', 'n', 'g', '\n',
        's', 'c', 'r', 'e', 'a', 'm', 'i', 'n', 'g', 'l', 'y', '\n',
        's', 'c', 'r', 'e', 'a', 'm', 's', '\n',
        's', 'c', 'r', 'e', 'e', '\n',
        's', 'c', 'r', 'e', 'e', 'c', 'h', '\n',
        's', 'c', 'r', 'e', 'e', 'c', 'h', 'e', 'd', '\n',
        's', 'c', 'r', 'e', 'e', 'c', 'h', 'e', 's', '\n',
        's', 'c', 'r', 'e', 'e', 'c', 'h', 'i', 'e', 'r', '\n',
        's', 'c', 'r', 'e', 'e', 'c', 'h', 'i', 'e', 's', 't', '\n',
        's', 'c', 'r', 'e', 'e', 'c', 'h', 'i', 'n', 'g', '\n',
        's', 'c', 'r', 'e', 'e', 'c', 'h', 'y', '\n',
        's', 'c', 'r', 'e', 'e', 'd', '\n',
        's', 'c', 'r', 'e', 'e', 'd', 's', '\n',
        's', 'c', 'r', 'e', 'e', 'n', '\n',
        's', 'c', 'r', 'e', 'e', 'n', 'e', 'd', '\n',
        's', 'c', 'r', 'e', 'e', 'n', 'i', 'n', 'g', '\n',
        's', 'c', 'r', 'e', 'e', 'n', 'i', 'n', 'g', 's', '\n',
        's', 'c', 'r', 'e', 'e', 'n', 'p', 'l', 'a', 'y', '\n',
        's', 'c', 'r', 'e', 'e', 'n', 'p', 'l', 'a', 'y', 's', '\n',
        's', 'c', 'r', 'e', 'e', 'n', 's', '\n',
        's', 'c', 'r', 'e', 'e', 'n', 'w', 'r', 'i', 't', 'e', 'r', '\n',
        's', 'c', 'r', 'e', 'w', '\n',
        's', 'c', 'r', 'e', 'w', 'd', 'r', 'i', 'v', 'e', 'r', '\n',
        's', 'c', 'r', 'e', 'w', 'd', 'r', 'i', 'v', 'e', 'r', 's', '\n',
        's', 'c', 'r', 'e', 'w', 'e', 'd', '\n',
        's', 'c', 'r', 'e', 'w', 'i', 'n', 'g', '\n',
        's', 'c', 'r', 'e', 'w', 's', '\n',
        's', 'c', 'r', 'e', 'w', 'y', '\n',
        's', 'c', 'r', 'i', 'b', 'a', 'l', '\n',
        's', 'c', 'r', 'i', 'b', 'b', 'l', 'e', '\n',
        's', 'c', 'r', 'i', 'b', 'b', 'l', 'e', 'd', '\n',
        's', 'c', 'r', 'i', 'b', 'b', 'l', 'e', 'r', '\n',
        's', 'c', 'r', 'i', 'b', 'b', 'l', 'e', 'r', 's', '\n',
        's', 'c', 'r', 'i', 'b', 'b', 'l', 'e', 's', '\n',
        's', 'c', 'r', 'i', 'b', 'b', 'l', 'i', 'n', 'g', '\n',
        's', 'c', 'r', 'i', 'b', 'b', 'l', 'i', 'n', 'g', 's', '\n',
        's', 'c', 'r', 'i', 'b', 'e', '\n',
        's', 'c', 'r', 'i', 'b', 'e', 'd', '\n',
        's', 'c', 'r', 'i', 'b', 'e', 's', '\n',
        's', 'c', 'r', 'i', 'b', 'i', 'n', 'g', '\n',
        's', 'c', 'r', 'i', 'm', 'p', 'e', 'd', '\n',
        's', 'c', 'r', 'i', 'p', 't', '\n',
        's', 'c', 'r', 'i', 'p', 't', 'e', 'd', '\n',
        's', 'c', 'r', 'i', 'p', 't', 'i', 'n', 'g', '\n',
        's', 'c', 'r', 'i', 'p', 't', 'o', 'r', 'i', 'u', 'm', '\n',
        's', 'c', 'r', 'i', 'p', 't', 's', '\n',
        's', 'c', 'r', 'i', 'p', 't', 'u', 'r', 'a', 'l', '\n',
        's', 'c', 'r', 'i', 'p', 't', 'u', 'r', 'e', '\n',
        's', 'c', 'r', 'i', 'p', 't', 'u', 'r', 'e', 's', '\n',
        's', 'c', 'r', 'i', 'p', 't', 'w', 'r', 'i', 't', 'e', 'r', '\n',
        's', 'c', 'r', 'i', 'p', 't', 'w', 'r', 'i', 't', 'e', 'r', 's', '\n',
        's', 'c', 'r', 'i', 'p', 't', 'w', 'r', 'i', 't', 'i', 'n', 'g', '\n',
        's', 'c', 'r', 'o', 'l', 'l', '\n',
        's', 'c', 'r', 'o', 'l', 'l', 'a', 'b', 'l', 'e', '\n',
        's', 'c', 'r', 'o', 'l', 'l', 'e', 'd', '\n',
        's', 'c', 'r', 'o', 'l', 'l', 'i', 'n', 'g', '\n',
        's', 'c', 'r', 'o', 'l', 'l', 's', '\n',
        's', 'c', 'r', 'o', 'o', 'g', 'e', '\n',
        's', 'c', 'r', 'o', 'o', 'g', 'e', 's', '\n',
        's', 'c', 'r', 'o', 't', 'u', 'm', '\n',
        's', 'c', 'r', 'u', 'b', '\n',
        's', 'c', 'r', 'u', 'b', 'b', 'e', 'd', '\n',
        's', 'c', 'r', 'u', 'b', 'b', 'e', 'r', '\n',
        's', 'c', 'r', 'u', 'b', 'b', 'e', 'r', 's', '\n',
        's', 'c', 'r', 'u', 'b', 'b', 'i', 'n', 'g', '\n',
        's', 'c', 'r', 'u', 'b', 'b', 'y', '\n',
        's', 'c', 'r', 'u', 'b', 'l', 'a', 'n', 'd', '\n',
        's', 'c', 'r', 'u', 'b', 's', '\n',
        's', 'c', 'r', 'u', 'f', 'f', '\n',
        's', 'c', 'r', 'u', 'f', 'f', 'i', 'e', 'r', '\n',
        's', 'c', 'r', 'u', 'f', 'f', 'y', '\n',
        's', 'c', 'r', 'u', 'm', '\n',
        's', 'c', 'r', 'u', 'm', 'h', 'a', 'l', 'f', '\n',
        's', 'c', 'r', 'u', 'm', 'm', 'a', 'g', 'e', '\n',
        's', 'c', 'r', 'u', 'm', 'm', 'a', 'g', 'i', 'n', 'g', '\n',
        's', 'c', 'r', 'u', 'm', 's', '\n',
        's', 'c', 'r', 'u', 'n', 'c', 'h', 'e', 'd', '\n',
        's', 'c', 'r', 'u', 'p', 'l', 'e', '\n',
        's', 'c', 'r', 'u', 'p', 'l', 'e', 's', '\n',
        's', 'c', 'r', 'u', 'p', 'u', 'l', 'o', 'u', 's', '\n',
        's', 'c', 'r', 'u', 'p', 'u', 'l', 'o', 'u', 's', 'l', 'y', '\n',
        's', 'c', 'r', 'u', 'p', 'u', 'l', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        's', 'c', 'r', 'u', 't', 'i', 'n', 'e', 'e', 'r', 's', '\n',
        's', 'c', 'r', 'u', 't', 'i', 'n', 'i', 'e', 's', '\n',
        's', 'c', 'r', 'u', 't', 'i', 'n', 'i', 's', 'e', '\n',
        's', 'c', 'r', 'u', 't', 'i', 'n', 'i', 's', 'e', 'd', '\n',
        's', 'c', 'r', 'u', 't', 'i', 'n', 'i', 's', 'e', 's', '\n',
        's', 'c', 'r', 'u', 't', 'i', 'n', 'i', 's', 'i', 'n', 'g', '\n',
        's', 'c', 'r', 'u', 't', 'i', 'n', 'y', '\n',
        's', 'c', 'u', 'b', 'a', '\n',
        's', 'c', 'u', 'b', 'a', 's', '\n',
        's', 'c', 'u', 'd', '\n',
        's', 'c', 'u', 'd', 'd', 'e', 'd', '\n',
        's', 'c', 'u', 'd', 'd', 'i', 'n', 'g', '\n',
        's', 'c', 'u', 'd', 's', '\n',
        's', 'c', 'u', 'f', 'f', '\n',
        's', 'c', 'u', 'f', 'f', 'e', 'd', '\n',
        's', 'c', 'u', 'f', 'f', 'i', 'n', 'g', '\n',
        's', 'c', 'u', 'f', 'f', 'l', 'e', '\n',
        's', 'c', 'u', 'f', 'f', 'l', 'e', 'd', '\n',
        's', 'c', 'u', 'f', 'f', 'l', 'e', 's', '\n',
        's', 'c', 'u', 'f', 'f', 'l', 'i', 'n', 'g', '\n',
        's', 'c', 'u', 'l', 'l', '\n',
        's', 'c', 'u', 'l', 'l', 'e', 'd', '\n',
        's', 'c', 'u', 'l', 'l', 'e', 'r', '\n',
        's', 'c', 'u', 'l', 'l', 'e', 'r', 'i', 'e', 's', '\n',
        's', 'c', 'u', 'l', 'l', 'e', 'r', 'y', '\n',
        's', 'c', 'u', 'l', 'l', 'i', 'n', 'g', '\n',
        's', 'c', 'u', 'l', 'l', 's', '\n',
        's', 'c', 'u', 'l', 'p', 't', '\n',
        's', 'c', 'u', 'l', 'p', 't', 'e', 'd', '\n',
        's', 'c', 'u', 'l', 'p', 't', 'i', 'n', 'g', '\n',
        's', 'c', 'u', 'l', 'p', 't', 'o', 'r', '\n',
        's', 'c', 'u', 'l', 'p', 't', 'o', 'r', 's', '\n',
        's', 'c', 'u', 'l', 'p', 't', 'r', 'e', 's', 's', '\n',
        's', 'c', 'u', 'l', 'p', 't', 'u', 'r', 'a', 'l', '\n',
        's', 'c', 'u', 'l', 'p', 't', 'u', 'r', 'e', '\n',
        's', 'c', 'u', 'l', 'p', 't', 'u', 'r', 'e', 'd', '\n',
        's', 'c', 'u', 'l', 'p', 't', 'u', 'r', 'e', 's', '\n',
        's', 'c', 'u', 'm', '\n',
        's', 'c', 'u', 'p', 'p', 'e', 'r', '\n',
        's', 'c', 'u', 'p', 'p', 'e', 'r', 'e', 'd', '\n',
        's', 'c', 'u', 'r', 'r', 'i', 'e', 'd', '\n',
        's', 'c', 'u', 'r', 'r', 'i', 'e', 's', '\n',
        's', 'c', 'u', 'r', 'r', 'i', 'l', 'o', 'u', 's', '\n',
        's', 'c', 'u', 'r', 'r', 'y', '\n',
        's', 'c', 'u', 'r', 'r', 'y', 'i', 'n', 'g', '\n',
        's', 'c', 'u', 'r', 'r', 'y', 'i', 'n', 'g', 's', '\n',
        's', 'c', 'u', 'r', 'v', 'y', '\n',
        's', 'c', 'u', 't', 't', 'l', 'e', '\n',
        's', 'c', 'u', 't', 't', 'l', 'e', 'd', '\n',
        's', 'c', 'u', 't', 't', 'l', 'e', 's', '\n',
        's', 'c', 'u', 't', 't', 'l', 'i', 'n', 'g', '\n',
        's', 'c', 'y', 't', 'h', 'e', '\n',
        's', 'c', 'y', 't', 'h', 'e', 'd', '\n',
        's', 'c', 'y', 't', 'h', 'e', 's', '\n',
        's', 'c', 'y', 't', 'h', 'i', 'n', 'g', '\n',
        's', 'e', 'a', '\n',
        's', 'e', 'a', 'b', 'e', 'd', '\n',
        's', 'e', 'a', 'b', 'i', 'r', 'd', '\n',
        's', 'e', 'a', 'b', 'i', 'r', 'd', 's', '\n',
        's', 'e', 'a', 'b', 'o', 'a', 'r', 'd', '\n',
        's', 'e', 'a', 'b', 'o', 'r', 'n', 'e', '\n',
        's', 'e', 'a', 'c', 'o', 'w', '\n',
        's', 'e', 'a', 'c', 'o', 'w', 's', '\n',
        's', 'e', 'a', 'f', 'a', 'r', 'e', 'r', '\n',
        's', 'e', 'a', 'f', 'a', 'r', 'e', 'r', 's', '\n',
        's', 'e', 'a', 'f', 'a', 'r', 'i', 'n', 'g', '\n',
        's', 'e', 'a', 'f', 'o', 'o', 'd', '\n',
        's', 'e', 'a', 'f', 'r', 'o', 'n', 't', '\n',
        's', 'e', 'a', 'g', 'o', 'd', '\n',
        's', 'e', 'a', 'g', 'o', 'i', 'n', 'g', '\n',
        's', 'e', 'a', 'g', 'r', 'e', 'e', 'n', '\n',
        's', 'e', 'a', 'g', 'u', 'l', 'l', '\n',
        's', 'e', 'a', 'g', 'u', 'l', 'l', 's', '\n',
        's', 'e', 'a', 'l', '\n',
        's', 'e', 'a', 'l', 'a', 'n', 't', '\n',
        's', 'e', 'a', 'l', 'a', 'n', 't', 's', '\n',
        's', 'e', 'a', 'l', 'e', 'd', '\n',
        's', 'e', 'a', 'l', 'e', 'r', '\n',
        's', 'e', 'a', 'l', 'e', 'r', 's', '\n',
        's', 'e', 'a', 'l', 'i', 'n', 'g', '\n',
        's', 'e', 'a', 'l', 'i', 'o', 'n', '\n',
        's', 'e', 'a', 'l', 's', '\n',
        's', 'e', 'a', 'm', '\n',
        's', 'e', 'a', 'm', 'a', 'i', 'l', '\n',
        's', 'e', 'a', 'm', 'a', 'n', '\n',
        's', 'e', 'a', 'm', 'a', 'n', 's', 'h', 'i', 'p', '\n',
        's', 'e', 'a', 'm', 'e', 'd', '\n',
        's', 'e', 'a', 'm', 'e', 'n', '\n',
        's', 'e', 'a', 'm', 'i', 'e', 'r', '\n',
        's', 'e', 'a', 'm', 'l', 'e', 's', 's', '\n',
        's', 'e', 'a', 'm', 'l', 'e', 's', 's', 'l', 'y', '\n',
        's', 'e', 'a', 'm', 's', '\n',
        's', 'e', 'a', 'm', 's', 't', 'r', 'e', 's', 's', '\n',
        's', 'e', 'a', 'm', 's', 't', 'r', 'e', 's', 's', 'e', 's', '\n',
        's', 'e', 'a', 'm', 'y', '\n',
        's', 'e', 'a', 'n', 'c', 'e', '\n',
        's', 'e', 'a', 'n', 'c', 'e', 's', '\n',
        's', 'e', 'a', 'p', 'l', 'a', 'n', 'e', '\n',
        's', 'e', 'a', 'p', 'l', 'a', 'n', 'e', 's', '\n',
        's', 'e', 'a', 'p', 'o', 'r', 't', '\n',
        's', 'e', 'a', 'p', 'o', 'r', 't', 's', '\n',
        's', 'e', 'a', 'r', '\n',
        's', 'e', 'a', 'r', 'c', 'h', '\n',
        's', 'e', 'a', 'r', 'c', 'h', 'e', 'd', '\n',
        's', 'e', 'a', 'r', 'c', 'h', 'e', 'r', '\n',
        's', 'e', 'a', 'r', 'c', 'h', 'e', 'r', 's', '\n',
        's', 'e', 'a', 'r', 'c', 'h', 'e', 's', '\n',
        's', 'e', 'a', 'r', 'c', 'h', 'i', 'n', 'g', '\n',
        's', 'e', 'a', 'r', 'c', 'h', 'i', 'n', 'g', 'l', 'y', '\n',
        's', 'e', 'a', 'r', 'c', 'h', 'l', 'i', 'g', 'h', 't', '\n',
        's', 'e', 'a', 'r', 'c', 'h', 'l', 'i', 'g', 'h', 't', 's', '\n',
        's', 'e', 'a', 'r', 'e', 'd', '\n',
        's', 'e', 'a', 'r', 'i', 'n', 'g', '\n',
        's', 'e', 'a', 'r', 's', '\n',
        's', 'e', 'a', 's', '\n',
        's', 'e', 'a', 's', 'c', 'a', 'p', 'e', '\n',
        's', 'e', 'a', 's', 'c', 'a', 'p', 'e', 's', '\n',
        's', 'e', 'a', 's', 'h', 'e', 'l', 'l', 's', '\n',
        's', 'e', 'a', 's', 'h', 'o', 'r', 'e', '\n',
        's', 'e', 'a', 's', 'h', 'o', 'r', 'e', 's', '\n',
        's', 'e', 'a', 's', 'i', 'c', 'k', '\n',
        's', 'e', 'a', 's', 'i', 'c', 'k', 'n', 'e', 's', 's', '\n',
        's', 'e', 'a', 's', 'i', 'd', 'e', '\n',
        's', 'e', 'a', 's', 'o', 'n', '\n',
        's', 'e', 'a', 's', 'o', 'n', 'a', 'b', 'l', 'e', '\n',
        's', 'e', 'a', 's', 'o', 'n', 'a', 'b', 'l', 'y', '\n',
        's', 'e', 'a', 's', 'o', 'n', 'a', 'l', '\n',
        's', 'e', 'a', 's', 'o', 'n', 'a', 'l', 'i', 't', 'y', '\n',
        's', 'e', 'a', 's', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        's', 'e', 'a', 's', 'o', 'n', 'e', 'd', '\n',
        's', 'e', 'a', 's', 'o', 'n', 'e', 'r', '\n',
        's', 'e', 'a', 's', 'o', 'n', 'i', 'n', 'g', '\n',
        's', 'e', 'a', 's', 'o', 'n', 's', '\n',
        's', 'e', 'a', 't', '\n',
        's', 'e', 'a', 't', 'e', 'd', '\n',
        's', 'e', 'a', 't', 'i', 'n', 'g', '\n',
        's', 'e', 'a', 't', 'i', 'n', 'g', 's', '\n',
        's', 'e', 'a', 't', 's', '\n',
        's', 'e', 'a', 't', 't', 'l', 'e', '\n',
        's', 'e', 'a', 'w', 'a', 'r', 'd', '\n',
        's', 'e', 'a', 'w', 'a', 'r', 'd', 's', '\n',
        's', 'e', 'a', 'w', 'a', 't', 'e', 'r', '\n',
        's', 'e', 'a', 'w', 'e', 'e', 'd', '\n',
        's', 'e', 'a', 'w', 'e', 'e', 'd', 's', '\n',
        's', 'e', 'a', 'w', 'o', 'r', 't', 'h', 'y', '\n',
        's', 'e', 'b', 'a', 'c', 'e', 'o', 'u', 's', '\n',
        's', 'e', 'c', '\n',
        's', 'e', 'c', 'a', 'n', 't', '\n',
        's', 'e', 'c', 'a', 't', 'e', 'u', 'r', 's', '\n',
        's', 'e', 'c', 'e', 'd', 'e', '\n',
        's', 'e', 'c', 'e', 'd', 'e', 'd', '\n',
        's', 'e', 'c', 'e', 'd', 'e', 's', '\n',
        's', 'e', 'c', 'e', 'd', 'i', 'n', 'g', '\n',
        's', 'e', 'c', 'e', 's', 's', 'i', 'o', 'n', '\n',
        's', 'e', 'c', 'e', 's', 's', 'i', 'o', 'n', 'i', 's', 't', '\n',
        's', 'e', 'c', 'e', 's', 's', 'i', 'o', 'n', 'i', 's', 't', 's', '\n',
        's', 'e', 'c', 'e', 's', 's', 'i', 'o', 'n', 's', '\n',
        's', 'e', 'c', 'l', 'u', 'd', 'e', '\n',
        's', 'e', 'c', 'l', 'u', 'd', 'e', 'd', '\n',
        's', 'e', 'c', 'l', 'u', 's', 'i', 'o', 'n', '\n',
        's', 'e', 'c', 'o', 'n', 'd', '\n',
        's', 'e', 'c', 'o', 'n', 'd', 'a', 'r', 'i', 'e', 's', '\n',
        's', 'e', 'c', 'o', 'n', 'd', 'a', 'r', 'i', 'l', 'y', '\n',
        's', 'e', 'c', 'o', 'n', 'd', 'a', 'r', 'y', '\n',
        's', 'e', 'c', 'o', 'n', 'd', 'b', 'e', 's', 't', '\n',
        's', 'e', 'c', 'o', 'n', 'd', 'c', 'l', 'a', 's', 's', '\n',
        's', 'e', 'c', 'o', 'n', 'd', 'e', 'd', '\n',
        's', 'e', 'c', 'o', 'n', 'd', 'e', 'r', '\n',
        's', 'e', 'c', 'o', 'n', 'd', 'e', 'r', 's', '\n',
        's', 'e', 'c', 'o', 'n', 'd', 'h', 'a', 'n', 'd', '\n',
        's', 'e', 'c', 'o', 'n', 'd', 'i', 'n', 'g', '\n',
        's', 'e', 'c', 'o', 'n', 'd', 'l', 'y', '\n',
        's', 'e', 'c', 'o', 'n', 'd', 'm', 'e', 'n', 't', '\n',
        's', 'e', 'c', 'o', 'n', 'd', 'm', 'e', 'n', 't', 's', '\n',
        's', 'e', 'c', 'o', 'n', 'd', 'r', 'a', 't', 'e', '\n',
        's', 'e', 'c', 'o', 'n', 'd', 's', '\n',
        's', 'e', 'c', 'r', 'e', 'c', 'y', '\n',
        's', 'e', 'c', 'r', 'e', 't', '\n',
        's', 'e', 'c', 'r', 'e', 't', 'a', 'r', 'i', 'a', 'l', '\n',
        's', 'e', 'c', 'r', 'e', 't', 'a', 'r', 'i', 'a', 't', '\n',
        's', 'e', 'c', 'r', 'e', 't', 'a', 'r', 'i', 'a', 't', 's', '\n',
        's', 'e', 'c', 'r', 'e', 't', 'a', 'r', 'i', 'e', 's', '\n',
        's', 'e', 'c', 'r', 'e', 't', 'a', 'r', 'y', '\n',
        's', 'e', 'c', 'r', 'e', 't', 'a', 'r', 'y', 's', 'h', 'i', 'p', '\n',
        's', 'e', 'c', 'r', 'e', 't', 'e', '\n',
        's', 'e', 'c', 'r', 'e', 't', 'e', 'd', '\n',
        's', 'e', 'c', 'r', 'e', 't', 'e', 's', '\n',
        's', 'e', 'c', 'r', 'e', 't', 'i', 'n', 'g', '\n',
        's', 'e', 'c', 'r', 'e', 't', 'i', 'o', 'n', '\n',
        's', 'e', 'c', 'r', 'e', 't', 'i', 'o', 'n', 's', '\n',
        's', 'e', 'c', 'r', 'e', 't', 'i', 'v', 'e', '\n',
        's', 'e', 'c', 'r', 'e', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        's', 'e', 'c', 'r', 'e', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        's', 'e', 'c', 'r', 'e', 't', 'l', 'y', '\n',
        's', 'e', 'c', 'r', 'e', 't', 'o', 'r', 'y', '\n',
        's', 'e', 'c', 'r', 'e', 't', 's', '\n',
        's', 'e', 'c', 't', '\n',
        's', 'e', 'c', 't', 'a', 'r', 'i', 'a', 'n', '\n',
        's', 'e', 'c', 't', 'a', 'r', 'i', 'a', 'n', 'i', 's', 'm', '\n',
        's', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        's', 'e', 'c', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        's', 'e', 'c', 't', 'i', 'o', 'n', 'e', 'd', '\n',
        's', 'e', 'c', 't', 'i', 'o', 'n', 'i', 'n', 'g', '\n',
        's', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        's', 'e', 'c', 't', 'o', 'r', '\n',
        's', 'e', 'c', 't', 'o', 'r', 'a', 'l', '\n',
        's', 'e', 'c', 't', 'o', 'r', 'e', 'd', '\n',
        's', 'e', 'c', 't', 'o', 'r', 's', '\n',
        's', 'e', 'c', 't', 's', '\n',
        's', 'e', 'c', 'u', 'l', 'a', 'r', '\n',
        's', 'e', 'c', 'u', 'l', 'a', 'r', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'e', 'c', 'u', 'l', 'a', 'r', 'i', 's', 'e', 'd', '\n',
        's', 'e', 'c', 'u', 'l', 'a', 'r', 'i', 's', 'm', '\n',
        's', 'e', 'c', 'u', 'l', 'a', 'r', 'i', 's', 't', '\n',
        's', 'e', 'c', 'u', 'l', 'a', 'r', 'i', 's', 't', 's', '\n',
        's', 'e', 'c', 'u', 'r', 'e', '\n',
        's', 'e', 'c', 'u', 'r', 'e', 'd', '\n',
        's', 'e', 'c', 'u', 'r', 'e', 'l', 'y', '\n',
        's', 'e', 'c', 'u', 'r', 'e', 'r', '\n',
        's', 'e', 'c', 'u', 'r', 'e', 's', '\n',
        's', 'e', 'c', 'u', 'r', 'e', 's', 't', '\n',
        's', 'e', 'c', 'u', 'r', 'i', 'n', 'g', '\n',
        's', 'e', 'c', 'u', 'r', 'i', 't', 'i', 'e', 's', '\n',
        's', 'e', 'c', 'u', 'r', 'i', 't', 'y', '\n',
        's', 'e', 'd', 'a', 'n', '\n',
        's', 'e', 'd', 'a', 't', 'e', '\n',
        's', 'e', 'd', 'a', 't', 'e', 'd', '\n',
        's', 'e', 'd', 'a', 't', 'e', 'l', 'y', '\n',
        's', 'e', 'd', 'a', 't', 'e', 'n', 'e', 's', 's', '\n',
        's', 'e', 'd', 'a', 't', 'e', 'r', '\n',
        's', 'e', 'd', 'a', 't', 'e', 's', '\n',
        's', 'e', 'd', 'a', 't', 'i', 'n', 'g', '\n',
        's', 'e', 'd', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'e', 'd', 'a', 't', 'i', 'v', 'e', '\n',
        's', 'e', 'd', 'a', 't', 'i', 'v', 'e', 's', '\n',
        's', 'e', 'd', 'e', 'n', 't', 'a', 'r', 'y', '\n',
        's', 'e', 'd', 'g', 'e', '\n',
        's', 'e', 'd', 'g', 'e', 's', '\n',
        's', 'e', 'd', 'i', 'm', 'e', 'n', 't', '\n',
        's', 'e', 'd', 'i', 'm', 'e', 'n', 't', 'a', 'r', 'y', '\n',
        's', 'e', 'd', 'i', 'm', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'e', 'd', 'i', 'm', 'e', 'n', 't', 's', '\n',
        's', 'e', 'd', 'i', 't', 'i', 'o', 'n', '\n',
        's', 'e', 'd', 'i', 't', 'i', 'o', 'u', 's', '\n',
        's', 'e', 'd', 'u', 'c', 'e', '\n',
        's', 'e', 'd', 'u', 'c', 'e', 'd', '\n',
        's', 'e', 'd', 'u', 'c', 'e', 'r', '\n',
        's', 'e', 'd', 'u', 'c', 'e', 'r', 's', '\n',
        's', 'e', 'd', 'u', 'c', 'e', 's', '\n',
        's', 'e', 'd', 'u', 'c', 'i', 'n', 'g', '\n',
        's', 'e', 'd', 'u', 'c', 't', 'i', 'o', 'n', '\n',
        's', 'e', 'd', 'u', 'c', 't', 'i', 'o', 'n', 's', '\n',
        's', 'e', 'd', 'u', 'c', 't', 'i', 'v', 'e', '\n',
        's', 'e', 'd', 'u', 'c', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        's', 'e', 'd', 'u', 'c', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        's', 'e', 'd', 'u', 'l', 'o', 'u', 's', 'l', 'y', '\n',
        's', 'e', 'e', '\n',
        's', 'e', 'e', 'a', 'b', 'l', 'e', '\n',
        's', 'e', 'e', 'd', '\n',
        's', 'e', 'e', 'd', 'b', 'e', 'd', '\n',
        's', 'e', 'e', 'd', 'e', 'd', '\n',
        's', 'e', 'e', 'd', 'e', 'r', '\n',
        's', 'e', 'e', 'd', 'i', 'e', 'r', '\n',
        's', 'e', 'e', 'd', 'i', 'e', 's', 't', '\n',
        's', 'e', 'e', 'd', 'i', 'n', 'e', 's', 's', '\n',
        's', 'e', 'e', 'd', 'i', 'n', 'g', '\n',
        's', 'e', 'e', 'd', 'l', 'e', 's', 's', '\n',
        's', 'e', 'e', 'd', 'l', 'i', 'n', 'g', '\n',
        's', 'e', 'e', 'd', 'l', 'i', 'n', 'g', 's', '\n',
        's', 'e', 'e', 'd', 's', '\n',
        's', 'e', 'e', 'd', 'y', '\n',
        's', 'e', 'e', 'i', 'n', 'g', '\n',
        's', 'e', 'e', 'i', 'n', 'g', 's', '\n',
        's', 'e', 'e', 'k', '\n',
        's', 'e', 'e', 'k', 'e', 'r', '\n',
        's', 'e', 'e', 'k', 'e', 'r', 's', '\n',
        's', 'e', 'e', 'k', 'i', 'n', 'g', '\n',
        's', 'e', 'e', 'k', 's', '\n',
        's', 'e', 'e', 'm', '\n',
        's', 'e', 'e', 'm', 'e', 'd', '\n',
        's', 'e', 'e', 'm', 'i', 'n', 'g', '\n',
        's', 'e', 'e', 'm', 'i', 'n', 'g', 'l', 'y', '\n',
        's', 'e', 'e', 'm', 'l', 'i', 'e', 'r', '\n',
        's', 'e', 'e', 'm', 'l', 'i', 'e', 's', 't', '\n',
        's', 'e', 'e', 'm', 'l', 'y', '\n',
        's', 'e', 'e', 'm', 's', '\n',
        's', 'e', 'e', 'n', '\n',
        's', 'e', 'e', 'p', '\n',
        's', 'e', 'e', 'p', 'a', 'g', 'e', '\n',
        's', 'e', 'e', 'p', 'e', 'd', '\n',
        's', 'e', 'e', 'p', 'i', 'n', 'g', '\n',
        's', 'e', 'e', 'p', 's', '\n',
        's', 'e', 'e', 'r', '\n',
        's', 'e', 'e', 'r', 's', '\n',
        's', 'e', 'e', 's', '\n',
        's', 'e', 'e', 's', 'a', 'w', '\n',
        's', 'e', 'e', 's', 'a', 'w', 's', '\n',
        's', 'e', 'e', 't', 'h', 'e', '\n',
        's', 'e', 'e', 't', 'h', 'e', 'd', '\n',
        's', 'e', 'e', 't', 'h', 'e', 's', '\n',
        's', 'e', 'e', 't', 'h', 'i', 'n', 'g', '\n',
        's', 'e', 'e', 't', 'h', 'r', 'o', 'u', 'g', 'h', '\n',
        's', 'e', 'g', 'm', 'e', 'n', 't', '\n',
        's', 'e', 'g', 'm', 'e', 'n', 't', 'a', 'l', '\n',
        's', 'e', 'g', 'm', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'e', 'g', 'm', 'e', 'n', 't', 'e', 'd', '\n',
        's', 'e', 'g', 'm', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        's', 'e', 'g', 'm', 'e', 'n', 't', 's', '\n',
        's', 'e', 'g', 'r', 'e', 'g', 'a', 't', 'e', '\n',
        's', 'e', 'g', 'r', 'e', 'g', 'a', 't', 'e', 'd', '\n',
        's', 'e', 'g', 'r', 'e', 'g', 'a', 't', 'e', 's', '\n',
        's', 'e', 'g', 'r', 'e', 'g', 'a', 't', 'i', 'n', 'g', '\n',
        's', 'e', 'g', 'r', 'e', 'g', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'e', 'i', 'n', 'e', '\n',
        's', 'e', 'i', 's', 'i', 'n', '\n',
        's', 'e', 'i', 's', 'm', 'i', 'c', '\n',
        's', 'e', 'i', 's', 'm', 'o', 'g', 'r', 'a', 'm', '\n',
        's', 'e', 'i', 's', 'm', 'o', 'g', 'r', 'a', 'p', 'h', '\n',
        's', 'e', 'i', 's', 'm', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        's', 'e', 'i', 's', 'm', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        's', 'e', 'i', 's', 'm', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        's', 'e', 'i', 's', 'm', 'o', 'l', 'o', 'g', 'y', '\n',
        's', 'e', 'i', 's', 'm', 'o', 'm', 'e', 't', 'e', 'r', '\n',
        's', 'e', 'i', 's', 'm', 'o', 'm', 'e', 't', 'e', 'r', 's', '\n',
        's', 'e', 'i', 'z', 'e', '\n',
        's', 'e', 'i', 'z', 'e', 'd', '\n',
        's', 'e', 'i', 'z', 'e', 'r', '\n',
        's', 'e', 'i', 'z', 'e', 's', '\n',
        's', 'e', 'i', 'z', 'i', 'n', 'g', '\n',
        's', 'e', 'i', 'z', 'u', 'r', 'e', '\n',
        's', 'e', 'i', 'z', 'u', 'r', 'e', 's', '\n',
        's', 'e', 'l', 'd', 'o', 'm', '\n',
        's', 'e', 'l', 'e', 'c', 't', '\n',
        's', 'e', 'l', 'e', 'c', 't', 'a', 'b', 'l', 'e', '\n',
        's', 'e', 'l', 'e', 'c', 't', 'e', 'd', '\n',
        's', 'e', 'l', 'e', 'c', 't', 'e', 'e', '\n',
        's', 'e', 'l', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        's', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        's', 'e', 'l', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        's', 'e', 'l', 'e', 'c', 't', 'i', 'v', 'e', '\n',
        's', 'e', 'l', 'e', 'c', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        's', 'e', 'l', 'e', 'c', 't', 'i', 'v', 'i', 't', 'y', '\n',
        's', 'e', 'l', 'e', 'c', 't', 'o', 'r', '\n',
        's', 'e', 'l', 'e', 'c', 't', 'o', 'r', 's', '\n',
        's', 'e', 'l', 'e', 'c', 't', 's', '\n',
        's', 'e', 'l', 'e', 'n', 'i', 'u', 'm', '\n',
        's', 'e', 'l', 'e', 'n', 'o', 'l', 'o', 'g', 'y', '\n',
        's', 'e', 'l', 'f', '\n',
        's', 'e', 'l', 'f', 'c', 'e', 'n', 't', 'r', 'e', 'd', '\n',
        's', 'e', 'l', 'f', 'c', 'e', 'n', 't', 'r', 'e', 'd', 'n', 'e', 's', 's', '\n',
        's', 'e', 'l', 'f', 'c', 'o', 'n', 'f', 'i', 'd', 'e', 'n', 'c', 'e', '\n',
        's', 'e', 'l', 'f', 'c', 'o', 'n', 'f', 'i', 'd', 'e', 'n', 't', '\n',
        's', 'e', 'l', 'f', 'c', 'o', 'n', 's', 'c', 'i', 'o', 'u', 's', '\n',
        's', 'e', 'l', 'f', 'c', 'o', 'n', 's', 'c', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        's', 'e', 'l', 'f', 'c', 'o', 'n', 's', 'c', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        's', 'e', 'l', 'f', 'c', 'o', 'n', 't', 'r', 'o', 'l', '\n',
        's', 'e', 'l', 'f', 'c', 'o', 'n', 't', 'r', 'o', 'l', 'l', 'e', 'd', '\n',
        's', 'e', 'l', 'f', 'd', 'e', 'f', 'e', 'n', 'c', 'e', '\n',
        's', 'e', 'l', 'f', 'd', 'e', 's', 't', 'r', 'u', 'c', 't', '\n',
        's', 'e', 'l', 'f', 'd', 'e', 's', 't', 'r', 'u', 'c', 't', 'e', 'd', '\n',
        's', 'e', 'l', 'f', 'd', 'e', 's', 't', 'r', 'u', 'c', 't', 'i', 'n', 'g', '\n',
        's', 'e', 'l', 'f', 'd', 'e', 's', 't', 'r', 'u', 'c', 't', 'i', 'o', 'n', '\n',
        's', 'e', 'l', 'f', 'd', 'e', 's', 't', 'r', 'u', 'c', 't', 'i', 'v', 'e', '\n',
        's', 'e', 'l', 'f', 'd', 'e', 's', 't', 'r', 'u', 'c', 't', 's', '\n',
        's', 'e', 'l', 'f', 'd', 'i', 's', 'c', 'i', 'p', 'l', 'i', 'n', 'e', '\n',
        's', 'e', 'l', 'f', 'e', 'm', 'p', 'l', 'o', 'y', 'e', 'd', '\n',
        's', 'e', 'l', 'f', 'e', 's', 't', 'e', 'e', 'm', '\n',
        's', 'e', 'l', 'f', 'e', 'v', 'i', 'd', 'e', 'n', 't', '\n',
        's', 'e', 'l', 'f', 'g', 'o', 'v', 'e', 'r', 'n', 'i', 'n', 'g', '\n',
        's', 'e', 'l', 'f', 'g', 'o', 'v', 'e', 'r', 'n', 'm', 'e', 'n', 't', '\n',
        's', 'e', 'l', 'f', 'i', 'n', 'f', 'l', 'i', 'c', 't', 'e', 'd', '\n',
        's', 'e', 'l', 'f', 'i', 'n', 't', 'e', 'r', 'e', 's', 't', '\n',
        's', 'e', 'l', 'f', 'i', 's', 'h', '\n',
        's', 'e', 'l', 'f', 'i', 's', 'h', 'l', 'y', '\n',
        's', 'e', 'l', 'f', 'i', 's', 'h', 'n', 'e', 's', 's', '\n',
        's', 'e', 'l', 'f', 'l', 'e', 's', 's', '\n',
        's', 'e', 'l', 'f', 'l', 'e', 's', 's', 'l', 'y', '\n',
        's', 'e', 'l', 'f', 'm', 'a', 'd', 'e', '\n',
        's', 'e', 'l', 'f', 'p', 'i', 't', 'y', '\n',
        's', 'e', 'l', 'f', 'p', 'o', 'r', 't', 'r', 'a', 'i', 't', '\n',
        's', 'e', 'l', 'f', 'p', 'o', 'r', 't', 'r', 'a', 'i', 't', 's', '\n',
        's', 'e', 'l', 'f', 'r', 'e', 's', 'p', 'e', 'c', 't', '\n',
        's', 'e', 'l', 'f', 'r', 'e', 's', 'p', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        's', 'e', 'l', 'f', 'r', 'e', 's', 't', 'r', 'a', 'i', 'n', 't', '\n',
        's', 'e', 'l', 'f', 'r', 'i', 'g', 'h', 't', 'e', 'o', 'u', 's', '\n',
        's', 'e', 'l', 'f', 'r', 'i', 'g', 'h', 't', 'e', 'o', 'u', 's', 'l', 'y', '\n',
        's', 'e', 'l', 'f', 'r', 'i', 'g', 'h', 't', 'e', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        's', 'e', 'l', 'f', 's', 'a', 'c', 'r', 'i', 'f', 'i', 'c', 'e', '\n',
        's', 'e', 'l', 'f', 's', 'a', 'c', 'r', 'i', 'f', 'i', 'c', 'i', 'n', 'g', '\n',
        's', 'e', 'l', 'f', 's', 'a', 'm', 'e', '\n',
        's', 'e', 'l', 'f', 's', 'u', 'p', 'p', 'o', 'r', 't', 'i', 'n', 'g', '\n',
        's', 'e', 'l', 'f', 't', 'a', 'u', 'g', 'h', 't', '\n',
        's', 'e', 'l', 'l', '\n',
        's', 'e', 'l', 'l', 'a', 'b', 'l', 'e', '\n',
        's', 'e', 'l', 'l', 'e', 'r', '\n',
        's', 'e', 'l', 'l', 'e', 'r', 's', '\n',
        's', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        's', 'e', 'l', 'l', 's', '\n',
        's', 'e', 'l', 'v', 'e', 's', '\n',
        's', 'e', 'm', 'a', 'n', 't', 'i', 'c', '\n',
        's', 'e', 'm', 'a', 'n', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 'e', 'm', 'a', 'n', 't', 'i', 'c', 's', '\n',
        's', 'e', 'm', 'a', 'p', 'h', 'o', 'r', 'e', '\n',
        's', 'e', 'm', 'a', 'p', 'h', 'o', 'r', 'e', 's', '\n',
        's', 'e', 'm', 'a', 'p', 'h', 'o', 'r', 'i', 'n', 'g', '\n',
        's', 'e', 'm', 'b', 'l', 'a', 'n', 'c', 'e', '\n',
        's', 'e', 'm', 'b', 'l', 'a', 'n', 'c', 'e', 's', '\n',
        's', 'e', 'm', 'e', 'n', '\n',
        's', 'e', 'm', 'e', 's', 't', 'e', 'r', '\n',
        's', 'e', 'm', 'e', 's', 't', 'e', 'r', 's', '\n',
        's', 'e', 'm', 'i', '\n',
        's', 'e', 'm', 'i', 'c', 'i', 'r', 'c', 'l', 'e', '\n',
        's', 'e', 'm', 'i', 'c', 'i', 'r', 'c', 'u', 'l', 'a', 'r', '\n',
        's', 'e', 'm', 'i', 'c', 'o', 'l', 'o', 'n', '\n',
        's', 'e', 'm', 'i', 'c', 'o', 'l', 'o', 'n', 's', '\n',
        's', 'e', 'm', 'i', 'c', 'o', 'n', 'd', 'u', 'c', 't', 'i', 'n', 'g', '\n',
        's', 'e', 'm', 'i', 'c', 'o', 'n', 'd', 'u', 'c', 't', 'o', 'r', '\n',
        's', 'e', 'm', 'i', 'c', 'o', 'n', 'd', 'u', 'c', 't', 'o', 'r', 's', '\n',
        's', 'e', 'm', 'i', 'c', 'o', 'n', 's', 'c', 'i', 'o', 'u', 's', '\n',
        's', 'e', 'm', 'i', 'd', 'e', 't', 'a', 'c', 'h', 'e', 'd', '\n',
        's', 'e', 'm', 'i', 'f', 'i', 'n', 'a', 'l', '\n',
        's', 'e', 'm', 'i', 'f', 'i', 'n', 'a', 'l', 'i', 's', 't', '\n',
        's', 'e', 'm', 'i', 'f', 'i', 'n', 'a', 'l', 'i', 's', 't', 's', '\n',
        's', 'e', 'm', 'i', 'f', 'i', 'n', 'a', 'l', 's', '\n',
        's', 'e', 'm', 'i', 'n', 'a', 'r', '\n',
        's', 'e', 'm', 'i', 'n', 'a', 'r', 'i', 'e', 's', '\n',
        's', 'e', 'm', 'i', 'n', 'a', 'r', 's', '\n',
        's', 'e', 'm', 'i', 'n', 'a', 'r', 'y', '\n',
        's', 'e', 'm', 'i', 't', 'e', '\n',
        's', 'e', 'm', 'i', 't', 'e', 's', '\n',
        's', 'e', 'm', 'i', 't', 'i', 'c', '\n',
        's', 'e', 'm', 'i', 't', 'i', 'c', 's', '\n',
        's', 'e', 'n', '\n',
        's', 'e', 'n', 'a', 't', 'e', '\n',
        's', 'e', 'n', 'a', 't', 'e', 's', '\n',
        's', 'e', 'n', 'a', 't', 'o', 'r', '\n',
        's', 'e', 'n', 'a', 't', 'o', 'r', 'i', 'a', 'l', '\n',
        's', 'e', 'n', 'a', 't', 'o', 'r', 's', '\n',
        's', 'e', 'n', 'd', '\n',
        's', 'e', 'n', 'd', 'e', 'r', '\n',
        's', 'e', 'n', 'd', 'e', 'r', 's', '\n',
        's', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        's', 'e', 'n', 'd', 's', '\n',
        's', 'e', 'n', 'e', 'g', 'a', 'l', '\n',
        's', 'e', 'n', 'h', 'o', 'r', '\n',
        's', 'e', 'n', 'h', 'o', 'r', 's', '\n',
        's', 'e', 'n', 'i', 'l', 'e', '\n',
        's', 'e', 'n', 'i', 'l', 'i', 't', 'y', '\n',
        's', 'e', 'n', 'i', 'o', 'r', '\n',
        's', 'e', 'n', 'i', 'o', 'r', 'i', 't', 'y', '\n',
        's', 'e', 'n', 'i', 'o', 'r', 's', '\n',
        's', 'e', 'n', 'o', 'r', 'a', '\n',
        's', 'e', 'n', 'o', 'r', 'i', 't', 'a', 's', '\n',
        's', 'e', 'n', 's', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'e', 'n', 's', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        's', 'e', 'n', 's', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        's', 'e', 'n', 's', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 'm', '\n',
        's', 'e', 'n', 's', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 't', '\n',
        's', 'e', 'n', 's', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 't', 'i', 'c', '\n',
        's', 'e', 'n', 's', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        's', 'e', 'n', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        's', 'e', 'n', 's', 'e', '\n',
        's', 'e', 'n', 's', 'e', 'd', '\n',
        's', 'e', 'n', 's', 'e', 'l', 'e', 's', 's', '\n',
        's', 'e', 'n', 's', 'e', 'l', 'e', 's', 's', 'l', 'y', '\n',
        's', 'e', 'n', 's', 'e', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        's', 'e', 'n', 's', 'e', 's', '\n',
        's', 'e', 'n', 's', 'i', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', '\n',
        's', 'e', 'n', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        's', 'e', 'n', 's', 'i', 'b', 'l', 'e', '\n',
        's', 'e', 'n', 's', 'i', 'b', 'l', 'e', 'n', 'e', 's', 's', '\n',
        's', 'e', 'n', 's', 'i', 'b', 'l', 'y', '\n',
        's', 'e', 'n', 's', 'i', 'n', 'g', '\n',
        's', 'e', 'n', 's', 'i', 'n', 'g', 's', '\n',
        's', 'e', 'n', 's', 'i', 't', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'e', 'n', 's', 'i', 't', 'i', 's', 'e', 'd', '\n',
        's', 'e', 'n', 's', 'i', 't', 'i', 's', 'e', 'r', 's', '\n',
        's', 'e', 'n', 's', 'i', 't', 'i', 'v', 'e', '\n',
        's', 'e', 'n', 's', 'i', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        's', 'e', 'n', 's', 'i', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        's', 'e', 'n', 's', 'i', 't', 'i', 'v', 'i', 't', 'i', 'e', 's', '\n',
        's', 'e', 'n', 's', 'i', 't', 'i', 'v', 'i', 't', 'y', '\n',
        's', 'e', 'n', 's', 'o', 'r', '\n',
        's', 'e', 'n', 's', 'o', 'r', 's', '\n',
        's', 'e', 'n', 's', 'o', 'r', 'y', '\n',
        's', 'e', 'n', 's', 'u', 'a', 'l', '\n',
        's', 'e', 'n', 's', 'u', 'a', 'l', 'i', 't', 'y', '\n',
        's', 'e', 'n', 's', 'u', 'a', 'l', 'l', 'y', '\n',
        's', 'e', 'n', 's', 'u', 'o', 'u', 's', '\n',
        's', 'e', 'n', 's', 'u', 'o', 'u', 's', 'l', 'y', '\n',
        's', 'e', 'n', 's', 'u', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        's', 'e', 'n', 't', '\n',
        's', 'e', 'n', 't', 'e', 'n', 'c', 'e', '\n',
        's', 'e', 'n', 't', 'e', 'n', 'c', 'e', 'd', '\n',
        's', 'e', 'n', 't', 'e', 'n', 'c', 'e', 's', '\n',
        's', 'e', 'n', 't', 'e', 'n', 'c', 'i', 'n', 'g', '\n',
        's', 'e', 'n', 't', 'e', 'n', 't', 'i', 'a', 'l', '\n',
        's', 'e', 'n', 't', 'e', 'n', 't', 'i', 'o', 'u', 's', '\n',
        's', 'e', 'n', 't', 'e', 'n', 't', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        's', 'e', 'n', 't', 'i', 'e', 'n', 'c', 'e', '\n',
        's', 'e', 'n', 't', 'i', 'e', 'n', 't', '\n',
        's', 'e', 'n', 't', 'i', 'm', 'e', 'n', 't', '\n',
        's', 'e', 'n', 't', 'i', 'm', 'e', 'n', 't', 'a', 'l', '\n',
        's', 'e', 'n', 't', 'i', 'm', 'e', 'n', 't', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        's', 'e', 'n', 't', 'i', 'm', 'e', 'n', 't', 'a', 'l', 'i', 's', 'm', '\n',
        's', 'e', 'n', 't', 'i', 'm', 'e', 'n', 't', 'a', 'l', 'i', 's', 't', '\n',
        's', 'e', 'n', 't', 'i', 'm', 'e', 'n', 't', 'a', 'l', 'i', 't', 'y', '\n',
        's', 'e', 'n', 't', 'i', 'm', 'e', 'n', 't', 'a', 'l', 'l', 'y', '\n',
        's', 'e', 'n', 't', 'i', 'm', 'e', 'n', 't', 's', '\n',
        's', 'e', 'n', 't', 'i', 'n', 'e', 'l', '\n',
        's', 'e', 'n', 't', 'i', 'n', 'e', 'l', 's', '\n',
        's', 'e', 'n', 't', 'r', 'i', 'e', 's', '\n',
        's', 'e', 'n', 't', 'r', 'y', '\n',
        's', 'e', 'o', 'u', 'l', '\n',
        's', 'e', 'p', 'a', 'r', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        's', 'e', 'p', 'a', 'r', 'a', 'b', 'l', 'e', '\n',
        's', 'e', 'p', 'a', 'r', 'a', 't', 'e', '\n',
        's', 'e', 'p', 'a', 'r', 'a', 't', 'e', 'd', '\n',
        's', 'e', 'p', 'a', 'r', 'a', 't', 'e', 'l', 'y', '\n',
        's', 'e', 'p', 'a', 'r', 'a', 't', 'e', 'n', 'e', 's', 's', '\n',
        's', 'e', 'p', 'a', 'r', 'a', 't', 'e', 's', '\n',
        's', 'e', 'p', 'a', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        's', 'e', 'p', 'a', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'e', 'p', 'a', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        's', 'e', 'p', 'a', 'r', 'a', 't', 'i', 's', 'm', '\n',
        's', 'e', 'p', 'a', 'r', 'a', 't', 'i', 's', 't', '\n',
        's', 'e', 'p', 'a', 'r', 'a', 't', 'i', 's', 't', 's', '\n',
        's', 'e', 'p', 'a', 'r', 'a', 't', 'o', 'r', '\n',
        's', 'e', 'p', 'a', 'r', 'a', 't', 'o', 'r', 's', '\n',
        's', 'e', 'p', 'i', 'a', '\n',
        's', 'e', 'p', 't', 'e', 'm', 'b', 'e', 'r', '\n',
        's', 'e', 'p', 't', 'e', 't', '\n',
        's', 'e', 'p', 't', 'e', 't', 's', '\n',
        's', 'e', 'p', 't', 'i', 'c', '\n',
        's', 'e', 'p', 't', 'i', 'c', 'a', 'e', 'm', 'i', 'a', '\n',
        's', 'e', 'p', 'u', 'l', 'c', 'h', 'r', 'a', 'l', '\n',
        's', 'e', 'p', 'u', 'l', 'c', 'h', 'r', 'e', '\n',
        's', 'e', 'p', 'u', 'l', 'c', 'h', 'r', 'e', 's', '\n',
        's', 'e', 'q', 'u', 'e', 'l', '\n',
        's', 'e', 'q', 'u', 'e', 'l', 's', '\n',
        's', 'e', 'q', 'u', 'e', 'n', 'c', 'e', '\n',
        's', 'e', 'q', 'u', 'e', 'n', 'c', 'e', 'd', '\n',
        's', 'e', 'q', 'u', 'e', 'n', 'c', 'e', 'r', '\n',
        's', 'e', 'q', 'u', 'e', 'n', 'c', 'e', 'r', 's', '\n',
        's', 'e', 'q', 'u', 'e', 'n', 'c', 'e', 's', '\n',
        's', 'e', 'q', 'u', 'e', 'n', 'c', 'i', 'n', 'g', '\n',
        's', 'e', 'q', 'u', 'e', 'n', 't', '\n',
        's', 'e', 'q', 'u', 'e', 'n', 't', 'i', 'a', 'l', '\n',
        's', 'e', 'q', 'u', 'e', 'n', 't', 'i', 'a', 'l', 'l', 'y', '\n',
        's', 'e', 'q', 'u', 'e', 's', 't', 'e', 'r', 'e', 'd', '\n',
        's', 'e', 'q', 'u', 'e', 's', 't', 'r', 'a', 't', 'e', 'd', '\n',
        's', 'e', 'q', 'u', 'e', 's', 't', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'e', 'q', 'u', 'i', 'n', '\n',
        's', 'e', 'q', 'u', 'i', 'n', 'n', 'e', 'd', '\n',
        's', 'e', 'q', 'u', 'i', 'n', 's', '\n',
        's', 'e', 'q', 'u', 'o', 'i', 'a', '\n',
        's', 'e', 'r', 'a', 'g', 'l', 'i', 'o', '\n',
        's', 'e', 'r', 'a', 'i', '\n',
        's', 'e', 'r', 'a', 'p', 'h', 'i', 'c', '\n',
        's', 'e', 'r', 'a', 'p', 'h', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 'e', 'r', 'a', 'p', 'h', 'i', 'm', '\n',
        's', 'e', 'r', 'a', 'p', 'h', 's', '\n',
        's', 'e', 'r', 'e', 'n', 'a', 'd', 'e', '\n',
        's', 'e', 'r', 'e', 'n', 'a', 'd', 'e', 'r', '\n',
        's', 'e', 'r', 'e', 'n', 'a', 'd', 'e', 's', '\n',
        's', 'e', 'r', 'e', 'n', 'a', 'd', 'i', 'n', 'g', '\n',
        's', 'e', 'r', 'e', 'n', 'a', 't', 'a', '\n',
        's', 'e', 'r', 'e', 'n', 'd', 'i', 'p', 'i', 't', 'o', 'u', 's', '\n',
        's', 'e', 'r', 'e', 'n', 'd', 'i', 'p', 'i', 't', 'o', 'u', 's', 'l', 'y', '\n',
        's', 'e', 'r', 'e', 'n', 'd', 'i', 'p', 'i', 't', 'y', '\n',
        's', 'e', 'r', 'e', 'n', 'e', '\n',
        's', 'e', 'r', 'e', 'n', 'e', 'l', 'y', '\n',
        's', 'e', 'r', 'e', 'n', 'e', 'r', '\n',
        's', 'e', 'r', 'e', 'n', 'e', 's', 't', '\n',
        's', 'e', 'r', 'e', 'n', 'i', 't', 'y', '\n',
        's', 'e', 'r', 'f', '\n',
        's', 'e', 'r', 'f', 'd', 'o', 'm', '\n',
        's', 'e', 'r', 'f', 'h', 'o', 'o', 'd', '\n',
        's', 'e', 'r', 'f', 's', '\n',
        's', 'e', 'r', 'g', 'e', '\n',
        's', 'e', 'r', 'g', 'e', 'a', 'n', 't', '\n',
        's', 'e', 'r', 'g', 'e', 'a', 'n', 't', 's', '\n',
        's', 'e', 'r', 'i', 'a', 'l', '\n',
        's', 'e', 'r', 'i', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'e', 'r', 'i', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        's', 'e', 'r', 'i', 'a', 'l', 'i', 's', 'e', '\n',
        's', 'e', 'r', 'i', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        's', 'e', 'r', 'i', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        's', 'e', 'r', 'i', 'a', 'l', 'l', 'y', '\n',
        's', 'e', 'r', 'i', 'a', 'l', 's', '\n',
        's', 'e', 'r', 'i', 'e', 's', '\n',
        's', 'e', 'r', 'i', 'f', '\n',
        's', 'e', 'r', 'i', 'f', 'e', 'd', '\n',
        's', 'e', 'r', 'i', 'f', 's', '\n',
        's', 'e', 'r', 'i', 'o', 'u', 's', '\n',
        's', 'e', 'r', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        's', 'e', 'r', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        's', 'e', 'r', 'm', 'o', 'n', '\n',
        's', 'e', 'r', 'm', 'o', 'n', 's', '\n',
        's', 'e', 'r', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        's', 'e', 'r', 'o', 'l', 'o', 'g', 'y', '\n',
        's', 'e', 'r', 'o', 'n', 'e', 'g', 'a', 't', 'i', 'v', 'e', '\n',
        's', 'e', 'r', 'o', 't', 'o', 'n', 'i', 'n', '\n',
        's', 'e', 'r', 'p', 'e', 'n', 't', '\n',
        's', 'e', 'r', 'p', 'e', 'n', 't', 'i', 'n', 'e', '\n',
        's', 'e', 'r', 'p', 'e', 'n', 't', 's', '\n',
        's', 'e', 'r', 'r', 'a', 't', 'e', '\n',
        's', 'e', 'r', 'r', 'a', 't', 'e', 'd', '\n',
        's', 'e', 'r', 'r', 'i', 'e', 'd', '\n',
        's', 'e', 'r', 'u', 'm', '\n',
        's', 'e', 'r', 'u', 'm', 's', '\n',
        's', 'e', 'r', 'v', 'a', 'n', 't', '\n',
        's', 'e', 'r', 'v', 'a', 'n', 't', 's', '\n',
        's', 'e', 'r', 'v', 'e', '\n',
        's', 'e', 'r', 'v', 'e', 'd', '\n',
        's', 'e', 'r', 'v', 'e', 'r', '\n',
        's', 'e', 'r', 'v', 'e', 'r', 's', '\n',
        's', 'e', 'r', 'v', 'e', 's', '\n',
        's', 'e', 'r', 'v', 'i', 'c', 'e', '\n',
        's', 'e', 'r', 'v', 'i', 'c', 'e', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        's', 'e', 'r', 'v', 'i', 'c', 'e', 'a', 'b', 'l', 'e', '\n',
        's', 'e', 'r', 'v', 'i', 'c', 'e', 'd', '\n',
        's', 'e', 'r', 'v', 'i', 'c', 'e', 'm', 'a', 'n', '\n',
        's', 'e', 'r', 'v', 'i', 'c', 'e', 'm', 'e', 'n', '\n',
        's', 'e', 'r', 'v', 'i', 'c', 'e', 's', '\n',
        's', 'e', 'r', 'v', 'i', 'c', 'i', 'n', 'g', '\n',
        's', 'e', 'r', 'v', 'i', 'e', 't', 't', 'e', '\n',
        's', 'e', 'r', 'v', 'i', 'l', 'e', '\n',
        's', 'e', 'r', 'v', 'i', 'l', 'e', 'l', 'y', '\n',
        's', 'e', 'r', 'v', 'i', 'l', 'i', 't', 'y', '\n',
        's', 'e', 'r', 'v', 'i', 'n', 'g', '\n',
        's', 'e', 'r', 'v', 'i', 'n', 'g', 's', '\n',
        's', 'e', 'r', 'v', 'i', 't', 'u', 'd', 'e', '\n',
        's', 'e', 's', 'a', 'm', 'e', '\n',
        's', 'e', 's', 'o', 't', 'h', 'o', '\n',
        's', 'e', 's', 's', 'i', 'l', 'e', '\n',
        's', 'e', 's', 's', 'i', 'o', 'n', '\n',
        's', 'e', 's', 's', 'i', 'o', 'n', 's', '\n',
        's', 'e', 't', '\n',
        's', 'e', 't', 'b', 'a', 'c', 'k', '\n',
        's', 'e', 't', 'b', 'a', 'c', 'k', 's', '\n',
        's', 'e', 't', 'h', '\n',
        's', 'e', 't', 's', '\n',
        's', 'e', 't', 's', 'w', 'a', 'n', 'a', '\n',
        's', 'e', 't', 't', 'e', 'e', '\n',
        's', 'e', 't', 't', 'e', 'e', 's', '\n',
        's', 'e', 't', 't', 'e', 'r', '\n',
        's', 'e', 't', 't', 'e', 'r', 's', '\n',
        's', 'e', 't', 't', 'i', 'n', 'g', '\n',
        's', 'e', 't', 't', 'i', 'n', 'g', 's', '\n',
        's', 'e', 't', 't', 'l', 'e', '\n',
        's', 'e', 't', 't', 'l', 'e', 'd', '\n',
        's', 'e', 't', 't', 'l', 'e', 'm', 'e', 'n', 't', '\n',
        's', 'e', 't', 't', 'l', 'e', 'm', 'e', 'n', 't', 's', '\n',
        's', 'e', 't', 't', 'l', 'e', 'r', '\n',
        's', 'e', 't', 't', 'l', 'e', 'r', 's', '\n',
        's', 'e', 't', 't', 'l', 'e', 's', '\n',
        's', 'e', 't', 't', 'l', 'i', 'n', 'g', '\n',
        's', 'e', 't', 't', 's', '\n',
        's', 'e', 't', 'u', 'p', '\n',
        's', 'e', 'v', 'e', 'n', '\n',
        's', 'e', 'v', 'e', 'n', 'f', 'o', 'l', 'd', '\n',
        's', 'e', 'v', 'e', 'n', 'p', 'e', 'n', 'c', 'e', '\n',
        's', 'e', 'v', 'e', 'n', 's', '\n',
        's', 'e', 'v', 'e', 'n', 't', 'e', 'e', 'n', '\n',
        's', 'e', 'v', 'e', 'n', 't', 'e', 'e', 'n', 't', 'h', '\n',
        's', 'e', 'v', 'e', 'n', 't', 'h', '\n',
        's', 'e', 'v', 'e', 'n', 't', 'i', 'e', 's', '\n',
        's', 'e', 'v', 'e', 'n', 't', 'i', 'e', 't', 'h', '\n',
        's', 'e', 'v', 'e', 'n', 't', 'y', '\n',
        's', 'e', 'v', 'e', 'r', '\n',
        's', 'e', 'v', 'e', 'r', 'a', 'b', 'l', 'e', '\n',
        's', 'e', 'v', 'e', 'r', 'a', 'l', '\n',
        's', 'e', 'v', 'e', 'r', 'a', 'l', 'l', 'y', '\n',
        's', 'e', 'v', 'e', 'r', 'a', 'n', 'c', 'e', '\n',
        's', 'e', 'v', 'e', 'r', 'e', '\n',
        's', 'e', 'v', 'e', 'r', 'e', 'd', '\n',
        's', 'e', 'v', 'e', 'r', 'e', 'l', 'y', '\n',
        's', 'e', 'v', 'e', 'r', 'e', 'r', '\n',
        's', 'e', 'v', 'e', 'r', 'e', 's', 't', '\n',
        's', 'e', 'v', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'e', 'v', 'e', 'r', 'i', 't', 'y', '\n',
        's', 'e', 'v', 'e', 'r', 's', '\n',
        's', 'e', 'w', '\n',
        's', 'e', 'w', 'a', 'g', 'e', '\n',
        's', 'e', 'w', 'e', 'd', '\n',
        's', 'e', 'w', 'e', 'r', '\n',
        's', 'e', 'w', 'e', 'r', 'a', 'g', 'e', '\n',
        's', 'e', 'w', 'e', 'r', 'r', 'a', 't', '\n',
        's', 'e', 'w', 'e', 'r', 's', '\n',
        's', 'e', 'w', 'i', 'n', 'g', '\n',
        's', 'e', 'w', 'i', 'n', 'g', 's', '\n',
        's', 'e', 'w', 'n', '\n',
        's', 'e', 'w', 's', '\n',
        's', 'e', 'x', '\n',
        's', 'e', 'x', 'e', 'd', '\n',
        's', 'e', 'x', 'e', 's', '\n',
        's', 'e', 'x', 'i', 'e', 'r', '\n',
        's', 'e', 'x', 'i', 'e', 's', 't', '\n',
        's', 'e', 'x', 'i', 'l', 'y', '\n',
        's', 'e', 'x', 'i', 'n', 'e', 's', 's', '\n',
        's', 'e', 'x', 'i', 'n', 'g', '\n',
        's', 'e', 'x', 'i', 's', 'm', '\n',
        's', 'e', 'x', 'i', 's', 't', '\n',
        's', 'e', 'x', 'i', 's', 't', 's', '\n',
        's', 'e', 'x', 'l', 'e', 's', 's', '\n',
        's', 'e', 'x', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        's', 'e', 'x', 'o', 'l', 'o', 'g', 'y', '\n',
        's', 'e', 'x', 't', 'a', 'n', 't', '\n',
        's', 'e', 'x', 't', 'a', 'n', 't', 's', '\n',
        's', 'e', 'x', 't', 'e', 't', '\n',
        's', 'e', 'x', 't', 'e', 't', 's', '\n',
        's', 'e', 'x', 't', 'o', 'n', '\n',
        's', 'e', 'x', 't', 'o', 'n', 's', '\n',
        's', 'e', 'x', 't', 'u', 'p', 'l', 'e', 't', '\n',
        's', 'e', 'x', 't', 'u', 'p', 'l', 'e', 't', 's', '\n',
        's', 'e', 'x', 'u', 'a', 'l', '\n',
        's', 'e', 'x', 'u', 'a', 'l', 'i', 't', 'i', 'e', 's', '\n',
        's', 'e', 'x', 'u', 'a', 'l', 'i', 't', 'y', '\n',
        's', 'e', 'x', 'u', 'a', 'l', 'l', 'y', '\n',
        's', 'e', 'x', 'y', '\n',
        's', 'h', 'a', 'b', 'b', 'i', 'e', 'r', '\n',
        's', 'h', 'a', 'b', 'b', 'i', 'e', 's', 't', '\n',
        's', 'h', 'a', 'b', 'b', 'i', 'l', 'y', '\n',
        's', 'h', 'a', 'b', 'b', 'i', 'n', 'e', 's', 's', '\n',
        's', 'h', 'a', 'b', 'b', 'y', '\n',
        's', 'h', 'a', 'c', 'k', '\n',
        's', 'h', 'a', 'c', 'k', 'l', 'e', '\n',
        's', 'h', 'a', 'c', 'k', 'l', 'e', 'd', '\n',
        's', 'h', 'a', 'c', 'k', 'l', 'e', 's', '\n',
        's', 'h', 'a', 'c', 'k', 's', '\n',
        's', 'h', 'a', 'd', 'e', '\n',
        's', 'h', 'a', 'd', 'e', 'd', '\n',
        's', 'h', 'a', 'd', 'e', 'l', 'e', 's', 's', '\n',
        's', 'h', 'a', 'd', 'e', 's', '\n',
        's', 'h', 'a', 'd', 'i', 'e', 'r', '\n',
        's', 'h', 'a', 'd', 'i', 'e', 's', 't', '\n',
        's', 'h', 'a', 'd', 'i', 'l', 'y', '\n',
        's', 'h', 'a', 'd', 'i', 'n', 'g', '\n',
        's', 'h', 'a', 'd', 'i', 'n', 'g', 's', '\n',
        's', 'h', 'a', 'd', 'o', 'w', '\n',
        's', 'h', 'a', 'd', 'o', 'w', 'e', 'd', '\n',
        's', 'h', 'a', 'd', 'o', 'w', 'i', 'n', 'g', '\n',
        's', 'h', 'a', 'd', 'o', 'w', 'l', 'e', 's', 's', '\n',
        's', 'h', 'a', 'd', 'o', 'w', 's', '\n',
        's', 'h', 'a', 'd', 'o', 'w', 'y', '\n',
        's', 'h', 'a', 'd', 'y', '\n',
        's', 'h', 'a', 'f', 't', '\n',
        's', 'h', 'a', 'f', 't', 'e', 'd', '\n',
        's', 'h', 'a', 'f', 't', 'i', 'n', 'g', '\n',
        's', 'h', 'a', 'f', 't', 's', '\n',
        's', 'h', 'a', 'g', '\n',
        's', 'h', 'a', 'g', 'g', 'e', 'd', '\n',
        's', 'h', 'a', 'g', 'g', 'i', 'e', 's', 't', '\n',
        's', 'h', 'a', 'g', 'g', 'y', '\n',
        's', 'h', 'a', 'g', 's', '\n',
        's', 'h', 'a', 'h', '\n',
        's', 'h', 'a', 'h', 's', '\n',
        's', 'h', 'a', 'k', 'a', 'b', 'l', 'e', '\n',
        's', 'h', 'a', 'k', 'e', '\n',
        's', 'h', 'a', 'k', 'e', 'a', 'b', 'l', 'e', '\n',
        's', 'h', 'a', 'k', 'e', 'd', 'o', 'w', 'n', '\n',
        's', 'h', 'a', 'k', 'e', 'n', '\n',
        's', 'h', 'a', 'k', 'e', 'r', '\n',
        's', 'h', 'a', 'k', 'e', 'r', 's', '\n',
        's', 'h', 'a', 'k', 'e', 's', '\n',
        's', 'h', 'a', 'k', 'e', 'u', 'p', '\n',
        's', 'h', 'a', 'k', 'e', 'u', 'p', 's', '\n',
        's', 'h', 'a', 'k', 'i', 'e', 'r', '\n',
        's', 'h', 'a', 'k', 'i', 'e', 's', 't', '\n',
        's', 'h', 'a', 'k', 'i', 'l', 'y', '\n',
        's', 'h', 'a', 'k', 'i', 'n', 'g', '\n',
        's', 'h', 'a', 'k', 'y', '\n',
        's', 'h', 'a', 'l', 'e', '\n',
        's', 'h', 'a', 'l', 'l', '\n',
        's', 'h', 'a', 'l', 'l', 'o', 't', '\n',
        's', 'h', 'a', 'l', 'l', 'o', 't', 's', '\n',
        's', 'h', 'a', 'l', 'l', 'o', 'w', '\n',
        's', 'h', 'a', 'l', 'l', 'o', 'w', 'e', 'r', '\n',
        's', 'h', 'a', 'l', 'l', 'o', 'w', 'e', 's', 't', '\n',
        's', 'h', 'a', 'l', 'l', 'o', 'w', 'l', 'y', '\n',
        's', 'h', 'a', 'l', 'l', 'o', 'w', 'n', 'e', 's', 's', '\n',
        's', 'h', 'a', 'l', 'l', 'o', 'w', 's', '\n',
        's', 'h', 'a', 'm', '\n',
        's', 'h', 'a', 'm', 'a', 'n', '\n',
        's', 'h', 'a', 'm', 'a', 'n', 'i', 'c', '\n',
        's', 'h', 'a', 'm', 'a', 'n', 'i', 's', 'm', '\n',
        's', 'h', 'a', 'm', 'a', 'n', 'i', 's', 't', 'i', 'c', '\n',
        's', 'h', 'a', 'm', 'a', 'n', 's', '\n',
        's', 'h', 'a', 'm', 'b', 'l', 'e', '\n',
        's', 'h', 'a', 'm', 'b', 'l', 'e', 'd', '\n',
        's', 'h', 'a', 'm', 'b', 'l', 'e', 's', '\n',
        's', 'h', 'a', 'm', 'b', 'l', 'i', 'n', 'g', '\n',
        's', 'h', 'a', 'm', 'e', '\n',
        's', 'h', 'a', 'm', 'e', 'd', '\n',
        's', 'h', 'a', 'm', 'e', 'f', 'a', 'c', 'e', 'd', '\n',
        's', 'h', 'a', 'm', 'e', 'f', 'a', 'c', 'e', 'd', 'l', 'y', '\n',
        's', 'h', 'a', 'm', 'e', 'f', 'u', 'l', '\n',
        's', 'h', 'a', 'm', 'e', 'f', 'u', 'l', 'l', 'y', '\n',
        's', 'h', 'a', 'm', 'e', 'l', 'e', 's', 's', '\n',
        's', 'h', 'a', 'm', 'e', 'l', 'e', 's', 's', 'l', 'y', '\n',
        's', 'h', 'a', 'm', 'e', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        's', 'h', 'a', 'm', 'e', 's', '\n',
        's', 'h', 'a', 'm', 'i', 'n', 'g', '\n',
        's', 'h', 'a', 'm', 'm', 'e', 'd', '\n',
        's', 'h', 'a', 'm', 'm', 'i', 'n', 'g', '\n',
        's', 'h', 'a', 'm', 'p', 'o', 'o', '\n',
        's', 'h', 'a', 'm', 'p', 'o', 'o', 'e', 'd', '\n',
        's', 'h', 'a', 'm', 'p', 'o', 'o', 'i', 'n', 'g', '\n',
        's', 'h', 'a', 'm', 'p', 'o', 'o', 's', '\n',
        's', 'h', 'a', 'm', 'r', 'o', 'c', 'k', '\n',
        's', 'h', 'a', 'm', 's', '\n',
        's', 'h', 'a', 'n', 'd', 'y', '\n',
        's', 'h', 'a', 'n', 'k', '\n',
        's', 'h', 'a', 'n', 'k', 's', '\n',
        's', 'h', 'a', 'n', 't', 'i', 'e', 's', '\n',
        's', 'h', 'a', 'n', 't', 'y', '\n',
        's', 'h', 'a', 'p', 'e', '\n',
        's', 'h', 'a', 'p', 'e', 'd', '\n',
        's', 'h', 'a', 'p', 'e', 'l', 'e', 's', 's', '\n',
        's', 'h', 'a', 'p', 'e', 'l', 'i', 'e', 'r', '\n',
        's', 'h', 'a', 'p', 'e', 'l', 'i', 'e', 's', 't', '\n',
        's', 'h', 'a', 'p', 'e', 'l', 'y', '\n',
        's', 'h', 'a', 'p', 'e', 'r', '\n',
        's', 'h', 'a', 'p', 'e', 'r', 's', '\n',
        's', 'h', 'a', 'p', 'e', 's', '\n',
        's', 'h', 'a', 'p', 'i', 'n', 'g', '\n',
        's', 'h', 'a', 'r', 'a', 'b', 'l', 'e', '\n',
        's', 'h', 'a', 'r', 'd', '\n',
        's', 'h', 'a', 'r', 'd', 's', '\n',
        's', 'h', 'a', 'r', 'e', '\n',
        's', 'h', 'a', 'r', 'e', 'a', 'b', 'l', 'e', '\n',
        's', 'h', 'a', 'r', 'e', 'd', '\n',
        's', 'h', 'a', 'r', 'e', 'h', 'o', 'l', 'd', 'e', 'r', '\n',
        's', 'h', 'a', 'r', 'e', 'h', 'o', 'l', 'd', 'e', 'r', 's', '\n',
        's', 'h', 'a', 'r', 'e', 'h', 'o', 'l', 'd', 'i', 'n', 'g', '\n',
        's', 'h', 'a', 'r', 'e', 'h', 'o', 'l', 'd', 'i', 'n', 'g', 's', '\n',
        's', 'h', 'a', 'r', 'e', 'r', '\n',
        's', 'h', 'a', 'r', 'e', 's', '\n',
        's', 'h', 'a', 'r', 'e', 'w', 'a', 'r', 'e', '\n',
        's', 'h', 'a', 'r', 'i', 'n', 'g', '\n',
        's', 'h', 'a', 'r', 'k', '\n',
        's', 'h', 'a', 'r', 'k', 's', '\n',
        's', 'h', 'a', 'r', 'p', '\n',
        's', 'h', 'a', 'r', 'p', 'e', 'n', '\n',
        's', 'h', 'a', 'r', 'p', 'e', 'n', 'e', 'd', '\n',
        's', 'h', 'a', 'r', 'p', 'e', 'n', 'e', 'r', '\n',
        's', 'h', 'a', 'r', 'p', 'e', 'n', 'e', 'r', 's', '\n',
        's', 'h', 'a', 'r', 'p', 'e', 'n', 'i', 'n', 'g', '\n',
        's', 'h', 'a', 'r', 'p', 'e', 'n', 's', '\n',
        's', 'h', 'a', 'r', 'p', 'e', 'r', '\n',
        's', 'h', 'a', 'r', 'p', 'e', 's', 't', '\n',
        's', 'h', 'a', 'r', 'p', 'l', 'y', '\n',
        's', 'h', 'a', 'r', 'p', 'n', 'e', 's', 's', '\n',
        's', 'h', 'a', 'r', 'p', 's', '\n',
        's', 'h', 'a', 't', 't', 'e', 'r', '\n',
        's', 'h', 'a', 't', 't', 'e', 'r', 'e', 'd', '\n',
        's', 'h', 'a', 't', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'h', 'a', 't', 't', 'e', 'r', 'i', 'n', 'g', 'l', 'y', '\n',
        's', 'h', 'a', 't', 't', 'e', 'r', 'p', 'r', 'o', 'o', 'f', '\n',
        's', 'h', 'a', 't', 't', 'e', 'r', 's', '\n',
        's', 'h', 'a', 'v', 'e', '\n',
        's', 'h', 'a', 'v', 'e', 'd', '\n',
        's', 'h', 'a', 'v', 'e', 'n', '\n',
        's', 'h', 'a', 'v', 'e', 'r', '\n',
        's', 'h', 'a', 'v', 'e', 'r', 's', '\n',
        's', 'h', 'a', 'v', 'e', 's', '\n',
        's', 'h', 'a', 'v', 'i', 'n', 'g', '\n',
        's', 'h', 'a', 'v', 'i', 'n', 'g', 's', '\n',
        's', 'h', 'a', 'w', '\n',
        's', 'h', 'a', 'w', 'l', '\n',
        's', 'h', 'a', 'w', 'l', 's', '\n',
        's', 'h', 'e', '\n',
        's', 'h', 'e', 'a', 'f', '\n',
        's', 'h', 'e', 'a', 'r', '\n',
        's', 'h', 'e', 'a', 'r', 'e', 'd', '\n',
        's', 'h', 'e', 'a', 'r', 'e', 'r', '\n',
        's', 'h', 'e', 'a', 'r', 'e', 'r', 's', '\n',
        's', 'h', 'e', 'a', 'r', 'i', 'n', 'g', '\n',
        's', 'h', 'e', 'a', 'r', 's', '\n',
        's', 'h', 'e', 'a', 'r', 'w', 'a', 't', 'e', 'r', '\n',
        's', 'h', 'e', 'a', 'r', 'w', 'a', 't', 'e', 'r', 's', '\n',
        's', 'h', 'e', 'a', 't', 'h', '\n',
        's', 'h', 'e', 'a', 't', 'h', 'e', '\n',
        's', 'h', 'e', 'a', 't', 'h', 'e', 'd', '\n',
        's', 'h', 'e', 'a', 't', 'h', 'i', 'n', 'g', '\n',
        's', 'h', 'e', 'a', 't', 'h', 's', '\n',
        's', 'h', 'e', 'a', 'v', 'e', 's', '\n',
        's', 'h', 'e', 'd', '\n',
        's', 'h', 'e', 'd', 'd', 'i', 'n', 'g', '\n',
        's', 'h', 'e', 'd', 's', '\n',
        's', 'h', 'e', 'e', 'n', '\n',
        's', 'h', 'e', 'e', 'p', '\n',
        's', 'h', 'e', 'e', 'p', 'd', 'o', 'g', '\n',
        's', 'h', 'e', 'e', 'p', 'd', 'o', 'g', 's', '\n',
        's', 'h', 'e', 'e', 'p', 'i', 's', 'h', '\n',
        's', 'h', 'e', 'e', 'p', 'i', 's', 'h', 'l', 'y', '\n',
        's', 'h', 'e', 'e', 'p', 'i', 's', 'h', 'n', 'e', 's', 's', '\n',
        's', 'h', 'e', 'e', 'p', 's', 'k', 'i', 'n', '\n',
        's', 'h', 'e', 'e', 'p', 's', 'k', 'i', 'n', 's', '\n',
        's', 'h', 'e', 'e', 'r', '\n',
        's', 'h', 'e', 'e', 'r', 'e', 'd', '\n',
        's', 'h', 'e', 'e', 'r', 'e', 's', 't', '\n',
        's', 'h', 'e', 'e', 'r', 'n', 'e', 's', 's', '\n',
        's', 'h', 'e', 'e', 't', '\n',
        's', 'h', 'e', 'e', 't', 'e', 'd', '\n',
        's', 'h', 'e', 'e', 't', 'i', 'n', 'g', '\n',
        's', 'h', 'e', 'e', 't', 's', '\n',
        's', 'h', 'e', 'i', 'k', '\n',
        's', 'h', 'e', 'i', 'k', 'h', '\n',
        's', 'h', 'e', 'i', 'k', 'h', 's', '\n',
        's', 'h', 'e', 'i', 'k', 's', '\n',
        's', 'h', 'e', 'k', 'e', 'l', '\n',
        's', 'h', 'e', 'k', 'e', 'l', 's', '\n',
        's', 'h', 'e', 'l', 'f', '\n',
        's', 'h', 'e', 'l', 'l', '\n',
        's', 'h', 'e', 'l', 'l', 'a', 'c', '\n',
        's', 'h', 'e', 'l', 'l', 'e', 'd', '\n',
        's', 'h', 'e', 'l', 'l', 'f', 'i', 'r', 'e', '\n',
        's', 'h', 'e', 'l', 'l', 'f', 'i', 's', 'h', '\n',
        's', 'h', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        's', 'h', 'e', 'l', 'l', 's', '\n',
        's', 'h', 'e', 'l', 't', 'e', 'r', '\n',
        's', 'h', 'e', 'l', 't', 'e', 'r', 'e', 'd', '\n',
        's', 'h', 'e', 'l', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'h', 'e', 'l', 't', 'e', 'r', 's', '\n',
        's', 'h', 'e', 'l', 'v', 'e', '\n',
        's', 'h', 'e', 'l', 'v', 'e', 'd', '\n',
        's', 'h', 'e', 'l', 'v', 'e', 's', '\n',
        's', 'h', 'e', 'l', 'v', 'i', 'n', 'g', '\n',
        's', 'h', 'e', 'p', 'h', 'e', 'r', 'd', '\n',
        's', 'h', 'e', 'p', 'h', 'e', 'r', 'd', 'e', 'd', '\n',
        's', 'h', 'e', 'p', 'h', 'e', 'r', 'd', 'e', 's', 's', '\n',
        's', 'h', 'e', 'p', 'h', 'e', 'r', 'd', 'i', 'n', 'g', '\n',
        's', 'h', 'e', 'p', 'h', 'e', 'r', 'd', 's', '\n',
        's', 'h', 'e', 'r', 'b', 'e', 't', '\n',
        's', 'h', 'e', 'r', 'd', 's', '\n',
        's', 'h', 'e', 'r', 'i', 'f', 'f', '\n',
        's', 'h', 'e', 'r', 'i', 'f', 'f', 's', '\n',
        's', 'h', 'e', 'r', 'l', 'o', 'c', 'k', '\n',
        's', 'h', 'e', 'r', 'r', 'i', 'e', 's', '\n',
        's', 'h', 'e', 'r', 'r', 'y', '\n',
        's', 'h', 'e', 't', 'l', 'a', 'n', 'd', '\n',
        's', 'h', 'i', 'b', 'b', 'o', 'l', 'e', 't', 'h', '\n',
        's', 'h', 'i', 'b', 'b', 'o', 'l', 'e', 't', 'h', 's', '\n',
        's', 'h', 'i', 'e', 'd', '\n',
        's', 'h', 'i', 'e', 'l', 'd', '\n',
        's', 'h', 'i', 'e', 'l', 'd', 'e', 'd', '\n',
        's', 'h', 'i', 'e', 'l', 'd', 'i', 'n', 'g', '\n',
        's', 'h', 'i', 'e', 'l', 'd', 's', '\n',
        's', 'h', 'i', 'e', 'l', 'i', 'n', 'g', 's', '\n',
        's', 'h', 'i', 'e', 's', '\n',
        's', 'h', 'i', 'f', 't', '\n',
        's', 'h', 'i', 'f', 't', 'e', 'd', '\n',
        's', 'h', 'i', 'f', 't', 'e', 'r', '\n',
        's', 'h', 'i', 'f', 't', 'e', 'r', 's', '\n',
        's', 'h', 'i', 'f', 't', 'i', 'e', 'r', '\n',
        's', 'h', 'i', 'f', 't', 'i', 'l', 'y', '\n',
        's', 'h', 'i', 'f', 't', 'i', 'n', 'e', 's', 's', '\n',
        's', 'h', 'i', 'f', 't', 'i', 'n', 'g', '\n',
        's', 'h', 'i', 'f', 't', 'l', 'e', 's', 's', '\n',
        's', 'h', 'i', 'f', 't', 's', '\n',
        's', 'h', 'i', 'f', 't', 'y', '\n',
        's', 'h', 'i', 'l', 'l', 'i', 'n', 'g', '\n',
        's', 'h', 'i', 'm', 'm', 'e', 'r', '\n',
        's', 'h', 'i', 'm', 'm', 'e', 'r', 'e', 'd', '\n',
        's', 'h', 'i', 'm', 'm', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'h', 'i', 'm', 'm', 'e', 'r', 's', '\n',
        's', 'h', 'i', 'n', '\n',
        's', 'h', 'i', 'n', 'b', 'o', 'n', 'e', '\n',
        's', 'h', 'i', 'n', 'd', 'i', 'g', '\n',
        's', 'h', 'i', 'n', 'e', '\n',
        's', 'h', 'i', 'n', 'e', 'd', '\n',
        's', 'h', 'i', 'n', 'e', 'r', '\n',
        's', 'h', 'i', 'n', 'e', 's', '\n',
        's', 'h', 'i', 'n', 'g', 'l', 'e', '\n',
        's', 'h', 'i', 'n', 'g', 'l', 'e', 's', '\n',
        's', 'h', 'i', 'n', 'i', 'e', 'r', '\n',
        's', 'h', 'i', 'n', 'i', 'e', 's', 't', '\n',
        's', 'h', 'i', 'n', 'i', 'n', 'g', '\n',
        's', 'h', 'i', 'n', 'n', 'e', 'd', '\n',
        's', 'h', 'i', 'n', 'n', 'i', 'n', 'g', '\n',
        's', 'h', 'i', 'n', 's', '\n',
        's', 'h', 'i', 'n', 'y', '\n',
        's', 'h', 'i', 'p', '\n',
        's', 'h', 'i', 'p', 'b', 'o', 'a', 'r', 'd', '\n',
        's', 'h', 'i', 'p', 'b', 'o', 'r', 'n', 'e', '\n',
        's', 'h', 'i', 'p', 'b', 'u', 'i', 'l', 'd', 'e', 'r', '\n',
        's', 'h', 'i', 'p', 'b', 'u', 'i', 'l', 'd', 'e', 'r', 's', '\n',
        's', 'h', 'i', 'p', 'b', 'u', 'i', 'l', 'd', 'i', 'n', 'g', '\n',
        's', 'h', 'i', 'p', 'l', 'o', 'a', 'd', '\n',
        's', 'h', 'i', 'p', 'l', 'o', 'a', 'd', 's', '\n',
        's', 'h', 'i', 'p', 'm', 'a', 't', 'e', '\n',
        's', 'h', 'i', 'p', 'm', 'a', 't', 'e', 's', '\n',
        's', 'h', 'i', 'p', 'm', 'e', 'n', 't', '\n',
        's', 'h', 'i', 'p', 'm', 'e', 'n', 't', 's', '\n',
        's', 'h', 'i', 'p', 'o', 'w', 'n', 'e', 'r', '\n',
        's', 'h', 'i', 'p', 'o', 'w', 'n', 'e', 'r', 's', '\n',
        's', 'h', 'i', 'p', 'p', 'a', 'b', 'l', 'e', '\n',
        's', 'h', 'i', 'p', 'p', 'e', 'd', '\n',
        's', 'h', 'i', 'p', 'p', 'i', 'n', 'g', '\n',
        's', 'h', 'i', 'p', 's', '\n',
        's', 'h', 'i', 'p', 's', 'h', 'a', 'p', 'e', '\n',
        's', 'h', 'i', 'p', 'w', 'r', 'e', 'c', 'k', '\n',
        's', 'h', 'i', 'p', 'w', 'r', 'e', 'c', 'k', 'e', 'd', '\n',
        's', 'h', 'i', 'p', 'w', 'r', 'e', 'c', 'k', 's', '\n',
        's', 'h', 'i', 'p', 'w', 'r', 'i', 'g', 'h', 't', '\n',
        's', 'h', 'i', 'p', 'w', 'r', 'i', 'g', 'h', 't', 's', '\n',
        's', 'h', 'i', 'p', 'y', 'a', 'r', 'd', '\n',
        's', 'h', 'i', 'p', 'y', 'a', 'r', 'd', 's', '\n',
        's', 'h', 'i', 'r', 'e', '\n',
        's', 'h', 'i', 'r', 'e', 's', '\n',
        's', 'h', 'i', 'r', 'k', '\n',
        's', 'h', 'i', 'r', 'k', 'e', 'd', '\n',
        's', 'h', 'i', 'r', 'k', 'i', 'n', 'g', '\n',
        's', 'h', 'i', 'r', 't', '\n',
        's', 'h', 'i', 'r', 't', 'l', 'e', 's', 's', '\n',
        's', 'h', 'i', 'r', 't', 's', '\n',
        's', 'h', 'i', 'r', 't', 's', 'l', 'e', 'e', 'v', 'e', 's', '\n',
        's', 'h', 'i', 'v', 'e', 'r', '\n',
        's', 'h', 'i', 'v', 'e', 'r', 'e', 'd', '\n',
        's', 'h', 'i', 'v', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'h', 'i', 'v', 'e', 'r', 'i', 'n', 'g', 'l', 'y', '\n',
        's', 'h', 'i', 'v', 'e', 'r', 's', '\n',
        's', 'h', 'i', 'v', 'e', 'r', 'y', '\n',
        's', 'h', 'o', 'a', 'l', '\n',
        's', 'h', 'o', 'a', 'l', 's', '\n',
        's', 'h', 'o', 'c', 'k', '\n',
        's', 'h', 'o', 'c', 'k', 'e', 'd', '\n',
        's', 'h', 'o', 'c', 'k', 'e', 'r', '\n',
        's', 'h', 'o', 'c', 'k', 'e', 'r', 's', '\n',
        's', 'h', 'o', 'c', 'k', 'i', 'n', 'g', '\n',
        's', 'h', 'o', 'c', 'k', 'i', 'n', 'g', 'l', 'y', '\n',
        's', 'h', 'o', 'c', 'k', 's', '\n',
        's', 'h', 'o', 'd', '\n',
        's', 'h', 'o', 'd', 'd', 'i', 'e', 'r', '\n',
        's', 'h', 'o', 'd', 'd', 'i', 'e', 's', 't', '\n',
        's', 'h', 'o', 'd', 'd', 'i', 'l', 'y', '\n',
        's', 'h', 'o', 'd', 'd', 'i', 'n', 'e', 's', 's', '\n',
        's', 'h', 'o', 'd', 'd', 'y', '\n',
        's', 'h', 'o', 'e', '\n',
        's', 'h', 'o', 'e', 'b', 'o', 'x', '\n',
        's', 'h', 'o', 'e', 'd', '\n',
        's', 'h', 'o', 'e', 'h', 'o', 'r', 'n', '\n',
        's', 'h', 'o', 'e', 'i', 'n', 'g', '\n',
        's', 'h', 'o', 'e', 'l', 'a', 'c', 'e', '\n',
        's', 'h', 'o', 'e', 'l', 'a', 'c', 'e', 's', '\n',
        's', 'h', 'o', 'e', 'l', 'e', 's', 's', '\n',
        's', 'h', 'o', 'e', 'm', 'a', 'k', 'e', 'r', '\n',
        's', 'h', 'o', 'e', 'm', 'a', 'k', 'e', 'r', 's', '\n',
        's', 'h', 'o', 'e', 's', '\n',
        's', 'h', 'o', 'e', 's', 't', 'r', 'i', 'n', 'g', '\n',
        's', 'h', 'o', 'e', 's', 't', 'r', 'i', 'n', 'g', 's', '\n',
        's', 'h', 'o', 'g', 'u', 'n', '\n',
        's', 'h', 'o', 'g', 'u', 'n', 's', '\n',
        's', 'h', 'o', 'n', 'e', '\n',
        's', 'h', 'o', 'o', '\n',
        's', 'h', 'o', 'o', 'e', 'd', '\n',
        's', 'h', 'o', 'o', 'i', 'n', 'g', '\n',
        's', 'h', 'o', 'o', 'k', '\n',
        's', 'h', 'o', 'o', 't', '\n',
        's', 'h', 'o', 'o', 't', 'e', 'r', '\n',
        's', 'h', 'o', 'o', 't', 'e', 'r', 's', '\n',
        's', 'h', 'o', 'o', 't', 'i', 'n', 'g', '\n',
        's', 'h', 'o', 'o', 't', 'i', 'n', 'g', 's', '\n',
        's', 'h', 'o', 'o', 't', 's', '\n',
        's', 'h', 'o', 'p', '\n',
        's', 'h', 'o', 'p', 'f', 'r', 'o', 'n', 't', '\n',
        's', 'h', 'o', 'p', 'f', 'r', 'o', 'n', 't', 's', '\n',
        's', 'h', 'o', 'p', 'k', 'e', 'e', 'p', 'e', 'r', '\n',
        's', 'h', 'o', 'p', 'k', 'e', 'e', 'p', 'e', 'r', 's', '\n',
        's', 'h', 'o', 'p', 'k', 'e', 'e', 'p', 'i', 'n', 'g', '\n',
        's', 'h', 'o', 'p', 'l', 'i', 'f', 't', '\n',
        's', 'h', 'o', 'p', 'l', 'i', 'f', 't', 'e', 'd', '\n',
        's', 'h', 'o', 'p', 'l', 'i', 'f', 't', 'e', 'r', '\n',
        's', 'h', 'o', 'p', 'l', 'i', 'f', 't', 'e', 'r', 's', '\n',
        's', 'h', 'o', 'p', 'l', 'i', 'f', 't', 'i', 'n', 'g', '\n',
        's', 'h', 'o', 'p', 'p', 'e', 'd', '\n',
        's', 'h', 'o', 'p', 'p', 'e', 'r', '\n',
        's', 'h', 'o', 'p', 'p', 'e', 'r', 's', '\n',
        's', 'h', 'o', 'p', 'p', 'i', 'n', 'g', '\n',
        's', 'h', 'o', 'p', 's', '\n',
        's', 'h', 'o', 'r', 'e', '\n',
        's', 'h', 'o', 'r', 'e', 'd', '\n',
        's', 'h', 'o', 'r', 'e', 'l', 'i', 'n', 'e', '\n',
        's', 'h', 'o', 'r', 'e', 'l', 'i', 'n', 'e', 's', '\n',
        's', 'h', 'o', 'r', 'e', 's', '\n',
        's', 'h', 'o', 'r', 'e', 'w', 'a', 'r', 'd', '\n',
        's', 'h', 'o', 'r', 'e', 'w', 'a', 'r', 'd', 's', '\n',
        's', 'h', 'o', 'r', 'i', 'n', 'g', '\n',
        's', 'h', 'o', 'r', 'n', '\n',
        's', 'h', 'o', 'r', 't', '\n',
        's', 'h', 'o', 'r', 't', 'a', 'g', 'e', '\n',
        's', 'h', 'o', 'r', 't', 'a', 'g', 'e', 's', '\n',
        's', 'h', 'o', 'r', 't', 'b', 'r', 'e', 'a', 'd', '\n',
        's', 'h', 'o', 'r', 't', 'c', 'i', 'r', 'c', 'u', 'i', 't', '\n',
        's', 'h', 'o', 'r', 't', 'c', 'i', 'r', 'c', 'u', 'i', 't', 'e', 'd', '\n',
        's', 'h', 'o', 'r', 't', 'c', 'i', 'r', 'c', 'u', 'i', 't', 'i', 'n', 'g', '\n',
        's', 'h', 'o', 'r', 't', 'c', 'o', 'm', 'i', 'n', 'g', '\n',
        's', 'h', 'o', 'r', 't', 'c', 'o', 'm', 'i', 'n', 'g', 's', '\n',
        's', 'h', 'o', 'r', 't', 'c', 'r', 'u', 's', 't', '\n',
        's', 'h', 'o', 'r', 't', 'c', 'u', 't', '\n',
        's', 'h', 'o', 'r', 't', 'c', 'u', 't', 's', '\n',
        's', 'h', 'o', 'r', 't', 'e', 'd', '\n',
        's', 'h', 'o', 'r', 't', 'e', 'n', '\n',
        's', 'h', 'o', 'r', 't', 'e', 'n', 'e', 'd', '\n',
        's', 'h', 'o', 'r', 't', 'e', 'n', 'i', 'n', 'g', '\n',
        's', 'h', 'o', 'r', 't', 'e', 'n', 's', '\n',
        's', 'h', 'o', 'r', 't', 'e', 'r', '\n',
        's', 'h', 'o', 'r', 't', 'e', 's', 't', '\n',
        's', 'h', 'o', 'r', 't', 'f', 'a', 'l', 'l', '\n',
        's', 'h', 'o', 'r', 't', 'f', 'a', 'l', 'l', 's', '\n',
        's', 'h', 'o', 'r', 't', 'h', 'a', 'n', 'd', '\n',
        's', 'h', 'o', 'r', 't', 'i', 'n', 'g', '\n',
        's', 'h', 'o', 'r', 't', 'i', 's', 'h', '\n',
        's', 'h', 'o', 'r', 't', 'l', 'i', 's', 't', '\n',
        's', 'h', 'o', 'r', 't', 'l', 'i', 's', 't', 'e', 'd', '\n',
        's', 'h', 'o', 'r', 't', 'l', 'i', 's', 't', 'i', 'n', 'g', '\n',
        's', 'h', 'o', 'r', 't', 'l', 'i', 'v', 'e', 'd', '\n',
        's', 'h', 'o', 'r', 't', 'l', 'y', '\n',
        's', 'h', 'o', 'r', 't', 'n', 'e', 's', 's', '\n',
        's', 'h', 'o', 'r', 't', 's', '\n',
        's', 'h', 'o', 'r', 't', 's', 'i', 'g', 'h', 't', 'e', 'd', '\n',
        's', 'h', 'o', 'r', 't', 's', 'i', 'g', 'h', 't', 'e', 'd', 'l', 'y', '\n',
        's', 'h', 'o', 'r', 't', 's', 'i', 'g', 'h', 't', 'e', 'd', 'n', 'e', 's', 's', '\n',
        's', 'h', 'o', 'r', 't', 's', 't', 'a', 'f', 'f', 'e', 'd', '\n',
        's', 'h', 'o', 'r', 't', 't', 'e', 'm', 'p', 'e', 'r', 'e', 'd', '\n',
        's', 'h', 'o', 'r', 't', 't', 'e', 'r', 'm', '\n',
        's', 'h', 'o', 'r', 't', 'w', 'i', 'n', 'd', 'e', 'd', '\n',
        's', 'h', 'o', 'r', 't', 'y', '\n',
        's', 'h', 'o', 't', '\n',
        's', 'h', 'o', 't', 'g', 'u', 'n', '\n',
        's', 'h', 'o', 't', 'g', 'u', 'n', 's', '\n',
        's', 'h', 'o', 't', 's', '\n',
        's', 'h', 'o', 'u', 'l', 'd', '\n',
        's', 'h', 'o', 'u', 'l', 'd', 'e', 'r', '\n',
        's', 'h', 'o', 'u', 'l', 'd', 'e', 'r', 'e', 'd', '\n',
        's', 'h', 'o', 'u', 'l', 'd', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'h', 'o', 'u', 'l', 'd', 'e', 'r', 's', '\n',
        's', 'h', 'o', 'u', 't', '\n',
        's', 'h', 'o', 'u', 't', 'e', 'd', '\n',
        's', 'h', 'o', 'u', 't', 'e', 'r', '\n',
        's', 'h', 'o', 'u', 't', 'e', 'r', 's', '\n',
        's', 'h', 'o', 'u', 't', 'i', 'n', 'g', '\n',
        's', 'h', 'o', 'u', 't', 's', '\n',
        's', 'h', 'o', 'v', 'e', '\n',
        's', 'h', 'o', 'v', 'e', 'd', '\n',
        's', 'h', 'o', 'v', 'e', 'l', '\n',
        's', 'h', 'o', 'v', 'e', 'l', 'f', 'u', 'l', '\n',
        's', 'h', 'o', 'v', 'e', 'l', 'l', 'e', 'd', '\n',
        's', 'h', 'o', 'v', 'e', 'l', 'l', 'e', 'r', '\n',
        's', 'h', 'o', 'v', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        's', 'h', 'o', 'v', 'e', 'l', 's', '\n',
        's', 'h', 'o', 'v', 'e', 's', '\n',
        's', 'h', 'o', 'v', 'i', 'n', 'g', '\n',
        's', 'h', 'o', 'w', '\n',
        's', 'h', 'o', 'w', 'c', 'a', 's', 'e', '\n',
        's', 'h', 'o', 'w', 'c', 'a', 's', 'e', 's', '\n',
        's', 'h', 'o', 'w', 'c', 'a', 's', 'i', 'n', 'g', '\n',
        's', 'h', 'o', 'w', 'd', 'o', 'w', 'n', '\n',
        's', 'h', 'o', 'w', 'e', 'd', '\n',
        's', 'h', 'o', 'w', 'e', 'r', '\n',
        's', 'h', 'o', 'w', 'e', 'r', 'e', 'd', '\n',
        's', 'h', 'o', 'w', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'h', 'o', 'w', 'e', 'r', 's', '\n',
        's', 'h', 'o', 'w', 'e', 'r', 'y', '\n',
        's', 'h', 'o', 'w', 'g', 'i', 'r', 'l', '\n',
        's', 'h', 'o', 'w', 'g', 'r', 'o', 'u', 'n', 'd', '\n',
        's', 'h', 'o', 'w', 'i', 'e', 'r', '\n',
        's', 'h', 'o', 'w', 'i', 'e', 's', 't', '\n',
        's', 'h', 'o', 'w', 'i', 'n', 'g', '\n',
        's', 'h', 'o', 'w', 'i', 'n', 'g', 's', '\n',
        's', 'h', 'o', 'w', 'j', 'u', 'm', 'p', 'e', 'r', 's', '\n',
        's', 'h', 'o', 'w', 'm', 'a', 'n', '\n',
        's', 'h', 'o', 'w', 'm', 'a', 'n', 's', 'h', 'i', 'p', '\n',
        's', 'h', 'o', 'w', 'm', 'e', 'n', '\n',
        's', 'h', 'o', 'w', 'n', '\n',
        's', 'h', 'o', 'w', 'o', 'f', 'f', '\n',
        's', 'h', 'o', 'w', 'p', 'i', 'e', 'c', 'e', '\n',
        's', 'h', 'o', 'w', 'p', 'i', 'e', 'c', 'e', 's', '\n',
        's', 'h', 'o', 'w', 'p', 'l', 'a', 'c', 'e', '\n',
        's', 'h', 'o', 'w', 'r', 'o', 'o', 'm', '\n',
        's', 'h', 'o', 'w', 'r', 'o', 'o', 'm', 's', '\n',
        's', 'h', 'o', 'w', 's', '\n',
        's', 'h', 'o', 'w', 'y', '\n',
        's', 'h', 'r', 'a', 'n', 'k', '\n',
        's', 'h', 'r', 'a', 'p', 'n', 'e', 'l', '\n',
        's', 'h', 'r', 'e', 'd', '\n',
        's', 'h', 'r', 'e', 'd', 'd', 'e', 'd', '\n',
        's', 'h', 'r', 'e', 'd', 'd', 'e', 'r', '\n',
        's', 'h', 'r', 'e', 'd', 'd', 'e', 'r', 's', '\n',
        's', 'h', 'r', 'e', 'd', 'd', 'i', 'n', 'g', '\n',
        's', 'h', 'r', 'e', 'd', 's', '\n',
        's', 'h', 'r', 'e', 'w', '\n',
        's', 'h', 'r', 'e', 'w', 'd', '\n',
        's', 'h', 'r', 'e', 'w', 'd', 'e', 'r', '\n',
        's', 'h', 'r', 'e', 'w', 'd', 'e', 's', 't', '\n',
        's', 'h', 'r', 'e', 'w', 'd', 'l', 'y', '\n',
        's', 'h', 'r', 'e', 'w', 'd', 'n', 'e', 's', 's', '\n',
        's', 'h', 'r', 'e', 'w', 's', '\n',
        's', 'h', 'r', 'i', 'e', 'k', '\n',
        's', 'h', 'r', 'i', 'e', 'k', 'e', 'd', '\n',
        's', 'h', 'r', 'i', 'e', 'k', 'e', 'r', '\n',
        's', 'h', 'r', 'i', 'e', 'k', 'e', 'r', 's', '\n',
        's', 'h', 'r', 'i', 'e', 'k', 'i', 'n', 'g', '\n',
        's', 'h', 'r', 'i', 'e', 'k', 's', '\n',
        's', 'h', 'r', 'i', 'f', 't', '\n',
        's', 'h', 'r', 'i', 'l', 'l', '\n',
        's', 'h', 'r', 'i', 'l', 'l', 'e', 'd', '\n',
        's', 'h', 'r', 'i', 'l', 'l', 'e', 's', 't', '\n',
        's', 'h', 'r', 'i', 'l', 'l', 'n', 'e', 's', 's', '\n',
        's', 'h', 'r', 'i', 'l', 'l', 's', '\n',
        's', 'h', 'r', 'i', 'l', 'l', 'y', '\n',
        's', 'h', 'r', 'i', 'm', 'p', '\n',
        's', 'h', 'r', 'i', 'm', 'p', 's', '\n',
        's', 'h', 'r', 'i', 'n', 'e', '\n',
        's', 'h', 'r', 'i', 'n', 'e', 's', '\n',
        's', 'h', 'r', 'i', 'n', 'k', '\n',
        's', 'h', 'r', 'i', 'n', 'k', 'a', 'b', 'l', 'e', '\n',
        's', 'h', 'r', 'i', 'n', 'k', 'a', 'g', 'e', '\n',
        's', 'h', 'r', 'i', 'n', 'k', 'i', 'n', 'g', '\n',
        's', 'h', 'r', 'i', 'n', 'k', 'i', 'n', 'g', 'l', 'y', '\n',
        's', 'h', 'r', 'i', 'n', 'k', 's', '\n',
        's', 'h', 'r', 'i', 'v', 'e', 'l', '\n',
        's', 'h', 'r', 'i', 'v', 'e', 'l', 'l', 'e', 'd', '\n',
        's', 'h', 'r', 'i', 'v', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        's', 'h', 'r', 'i', 'v', 'e', 'l', 's', '\n',
        's', 'h', 'r', 'o', 'u', 'd', '\n',
        's', 'h', 'r', 'o', 'u', 'd', 'e', 'd', '\n',
        's', 'h', 'r', 'o', 'u', 'd', 'i', 'n', 'g', '\n',
        's', 'h', 'r', 'o', 'u', 'd', 's', '\n',
        's', 'h', 'r', 'u', 'b', '\n',
        's', 'h', 'r', 'u', 'b', 'b', 'e', 'r', 'i', 'e', 's', '\n',
        's', 'h', 'r', 'u', 'b', 'b', 'e', 'r', 'y', '\n',
        's', 'h', 'r', 'u', 'b', 'b', 'y', '\n',
        's', 'h', 'r', 'u', 'b', 's', '\n',
        's', 'h', 'r', 'u', 'g', '\n',
        's', 'h', 'r', 'u', 'g', 'g', 'e', 'd', '\n',
        's', 'h', 'r', 'u', 'g', 'g', 'i', 'n', 'g', '\n',
        's', 'h', 'r', 'u', 'g', 's', '\n',
        's', 'h', 'r', 'u', 'n', 'k', '\n',
        's', 'h', 'r', 'u', 'n', 'k', 'e', 'n', '\n',
        's', 'h', 'u', 'd', 'd', 'e', 'r', '\n',
        's', 'h', 'u', 'd', 'd', 'e', 'r', 'e', 'd', '\n',
        's', 'h', 'u', 'd', 'd', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'h', 'u', 'd', 'd', 'e', 'r', 's', '\n',
        's', 'h', 'u', 'f', 'f', 'l', 'e', '\n',
        's', 'h', 'u', 'f', 'f', 'l', 'e', 'd', '\n',
        's', 'h', 'u', 'f', 'f', 'l', 'e', 'r', '\n',
        's', 'h', 'u', 'f', 'f', 'l', 'e', 'r', 's', '\n',
        's', 'h', 'u', 'f', 'f', 'l', 'e', 's', '\n',
        's', 'h', 'u', 'f', 'f', 'l', 'i', 'n', 'g', '\n',
        's', 'h', 'u', 'n', '\n',
        's', 'h', 'u', 'n', 'n', 'e', 'd', '\n',
        's', 'h', 'u', 'n', 'n', 'i', 'n', 'g', '\n',
        's', 'h', 'u', 'n', 's', '\n',
        's', 'h', 'u', 'n', 't', '\n',
        's', 'h', 'u', 'n', 't', 'e', 'd', '\n',
        's', 'h', 'u', 'n', 't', 'e', 'r', '\n',
        's', 'h', 'u', 'n', 't', 'e', 'r', 's', '\n',
        's', 'h', 'u', 'n', 't', 'i', 'n', 'g', '\n',
        's', 'h', 'u', 'n', 't', 's', '\n',
        's', 'h', 'u', 's', 'h', 'e', 'd', '\n',
        's', 'h', 'u', 't', '\n',
        's', 'h', 'u', 't', 'd', 'o', 'w', 'n', '\n',
        's', 'h', 'u', 't', 'd', 'o', 'w', 'n', 's', '\n',
        's', 'h', 'u', 't', 's', '\n',
        's', 'h', 'u', 't', 't', 'e', 'r', '\n',
        's', 'h', 'u', 't', 't', 'e', 'r', 'e', 'd', '\n',
        's', 'h', 'u', 't', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'h', 'u', 't', 't', 'e', 'r', 's', '\n',
        's', 'h', 'u', 't', 't', 'i', 'n', 'g', '\n',
        's', 'h', 'u', 't', 't', 'l', 'e', '\n',
        's', 'h', 'u', 't', 't', 'l', 'e', 'c', 'o', 'c', 'k', '\n',
        's', 'h', 'u', 't', 't', 'l', 'e', 'c', 'o', 'c', 'k', 's', '\n',
        's', 'h', 'u', 't', 't', 'l', 'e', 'd', '\n',
        's', 'h', 'u', 't', 't', 'l', 'e', 's', '\n',
        's', 'h', 'u', 't', 't', 'l', 'i', 'n', 'g', '\n',
        's', 'h', 'u', 't', 'u', 'p', '\n',
        's', 'h', 'y', '\n',
        's', 'h', 'y', 'e', 'r', '\n',
        's', 'h', 'y', 'e', 's', 't', '\n',
        's', 'h', 'y', 'i', 'n', 'g', '\n',
        's', 'h', 'y', 'l', 'y', '\n',
        's', 'h', 'y', 'n', 'e', 's', 's', '\n',
        's', 'i', 'a', 'm', '\n',
        's', 'i', 'a', 'm', 'e', 's', 'e', '\n',
        's', 'i', 'b', 'e', 'r', 'i', 'a', '\n',
        's', 'i', 'b', 'e', 'r', 'i', 'a', 'n', '\n',
        's', 'i', 'b', 'i', 'l', 'a', 'n', 'c', 'e', '\n',
        's', 'i', 'b', 'i', 'l', 'a', 'n', 'c', 'y', '\n',
        's', 'i', 'b', 'i', 'l', 'a', 'n', 't', '\n',
        's', 'i', 'b', 'l', 'i', 'n', 'g', '\n',
        's', 'i', 'b', 'l', 'i', 'n', 'g', 's', '\n',
        's', 'i', 'b', 'y', 'l', '\n',
        's', 'i', 'c', '\n',
        's', 'i', 'c', 'i', 'l', 'i', 'a', 'n', '\n',
        's', 'i', 'c', 'i', 'l', 'y', '\n',
        's', 'i', 'c', 'k', '\n',
        's', 'i', 'c', 'k', 'b', 'a', 'y', '\n',
        's', 'i', 'c', 'k', 'b', 'e', 'd', '\n',
        's', 'i', 'c', 'k', 'e', 'n', '\n',
        's', 'i', 'c', 'k', 'e', 'n', 'e', 'd', '\n',
        's', 'i', 'c', 'k', 'e', 'n', 'i', 'n', 'g', '\n',
        's', 'i', 'c', 'k', 'e', 'n', 'i', 'n', 'g', 'l', 'y', '\n',
        's', 'i', 'c', 'k', 'e', 'n', 's', '\n',
        's', 'i', 'c', 'k', 'e', 'r', '\n',
        's', 'i', 'c', 'k', 'e', 's', 't', '\n',
        's', 'i', 'c', 'k', 'l', 'e', '\n',
        's', 'i', 'c', 'k', 'l', 'e', 's', '\n',
        's', 'i', 'c', 'k', 'l', 'i', 'e', 's', 't', '\n',
        's', 'i', 'c', 'k', 'l', 'y', '\n',
        's', 'i', 'c', 'k', 'n', 'e', 's', 's', '\n',
        's', 'i', 'c', 'k', 'n', 'e', 's', 's', 'e', 's', '\n',
        's', 'i', 'c', 'k', 'r', 'o', 'o', 'm', '\n',
        's', 'i', 'd', 'e', '\n',
        's', 'i', 'd', 'e', 'b', 'a', 'n', 'd', '\n',
        's', 'i', 'd', 'e', 'b', 'a', 'n', 'd', 's', '\n',
        's', 'i', 'd', 'e', 'b', 'o', 'a', 'r', 'd', '\n',
        's', 'i', 'd', 'e', 'b', 'o', 'a', 'r', 'd', 's', '\n',
        's', 'i', 'd', 'e', 'b', 'u', 'r', 'n', 's', '\n',
        's', 'i', 'd', 'e', 'c', 'a', 'r', '\n',
        's', 'i', 'd', 'e', 'd', '\n',
        's', 'i', 'd', 'e', 'k', 'i', 'c', 'k', '\n',
        's', 'i', 'd', 'e', 'l', 'i', 'g', 'h', 't', '\n',
        's', 'i', 'd', 'e', 'l', 'i', 'g', 'h', 't', 's', '\n',
        's', 'i', 'd', 'e', 'l', 'i', 'n', 'e', '\n',
        's', 'i', 'd', 'e', 'l', 'i', 'n', 'e', 's', '\n',
        's', 'i', 'd', 'e', 'l', 'o', 'n', 'g', '\n',
        's', 'i', 'd', 'e', 'r', '\n',
        's', 'i', 'd', 'e', 'r', 'e', 'a', 'l', '\n',
        's', 'i', 'd', 'e', 's', '\n',
        's', 'i', 'd', 'e', 's', 'h', 'o', 'w', '\n',
        's', 'i', 'd', 'e', 's', 'h', 'o', 'w', 's', '\n',
        's', 'i', 'd', 'e', 's', 't', 'e', 'p', '\n',
        's', 'i', 'd', 'e', 's', 't', 'e', 'p', 'p', 'e', 'd', '\n',
        's', 'i', 'd', 'e', 's', 't', 'e', 'p', 'p', 'i', 'n', 'g', '\n',
        's', 'i', 'd', 'e', 's', 't', 'e', 'p', 's', '\n',
        's', 'i', 'd', 'e', 's', 'w', 'i', 'p', 'e', 's', '\n',
        's', 'i', 'd', 'e', 't', 'r', 'a', 'c', 'k', '\n',
        's', 'i', 'd', 'e', 't', 'r', 'a', 'c', 'k', 'e', 'd', '\n',
        's', 'i', 'd', 'e', 't', 'r', 'a', 'c', 'k', 'i', 'n', 'g', '\n',
        's', 'i', 'd', 'e', 'w', 'a', 'l', 'k', '\n',
        's', 'i', 'd', 'e', 'w', 'a', 'r', 'd', 's', '\n',
        's', 'i', 'd', 'e', 'w', 'a', 'y', 's', '\n',
        's', 'i', 'd', 'e', 'w', 'i', 'n', 'd', 'e', 'r', 's', '\n',
        's', 'i', 'd', 'i', 'n', 'g', '\n',
        's', 'i', 'd', 'i', 'n', 'g', 's', '\n',
        's', 'i', 'd', 'l', 'e', '\n',
        's', 'i', 'd', 'l', 'e', 'd', '\n',
        's', 'i', 'd', 'l', 'i', 'n', 'g', '\n',
        's', 'i', 'e', 'g', 'e', '\n',
        's', 'i', 'e', 'g', 'e', 's', '\n',
        's', 'i', 'e', 'n', 'n', 'a', '\n',
        's', 'i', 'e', 'r', 'r', 'a', '\n',
        's', 'i', 'e', 's', 't', 'a', '\n',
        's', 'i', 'e', 's', 't', 'a', 's', '\n',
        's', 'i', 'e', 'v', 'e', '\n',
        's', 'i', 'e', 'v', 'e', 'd', '\n',
        's', 'i', 'e', 'v', 'e', 's', '\n',
        's', 'i', 'e', 'v', 'i', 'n', 'g', '\n',
        's', 'i', 'f', 't', '\n',
        's', 'i', 'f', 't', 'e', 'd', '\n',
        's', 'i', 'f', 't', 'e', 'r', '\n',
        's', 'i', 'f', 't', 'e', 'r', 's', '\n',
        's', 'i', 'f', 't', 'i', 'n', 'g', '\n',
        's', 'i', 'f', 't', 'i', 'n', 'g', 's', '\n',
        's', 'i', 'f', 't', 's', '\n',
        's', 'i', 'g', 'h', '\n',
        's', 'i', 'g', 'h', 'e', 'd', '\n',
        's', 'i', 'g', 'h', 'i', 'n', 'g', '\n',
        's', 'i', 'g', 'h', 's', '\n',
        's', 'i', 'g', 'h', 't', '\n',
        's', 'i', 'g', 'h', 't', 'e', 'd', '\n',
        's', 'i', 'g', 'h', 't', 'e', 'd', 'n', 'e', 's', 's', '\n',
        's', 'i', 'g', 'h', 't', 'i', 'n', 'g', '\n',
        's', 'i', 'g', 'h', 't', 'i', 'n', 'g', 's', '\n',
        's', 'i', 'g', 'h', 't', 'l', 'e', 's', 's', '\n',
        's', 'i', 'g', 'h', 't', 'l', 'e', 's', 's', 'l', 'y', '\n',
        's', 'i', 'g', 'h', 't', 'l', 'y', '\n',
        's', 'i', 'g', 'h', 't', 's', '\n',
        's', 'i', 'g', 'h', 't', 's', 'e', 'e', '\n',
        's', 'i', 'g', 'h', 't', 's', 'e', 'e', 'i', 'n', 'g', '\n',
        's', 'i', 'g', 'h', 't', 's', 'e', 'e', 'r', 's', '\n',
        's', 'i', 'g', 'm', 'a', '\n',
        's', 'i', 'g', 'm', 'o', 'i', 'd', '\n',
        's', 'i', 'g', 'n', '\n',
        's', 'i', 'g', 'n', 'a', 'l', '\n',
        's', 'i', 'g', 'n', 'a', 'l', 'l', 'e', 'd', '\n',
        's', 'i', 'g', 'n', 'a', 'l', 'l', 'e', 'r', '\n',
        's', 'i', 'g', 'n', 'a', 'l', 'l', 'e', 'r', 's', '\n',
        's', 'i', 'g', 'n', 'a', 'l', 'l', 'i', 'n', 'g', '\n',
        's', 'i', 'g', 'n', 'a', 'l', 'l', 'y', '\n',
        's', 'i', 'g', 'n', 'a', 'l', 'm', 'a', 'n', '\n',
        's', 'i', 'g', 'n', 'a', 'l', 'm', 'e', 'n', '\n',
        's', 'i', 'g', 'n', 'a', 'l', 's', '\n',
        's', 'i', 'g', 'n', 'a', 't', 'o', 'r', 'i', 'e', 's', '\n',
        's', 'i', 'g', 'n', 'a', 't', 'o', 'r', 'y', '\n',
        's', 'i', 'g', 'n', 'a', 't', 'u', 'r', 'e', '\n',
        's', 'i', 'g', 'n', 'a', 't', 'u', 'r', 'e', 's', '\n',
        's', 'i', 'g', 'n', 'b', 'o', 'a', 'r', 'd', 's', '\n',
        's', 'i', 'g', 'n', 'e', 'd', '\n',
        's', 'i', 'g', 'n', 'e', 'r', '\n',
        's', 'i', 'g', 'n', 'e', 'r', 's', '\n',
        's', 'i', 'g', 'n', 'e', 't', '\n',
        's', 'i', 'g', 'n', 'i', 'f', 'i', 'c', 'a', 'n', 'c', 'e', '\n',
        's', 'i', 'g', 'n', 'i', 'f', 'i', 'c', 'a', 'n', 'c', 'e', 's', '\n',
        's', 'i', 'g', 'n', 'i', 'f', 'i', 'c', 'a', 'n', 't', '\n',
        's', 'i', 'g', 'n', 'i', 'f', 'i', 'c', 'a', 'n', 't', 'l', 'y', '\n',
        's', 'i', 'g', 'n', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'i', 'g', 'n', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        's', 'i', 'g', 'n', 'i', 'f', 'i', 'e', 'd', '\n',
        's', 'i', 'g', 'n', 'i', 'f', 'i', 'e', 'r', '\n',
        's', 'i', 'g', 'n', 'i', 'f', 'i', 'e', 's', '\n',
        's', 'i', 'g', 'n', 'i', 'f', 'y', '\n',
        's', 'i', 'g', 'n', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        's', 'i', 'g', 'n', 'i', 'n', 'g', '\n',
        's', 'i', 'g', 'n', 'i', 'n', 'g', 's', '\n',
        's', 'i', 'g', 'n', 'o', 'r', '\n',
        's', 'i', 'g', 'n', 'o', 'r', 'a', '\n',
        's', 'i', 'g', 'n', 'o', 'r', 's', '\n',
        's', 'i', 'g', 'n', 'p', 'o', 's', 't', '\n',
        's', 'i', 'g', 'n', 'p', 'o', 's', 't', 'e', 'd', '\n',
        's', 'i', 'g', 'n', 'p', 'o', 's', 't', 'i', 'n', 'g', '\n',
        's', 'i', 'g', 'n', 'p', 'o', 's', 't', 's', '\n',
        's', 'i', 'g', 'n', 's', '\n',
        's', 'i', 'g', 'n', 'w', 'r', 'i', 't', 'e', 'r', '\n',
        's', 'i', 'l', 'a', 'g', 'e', '\n',
        's', 'i', 'l', 'e', 'n', 'c', 'e', '\n',
        's', 'i', 'l', 'e', 'n', 'c', 'e', 'd', '\n',
        's', 'i', 'l', 'e', 'n', 'c', 'e', 'r', '\n',
        's', 'i', 'l', 'e', 'n', 'c', 'e', 'r', 's', '\n',
        's', 'i', 'l', 'e', 'n', 'c', 'e', 's', '\n',
        's', 'i', 'l', 'e', 'n', 'c', 'i', 'n', 'g', '\n',
        's', 'i', 'l', 'e', 'n', 't', '\n',
        's', 'i', 'l', 'e', 'n', 't', 'l', 'y', '\n',
        's', 'i', 'l', 'h', 'o', 'u', 'e', 't', 't', 'e', '\n',
        's', 'i', 'l', 'h', 'o', 'u', 'e', 't', 't', 'e', 'd', '\n',
        's', 'i', 'l', 'h', 'o', 'u', 'e', 't', 't', 'e', 's', '\n',
        's', 'i', 'l', 'i', 'c', 'a', '\n',
        's', 'i', 'l', 'i', 'c', 'a', 't', 'e', '\n',
        's', 'i', 'l', 'i', 'c', 'a', 't', 'e', 's', '\n',
        's', 'i', 'l', 'i', 'c', 'o', 'n', '\n',
        's', 'i', 'l', 'i', 'c', 'o', 'n', 'e', '\n',
        's', 'i', 'l', 'i', 'c', 'o', 's', 'i', 's', '\n',
        's', 'i', 'l', 'k', '\n',
        's', 'i', 'l', 'k', 'e', 'n', '\n',
        's', 'i', 'l', 'k', 'i', 'e', 'r', '\n',
        's', 'i', 'l', 'k', 'i', 'e', 's', 't', '\n',
        's', 'i', 'l', 'k', 'i', 'l', 'y', '\n',
        's', 'i', 'l', 'k', 'i', 'n', 'e', 's', 's', '\n',
        's', 'i', 'l', 'k', 'l', 'i', 'k', 'e', '\n',
        's', 'i', 'l', 'k', 's', '\n',
        's', 'i', 'l', 'k', 'w', 'o', 'r', 'm', '\n',
        's', 'i', 'l', 'k', 'w', 'o', 'r', 'm', 's', '\n',
        's', 'i', 'l', 'k', 'y', '\n',
        's', 'i', 'l', 'l', 'i', 'e', 'r', '\n',
        's', 'i', 'l', 'l', 'i', 'e', 's', 't', '\n',
        's', 'i', 'l', 'l', 'i', 'n', 'e', 's', 's', '\n',
        's', 'i', 'l', 'l', 'y', '\n',
        's', 'i', 'l', 'o', '\n',
        's', 'i', 'l', 't', '\n',
        's', 'i', 'l', 't', 'e', 'd', '\n',
        's', 'i', 'l', 't', 'i', 'n', 'g', '\n',
        's', 'i', 'l', 't', 's', '\n',
        's', 'i', 'l', 't', 's', 't', 'o', 'n', 'e', '\n',
        's', 'i', 'l', 't', 'y', '\n',
        's', 'i', 'l', 'v', 'e', 'r', '\n',
        's', 'i', 'l', 'v', 'e', 'r', 'e', 'd', '\n',
        's', 'i', 'l', 'v', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'i', 'l', 'v', 'e', 'r', 's', '\n',
        's', 'i', 'l', 'v', 'e', 'r', 's', 'm', 'i', 't', 'h', '\n',
        's', 'i', 'l', 'v', 'e', 'r', 's', 'm', 'i', 't', 'h', 's', '\n',
        's', 'i', 'l', 'v', 'e', 'r', 'w', 'a', 'r', 'e', '\n',
        's', 'i', 'l', 'v', 'e', 'r', 'y', '\n',
        's', 'i', 'm', 'e', 'o', 'n', '\n',
        's', 'i', 'm', 'i', 'l', 'a', 'r', '\n',
        's', 'i', 'm', 'i', 'l', 'a', 'r', 'i', 't', 'i', 'e', 's', '\n',
        's', 'i', 'm', 'i', 'l', 'a', 'r', 'i', 't', 'y', '\n',
        's', 'i', 'm', 'i', 'l', 'a', 'r', 'l', 'y', '\n',
        's', 'i', 'm', 'i', 'l', 'e', '\n',
        's', 'i', 'm', 'i', 'l', 'e', 's', '\n',
        's', 'i', 'm', 'i', 'l', 'i', 't', 'u', 'd', 'e', '\n',
        's', 'i', 'm', 'm', 'e', 'r', '\n',
        's', 'i', 'm', 'm', 'e', 'r', 'e', 'd', '\n',
        's', 'i', 'm', 'm', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'i', 'm', 'm', 'e', 'r', 's', '\n',
        's', 'i', 'm', 'p', 'e', 'r', '\n',
        's', 'i', 'm', 'p', 'e', 'r', 'e', 'd', '\n',
        's', 'i', 'm', 'p', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'i', 'm', 'p', 'e', 'r', 's', '\n',
        's', 'i', 'm', 'p', 'l', 'e', '\n',
        's', 'i', 'm', 'p', 'l', 'e', 'm', 'i', 'n', 'd', 'e', 'd', '\n',
        's', 'i', 'm', 'p', 'l', 'e', 'r', '\n',
        's', 'i', 'm', 'p', 'l', 'e', 's', 't', '\n',
        's', 'i', 'm', 'p', 'l', 'e', 't', 'o', 'n', '\n',
        's', 'i', 'm', 'p', 'l', 'e', 't', 'o', 'n', 's', '\n',
        's', 'i', 'm', 'p', 'l', 'e', 'x', '\n',
        's', 'i', 'm', 'p', 'l', 'e', 'x', 'e', 's', '\n',
        's', 'i', 'm', 'p', 'l', 'i', 'c', 'i', 't', 'i', 'e', 's', '\n',
        's', 'i', 'm', 'p', 'l', 'i', 'c', 'i', 't', 'y', '\n',
        's', 'i', 'm', 'p', 'l', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'i', 'm', 'p', 'l', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        's', 'i', 'm', 'p', 'l', 'i', 'f', 'i', 'e', 'd', '\n',
        's', 'i', 'm', 'p', 'l', 'i', 'f', 'i', 'e', 'r', '\n',
        's', 'i', 'm', 'p', 'l', 'i', 'f', 'i', 'e', 's', '\n',
        's', 'i', 'm', 'p', 'l', 'i', 'f', 'y', '\n',
        's', 'i', 'm', 'p', 'l', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        's', 'i', 'm', 'p', 'l', 'i', 's', 'm', '\n',
        's', 'i', 'm', 'p', 'l', 'i', 's', 't', 'i', 'c', '\n',
        's', 'i', 'm', 'p', 'l', 'i', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 'i', 'm', 'p', 'l', 'y', '\n',
        's', 'i', 'm', 'u', 'l', 'a', 'c', 'r', 'u', 'm', '\n',
        's', 'i', 'm', 'u', 'l', 'a', 't', 'e', '\n',
        's', 'i', 'm', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        's', 'i', 'm', 'u', 'l', 'a', 't', 'e', 's', '\n',
        's', 'i', 'm', 'u', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        's', 'i', 'm', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'i', 'm', 'u', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        's', 'i', 'm', 'u', 'l', 'a', 't', 'o', 'r', '\n',
        's', 'i', 'm', 'u', 'l', 'a', 't', 'o', 'r', 's', '\n',
        's', 'i', 'm', 'u', 'l', 'c', 'a', 's', 't', 's', '\n',
        's', 'i', 'm', 'u', 'l', 't', 'a', 'n', 'e', 'i', 't', 'y', '\n',
        's', 'i', 'm', 'u', 'l', 't', 'a', 'n', 'e', 'o', 'u', 's', '\n',
        's', 'i', 'm', 'u', 'l', 't', 'a', 'n', 'e', 'o', 'u', 's', 'l', 'y', '\n',
        's', 'i', 'n', '\n',
        's', 'i', 'n', 'a', 'i', '\n',
        's', 'i', 'n', 'c', 'e', '\n',
        's', 'i', 'n', 'c', 'e', 'r', 'e', '\n',
        's', 'i', 'n', 'c', 'e', 'r', 'e', 'l', 'y', '\n',
        's', 'i', 'n', 'c', 'e', 'r', 'e', 's', 't', '\n',
        's', 'i', 'n', 'c', 'e', 'r', 'i', 't', 'y', '\n',
        's', 'i', 'n', 'e', '\n',
        's', 'i', 'n', 'e', 'c', 'u', 'r', 'e', '\n',
        's', 'i', 'n', 'e', 'c', 'u', 'r', 'e', 's', '\n',
        's', 'i', 'n', 'e', 'c', 'u', 'r', 'i', 's', 't', '\n',
        's', 'i', 'n', 'e', 's', '\n',
        's', 'i', 'n', 'e', 'w', '\n',
        's', 'i', 'n', 'e', 'w', 's', '\n',
        's', 'i', 'n', 'e', 'w', 'y', '\n',
        's', 'i', 'n', 'f', 'u', 'l', '\n',
        's', 'i', 'n', 'f', 'u', 'l', 'l', 'y', '\n',
        's', 'i', 'n', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        's', 'i', 'n', 'g', '\n',
        's', 'i', 'n', 'g', 'a', 'b', 'l', 'e', '\n',
        's', 'i', 'n', 'g', 'a', 'l', 'o', 'n', 'g', '\n',
        's', 'i', 'n', 'g', 'e', '\n',
        's', 'i', 'n', 'g', 'e', 'd', '\n',
        's', 'i', 'n', 'g', 'e', 'i', 'n', 'g', '\n',
        's', 'i', 'n', 'g', 'e', 'r', '\n',
        's', 'i', 'n', 'g', 'e', 'r', 's', '\n',
        's', 'i', 'n', 'g', 'e', 's', '\n',
        's', 'i', 'n', 'g', 'i', 'n', 'g', '\n',
        's', 'i', 'n', 'g', 'l', 'e', '\n',
        's', 'i', 'n', 'g', 'l', 'e', 'h', 'a', 'n', 'd', 'e', 'd', '\n',
        's', 'i', 'n', 'g', 'l', 'e', 'h', 'a', 'n', 'd', 'e', 'd', 'l', 'y', '\n',
        's', 'i', 'n', 'g', 'l', 'e', 'm', 'i', 'n', 'd', 'e', 'd', '\n',
        's', 'i', 'n', 'g', 'l', 'e', 'm', 'i', 'n', 'd', 'e', 'd', 'l', 'y', '\n',
        's', 'i', 'n', 'g', 'l', 'e', 'm', 'i', 'n', 'd', 'e', 'd', 'n', 'e', 's', 's', '\n',
        's', 'i', 'n', 'g', 'l', 'e', 'n', 'e', 's', 's', '\n',
        's', 'i', 'n', 'g', 'l', 'e', 's', '\n',
        's', 'i', 'n', 'g', 'l', 'y', '\n',
        's', 'i', 'n', 'g', 's', '\n',
        's', 'i', 'n', 'g', 's', 'o', 'n', 'g', '\n',
        's', 'i', 'n', 'g', 'u', 'l', 'a', 'r', '\n',
        's', 'i', 'n', 'g', 'u', 'l', 'a', 'r', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'i', 'n', 'g', 'u', 'l', 'a', 'r', 'i', 't', 'i', 'e', 's', '\n',
        's', 'i', 'n', 'g', 'u', 'l', 'a', 'r', 'i', 't', 'y', '\n',
        's', 'i', 'n', 'g', 'u', 'l', 'a', 'r', 'l', 'y', '\n',
        's', 'i', 'n', 'g', 'u', 'l', 'a', 'r', 's', '\n',
        's', 'i', 'n', 'i', 's', 't', 'e', 'r', '\n',
        's', 'i', 'n', 'i', 's', 't', 'e', 'r', 'l', 'y', '\n',
        's', 'i', 'n', 'i', 's', 't', 'r', 'a', 'l', '\n',
        's', 'i', 'n', 'k', '\n',
        's', 'i', 'n', 'k', 'a', 'b', 'l', 'e', '\n',
        's', 'i', 'n', 'k', 'e', 'r', '\n',
        's', 'i', 'n', 'k', 'e', 'r', 's', '\n',
        's', 'i', 'n', 'k', 'i', 'n', 'g', '\n',
        's', 'i', 'n', 'k', 's', '\n',
        's', 'i', 'n', 'l', 'e', 's', 's', '\n',
        's', 'i', 'n', 'n', 'e', 'd', '\n',
        's', 'i', 'n', 'n', 'e', 'r', '\n',
        's', 'i', 'n', 'n', 'e', 'r', 's', '\n',
        's', 'i', 'n', 'n', 'i', 'n', 'g', '\n',
        's', 'i', 'n', 's', '\n',
        's', 'i', 'n', 't', 'e', 'r', '\n',
        's', 'i', 'n', 't', 'e', 'r', 's', '\n',
        's', 'i', 'n', 'u', 'o', 'u', 's', '\n',
        's', 'i', 'n', 'u', 'o', 'u', 's', 'l', 'y', '\n',
        's', 'i', 'n', 'u', 's', '\n',
        's', 'i', 'n', 'u', 's', 'e', 's', '\n',
        's', 'i', 'n', 'u', 's', 'i', 't', 'i', 's', '\n',
        's', 'i', 'n', 'u', 's', 'o', 'i', 'd', '\n',
        's', 'i', 'n', 'u', 's', 'o', 'i', 'd', 'a', 'l', '\n',
        's', 'i', 'n', 'u', 's', 'o', 'i', 'd', 'a', 'l', 'l', 'y', '\n',
        's', 'i', 'p', '\n',
        's', 'i', 'p', 'h', 'o', 'n', '\n',
        's', 'i', 'p', 'h', 'o', 'n', 'e', 'd', '\n',
        's', 'i', 'p', 'h', 'o', 'n', 'i', 'n', 'g', '\n',
        's', 'i', 'p', 'h', 'o', 'n', 's', '\n',
        's', 'i', 'p', 'p', 'e', 'd', '\n',
        's', 'i', 'p', 'p', 'e', 'r', '\n',
        's', 'i', 'p', 'p', 'e', 'r', 's', '\n',
        's', 'i', 'p', 'p', 'i', 'n', 'g', '\n',
        's', 'i', 'p', 's', '\n',
        's', 'i', 'r', '\n',
        's', 'i', 'r', 'e', '\n',
        's', 'i', 'r', 'e', 'd', '\n',
        's', 'i', 'r', 'e', 'n', '\n',
        's', 'i', 'r', 'e', 'n', 's', '\n',
        's', 'i', 'r', 'e', 's', '\n',
        's', 'i', 'r', 'i', 'u', 's', '\n',
        's', 'i', 'r', 'l', 'o', 'i', 'n', '\n',
        's', 'i', 'r', 'l', 'o', 'i', 'n', 's', '\n',
        's', 'i', 'r', 's', '\n',
        's', 'i', 's', '\n',
        's', 'i', 's', 'a', 'l', '\n',
        's', 'i', 's', 's', 'i', 'e', 's', '\n',
        's', 'i', 's', 's', 'y', '\n',
        's', 'i', 's', 't', 'e', 'r', '\n',
        's', 'i', 's', 't', 'e', 'r', 'h', 'o', 'o', 'd', '\n',
        's', 'i', 's', 't', 'e', 'r', 'i', 'n', 'l', 'a', 'w', '\n',
        's', 'i', 's', 't', 'e', 'r', 'l', 'y', '\n',
        's', 'i', 's', 't', 'e', 'r', 's', '\n',
        's', 'i', 's', 't', 'e', 'r', 's', 'i', 'n', 'l', 'a', 'w', '\n',
        's', 'i', 't', '\n',
        's', 'i', 't', 'a', 'r', '\n',
        's', 'i', 't', 'c', 'o', 'm', '\n',
        's', 'i', 't', 'c', 'o', 'm', 's', '\n',
        's', 'i', 't', 'e', '\n',
        's', 'i', 't', 'e', 'd', '\n',
        's', 'i', 't', 'e', 's', '\n',
        's', 'i', 't', 'i', 'n', 'g', '\n',
        's', 'i', 't', 'i', 'n', 'g', 's', '\n',
        's', 'i', 't', 's', '\n',
        's', 'i', 't', 't', 'e', 'r', '\n',
        's', 'i', 't', 't', 'e', 'r', 's', '\n',
        's', 'i', 't', 't', 'i', 'n', 'g', '\n',
        's', 'i', 't', 't', 'i', 'n', 'g', 's', '\n',
        's', 'i', 't', 'u', 'a', 't', 'e', '\n',
        's', 'i', 't', 'u', 'a', 't', 'e', 'd', '\n',
        's', 'i', 't', 'u', 'a', 't', 'i', 'n', 'g', '\n',
        's', 'i', 't', 'u', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'i', 't', 'u', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        's', 'i', 't', 'u', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        's', 'i', 't', 'u', 'a', 't', 'i', 'o', 'n', 'i', 's', 't', '\n',
        's', 'i', 't', 'u', 'a', 't', 'i', 'o', 'n', 's', '\n',
        's', 'i', 'x', '\n',
        's', 'i', 'x', 'e', 's', '\n',
        's', 'i', 'x', 'f', 'o', 'l', 'd', '\n',
        's', 'i', 'x', 'p', 'e', 'n', 'c', 'e', '\n',
        's', 'i', 'x', 't', 'e', 'e', 'n', '\n',
        's', 'i', 'x', 't', 'e', 'e', 'n', 't', 'h', '\n',
        's', 'i', 'x', 't', 'h', '\n',
        's', 'i', 'x', 't', 'h', 's', '\n',
        's', 'i', 'x', 't', 'i', 'e', 's', '\n',
        's', 'i', 'x', 't', 'i', 'e', 't', 'h', '\n',
        's', 'i', 'x', 't', 'y', '\n',
        's', 'i', 'z', 'e', '\n',
        's', 'i', 'z', 'e', 'a', 'b', 'l', 'e', '\n',
        's', 'i', 'z', 'e', 'd', '\n',
        's', 'i', 'z', 'e', 's', '\n',
        's', 'i', 'z', 'i', 'n', 'g', '\n',
        's', 'i', 'z', 'z', 'l', 'e', '\n',
        's', 'i', 'z', 'z', 'l', 'e', 'd', '\n',
        's', 'i', 'z', 'z', 'l', 'e', 's', '\n',
        's', 'i', 'z', 'z', 'l', 'i', 'n', 'g', '\n',
        's', 'j', 'a', 'm', 'b', 'o', 'k', '\n',
        's', 'k', 'a', 't', 'e', '\n',
        's', 'k', 'a', 't', 'e', 'b', 'o', 'a', 'r', 'd', '\n',
        's', 'k', 'a', 't', 'e', 'b', 'o', 'a', 'r', 'd', 's', '\n',
        's', 'k', 'a', 't', 'e', 'd', '\n',
        's', 'k', 'a', 't', 'e', 'r', '\n',
        's', 'k', 'a', 't', 'e', 'r', 's', '\n',
        's', 'k', 'a', 't', 'e', 's', '\n',
        's', 'k', 'a', 't', 'i', 'n', 'g', '\n',
        's', 'k', 'e', 'i', 'n', '\n',
        's', 'k', 'e', 'l', 'e', 't', 'a', 'l', '\n',
        's', 'k', 'e', 'l', 'e', 't', 'o', 'n', '\n',
        's', 'k', 'e', 'l', 'e', 't', 'o', 'n', 's', '\n',
        's', 'k', 'e', 'p', 't', 'i', 'c', '\n',
        's', 'k', 'e', 'r', 'r', 'i', 'e', 's', '\n',
        's', 'k', 'e', 't', 'c', 'h', '\n',
        's', 'k', 'e', 't', 'c', 'h', 'b', 'o', 'o', 'k', '\n',
        's', 'k', 'e', 't', 'c', 'h', 'b', 'o', 'o', 'k', 's', '\n',
        's', 'k', 'e', 't', 'c', 'h', 'e', 'd', '\n',
        's', 'k', 'e', 't', 'c', 'h', 'e', 'r', '\n',
        's', 'k', 'e', 't', 'c', 'h', 'e', 's', '\n',
        's', 'k', 'e', 't', 'c', 'h', 'i', 'e', 'r', '\n',
        's', 'k', 'e', 't', 'c', 'h', 'i', 'e', 's', 't', '\n',
        's', 'k', 'e', 't', 'c', 'h', 'i', 'l', 'y', '\n',
        's', 'k', 'e', 't', 'c', 'h', 'i', 'n', 'g', '\n',
        's', 'k', 'e', 't', 'c', 'h', 'p', 'a', 'd', '\n',
        's', 'k', 'e', 't', 'c', 'h', 'y', '\n',
        's', 'k', 'e', 'w', '\n',
        's', 'k', 'e', 'w', 'e', 'd', '\n',
        's', 'k', 'e', 'w', 'e', 'r', '\n',
        's', 'k', 'e', 'w', 'e', 'r', 'e', 'd', '\n',
        's', 'k', 'e', 'w', 'e', 'r', 's', '\n',
        's', 'k', 'e', 'w', 'n', 'e', 's', 's', '\n',
        's', 'k', 'e', 'w', 's', '\n',
        's', 'k', 'i', '\n',
        's', 'k', 'i', 'd', '\n',
        's', 'k', 'i', 'd', 'd', 'e', 'd', '\n',
        's', 'k', 'i', 'd', 'd', 'i', 'n', 'g', '\n',
        's', 'k', 'i', 'd', 's', '\n',
        's', 'k', 'i', 'e', 'd', '\n',
        's', 'k', 'i', 'e', 'r', '\n',
        's', 'k', 'i', 'e', 'r', 's', '\n',
        's', 'k', 'i', 'e', 's', '\n',
        's', 'k', 'i', 'i', 'n', 'g', '\n',
        's', 'k', 'i', 'l', 'f', 'u', 'l', '\n',
        's', 'k', 'i', 'l', 'f', 'u', 'l', 'l', 'y', '\n',
        's', 'k', 'i', 'l', 'l', '\n',
        's', 'k', 'i', 'l', 'l', 'e', 'd', '\n',
        's', 'k', 'i', 'l', 'l', 'e', 't', '\n',
        's', 'k', 'i', 'l', 'l', 'f', 'u', 'l', '\n',
        's', 'k', 'i', 'l', 'l', 's', '\n',
        's', 'k', 'i', 'm', '\n',
        's', 'k', 'i', 'm', 'm', 'e', 'd', '\n',
        's', 'k', 'i', 'm', 'm', 'e', 'r', '\n',
        's', 'k', 'i', 'm', 'm', 'i', 'n', 'g', '\n',
        's', 'k', 'i', 'm', 'p', '\n',
        's', 'k', 'i', 'm', 'p', 'e', 'd', '\n',
        's', 'k', 'i', 'm', 'p', 'i', 'n', 'g', '\n',
        's', 'k', 'i', 'm', 'p', 'y', '\n',
        's', 'k', 'i', 'm', 's', '\n',
        's', 'k', 'i', 'n', '\n',
        's', 'k', 'i', 'n', 'c', 'a', 'r', 'e', '\n',
        's', 'k', 'i', 'n', 'd', 'e', 'e', 'p', '\n',
        's', 'k', 'i', 'n', 'f', 'l', 'i', 'n', 't', '\n',
        's', 'k', 'i', 'n', 'h', 'e', 'a', 'd', '\n',
        's', 'k', 'i', 'n', 'h', 'e', 'a', 'd', 's', '\n',
        's', 'k', 'i', 'n', 'l', 'e', 's', 's', '\n',
        's', 'k', 'i', 'n', 'n', 'e', 'd', '\n',
        's', 'k', 'i', 'n', 'n', 'e', 'r', '\n',
        's', 'k', 'i', 'n', 'n', 'e', 'r', 's', '\n',
        's', 'k', 'i', 'n', 'n', 'i', 'e', 'r', '\n',
        's', 'k', 'i', 'n', 'n', 'i', 'e', 's', 't', '\n',
        's', 'k', 'i', 'n', 'n', 'i', 'n', 'g', '\n',
        's', 'k', 'i', 'n', 'n', 'y', '\n',
        's', 'k', 'i', 'n', 's', '\n',
        's', 'k', 'i', 'n', 't', 'i', 'g', 'h', 't', '\n',
        's', 'k', 'i', 'p', '\n',
        's', 'k', 'i', 'p', 'p', 'e', 'd', '\n',
        's', 'k', 'i', 'p', 'p', 'e', 'r', '\n',
        's', 'k', 'i', 'p', 'p', 'e', 'r', 'e', 'd', '\n',
        's', 'k', 'i', 'p', 'p', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'k', 'i', 'p', 'p', 'e', 'r', 's', '\n',
        's', 'k', 'i', 'p', 'p', 'i', 'n', 'g', '\n',
        's', 'k', 'i', 'p', 's', '\n',
        's', 'k', 'i', 'r', 'l', '\n',
        's', 'k', 'i', 'r', 'm', 'i', 's', 'h', '\n',
        's', 'k', 'i', 'r', 'm', 'i', 's', 'h', 'e', 's', '\n',
        's', 'k', 'i', 'r', 'm', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        's', 'k', 'i', 'r', 't', '\n',
        's', 'k', 'i', 'r', 't', 'e', 'd', '\n',
        's', 'k', 'i', 'r', 't', 'i', 'n', 'g', '\n',
        's', 'k', 'i', 'r', 't', 's', '\n',
        's', 'k', 'i', 's', '\n',
        's', 'k', 'i', 't', '\n',
        's', 'k', 'i', 't', 's', '\n',
        's', 'k', 'i', 't', 't', 'i', 's', 'h', '\n',
        's', 'k', 'i', 't', 't', 'i', 's', 'h', 'l', 'y', '\n',
        's', 'k', 'i', 't', 't', 'i', 's', 'h', 'n', 'e', 's', 's', '\n',
        's', 'k', 'i', 't', 't', 'l', 'e', '\n',
        's', 'k', 'i', 't', 't', 'l', 'e', 's', '\n',
        's', 'k', 'u', 'a', '\n',
        's', 'k', 'u', 'a', 's', '\n',
        's', 'k', 'u', 'l', 'd', 'u', 'g', 'g', 'e', 'r', 'y', '\n',
        's', 'k', 'u', 'l', 'k', '\n',
        's', 'k', 'u', 'l', 'k', 'e', 'd', '\n',
        's', 'k', 'u', 'l', 'k', 'i', 'n', 'g', '\n',
        's', 'k', 'u', 'l', 'k', 's', '\n',
        's', 'k', 'u', 'l', 'l', '\n',
        's', 'k', 'u', 'l', 'l', 'c', 'a', 'p', '\n',
        's', 'k', 'u', 'l', 'l', 'd', 'u', 'g', 'g', 'e', 'r', 'y', '\n',
        's', 'k', 'u', 'l', 'l', 's', '\n',
        's', 'k', 'u', 'n', 'k', '\n',
        's', 'k', 'u', 'n', 'k', 's', '\n',
        's', 'k', 'y', '\n',
        's', 'k', 'y', 'd', 'i', 'v', 'e', '\n',
        's', 'k', 'y', 'd', 'i', 'v', 'e', 'd', '\n',
        's', 'k', 'y', 'd', 'i', 'v', 'e', 'r', '\n',
        's', 'k', 'y', 'd', 'i', 'v', 'e', 'r', 's', '\n',
        's', 'k', 'y', 'd', 'i', 'v', 'e', 's', '\n',
        's', 'k', 'y', 'd', 'i', 'v', 'i', 'n', 'g', '\n',
        's', 'k', 'y', 'h', 'i', 'g', 'h', '\n',
        's', 'k', 'y', 'l', 'a', 'r', 'k', '\n',
        's', 'k', 'y', 'l', 'a', 'r', 'k', 's', '\n',
        's', 'k', 'y', 'l', 'i', 'g', 'h', 't', '\n',
        's', 'k', 'y', 'l', 'i', 'g', 'h', 't', 's', '\n',
        's', 'k', 'y', 'l', 'i', 'n', 'e', '\n',
        's', 'k', 'y', 'l', 'i', 'n', 'e', 's', '\n',
        's', 'k', 'y', 's', 'c', 'a', 'p', 'e', '\n',
        's', 'k', 'y', 's', 'c', 'r', 'a', 'p', 'e', 'r', '\n',
        's', 'k', 'y', 's', 'c', 'r', 'a', 'p', 'e', 'r', 's', '\n',
        's', 'k', 'y', 'w', 'a', 'r', 'd', '\n',
        's', 'k', 'y', 'w', 'a', 'r', 'd', 's', '\n',
        's', 'l', 'a', 'b', '\n',
        's', 'l', 'a', 'b', 's', '\n',
        's', 'l', 'a', 'c', 'k', '\n',
        's', 'l', 'a', 'c', 'k', 'e', 'd', '\n',
        's', 'l', 'a', 'c', 'k', 'e', 'n', '\n',
        's', 'l', 'a', 'c', 'k', 'e', 'n', 'e', 'd', '\n',
        's', 'l', 'a', 'c', 'k', 'e', 'n', 'i', 'n', 'g', '\n',
        's', 'l', 'a', 'c', 'k', 'e', 'n', 's', '\n',
        's', 'l', 'a', 'c', 'k', 'e', 'r', '\n',
        's', 'l', 'a', 'c', 'k', 'e', 'r', 's', '\n',
        's', 'l', 'a', 'c', 'k', 'e', 's', 't', '\n',
        's', 'l', 'a', 'c', 'k', 'i', 'n', 'g', '\n',
        's', 'l', 'a', 'c', 'k', 'l', 'y', '\n',
        's', 'l', 'a', 'c', 'k', 'n', 'e', 's', 's', '\n',
        's', 'l', 'a', 'c', 'k', 's', '\n',
        's', 'l', 'a', 'g', '\n',
        's', 'l', 'a', 'g', 's', '\n',
        's', 'l', 'a', 'i', 'n', '\n',
        's', 'l', 'a', 'k', 'e', '\n',
        's', 'l', 'a', 'k', 'e', 'd', '\n',
        's', 'l', 'a', 'l', 'o', 'm', '\n',
        's', 'l', 'a', 'l', 'o', 'm', 's', '\n',
        's', 'l', 'a', 'm', '\n',
        's', 'l', 'a', 'm', 'm', 'e', 'd', '\n',
        's', 'l', 'a', 'm', 'm', 'i', 'n', 'g', '\n',
        's', 'l', 'a', 'm', 's', '\n',
        's', 'l', 'a', 'n', 'd', 'e', 'r', '\n',
        's', 'l', 'a', 'n', 'd', 'e', 'r', 'e', 'd', '\n',
        's', 'l', 'a', 'n', 'd', 'e', 'r', 'e', 'r', '\n',
        's', 'l', 'a', 'n', 'd', 'e', 'r', 'e', 'r', 's', '\n',
        's', 'l', 'a', 'n', 'd', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'l', 'a', 'n', 'd', 'e', 'r', 'o', 'u', 's', '\n',
        's', 'l', 'a', 'n', 'd', 'e', 'r', 's', '\n',
        's', 'l', 'a', 'n', 'g', '\n',
        's', 'l', 'a', 'n', 'g', 'i', 'n', 'g', '\n',
        's', 'l', 'a', 'n', 't', '\n',
        's', 'l', 'a', 'n', 't', 'e', 'd', '\n',
        's', 'l', 'a', 'n', 't', 'i', 'n', 'g', '\n',
        's', 'l', 'a', 'n', 't', 's', '\n',
        's', 'l', 'a', 'n', 't', 'w', 'i', 's', 'e', '\n',
        's', 'l', 'a', 'p', '\n',
        's', 'l', 'a', 'p', 'd', 'a', 's', 'h', '\n',
        's', 'l', 'a', 'p', 'p', 'e', 'd', '\n',
        's', 'l', 'a', 'p', 'p', 'e', 'r', '\n',
        's', 'l', 'a', 'p', 'p', 'i', 'n', 'g', '\n',
        's', 'l', 'a', 'p', 's', '\n',
        's', 'l', 'a', 'p', 's', 't', 'i', 'c', 'k', '\n',
        's', 'l', 'a', 's', 'h', '\n',
        's', 'l', 'a', 's', 'h', 'e', 'd', '\n',
        's', 'l', 'a', 's', 'h', 'e', 'r', '\n',
        's', 'l', 'a', 's', 'h', 'e', 's', '\n',
        's', 'l', 'a', 's', 'h', 'i', 'n', 'g', '\n',
        's', 'l', 'a', 't', '\n',
        's', 'l', 'a', 't', 'e', '\n',
        's', 'l', 'a', 't', 'e', 'd', '\n',
        's', 'l', 'a', 't', 'e', 'r', '\n',
        's', 'l', 'a', 't', 'e', 'r', 's', '\n',
        's', 'l', 'a', 't', 'e', 's', '\n',
        's', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        's', 'l', 'a', 't', 's', '\n',
        's', 'l', 'a', 't', 't', 'e', 'd', '\n',
        's', 'l', 'a', 'u', 'g', 'h', 't', 'e', 'r', '\n',
        's', 'l', 'a', 'u', 'g', 'h', 't', 'e', 'r', 'e', 'd', '\n',
        's', 'l', 'a', 'u', 'g', 'h', 't', 'e', 'r', 'e', 'r', '\n',
        's', 'l', 'a', 'u', 'g', 'h', 't', 'e', 'r', 'h', 'o', 'u', 's', 'e', '\n',
        's', 'l', 'a', 'u', 'g', 'h', 't', 'e', 'r', 'h', 'o', 'u', 's', 'e', 's', '\n',
        's', 'l', 'a', 'u', 'g', 'h', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'l', 'a', 'u', 'g', 'h', 't', 'e', 'r', 'i', 'n', 'g', 's', '\n',
        's', 'l', 'a', 'u', 'g', 'h', 't', 'e', 'r', 's', '\n',
        's', 'l', 'a', 'v', '\n',
        's', 'l', 'a', 'v', 'e', '\n',
        's', 'l', 'a', 'v', 'e', 'd', '\n',
        's', 'l', 'a', 'v', 'e', 'd', 'r', 'i', 'v', 'e', 'r', '\n',
        's', 'l', 'a', 'v', 'e', 'd', 'r', 'i', 'v', 'e', 'r', 's', '\n',
        's', 'l', 'a', 'v', 'e', 'r', '\n',
        's', 'l', 'a', 'v', 'e', 'r', 'e', 'd', '\n',
        's', 'l', 'a', 'v', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'l', 'a', 'v', 'e', 'r', 's', '\n',
        's', 'l', 'a', 'v', 'e', 'r', 'y', '\n',
        's', 'l', 'a', 'v', 'e', 's', '\n',
        's', 'l', 'a', 'v', 'i', 'c', '\n',
        's', 'l', 'a', 'v', 'i', 'n', 'g', '\n',
        's', 'l', 'a', 'v', 'i', 's', 'h', '\n',
        's', 'l', 'a', 'v', 'i', 's', 'h', 'l', 'y', '\n',
        's', 'l', 'a', 'v', 's', '\n',
        's', 'l', 'a', 'y', '\n',
        's', 'l', 'a', 'y', 'e', 'd', '\n',
        's', 'l', 'a', 'y', 'e', 'r', '\n',
        's', 'l', 'a', 'y', 'e', 'r', 's', '\n',
        's', 'l', 'a', 'y', 'i', 'n', 'g', '\n',
        's', 'l', 'a', 'y', 's', '\n',
        's', 'l', 'e', 'a', 'z', 'e', '\n',
        's', 'l', 'e', 'a', 'z', 'i', 'e', 'r', '\n',
        's', 'l', 'e', 'a', 'z', 'i', 'e', 's', 't', '\n',
        's', 'l', 'e', 'a', 'z', 'y', '\n',
        's', 'l', 'e', 'd', '\n',
        's', 'l', 'e', 'd', 'd', 'i', 'n', 'g', '\n',
        's', 'l', 'e', 'd', 'g', 'e', '\n',
        's', 'l', 'e', 'd', 'g', 'e', 'h', 'a', 'm', 'm', 'e', 'r', '\n',
        's', 'l', 'e', 'd', 'g', 'e', 'h', 'a', 'm', 'm', 'e', 'r', 's', '\n',
        's', 'l', 'e', 'd', 'g', 'e', 's', '\n',
        's', 'l', 'e', 'd', 'g', 'i', 'n', 'g', '\n',
        's', 'l', 'e', 'd', 's', '\n',
        's', 'l', 'e', 'e', 'k', '\n',
        's', 'l', 'e', 'e', 'k', 'e', 'r', '\n',
        's', 'l', 'e', 'e', 'k', 'l', 'y', '\n',
        's', 'l', 'e', 'e', 'k', 'n', 'e', 's', 's', '\n',
        's', 'l', 'e', 'e', 'k', 's', '\n',
        's', 'l', 'e', 'e', 'p', '\n',
        's', 'l', 'e', 'e', 'p', 'e', 'r', '\n',
        's', 'l', 'e', 'e', 'p', 'e', 'r', 's', '\n',
        's', 'l', 'e', 'e', 'p', 'i', 'e', 'r', '\n',
        's', 'l', 'e', 'e', 'p', 'i', 'e', 's', 't', '\n',
        's', 'l', 'e', 'e', 'p', 'i', 'l', 'y', '\n',
        's', 'l', 'e', 'e', 'p', 'i', 'n', 'e', 's', 's', '\n',
        's', 'l', 'e', 'e', 'p', 'i', 'n', 'g', '\n',
        's', 'l', 'e', 'e', 'p', 'l', 'e', 's', 's', '\n',
        's', 'l', 'e', 'e', 'p', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        's', 'l', 'e', 'e', 'p', 's', '\n',
        's', 'l', 'e', 'e', 'p', 'w', 'a', 'l', 'k', '\n',
        's', 'l', 'e', 'e', 'p', 'w', 'a', 'l', 'k', 'e', 'r', '\n',
        's', 'l', 'e', 'e', 'p', 'w', 'a', 'l', 'k', 'i', 'n', 'g', '\n',
        's', 'l', 'e', 'e', 'p', 'w', 'a', 'l', 'k', 's', '\n',
        's', 'l', 'e', 'e', 'p', 'y', '\n',
        's', 'l', 'e', 'e', 't', '\n',
        's', 'l', 'e', 'e', 't', 's', '\n',
        's', 'l', 'e', 'e', 'v', 'e', '\n',
        's', 'l', 'e', 'e', 'v', 'e', 'd', '\n',
        's', 'l', 'e', 'e', 'v', 'e', 'l', 'e', 's', 's', '\n',
        's', 'l', 'e', 'e', 'v', 'e', 's', '\n',
        's', 'l', 'e', 'i', 'g', 'h', '\n',
        's', 'l', 'e', 'i', 'g', 'h', 's', '\n',
        's', 'l', 'e', 'i', 'g', 'h', 't', '\n',
        's', 'l', 'e', 'i', 'g', 'h', 't', 's', '\n',
        's', 'l', 'e', 'n', 'd', 'e', 'r', '\n',
        's', 'l', 'e', 'n', 'd', 'e', 'r', 'e', 's', 't', '\n',
        's', 'l', 'e', 'n', 'd', 'e', 'r', 'l', 'y', '\n',
        's', 'l', 'e', 'n', 'd', 'e', 'r', 'n', 'e', 's', 's', '\n',
        's', 'l', 'e', 'p', 't', '\n',
        's', 'l', 'e', 'u', 't', 'h', '\n',
        's', 'l', 'e', 'u', 't', 'h', 's', '\n',
        's', 'l', 'e', 'w', '\n',
        's', 'l', 'e', 'w', 'e', 'd', '\n',
        's', 'l', 'e', 'w', 'i', 'n', 'g', '\n',
        's', 'l', 'i', 'c', 'e', '\n',
        's', 'l', 'i', 'c', 'e', 'd', '\n',
        's', 'l', 'i', 'c', 'e', 'r', '\n',
        's', 'l', 'i', 'c', 'e', 'r', 's', '\n',
        's', 'l', 'i', 'c', 'e', 's', '\n',
        's', 'l', 'i', 'c', 'i', 'n', 'g', '\n',
        's', 'l', 'i', 'c', 'i', 'n', 'g', 's', '\n',
        's', 'l', 'i', 'c', 'k', '\n',
        's', 'l', 'i', 'c', 'k', 'e', 'd', '\n',
        's', 'l', 'i', 'c', 'k', 'e', 'r', '\n',
        's', 'l', 'i', 'c', 'k', 'e', 's', 't', '\n',
        's', 'l', 'i', 'c', 'k', 'l', 'y', '\n',
        's', 'l', 'i', 'c', 'k', 'n', 'e', 's', 's', '\n',
        's', 'l', 'i', 'c', 'k', 's', '\n',
        's', 'l', 'i', 'd', '\n',
        's', 'l', 'i', 'd', 'e', '\n',
        's', 'l', 'i', 'd', 'e', 'd', '\n',
        's', 'l', 'i', 'd', 'e', 'r', '\n',
        's', 'l', 'i', 'd', 'e', 'r', 's', '\n',
        's', 'l', 'i', 'd', 'e', 's', '\n',
        's', 'l', 'i', 'd', 'i', 'n', 'g', '\n',
        's', 'l', 'i', 'g', 'h', 't', '\n',
        's', 'l', 'i', 'g', 'h', 't', 'e', 'd', '\n',
        's', 'l', 'i', 'g', 'h', 't', 'e', 'r', '\n',
        's', 'l', 'i', 'g', 'h', 't', 'e', 's', 't', '\n',
        's', 'l', 'i', 'g', 'h', 't', 'i', 'n', 'g', '\n',
        's', 'l', 'i', 'g', 'h', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        's', 'l', 'i', 'g', 'h', 't', 'l', 'y', '\n',
        's', 'l', 'i', 'g', 'h', 't', 's', '\n',
        's', 'l', 'i', 'l', 'y', '\n',
        's', 'l', 'i', 'm', '\n',
        's', 'l', 'i', 'm', 'e', '\n',
        's', 'l', 'i', 'm', 'e', 's', '\n',
        's', 'l', 'i', 'm', 'i', 'e', 'r', '\n',
        's', 'l', 'i', 'm', 'i', 'e', 's', 't', '\n',
        's', 'l', 'i', 'm', 'l', 'i', 'n', 'e', '\n',
        's', 'l', 'i', 'm', 'l', 'y', '\n',
        's', 'l', 'i', 'm', 'm', 'e', 'd', '\n',
        's', 'l', 'i', 'm', 'm', 'e', 'r', '\n',
        's', 'l', 'i', 'm', 'm', 'e', 'r', 's', '\n',
        's', 'l', 'i', 'm', 'm', 'e', 's', 't', '\n',
        's', 'l', 'i', 'm', 'm', 'i', 'n', 'g', '\n',
        's', 'l', 'i', 'm', 'n', 'e', 's', 's', '\n',
        's', 'l', 'i', 'm', 's', '\n',
        's', 'l', 'i', 'm', 'y', '\n',
        's', 'l', 'i', 'n', 'g', '\n',
        's', 'l', 'i', 'n', 'g', 'i', 'n', 'g', '\n',
        's', 'l', 'i', 'n', 'g', 's', '\n',
        's', 'l', 'i', 'n', 'g', 's', 'h', 'o', 't', '\n',
        's', 'l', 'i', 'n', 'k', '\n',
        's', 'l', 'i', 'n', 'k', 'i', 'n', 'g', '\n',
        's', 'l', 'i', 'n', 'k', 'y', '\n',
        's', 'l', 'i', 'p', '\n',
        's', 'l', 'i', 'p', 'p', 'a', 'g', 'e', '\n',
        's', 'l', 'i', 'p', 'p', 'e', 'd', '\n',
        's', 'l', 'i', 'p', 'p', 'e', 'r', '\n',
        's', 'l', 'i', 'p', 'p', 'e', 'r', 'i', 'n', 'e', 's', 's', '\n',
        's', 'l', 'i', 'p', 'p', 'e', 'r', 's', '\n',
        's', 'l', 'i', 'p', 'p', 'e', 'r', 'y', '\n',
        's', 'l', 'i', 'p', 'p', 'i', 'n', 'g', '\n',
        's', 'l', 'i', 'p', 's', '\n',
        's', 'l', 'i', 'p', 's', 'h', 'o', 'd', '\n',
        's', 'l', 'i', 'p', 's', 't', 'r', 'e', 'a', 'm', '\n',
        's', 'l', 'i', 'p', 'u', 'p', '\n',
        's', 'l', 'i', 'p', 'w', 'a', 'y', '\n',
        's', 'l', 'i', 't', '\n',
        's', 'l', 'i', 't', 'h', 'e', 'r', '\n',
        's', 'l', 'i', 't', 'h', 'e', 'r', 'e', 'd', '\n',
        's', 'l', 'i', 't', 'h', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'l', 'i', 't', 'h', 'e', 'r', 's', '\n',
        's', 'l', 'i', 't', 'h', 'e', 'r', 'y', '\n',
        's', 'l', 'i', 't', 's', '\n',
        's', 'l', 'i', 't', 't', 'i', 'n', 'g', '\n',
        's', 'l', 'i', 'v', 'e', 'r', '\n',
        's', 'l', 'i', 'v', 'e', 'r', 's', '\n',
        's', 'l', 'o', 'b', '\n',
        's', 'l', 'o', 'b', 'b', 'e', 'r', '\n',
        's', 'l', 'o', 'b', 'b', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'l', 'o', 'b', 'b', 'e', 'r', 's', '\n',
        's', 'l', 'o', 'b', 'b', 'e', 'r', 'y', '\n',
        's', 'l', 'o', 'b', 's', '\n',
        's', 'l', 'o', 'g', '\n',
        's', 'l', 'o', 'g', 'a', 'n', '\n',
        's', 'l', 'o', 'g', 'a', 'n', 's', '\n',
        's', 'l', 'o', 'g', 'g', 'e', 'd', '\n',
        's', 'l', 'o', 'g', 'g', 'i', 'n', 'g', '\n',
        's', 'l', 'o', 'g', 's', '\n',
        's', 'l', 'o', 'o', 'p', '\n',
        's', 'l', 'o', 'p', '\n',
        's', 'l', 'o', 'p', 'e', '\n',
        's', 'l', 'o', 'p', 'e', 'd', '\n',
        's', 'l', 'o', 'p', 'e', 's', '\n',
        's', 'l', 'o', 'p', 'i', 'n', 'g', '\n',
        's', 'l', 'o', 'p', 'p', 'e', 'd', '\n',
        's', 'l', 'o', 'p', 'p', 'i', 'e', 'r', '\n',
        's', 'l', 'o', 'p', 'p', 'i', 'e', 's', 't', '\n',
        's', 'l', 'o', 'p', 'p', 'i', 'l', 'y', '\n',
        's', 'l', 'o', 'p', 'p', 'i', 'n', 'e', 's', 's', '\n',
        's', 'l', 'o', 'p', 'p', 'i', 'n', 'g', '\n',
        's', 'l', 'o', 'p', 'p', 'y', '\n',
        's', 'l', 'o', 'p', 's', '\n',
        's', 'l', 'o', 's', 'h', '\n',
        's', 'l', 'o', 's', 'h', 'e', 'd', '\n',
        's', 'l', 'o', 's', 'h', 'i', 'n', 'g', '\n',
        's', 'l', 'o', 't', '\n',
        's', 'l', 'o', 't', 'h', '\n',
        's', 'l', 'o', 't', 'h', 'f', 'u', 'l', '\n',
        's', 'l', 'o', 't', 'h', 's', '\n',
        's', 'l', 'o', 't', 's', '\n',
        's', 'l', 'o', 't', 't', 'e', 'd', '\n',
        's', 'l', 'o', 't', 't', 'i', 'n', 'g', '\n',
        's', 'l', 'o', 'u', 'c', 'h', '\n',
        's', 'l', 'o', 'u', 'c', 'h', 'e', 'd', '\n',
        's', 'l', 'o', 'u', 'c', 'h', 'e', 's', '\n',
        's', 'l', 'o', 'u', 'c', 'h', 'i', 'n', 'g', '\n',
        's', 'l', 'o', 'u', 'g', 'h', '\n',
        's', 'l', 'o', 'u', 'g', 'h', 'e', 'd', '\n',
        's', 'l', 'o', 'u', 'g', 'h', 'i', 'n', 'g', '\n',
        's', 'l', 'o', 'v', 'a', 'k', '\n',
        's', 'l', 'o', 'v', 'e', 'n', 'i', 'a', '\n',
        's', 'l', 'o', 'v', 'e', 'n', 'l', 'i', 'n', 'e', 's', 's', '\n',
        's', 'l', 'o', 'v', 'e', 'n', 'l', 'y', '\n',
        's', 'l', 'o', 'w', '\n',
        's', 'l', 'o', 'w', 'c', 'o', 'a', 'c', 'h', 'e', 's', '\n',
        's', 'l', 'o', 'w', 'd', 'o', 'w', 'n', '\n',
        's', 'l', 'o', 'w', 'e', 'd', '\n',
        's', 'l', 'o', 'w', 'e', 'r', '\n',
        's', 'l', 'o', 'w', 'e', 's', 't', '\n',
        's', 'l', 'o', 'w', 'i', 'n', 'g', '\n',
        's', 'l', 'o', 'w', 'i', 's', 'h', '\n',
        's', 'l', 'o', 'w', 'l', 'y', '\n',
        's', 'l', 'o', 'w', 'n', 'e', 's', 's', '\n',
        's', 'l', 'o', 'w', 'p', 'o', 'k', 'e', '\n',
        's', 'l', 'o', 'w', 's', '\n',
        's', 'l', 'u', 'd', 'g', 'e', '\n',
        's', 'l', 'u', 'd', 'g', 'y', '\n',
        's', 'l', 'u', 'g', '\n',
        's', 'l', 'u', 'g', 'g', 'a', 'r', 'd', '\n',
        's', 'l', 'u', 'g', 'g', 'a', 'r', 'd', 's', '\n',
        's', 'l', 'u', 'g', 'g', 'e', 'd', '\n',
        's', 'l', 'u', 'g', 'g', 'i', 'n', 'g', '\n',
        's', 'l', 'u', 'g', 'g', 'i', 's', 'h', '\n',
        's', 'l', 'u', 'g', 'g', 'i', 's', 'h', 'l', 'y', '\n',
        's', 'l', 'u', 'g', 'g', 'i', 's', 'h', 'n', 'e', 's', 's', '\n',
        's', 'l', 'u', 'g', 's', '\n',
        's', 'l', 'u', 'i', 'c', 'e', '\n',
        's', 'l', 'u', 'i', 'c', 'e', 'd', '\n',
        's', 'l', 'u', 'i', 'c', 'e', 's', '\n',
        's', 'l', 'u', 'i', 'c', 'i', 'n', 'g', '\n',
        's', 'l', 'u', 'm', '\n',
        's', 'l', 'u', 'm', 'b', 'e', 'r', '\n',
        's', 'l', 'u', 'm', 'b', 'e', 'r', 'e', 'd', '\n',
        's', 'l', 'u', 'm', 'b', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'l', 'u', 'm', 'b', 'e', 'r', 's', '\n',
        's', 'l', 'u', 'm', 'm', 'i', 'n', 'g', '\n',
        's', 'l', 'u', 'm', 'p', '\n',
        's', 'l', 'u', 'm', 'p', 'e', 'd', '\n',
        's', 'l', 'u', 'm', 'p', 'i', 'n', 'g', '\n',
        's', 'l', 'u', 'm', 'p', 's', '\n',
        's', 'l', 'u', 'm', 's', '\n',
        's', 'l', 'u', 'n', 'g', '\n',
        's', 'l', 'u', 'n', 'k', '\n',
        's', 'l', 'u', 'r', '\n',
        's', 'l', 'u', 'r', 'p', '\n',
        's', 'l', 'u', 'r', 'p', 'e', 'd', '\n',
        's', 'l', 'u', 'r', 'p', 'i', 'n', 'g', '\n',
        's', 'l', 'u', 'r', 'p', 's', '\n',
        's', 'l', 'u', 'r', 'r', 'e', 'd', '\n',
        's', 'l', 'u', 'r', 'r', 'i', 'n', 'g', '\n',
        's', 'l', 'u', 'r', 'r', 'y', '\n',
        's', 'l', 'u', 'r', 's', '\n',
        's', 'l', 'u', 's', 'h', '\n',
        's', 'l', 'u', 's', 'h', 'e', 'd', '\n',
        's', 'l', 'u', 's', 'h', 'e', 's', '\n',
        's', 'l', 'u', 's', 'h', 'i', 'e', 'r', '\n',
        's', 'l', 'u', 's', 'h', 'i', 'e', 's', 't', '\n',
        's', 'l', 'u', 's', 'h', 'y', '\n',
        's', 'l', 'u', 't', '\n',
        's', 'l', 'u', 't', 's', '\n',
        's', 'l', 'y', '\n',
        's', 'l', 'y', 'e', 'r', '\n',
        's', 'l', 'y', 'l', 'y', '\n',
        's', 'l', 'y', 'n', 'e', 's', 's', '\n',
        's', 'm', 'a', 'c', 'k', '\n',
        's', 'm', 'a', 'c', 'k', 'e', 'd', '\n',
        's', 'm', 'a', 'c', 'k', 'e', 'r', '\n',
        's', 'm', 'a', 'c', 'k', 'i', 'n', 'g', '\n',
        's', 'm', 'a', 'c', 'k', 's', '\n',
        's', 'm', 'a', 'l', 'l', '\n',
        's', 'm', 'a', 'l', 'l', 'e', 'r', '\n',
        's', 'm', 'a', 'l', 'l', 'e', 's', 't', '\n',
        's', 'm', 'a', 'l', 'l', 'h', 'o', 'l', 'd', 'e', 'r', '\n',
        's', 'm', 'a', 'l', 'l', 'h', 'o', 'l', 'd', 'e', 'r', 's', '\n',
        's', 'm', 'a', 'l', 'l', 'h', 'o', 'l', 'd', 'i', 'n', 'g', '\n',
        's', 'm', 'a', 'l', 'l', 'h', 'o', 'l', 'd', 'i', 'n', 'g', 's', '\n',
        's', 'm', 'a', 'l', 'l', 'i', 's', 'h', '\n',
        's', 'm', 'a', 'l', 'l', 'm', 'i', 'n', 'd', 'e', 'd', '\n',
        's', 'm', 'a', 'l', 'l', 'm', 'i', 'n', 'd', 'e', 'd', 'n', 'e', 's', 's', '\n',
        's', 'm', 'a', 'l', 'l', 'n', 'e', 's', 's', '\n',
        's', 'm', 'a', 'l', 'l', 'p', 'o', 'x', '\n',
        's', 'm', 'a', 'l', 'l', 's', '\n',
        's', 'm', 'a', 'l', 'l', 's', 'c', 'a', 'l', 'e', '\n',
        's', 'm', 'a', 'l', 'l', 't', 'a', 'l', 'k', '\n',
        's', 'm', 'a', 'l', 'l', 't', 'i', 'm', 'e', '\n',
        's', 'm', 'a', 'l', 'l', 't', 'o', 'w', 'n', '\n',
        's', 'm', 'a', 'r', 't', '\n',
        's', 'm', 'a', 'r', 't', 'e', 'd', '\n',
        's', 'm', 'a', 'r', 't', 'e', 'n', '\n',
        's', 'm', 'a', 'r', 't', 'e', 'n', 'e', 'd', '\n',
        's', 'm', 'a', 'r', 't', 'e', 'n', 'i', 'n', 'g', '\n',
        's', 'm', 'a', 'r', 't', 'e', 'r', '\n',
        's', 'm', 'a', 'r', 't', 'e', 's', 't', '\n',
        's', 'm', 'a', 'r', 't', 'i', 'n', 'g', '\n',
        's', 'm', 'a', 'r', 't', 'l', 'y', '\n',
        's', 'm', 'a', 'r', 't', 'n', 'e', 's', 's', '\n',
        's', 'm', 'a', 'r', 't', 's', '\n',
        's', 'm', 'a', 's', 'h', '\n',
        's', 'm', 'a', 's', 'h', 'e', 'd', '\n',
        's', 'm', 'a', 's', 'h', 'e', 'r', '\n',
        's', 'm', 'a', 's', 'h', 'e', 's', '\n',
        's', 'm', 'a', 's', 'h', 'i', 'n', 'g', '\n',
        's', 'm', 'a', 't', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'm', 'a', 't', 't', 'e', 'r', 'i', 'n', 'g', 's', '\n',
        's', 'm', 'e', 'a', 'r', '\n',
        's', 'm', 'e', 'a', 'r', 'e', 'd', '\n',
        's', 'm', 'e', 'a', 'r', 'i', 'n', 'g', '\n',
        's', 'm', 'e', 'a', 'r', 's', '\n',
        's', 'm', 'e', 'g', 'm', 'a', '\n',
        's', 'm', 'e', 'l', 'l', '\n',
        's', 'm', 'e', 'l', 'l', 'a', 'b', 'l', 'e', '\n',
        's', 'm', 'e', 'l', 'l', 'e', 'd', '\n',
        's', 'm', 'e', 'l', 'l', 'i', 'e', 'r', '\n',
        's', 'm', 'e', 'l', 'l', 'i', 'e', 's', 't', '\n',
        's', 'm', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        's', 'm', 'e', 'l', 'l', 's', '\n',
        's', 'm', 'e', 'l', 'l', 'y', '\n',
        's', 'm', 'e', 'l', 't', '\n',
        's', 'm', 'e', 'l', 't', 'e', 'd', '\n',
        's', 'm', 'e', 'l', 't', 'e', 'r', '\n',
        's', 'm', 'e', 'l', 't', 'e', 'r', 's', '\n',
        's', 'm', 'e', 'l', 't', 'i', 'n', 'g', '\n',
        's', 'm', 'i', 'd', 'g', 'e', 'o', 'n', '\n',
        's', 'm', 'i', 'l', 'e', '\n',
        's', 'm', 'i', 'l', 'e', 'd', '\n',
        's', 'm', 'i', 'l', 'e', 'r', '\n',
        's', 'm', 'i', 'l', 'e', 'r', 's', '\n',
        's', 'm', 'i', 'l', 'e', 's', '\n',
        's', 'm', 'i', 'l', 'i', 'n', 'g', '\n',
        's', 'm', 'i', 'l', 'i', 'n', 'g', 'l', 'y', '\n',
        's', 'm', 'i', 'r', 'k', '\n',
        's', 'm', 'i', 'r', 'k', 'e', 'd', '\n',
        's', 'm', 'i', 'r', 'k', 'i', 'n', 'g', '\n',
        's', 'm', 'i', 'r', 'k', 's', '\n',
        's', 'm', 'i', 't', 'e', '\n',
        's', 'm', 'i', 't', 'h', '\n',
        's', 'm', 'i', 't', 'h', 'e', 'r', 'e', 'e', 'n', 's', '\n',
        's', 'm', 'i', 't', 'h', 's', '\n',
        's', 'm', 'i', 't', 'h', 'y', '\n',
        's', 'm', 'i', 't', 'i', 'n', 'g', '\n',
        's', 'm', 'i', 't', 't', 'e', 'n', '\n',
        's', 'm', 'o', 'c', 'k', '\n',
        's', 'm', 'o', 'c', 'k', 's', '\n',
        's', 'm', 'o', 'g', '\n',
        's', 'm', 'o', 'g', 'g', 'y', '\n',
        's', 'm', 'o', 'g', 's', '\n',
        's', 'm', 'o', 'k', 'e', '\n',
        's', 'm', 'o', 'k', 'e', 'd', '\n',
        's', 'm', 'o', 'k', 'e', 'l', 'e', 's', 's', '\n',
        's', 'm', 'o', 'k', 'e', 'r', '\n',
        's', 'm', 'o', 'k', 'e', 'r', 's', '\n',
        's', 'm', 'o', 'k', 'e', 's', '\n',
        's', 'm', 'o', 'k', 'e', 's', 'c', 'r', 'e', 'e', 'n', '\n',
        's', 'm', 'o', 'k', 'e', 's', 't', 'a', 'c', 'k', '\n',
        's', 'm', 'o', 'k', 'e', 's', 't', 'a', 'c', 'k', 's', '\n',
        's', 'm', 'o', 'k', 'i', 'e', 'r', '\n',
        's', 'm', 'o', 'k', 'i', 'e', 's', 't', '\n',
        's', 'm', 'o', 'k', 'i', 'n', 'e', 's', 's', '\n',
        's', 'm', 'o', 'k', 'i', 'n', 'g', '\n',
        's', 'm', 'o', 'k', 'y', '\n',
        's', 'm', 'o', 'l', 'd', 'e', 'r', '\n',
        's', 'm', 'o', 'o', 'c', 'h', '\n',
        's', 'm', 'o', 'o', 't', 'h', '\n',
        's', 'm', 'o', 'o', 't', 'h', 'e', 'd', '\n',
        's', 'm', 'o', 'o', 't', 'h', 'e', 'r', '\n',
        's', 'm', 'o', 'o', 't', 'h', 'e', 's', 't', '\n',
        's', 'm', 'o', 'o', 't', 'h', 'i', 'n', 'g', '\n',
        's', 'm', 'o', 'o', 't', 'h', 'l', 'y', '\n',
        's', 'm', 'o', 'o', 't', 'h', 'n', 'e', 's', 's', '\n',
        's', 'm', 'o', 'o', 't', 'h', 's', '\n',
        's', 'm', 'o', 'o', 't', 'h', 't', 'o', 'n', 'g', 'u', 'e', 'd', '\n',
        's', 'm', 'o', 't', 'e', '\n',
        's', 'm', 'o', 't', 'h', 'e', 'r', '\n',
        's', 'm', 'o', 't', 'h', 'e', 'r', 'e', 'd', '\n',
        's', 'm', 'o', 't', 'h', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'm', 'o', 't', 'h', 'e', 'r', 's', '\n',
        's', 'm', 'o', 'u', 'l', 'd', 'e', 'r', '\n',
        's', 'm', 'o', 'u', 'l', 'd', 'e', 'r', 'e', 'd', '\n',
        's', 'm', 'o', 'u', 'l', 'd', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'm', 'o', 'u', 'l', 'd', 'e', 'r', 's', '\n',
        's', 'm', 'u', 'd', 'g', 'e', '\n',
        's', 'm', 'u', 'd', 'g', 'e', 'd', '\n',
        's', 'm', 'u', 'd', 'g', 'e', 's', '\n',
        's', 'm', 'u', 'd', 'g', 'i', 'e', 'r', '\n',
        's', 'm', 'u', 'd', 'g', 'i', 'e', 's', 't', '\n',
        's', 'm', 'u', 'd', 'g', 'i', 'n', 'g', '\n',
        's', 'm', 'u', 'd', 'g', 'y', '\n',
        's', 'm', 'u', 'g', '\n',
        's', 'm', 'u', 'g', 'g', 'l', 'e', '\n',
        's', 'm', 'u', 'g', 'g', 'l', 'e', 'd', '\n',
        's', 'm', 'u', 'g', 'g', 'l', 'e', 'r', '\n',
        's', 'm', 'u', 'g', 'g', 'l', 'e', 'r', 's', '\n',
        's', 'm', 'u', 'g', 'g', 'l', 'e', 's', '\n',
        's', 'm', 'u', 'g', 'g', 'l', 'i', 'n', 'g', '\n',
        's', 'm', 'u', 'g', 'l', 'y', '\n',
        's', 'm', 'u', 'g', 'n', 'e', 's', 's', '\n',
        's', 'm', 'u', 't', '\n',
        's', 'm', 'u', 't', 's', '\n',
        's', 'm', 'u', 't', 't', 'y', '\n',
        's', 'n', 'a', 'c', 'k', '\n',
        's', 'n', 'a', 'c', 'k', 's', '\n',
        's', 'n', 'a', 'f', 'f', 'l', 'e', '\n',
        's', 'n', 'a', 'g', '\n',
        's', 'n', 'a', 'g', 'g', 'e', 'd', '\n',
        's', 'n', 'a', 'g', 'g', 'i', 'n', 'g', '\n',
        's', 'n', 'a', 'g', 's', '\n',
        's', 'n', 'a', 'i', 'l', '\n',
        's', 'n', 'a', 'i', 'l', 's', '\n',
        's', 'n', 'a', 'k', 'e', '\n',
        's', 'n', 'a', 'k', 'e', 'd', '\n',
        's', 'n', 'a', 'k', 'e', 'p', 'i', 't', '\n',
        's', 'n', 'a', 'k', 'e', 's', '\n',
        's', 'n', 'a', 'k', 'e', 's', 'k', 'i', 'n', '\n',
        's', 'n', 'a', 'k', 'i', 'n', 'g', '\n',
        's', 'n', 'a', 'k', 'y', '\n',
        's', 'n', 'a', 'p', '\n',
        's', 'n', 'a', 'p', 'p', 'e', 'd', '\n',
        's', 'n', 'a', 'p', 'p', 'e', 'r', '\n',
        's', 'n', 'a', 'p', 'p', 'i', 'e', 'r', '\n',
        's', 'n', 'a', 'p', 'p', 'i', 'l', 'y', '\n',
        's', 'n', 'a', 'p', 'p', 'i', 'n', 'g', '\n',
        's', 'n', 'a', 'p', 'p', 'y', '\n',
        's', 'n', 'a', 'p', 's', '\n',
        's', 'n', 'a', 'p', 's', 'h', 'o', 't', '\n',
        's', 'n', 'a', 'p', 's', 'h', 'o', 't', 's', '\n',
        's', 'n', 'a', 'r', 'e', '\n',
        's', 'n', 'a', 'r', 'e', 'd', '\n',
        's', 'n', 'a', 'r', 'e', 's', '\n',
        's', 'n', 'a', 'r', 'i', 'n', 'g', '\n',
        's', 'n', 'a', 'r', 'l', '\n',
        's', 'n', 'a', 'r', 'l', 'e', 'd', '\n',
        's', 'n', 'a', 'r', 'l', 'i', 'n', 'g', '\n',
        's', 'n', 'a', 'r', 'l', 's', '\n',
        's', 'n', 'a', 't', 'c', 'h', '\n',
        's', 'n', 'a', 't', 'c', 'h', 'e', 'd', '\n',
        's', 'n', 'a', 't', 'c', 'h', 'e', 'r', '\n',
        's', 'n', 'a', 't', 'c', 'h', 'e', 'r', 's', '\n',
        's', 'n', 'a', 't', 'c', 'h', 'e', 's', '\n',
        's', 'n', 'a', 't', 'c', 'h', 'i', 'n', 'g', '\n',
        's', 'n', 'e', 'a', 'k', '\n',
        's', 'n', 'e', 'a', 'k', 'e', 'd', '\n',
        's', 'n', 'e', 'a', 'k', 'e', 'r', 's', '\n',
        's', 'n', 'e', 'a', 'k', 'i', 'e', 'r', '\n',
        's', 'n', 'e', 'a', 'k', 'i', 'e', 's', 't', '\n',
        's', 'n', 'e', 'a', 'k', 'i', 'l', 'y', '\n',
        's', 'n', 'e', 'a', 'k', 'i', 'n', 'g', '\n',
        's', 'n', 'e', 'a', 'k', 's', '\n',
        's', 'n', 'e', 'a', 'k', 'y', '\n',
        's', 'n', 'e', 'e', 'r', '\n',
        's', 'n', 'e', 'e', 'r', 'e', 'd', '\n',
        's', 'n', 'e', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'n', 'e', 'e', 'r', 'i', 'n', 'g', 'l', 'y', '\n',
        's', 'n', 'e', 'e', 'r', 's', '\n',
        's', 'n', 'e', 'e', 'z', 'e', '\n',
        's', 'n', 'e', 'e', 'z', 'e', 'd', '\n',
        's', 'n', 'e', 'e', 'z', 'e', 's', '\n',
        's', 'n', 'e', 'e', 'z', 'i', 'n', 'g', '\n',
        's', 'n', 'i', 'c', 'k', '\n',
        's', 'n', 'i', 'd', 'e', '\n',
        's', 'n', 'i', 'f', 'f', '\n',
        's', 'n', 'i', 'f', 'f', 'e', 'd', '\n',
        's', 'n', 'i', 'f', 'f', 'e', 'r', '\n',
        's', 'n', 'i', 'f', 'f', 'e', 'r', 's', '\n',
        's', 'n', 'i', 'f', 'f', 'i', 'n', 'g', '\n',
        's', 'n', 'i', 'f', 'f', 'l', 'e', '\n',
        's', 'n', 'i', 'f', 'f', 'l', 'e', 's', '\n',
        's', 'n', 'i', 'f', 'f', 'l', 'i', 'n', 'g', '\n',
        's', 'n', 'i', 'f', 'f', 'l', 'y', '\n',
        's', 'n', 'i', 'f', 'f', 's', '\n',
        's', 'n', 'i', 'f', 't', 'e', 'r', '\n',
        's', 'n', 'i', 'g', 'g', 'e', 'r', '\n',
        's', 'n', 'i', 'g', 'g', 'e', 'r', 'e', 'd', '\n',
        's', 'n', 'i', 'g', 'g', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'n', 'i', 'g', 'g', 'e', 'r', 's', '\n',
        's', 'n', 'i', 'p', '\n',
        's', 'n', 'i', 'p', 'e', '\n',
        's', 'n', 'i', 'p', 'e', 'r', '\n',
        's', 'n', 'i', 'p', 'e', 'r', 's', '\n',
        's', 'n', 'i', 'p', 'e', 's', '\n',
        's', 'n', 'i', 'p', 'i', 'n', 'g', '\n',
        's', 'n', 'i', 'p', 'p', 'e', 'd', '\n',
        's', 'n', 'i', 'p', 'p', 'e', 't', '\n',
        's', 'n', 'i', 'p', 'p', 'e', 't', 's', '\n',
        's', 'n', 'i', 'p', 'p', 'i', 'n', 'g', '\n',
        's', 'n', 'i', 'p', 's', '\n',
        's', 'n', 'i', 't', 's', '\n',
        's', 'n', 'i', 'v', 'e', 'l', '\n',
        's', 'n', 'i', 'v', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        's', 'n', 'o', 'b', '\n',
        's', 'n', 'o', 'b', 'b', 'e', 'r', 'y', '\n',
        's', 'n', 'o', 'b', 'b', 'i', 's', 'h', '\n',
        's', 'n', 'o', 'b', 'b', 'i', 's', 'h', 'l', 'y', '\n',
        's', 'n', 'o', 'b', 'b', 'i', 's', 'h', 'n', 'e', 's', 's', '\n',
        's', 'n', 'o', 'b', 's', '\n',
        's', 'n', 'o', 'e', 'k', '\n',
        's', 'n', 'o', 'o', 'k', 'e', 'r', '\n',
        's', 'n', 'o', 'o', 'p', '\n',
        's', 'n', 'o', 'o', 'p', 'e', 'd', '\n',
        's', 'n', 'o', 'o', 'p', 'e', 'r', '\n',
        's', 'n', 'o', 'o', 'p', 'e', 'r', 's', '\n',
        's', 'n', 'o', 'o', 'p', 'i', 'n', 'g', '\n',
        's', 'n', 'o', 'o', 'p', 's', '\n',
        's', 'n', 'o', 'o', 'p', 'y', '\n',
        's', 'n', 'o', 'o', 'z', 'e', '\n',
        's', 'n', 'o', 'o', 'z', 'e', 'd', '\n',
        's', 'n', 'o', 'o', 'z', 'e', 's', '\n',
        's', 'n', 'o', 'o', 'z', 'i', 'n', 'g', '\n',
        's', 'n', 'o', 'r', 'e', '\n',
        's', 'n', 'o', 'r', 'e', 'd', '\n',
        's', 'n', 'o', 'r', 'e', 'r', '\n',
        's', 'n', 'o', 'r', 'e', 'r', 's', '\n',
        's', 'n', 'o', 'r', 'e', 's', '\n',
        's', 'n', 'o', 'r', 'i', 'n', 'g', '\n',
        's', 'n', 'o', 'r', 'k', 'e', 'l', '\n',
        's', 'n', 'o', 'r', 'k', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        's', 'n', 'o', 'r', 'k', 'e', 'l', 's', '\n',
        's', 'n', 'o', 'r', 't', '\n',
        's', 'n', 'o', 'r', 't', 'e', 'd', '\n',
        's', 'n', 'o', 'r', 't', 'i', 'n', 'g', '\n',
        's', 'n', 'o', 'r', 't', 's', '\n',
        's', 'n', 'o', 't', 't', 'y', '\n',
        's', 'n', 'o', 'u', 't', '\n',
        's', 'n', 'o', 'u', 't', 's', '\n',
        's', 'n', 'o', 'w', '\n',
        's', 'n', 'o', 'w', 'b', 'a', 'l', 'l', '\n',
        's', 'n', 'o', 'w', 'b', 'a', 'l', 'l', 'e', 'd', '\n',
        's', 'n', 'o', 'w', 'b', 'a', 'l', 'l', 'i', 'n', 'g', '\n',
        's', 'n', 'o', 'w', 'b', 'a', 'l', 'l', 's', '\n',
        's', 'n', 'o', 'w', 'b', 'o', 'u', 'n', 'd', '\n',
        's', 'n', 'o', 'w', 'c', 'a', 'p', 'p', 'e', 'd', '\n',
        's', 'n', 'o', 'w', 'd', 'r', 'i', 'f', 't', '\n',
        's', 'n', 'o', 'w', 'd', 'r', 'i', 'f', 't', 's', '\n',
        's', 'n', 'o', 'w', 'd', 'r', 'o', 'p', '\n',
        's', 'n', 'o', 'w', 'd', 'r', 'o', 'p', 's', '\n',
        's', 'n', 'o', 'w', 'e', 'd', '\n',
        's', 'n', 'o', 'w', 'f', 'a', 'l', 'l', '\n',
        's', 'n', 'o', 'w', 'f', 'a', 'l', 'l', 's', '\n',
        's', 'n', 'o', 'w', 'f', 'i', 'e', 'l', 'd', 's', '\n',
        's', 'n', 'o', 'w', 'f', 'l', 'a', 'k', 'e', '\n',
        's', 'n', 'o', 'w', 'f', 'l', 'a', 'k', 'e', 's', '\n',
        's', 'n', 'o', 'w', 'i', 'e', 'r', '\n',
        's', 'n', 'o', 'w', 'i', 'e', 's', 't', '\n',
        's', 'n', 'o', 'w', 'i', 'n', 'g', '\n',
        's', 'n', 'o', 'w', 'l', 'i', 'n', 'e', '\n',
        's', 'n', 'o', 'w', 'm', 'a', 'n', '\n',
        's', 'n', 'o', 'w', 'm', 'e', 'n', '\n',
        's', 'n', 'o', 'w', 'p', 'l', 'o', 'u', 'g', 'h', '\n',
        's', 'n', 'o', 'w', 'p', 'l', 'o', 'u', 'g', 'h', 's', '\n',
        's', 'n', 'o', 'w', 's', '\n',
        's', 'n', 'o', 'w', 's', 't', 'o', 'r', 'm', '\n',
        's', 'n', 'o', 'w', 's', 't', 'o', 'r', 'm', 's', '\n',
        's', 'n', 'o', 'w', 'w', 'h', 'i', 't', 'e', '\n',
        's', 'n', 'o', 'w', 'y', '\n',
        's', 'n', 'u', 'b', '\n',
        's', 'n', 'u', 'b', 'b', 'e', 'd', '\n',
        's', 'n', 'u', 'b', 'b', 'i', 'n', 'g', '\n',
        's', 'n', 'u', 'b', 'n', 'o', 's', 'e', 'd', '\n',
        's', 'n', 'u', 'b', 's', '\n',
        's', 'n', 'u', 'f', 'f', '\n',
        's', 'n', 'u', 'f', 'f', 'b', 'o', 'x', '\n',
        's', 'n', 'u', 'f', 'f', 'e', 'd', '\n',
        's', 'n', 'u', 'f', 'f', 'i', 'n', 'g', '\n',
        's', 'n', 'u', 'f', 'f', 'l', 'e', '\n',
        's', 'n', 'u', 'f', 'f', 'l', 'e', 'd', '\n',
        's', 'n', 'u', 'f', 'f', 'l', 'e', 's', '\n',
        's', 'n', 'u', 'f', 'f', 'l', 'i', 'n', 'g', '\n',
        's', 'n', 'u', 'f', 'f', 's', '\n',
        's', 'n', 'u', 'g', '\n',
        's', 'n', 'u', 'g', 'g', 'e', 'r', '\n',
        's', 'n', 'u', 'g', 'g', 'l', 'e', '\n',
        's', 'n', 'u', 'g', 'g', 'l', 'e', 'd', '\n',
        's', 'n', 'u', 'g', 'g', 'l', 'e', 's', '\n',
        's', 'n', 'u', 'g', 'g', 'l', 'i', 'n', 'g', '\n',
        's', 'n', 'u', 'g', 'l', 'y', '\n',
        's', 'n', 'u', 'g', 'n', 'e', 's', 's', '\n',
        's', 'o', '\n',
        's', 'o', 'a', 'k', '\n',
        's', 'o', 'a', 'k', 'e', 'd', '\n',
        's', 'o', 'a', 'k', 'e', 'r', '\n',
        's', 'o', 'a', 'k', 'e', 'r', 's', '\n',
        's', 'o', 'a', 'k', 'i', 'n', 'g', '\n',
        's', 'o', 'a', 'k', 'i', 'n', 'g', 's', '\n',
        's', 'o', 'a', 'k', 's', '\n',
        's', 'o', 'a', 'n', 'd', 's', 'o', '\n',
        's', 'o', 'a', 'p', '\n',
        's', 'o', 'a', 'p', 'b', 'o', 'x', '\n',
        's', 'o', 'a', 'p', 'e', 'd', '\n',
        's', 'o', 'a', 'p', 'i', 'e', 'r', '\n',
        's', 'o', 'a', 'p', 'i', 'e', 's', 't', '\n',
        's', 'o', 'a', 'p', 'i', 'n', 'g', '\n',
        's', 'o', 'a', 'p', 's', '\n',
        's', 'o', 'a', 'p', 'y', '\n',
        's', 'o', 'a', 'r', '\n',
        's', 'o', 'a', 'r', 'e', 'd', '\n',
        's', 'o', 'a', 'r', 'i', 'n', 'g', '\n',
        's', 'o', 'a', 'r', 'i', 'n', 'g', 'l', 'y', '\n',
        's', 'o', 'a', 'r', 's', '\n',
        's', 'o', 'b', '\n',
        's', 'o', 'b', 'b', 'e', 'd', '\n',
        's', 'o', 'b', 'b', 'i', 'n', 'g', '\n',
        's', 'o', 'b', 'b', 'i', 'n', 'g', 's', '\n',
        's', 'o', 'b', 'e', 'r', '\n',
        's', 'o', 'b', 'e', 'r', 'e', 'd', '\n',
        's', 'o', 'b', 'e', 'r', 'e', 'r', '\n',
        's', 'o', 'b', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'o', 'b', 'e', 'r', 'l', 'y', '\n',
        's', 'o', 'b', 'e', 'r', 's', '\n',
        's', 'o', 'b', 'r', 'i', 'e', 't', 'y', '\n',
        's', 'o', 'b', 'r', 'i', 'q', 'u', 'e', 't', '\n',
        's', 'o', 'b', 's', '\n',
        's', 'o', 'c', 'a', 'l', 'l', 'e', 'd', '\n',
        's', 'o', 'c', 'c', 'e', 'r', '\n',
        's', 'o', 'c', 'i', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        's', 'o', 'c', 'i', 'a', 'b', 'l', 'e', '\n',
        's', 'o', 'c', 'i', 'a', 'b', 'l', 'y', '\n',
        's', 'o', 'c', 'i', 'a', 'l', '\n',
        's', 'o', 'c', 'i', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'o', 'c', 'i', 'a', 'l', 'i', 's', 'e', '\n',
        's', 'o', 'c', 'i', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        's', 'o', 'c', 'i', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        's', 'o', 'c', 'i', 'a', 'l', 'i', 's', 'm', '\n',
        's', 'o', 'c', 'i', 'a', 'l', 'i', 's', 't', '\n',
        's', 'o', 'c', 'i', 'a', 'l', 'i', 's', 't', 'i', 'c', '\n',
        's', 'o', 'c', 'i', 'a', 'l', 'i', 's', 't', 's', '\n',
        's', 'o', 'c', 'i', 'a', 'l', 'i', 't', 'e', '\n',
        's', 'o', 'c', 'i', 'a', 'l', 'l', 'y', '\n',
        's', 'o', 'c', 'i', 'a', 'l', 's', '\n',
        's', 'o', 'c', 'i', 'e', 't', 'a', 'l', '\n',
        's', 'o', 'c', 'i', 'e', 't', 'i', 'e', 's', '\n',
        's', 'o', 'c', 'i', 'e', 't', 'y', '\n',
        's', 'o', 'c', 'i', 'o', 'b', 'i', 'o', 'l', 'o', 'g', 'y', '\n',
        's', 'o', 'c', 'i', 'o', 'c', 'u', 'l', 't', 'u', 'r', 'a', 'l', '\n',
        's', 'o', 'c', 'i', 'o', 'e', 'c', 'o', 'n', 'o', 'm', 'i', 'c', '\n',
        's', 'o', 'c', 'i', 'o', 'l', 'i', 'n', 'g', 'u', 'i', 's', 't', 'i', 'c', '\n',
        's', 'o', 'c', 'i', 'o', 'l', 'i', 'n', 'g', 'u', 'i', 's', 't', 'i', 'c', 's', '\n',
        's', 'o', 'c', 'i', 'o', 'l', 'i', 'n', 'g', 'u', 'i', 's', 't', 's', '\n',
        's', 'o', 'c', 'i', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        's', 'o', 'c', 'i', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 'o', 'c', 'i', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        's', 'o', 'c', 'i', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        's', 'o', 'c', 'i', 'o', 'l', 'o', 'g', 'y', '\n',
        's', 'o', 'c', 'i', 'o', 'p', 'o', 'l', 'i', 't', 'i', 'c', 'a', 'l', '\n',
        's', 'o', 'c', 'k', '\n',
        's', 'o', 'c', 'k', 'e', 'd', '\n',
        's', 'o', 'c', 'k', 'e', 't', '\n',
        's', 'o', 'c', 'k', 'e', 't', 's', '\n',
        's', 'o', 'c', 'k', 'i', 'n', 'g', '\n',
        's', 'o', 'c', 'k', 's', '\n',
        's', 'o', 'c', 'r', 'a', 't', 'e', 's', '\n',
        's', 'o', 'd', '\n',
        's', 'o', 'd', 'a', '\n',
        's', 'o', 'd', 'a', 's', '\n',
        's', 'o', 'd', 'd', 'e', 'd', '\n',
        's', 'o', 'd', 'd', 'e', 'n', '\n',
        's', 'o', 'd', 'd', 'y', '\n',
        's', 'o', 'd', 'i', 'u', 'm', '\n',
        's', 'o', 'd', 'o', 'm', '\n',
        's', 'o', 'd', 'o', 'm', 'i', 's', 'e', '\n',
        's', 'o', 'd', 'o', 'm', 'i', 's', 'e', 'd', '\n',
        's', 'o', 'd', 'o', 'm', 'i', 's', 'i', 'n', 'g', '\n',
        's', 'o', 'd', 'o', 'm', 'i', 't', 'e', '\n',
        's', 'o', 'd', 'o', 'm', 'i', 't', 'e', 's', '\n',
        's', 'o', 'd', 'o', 'm', 'y', '\n',
        's', 'o', 'd', 's', '\n',
        's', 'o', 'f', 'a', '\n',
        's', 'o', 'f', 'a', 's', '\n',
        's', 'o', 'f', 'f', 'i', 't', '\n',
        's', 'o', 'f', 't', '\n',
        's', 'o', 'f', 't', 'b', 'a', 'l', 'l', '\n',
        's', 'o', 'f', 't', 'b', 'o', 'i', 'l', 'e', 'd', '\n',
        's', 'o', 'f', 't', 'e', 'n', '\n',
        's', 'o', 'f', 't', 'e', 'n', 'e', 'd', '\n',
        's', 'o', 'f', 't', 'e', 'n', 'e', 'r', '\n',
        's', 'o', 'f', 't', 'e', 'n', 'e', 'r', 's', '\n',
        's', 'o', 'f', 't', 'e', 'n', 'i', 'n', 'g', '\n',
        's', 'o', 'f', 't', 'e', 'n', 's', '\n',
        's', 'o', 'f', 't', 'e', 'r', '\n',
        's', 'o', 'f', 't', 'e', 's', 't', '\n',
        's', 'o', 'f', 't', 'h', 'e', 'a', 'r', 't', 'e', 'd', '\n',
        's', 'o', 'f', 't', 'i', 'e', '\n',
        's', 'o', 'f', 't', 'i', 's', 'h', '\n',
        's', 'o', 'f', 't', 'l', 'y', '\n',
        's', 'o', 'f', 't', 'n', 'e', 's', 's', '\n',
        's', 'o', 'f', 't', 's', 'p', 'o', 'k', 'e', 'n', '\n',
        's', 'o', 'f', 't', 'w', 'a', 'r', 'e', '\n',
        's', 'o', 'f', 't', 'w', 'o', 'o', 'd', '\n',
        's', 'o', 'f', 't', 'y', '\n',
        's', 'o', 'g', 'g', 'i', 'e', 'r', '\n',
        's', 'o', 'g', 'g', 'i', 'e', 's', 't', '\n',
        's', 'o', 'g', 'g', 'y', '\n',
        's', 'o', 'h', '\n',
        's', 'o', 'i', 'l', '\n',
        's', 'o', 'i', 'l', 'e', 'd', '\n',
        's', 'o', 'i', 'l', 'i', 'n', 'g', '\n',
        's', 'o', 'i', 'l', 'i', 'n', 'g', 's', '\n',
        's', 'o', 'i', 'l', 's', '\n',
        's', 'o', 'i', 'r', 'e', 'e', '\n',
        's', 'o', 'j', 'o', 'u', 'r', 'n', '\n',
        's', 'o', 'j', 'o', 'u', 'r', 'n', 'e', 'd', '\n',
        's', 'o', 'j', 'o', 'u', 'r', 'n', 'e', 'r', '\n',
        's', 'o', 'j', 'o', 'u', 'r', 'n', 'e', 'r', 's', '\n',
        's', 'o', 'j', 'o', 'u', 'r', 'n', 'i', 'n', 'g', '\n',
        's', 'o', 'j', 'o', 'u', 'r', 'n', 's', '\n',
        's', 'o', 'l', 'a', 'c', 'e', '\n',
        's', 'o', 'l', 'a', 'c', 'e', 's', '\n',
        's', 'o', 'l', 'a', 'n', 'u', 'm', '\n',
        's', 'o', 'l', 'a', 'r', '\n',
        's', 'o', 'l', 'a', 'r', 'i', 'a', '\n',
        's', 'o', 'l', 'a', 'r', 'i', 'u', 'm', '\n',
        's', 'o', 'l', 'd', '\n',
        's', 'o', 'l', 'd', 'e', 'r', '\n',
        's', 'o', 'l', 'd', 'e', 'r', 'e', 'd', '\n',
        's', 'o', 'l', 'd', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'o', 'l', 'd', 'e', 'r', 's', '\n',
        's', 'o', 'l', 'd', 'i', 'e', 'r', '\n',
        's', 'o', 'l', 'd', 'i', 'e', 'r', 'e', 'd', '\n',
        's', 'o', 'l', 'd', 'i', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'o', 'l', 'd', 'i', 'e', 'r', 'l', 'y', '\n',
        's', 'o', 'l', 'd', 'i', 'e', 'r', 's', '\n',
        's', 'o', 'l', 'd', 'i', 'e', 'r', 'y', '\n',
        's', 'o', 'l', 'e', '\n',
        's', 'o', 'l', 'e', 'c', 'i', 's', 'm', '\n',
        's', 'o', 'l', 'e', 'c', 'i', 's', 'm', 's', '\n',
        's', 'o', 'l', 'e', 'l', 'y', '\n',
        's', 'o', 'l', 'e', 'm', 'n', '\n',
        's', 'o', 'l', 'e', 'm', 'n', 'i', 't', 'i', 'e', 's', '\n',
        's', 'o', 'l', 'e', 'm', 'n', 'i', 't', 'y', '\n',
        's', 'o', 'l', 'e', 'm', 'n', 'l', 'y', '\n',
        's', 'o', 'l', 'e', 'n', 'o', 'i', 'd', '\n',
        's', 'o', 'l', 'e', 'n', 'o', 'i', 'd', 'a', 'l', '\n',
        's', 'o', 'l', 'e', 'n', 'o', 'i', 'd', 's', '\n',
        's', 'o', 'l', 'e', 'r', '\n',
        's', 'o', 'l', 'e', 's', '\n',
        's', 'o', 'l', 'f', 'a', '\n',
        's', 'o', 'l', 'i', 'c', 'i', 't', '\n',
        's', 'o', 'l', 'i', 'c', 'i', 't', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'o', 'l', 'i', 'c', 'i', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        's', 'o', 'l', 'i', 'c', 'i', 't', 'e', 'd', '\n',
        's', 'o', 'l', 'i', 'c', 'i', 't', 'i', 'n', 'g', '\n',
        's', 'o', 'l', 'i', 'c', 'i', 't', 'o', 'r', '\n',
        's', 'o', 'l', 'i', 'c', 'i', 't', 'o', 'r', 's', '\n',
        's', 'o', 'l', 'i', 'c', 'i', 't', 'o', 'u', 's', '\n',
        's', 'o', 'l', 'i', 'c', 'i', 't', 'o', 'u', 's', 'l', 'y', '\n',
        's', 'o', 'l', 'i', 'c', 'i', 't', 's', '\n',
        's', 'o', 'l', 'i', 'c', 'i', 't', 'u', 'd', 'e', '\n',
        's', 'o', 'l', 'i', 'd', '\n',
        's', 'o', 'l', 'i', 'd', 'a', 'r', 'i', 't', 'y', '\n',
        's', 'o', 'l', 'i', 'd', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'o', 'l', 'i', 'd', 'i', 'f', 'i', 'e', 'd', '\n',
        's', 'o', 'l', 'i', 'd', 'i', 'f', 'i', 'e', 's', '\n',
        's', 'o', 'l', 'i', 'd', 'i', 'f', 'y', '\n',
        's', 'o', 'l', 'i', 'd', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        's', 'o', 'l', 'i', 'd', 'i', 't', 'y', '\n',
        's', 'o', 'l', 'i', 'd', 'l', 'y', '\n',
        's', 'o', 'l', 'i', 'd', 'n', 'e', 's', 's', '\n',
        's', 'o', 'l', 'i', 'd', 's', '\n',
        's', 'o', 'l', 'i', 't', 'a', 'i', 'r', 'e', '\n',
        's', 'o', 'l', 'i', 't', 'a', 'r', 'y', '\n',
        's', 'o', 'l', 'i', 't', 'u', 'd', 'e', '\n',
        's', 'o', 'l', 'i', 't', 'u', 'd', 'e', 's', '\n',
        's', 'o', 'l', 'o', '\n',
        's', 'o', 'l', 'o', 'i', 'n', 'g', '\n',
        's', 'o', 'l', 'o', 'i', 's', 't', '\n',
        's', 'o', 'l', 'o', 'i', 's', 't', 's', '\n',
        's', 'o', 'l', 's', 't', 'i', 'c', 'e', '\n',
        's', 'o', 'l', 's', 't', 'i', 'c', 'e', 's', '\n',
        's', 'o', 'l', 'u', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        's', 'o', 'l', 'u', 'b', 'l', 'e', '\n',
        's', 'o', 'l', 'u', 't', 'e', '\n',
        's', 'o', 'l', 'u', 't', 'e', 's', '\n',
        's', 'o', 'l', 'u', 't', 'i', 'o', 'n', '\n',
        's', 'o', 'l', 'u', 't', 'i', 'o', 'n', 's', '\n',
        's', 'o', 'l', 'v', 'a', 'b', 'l', 'e', '\n',
        's', 'o', 'l', 'v', 'e', '\n',
        's', 'o', 'l', 'v', 'e', 'd', '\n',
        's', 'o', 'l', 'v', 'e', 'n', 'c', 'y', '\n',
        's', 'o', 'l', 'v', 'e', 'n', 't', '\n',
        's', 'o', 'l', 'v', 'e', 'n', 't', 's', '\n',
        's', 'o', 'l', 'v', 'e', 'r', '\n',
        's', 'o', 'l', 'v', 'e', 'r', 's', '\n',
        's', 'o', 'l', 'v', 'e', 's', '\n',
        's', 'o', 'l', 'v', 'i', 'n', 'g', '\n',
        's', 'o', 'm', 'a', '\n',
        's', 'o', 'm', 'a', 'l', 'i', '\n',
        's', 'o', 'm', 'a', 'l', 'i', 'a', '\n',
        's', 'o', 'm', 'a', 's', '\n',
        's', 'o', 'm', 'a', 't', 'i', 'c', '\n',
        's', 'o', 'm', 'b', 'r', 'e', '\n',
        's', 'o', 'm', 'b', 'r', 'e', 'l', 'y', '\n',
        's', 'o', 'm', 'b', 'r', 'e', 'n', 'e', 's', 's', '\n',
        's', 'o', 'm', 'b', 'r', 'e', 'r', 'o', '\n',
        's', 'o', 'm', 'e', '\n',
        's', 'o', 'm', 'e', 'b', 'o', 'd', 'y', '\n',
        's', 'o', 'm', 'e', 'd', 'a', 'y', '\n',
        's', 'o', 'm', 'e', 'h', 'o', 'w', '\n',
        's', 'o', 'm', 'e', 'o', 'n', 'e', '\n',
        's', 'o', 'm', 'e', 'r', 's', 'a', 'u', 'l', 't', '\n',
        's', 'o', 'm', 'e', 'r', 's', 'a', 'u', 'l', 't', 'e', 'd', '\n',
        's', 'o', 'm', 'e', 'r', 's', 'a', 'u', 'l', 't', 'i', 'n', 'g', '\n',
        's', 'o', 'm', 'e', 'r', 's', 'a', 'u', 'l', 't', 's', '\n',
        's', 'o', 'm', 'e', 't', 'h', 'i', 'n', 'g', '\n',
        's', 'o', 'm', 'e', 't', 'i', 'm', 'e', '\n',
        's', 'o', 'm', 'e', 't', 'i', 'm', 'e', 's', '\n',
        's', 'o', 'm', 'e', 'w', 'a', 'y', '\n',
        's', 'o', 'm', 'e', 'w', 'a', 'y', 's', '\n',
        's', 'o', 'm', 'e', 'w', 'h', 'a', 't', '\n',
        's', 'o', 'm', 'e', 'w', 'h', 'e', 'r', 'e', '\n',
        's', 'o', 'm', 'n', 'a', 'm', 'b', 'u', 'l', 'i', 's', 't', '\n',
        's', 'o', 'm', 'n', 'o', 'l', 'e', 'n', 'c', 'e', '\n',
        's', 'o', 'm', 'n', 'o', 'l', 'e', 'n', 't', '\n',
        's', 'o', 'n', '\n',
        's', 'o', 'n', 'a', 'r', '\n',
        's', 'o', 'n', 'a', 'r', 's', '\n',
        's', 'o', 'n', 'a', 't', 'a', '\n',
        's', 'o', 'n', 'a', 't', 'a', 's', '\n',
        's', 'o', 'n', 'e', 's', '\n',
        's', 'o', 'n', 'g', '\n',
        's', 'o', 'n', 'g', 'b', 'i', 'r', 'd', '\n',
        's', 'o', 'n', 'g', 'b', 'i', 'r', 'd', 's', '\n',
        's', 'o', 'n', 'g', 'b', 'o', 'o', 'k', '\n',
        's', 'o', 'n', 'g', 's', '\n',
        's', 'o', 'n', 'g', 's', 't', 'e', 'r', 's', '\n',
        's', 'o', 'n', 'g', 'w', 'r', 'i', 't', 'e', 'r', '\n',
        's', 'o', 'n', 'g', 'w', 'r', 'i', 't', 'e', 'r', 's', '\n',
        's', 'o', 'n', 'g', 'w', 'r', 'i', 't', 'i', 'n', 'g', '\n',
        's', 'o', 'n', 'i', 'c', '\n',
        's', 'o', 'n', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 'o', 'n', 'i', 'n', 'l', 'a', 'w', '\n',
        's', 'o', 'n', 'n', 'e', 't', '\n',
        's', 'o', 'n', 'n', 'e', 't', 's', '\n',
        's', 'o', 'n', 'n', 'y', '\n',
        's', 'o', 'n', 'o', 'r', 'a', '\n',
        's', 'o', 'n', 'o', 'r', 'i', 't', 'i', 'e', 's', '\n',
        's', 'o', 'n', 'o', 'r', 'i', 't', 'y', '\n',
        's', 'o', 'n', 'o', 'r', 'o', 'u', 's', '\n',
        's', 'o', 'n', 'o', 'r', 'o', 'u', 's', 'l', 'y', '\n',
        's', 'o', 'n', 'o', 'r', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        's', 'o', 'n', 's', '\n',
        's', 'o', 'n', 's', 'i', 'n', 'l', 'a', 'w', '\n',
        's', 'o', 'o', 'n', '\n',
        's', 'o', 'o', 'n', 'e', 'r', '\n',
        's', 'o', 'o', 'n', 'e', 's', 't', '\n',
        's', 'o', 'o', 'n', 'i', 's', 'h', '\n',
        's', 'o', 'o', 't', '\n',
        's', 'o', 'o', 't', 'h', 'e', '\n',
        's', 'o', 'o', 't', 'h', 'e', 'd', '\n',
        's', 'o', 'o', 't', 'h', 'e', 'r', 's', '\n',
        's', 'o', 'o', 't', 'h', 'e', 's', '\n',
        's', 'o', 'o', 't', 'h', 'i', 'n', 'g', '\n',
        's', 'o', 'o', 't', 'h', 'i', 'n', 'g', 'l', 'y', '\n',
        's', 'o', 'o', 't', 'h', 's', 'a', 'y', 'e', 'r', '\n',
        's', 'o', 'o', 't', 'h', 's', 'a', 'y', 'e', 'r', 's', '\n',
        's', 'o', 'o', 't', 'h', 's', 'a', 'y', 'i', 'n', 'g', '\n',
        's', 'o', 'o', 't', 'i', 'e', 'r', '\n',
        's', 'o', 'o', 't', 's', '\n',
        's', 'o', 'o', 't', 'y', '\n',
        's', 'o', 'p', '\n',
        's', 'o', 'p', 'h', 'i', 's', 't', '\n',
        's', 'o', 'p', 'h', 'i', 's', 't', 'i', 'c', 'a', 't', 'e', '\n',
        's', 'o', 'p', 'h', 'i', 's', 't', 'i', 'c', 'a', 't', 'e', 'd', '\n',
        's', 'o', 'p', 'h', 'i', 's', 't', 'i', 'c', 'a', 't', 'e', 's', '\n',
        's', 'o', 'p', 'h', 'i', 's', 't', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'o', 'p', 'h', 'i', 's', 't', 'r', 'y', '\n',
        's', 'o', 'p', 'h', 'i', 's', 't', 's', '\n',
        's', 'o', 'p', 'o', 'r', 'i', 'f', 'i', 'c', '\n',
        's', 'o', 'p', 'p', 'i', 'n', 'g', '\n',
        's', 'o', 'p', 'p', 'y', '\n',
        's', 'o', 'p', 'r', 'a', 'n', 'o', '\n',
        's', 'o', 'r', 'b', 'e', 't', '\n',
        's', 'o', 'r', 'b', 'e', 't', 's', '\n',
        's', 'o', 'r', 'c', 'e', 'r', 'e', 'r', '\n',
        's', 'o', 'r', 'c', 'e', 'r', 'e', 'r', 's', '\n',
        's', 'o', 'r', 'c', 'e', 'r', 'e', 's', 's', '\n',
        's', 'o', 'r', 'c', 'e', 'r', 'y', '\n',
        's', 'o', 'r', 'd', 'i', 'd', '\n',
        's', 'o', 'r', 'd', 'i', 'd', 'l', 'y', '\n',
        's', 'o', 'r', 'd', 'i', 'd', 'n', 'e', 's', 's', '\n',
        's', 'o', 'r', 'e', '\n',
        's', 'o', 'r', 'e', 'l', 'y', '\n',
        's', 'o', 'r', 'e', 'n', 'e', 's', 's', '\n',
        's', 'o', 'r', 'e', 's', '\n',
        's', 'o', 'r', 'g', 'h', 'u', 'm', '\n',
        's', 'o', 'r', 'o', 'r', 'i', 't', 'y', '\n',
        's', 'o', 'r', 'r', 'e', 'l', '\n',
        's', 'o', 'r', 'r', 'i', 'e', 'r', '\n',
        's', 'o', 'r', 'r', 'i', 'e', 's', 't', '\n',
        's', 'o', 'r', 'r', 'o', 'w', '\n',
        's', 'o', 'r', 'r', 'o', 'w', 'e', 'd', '\n',
        's', 'o', 'r', 'r', 'o', 'w', 'f', 'u', 'l', '\n',
        's', 'o', 'r', 'r', 'o', 'w', 'f', 'u', 'l', 'l', 'y', '\n',
        's', 'o', 'r', 'r', 'o', 'w', 'i', 'n', 'g', '\n',
        's', 'o', 'r', 'r', 'o', 'w', 's', '\n',
        's', 'o', 'r', 'r', 'y', '\n',
        's', 'o', 'r', 't', '\n',
        's', 'o', 'r', 't', 'a', 'b', 'l', 'e', '\n',
        's', 'o', 'r', 't', 'e', 'd', '\n',
        's', 'o', 'r', 't', 'e', 'r', '\n',
        's', 'o', 'r', 't', 'e', 'r', 's', '\n',
        's', 'o', 'r', 't', 'i', 'e', '\n',
        's', 'o', 'r', 't', 'i', 'e', 's', '\n',
        's', 'o', 'r', 't', 'i', 'n', 'g', '\n',
        's', 'o', 'r', 't', 's', '\n',
        's', 'o', 's', '\n',
        's', 'o', 's', 'o', '\n',
        's', 'o', 't', '\n',
        's', 'o', 't', 'h', 'o', '\n',
        's', 'o', 'u', 'b', 'r', 'i', 'q', 'u', 'e', 't', '\n',
        's', 'o', 'u', 'd', 'a', 'n', '\n',
        's', 'o', 'u', 'f', 'f', 'l', 'e', '\n',
        's', 'o', 'u', 'g', 'h', 't', '\n',
        's', 'o', 'u', 'g', 'h', 't', 'a', 'f', 't', 'e', 'r', '\n',
        's', 'o', 'u', 'k', '\n',
        's', 'o', 'u', 'k', 's', '\n',
        's', 'o', 'u', 'l', '\n',
        's', 'o', 'u', 'l', 'd', 'e', 's', 't', 'r', 'o', 'y', 'i', 'n', 'g', '\n',
        's', 'o', 'u', 'l', 'e', 'd', '\n',
        's', 'o', 'u', 'l', 'f', 'u', 'l', '\n',
        's', 'o', 'u', 'l', 'f', 'u', 'l', 'l', 'y', '\n',
        's', 'o', 'u', 'l', 'l', 'e', 's', 's', '\n',
        's', 'o', 'u', 'l', 's', '\n',
        's', 'o', 'u', 'l', 's', 'e', 'a', 'r', 'c', 'h', 'i', 'n', 'g', '\n',
        's', 'o', 'u', 'n', 'd', '\n',
        's', 'o', 'u', 'n', 'd', 'c', 'h', 'e', 'c', 'k', '\n',
        's', 'o', 'u', 'n', 'd', 'e', 'd', '\n',
        's', 'o', 'u', 'n', 'd', 'e', 'r', '\n',
        's', 'o', 'u', 'n', 'd', 'e', 's', 't', '\n',
        's', 'o', 'u', 'n', 'd', 'i', 'n', 'g', '\n',
        's', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 's', '\n',
        's', 'o', 'u', 'n', 'd', 'l', 'e', 's', 's', '\n',
        's', 'o', 'u', 'n', 'd', 'l', 'e', 's', 's', 'l', 'y', '\n',
        's', 'o', 'u', 'n', 'd', 'l', 'y', '\n',
        's', 'o', 'u', 'n', 'd', 'n', 'e', 's', 's', '\n',
        's', 'o', 'u', 'n', 'd', 'p', 'r', 'o', 'o', 'f', '\n',
        's', 'o', 'u', 'n', 'd', 'p', 'r', 'o', 'o', 'f', 'e', 'd', '\n',
        's', 'o', 'u', 'n', 'd', 'p', 'r', 'o', 'o', 'f', 'i', 'n', 'g', '\n',
        's', 'o', 'u', 'n', 'd', 's', '\n',
        's', 'o', 'u', 'n', 'd', 't', 'r', 'a', 'c', 'k', '\n',
        's', 'o', 'u', 'n', 'd', 't', 'r', 'a', 'c', 'k', 's', '\n',
        's', 'o', 'u', 'p', '\n',
        's', 'o', 'u', 'p', 's', '\n',
        's', 'o', 'u', 'p', 'y', '\n',
        's', 'o', 'u', 'r', '\n',
        's', 'o', 'u', 'r', 'c', 'e', '\n',
        's', 'o', 'u', 'r', 'c', 'e', 'd', '\n',
        's', 'o', 'u', 'r', 'c', 'e', 'l', 'e', 's', 's', '\n',
        's', 'o', 'u', 'r', 'c', 'e', 's', '\n',
        's', 'o', 'u', 'r', 'c', 'i', 'n', 'g', '\n',
        's', 'o', 'u', 'r', 'e', 'd', '\n',
        's', 'o', 'u', 'r', 'e', 's', 't', '\n',
        's', 'o', 'u', 'r', 'i', 'n', 'g', '\n',
        's', 'o', 'u', 'r', 'l', 'y', '\n',
        's', 'o', 'u', 'r', 'n', 'e', 's', 's', '\n',
        's', 'o', 'u', 'r', 's', '\n',
        's', 'o', 'u', 's', 'e', 'd', '\n',
        's', 'o', 'u', 't', 'h', '\n',
        's', 'o', 'u', 't', 'h', 'b', 'o', 'u', 'n', 'd', '\n',
        's', 'o', 'u', 't', 'h', 'e', 'r', 'l', 'y', '\n',
        's', 'o', 'u', 't', 'h', 'e', 'r', 'n', '\n',
        's', 'o', 'u', 't', 'h', 'e', 'r', 'n', 'e', 'r', '\n',
        's', 'o', 'u', 't', 'h', 'e', 'r', 'n', 'e', 'r', 's', '\n',
        's', 'o', 'u', 't', 'h', 'e', 'r', 'n', 'm', 'o', 's', 't', '\n',
        's', 'o', 'u', 't', 'h', 'w', 'a', 'r', 'd', '\n',
        's', 'o', 'u', 't', 'h', 'w', 'a', 'r', 'd', 's', '\n',
        's', 'o', 'u', 'v', 'e', 'n', 'i', 'r', '\n',
        's', 'o', 'u', 'v', 'e', 'n', 'i', 'r', 's', '\n',
        's', 'o', 'v', 'e', 'r', 'e', 'i', 'g', 'n', '\n',
        's', 'o', 'v', 'e', 'r', 'e', 'i', 'g', 'n', 's', '\n',
        's', 'o', 'v', 'e', 'r', 'e', 'i', 'g', 'n', 't', 'y', '\n',
        's', 'o', 'v', 'i', 'e', 't', '\n',
        's', 'o', 'w', '\n',
        's', 'o', 'w', 'e', 'd', '\n',
        's', 'o', 'w', 'e', 'r', '\n',
        's', 'o', 'w', 'e', 'r', 's', '\n',
        's', 'o', 'w', 'e', 't', 'o', '\n',
        's', 'o', 'w', 'i', 'n', 'g', '\n',
        's', 'o', 'w', 'n', '\n',
        's', 'o', 'w', 's', '\n',
        's', 'o', 'y', '\n',
        's', 'o', 'y', 'a', '\n',
        's', 'o', 'y', 'b', 'e', 'a', 'n', '\n',
        's', 'o', 'y', 'b', 'e', 'a', 'n', 's', '\n',
        's', 'p', 'a', '\n',
        's', 'p', 'a', 'c', 'e', '\n',
        's', 'p', 'a', 'c', 'e', 'a', 'g', 'e', '\n',
        's', 'p', 'a', 'c', 'e', 'c', 'r', 'a', 'f', 't', '\n',
        's', 'p', 'a', 'c', 'e', 'd', '\n',
        's', 'p', 'a', 'c', 'e', 'f', 'l', 'i', 'g', 'h', 't', '\n',
        's', 'p', 'a', 'c', 'e', 'm', 'a', 'n', '\n',
        's', 'p', 'a', 'c', 'e', 'm', 'e', 'n', '\n',
        's', 'p', 'a', 'c', 'e', 'r', '\n',
        's', 'p', 'a', 'c', 'e', 'r', 's', '\n',
        's', 'p', 'a', 'c', 'e', 's', '\n',
        's', 'p', 'a', 'c', 'e', 's', 'h', 'i', 'p', '\n',
        's', 'p', 'a', 'c', 'e', 's', 'h', 'i', 'p', 's', '\n',
        's', 'p', 'a', 'c', 'e', 's', 'u', 'i', 't', '\n',
        's', 'p', 'a', 'c', 'e', 's', 'u', 'i', 't', 's', '\n',
        's', 'p', 'a', 'c', 'e', 'y', '\n',
        's', 'p', 'a', 'c', 'i', 'a', 'l', '\n',
        's', 'p', 'a', 'c', 'i', 'n', 'g', '\n',
        's', 'p', 'a', 'c', 'i', 'n', 'g', 's', '\n',
        's', 'p', 'a', 'c', 'i', 'o', 'u', 's', '\n',
        's', 'p', 'a', 'c', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        's', 'p', 'a', 'c', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        's', 'p', 'a', 'd', 'e', '\n',
        's', 'p', 'a', 'd', 'e', 'd', '\n',
        's', 'p', 'a', 'd', 'e', 's', '\n',
        's', 'p', 'a', 'd', 'e', 'w', 'o', 'r', 'k', '\n',
        's', 'p', 'a', 'g', 'h', 'e', 't', 't', 'i', '\n',
        's', 'p', 'a', 'i', 'n', '\n',
        's', 'p', 'a', 'm', '\n',
        's', 'p', 'a', 'n', '\n',
        's', 'p', 'a', 'n', 'd', 'r', 'e', 'l', 's', '\n',
        's', 'p', 'a', 'n', 'g', 'l', 'e', '\n',
        's', 'p', 'a', 'n', 'g', 'l', 'e', 'd', '\n',
        's', 'p', 'a', 'n', 'g', 'l', 'e', 's', '\n',
        's', 'p', 'a', 'n', 'i', 'e', 'l', '\n',
        's', 'p', 'a', 'n', 'i', 'e', 'l', 's', '\n',
        's', 'p', 'a', 'n', 'i', 's', 'h', '\n',
        's', 'p', 'a', 'n', 'k', '\n',
        's', 'p', 'a', 'n', 'k', 'e', 'd', '\n',
        's', 'p', 'a', 'n', 'k', 'e', 'r', '\n',
        's', 'p', 'a', 'n', 'k', 'i', 'n', 'g', '\n',
        's', 'p', 'a', 'n', 'k', 'i', 'n', 'g', 's', '\n',
        's', 'p', 'a', 'n', 'k', 's', '\n',
        's', 'p', 'a', 'n', 'n', 'e', 'd', '\n',
        's', 'p', 'a', 'n', 'n', 'e', 'r', '\n',
        's', 'p', 'a', 'n', 'n', 'e', 'r', 's', '\n',
        's', 'p', 'a', 'n', 'n', 'i', 'n', 'g', '\n',
        's', 'p', 'a', 'n', 's', '\n',
        's', 'p', 'a', 'r', '\n',
        's', 'p', 'a', 'r', 'e', '\n',
        's', 'p', 'a', 'r', 'e', 'd', '\n',
        's', 'p', 'a', 'r', 'e', 'l', 'y', '\n',
        's', 'p', 'a', 'r', 'e', 's', '\n',
        's', 'p', 'a', 'r', 'e', 't', 'i', 'm', 'e', '\n',
        's', 'p', 'a', 'r', 'i', 'n', 'g', '\n',
        's', 'p', 'a', 'r', 'i', 'n', 'g', 'l', 'y', '\n',
        's', 'p', 'a', 'r', 'k', '\n',
        's', 'p', 'a', 'r', 'k', 'e', 'd', '\n',
        's', 'p', 'a', 'r', 'k', 'i', 'n', 'g', '\n',
        's', 'p', 'a', 'r', 'k', 'l', 'e', '\n',
        's', 'p', 'a', 'r', 'k', 'l', 'e', 'd', '\n',
        's', 'p', 'a', 'r', 'k', 'l', 'e', 'r', '\n',
        's', 'p', 'a', 'r', 'k', 'l', 'e', 'r', 's', '\n',
        's', 'p', 'a', 'r', 'k', 'l', 'e', 's', '\n',
        's', 'p', 'a', 'r', 'k', 'l', 'i', 'n', 'g', '\n',
        's', 'p', 'a', 'r', 'k', 'l', 'i', 'n', 'g', 'l', 'y', '\n',
        's', 'p', 'a', 'r', 'k', 'l', 'y', '\n',
        's', 'p', 'a', 'r', 'k', 's', '\n',
        's', 'p', 'a', 'r', 'r', 'e', 'd', '\n',
        's', 'p', 'a', 'r', 'r', 'i', 'n', 'g', '\n',
        's', 'p', 'a', 'r', 'r', 'o', 'w', '\n',
        's', 'p', 'a', 'r', 'r', 'o', 'w', 'h', 'a', 'w', 'k', '\n',
        's', 'p', 'a', 'r', 'r', 'o', 'w', 's', '\n',
        's', 'p', 'a', 'r', 's', '\n',
        's', 'p', 'a', 'r', 's', 'e', '\n',
        's', 'p', 'a', 'r', 's', 'e', 'l', 'y', '\n',
        's', 'p', 'a', 'r', 's', 'e', 'n', 'e', 's', 's', '\n',
        's', 'p', 'a', 'r', 's', 'e', 'r', '\n',
        's', 'p', 'a', 'r', 's', 'e', 's', 't', '\n',
        's', 'p', 'a', 'r', 's', 'i', 't', 'y', '\n',
        's', 'p', 'a', 'r', 't', 'a', '\n',
        's', 'p', 'a', 'r', 't', 'a', 'n', '\n',
        's', 'p', 'a', 'r', 't', 'a', 'n', 's', '\n',
        's', 'p', 'a', 's', '\n',
        's', 'p', 'a', 's', 'm', '\n',
        's', 'p', 'a', 's', 'm', 'o', 'd', 'i', 'c', '\n',
        's', 'p', 'a', 's', 'm', 'o', 'd', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 'p', 'a', 's', 'm', 's', '\n',
        's', 'p', 'a', 's', 't', 'i', 'c', '\n',
        's', 'p', 'a', 's', 't', 'i', 'c', 's', '\n',
        's', 'p', 'a', 't', '\n',
        's', 'p', 'a', 't', 'e', '\n',
        's', 'p', 'a', 't', 'i', 'a', 'l', '\n',
        's', 'p', 'a', 't', 'i', 'a', 'l', 'l', 'y', '\n',
        's', 'p', 'a', 't', 's', '\n',
        's', 'p', 'a', 't', 't', 'e', 'r', '\n',
        's', 'p', 'a', 't', 't', 'e', 'r', 'e', 'd', '\n',
        's', 'p', 'a', 't', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'p', 'a', 't', 't', 'e', 'r', 's', '\n',
        's', 'p', 'a', 't', 'u', 'l', 'a', '\n',
        's', 'p', 'a', 't', 'u', 'l', 'a', 's', '\n',
        's', 'p', 'a', 'w', 'n', '\n',
        's', 'p', 'a', 'w', 'n', 'e', 'd', '\n',
        's', 'p', 'a', 'w', 'n', 'i', 'n', 'g', '\n',
        's', 'p', 'a', 'w', 'n', 's', '\n',
        's', 'p', 'a', 'y', '\n',
        's', 'p', 'a', 'y', 'e', 'd', '\n',
        's', 'p', 'a', 'y', 'i', 'n', 'g', '\n',
        's', 'p', 'a', 'y', 's', '\n',
        's', 'p', 'e', 'a', 'k', '\n',
        's', 'p', 'e', 'a', 'k', 'a', 'b', 'l', 'e', '\n',
        's', 'p', 'e', 'a', 'k', 'e', 'r', '\n',
        's', 'p', 'e', 'a', 'k', 'e', 'r', 's', '\n',
        's', 'p', 'e', 'a', 'k', 'i', 'n', 'g', '\n',
        's', 'p', 'e', 'a', 'k', 's', '\n',
        's', 'p', 'e', 'a', 'r', '\n',
        's', 'p', 'e', 'a', 'r', 'e', 'd', '\n',
        's', 'p', 'e', 'a', 'r', 'h', 'e', 'a', 'd', '\n',
        's', 'p', 'e', 'a', 'r', 'h', 'e', 'a', 'd', 'e', 'd', '\n',
        's', 'p', 'e', 'a', 'r', 'h', 'e', 'a', 'd', 'i', 'n', 'g', '\n',
        's', 'p', 'e', 'a', 'r', 'h', 'e', 'a', 'd', 's', '\n',
        's', 'p', 'e', 'a', 'r', 'i', 'n', 'g', '\n',
        's', 'p', 'e', 'a', 'r', 's', '\n',
        's', 'p', 'e', 'c', '\n',
        's', 'p', 'e', 'c', 'i', 'a', 'l', '\n',
        's', 'p', 'e', 'c', 'i', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'p', 'e', 'c', 'i', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        's', 'p', 'e', 'c', 'i', 'a', 'l', 'i', 's', 'e', '\n',
        's', 'p', 'e', 'c', 'i', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        's', 'p', 'e', 'c', 'i', 'a', 'l', 'i', 's', 'e', 's', '\n',
        's', 'p', 'e', 'c', 'i', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        's', 'p', 'e', 'c', 'i', 'a', 'l', 'i', 's', 'm', '\n',
        's', 'p', 'e', 'c', 'i', 'a', 'l', 'i', 's', 'm', 's', '\n',
        's', 'p', 'e', 'c', 'i', 'a', 'l', 'i', 's', 't', '\n',
        's', 'p', 'e', 'c', 'i', 'a', 'l', 'i', 's', 't', 's', '\n',
        's', 'p', 'e', 'c', 'i', 'a', 'l', 'i', 't', 'i', 'e', 's', '\n',
        's', 'p', 'e', 'c', 'i', 'a', 'l', 'i', 't', 'y', '\n',
        's', 'p', 'e', 'c', 'i', 'a', 'l', 'l', 'y', '\n',
        's', 'p', 'e', 'c', 'i', 'a', 'l', 'n', 'e', 's', 's', '\n',
        's', 'p', 'e', 'c', 'i', 'a', 'l', 's', '\n',
        's', 'p', 'e', 'c', 'i', 'a', 'l', 't', 'y', '\n',
        's', 'p', 'e', 'c', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'p', 'e', 'c', 'i', 'e', 's', '\n',
        's', 'p', 'e', 'c', 'i', 'f', 'i', 'a', 'b', 'l', 'e', '\n',
        's', 'p', 'e', 'c', 'i', 'f', 'i', 'a', 'b', 'l', 'y', '\n',
        's', 'p', 'e', 'c', 'i', 'f', 'i', 'c', '\n',
        's', 'p', 'e', 'c', 'i', 'f', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 'p', 'e', 'c', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'p', 'e', 'c', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        's', 'p', 'e', 'c', 'i', 'f', 'i', 'c', 'i', 't', 'i', 'e', 's', '\n',
        's', 'p', 'e', 'c', 'i', 'f', 'i', 'c', 'i', 't', 'y', '\n',
        's', 'p', 'e', 'c', 'i', 'f', 'i', 'c', 'n', 'e', 's', 's', '\n',
        's', 'p', 'e', 'c', 'i', 'f', 'i', 'c', 's', '\n',
        's', 'p', 'e', 'c', 'i', 'f', 'i', 'e', 'd', '\n',
        's', 'p', 'e', 'c', 'i', 'f', 'i', 'e', 'r', '\n',
        's', 'p', 'e', 'c', 'i', 'f', 'i', 'e', 'r', 's', '\n',
        's', 'p', 'e', 'c', 'i', 'f', 'i', 'e', 's', '\n',
        's', 'p', 'e', 'c', 'i', 'f', 'y', '\n',
        's', 'p', 'e', 'c', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        's', 'p', 'e', 'c', 'i', 'm', 'e', 'n', '\n',
        's', 'p', 'e', 'c', 'i', 'm', 'e', 'n', 's', '\n',
        's', 'p', 'e', 'c', 'i', 'o', 'u', 's', '\n',
        's', 'p', 'e', 'c', 'k', '\n',
        's', 'p', 'e', 'c', 'k', 'l', 'e', '\n',
        's', 'p', 'e', 'c', 'k', 'l', 'e', 'd', '\n',
        's', 'p', 'e', 'c', 'k', 'l', 'e', 's', '\n',
        's', 'p', 'e', 'c', 'k', 's', '\n',
        's', 'p', 'e', 'c', 's', '\n',
        's', 'p', 'e', 'c', 't', 'a', 'c', 'l', 'e', '\n',
        's', 'p', 'e', 'c', 't', 'a', 'c', 'l', 'e', 's', '\n',
        's', 'p', 'e', 'c', 't', 'a', 'c', 'u', 'l', 'a', 'r', '\n',
        's', 'p', 'e', 'c', 't', 'a', 'c', 'u', 'l', 'a', 'r', 'l', 'y', '\n',
        's', 'p', 'e', 'c', 't', 'a', 'c', 'u', 'l', 'a', 'r', 's', '\n',
        's', 'p', 'e', 'c', 't', 'a', 't', 'o', 'r', '\n',
        's', 'p', 'e', 'c', 't', 'a', 't', 'o', 'r', 's', '\n',
        's', 'p', 'e', 'c', 't', 'r', 'a', '\n',
        's', 'p', 'e', 'c', 't', 'r', 'a', 'l', '\n',
        's', 'p', 'e', 'c', 't', 'r', 'e', '\n',
        's', 'p', 'e', 'c', 't', 'r', 'e', 's', '\n',
        's', 'p', 'e', 'c', 't', 'r', 'o', 'g', 'r', 'a', 'm', '\n',
        's', 'p', 'e', 'c', 't', 'r', 'o', 'g', 'r', 'a', 'p', 'h', '\n',
        's', 'p', 'e', 'c', 't', 'r', 'o', 'm', 'e', 't', 'e', 'r', '\n',
        's', 'p', 'e', 'c', 't', 'r', 'o', 'm', 'e', 't', 'e', 'r', 's', '\n',
        's', 'p', 'e', 'c', 't', 'r', 'o', 'm', 'e', 't', 'r', 'i', 'c', '\n',
        's', 'p', 'e', 'c', 't', 'r', 'o', 'm', 'e', 't', 'r', 'y', '\n',
        's', 'p', 'e', 'c', 't', 'r', 'o', 'p', 'h', 'o', 't', 'o', 'm', 'e', 't', 'e', 'r', '\n',
        's', 'p', 'e', 'c', 't', 'r', 'o', 'p', 'h', 'o', 't', 'o', 'm', 'e', 't', 'e', 'r', 's', '\n',
        's', 'p', 'e', 'c', 't', 'r', 'o', 'p', 'h', 'o', 't', 'o', 'm', 'e', 't', 'r', 'y', '\n',
        's', 'p', 'e', 'c', 't', 'r', 'o', 's', 'c', 'o', 'p', 'e', '\n',
        's', 'p', 'e', 'c', 't', 'r', 'o', 's', 'c', 'o', 'p', 'e', 's', '\n',
        's', 'p', 'e', 'c', 't', 'r', 'o', 's', 'c', 'o', 'p', 'i', 'c', '\n',
        's', 'p', 'e', 'c', 't', 'r', 'o', 's', 'c', 'o', 'p', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 'p', 'e', 'c', 't', 'r', 'o', 's', 'c', 'o', 'p', 'y', '\n',
        's', 'p', 'e', 'c', 't', 'r', 'u', 'm', '\n',
        's', 'p', 'e', 'c', 'u', 'l', 'a', 'r', '\n',
        's', 'p', 'e', 'c', 'u', 'l', 'a', 't', 'e', '\n',
        's', 'p', 'e', 'c', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        's', 'p', 'e', 'c', 'u', 'l', 'a', 't', 'e', 's', '\n',
        's', 'p', 'e', 'c', 'u', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        's', 'p', 'e', 'c', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'p', 'e', 'c', 'u', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        's', 'p', 'e', 'c', 'u', 'l', 'a', 't', 'i', 'v', 'e', '\n',
        's', 'p', 'e', 'c', 'u', 'l', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        's', 'p', 'e', 'c', 'u', 'l', 'a', 't', 'o', 'r', '\n',
        's', 'p', 'e', 'c', 'u', 'l', 'a', 't', 'o', 'r', 's', '\n',
        's', 'p', 'e', 'c', 'u', 'l', 'u', 'm', '\n',
        's', 'p', 'e', 'd', '\n',
        's', 'p', 'e', 'e', 'c', 'h', '\n',
        's', 'p', 'e', 'e', 'c', 'h', 'e', 's', '\n',
        's', 'p', 'e', 'e', 'c', 'h', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        's', 'p', 'e', 'e', 'c', 'h', 'l', 'e', 's', 's', '\n',
        's', 'p', 'e', 'e', 'c', 'h', 'l', 'e', 's', 's', 'l', 'y', '\n',
        's', 'p', 'e', 'e', 'd', '\n',
        's', 'p', 'e', 'e', 'd', 'b', 'o', 'a', 't', '\n',
        's', 'p', 'e', 'e', 'd', 'b', 'o', 'a', 't', 's', '\n',
        's', 'p', 'e', 'e', 'd', 'c', 'o', 'p', '\n',
        's', 'p', 'e', 'e', 'd', 'e', 'd', '\n',
        's', 'p', 'e', 'e', 'd', 'i', 'e', 'r', '\n',
        's', 'p', 'e', 'e', 'd', 'i', 'e', 's', 't', '\n',
        's', 'p', 'e', 'e', 'd', 'i', 'l', 'y', '\n',
        's', 'p', 'e', 'e', 'd', 'i', 'n', 'g', '\n',
        's', 'p', 'e', 'e', 'd', 'o', 'm', 'e', 't', 'e', 'r', '\n',
        's', 'p', 'e', 'e', 'd', 'o', 'm', 'e', 't', 'e', 'r', 's', '\n',
        's', 'p', 'e', 'e', 'd', 's', '\n',
        's', 'p', 'e', 'e', 'd', 'u', 'p', '\n',
        's', 'p', 'e', 'e', 'd', 'w', 'a', 'y', '\n',
        's', 'p', 'e', 'e', 'd', 'w', 'e', 'l', 'l', '\n',
        's', 'p', 'e', 'e', 'd', 'y', '\n',
        's', 'p', 'e', 'l', 'l', '\n',
        's', 'p', 'e', 'l', 'l', 'a', 'b', 'l', 'e', '\n',
        's', 'p', 'e', 'l', 'l', 'b', 'i', 'n', 'd', 'e', 'r', '\n',
        's', 'p', 'e', 'l', 'l', 'b', 'i', 'n', 'd', 'i', 'n', 'g', '\n',
        's', 'p', 'e', 'l', 'l', 'b', 'o', 'u', 'n', 'd', '\n',
        's', 'p', 'e', 'l', 'l', 'e', 'd', '\n',
        's', 'p', 'e', 'l', 'l', 'e', 'r', '\n',
        's', 'p', 'e', 'l', 'l', 'e', 'r', 's', '\n',
        's', 'p', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        's', 'p', 'e', 'l', 'l', 'i', 'n', 'g', 's', '\n',
        's', 'p', 'e', 'l', 'l', 's', '\n',
        's', 'p', 'e', 'l', 't', '\n',
        's', 'p', 'e', 'n', 'c', 'e', 'r', '\n',
        's', 'p', 'e', 'n', 'd', '\n',
        's', 'p', 'e', 'n', 'd', 'e', 'r', '\n',
        's', 'p', 'e', 'n', 'd', 'e', 'r', 's', '\n',
        's', 'p', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        's', 'p', 'e', 'n', 'd', 's', '\n',
        's', 'p', 'e', 'n', 'd', 't', 'h', 'r', 'i', 'f', 't', '\n',
        's', 'p', 'e', 'n', 't', '\n',
        's', 'p', 'e', 'r', 'm', 'a', 't', 'o', 'z', 'o', 'a', '\n',
        's', 'p', 'e', 'w', '\n',
        's', 'p', 'e', 'w', 'e', 'd', '\n',
        's', 'p', 'e', 'w', 'i', 'n', 'g', '\n',
        's', 'p', 'e', 'w', 's', '\n',
        's', 'p', 'h', 'a', 'g', 'n', 'u', 'm', '\n',
        's', 'p', 'h', 'e', 'r', 'e', '\n',
        's', 'p', 'h', 'e', 'r', 'e', 's', '\n',
        's', 'p', 'h', 'e', 'r', 'i', 'c', '\n',
        's', 'p', 'h', 'e', 'r', 'i', 'c', 'a', 'l', '\n',
        's', 'p', 'h', 'e', 'r', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 'p', 'h', 'e', 'r', 'o', 'i', 'd', '\n',
        's', 'p', 'h', 'e', 'r', 'o', 'i', 'd', 'a', 'l', '\n',
        's', 'p', 'h', 'i', 'n', 'c', 't', 'e', 'r', '\n',
        's', 'p', 'h', 'i', 'n', 'c', 't', 'e', 'r', 's', '\n',
        's', 'p', 'h', 'i', 'n', 'x', '\n',
        's', 'p', 'h', 'y', 'g', 'm', 'o', 'm', 'a', 'n', 'o', 'm', 'e', 't', 'e', 'r', '\n',
        's', 'p', 'i', 'c', 'e', '\n',
        's', 'p', 'i', 'c', 'e', 'd', '\n',
        's', 'p', 'i', 'c', 'e', 'r', '\n',
        's', 'p', 'i', 'c', 'e', 'r', 'y', '\n',
        's', 'p', 'i', 'c', 'e', 's', '\n',
        's', 'p', 'i', 'c', 'i', 'e', 'r', '\n',
        's', 'p', 'i', 'c', 'i', 'l', 'y', '\n',
        's', 'p', 'i', 'c', 'i', 'n', 'g', '\n',
        's', 'p', 'i', 'c', 'y', '\n',
        's', 'p', 'i', 'd', 'e', 'r', '\n',
        's', 'p', 'i', 'd', 'e', 'r', 's', '\n',
        's', 'p', 'i', 'd', 'e', 'r', 'y', '\n',
        's', 'p', 'i', 'e', 'd', '\n',
        's', 'p', 'i', 'e', 's', '\n',
        's', 'p', 'i', 'g', 'o', 't', '\n',
        's', 'p', 'i', 'k', 'e', '\n',
        's', 'p', 'i', 'k', 'e', 'd', '\n',
        's', 'p', 'i', 'k', 'e', 's', '\n',
        's', 'p', 'i', 'k', 'i', 'e', 'r', '\n',
        's', 'p', 'i', 'k', 'i', 'e', 's', 't', '\n',
        's', 'p', 'i', 'k', 'i', 'n', 'g', '\n',
        's', 'p', 'i', 'k', 'y', '\n',
        's', 'p', 'i', 'l', 'l', '\n',
        's', 'p', 'i', 'l', 'l', 'a', 'g', 'e', '\n',
        's', 'p', 'i', 'l', 'l', 'a', 'g', 'e', 's', '\n',
        's', 'p', 'i', 'l', 'l', 'e', 'd', '\n',
        's', 'p', 'i', 'l', 'l', 'e', 'r', '\n',
        's', 'p', 'i', 'l', 'l', 'i', 'n', 'g', '\n',
        's', 'p', 'i', 'l', 'l', 's', '\n',
        's', 'p', 'i', 'l', 't', '\n',
        's', 'p', 'i', 'n', '\n',
        's', 'p', 'i', 'n', 'a', 'c', 'h', '\n',
        's', 'p', 'i', 'n', 'a', 'l', '\n',
        's', 'p', 'i', 'n', 'd', 'l', 'e', '\n',
        's', 'p', 'i', 'n', 'd', 'l', 'e', 's', '\n',
        's', 'p', 'i', 'n', 'd', 'l', 'y', '\n',
        's', 'p', 'i', 'n', 'd', 'r', 'i', 'e', 'r', '\n',
        's', 'p', 'i', 'n', 'd', 'r', 'i', 'e', 'r', 's', '\n',
        's', 'p', 'i', 'n', 'd', 'r', 'i', 'f', 't', '\n',
        's', 'p', 'i', 'n', 'd', 'r', 'y', '\n',
        's', 'p', 'i', 'n', 'e', '\n',
        's', 'p', 'i', 'n', 'e', 'c', 'h', 'i', 'l', 'l', 'i', 'n', 'g', '\n',
        's', 'p', 'i', 'n', 'e', 'l', 'e', 's', 's', '\n',
        's', 'p', 'i', 'n', 'e', 's', '\n',
        's', 'p', 'i', 'n', 'e', 't', '\n',
        's', 'p', 'i', 'n', 'n', 'a', 'k', 'e', 'r', '\n',
        's', 'p', 'i', 'n', 'n', 'e', 'r', '\n',
        's', 'p', 'i', 'n', 'n', 'e', 'r', 's', '\n',
        's', 'p', 'i', 'n', 'n', 'e', 'y', '\n',
        's', 'p', 'i', 'n', 'n', 'i', 'n', 'g', '\n',
        's', 'p', 'i', 'n', 'o', 'f', 'f', '\n',
        's', 'p', 'i', 'n', 'o', 'f', 'f', 's', '\n',
        's', 'p', 'i', 'n', 's', '\n',
        's', 'p', 'i', 'n', 's', 't', 'e', 'r', '\n',
        's', 'p', 'i', 'n', 's', 't', 'e', 'r', 'h', 'o', 'o', 'd', '\n',
        's', 'p', 'i', 'n', 's', 't', 'e', 'r', 's', '\n',
        's', 'p', 'i', 'n', 'y', '\n',
        's', 'p', 'i', 'r', 'a', 'l', '\n',
        's', 'p', 'i', 'r', 'a', 'l', 'l', 'e', 'd', '\n',
        's', 'p', 'i', 'r', 'a', 'l', 'l', 'i', 'n', 'g', '\n',
        's', 'p', 'i', 'r', 'a', 'l', 'l', 'y', '\n',
        's', 'p', 'i', 'r', 'a', 'l', 's', '\n',
        's', 'p', 'i', 'r', 'a', 'n', 't', '\n',
        's', 'p', 'i', 'r', 'a', 'n', 't', 's', '\n',
        's', 'p', 'i', 'r', 'e', '\n',
        's', 'p', 'i', 'r', 'e', 's', '\n',
        's', 'p', 'i', 'r', 'i', 't', '\n',
        's', 'p', 'i', 'r', 'i', 't', 'e', 'd', '\n',
        's', 'p', 'i', 'r', 'i', 't', 'e', 'd', 'l', '\n',
        's', 'p', 'i', 'r', 'i', 't', 'e', 'd', 'l', 'y', '\n',
        's', 'p', 'i', 'r', 'i', 't', 'l', 'e', 's', 's', '\n',
        's', 'p', 'i', 'r', 'i', 't', 's', '\n',
        's', 'p', 'i', 'r', 'i', 't', 'u', 'a', 'l', '\n',
        's', 'p', 'i', 'r', 'i', 't', 'u', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        's', 'p', 'i', 'r', 'i', 't', 'u', 'a', 'l', 'i', 's', 'm', '\n',
        's', 'p', 'i', 'r', 'i', 't', 'u', 'a', 'l', 'i', 's', 't', '\n',
        's', 'p', 'i', 'r', 'i', 't', 'u', 'a', 'l', 'i', 's', 't', 's', '\n',
        's', 'p', 'i', 'r', 'i', 't', 'u', 'a', 'l', 'i', 't', 'y', '\n',
        's', 'p', 'i', 'r', 'i', 't', 'u', 'a', 'l', 'l', 'y', '\n',
        's', 'p', 'i', 'r', 'i', 't', 'u', 'a', 'l', 's', '\n',
        's', 'p', 'i', 't', '\n',
        's', 'p', 'i', 't', 'e', '\n',
        's', 'p', 'i', 't', 'e', 'f', 'u', 'l', '\n',
        's', 'p', 'i', 't', 'e', 'f', 'u', 'l', 'l', 'y', '\n',
        's', 'p', 'i', 't', 'f', 'i', 'r', 'e', '\n',
        's', 'p', 'i', 't', 'f', 'i', 'r', 'e', 's', '\n',
        's', 'p', 'i', 't', 's', '\n',
        's', 'p', 'i', 't', 't', 'i', 'n', 'g', '\n',
        's', 'p', 'i', 't', 't', 'l', 'e', '\n',
        's', 'p', 'i', 't', 't', 'o', 'o', 'n', '\n',
        's', 'p', 'i', 't', 't', 'o', 'o', 'n', 's', '\n',
        's', 'p', 'l', 'a', 's', 'h', '\n',
        's', 'p', 'l', 'a', 's', 'h', 'd', 'o', 'w', 'n', '\n',
        's', 'p', 'l', 'a', 's', 'h', 'e', 'd', '\n',
        's', 'p', 'l', 'a', 's', 'h', 'e', 's', '\n',
        's', 'p', 'l', 'a', 's', 'h', 'i', 'n', 'g', '\n',
        's', 'p', 'l', 'a', 's', 'h', 'y', '\n',
        's', 'p', 'l', 'a', 't', '\n',
        's', 'p', 'l', 'a', 't', 't', 'e', 'r', '\n',
        's', 'p', 'l', 'a', 't', 't', 'e', 'r', 'e', 'd', '\n',
        's', 'p', 'l', 'a', 't', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'p', 'l', 'a', 'y', 'e', 'd', '\n',
        's', 'p', 'l', 'a', 'y', 'i', 'n', 'g', '\n',
        's', 'p', 'l', 'e', 'e', 'n', '\n',
        's', 'p', 'l', 'e', 'e', 'n', 's', '\n',
        's', 'p', 'l', 'e', 'n', 'd', 'i', 'd', '\n',
        's', 'p', 'l', 'e', 'n', 'd', 'i', 'd', 'l', 'y', '\n',
        's', 'p', 'l', 'e', 'n', 'd', 'o', 'u', 'r', '\n',
        's', 'p', 'l', 'e', 'n', 'd', 'o', 'u', 'r', 's', '\n',
        's', 'p', 'l', 'e', 'n', 'e', 't', 'i', 'c', '\n',
        's', 'p', 'l', 'i', 'c', 'e', '\n',
        's', 'p', 'l', 'i', 'c', 'e', 'd', '\n',
        's', 'p', 'l', 'i', 'c', 'e', 'r', '\n',
        's', 'p', 'l', 'i', 'c', 'e', 'r', 's', '\n',
        's', 'p', 'l', 'i', 'c', 'e', 's', '\n',
        's', 'p', 'l', 'i', 'c', 'i', 'n', 'g', '\n',
        's', 'p', 'l', 'i', 'n', 'e', '\n',
        's', 'p', 'l', 'i', 'n', 'e', 's', '\n',
        's', 'p', 'l', 'i', 'n', 't', '\n',
        's', 'p', 'l', 'i', 'n', 't', 'e', 'd', '\n',
        's', 'p', 'l', 'i', 'n', 't', 'e', 'r', '\n',
        's', 'p', 'l', 'i', 'n', 't', 'e', 'r', 'e', 'd', '\n',
        's', 'p', 'l', 'i', 'n', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'p', 'l', 'i', 'n', 't', 'e', 'r', 's', '\n',
        's', 'p', 'l', 'i', 'n', 't', 's', '\n',
        's', 'p', 'l', 'i', 't', '\n',
        's', 'p', 'l', 'i', 't', 's', '\n',
        's', 'p', 'l', 'i', 't', 't', 'a', 'b', 'l', 'e', '\n',
        's', 'p', 'l', 'i', 't', 't', 'e', 'r', '\n',
        's', 'p', 'l', 'i', 't', 't', 'e', 'r', 's', '\n',
        's', 'p', 'l', 'i', 't', 't', 'i', 'n', 'g', '\n',
        's', 'p', 'l', 'i', 't', 't', 'i', 'n', 'g', 's', '\n',
        's', 'p', 'l', 'o', 'd', 'g', 'e', '\n',
        's', 'p', 'l', 'o', 'd', 'g', 'e', 's', '\n',
        's', 'p', 'l', 'o', 't', 'c', 'h', 'e', 's', '\n',
        's', 'p', 'l', 'u', 'r', 'g', 'e', '\n',
        's', 'p', 'l', 'u', 't', 't', 'e', 'r', '\n',
        's', 'p', 'l', 'u', 't', 't', 'e', 'r', 'e', 'd', '\n',
        's', 'p', 'l', 'u', 't', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'p', 'l', 'u', 't', 't', 'e', 'r', 's', '\n',
        's', 'p', 'o', 'i', 'l', '\n',
        's', 'p', 'o', 'i', 'l', 'a', 'g', 'e', '\n',
        's', 'p', 'o', 'i', 'l', 'e', 'd', '\n',
        's', 'p', 'o', 'i', 'l', 'e', 'r', '\n',
        's', 'p', 'o', 'i', 'l', 'e', 'r', 's', '\n',
        's', 'p', 'o', 'i', 'l', 'i', 'n', 'g', '\n',
        's', 'p', 'o', 'i', 'l', 's', '\n',
        's', 'p', 'o', 'i', 'l', 's', 'p', 'o', 'r', 't', '\n',
        's', 'p', 'o', 'i', 'l', 't', '\n',
        's', 'p', 'o', 'k', 'e', '\n',
        's', 'p', 'o', 'k', 'e', 'n', '\n',
        's', 'p', 'o', 'k', 'e', 's', '\n',
        's', 'p', 'o', 'k', 'e', 's', 'h', 'a', 'v', 'e', '\n',
        's', 'p', 'o', 'k', 'e', 's', 'h', 'a', 'v', 'e', 's', '\n',
        's', 'p', 'o', 'k', 'e', 's', 'm', 'a', 'n', '\n',
        's', 'p', 'o', 'k', 'e', 's', 'm', 'e', 'n', '\n',
        's', 'p', 'o', 'k', 'e', 's', 'p', 'e', 'o', 'p', 'l', 'e', '\n',
        's', 'p', 'o', 'k', 'e', 's', 'p', 'e', 'r', 's', 'o', 'n', '\n',
        's', 'p', 'o', 'k', 'e', 's', 'p', 'e', 'r', 's', 'o', 'n', 's', '\n',
        's', 'p', 'o', 'k', 'e', 's', 'w', 'o', 'm', 'a', 'n', '\n',
        's', 'p', 'o', 'k', 'e', 's', 'w', 'o', 'm', 'e', 'n', '\n',
        's', 'p', 'o', 'n', 'g', 'e', '\n',
        's', 'p', 'o', 'n', 'g', 'e', 'd', '\n',
        's', 'p', 'o', 'n', 'g', 'e', 'r', '\n',
        's', 'p', 'o', 'n', 'g', 'e', 's', '\n',
        's', 'p', 'o', 'n', 'g', 'i', 'e', 'r', '\n',
        's', 'p', 'o', 'n', 'g', 'i', 'e', 's', 't', '\n',
        's', 'p', 'o', 'n', 'g', 'i', 'n', 'e', 's', 's', '\n',
        's', 'p', 'o', 'n', 'g', 'i', 'n', 'g', '\n',
        's', 'p', 'o', 'n', 'g', 'y', '\n',
        's', 'p', 'o', 'n', 's', 'o', 'r', '\n',
        's', 'p', 'o', 'n', 's', 'o', 'r', 'e', 'd', '\n',
        's', 'p', 'o', 'n', 's', 'o', 'r', 'i', 'n', 'g', '\n',
        's', 'p', 'o', 'n', 's', 'o', 'r', 's', '\n',
        's', 'p', 'o', 'n', 's', 'o', 'r', 's', 'h', 'i', 'p', '\n',
        's', 'p', 'o', 'n', 's', 'o', 'r', 's', 'h', 'i', 'p', 's', '\n',
        's', 'p', 'o', 'n', 't', 'a', 'n', 'e', 'i', 't', 'y', '\n',
        's', 'p', 'o', 'n', 't', 'a', 'n', 'e', 'o', 'u', 's', '\n',
        's', 'p', 'o', 'n', 't', 'a', 'n', 'e', 'o', 'u', 's', 'l', 'y', '\n',
        's', 'p', 'o', 'o', 'f', '\n',
        's', 'p', 'o', 'o', 'f', 's', '\n',
        's', 'p', 'o', 'o', 'k', '\n',
        's', 'p', 'o', 'o', 'k', 'e', 'd', '\n',
        's', 'p', 'o', 'o', 'k', 'i', 'n', 'g', '\n',
        's', 'p', 'o', 'o', 'k', 's', '\n',
        's', 'p', 'o', 'o', 'k', 'y', '\n',
        's', 'p', 'o', 'o', 'l', '\n',
        's', 'p', 'o', 'o', 'l', 'e', 'd', '\n',
        's', 'p', 'o', 'o', 'l', 'i', 'n', 'g', '\n',
        's', 'p', 'o', 'o', 'l', 's', '\n',
        's', 'p', 'o', 'o', 'n', '\n',
        's', 'p', 'o', 'o', 'n', 'e', 'd', '\n',
        's', 'p', 'o', 'o', 'n', 'f', 'u', 'l', '\n',
        's', 'p', 'o', 'o', 'n', 'f', 'u', 'l', 's', '\n',
        's', 'p', 'o', 'o', 'n', 'i', 'n', 'g', '\n',
        's', 'p', 'o', 'o', 'n', 's', '\n',
        's', 'p', 'o', 'o', 'r', '\n',
        's', 'p', 'o', 'r', 'a', 'd', 'i', 'c', '\n',
        's', 'p', 'o', 'r', 'a', 'd', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 'p', 'o', 'r', 'e', '\n',
        's', 'p', 'o', 'r', 'e', 's', '\n',
        's', 'p', 'o', 'r', 'r', 'a', 'n', '\n',
        's', 'p', 'o', 'r', 'r', 'a', 'n', 's', '\n',
        's', 'p', 'o', 'r', 't', '\n',
        's', 'p', 'o', 'r', 't', 'e', 'd', '\n',
        's', 'p', 'o', 'r', 't', 'i', 'n', 'g', '\n',
        's', 'p', 'o', 'r', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        's', 'p', 'o', 'r', 't', 'i', 'v', 'e', '\n',
        's', 'p', 'o', 'r', 't', 's', '\n',
        's', 'p', 'o', 'r', 't', 's', 'm', 'a', 'n', '\n',
        's', 'p', 'o', 'r', 't', 's', 'm', 'a', 'n', 's', 'h', 'i', 'p', '\n',
        's', 'p', 'o', 'r', 't', 's', 'm', 'e', 'n', '\n',
        's', 'p', 'o', 'r', 't', 's', 'w', 'e', 'a', 'r', '\n',
        's', 'p', 'o', 'r', 't', 'y', '\n',
        's', 'p', 'o', 't', '\n',
        's', 'p', 'o', 't', 'l', 'e', 's', 's', '\n',
        's', 'p', 'o', 't', 'l', 'e', 's', 's', 'l', 'y', '\n',
        's', 'p', 'o', 't', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        's', 'p', 'o', 't', 'l', 'i', 'g', 'h', 't', '\n',
        's', 'p', 'o', 't', 'l', 'i', 'g', 'h', 't', 'i', 'n', 'g', '\n',
        's', 'p', 'o', 't', 'l', 'i', 'g', 'h', 't', 's', '\n',
        's', 'p', 'o', 't', 'l', 'i', 't', '\n',
        's', 'p', 'o', 't', 'o', 'n', '\n',
        's', 'p', 'o', 't', 's', '\n',
        's', 'p', 'o', 't', 't', 'e', 'd', '\n',
        's', 'p', 'o', 't', 't', 'e', 'r', '\n',
        's', 'p', 'o', 't', 't', 'e', 'r', 's', '\n',
        's', 'p', 'o', 't', 't', 'i', 'e', 'r', '\n',
        's', 'p', 'o', 't', 't', 'i', 'e', 's', 't', '\n',
        's', 'p', 'o', 't', 't', 'i', 'n', 'g', '\n',
        's', 'p', 'o', 't', 't', 'y', '\n',
        's', 'p', 'o', 'u', 's', 'e', '\n',
        's', 'p', 'o', 'u', 's', 'e', 's', '\n',
        's', 'p', 'o', 'u', 't', '\n',
        's', 'p', 'o', 'u', 't', 'e', 'd', '\n',
        's', 'p', 'o', 'u', 't', 'i', 'n', 'g', '\n',
        's', 'p', 'o', 'u', 't', 's', '\n',
        's', 'p', 'r', 'a', 'i', 'n', '\n',
        's', 'p', 'r', 'a', 'i', 'n', 'e', 'd', '\n',
        's', 'p', 'r', 'a', 'i', 'n', 'i', 'n', 'g', '\n',
        's', 'p', 'r', 'a', 'i', 'n', 's', '\n',
        's', 'p', 'r', 'a', 'n', 'g', '\n',
        's', 'p', 'r', 'a', 't', '\n',
        's', 'p', 'r', 'a', 't', 's', '\n',
        's', 'p', 'r', 'a', 'w', 'l', '\n',
        's', 'p', 'r', 'a', 'w', 'l', 'e', 'd', '\n',
        's', 'p', 'r', 'a', 'w', 'l', 'i', 'n', 'g', '\n',
        's', 'p', 'r', 'a', 'w', 'l', 's', '\n',
        's', 'p', 'r', 'a', 'y', '\n',
        's', 'p', 'r', 'a', 'y', 'e', 'd', '\n',
        's', 'p', 'r', 'a', 'y', 'e', 'r', '\n',
        's', 'p', 'r', 'a', 'y', 'e', 'r', 's', '\n',
        's', 'p', 'r', 'a', 'y', 'i', 'n', 'g', '\n',
        's', 'p', 'r', 'a', 'y', 's', '\n',
        's', 'p', 'r', 'e', 'a', 'd', '\n',
        's', 'p', 'r', 'e', 'a', 'd', 'e', 'a', 'g', 'l', 'e', 'd', '\n',
        's', 'p', 'r', 'e', 'a', 'd', 'e', 'r', 's', '\n',
        's', 'p', 'r', 'e', 'a', 'd', 'i', 'n', 'g', '\n',
        's', 'p', 'r', 'e', 'a', 'd', 's', '\n',
        's', 'p', 'r', 'e', 'a', 'd', 's', 'h', 'e', 'e', 't', '\n',
        's', 'p', 'r', 'e', 'a', 'd', 's', 'h', 'e', 'e', 't', 's', '\n',
        's', 'p', 'r', 'e', 'e', '\n',
        's', 'p', 'r', 'e', 'e', 'i', 'n', 'g', '\n',
        's', 'p', 'r', 'i', 'g', '\n',
        's', 'p', 'r', 'i', 'g', 'h', 't', 'l', 'i', 'e', 'r', '\n',
        's', 'p', 'r', 'i', 'g', 'h', 't', 'l', 'i', 'e', 's', 't', '\n',
        's', 'p', 'r', 'i', 'g', 'h', 't', 'l', 'i', 'n', 'e', 's', 's', '\n',
        's', 'p', 'r', 'i', 'g', 'h', 't', 'l', 'y', '\n',
        's', 'p', 'r', 'i', 'g', 's', '\n',
        's', 'p', 'r', 'i', 'n', 'g', '\n',
        's', 'p', 'r', 'i', 'n', 'g', 'b', 'o', 'a', 'r', 'd', '\n',
        's', 'p', 'r', 'i', 'n', 'g', 'b', 'o', 'a', 'r', 'd', 's', '\n',
        's', 'p', 'r', 'i', 'n', 'g', 'b', 'o', 'k', '\n',
        's', 'p', 'r', 'i', 'n', 'g', 'b', 'o', 'k', 's', '\n',
        's', 'p', 'r', 'i', 'n', 'g', 'c', 'l', 'e', 'a', 'n', '\n',
        's', 'p', 'r', 'i', 'n', 'g', 'c', 'l', 'e', 'a', 'n', 'e', 'd', '\n',
        's', 'p', 'r', 'i', 'n', 'g', 'e', 'r', '\n',
        's', 'p', 'r', 'i', 'n', 'g', 'i', 'e', 'r', '\n',
        's', 'p', 'r', 'i', 'n', 'g', 'i', 'e', 's', 't', '\n',
        's', 'p', 'r', 'i', 'n', 'g', 'i', 'n', 'g', '\n',
        's', 'p', 'r', 'i', 'n', 'g', 's', '\n',
        's', 'p', 'r', 'i', 'n', 'g', 't', 'i', 'm', 'e', '\n',
        's', 'p', 'r', 'i', 'n', 'g', 'y', '\n',
        's', 'p', 'r', 'i', 'n', 'k', 'l', 'e', '\n',
        's', 'p', 'r', 'i', 'n', 'k', 'l', 'e', 'd', '\n',
        's', 'p', 'r', 'i', 'n', 'k', 'l', 'e', 'r', '\n',
        's', 'p', 'r', 'i', 'n', 'k', 'l', 'e', 'r', 's', '\n',
        's', 'p', 'r', 'i', 'n', 'k', 'l', 'e', 's', '\n',
        's', 'p', 'r', 'i', 'n', 'k', 'l', 'i', 'n', 'g', '\n',
        's', 'p', 'r', 'i', 'n', 't', '\n',
        's', 'p', 'r', 'i', 'n', 't', 'e', 'd', '\n',
        's', 'p', 'r', 'i', 'n', 't', 'e', 'r', '\n',
        's', 'p', 'r', 'i', 'n', 't', 'e', 'r', 's', '\n',
        's', 'p', 'r', 'i', 'n', 't', 'i', 'n', 'g', '\n',
        's', 'p', 'r', 'i', 'n', 't', 's', '\n',
        's', 'p', 'r', 'i', 't', 'e', '\n',
        's', 'p', 'r', 'i', 't', 'e', 's', '\n',
        's', 'p', 'r', 'o', 'c', 'k', 'e', 't', '\n',
        's', 'p', 'r', 'o', 'c', 'k', 'e', 't', 's', '\n',
        's', 'p', 'r', 'o', 'u', 't', '\n',
        's', 'p', 'r', 'o', 'u', 't', 'e', 'd', '\n',
        's', 'p', 'r', 'o', 'u', 't', 'i', 'n', 'g', '\n',
        's', 'p', 'r', 'o', 'u', 't', 's', '\n',
        's', 'p', 'r', 'u', 'c', 'e', '\n',
        's', 'p', 'r', 'u', 'c', 'e', 'd', '\n',
        's', 'p', 'r', 'u', 'c', 'i', 'n', 'g', '\n',
        's', 'p', 'r', 'u', 'n', 'g', '\n',
        's', 'p', 'r', 'y', '\n',
        's', 'p', 'u', 'd', '\n',
        's', 'p', 'u', 'm', 'e', '\n',
        's', 'p', 'u', 'n', '\n',
        's', 'p', 'u', 'n', 'k', 'y', '\n',
        's', 'p', 'u', 'r', '\n',
        's', 'p', 'u', 'r', 'g', 'e', '\n',
        's', 'p', 'u', 'r', 'g', 'e', 's', '\n',
        's', 'p', 'u', 'r', 'i', 'o', 'u', 's', '\n',
        's', 'p', 'u', 'r', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        's', 'p', 'u', 'r', 'n', '\n',
        's', 'p', 'u', 'r', 'n', 'e', 'd', '\n',
        's', 'p', 'u', 'r', 'n', 'i', 'n', 'g', '\n',
        's', 'p', 'u', 'r', 'n', 's', '\n',
        's', 'p', 'u', 'r', 'r', 'e', 'd', '\n',
        's', 'p', 'u', 'r', 'r', 'i', 'n', 'g', '\n',
        's', 'p', 'u', 'r', 's', '\n',
        's', 'p', 'u', 'r', 't', '\n',
        's', 'p', 'u', 'r', 't', 'e', 'd', '\n',
        's', 'p', 'u', 'r', 't', 'i', 'n', 'g', '\n',
        's', 'p', 'u', 'r', 't', 's', '\n',
        's', 'p', 'u', 't', 'n', 'i', 'k', '\n',
        's', 'p', 'u', 't', 'n', 'i', 'k', 's', '\n',
        's', 'p', 'u', 't', 't', 'e', 'r', '\n',
        's', 'p', 'u', 't', 't', 'e', 'r', 'e', 'd', '\n',
        's', 'p', 'u', 't', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'p', 'u', 't', 'u', 'm', '\n',
        's', 'p', 'y', '\n',
        's', 'p', 'y', 'g', 'l', 'a', 's', 's', '\n',
        's', 'p', 'y', 'h', 'o', 'l', 'e', '\n',
        's', 'p', 'y', 'i', 'n', 'g', '\n',
        's', 'p', 'y', 'i', 'n', 'g', 's', '\n',
        's', 'q', 'u', 'a', 'b', 'b', 'l', 'e', '\n',
        's', 'q', 'u', 'a', 'b', 'b', 'l', 'e', 'd', '\n',
        's', 'q', 'u', 'a', 'b', 'b', 'l', 'e', 's', '\n',
        's', 'q', 'u', 'a', 'b', 'b', 'l', 'i', 'n', 'g', '\n',
        's', 'q', 'u', 'a', 'd', '\n',
        's', 'q', 'u', 'a', 'd', 'r', 'o', 'n', '\n',
        's', 'q', 'u', 'a', 'd', 'r', 'o', 'n', 's', '\n',
        's', 'q', 'u', 'a', 'd', 's', '\n',
        's', 'q', 'u', 'a', 'l', 'i', 'd', '\n',
        's', 'q', 'u', 'a', 'l', 'l', '\n',
        's', 'q', 'u', 'a', 'l', 'l', 'i', 'n', 'g', '\n',
        's', 'q', 'u', 'a', 'l', 'l', 's', '\n',
        's', 'q', 'u', 'a', 'l', 'l', 'y', '\n',
        's', 'q', 'u', 'a', 'l', 'o', 'r', '\n',
        's', 'q', 'u', 'a', 'n', 'd', 'e', 'r', '\n',
        's', 'q', 'u', 'a', 'n', 'd', 'e', 'r', 'e', 'd', '\n',
        's', 'q', 'u', 'a', 'n', 'd', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'q', 'u', 'a', 'n', 'd', 'e', 'r', 's', '\n',
        's', 'q', 'u', 'a', 'r', 'e', '\n',
        's', 'q', 'u', 'a', 'r', 'e', 'd', '\n',
        's', 'q', 'u', 'a', 'r', 'e', 'l', 'y', '\n',
        's', 'q', 'u', 'a', 'r', 'e', 'n', 'e', 's', 's', '\n',
        's', 'q', 'u', 'a', 'r', 'e', 'r', '\n',
        's', 'q', 'u', 'a', 'r', 'e', 's', '\n',
        's', 'q', 'u', 'a', 'r', 'i', 'n', 'g', '\n',
        's', 'q', 'u', 'a', 'r', 'i', 's', 'h', '\n',
        's', 'q', 'u', 'a', 's', 'h', '\n',
        's', 'q', 'u', 'a', 's', 'h', 'e', 'd', '\n',
        's', 'q', 'u', 'a', 's', 'h', 'e', 's', '\n',
        's', 'q', 'u', 'a', 's', 'h', 'i', 'e', 'r', '\n',
        's', 'q', 'u', 'a', 's', 'h', 'i', 'e', 's', 't', '\n',
        's', 'q', 'u', 'a', 's', 'h', 'i', 'n', 'g', '\n',
        's', 'q', 'u', 'a', 's', 'h', 'y', '\n',
        's', 'q', 'u', 'a', 't', '\n',
        's', 'q', 'u', 'a', 't', 's', '\n',
        's', 'q', 'u', 'a', 't', 't', 'e', 'd', '\n',
        's', 'q', 'u', 'a', 't', 't', 'e', 'r', '\n',
        's', 'q', 'u', 'a', 't', 't', 'e', 'r', 's', '\n',
        's', 'q', 'u', 'a', 't', 't', 'i', 'n', 'g', '\n',
        's', 'q', 'u', 'a', 'w', '\n',
        's', 'q', 'u', 'a', 'w', 'k', '\n',
        's', 'q', 'u', 'a', 'w', 'k', 'e', 'd', '\n',
        's', 'q', 'u', 'a', 'w', 'k', 'i', 'n', 'g', '\n',
        's', 'q', 'u', 'a', 'w', 'k', 's', '\n',
        's', 'q', 'u', 'e', 'a', 'k', '\n',
        's', 'q', 'u', 'e', 'a', 'k', 'e', 'd', '\n',
        's', 'q', 'u', 'e', 'a', 'k', 'e', 'r', '\n',
        's', 'q', 'u', 'e', 'a', 'k', 'i', 'e', 'r', '\n',
        's', 'q', 'u', 'e', 'a', 'k', 'i', 'e', 's', 't', '\n',
        's', 'q', 'u', 'e', 'a', 'k', 'i', 'n', 'g', '\n',
        's', 'q', 'u', 'e', 'a', 'k', 's', '\n',
        's', 'q', 'u', 'e', 'a', 'k', 'y', '\n',
        's', 'q', 'u', 'e', 'a', 'l', '\n',
        's', 'q', 'u', 'e', 'a', 'l', 'e', 'd', '\n',
        's', 'q', 'u', 'e', 'a', 'l', 'e', 'r', '\n',
        's', 'q', 'u', 'e', 'a', 'l', 'i', 'n', 'g', '\n',
        's', 'q', 'u', 'e', 'a', 'l', 's', '\n',
        's', 'q', 'u', 'e', 'a', 'm', 'i', 's', 'h', '\n',
        's', 'q', 'u', 'e', 'a', 'm', 'i', 's', 'h', 'l', 'y', '\n',
        's', 'q', 'u', 'e', 'a', 'm', 'i', 's', 'h', 'n', 'e', 's', 's', '\n',
        's', 'q', 'u', 'e', 'e', 'g', 'e', 'e', '\n',
        's', 'q', 'u', 'e', 'e', 'z', 'e', '\n',
        's', 'q', 'u', 'e', 'e', 'z', 'e', 'd', '\n',
        's', 'q', 'u', 'e', 'e', 'z', 'e', 'r', '\n',
        's', 'q', 'u', 'e', 'e', 'z', 'e', 's', '\n',
        's', 'q', 'u', 'e', 'e', 'z', 'i', 'n', 'g', '\n',
        's', 'q', 'u', 'e', 'e', 'z', 'y', '\n',
        's', 'q', 'u', 'e', 'l', 'c', 'h', '\n',
        's', 'q', 'u', 'e', 'l', 'c', 'h', 'e', 'd', '\n',
        's', 'q', 'u', 'e', 'l', 'c', 'h', 'i', 'n', 'g', '\n',
        's', 'q', 'u', 'e', 'l', 'c', 'h', 'y', '\n',
        's', 'q', 'u', 'i', 'b', '\n',
        's', 'q', 'u', 'i', 'b', 's', '\n',
        's', 'q', 'u', 'i', 'd', '\n',
        's', 'q', 'u', 'i', 'd', 's', '\n',
        's', 'q', 'u', 'i', 'g', 'g', 'l', 'e', '\n',
        's', 'q', 'u', 'i', 'g', 'g', 'l', 'e', 's', '\n',
        's', 'q', 'u', 'i', 'n', 't', '\n',
        's', 'q', 'u', 'i', 'n', 't', 'e', 'd', '\n',
        's', 'q', 'u', 'i', 'n', 't', 'i', 'n', 'g', '\n',
        's', 'q', 'u', 'i', 'n', 't', 's', '\n',
        's', 'q', 'u', 'i', 'r', 'e', '\n',
        's', 'q', 'u', 'i', 'r', 'e', 'a', 'r', 'c', 'h', 'y', '\n',
        's', 'q', 'u', 'i', 'r', 'e', 's', '\n',
        's', 'q', 'u', 'i', 'r', 'm', '\n',
        's', 'q', 'u', 'i', 'r', 'm', 'e', 'd', '\n',
        's', 'q', 'u', 'i', 'r', 'm', 'i', 'n', 'g', '\n',
        's', 'q', 'u', 'i', 'r', 'm', 's', '\n',
        's', 'q', 'u', 'i', 'r', 'r', 'e', 'l', '\n',
        's', 'q', 'u', 'i', 'r', 'r', 'e', 'l', 'l', 'e', 'd', '\n',
        's', 'q', 'u', 'i', 'r', 'r', 'e', 'l', 's', '\n',
        's', 'q', 'u', 'i', 'r', 't', '\n',
        's', 'q', 'u', 'i', 'r', 't', 'e', 'd', '\n',
        's', 'q', 'u', 'i', 'r', 't', 'i', 'n', 'g', '\n',
        's', 'q', 'u', 'i', 'r', 't', 's', '\n',
        's', 'r', 'i', 'l', 'a', 'n', 'k', 'a', '\n',
        's', 't', 'a', 'b', '\n',
        's', 't', 'a', 'b', 'b', 'e', 'd', '\n',
        's', 't', 'a', 'b', 'b', 'e', 'r', '\n',
        's', 't', 'a', 'b', 'b', 'i', 'n', 'g', '\n',
        's', 't', 'a', 'b', 'b', 'i', 'n', 'g', 's', '\n',
        's', 't', 'a', 'b', 'i', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        's', 't', 'a', 'b', 'i', 'l', 'i', 's', 'e', '\n',
        's', 't', 'a', 'b', 'i', 'l', 'i', 's', 'e', 'd', '\n',
        's', 't', 'a', 'b', 'i', 'l', 'i', 's', 'e', 'r', '\n',
        's', 't', 'a', 'b', 'i', 'l', 'i', 's', 'e', 'r', 's', '\n',
        's', 't', 'a', 'b', 'i', 'l', 'i', 's', 'e', 's', '\n',
        's', 't', 'a', 'b', 'i', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        's', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        's', 't', 'a', 'b', 'l', 'e', '\n',
        's', 't', 'a', 'b', 'l', 'e', 'd', '\n',
        's', 't', 'a', 'b', 'l', 'e', 'm', 'a', 't', 'e', '\n',
        's', 't', 'a', 'b', 'l', 'e', 'r', '\n',
        's', 't', 'a', 'b', 'l', 'e', 's', '\n',
        's', 't', 'a', 'b', 'l', 'i', 'n', 'g', '\n',
        's', 't', 'a', 'b', 'l', 'y', '\n',
        's', 't', 'a', 'b', 's', '\n',
        's', 't', 'a', 'c', 'c', 'a', 't', 'o', '\n',
        's', 't', 'a', 'c', 'k', '\n',
        's', 't', 'a', 'c', 'k', 'e', 'd', '\n',
        's', 't', 'a', 'c', 'k', 'e', 'r', '\n',
        's', 't', 'a', 'c', 'k', 'i', 'n', 'g', '\n',
        's', 't', 'a', 'c', 'k', 's', '\n',
        's', 't', 'a', 'd', 'i', 'a', '\n',
        's', 't', 'a', 'd', 'i', 'u', 'm', '\n',
        's', 't', 'a', 'd', 'i', 'u', 'm', 's', '\n',
        's', 't', 'a', 'f', 'f', '\n',
        's', 't', 'a', 'f', 'f', 'e', 'd', '\n',
        's', 't', 'a', 'f', 'f', 'i', 'n', 'g', '\n',
        's', 't', 'a', 'f', 'f', 'r', 'o', 'o', 'm', '\n',
        's', 't', 'a', 'f', 'f', 's', '\n',
        's', 't', 'a', 'g', '\n',
        's', 't', 'a', 'g', 'e', '\n',
        's', 't', 'a', 'g', 'e', 'c', 'o', 'a', 'c', 'h', '\n',
        's', 't', 'a', 'g', 'e', 'c', 'o', 'a', 'c', 'h', 'e', 's', '\n',
        's', 't', 'a', 'g', 'e', 'd', '\n',
        's', 't', 'a', 'g', 'e', 'h', 'a', 'n', 'd', 's', '\n',
        's', 't', 'a', 'g', 'e', 'r', '\n',
        's', 't', 'a', 'g', 'e', 's', '\n',
        's', 't', 'a', 'g', 'e', 'y', '\n',
        's', 't', 'a', 'g', 'f', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        's', 't', 'a', 'g', 'g', 'e', 'r', '\n',
        's', 't', 'a', 'g', 'g', 'e', 'r', 'e', 'd', '\n',
        's', 't', 'a', 'g', 'g', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 't', 'a', 'g', 'g', 'e', 'r', 'i', 'n', 'g', 'l', 'y', '\n',
        's', 't', 'a', 'g', 'g', 'e', 'r', 's', '\n',
        's', 't', 'a', 'g', 'i', 'n', 'g', '\n',
        's', 't', 'a', 'g', 'i', 'n', 'g', 's', '\n',
        's', 't', 'a', 'g', 'n', 'a', 'n', 'c', 'y', '\n',
        's', 't', 'a', 'g', 'n', 'a', 'n', 't', '\n',
        's', 't', 'a', 'g', 'n', 'a', 't', 'e', '\n',
        's', 't', 'a', 'g', 'n', 'a', 't', 'e', 'd', '\n',
        's', 't', 'a', 'g', 'n', 'a', 't', 'e', 's', '\n',
        's', 't', 'a', 'g', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        's', 't', 'a', 'g', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        's', 't', 'a', 'g', 's', '\n',
        's', 't', 'a', 'i', 'd', '\n',
        's', 't', 'a', 'i', 'd', 'n', 'e', 's', 's', '\n',
        's', 't', 'a', 'i', 'n', '\n',
        's', 't', 'a', 'i', 'n', 'e', 'd', '\n',
        's', 't', 'a', 'i', 'n', 'e', 'r', '\n',
        's', 't', 'a', 'i', 'n', 'i', 'n', 'g', '\n',
        's', 't', 'a', 'i', 'n', 'l', 'e', 's', 's', '\n',
        's', 't', 'a', 'i', 'n', 's', '\n',
        's', 't', 'a', 'i', 'r', '\n',
        's', 't', 'a', 'i', 'r', 'c', 'a', 's', 'e', '\n',
        's', 't', 'a', 'i', 'r', 'c', 'a', 's', 'e', 's', '\n',
        's', 't', 'a', 'i', 'r', 'h', 'e', 'a', 'd', '\n',
        's', 't', 'a', 'i', 'r', 's', '\n',
        's', 't', 'a', 'i', 'r', 'w', 'a', 'y', '\n',
        's', 't', 'a', 'i', 'r', 'w', 'a', 'y', 's', '\n',
        's', 't', 'a', 'i', 'r', 'w', 'e', 'l', 'l', '\n',
        's', 't', 'a', 'i', 'r', 'w', 'e', 'l', 'l', 's', '\n',
        's', 't', 'a', 'k', 'e', '\n',
        's', 't', 'a', 'k', 'e', 'd', '\n',
        's', 't', 'a', 'k', 'e', 'h', 'o', 'l', 'd', 'e', 'r', '\n',
        's', 't', 'a', 'k', 'e', 'h', 'o', 'l', 'd', 'e', 'r', 's', '\n',
        's', 't', 'a', 'k', 'e', 's', '\n',
        's', 't', 'a', 'k', 'i', 'n', 'g', '\n',
        's', 't', 'a', 'l', 'a', 'c', 't', 'i', 't', 'e', '\n',
        's', 't', 'a', 'l', 'a', 'c', 't', 'i', 't', 'e', 's', '\n',
        's', 't', 'a', 'l', 'a', 'g', 'm', 'i', 't', 'e', '\n',
        's', 't', 'a', 'l', 'a', 'g', 'm', 'i', 't', 'e', 's', '\n',
        's', 't', 'a', 'l', 'e', '\n',
        's', 't', 'a', 'l', 'e', 'm', 'a', 't', 'e', '\n',
        's', 't', 'a', 'l', 'e', 'm', 'a', 't', 'e', 'd', '\n',
        's', 't', 'a', 'l', 'e', 'm', 'a', 't', 'e', 's', '\n',
        's', 't', 'a', 'l', 'e', 'n', 'e', 's', 's', '\n',
        's', 't', 'a', 'l', 'i', 'n', '\n',
        's', 't', 'a', 'l', 'k', '\n',
        's', 't', 'a', 'l', 'k', 'e', 'd', '\n',
        's', 't', 'a', 'l', 'k', 'e', 'r', '\n',
        's', 't', 'a', 'l', 'k', 'e', 'r', 's', '\n',
        's', 't', 'a', 'l', 'k', 'i', 'n', 'g', '\n',
        's', 't', 'a', 'l', 'k', 's', '\n',
        's', 't', 'a', 'l', 'l', '\n',
        's', 't', 'a', 'l', 'l', 'e', 'd', '\n',
        's', 't', 'a', 'l', 'l', 'h', 'o', 'l', 'd', 'e', 'r', 's', '\n',
        's', 't', 'a', 'l', 'l', 'i', 'n', 'g', '\n',
        's', 't', 'a', 'l', 'l', 'i', 'o', 'n', '\n',
        's', 't', 'a', 'l', 'l', 'i', 'o', 'n', 's', '\n',
        's', 't', 'a', 'l', 'l', 's', '\n',
        's', 't', 'a', 'l', 'w', 'a', 'r', 't', '\n',
        's', 't', 'a', 'l', 'w', 'a', 'r', 't', 's', '\n',
        's', 't', 'a', 'm', 'e', 'n', '\n',
        's', 't', 'a', 'm', 'e', 'n', 's', '\n',
        's', 't', 'a', 'm', 'i', 'n', 'a', '\n',
        's', 't', 'a', 'm', 'm', 'e', 'r', '\n',
        's', 't', 'a', 'm', 'm', 'e', 'r', 'e', 'd', '\n',
        's', 't', 'a', 'm', 'm', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 't', 'a', 'm', 'm', 'e', 'r', 's', '\n',
        's', 't', 'a', 'm', 'p', '\n',
        's', 't', 'a', 'm', 'p', 'e', 'd', '\n',
        's', 't', 'a', 'm', 'p', 'e', 'd', 'e', '\n',
        's', 't', 'a', 'm', 'p', 'e', 'd', 'e', 'd', '\n',
        's', 't', 'a', 'm', 'p', 'e', 'd', 'i', 'n', 'g', '\n',
        's', 't', 'a', 'm', 'p', 'e', 'r', '\n',
        's', 't', 'a', 'm', 'p', 'e', 'r', 's', '\n',
        's', 't', 'a', 'm', 'p', 'i', 'n', 'g', '\n',
        's', 't', 'a', 'm', 'p', 'i', 'n', 'g', 's', '\n',
        's', 't', 'a', 'm', 'p', 's', '\n',
        's', 't', 'a', 'n', 'c', 'e', '\n',
        's', 't', 'a', 'n', 'c', 'e', 's', '\n',
        's', 't', 'a', 'n', 'c', 'h', 'i', 'o', 'n', '\n',
        's', 't', 'a', 'n', 'c', 'h', 'i', 'o', 'n', 's', '\n',
        's', 't', 'a', 'n', 'd', '\n',
        's', 't', 'a', 'n', 'd', 'a', 'r', 'd', '\n',
        's', 't', 'a', 'n', 'd', 'a', 'r', 'd', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        's', 't', 'a', 'n', 'd', 'a', 'r', 'd', 'i', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        's', 't', 'a', 'n', 'd', 'a', 'r', 'd', 'i', 's', 'e', '\n',
        's', 't', 'a', 'n', 'd', 'a', 'r', 'd', 'i', 's', 'e', 'd', '\n',
        's', 't', 'a', 'n', 'd', 'a', 'r', 'd', 'i', 's', 'e', 's', '\n',
        's', 't', 'a', 'n', 'd', 'a', 'r', 'd', 'i', 's', 'i', 'n', 'g', '\n',
        's', 't', 'a', 'n', 'd', 'a', 'r', 'd', 's', '\n',
        's', 't', 'a', 'n', 'd', 'b', 'y', '\n',
        's', 't', 'a', 'n', 'd', 'i', 'n', 'g', '\n',
        's', 't', 'a', 'n', 'd', 'i', 'n', 'g', 's', '\n',
        's', 't', 'a', 'n', 'd', 'p', 'o', 'i', 'n', 't', '\n',
        's', 't', 'a', 'n', 'd', 'p', 'o', 'i', 'n', 't', 's', '\n',
        's', 't', 'a', 'n', 'd', 's', '\n',
        's', 't', 'a', 'n', 'd', 's', 't', 'i', 'l', 'l', '\n',
        's', 't', 'a', 'n', 'k', '\n',
        's', 't', 'a', 'n', 'z', 'a', '\n',
        's', 't', 'a', 'n', 'z', 'a', 's', '\n',
        's', 't', 'a', 'p', 'e', 's', '\n',
        's', 't', 'a', 'p', 'h', 'y', 'l', 'o', 'c', 'o', 'c', 'c', 'u', 's', '\n',
        's', 't', 'a', 'p', 'l', 'e', '\n',
        's', 't', 'a', 'p', 'l', 'e', 'd', '\n',
        's', 't', 'a', 'p', 'l', 'e', 'r', '\n',
        's', 't', 'a', 'p', 'l', 'e', 'r', 's', '\n',
        's', 't', 'a', 'p', 'l', 'e', 's', '\n',
        's', 't', 'a', 'p', 'l', 'i', 'n', 'g', '\n',
        's', 't', 'a', 'r', '\n',
        's', 't', 'a', 'r', 'b', 'o', 'a', 'r', 'd', '\n',
        's', 't', 'a', 'r', 'c', 'h', '\n',
        's', 't', 'a', 'r', 'c', 'h', 'e', 'd', '\n',
        's', 't', 'a', 'r', 'c', 'h', 'e', 's', '\n',
        's', 't', 'a', 'r', 'c', 'h', 'i', 'e', 'r', '\n',
        's', 't', 'a', 'r', 'c', 'h', 'i', 'e', 's', 't', '\n',
        's', 't', 'a', 'r', 'c', 'h', 'y', '\n',
        's', 't', 'a', 'r', 'd', 'o', 'm', '\n',
        's', 't', 'a', 'r', 'd', 'u', 's', 't', '\n',
        's', 't', 'a', 'r', 'e', '\n',
        's', 't', 'a', 'r', 'e', 'd', '\n',
        's', 't', 'a', 'r', 'e', 'r', '\n',
        's', 't', 'a', 'r', 'e', 's', '\n',
        's', 't', 'a', 'r', 'f', 'i', 's', 'h', '\n',
        's', 't', 'a', 'r', 'g', 'a', 'z', 'e', '\n',
        's', 't', 'a', 'r', 'g', 'a', 'z', 'e', 'r', '\n',
        's', 't', 'a', 'r', 'g', 'a', 'z', 'e', 'r', 's', '\n',
        's', 't', 'a', 'r', 'g', 'a', 'z', 'i', 'n', 'g', '\n',
        's', 't', 'a', 'r', 'i', 'n', 'g', '\n',
        's', 't', 'a', 'r', 'k', '\n',
        's', 't', 'a', 'r', 'k', 'e', 'r', '\n',
        's', 't', 'a', 'r', 'k', 'e', 's', 't', '\n',
        's', 't', 'a', 'r', 'k', 'l', 'y', '\n',
        's', 't', 'a', 'r', 'k', 'n', 'e', 's', 's', '\n',
        's', 't', 'a', 'r', 'l', 'e', 's', 's', '\n',
        's', 't', 'a', 'r', 'l', 'e', 't', '\n',
        's', 't', 'a', 'r', 'l', 'e', 't', 's', '\n',
        's', 't', 'a', 'r', 'l', 'i', 'g', 'h', 't', '\n',
        's', 't', 'a', 'r', 'l', 'i', 'k', 'e', '\n',
        's', 't', 'a', 'r', 'l', 'i', 'n', 'g', '\n',
        's', 't', 'a', 'r', 'l', 'i', 'n', 'g', 's', '\n',
        's', 't', 'a', 'r', 'l', 'i', 't', '\n',
        's', 't', 'a', 'r', 'r', 'e', 'd', '\n',
        's', 't', 'a', 'r', 'r', 'i', 'e', 'r', '\n',
        's', 't', 'a', 'r', 'r', 'i', 'e', 's', 't', '\n',
        's', 't', 'a', 'r', 'r', 'i', 'n', 'g', '\n',
        's', 't', 'a', 'r', 'r', 'y', '\n',
        's', 't', 'a', 'r', 'r', 'y', 'e', 'y', 'e', 'd', '\n',
        's', 't', 'a', 'r', 's', '\n',
        's', 't', 'a', 'r', 's', 'h', 'i', 'p', '\n',
        's', 't', 'a', 'r', 's', 'p', 'a', 'n', 'g', 'l', 'e', 'd', '\n',
        's', 't', 'a', 'r', 's', 't', 'r', 'u', 'c', 'k', '\n',
        's', 't', 'a', 'r', 's', 't', 'u', 'd', 'd', 'e', 'd', '\n',
        's', 't', 'a', 'r', 't', '\n',
        's', 't', 'a', 'r', 't', 'e', 'd', '\n',
        's', 't', 'a', 'r', 't', 'e', 'r', '\n',
        's', 't', 'a', 'r', 't', 'e', 'r', 's', '\n',
        's', 't', 'a', 'r', 't', 'i', 'n', 'g', '\n',
        's', 't', 'a', 'r', 't', 'l', 'e', '\n',
        's', 't', 'a', 'r', 't', 'l', 'e', 'd', '\n',
        's', 't', 'a', 'r', 't', 'l', 'e', 's', '\n',
        's', 't', 'a', 'r', 't', 'l', 'i', 'n', 'g', '\n',
        's', 't', 'a', 'r', 't', 'l', 'i', 'n', 'g', 'l', 'y', '\n',
        's', 't', 'a', 'r', 't', 's', '\n',
        's', 't', 'a', 'r', 't', 'u', 'p', '\n',
        's', 't', 'a', 'r', 't', 'u', 'p', 's', '\n',
        's', 't', 'a', 'r', 'v', 'a', 't', 'i', 'o', 'n', '\n',
        's', 't', 'a', 'r', 'v', 'e', '\n',
        's', 't', 'a', 'r', 'v', 'e', 'd', '\n',
        's', 't', 'a', 'r', 'v', 'e', 's', '\n',
        's', 't', 'a', 'r', 'v', 'i', 'n', 'g', '\n',
        's', 't', 'a', 's', 'h', 'e', 'd', '\n',
        's', 't', 'a', 's', 'h', 'e', 's', '\n',
        's', 't', 'a', 's', 'h', 'i', 'n', 'g', '\n',
        's', 't', 'a', 's', 'i', 's', '\n',
        's', 't', 'a', 't', 'e', '\n',
        's', 't', 'a', 't', 'e', 'c', 'r', 'a', 'f', 't', '\n',
        's', 't', 'a', 't', 'e', 'd', '\n',
        's', 't', 'a', 't', 'e', 'h', 'o', 'o', 'd', '\n',
        's', 't', 'a', 't', 'e', 'l', 'e', 's', 's', '\n',
        's', 't', 'a', 't', 'e', 'l', 'i', 'e', 's', 't', '\n',
        's', 't', 'a', 't', 'e', 'l', 'i', 'n', 'e', 's', 's', '\n',
        's', 't', 'a', 't', 'e', 'l', 'y', '\n',
        's', 't', 'a', 't', 'e', 'm', 'e', 'n', 't', '\n',
        's', 't', 'a', 't', 'e', 'm', 'e', 'n', 't', 's', '\n',
        's', 't', 'a', 't', 'e', 'o', 'f', 't', 'h', 'e', 'a', 'r', 't', '\n',
        's', 't', 'a', 't', 'e', 'r', 'o', 'o', 'm', 's', '\n',
        's', 't', 'a', 't', 'e', 's', '\n',
        's', 't', 'a', 't', 'e', 's', 'm', 'a', 'n', '\n',
        's', 't', 'a', 't', 'e', 's', 'm', 'a', 'n', 'l', 'i', 'k', 'e', '\n',
        's', 't', 'a', 't', 'e', 's', 'm', 'a', 'n', 's', 'h', 'i', 'p', '\n',
        's', 't', 'a', 't', 'e', 's', 'm', 'e', 'n', '\n',
        's', 't', 'a', 't', 'i', 'c', '\n',
        's', 't', 'a', 't', 'i', 'c', 'a', 'l', '\n',
        's', 't', 'a', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 't', 'a', 't', 'i', 'c', 's', '\n',
        's', 't', 'a', 't', 'i', 'n', 'g', '\n',
        's', 't', 'a', 't', 'i', 'o', 'n', '\n',
        's', 't', 'a', 't', 'i', 'o', 'n', 'a', 'r', 'y', '\n',
        's', 't', 'a', 't', 'i', 'o', 'n', 'e', 'd', '\n',
        's', 't', 'a', 't', 'i', 'o', 'n', 'e', 'r', '\n',
        's', 't', 'a', 't', 'i', 'o', 'n', 'e', 'r', 's', '\n',
        's', 't', 'a', 't', 'i', 'o', 'n', 'e', 'r', 'y', '\n',
        's', 't', 'a', 't', 'i', 'o', 'n', 'i', 'n', 'g', '\n',
        's', 't', 'a', 't', 'i', 'o', 'n', 'm', 'a', 's', 't', 'e', 'r', '\n',
        's', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        's', 't', 'a', 't', 'i', 's', 't', 'i', 'c', '\n',
        's', 't', 'a', 't', 'i', 's', 't', 'i', 'c', 'a', 'l', '\n',
        's', 't', 'a', 't', 'i', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 't', 'a', 't', 'i', 's', 't', 'i', 'c', 'i', 'a', 'n', '\n',
        's', 't', 'a', 't', 'i', 's', 't', 'i', 'c', 'i', 'a', 'n', 's', '\n',
        's', 't', 'a', 't', 'i', 's', 't', 'i', 'c', 's', '\n',
        's', 't', 'a', 't', 'o', 'r', '\n',
        's', 't', 'a', 't', 'o', 'r', 's', '\n',
        's', 't', 'a', 't', 'u', 'a', 'r', 'y', '\n',
        's', 't', 'a', 't', 'u', 'e', '\n',
        's', 't', 'a', 't', 'u', 'e', 's', '\n',
        's', 't', 'a', 't', 'u', 'e', 's', 'q', 'u', 'e', '\n',
        's', 't', 'a', 't', 'u', 'e', 't', 't', 'e', '\n',
        's', 't', 'a', 't', 'u', 'e', 't', 't', 'e', 's', '\n',
        's', 't', 'a', 't', 'u', 'r', 'e', '\n',
        's', 't', 'a', 't', 'u', 'r', 'e', 's', '\n',
        's', 't', 'a', 't', 'u', 's', '\n',
        's', 't', 'a', 't', 'u', 's', 'e', 's', '\n',
        's', 't', 'a', 't', 'u', 't', 'e', '\n',
        's', 't', 'a', 't', 'u', 't', 'e', 's', '\n',
        's', 't', 'a', 't', 'u', 't', 'o', 'r', 'i', 'l', 'y', '\n',
        's', 't', 'a', 't', 'u', 't', 'o', 'r', 'y', '\n',
        's', 't', 'a', 'u', 'n', 'c', 'h', '\n',
        's', 't', 'a', 'u', 'n', 'c', 'h', 'e', 's', 't', '\n',
        's', 't', 'a', 'u', 'n', 'c', 'h', 'i', 'n', 'g', '\n',
        's', 't', 'a', 'u', 'n', 'c', 'h', 'l', 'y', '\n',
        's', 't', 'a', 'u', 'n', 'c', 'h', 'n', 'e', 's', 's', '\n',
        's', 't', 'a', 'v', 'e', '\n',
        's', 't', 'a', 'v', 'e', 'd', '\n',
        's', 't', 'a', 'v', 'e', 's', '\n',
        's', 't', 'a', 'v', 'i', 'n', 'g', '\n',
        's', 't', 'a', 'y', '\n',
        's', 't', 'a', 'y', 'e', 'd', '\n',
        's', 't', 'a', 'y', 'e', 'r', 's', '\n',
        's', 't', 'a', 'y', 'i', 'n', 'g', '\n',
        's', 't', 'a', 'y', 's', '\n',
        's', 't', 'e', 'a', 'd', '\n',
        's', 't', 'e', 'a', 'd', 'f', 'a', 's', 't', '\n',
        's', 't', 'e', 'a', 'd', 'f', 'a', 's', 't', 'l', 'y', '\n',
        's', 't', 'e', 'a', 'd', 'f', 'a', 's', 't', 'n', 'e', 's', 's', '\n',
        's', 't', 'e', 'a', 'd', 'i', 'e', 'd', '\n',
        's', 't', 'e', 'a', 'd', 'i', 'e', 'r', '\n',
        's', 't', 'e', 'a', 'd', 'i', 'e', 's', 't', '\n',
        's', 't', 'e', 'a', 'd', 'i', 'l', 'y', '\n',
        's', 't', 'e', 'a', 'd', 'i', 'n', 'e', 's', 's', '\n',
        's', 't', 'e', 'a', 'd', 'y', '\n',
        's', 't', 'e', 'a', 'd', 'y', 'g', 'o', 'i', 'n', 'g', '\n',
        's', 't', 'e', 'a', 'd', 'y', 'i', 'n', 'g', '\n',
        's', 't', 'e', 'a', 'k', '\n',
        's', 't', 'e', 'a', 'k', 's', '\n',
        's', 't', 'e', 'a', 'l', '\n',
        's', 't', 'e', 'a', 'l', 'e', 'r', '\n',
        's', 't', 'e', 'a', 'l', 'e', 'r', 's', '\n',
        's', 't', 'e', 'a', 'l', 'i', 'n', 'g', '\n',
        's', 't', 'e', 'a', 'l', 's', '\n',
        's', 't', 'e', 'a', 'l', 't', 'h', '\n',
        's', 't', 'e', 'a', 'l', 't', 'h', 'i', 'e', 'r', '\n',
        's', 't', 'e', 'a', 'l', 't', 'h', 'i', 'e', 's', 't', '\n',
        's', 't', 'e', 'a', 'l', 't', 'h', 'i', 'l', 'y', '\n',
        's', 't', 'e', 'a', 'l', 't', 'h', 'y', '\n',
        's', 't', 'e', 'a', 'm', '\n',
        's', 't', 'e', 'a', 'm', 'b', 'o', 'a', 't', '\n',
        's', 't', 'e', 'a', 'm', 'b', 'o', 'a', 't', 's', '\n',
        's', 't', 'e', 'a', 'm', 'e', 'd', '\n',
        's', 't', 'e', 'a', 'm', 'e', 'r', '\n',
        's', 't', 'e', 'a', 'm', 'e', 'r', 's', '\n',
        's', 't', 'e', 'a', 'm', 'i', 'e', 'r', '\n',
        's', 't', 'e', 'a', 'm', 'i', 'e', 's', 't', '\n',
        's', 't', 'e', 'a', 'm', 'i', 'n', 'g', '\n',
        's', 't', 'e', 'a', 'm', 'r', 'o', 'l', 'l', 'e', 'r', '\n',
        's', 't', 'e', 'a', 'm', 'r', 'o', 'l', 'l', 'e', 'r', 's', '\n',
        's', 't', 'e', 'a', 'm', 's', '\n',
        's', 't', 'e', 'a', 'm', 's', 'h', 'i', 'p', '\n',
        's', 't', 'e', 'a', 'm', 's', 'h', 'i', 'p', 's', '\n',
        's', 't', 'e', 'a', 'm', 'y', '\n',
        's', 't', 'e', 'e', 'd', '\n',
        's', 't', 'e', 'e', 'd', 's', '\n',
        's', 't', 'e', 'e', 'l', '\n',
        's', 't', 'e', 'e', 'l', 'c', 'l', 'a', 'd', '\n',
        's', 't', 'e', 'e', 'l', 'e', 'd', '\n',
        's', 't', 'e', 'e', 'l', 'i', 'n', 'g', '\n',
        's', 't', 'e', 'e', 'l', 's', '\n',
        's', 't', 'e', 'e', 'l', 'w', 'o', 'r', 'k', '\n',
        's', 't', 'e', 'e', 'l', 'w', 'o', 'r', 'k', 'e', 'r', '\n',
        's', 't', 'e', 'e', 'l', 'w', 'o', 'r', 'k', 'e', 'r', 's', '\n',
        's', 't', 'e', 'e', 'l', 'w', 'o', 'r', 'k', 's', '\n',
        's', 't', 'e', 'e', 'l', 'y', '\n',
        's', 't', 'e', 'e', 'p', '\n',
        's', 't', 'e', 'e', 'p', 'e', 'd', '\n',
        's', 't', 'e', 'e', 'p', 'e', 'n', '\n',
        's', 't', 'e', 'e', 'p', 'e', 'n', 'e', 'd', '\n',
        's', 't', 'e', 'e', 'p', 'e', 'n', 'i', 'n', 'g', '\n',
        's', 't', 'e', 'e', 'p', 'e', 'n', 's', '\n',
        's', 't', 'e', 'e', 'p', 'e', 'r', '\n',
        's', 't', 'e', 'e', 'p', 'e', 's', 't', '\n',
        's', 't', 'e', 'e', 'p', 'i', 'n', 'g', '\n',
        's', 't', 'e', 'e', 'p', 'l', 'e', '\n',
        's', 't', 'e', 'e', 'p', 'l', 'e', 'c', 'h', 'a', 's', 'e', '\n',
        's', 't', 'e', 'e', 'p', 'l', 'e', 'c', 'h', 'a', 's', 'e', 'r', '\n',
        's', 't', 'e', 'e', 'p', 'l', 'e', 'c', 'h', 'a', 's', 'e', 'r', 's', '\n',
        's', 't', 'e', 'e', 'p', 'l', 'e', 'c', 'h', 'a', 's', 'i', 'n', 'g', '\n',
        's', 't', 'e', 'e', 'p', 'l', 'e', 'd', '\n',
        's', 't', 'e', 'e', 'p', 'l', 'e', 'j', 'a', 'c', 'k', '\n',
        's', 't', 'e', 'e', 'p', 'l', 'e', 's', '\n',
        's', 't', 'e', 'e', 'p', 'l', 'y', '\n',
        's', 't', 'e', 'e', 'p', 'n', 'e', 's', 's', '\n',
        's', 't', 'e', 'e', 'p', 's', '\n',
        's', 't', 'e', 'e', 'r', '\n',
        's', 't', 'e', 'e', 'r', 'a', 'b', 'l', 'e', '\n',
        's', 't', 'e', 'e', 'r', 'a', 'g', 'e', '\n',
        's', 't', 'e', 'e', 'r', 'e', 'd', '\n',
        's', 't', 'e', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 't', 'e', 'e', 'r', 's', '\n',
        's', 't', 'e', 'g', 'o', 's', 'a', 'u', 'r', 'u', 's', '\n',
        's', 't', 'e', 'l', 'l', 'a', 'r', '\n',
        's', 't', 'e', 'l', 'l', 'a', 't', 'e', 'd', '\n',
        's', 't', 'e', 'm', '\n',
        's', 't', 'e', 'm', 'm', 'e', 'd', '\n',
        's', 't', 'e', 'm', 'm', 'i', 'n', 'g', '\n',
        's', 't', 'e', 'm', 's', '\n',
        's', 't', 'e', 'n', 'c', 'h', '\n',
        's', 't', 'e', 'n', 'c', 'h', 'e', 's', '\n',
        's', 't', 'e', 'n', 'c', 'i', 'l', '\n',
        's', 't', 'e', 'n', 'c', 'i', 'l', 'l', 'e', 'd', '\n',
        's', 't', 'e', 'n', 'c', 'i', 'l', 's', '\n',
        's', 't', 'e', 'n', 'o', 'g', 'r', 'a', 'p', 'h', 'e', 'r', '\n',
        's', 't', 'e', 'n', 'o', 'g', 'r', 'a', 'p', 'h', 'e', 'r', 's', '\n',
        's', 't', 'e', 'n', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', '\n',
        's', 't', 'e', 'n', 'o', 'g', 'r', 'a', 'p', 'h', 'y', '\n',
        's', 't', 'e', 'n', 'o', 's', 'i', 's', '\n',
        's', 't', 'e', 'n', 't', 'o', 'r', '\n',
        's', 't', 'e', 'n', 't', 'o', 'r', 'i', 'a', 'n', '\n',
        's', 't', 'e', 'p', '\n',
        's', 't', 'e', 'p', 'b', 'r', 'o', 't', 'h', 'e', 'r', '\n',
        's', 't', 'e', 'p', 'c', 'h', 'i', 'l', 'd', 'r', 'e', 'n', '\n',
        's', 't', 'e', 'p', 'd', 'a', 'u', 'g', 'h', 't', 'e', 'r', '\n',
        's', 't', 'e', 'p', 'f', 'a', 't', 'h', 'e', 'r', '\n',
        's', 't', 'e', 'p', 'l', 'a', 'd', 'd', 'e', 'r', '\n',
        's', 't', 'e', 'p', 'm', 'o', 't', 'h', 'e', 'r', '\n',
        's', 't', 'e', 'p', 'p', 'a', 'r', 'e', 'n', 't', 's', '\n',
        's', 't', 'e', 'p', 'p', 'e', '\n',
        's', 't', 'e', 'p', 'p', 'e', 'd', '\n',
        's', 't', 'e', 'p', 'p', 'e', 's', '\n',
        's', 't', 'e', 'p', 'p', 'i', 'n', 'g', '\n',
        's', 't', 'e', 'p', 's', '\n',
        's', 't', 'e', 'p', 's', 'i', 's', 't', 'e', 'r', '\n',
        's', 't', 'e', 'p', 's', 'o', 'n', '\n',
        's', 't', 'e', 'p', 's', 'o', 'n', 's', '\n',
        's', 't', 'e', 'p', 'w', 'i', 's', 'e', '\n',
        's', 't', 'e', 'r', 'a', 'd', 'i', 'a', 'n', 's', '\n',
        's', 't', 'e', 'r', 'e', 'o', '\n',
        's', 't', 'e', 'r', 'e', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', '\n',
        's', 't', 'e', 'r', 'e', 'o', 'p', 'h', 'o', 'n', 'i', 'c', '\n',
        's', 't', 'e', 'r', 'e', 'o', 's', '\n',
        's', 't', 'e', 'r', 'e', 'o', 's', 'c', 'o', 'p', 'i', 'c', '\n',
        's', 't', 'e', 'r', 'e', 'o', 's', 'c', 'o', 'p', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 't', 'e', 'r', 'e', 'o', 's', 'c', 'o', 'p', 'y', '\n',
        's', 't', 'e', 'r', 'e', 'o', 't', 'y', 'p', 'e', '\n',
        's', 't', 'e', 'r', 'e', 'o', 't', 'y', 'p', 'e', 'd', '\n',
        's', 't', 'e', 'r', 'e', 'o', 't', 'y', 'p', 'e', 's', '\n',
        's', 't', 'e', 'r', 'e', 'o', 't', 'y', 'p', 'i', 'c', 'a', 'l', '\n',
        's', 't', 'e', 'r', 'e', 'o', 't', 'y', 'p', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 't', 'e', 'r', 'e', 'o', 't', 'y', 'p', 'i', 'n', 'g', '\n',
        's', 't', 'e', 'r', 'i', 'l', 'e', '\n',
        's', 't', 'e', 'r', 'i', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        's', 't', 'e', 'r', 'i', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        's', 't', 'e', 'r', 'i', 'l', 'i', 's', 'e', '\n',
        's', 't', 'e', 'r', 'i', 'l', 'i', 's', 'e', 'd', '\n',
        's', 't', 'e', 'r', 'i', 'l', 'i', 's', 'e', 'r', '\n',
        's', 't', 'e', 'r', 'i', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        's', 't', 'e', 'r', 'i', 'l', 'i', 't', 'y', '\n',
        's', 't', 'e', 'r', 'l', 'i', 'n', 'g', '\n',
        's', 't', 'e', 'r', 'n', '\n',
        's', 't', 'e', 'r', 'n', 'e', 'r', '\n',
        's', 't', 'e', 'r', 'n', 'e', 's', 't', '\n',
        's', 't', 'e', 'r', 'n', 'l', 'y', '\n',
        's', 't', 'e', 'r', 'n', 'n', 'e', 's', 's', '\n',
        's', 't', 'e', 'r', 'n', 's', '\n',
        's', 't', 'e', 'r', 'n', 'u', 'm', '\n',
        's', 't', 'e', 'r', 'o', 'i', 'd', '\n',
        's', 't', 'e', 'r', 'o', 'i', 'd', 's', '\n',
        's', 't', 'e', 't', '\n',
        's', 't', 'e', 't', 'h', 'o', 's', 'c', 'o', 'p', 'e', '\n',
        's', 't', 'e', 'v', 'e', 'd', 'o', 'r', 'e', '\n',
        's', 't', 'e', 'w', '\n',
        's', 't', 'e', 'w', 'a', 'r', 'd', '\n',
        's', 't', 'e', 'w', 'a', 'r', 'd', 'e', 's', 's', '\n',
        's', 't', 'e', 'w', 'a', 'r', 'd', 'e', 's', 's', 'e', 's', '\n',
        's', 't', 'e', 'w', 'a', 'r', 'd', 's', '\n',
        's', 't', 'e', 'w', 'a', 'r', 'd', 's', 'h', 'i', 'p', '\n',
        's', 't', 'e', 'w', 'e', 'd', '\n',
        's', 't', 'e', 'w', 'i', 'n', 'g', '\n',
        's', 't', 'e', 'w', 's', '\n',
        's', 't', 'i', 'c', 'k', '\n',
        's', 't', 'i', 'c', 'k', 'e', 'r', '\n',
        's', 't', 'i', 'c', 'k', 'e', 'r', 's', '\n',
        's', 't', 'i', 'c', 'k', 'i', 'e', 's', 't', '\n',
        's', 't', 'i', 'c', 'k', 'i', 'l', 'y', '\n',
        's', 't', 'i', 'c', 'k', 'i', 'n', 'e', 's', 's', '\n',
        's', 't', 'i', 'c', 'k', 'i', 'n', 'g', '\n',
        's', 't', 'i', 'c', 'k', 'l', 'e', 'b', 'a', 'c', 'k', '\n',
        's', 't', 'i', 'c', 'k', 'l', 'e', 'b', 'a', 'c', 'k', 's', '\n',
        's', 't', 'i', 'c', 'k', 'l', 'e', 'r', '\n',
        's', 't', 'i', 'c', 'k', 's', '\n',
        's', 't', 'i', 'c', 'k', 'y', '\n',
        's', 't', 'i', 'e', 's', '\n',
        's', 't', 'i', 'f', 'f', '\n',
        's', 't', 'i', 'f', 'f', 'e', 'n', '\n',
        's', 't', 'i', 'f', 'f', 'e', 'n', 'e', 'd', '\n',
        's', 't', 'i', 'f', 'f', 'e', 'n', 'e', 'r', '\n',
        's', 't', 'i', 'f', 'f', 'e', 'n', 'i', 'n', 'g', '\n',
        's', 't', 'i', 'f', 'f', 'e', 'n', 's', '\n',
        's', 't', 'i', 'f', 'f', 'e', 'r', '\n',
        's', 't', 'i', 'f', 'f', 'e', 's', 't', '\n',
        's', 't', 'i', 'f', 'f', 'l', 'y', '\n',
        's', 't', 'i', 'f', 'f', 'n', 'e', 'c', 'k', 'e', 'd', '\n',
        's', 't', 'i', 'f', 'f', 'n', 'e', 's', 's', '\n',
        's', 't', 'i', 'f', 'l', 'e', '\n',
        's', 't', 'i', 'f', 'l', 'e', 'd', '\n',
        's', 't', 'i', 'f', 'l', 'e', 's', '\n',
        's', 't', 'i', 'f', 'l', 'i', 'n', 'g', '\n',
        's', 't', 'i', 'f', 'l', 'i', 'n', 'g', 'l', 'y', '\n',
        's', 't', 'i', 'g', 'm', 'a', '\n',
        's', 't', 'i', 'g', 'm', 'a', 's', '\n',
        's', 't', 'i', 'g', 'm', 'a', 't', 'a', '\n',
        's', 't', 'i', 'g', 'm', 'a', 't', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        's', 't', 'i', 'g', 'm', 'a', 't', 'i', 's', 'e', '\n',
        's', 't', 'i', 'g', 'm', 'a', 't', 'i', 's', 'e', 'd', '\n',
        's', 't', 'i', 'g', 'm', 'a', 't', 'i', 's', 'i', 'n', 'g', '\n',
        's', 't', 'i', 'l', 'e', 't', 't', 'o', '\n',
        's', 't', 'i', 'l', 'l', '\n',
        's', 't', 'i', 'l', 'l', 'b', 'i', 'r', 't', 'h', 's', '\n',
        's', 't', 'i', 'l', 'l', 'b', 'o', 'r', 'n', '\n',
        's', 't', 'i', 'l', 'l', 'e', 'd', '\n',
        's', 't', 'i', 'l', 'l', 'e', 'r', '\n',
        's', 't', 'i', 'l', 'l', 'i', 'n', 'g', '\n',
        's', 't', 'i', 'l', 'l', 'n', 'e', 's', 's', '\n',
        's', 't', 'i', 'l', 'l', 's', '\n',
        's', 't', 'i', 'l', 't', '\n',
        's', 't', 'i', 'l', 't', 'e', 'd', '\n',
        's', 't', 'i', 'l', 't', 's', '\n',
        's', 't', 'i', 'm', 'u', 'l', 'a', 'n', 't', '\n',
        's', 't', 'i', 'm', 'u', 'l', 'a', 'n', 't', 's', '\n',
        's', 't', 'i', 'm', 'u', 'l', 'a', 't', 'e', '\n',
        's', 't', 'i', 'm', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        's', 't', 'i', 'm', 'u', 'l', 'a', 't', 'e', 's', '\n',
        's', 't', 'i', 'm', 'u', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        's', 't', 'i', 'm', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        's', 't', 'i', 'm', 'u', 'l', 'a', 't', 'o', 'r', '\n',
        's', 't', 'i', 'm', 'u', 'l', 'a', 't', 'o', 'r', 'y', '\n',
        's', 't', 'i', 'm', 'u', 'l', 'i', '\n',
        's', 't', 'i', 'm', 'u', 'l', 'u', 's', '\n',
        's', 't', 'i', 'n', 'g', '\n',
        's', 't', 'i', 'n', 'g', 'e', 'd', '\n',
        's', 't', 'i', 'n', 'g', 'e', 'r', '\n',
        's', 't', 'i', 'n', 'g', 'e', 'r', 's', '\n',
        's', 't', 'i', 'n', 'g', 'i', 'e', 'r', '\n',
        's', 't', 'i', 'n', 'g', 'i', 'l', 'y', '\n',
        's', 't', 'i', 'n', 'g', 'i', 'n', 'g', '\n',
        's', 't', 'i', 'n', 'g', 'r', 'a', 'y', '\n',
        's', 't', 'i', 'n', 'g', 's', '\n',
        's', 't', 'i', 'n', 'g', 'y', '\n',
        's', 't', 'i', 'n', 'k', '\n',
        's', 't', 'i', 'n', 'k', 'e', 'r', '\n',
        's', 't', 'i', 'n', 'k', 'e', 'r', 's', '\n',
        's', 't', 'i', 'n', 'k', 'i', 'n', 'g', '\n',
        's', 't', 'i', 'n', 'k', 's', '\n',
        's', 't', 'i', 'n', 'k', 'y', '\n',
        's', 't', 'i', 'n', 't', '\n',
        's', 't', 'i', 'n', 't', 'e', 'd', '\n',
        's', 't', 'i', 'n', 't', 's', '\n',
        's', 't', 'i', 'p', 'e', 'l', '\n',
        's', 't', 'i', 'p', 'e', 'n', 'd', '\n',
        's', 't', 'i', 'p', 'e', 'n', 'd', 'i', 'a', 'r', 'y', '\n',
        's', 't', 'i', 'p', 'e', 'n', 'd', 's', '\n',
        's', 't', 'i', 'p', 'p', 'l', 'e', 'd', '\n',
        's', 't', 'i', 'p', 'p', 'l', 'e', 's', '\n',
        's', 't', 'i', 'p', 'u', 'l', 'a', 't', 'e', '\n',
        's', 't', 'i', 'p', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        's', 't', 'i', 'p', 'u', 'l', 'a', 't', 'e', 's', '\n',
        's', 't', 'i', 'p', 'u', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        's', 't', 'i', 'p', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        's', 't', 'i', 'p', 'u', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        's', 't', 'i', 'r', '\n',
        's', 't', 'i', 'r', 'f', 'r', 'i', 'e', 'd', '\n',
        's', 't', 'i', 'r', 'f', 'r', 'y', '\n',
        's', 't', 'i', 'r', 'r', 'e', 'd', '\n',
        's', 't', 'i', 'r', 'r', 'e', 'r', '\n',
        's', 't', 'i', 'r', 'r', 'e', 'r', 's', '\n',
        's', 't', 'i', 'r', 'r', 'i', 'n', 'g', '\n',
        's', 't', 'i', 'r', 'r', 'i', 'n', 'g', 's', '\n',
        's', 't', 'i', 'r', 'r', 'u', 'p', '\n',
        's', 't', 'i', 'r', 'r', 'u', 'p', 's', '\n',
        's', 't', 'i', 'r', 's', '\n',
        's', 't', 'i', 't', 'c', 'h', '\n',
        's', 't', 'i', 't', 'c', 'h', 'e', 'd', '\n',
        's', 't', 'i', 't', 'c', 'h', 'e', 'r', '\n',
        's', 't', 'i', 't', 'c', 'h', 'e', 's', '\n',
        's', 't', 'i', 't', 'c', 'h', 'i', 'n', 'g', '\n',
        's', 't', 'o', 'a', '\n',
        's', 't', 'o', 'a', 't', '\n',
        's', 't', 'o', 'a', 't', 's', '\n',
        's', 't', 'o', 'c', 'h', 'a', 's', 't', 'i', 'c', '\n',
        's', 't', 'o', 'c', 'k', '\n',
        's', 't', 'o', 'c', 'k', 'a', 'd', 'e', '\n',
        's', 't', 'o', 'c', 'k', 'b', 'r', 'o', 'k', 'e', 'r', '\n',
        's', 't', 'o', 'c', 'k', 'b', 'r', 'o', 'k', 'e', 'r', 's', '\n',
        's', 't', 'o', 'c', 'k', 'b', 'r', 'o', 'k', 'i', 'n', 'g', '\n',
        's', 't', 'o', 'c', 'k', 'c', 'a', 'r', '\n',
        's', 't', 'o', 'c', 'k', 'e', 'd', '\n',
        's', 't', 'o', 'c', 'k', 'h', 'o', 'l', 'd', 'e', 'r', 's', '\n',
        's', 't', 'o', 'c', 'k', 'h', 'o', 'l', 'd', 'i', 'n', 'g', '\n',
        's', 't', 'o', 'c', 'k', 'i', 'e', 'r', '\n',
        's', 't', 'o', 'c', 'k', 'i', 'l', 'y', '\n',
        's', 't', 'o', 'c', 'k', 'i', 'n', 'g', '\n',
        's', 't', 'o', 'c', 'k', 'i', 'n', 'g', 'e', 'd', '\n',
        's', 't', 'o', 'c', 'k', 'i', 'n', 'g', 's', '\n',
        's', 't', 'o', 'c', 'k', 'i', 's', 't', '\n',
        's', 't', 'o', 'c', 'k', 'i', 's', 't', 's', '\n',
        's', 't', 'o', 'c', 'k', 'p', 'i', 'l', 'e', '\n',
        's', 't', 'o', 'c', 'k', 'p', 'i', 'l', 'e', 'd', '\n',
        's', 't', 'o', 'c', 'k', 'p', 'i', 'l', 'e', 's', '\n',
        's', 't', 'o', 'c', 'k', 'p', 'i', 'l', 'i', 'n', 'g', '\n',
        's', 't', 'o', 'c', 'k', 'r', 'o', 'o', 'm', '\n',
        's', 't', 'o', 'c', 'k', 's', '\n',
        's', 't', 'o', 'c', 'k', 't', 'a', 'k', 'i', 'n', 'g', '\n',
        's', 't', 'o', 'c', 'k', 'y', '\n',
        's', 't', 'o', 'd', 'g', 'e', '\n',
        's', 't', 'o', 'd', 'g', 'i', 'e', 'r', '\n',
        's', 't', 'o', 'd', 'g', 'i', 'e', 's', 't', '\n',
        's', 't', 'o', 'd', 'g', 'y', '\n',
        's', 't', 'o', 'e', 'p', '\n',
        's', 't', 'o', 'i', 'c', '\n',
        's', 't', 'o', 'i', 'c', 'a', 'l', '\n',
        's', 't', 'o', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 't', 'o', 'i', 'c', 'i', 's', 'm', '\n',
        's', 't', 'o', 'i', 'c', 's', '\n',
        's', 't', 'o', 'k', 'e', '\n',
        's', 't', 'o', 'k', 'e', 'd', '\n',
        's', 't', 'o', 'k', 'e', 'r', '\n',
        's', 't', 'o', 'k', 'e', 'r', 's', '\n',
        's', 't', 'o', 'k', 'e', 's', '\n',
        's', 't', 'o', 'k', 'i', 'n', 'g', '\n',
        's', 't', 'o', 'l', 'e', '\n',
        's', 't', 'o', 'l', 'e', 'n', '\n',
        's', 't', 'o', 'l', 'i', 'd', '\n',
        's', 't', 'o', 'l', 'i', 'd', 'i', 't', 'y', '\n',
        's', 't', 'o', 'l', 'i', 'd', 'l', 'y', '\n',
        's', 't', 'o', 'm', 'a', '\n',
        's', 't', 'o', 'm', 'a', 'c', 'h', '\n',
        's', 't', 'o', 'm', 'a', 'c', 'h', 'a', 'c', 'h', 'e', '\n',
        's', 't', 'o', 'm', 'a', 'c', 'h', 's', '\n',
        's', 't', 'o', 'm', 'a', 't', 'a', '\n',
        's', 't', 'o', 'm', 'p', '\n',
        's', 't', 'o', 'm', 'p', 'e', 'd', '\n',
        's', 't', 'o', 'm', 'p', 'i', 'n', 'g', '\n',
        's', 't', 'o', 'm', 'p', 's', '\n',
        's', 't', 'o', 'n', 'e', '\n',
        's', 't', 'o', 'n', 'e', 'c', 'o', 'l', 'd', '\n',
        's', 't', 'o', 'n', 'e', 'd', '\n',
        's', 't', 'o', 'n', 'e', 'l', 'e', 's', 's', '\n',
        's', 't', 'o', 'n', 'e', 'm', 'a', 's', 'o', 'n', '\n',
        's', 't', 'o', 'n', 'e', 'm', 'a', 's', 'o', 'n', 's', '\n',
        's', 't', 'o', 'n', 'e', 's', '\n',
        's', 't', 'o', 'n', 'e', 'w', 'a', 'l', 'l', 'e', 'd', '\n',
        's', 't', 'o', 'n', 'e', 'w', 'a', 'r', 'e', '\n',
        's', 't', 'o', 'n', 'e', 'w', 'o', 'r', 'k', '\n',
        's', 't', 'o', 'n', 'i', 'e', 'r', '\n',
        's', 't', 'o', 'n', 'i', 'e', 's', 't', '\n',
        's', 't', 'o', 'n', 'i', 'l', 'y', '\n',
        's', 't', 'o', 'n', 'i', 'n', 'g', '\n',
        's', 't', 'o', 'n', 'y', '\n',
        's', 't', 'o', 'o', 'd', '\n',
        's', 't', 'o', 'o', 'g', 'e', '\n',
        's', 't', 'o', 'o', 'g', 'e', 's', '\n',
        's', 't', 'o', 'o', 'l', '\n',
        's', 't', 'o', 'o', 'l', 'p', 'i', 'g', 'e', 'o', 'n', '\n',
        's', 't', 'o', 'o', 'l', 's', '\n',
        's', 't', 'o', 'o', 'p', '\n',
        's', 't', 'o', 'o', 'p', 'e', 'd', '\n',
        's', 't', 'o', 'o', 'p', 'i', 'n', 'g', '\n',
        's', 't', 'o', 'o', 'p', 's', '\n',
        's', 't', 'o', 'p', '\n',
        's', 't', 'o', 'p', 'c', 'o', 'c', 'k', '\n',
        's', 't', 'o', 'p', 'g', 'a', 'p', '\n',
        's', 't', 'o', 'p', 'o', 'v', 'e', 'r', '\n',
        's', 't', 'o', 'p', 'p', 'a', 'b', 'l', 'e', '\n',
        's', 't', 'o', 'p', 'p', 'a', 'g', 'e', '\n',
        's', 't', 'o', 'p', 'p', 'a', 'g', 'e', 's', '\n',
        's', 't', 'o', 'p', 'p', 'e', 'd', '\n',
        's', 't', 'o', 'p', 'p', 'e', 'r', '\n',
        's', 't', 'o', 'p', 'p', 'e', 'r', 'e', 'd', '\n',
        's', 't', 'o', 'p', 'p', 'e', 'r', 's', '\n',
        's', 't', 'o', 'p', 'p', 'i', 'n', 'g', '\n',
        's', 't', 'o', 'p', 's', '\n',
        's', 't', 'o', 'p', 'w', 'a', 't', 'c', 'h', '\n',
        's', 't', 'o', 'r', 'a', 'g', 'e', '\n',
        's', 't', 'o', 'r', 'a', 'g', 'e', 's', '\n',
        's', 't', 'o', 'r', 'e', '\n',
        's', 't', 'o', 'r', 'e', 'd', '\n',
        's', 't', 'o', 'r', 'e', 'h', 'o', 'u', 's', 'e', '\n',
        's', 't', 'o', 'r', 'e', 'h', 'o', 'u', 's', 'e', 's', '\n',
        's', 't', 'o', 'r', 'e', 'k', 'e', 'e', 'p', 'e', 'r', '\n',
        's', 't', 'o', 'r', 'e', 'k', 'e', 'e', 'p', 'e', 'r', 's', '\n',
        's', 't', 'o', 'r', 'e', 'm', 'a', 'n', '\n',
        's', 't', 'o', 'r', 'e', 'r', 'o', 'o', 'm', '\n',
        's', 't', 'o', 'r', 'e', 'r', 'o', 'o', 'm', 's', '\n',
        's', 't', 'o', 'r', 'e', 's', '\n',
        's', 't', 'o', 'r', 'e', 'y', '\n',
        's', 't', 'o', 'r', 'e', 'y', 's', '\n',
        's', 't', 'o', 'r', 'i', 'e', 's', '\n',
        's', 't', 'o', 'r', 'i', 'n', 'g', '\n',
        's', 't', 'o', 'r', 'k', '\n',
        's', 't', 'o', 'r', 'k', 's', '\n',
        's', 't', 'o', 'r', 'm', '\n',
        's', 't', 'o', 'r', 'm', 'e', 'd', '\n',
        's', 't', 'o', 'r', 'm', 'e', 'r', '\n',
        's', 't', 'o', 'r', 'm', 'e', 'r', 's', '\n',
        's', 't', 'o', 'r', 'm', 'i', 'e', 'r', '\n',
        's', 't', 'o', 'r', 'm', 'i', 'e', 's', 't', '\n',
        's', 't', 'o', 'r', 'm', 'i', 'n', 'g', '\n',
        's', 't', 'o', 'r', 'm', 's', '\n',
        's', 't', 'o', 'r', 'm', 't', 'r', 'o', 'o', 'p', 'e', 'r', 's', '\n',
        's', 't', 'o', 'r', 'm', 'y', '\n',
        's', 't', 'o', 'r', 'y', '\n',
        's', 't', 'o', 'r', 'y', 'b', 'o', 'o', 'k', '\n',
        's', 't', 'o', 'r', 'y', 'l', 'i', 'n', 'e', '\n',
        's', 't', 'o', 'r', 'y', 'l', 'i', 'n', 'e', 's', '\n',
        's', 't', 'o', 'r', 'y', 't', 'e', 'l', 'l', 'e', 'r', '\n',
        's', 't', 'o', 'r', 'y', 't', 'e', 'l', 'l', 'e', 'r', 's', '\n',
        's', 't', 'o', 'r', 'y', 't', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        's', 't', 'o', 'u', 't', '\n',
        's', 't', 'o', 'u', 't', 'e', 'r', '\n',
        's', 't', 'o', 'u', 't', 'e', 's', 't', '\n',
        's', 't', 'o', 'u', 't', 'l', 'y', '\n',
        's', 't', 'o', 'u', 't', 'n', 'e', 's', 's', '\n',
        's', 't', 'o', 'v', 'e', '\n',
        's', 't', 'o', 'v', 'e', 'p', 'i', 'p', 'e', '\n',
        's', 't', 'o', 'v', 'e', 's', '\n',
        's', 't', 'o', 'w', '\n',
        's', 't', 'o', 'w', 'a', 'g', 'e', '\n',
        's', 't', 'o', 'w', 'a', 'w', 'a', 'y', '\n',
        's', 't', 'o', 'w', 'e', 'd', '\n',
        's', 't', 'o', 'w', 'i', 'n', 'g', '\n',
        's', 't', 'o', 'w', 's', '\n',
        's', 't', 'r', 'a', 'd', 'd', 'l', 'e', '\n',
        's', 't', 'r', 'a', 'd', 'd', 'l', 'e', 'd', '\n',
        's', 't', 'r', 'a', 'd', 'd', 'l', 'e', 's', '\n',
        's', 't', 'r', 'a', 'd', 'd', 'l', 'i', 'n', 'g', '\n',
        's', 't', 'r', 'a', 'f', 'e', '\n',
        's', 't', 'r', 'a', 'f', 'e', 'd', '\n',
        's', 't', 'r', 'a', 'f', 'i', 'n', 'g', '\n',
        's', 't', 'r', 'a', 'g', 'g', 'l', 'e', '\n',
        's', 't', 'r', 'a', 'g', 'g', 'l', 'e', 'd', '\n',
        's', 't', 'r', 'a', 'g', 'g', 'l', 'e', 'r', '\n',
        's', 't', 'r', 'a', 'g', 'g', 'l', 'e', 'r', 's', '\n',
        's', 't', 'r', 'a', 'g', 'g', 'l', 'i', 'n', 'g', '\n',
        's', 't', 'r', 'a', 'g', 'g', 'l', 'y', '\n',
        's', 't', 'r', 'a', 'i', 'g', 'h', 't', '\n',
        's', 't', 'r', 'a', 'i', 'g', 'h', 't', 'a', 'w', 'a', 'y', '\n',
        's', 't', 'r', 'a', 'i', 'g', 'h', 't', 'e', 'n', '\n',
        's', 't', 'r', 'a', 'i', 'g', 'h', 't', 'e', 'n', 'e', 'd', '\n',
        's', 't', 'r', 'a', 'i', 'g', 'h', 't', 'e', 'n', 'i', 'n', 'g', '\n',
        's', 't', 'r', 'a', 'i', 'g', 'h', 't', 'e', 'n', 's', '\n',
        's', 't', 'r', 'a', 'i', 'g', 'h', 't', 'e', 'r', '\n',
        's', 't', 'r', 'a', 'i', 'g', 'h', 't', 'e', 's', 't', '\n',
        's', 't', 'r', 'a', 'i', 'g', 'h', 't', 'f', 'o', 'r', 'w', 'a', 'r', 'd', '\n',
        's', 't', 'r', 'a', 'i', 'g', 'h', 't', 'f', 'o', 'r', 'w', 'a', 'r', 'd', 'l', 'y', '\n',
        's', 't', 'r', 'a', 'i', 'g', 'h', 't', 'f', 'o', 'r', 'w', 'a', 'r', 'd', 'n', 'e', 's', 's', '\n',
        's', 't', 'r', 'a', 'i', 'g', 'h', 't', 'n', 'e', 's', 's', '\n',
        's', 't', 'r', 'a', 'i', 'n', '\n',
        's', 't', 'r', 'a', 'i', 'n', 'e', 'd', '\n',
        's', 't', 'r', 'a', 'i', 'n', 'e', 'r', '\n',
        's', 't', 'r', 'a', 'i', 'n', 'e', 'r', 's', '\n',
        's', 't', 'r', 'a', 'i', 'n', 'i', 'n', 'g', '\n',
        's', 't', 'r', 'a', 'i', 'n', 's', '\n',
        's', 't', 'r', 'a', 'i', 't', '\n',
        's', 't', 'r', 'a', 'i', 't', 'e', 'n', '\n',
        's', 't', 'r', 'a', 'i', 't', 'e', 'n', 'e', 'd', '\n',
        's', 't', 'r', 'a', 'i', 't', 'j', 'a', 'c', 'k', 'e', 't', '\n',
        's', 't', 'r', 'a', 'i', 't', 'j', 'a', 'c', 'k', 'e', 't', 's', '\n',
        's', 't', 'r', 'a', 'i', 't', 's', '\n',
        's', 't', 'r', 'a', 'n', 'd', '\n',
        's', 't', 'r', 'a', 'n', 'd', 'e', 'd', '\n',
        's', 't', 'r', 'a', 'n', 'd', 'i', 'n', 'g', '\n',
        's', 't', 'r', 'a', 'n', 'd', 's', '\n',
        's', 't', 'r', 'a', 'n', 'g', 'e', '\n',
        's', 't', 'r', 'a', 'n', 'g', 'e', 'l', 'y', '\n',
        's', 't', 'r', 'a', 'n', 'g', 'e', 'n', 'e', 's', 's', '\n',
        's', 't', 'r', 'a', 'n', 'g', 'e', 'r', '\n',
        's', 't', 'r', 'a', 'n', 'g', 'e', 'r', 's', '\n',
        's', 't', 'r', 'a', 'n', 'g', 'e', 's', 't', '\n',
        's', 't', 'r', 'a', 'n', 'g', 'l', 'e', '\n',
        's', 't', 'r', 'a', 'n', 'g', 'l', 'e', 'd', '\n',
        's', 't', 'r', 'a', 'n', 'g', 'l', 'e', 'h', 'o', 'l', 'd', '\n',
        's', 't', 'r', 'a', 'n', 'g', 'l', 'e', 'r', '\n',
        's', 't', 'r', 'a', 'n', 'g', 'l', 'e', 'r', 's', '\n',
        's', 't', 'r', 'a', 'n', 'g', 'l', 'e', 's', '\n',
        's', 't', 'r', 'a', 'n', 'g', 'l', 'i', 'n', 'g', '\n',
        's', 't', 'r', 'a', 'n', 'g', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        's', 't', 'r', 'a', 'n', 'g', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        's', 't', 'r', 'a', 'p', '\n',
        's', 't', 'r', 'a', 'p', 'l', 'e', 's', 's', '\n',
        's', 't', 'r', 'a', 'p', 'p', 'e', 'd', '\n',
        's', 't', 'r', 'a', 'p', 'p', 'e', 'r', '\n',
        's', 't', 'r', 'a', 'p', 'p', 'i', 'n', 'g', '\n',
        's', 't', 'r', 'a', 'p', 's', '\n',
        's', 't', 'r', 'a', 't', 'a', '\n',
        's', 't', 'r', 'a', 't', 'a', 'g', 'e', 'm', '\n',
        's', 't', 'r', 'a', 't', 'a', 'g', 'e', 'm', 's', '\n',
        's', 't', 'r', 'a', 't', 'e', 'g', 'i', 'c', '\n',
        's', 't', 'r', 'a', 't', 'e', 'g', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 't', 'r', 'a', 't', 'e', 'g', 'i', 'e', 's', '\n',
        's', 't', 'r', 'a', 't', 'e', 'g', 'i', 's', 't', '\n',
        's', 't', 'r', 'a', 't', 'e', 'g', 'i', 's', 't', 's', '\n',
        's', 't', 'r', 'a', 't', 'e', 'g', 'y', '\n',
        's', 't', 'r', 'a', 't', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        's', 't', 'r', 'a', 't', 'i', 'f', 'i', 'e', 'd', '\n',
        's', 't', 'r', 'a', 't', 'i', 'f', 'i', 'e', 's', '\n',
        's', 't', 'r', 'a', 't', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        's', 't', 'r', 'a', 't', 'i', 'g', 'r', 'a', 'p', 'h', 'i', 'c', '\n',
        's', 't', 'r', 'a', 't', 'i', 'g', 'r', 'a', 'p', 'h', 'i', 'c', 'a', 'l', '\n',
        's', 't', 'r', 'a', 't', 'i', 'g', 'r', 'a', 'p', 'h', 'y', '\n',
        's', 't', 'r', 'a', 't', 'o', 's', 'p', 'h', 'e', 'r', 'e', '\n',
        's', 't', 'r', 'a', 't', 'o', 's', 'p', 'h', 'e', 'r', 'i', 'c', '\n',
        's', 't', 'r', 'a', 't', 'o', 's', 'p', 'h', 'e', 'r', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 't', 'r', 'a', 't', 'u', 'm', '\n',
        's', 't', 'r', 'a', 't', 'u', 's', '\n',
        's', 't', 'r', 'a', 'w', '\n',
        's', 't', 'r', 'a', 'w', 'b', 'e', 'r', 'r', 'i', 'e', 's', '\n',
        's', 't', 'r', 'a', 'w', 'b', 'e', 'r', 'r', 'y', '\n',
        's', 't', 'r', 'a', 'w', 'm', 'a', 'n', '\n',
        's', 't', 'r', 'a', 'w', 's', '\n',
        's', 't', 'r', 'a', 'y', '\n',
        's', 't', 'r', 'a', 'y', 'e', 'd', '\n',
        's', 't', 'r', 'a', 'y', 'e', 'r', '\n',
        's', 't', 'r', 'a', 'y', 'i', 'n', 'g', '\n',
        's', 't', 'r', 'a', 'y', 's', '\n',
        's', 't', 'r', 'e', 'a', 'k', '\n',
        's', 't', 'r', 'e', 'a', 'k', 'e', 'd', '\n',
        's', 't', 'r', 'e', 'a', 'k', 'e', 'r', '\n',
        's', 't', 'r', 'e', 'a', 'k', 'e', 'r', 's', '\n',
        's', 't', 'r', 'e', 'a', 'k', 'i', 'e', 'r', '\n',
        's', 't', 'r', 'e', 'a', 'k', 'i', 'e', 's', 't', '\n',
        's', 't', 'r', 'e', 'a', 'k', 'i', 'n', 'g', '\n',
        's', 't', 'r', 'e', 'a', 'k', 's', '\n',
        's', 't', 'r', 'e', 'a', 'k', 'y', '\n',
        's', 't', 'r', 'e', 'a', 'm', '\n',
        's', 't', 'r', 'e', 'a', 'm', 'e', 'd', '\n',
        's', 't', 'r', 'e', 'a', 'm', 'e', 'r', '\n',
        's', 't', 'r', 'e', 'a', 'm', 'e', 'r', 's', '\n',
        's', 't', 'r', 'e', 'a', 'm', 'i', 'n', 'g', '\n',
        's', 't', 'r', 'e', 'a', 'm', 'l', 'i', 'n', 'e', '\n',
        's', 't', 'r', 'e', 'a', 'm', 'l', 'i', 'n', 'e', 'd', '\n',
        's', 't', 'r', 'e', 'a', 'm', 'l', 'i', 'n', 'e', 's', '\n',
        's', 't', 'r', 'e', 'a', 'm', 'l', 'i', 'n', 'i', 'n', 'g', '\n',
        's', 't', 'r', 'e', 'a', 'm', 's', '\n',
        's', 't', 'r', 'e', 'e', 't', '\n',
        's', 't', 'r', 'e', 'e', 't', 's', '\n',
        's', 't', 'r', 'e', 'e', 't', 'w', 'a', 'l', 'k', 'e', 'r', 's', '\n',
        's', 't', 'r', 'e', 'e', 't', 'w', 'i', 's', 'e', '\n',
        's', 't', 'r', 'e', 'n', 'g', 't', 'h', '\n',
        's', 't', 'r', 'e', 'n', 'g', 't', 'h', 'e', 'n', '\n',
        's', 't', 'r', 'e', 'n', 'g', 't', 'h', 'e', 'n', 'e', 'd', '\n',
        's', 't', 'r', 'e', 'n', 'g', 't', 'h', 'e', 'n', 'i', 'n', 'g', '\n',
        's', 't', 'r', 'e', 'n', 'g', 't', 'h', 'e', 'n', 's', '\n',
        's', 't', 'r', 'e', 'n', 'g', 't', 'h', 's', '\n',
        's', 't', 'r', 'e', 'n', 'u', 'o', 'u', 's', '\n',
        's', 't', 'r', 'e', 'n', 'u', 'o', 'u', 's', 'l', 'y', '\n',
        's', 't', 'r', 'e', 'p', 't', 'o', 'c', 'o', 'c', 'c', 'a', 'l', '\n',
        's', 't', 'r', 'e', 'p', 't', 'o', 'c', 'o', 'c', 'c', 'i', '\n',
        's', 't', 'r', 'e', 'p', 't', 'o', 'm', 'y', 'c', 'i', 'n', '\n',
        's', 't', 'r', 'e', 's', 's', '\n',
        's', 't', 'r', 'e', 's', 's', 'e', 'd', '\n',
        's', 't', 'r', 'e', 's', 's', 'e', 's', '\n',
        's', 't', 'r', 'e', 's', 's', 'f', 'u', 'l', '\n',
        's', 't', 'r', 'e', 's', 's', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        's', 't', 'r', 'e', 's', 's', 'i', 'n', 'g', '\n',
        's', 't', 'r', 'e', 't', 'c', 'h', '\n',
        's', 't', 'r', 'e', 't', 'c', 'h', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        's', 't', 'r', 'e', 't', 'c', 'h', 'a', 'b', 'l', 'e', '\n',
        's', 't', 'r', 'e', 't', 'c', 'h', 'e', 'd', '\n',
        's', 't', 'r', 'e', 't', 'c', 'h', 'e', 'r', '\n',
        's', 't', 'r', 'e', 't', 'c', 'h', 'e', 'r', 'e', 'd', '\n',
        's', 't', 'r', 'e', 't', 'c', 'h', 'e', 'r', 's', '\n',
        's', 't', 'r', 'e', 't', 'c', 'h', 'e', 's', '\n',
        's', 't', 'r', 'e', 't', 'c', 'h', 'i', 'n', 'e', 's', 's', '\n',
        's', 't', 'r', 'e', 't', 'c', 'h', 'i', 'n', 'g', '\n',
        's', 't', 'r', 'e', 't', 'c', 'h', 'y', '\n',
        's', 't', 'r', 'e', 'w', '\n',
        's', 't', 'r', 'e', 'w', 'e', 'd', '\n',
        's', 't', 'r', 'e', 'w', 'i', 'n', 'g', '\n',
        's', 't', 'r', 'e', 'w', 'n', '\n',
        's', 't', 'r', 'i', 'a', 't', 'e', 'd', '\n',
        's', 't', 'r', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        's', 't', 'r', 'i', 'a', 't', 'i', 'o', 'n', 's', '\n',
        's', 't', 'r', 'i', 'c', 'k', 'e', 'n', '\n',
        's', 't', 'r', 'i', 'c', 't', '\n',
        's', 't', 'r', 'i', 'c', 't', 'e', 'r', '\n',
        's', 't', 'r', 'i', 'c', 't', 'e', 's', 't', '\n',
        's', 't', 'r', 'i', 'c', 't', 'l', 'y', '\n',
        's', 't', 'r', 'i', 'c', 't', 'n', 'e', 's', 's', '\n',
        's', 't', 'r', 'i', 'c', 't', 'u', 'r', 'e', '\n',
        's', 't', 'r', 'i', 'c', 't', 'u', 'r', 'e', 's', '\n',
        's', 't', 'r', 'i', 'd', 'e', '\n',
        's', 't', 'r', 'i', 'd', 'e', 'n', 'c', 'y', '\n',
        's', 't', 'r', 'i', 'd', 'e', 'n', 't', '\n',
        's', 't', 'r', 'i', 'd', 'e', 'n', 't', 'l', 'y', '\n',
        's', 't', 'r', 'i', 'd', 'e', 'r', '\n',
        's', 't', 'r', 'i', 'd', 'e', 's', '\n',
        's', 't', 'r', 'i', 'd', 'i', 'n', 'g', '\n',
        's', 't', 'r', 'i', 'f', 'e', '\n',
        's', 't', 'r', 'i', 'f', 'e', 's', '\n',
        's', 't', 'r', 'i', 'k', 'e', '\n',
        's', 't', 'r', 'i', 'k', 'e', 'r', '\n',
        's', 't', 'r', 'i', 'k', 'e', 'r', 's', '\n',
        's', 't', 'r', 'i', 'k', 'e', 's', '\n',
        's', 't', 'r', 'i', 'k', 'i', 'n', 'g', '\n',
        's', 't', 'r', 'i', 'k', 'i', 'n', 'g', 'l', 'y', '\n',
        's', 't', 'r', 'i', 'n', 'g', '\n',
        's', 't', 'r', 'i', 'n', 'g', 'e', 'd', '\n',
        's', 't', 'r', 'i', 'n', 'g', 'e', 'n', 'c', 'i', 'e', 's', '\n',
        's', 't', 'r', 'i', 'n', 'g', 'e', 'n', 'c', 'y', '\n',
        's', 't', 'r', 'i', 'n', 'g', 'e', 'n', 't', '\n',
        's', 't', 'r', 'i', 'n', 'g', 'e', 'n', 't', 'l', 'y', '\n',
        's', 't', 'r', 'i', 'n', 'g', 'e', 'r', '\n',
        's', 't', 'r', 'i', 'n', 'g', 'i', 'n', 'g', '\n',
        's', 't', 'r', 'i', 'n', 'g', 's', '\n',
        's', 't', 'r', 'i', 'n', 'g', 'y', '\n',
        's', 't', 'r', 'i', 'p', '\n',
        's', 't', 'r', 'i', 'p', 'e', '\n',
        's', 't', 'r', 'i', 'p', 'e', 'd', '\n',
        's', 't', 'r', 'i', 'p', 'e', 'r', '\n',
        's', 't', 'r', 'i', 'p', 'e', 's', '\n',
        's', 't', 'r', 'i', 'p', 'i', 'e', 'r', '\n',
        's', 't', 'r', 'i', 'p', 'i', 'e', 's', 't', '\n',
        's', 't', 'r', 'i', 'p', 'i', 'n', 'g', '\n',
        's', 't', 'r', 'i', 'p', 'l', 'i', 'n', 'g', '\n',
        's', 't', 'r', 'i', 'p', 'p', 'e', 'd', '\n',
        's', 't', 'r', 'i', 'p', 'p', 'e', 'r', '\n',
        's', 't', 'r', 'i', 'p', 'p', 'e', 'r', 's', '\n',
        's', 't', 'r', 'i', 'p', 'p', 'i', 'n', 'g', '\n',
        's', 't', 'r', 'i', 'p', 's', '\n',
        's', 't', 'r', 'i', 'p', 'y', '\n',
        's', 't', 'r', 'i', 'v', 'e', '\n',
        's', 't', 'r', 'i', 'v', 'e', 'd', '\n',
        's', 't', 'r', 'i', 'v', 'e', 'n', '\n',
        's', 't', 'r', 'i', 'v', 'e', 'r', '\n',
        's', 't', 'r', 'i', 'v', 'e', 's', '\n',
        's', 't', 'r', 'i', 'v', 'i', 'n', 'g', '\n',
        's', 't', 'r', 'i', 'v', 'i', 'n', 'g', 's', '\n',
        's', 't', 'r', 'o', 'd', 'e', '\n',
        's', 't', 'r', 'o', 'k', 'e', '\n',
        's', 't', 'r', 'o', 'k', 'e', 'd', '\n',
        's', 't', 'r', 'o', 'k', 'e', 's', '\n',
        's', 't', 'r', 'o', 'k', 'i', 'n', 'g', '\n',
        's', 't', 'r', 'o', 'l', 'l', '\n',
        's', 't', 'r', 'o', 'l', 'l', 'e', 'd', '\n',
        's', 't', 'r', 'o', 'l', 'l', 'e', 'r', '\n',
        's', 't', 'r', 'o', 'l', 'l', 'e', 'r', 's', '\n',
        's', 't', 'r', 'o', 'l', 'l', 'i', 'n', 'g', '\n',
        's', 't', 'r', 'o', 'l', 'l', 's', '\n',
        's', 't', 'r', 'o', 'n', 'g', '\n',
        's', 't', 'r', 'o', 'n', 'g', 'e', 'r', '\n',
        's', 't', 'r', 'o', 'n', 'g', 'e', 's', 't', '\n',
        's', 't', 'r', 'o', 'n', 'g', 'h', 'o', 'l', 'd', '\n',
        's', 't', 'r', 'o', 'n', 'g', 'h', 'o', 'l', 'd', 's', '\n',
        's', 't', 'r', 'o', 'n', 'g', 'i', 's', 'h', '\n',
        's', 't', 'r', 'o', 'n', 'g', 'l', 'y', '\n',
        's', 't', 'r', 'o', 'n', 'g', 'm', 'a', 'n', '\n',
        's', 't', 'r', 'o', 'n', 'g', 'm', 'e', 'n', '\n',
        's', 't', 'r', 'o', 'n', 'g', 'm', 'i', 'n', 'd', 'e', 'd', '\n',
        's', 't', 'r', 'o', 'n', 'g', 'r', 'o', 'o', 'm', '\n',
        's', 't', 'r', 'o', 'n', 't', 'i', 'u', 'm', '\n',
        's', 't', 'r', 'o', 'p', '\n',
        's', 't', 'r', 'o', 'p', 'p', 'e', 'd', '\n',
        's', 't', 'r', 'o', 'p', 'p', 'i', 'n', 'g', '\n',
        's', 't', 'r', 'o', 'p', 's', '\n',
        's', 't', 'r', 'o', 'v', 'e', '\n',
        's', 't', 'r', 'u', 'c', 'k', '\n',
        's', 't', 'r', 'u', 'c', 't', 'u', 'r', 'a', 'l', '\n',
        's', 't', 'r', 'u', 'c', 't', 'u', 'r', 'a', 'l', 'i', 's', 'm', '\n',
        's', 't', 'r', 'u', 'c', 't', 'u', 'r', 'a', 'l', 'i', 's', 't', '\n',
        's', 't', 'r', 'u', 'c', 't', 'u', 'r', 'a', 'l', 'i', 's', 't', 's', '\n',
        's', 't', 'r', 'u', 'c', 't', 'u', 'r', 'a', 'l', 'l', 'y', '\n',
        's', 't', 'r', 'u', 'c', 't', 'u', 'r', 'e', '\n',
        's', 't', 'r', 'u', 'c', 't', 'u', 'r', 'e', 'd', '\n',
        's', 't', 'r', 'u', 'c', 't', 'u', 'r', 'e', 'l', 'e', 's', 's', '\n',
        's', 't', 'r', 'u', 'c', 't', 'u', 'r', 'e', 's', '\n',
        's', 't', 'r', 'u', 'c', 't', 'u', 'r', 'i', 'n', 'g', '\n',
        's', 't', 'r', 'u', 'd', 'e', 'l', '\n',
        's', 't', 'r', 'u', 'd', 'e', 'l', 's', '\n',
        's', 't', 'r', 'u', 'g', 'g', 'l', 'e', '\n',
        's', 't', 'r', 'u', 'g', 'g', 'l', 'e', 'd', '\n',
        's', 't', 'r', 'u', 'g', 'g', 'l', 'e', 's', '\n',
        's', 't', 'r', 'u', 'g', 'g', 'l', 'i', 'n', 'g', '\n',
        's', 't', 'r', 'u', 'm', '\n',
        's', 't', 'r', 'u', 'm', 'm', 'e', 'd', '\n',
        's', 't', 'r', 'u', 'm', 'm', 'i', 'n', 'g', '\n',
        's', 't', 'r', 'u', 'm', 'p', 'e', 't', '\n',
        's', 't', 'r', 'u', 'n', 'g', '\n',
        's', 't', 'r', 'u', 't', '\n',
        's', 't', 'r', 'u', 't', 's', '\n',
        's', 't', 'r', 'u', 't', 't', 'e', 'd', '\n',
        's', 't', 'r', 'u', 't', 't', 'e', 'r', '\n',
        's', 't', 'r', 'u', 't', 't', 'i', 'n', 'g', '\n',
        's', 't', 'r', 'y', 'c', 'h', 'n', 'i', 'n', 'e', '\n',
        's', 't', 'u', 'b', '\n',
        's', 't', 'u', 'b', 'b', 'e', 'd', '\n',
        's', 't', 'u', 'b', 'b', 'i', 'n', 'g', '\n',
        's', 't', 'u', 'b', 'b', 'l', 'e', '\n',
        's', 't', 'u', 'b', 'b', 'l', 'e', 'd', '\n',
        's', 't', 'u', 'b', 'b', 'l', 'e', 's', '\n',
        's', 't', 'u', 'b', 'b', 'l', 'y', '\n',
        's', 't', 'u', 'b', 'b', 'o', 'r', 'n', '\n',
        's', 't', 'u', 'b', 'b', 'o', 'r', 'n', 'l', 'y', '\n',
        's', 't', 'u', 'b', 'b', 'o', 'r', 'n', 'n', 'e', 's', 's', '\n',
        's', 't', 'u', 'b', 'b', 'y', '\n',
        's', 't', 'u', 'b', 's', '\n',
        's', 't', 'u', 'c', 'c', 'o', '\n',
        's', 't', 'u', 'c', 'c', 'o', 'e', 'd', '\n',
        's', 't', 'u', 'c', 'k', '\n',
        's', 't', 'u', 'c', 'k', 'u', 'p', '\n',
        's', 't', 'u', 'd', '\n',
        's', 't', 'u', 'd', 'd', 'e', 'd', '\n',
        's', 't', 'u', 'd', 'e', 'n', 't', '\n',
        's', 't', 'u', 'd', 'e', 'n', 't', 's', '\n',
        's', 't', 'u', 'd', 'e', 'n', 't', 's', 'h', 'i', 'p', '\n',
        's', 't', 'u', 'd', 'e', 'n', 't', 's', 'h', 'i', 'p', 's', '\n',
        's', 't', 'u', 'd', 'i', 'e', 'd', '\n',
        's', 't', 'u', 'd', 'i', 'e', 'r', '\n',
        's', 't', 'u', 'd', 'i', 'e', 'r', 's', '\n',
        's', 't', 'u', 'd', 'i', 'e', 's', '\n',
        's', 't', 'u', 'd', 'i', 'o', '\n',
        's', 't', 'u', 'd', 'i', 'o', 's', '\n',
        's', 't', 'u', 'd', 'i', 'o', 'u', 's', '\n',
        's', 't', 'u', 'd', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        's', 't', 'u', 'd', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        's', 't', 'u', 'd', 's', '\n',
        's', 't', 'u', 'd', 'y', '\n',
        's', 't', 'u', 'd', 'y', 'i', 'n', 'g', '\n',
        's', 't', 'u', 'f', 'f', '\n',
        's', 't', 'u', 'f', 'f', 'e', 'd', '\n',
        's', 't', 'u', 'f', 'f', 'e', 'r', '\n',
        's', 't', 'u', 'f', 'f', 'i', 'e', 'r', '\n',
        's', 't', 'u', 'f', 'f', 'i', 'e', 's', 't', '\n',
        's', 't', 'u', 'f', 'f', 'i', 'n', 'e', 's', 's', '\n',
        's', 't', 'u', 'f', 'f', 'i', 'n', 'g', '\n',
        's', 't', 'u', 'f', 'f', 's', '\n',
        's', 't', 'u', 'f', 'f', 'y', '\n',
        's', 't', 'u', 'l', 't', 'i', 'f', 'i', 'e', 'd', '\n',
        's', 't', 'u', 'l', 't', 'i', 'f', 'y', '\n',
        's', 't', 'u', 'l', 't', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        's', 't', 'u', 'm', 'b', 'l', 'e', '\n',
        's', 't', 'u', 'm', 'b', 'l', 'e', 'd', '\n',
        's', 't', 'u', 'm', 'b', 'l', 'e', 's', '\n',
        's', 't', 'u', 'm', 'b', 'l', 'i', 'n', 'g', '\n',
        's', 't', 'u', 'm', 'b', 'l', 'i', 'n', 'g', 'l', 'y', '\n',
        's', 't', 'u', 'm', 'p', '\n',
        's', 't', 'u', 'm', 'p', 'e', 'd', '\n',
        's', 't', 'u', 'm', 'p', 'i', 'n', 'g', '\n',
        's', 't', 'u', 'm', 'p', 's', '\n',
        's', 't', 'u', 'm', 'p', 'y', '\n',
        's', 't', 'u', 'n', '\n',
        's', 't', 'u', 'n', 'g', '\n',
        's', 't', 'u', 'n', 'n', 'e', 'd', '\n',
        's', 't', 'u', 'n', 'n', 'e', 'r', '\n',
        's', 't', 'u', 'n', 'n', 'i', 'n', 'g', '\n',
        's', 't', 'u', 'n', 'n', 'i', 'n', 'g', 'l', 'y', '\n',
        's', 't', 'u', 'n', 's', '\n',
        's', 't', 'u', 'n', 't', '\n',
        's', 't', 'u', 'n', 't', 'e', 'd', '\n',
        's', 't', 'u', 'n', 't', 'i', 'n', 'g', '\n',
        's', 't', 'u', 'n', 't', 'm', 'a', 'n', '\n',
        's', 't', 'u', 'n', 't', 's', '\n',
        's', 't', 'u', 'p', 'e', 'f', 'a', 'c', 't', 'i', 'o', 'n', '\n',
        's', 't', 'u', 'p', 'e', 'f', 'i', 'e', 'd', '\n',
        's', 't', 'u', 'p', 'e', 'f', 'y', '\n',
        's', 't', 'u', 'p', 'e', 'f', 'y', 'i', 'n', 'g', '\n',
        's', 't', 'u', 'p', 'e', 'f', 'y', 'i', 'n', 'g', 'l', 'y', '\n',
        's', 't', 'u', 'p', 'e', 'n', 'd', 'o', 'u', 's', '\n',
        's', 't', 'u', 'p', 'e', 'n', 'd', 'o', 'u', 's', 'l', 'y', '\n',
        's', 't', 'u', 'p', 'i', 'd', '\n',
        's', 't', 'u', 'p', 'i', 'd', 'e', 'r', '\n',
        's', 't', 'u', 'p', 'i', 'd', 'e', 's', 't', '\n',
        's', 't', 'u', 'p', 'i', 'd', 'i', 't', 'i', 'e', 's', '\n',
        's', 't', 'u', 'p', 'i', 'd', 'i', 't', 'y', '\n',
        's', 't', 'u', 'p', 'i', 'd', 'l', 'y', '\n',
        's', 't', 'u', 'p', 'o', 'r', '\n',
        's', 't', 'u', 'p', 'o', 'r', 's', '\n',
        's', 't', 'u', 'r', 'd', 'i', 'e', 'r', '\n',
        's', 't', 'u', 'r', 'd', 'i', 'e', 's', 't', '\n',
        's', 't', 'u', 'r', 'd', 'i', 'l', 'y', '\n',
        's', 't', 'u', 'r', 'd', 'y', '\n',
        's', 't', 'u', 'r', 'g', 'e', 'o', 'n', '\n',
        's', 't', 'u', 'r', 'g', 'e', 'o', 'n', 's', '\n',
        's', 't', 'u', 't', 't', 'e', 'r', '\n',
        's', 't', 'u', 't', 't', 'e', 'r', 'e', 'd', '\n',
        's', 't', 'u', 't', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 't', 'u', 't', 't', 'e', 'r', 's', '\n',
        's', 't', 'y', '\n',
        's', 't', 'y', 'l', 'e', '\n',
        's', 't', 'y', 'l', 'e', 'd', '\n',
        's', 't', 'y', 'l', 'e', 's', '\n',
        's', 't', 'y', 'l', 'i', '\n',
        's', 't', 'y', 'l', 'i', 'n', 'g', '\n',
        's', 't', 'y', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        's', 't', 'y', 'l', 'i', 's', 'e', 'd', '\n',
        's', 't', 'y', 'l', 'i', 's', 'h', '\n',
        's', 't', 'y', 'l', 'i', 's', 'h', 'l', 'y', '\n',
        's', 't', 'y', 'l', 'i', 's', 'h', 'n', 'e', 's', 's', '\n',
        's', 't', 'y', 'l', 'i', 's', 't', '\n',
        's', 't', 'y', 'l', 'i', 's', 't', 'i', 'c', '\n',
        's', 't', 'y', 'l', 'i', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 't', 'y', 'l', 'i', 's', 't', 'i', 'c', 's', '\n',
        's', 't', 'y', 'l', 'i', 's', 't', 's', '\n',
        's', 't', 'y', 'l', 'u', 's', '\n',
        's', 't', 'y', 'l', 'u', 's', 'e', 's', '\n',
        's', 't', 'y', 'm', 'i', 'e', '\n',
        's', 't', 'y', 'm', 'i', 'e', 'd', '\n',
        's', 't', 'y', 'r', 'e', 'n', 'e', '\n',
        's', 't', 'y', 'x', '\n',
        's', 'u', 'a', 's', 'i', 'o', 'n', '\n',
        's', 'u', 'a', 'v', 'e', '\n',
        's', 'u', 'a', 'v', 'e', 'l', 'y', '\n',
        's', 'u', 'b', '\n',
        's', 'u', 'b', 'a', 'l', 't', 'e', 'r', 'n', '\n',
        's', 'u', 'b', 'a', 'l', 't', 'e', 'r', 'n', 's', '\n',
        's', 'u', 'b', 'a', 'r', 'c', 't', 'i', 'c', '\n',
        's', 'u', 'b', 'a', 't', 'o', 'm', 'i', 'c', '\n',
        's', 'u', 'b', 'b', 'e', 'd', '\n',
        's', 'u', 'b', 'b', 'i', 'n', 'g', '\n',
        's', 'u', 'b', 'c', 'l', 'a', 's', 's', '\n',
        's', 'u', 'b', 'c', 'l', 'a', 's', 's', 'e', 's', '\n',
        's', 'u', 'b', 'c', 'o', 'm', 'm', 'i', 't', 't', 'e', 'e', '\n',
        's', 'u', 'b', 'c', 'o', 'm', 'm', 'i', 't', 't', 'e', 'e', 's', '\n',
        's', 'u', 'b', 'c', 'o', 'n', 's', 'c', 'i', 'o', 'u', 's', '\n',
        's', 'u', 'b', 'c', 'o', 'n', 's', 'c', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        's', 'u', 'b', 'c', 'o', 'n', 's', 'c', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        's', 'u', 'b', 'c', 'o', 'n', 't', 'i', 'n', 'e', 'n', 't', '\n',
        's', 'u', 'b', 'c', 'o', 'n', 't', 'r', 'a', 'c', 't', '\n',
        's', 'u', 'b', 'c', 'o', 'n', 't', 'r', 'a', 'c', 't', 'e', 'd', '\n',
        's', 'u', 'b', 'c', 'o', 'n', 't', 'r', 'a', 'c', 't', 'i', 'n', 'g', '\n',
        's', 'u', 'b', 'c', 'o', 'n', 't', 'r', 'a', 'c', 't', 'o', 'r', '\n',
        's', 'u', 'b', 'c', 'o', 'n', 't', 'r', 'a', 'c', 't', 'o', 'r', 's', '\n',
        's', 'u', 'b', 'c', 'u', 'l', 't', 'u', 'r', 'a', 'l', '\n',
        's', 'u', 'b', 'c', 'u', 'l', 't', 'u', 'r', 'e', '\n',
        's', 'u', 'b', 'c', 'u', 'l', 't', 'u', 'r', 'e', 's', '\n',
        's', 'u', 'b', 'c', 'u', 't', 'a', 'n', 'e', 'o', 'u', 's', '\n',
        's', 'u', 'b', 'c', 'u', 't', 'a', 'n', 'e', 'o', 'u', 's', 'l', 'y', '\n',
        's', 'u', 'b', 'd', 'i', 'v', 'i', 'd', 'e', '\n',
        's', 'u', 'b', 'd', 'i', 'v', 'i', 'd', 'e', 'd', '\n',
        's', 'u', 'b', 'd', 'i', 'v', 'i', 'd', 'e', 's', '\n',
        's', 'u', 'b', 'd', 'i', 'v', 'i', 'd', 'i', 'n', 'g', '\n',
        's', 'u', 'b', 'd', 'i', 'v', 'i', 's', 'i', 'o', 'n', '\n',
        's', 'u', 'b', 'd', 'i', 'v', 'i', 's', 'i', 'o', 'n', 's', '\n',
        's', 'u', 'b', 'd', 'u', 'c', 't', 'e', 'd', '\n',
        's', 'u', 'b', 'd', 'u', 'c', 't', 'i', 'o', 'n', '\n',
        's', 'u', 'b', 'd', 'u', 'e', '\n',
        's', 'u', 'b', 'd', 'u', 'e', 'd', '\n',
        's', 'u', 'b', 'd', 'u', 'e', 's', '\n',
        's', 'u', 'b', 'd', 'u', 'i', 'n', 'g', '\n',
        's', 'u', 'b', 'e', 'd', 'i', 't', 'o', 'r', '\n',
        's', 'u', 'b', 'e', 'd', 'i', 't', 'o', 'r', 's', '\n',
        's', 'u', 'b', 'f', 'a', 'm', 'i', 'l', 'y', '\n',
        's', 'u', 'b', 'g', 'r', 'o', 'u', 'p', '\n',
        's', 'u', 'b', 'g', 'r', 'o', 'u', 'p', 's', '\n',
        's', 'u', 'b', 'h', 'a', 'r', 'm', 'o', 'n', 'i', 'c', '\n',
        's', 'u', 'b', 'h', 'a', 'r', 'm', 'o', 'n', 'i', 'c', 's', '\n',
        's', 'u', 'b', 'h', 'u', 'm', 'a', 'n', '\n',
        's', 'u', 'b', 'j', 'e', 'c', 't', '\n',
        's', 'u', 'b', 'j', 'e', 'c', 't', 'e', 'd', '\n',
        's', 'u', 'b', 'j', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        's', 'u', 'b', 'j', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        's', 'u', 'b', 'j', 'e', 'c', 't', 'i', 'v', 'e', '\n',
        's', 'u', 'b', 'j', 'e', 'c', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        's', 'u', 'b', 'j', 'e', 'c', 't', 'i', 'v', 'i', 's', 'm', '\n',
        's', 'u', 'b', 'j', 'e', 'c', 't', 'i', 'v', 'i', 's', 't', '\n',
        's', 'u', 'b', 'j', 'e', 'c', 't', 'i', 'v', 'i', 't', 'y', '\n',
        's', 'u', 'b', 'j', 'e', 'c', 't', 's', '\n',
        's', 'u', 'b', 'j', 'u', 'g', 'a', 't', 'e', '\n',
        's', 'u', 'b', 'j', 'u', 'g', 'a', 't', 'e', 'd', '\n',
        's', 'u', 'b', 'j', 'u', 'g', 'a', 't', 'i', 'n', 'g', '\n',
        's', 'u', 'b', 'j', 'u', 'g', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'u', 'b', 'j', 'u', 'n', 'c', 't', 'i', 'v', 'e', '\n',
        's', 'u', 'b', 'l', 'a', 'y', 'e', 'r', '\n',
        's', 'u', 'b', 'l', 'i', 'm', 'a', 't', 'e', '\n',
        's', 'u', 'b', 'l', 'i', 'm', 'a', 't', 'e', 'd', '\n',
        's', 'u', 'b', 'l', 'i', 'm', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'u', 'b', 'l', 'i', 'm', 'e', '\n',
        's', 'u', 'b', 'l', 'i', 'm', 'e', 'd', '\n',
        's', 'u', 'b', 'l', 'i', 'm', 'e', 'l', 'y', '\n',
        's', 'u', 'b', 'l', 'i', 'm', 'e', 's', '\n',
        's', 'u', 'b', 'l', 'i', 'm', 'e', 's', 't', '\n',
        's', 'u', 'b', 'l', 'i', 'm', 'i', 'n', 'a', 'l', '\n',
        's', 'u', 'b', 'l', 'i', 'm', 'i', 'n', 'a', 'l', 'l', 'y', '\n',
        's', 'u', 'b', 'l', 'i', 'm', 'i', 't', 'y', '\n',
        's', 'u', 'b', 'l', 'u', 'n', 'a', 'r', 'y', '\n',
        's', 'u', 'b', 'm', 'a', 'r', 'i', 'n', 'e', '\n',
        's', 'u', 'b', 'm', 'a', 'r', 'i', 'n', 'e', 's', '\n',
        's', 'u', 'b', 'm', 'e', 'r', 'g', 'e', '\n',
        's', 'u', 'b', 'm', 'e', 'r', 'g', 'e', 'd', '\n',
        's', 'u', 'b', 'm', 'e', 'r', 'g', 'e', 'n', 'c', 'e', '\n',
        's', 'u', 'b', 'm', 'e', 'r', 'g', 'e', 's', '\n',
        's', 'u', 'b', 'm', 'e', 'r', 'g', 'i', 'n', 'g', '\n',
        's', 'u', 'b', 'm', 'e', 'r', 's', 'i', 'b', 'l', 'e', '\n',
        's', 'u', 'b', 'm', 'e', 'r', 's', 'i', 'o', 'n', '\n',
        's', 'u', 'b', 'm', 'i', 's', 's', 'i', 'o', 'n', '\n',
        's', 'u', 'b', 'm', 'i', 's', 's', 'i', 'o', 'n', 's', '\n',
        's', 'u', 'b', 'm', 'i', 's', 's', 'i', 'v', 'e', '\n',
        's', 'u', 'b', 'm', 'i', 's', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        's', 'u', 'b', 'm', 'i', 's', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        's', 'u', 'b', 'm', 'i', 't', '\n',
        's', 'u', 'b', 'm', 'i', 't', 's', '\n',
        's', 'u', 'b', 'm', 'i', 't', 't', 'a', 'b', 'l', 'e', '\n',
        's', 'u', 'b', 'm', 'i', 't', 't', 'e', 'd', '\n',
        's', 'u', 'b', 'm', 'i', 't', 't', 'e', 'r', '\n',
        's', 'u', 'b', 'm', 'i', 't', 't', 'e', 'r', 's', '\n',
        's', 'u', 'b', 'm', 'i', 't', 't', 'i', 'n', 'g', '\n',
        's', 'u', 'b', 'n', 'o', 'r', 'm', 'a', 'l', '\n',
        's', 'u', 'b', 'o', 'p', 't', 'i', 'm', 'a', 'l', '\n',
        's', 'u', 'b', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'e', '\n',
        's', 'u', 'b', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'e', 'd', '\n',
        's', 'u', 'b', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'e', 's', '\n',
        's', 'u', 'b', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        's', 'u', 'b', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'u', 'b', 'p', 'l', 'o', 't', '\n',
        's', 'u', 'b', 'p', 'l', 'o', 't', 's', '\n',
        's', 'u', 'b', 'p', 'o', 'e', 'n', 'a', '\n',
        's', 'u', 'b', 'p', 'o', 'e', 'n', 'a', 'e', 'd', '\n',
        's', 'u', 'b', 'p', 'r', 'o', 'g', 'r', 'a', 'm', '\n',
        's', 'u', 'b', 'p', 'r', 'o', 'g', 'r', 'a', 'm', 's', '\n',
        's', 'u', 'b', 'r', 'e', 'g', 'i', 'o', 'n', 'a', 'l', '\n',
        's', 'u', 'b', 'r', 'o', 'u', 't', 'i', 'n', 'e', '\n',
        's', 'u', 'b', 'r', 'o', 'u', 't', 'i', 'n', 'e', 's', '\n',
        's', 'u', 'b', 's', '\n',
        's', 'u', 'b', 's', 'c', 'r', 'i', 'b', 'e', '\n',
        's', 'u', 'b', 's', 'c', 'r', 'i', 'b', 'e', 'd', '\n',
        's', 'u', 'b', 's', 'c', 'r', 'i', 'b', 'e', 'r', '\n',
        's', 'u', 'b', 's', 'c', 'r', 'i', 'b', 'e', 'r', 's', '\n',
        's', 'u', 'b', 's', 'c', 'r', 'i', 'b', 'e', 's', '\n',
        's', 'u', 'b', 's', 'c', 'r', 'i', 'b', 'i', 'n', 'g', '\n',
        's', 'u', 'b', 's', 'c', 'r', 'i', 'p', 't', '\n',
        's', 'u', 'b', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', '\n',
        's', 'u', 'b', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', 's', '\n',
        's', 'u', 'b', 's', 'c', 'r', 'i', 'p', 't', 's', '\n',
        's', 'u', 'b', 's', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        's', 'u', 'b', 's', 'e', 'c', 't', 'i', 'o', 'n', 's', '\n',
        's', 'u', 'b', 's', 'e', 'q', 'u', 'e', 'n', 't', '\n',
        's', 'u', 'b', 's', 'e', 'q', 'u', 'e', 'n', 't', 'l', 'y', '\n',
        's', 'u', 'b', 's', 'e', 'r', 'v', 'i', 'e', 'n', 'c', 'e', '\n',
        's', 'u', 'b', 's', 'e', 'r', 'v', 'i', 'e', 'n', 't', '\n',
        's', 'u', 'b', 's', 'e', 't', '\n',
        's', 'u', 'b', 's', 'e', 't', 's', '\n',
        's', 'u', 'b', 's', 'i', 'd', 'e', '\n',
        's', 'u', 'b', 's', 'i', 'd', 'e', 'd', '\n',
        's', 'u', 'b', 's', 'i', 'd', 'e', 'n', 'c', 'e', '\n',
        's', 'u', 'b', 's', 'i', 'd', 'e', 's', '\n',
        's', 'u', 'b', 's', 'i', 'd', 'i', 'a', 'r', 'i', 'e', 's', '\n',
        's', 'u', 'b', 's', 'i', 'd', 'i', 'a', 'r', 'i', 't', 'y', '\n',
        's', 'u', 'b', 's', 'i', 'd', 'i', 'a', 'r', 'y', '\n',
        's', 'u', 'b', 's', 'i', 'd', 'i', 'e', 's', '\n',
        's', 'u', 'b', 's', 'i', 'd', 'i', 'n', 'g', '\n',
        's', 'u', 'b', 's', 'i', 'd', 'i', 's', 'e', '\n',
        's', 'u', 'b', 's', 'i', 'd', 'i', 's', 'e', 'd', '\n',
        's', 'u', 'b', 's', 'i', 'd', 'i', 's', 'e', 's', '\n',
        's', 'u', 'b', 's', 'i', 'd', 'i', 's', 'i', 'n', 'g', '\n',
        's', 'u', 'b', 's', 'i', 'd', 'y', '\n',
        's', 'u', 'b', 's', 'i', 's', 't', '\n',
        's', 'u', 'b', 's', 'i', 's', 't', 'e', 'd', '\n',
        's', 'u', 'b', 's', 'i', 's', 't', 'e', 'n', 'c', 'e', '\n',
        's', 'u', 'b', 's', 'i', 's', 't', 'i', 'n', 'g', '\n',
        's', 'u', 'b', 's', 'i', 's', 't', 's', '\n',
        's', 'u', 'b', 's', 'o', 'i', 'l', '\n',
        's', 'u', 'b', 's', 'o', 'n', 'i', 'c', '\n',
        's', 'u', 'b', 's', 'p', 'a', 'c', 'e', '\n',
        's', 'u', 'b', 's', 'p', 'a', 'c', 'e', 's', '\n',
        's', 'u', 'b', 's', 'p', 'e', 'c', 'i', 'e', 's', '\n',
        's', 'u', 'b', 's', 't', 'a', 'n', 'c', 'e', '\n',
        's', 'u', 'b', 's', 't', 'a', 'n', 'c', 'e', 's', '\n',
        's', 'u', 'b', 's', 't', 'a', 'n', 'd', 'a', 'r', 'd', '\n',
        's', 'u', 'b', 's', 't', 'a', 'n', 't', 'i', 'a', 'l', '\n',
        's', 'u', 'b', 's', 't', 'a', 'n', 't', 'i', 'a', 'l', 'l', 'y', '\n',
        's', 'u', 'b', 's', 't', 'a', 'n', 't', 'i', 'a', 't', 'e', '\n',
        's', 'u', 'b', 's', 't', 'a', 'n', 't', 'i', 'a', 't', 'e', 'd', '\n',
        's', 'u', 'b', 's', 't', 'a', 'n', 't', 'i', 'a', 't', 'e', 's', '\n',
        's', 'u', 'b', 's', 't', 'a', 'n', 't', 'i', 'a', 't', 'i', 'n', 'g', '\n',
        's', 'u', 'b', 's', 't', 'a', 'n', 't', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'u', 'b', 's', 't', 'a', 'n', 't', 'i', 'v', 'e', '\n',
        's', 'u', 'b', 's', 't', 'a', 'n', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        's', 'u', 'b', 's', 't', 'a', 'n', 't', 'i', 'v', 'e', 's', '\n',
        's', 'u', 'b', 's', 't', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'u', 'b', 's', 't', 'i', 't', 'u', 't', 'a', 'b', 'l', 'e', '\n',
        's', 'u', 'b', 's', 't', 'i', 't', 'u', 't', 'e', '\n',
        's', 'u', 'b', 's', 't', 'i', 't', 'u', 't', 'e', 'd', '\n',
        's', 'u', 'b', 's', 't', 'i', 't', 'u', 't', 'e', 's', '\n',
        's', 'u', 'b', 's', 't', 'i', 't', 'u', 't', 'i', 'n', 'g', '\n',
        's', 'u', 'b', 's', 't', 'i', 't', 'u', 't', 'i', 'o', 'n', '\n',
        's', 'u', 'b', 's', 't', 'i', 't', 'u', 't', 'i', 'o', 'n', 's', '\n',
        's', 'u', 'b', 's', 't', 'r', 'a', 't', 'a', '\n',
        's', 'u', 'b', 's', 't', 'r', 'a', 't', 'e', '\n',
        's', 'u', 'b', 's', 't', 'r', 'a', 't', 'e', 's', '\n',
        's', 'u', 'b', 's', 't', 'r', 'a', 't', 'u', 'm', '\n',
        's', 'u', 'b', 's', 't', 'r', 'u', 'c', 't', 'u', 'r', 'e', '\n',
        's', 'u', 'b', 's', 't', 'r', 'u', 'c', 't', 'u', 'r', 'e', 's', '\n',
        's', 'u', 'b', 's', 'u', 'm', 'e', '\n',
        's', 'u', 'b', 's', 'u', 'm', 'e', 'd', '\n',
        's', 'u', 'b', 's', 'u', 'm', 'e', 's', '\n',
        's', 'u', 'b', 's', 'u', 'm', 'i', 'n', 'g', '\n',
        's', 'u', 'b', 's', 'u', 'r', 'f', 'a', 'c', 'e', '\n',
        's', 'u', 'b', 's', 'y', 's', 't', 'e', 'm', '\n',
        's', 'u', 'b', 's', 'y', 's', 't', 'e', 'm', 's', '\n',
        's', 'u', 'b', 't', 'e', 'n', 'a', 'n', 't', 's', '\n',
        's', 'u', 'b', 't', 'e', 'n', 'd', '\n',
        's', 'u', 'b', 't', 'e', 'n', 'd', 'e', 'd', '\n',
        's', 'u', 'b', 't', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        's', 'u', 'b', 't', 'e', 'n', 'd', 's', '\n',
        's', 'u', 'b', 't', 'e', 'r', 'f', 'u', 'g', 'e', '\n',
        's', 'u', 'b', 't', 'e', 'r', 'r', 'a', 'n', 'e', 'a', 'n', '\n',
        's', 'u', 'b', 't', 'e', 'x', 't', '\n',
        's', 'u', 'b', 't', 'i', 't', 'l', 'e', '\n',
        's', 'u', 'b', 't', 'i', 't', 'l', 'e', 'd', '\n',
        's', 'u', 'b', 't', 'i', 't', 'l', 'e', 's', '\n',
        's', 'u', 'b', 't', 'i', 't', 'l', 'i', 'n', 'g', '\n',
        's', 'u', 'b', 't', 'l', 'e', '\n',
        's', 'u', 'b', 't', 'l', 'e', 'r', '\n',
        's', 'u', 'b', 't', 'l', 'e', 's', 't', '\n',
        's', 'u', 'b', 't', 'l', 'e', 't', 'i', 'e', 's', '\n',
        's', 'u', 'b', 't', 'l', 'e', 't', 'y', '\n',
        's', 'u', 'b', 't', 'l', 'y', '\n',
        's', 'u', 'b', 't', 'o', 't', 'a', 'l', '\n',
        's', 'u', 'b', 't', 'o', 't', 'a', 'l', 's', '\n',
        's', 'u', 'b', 't', 'r', 'a', 'c', 't', '\n',
        's', 'u', 'b', 't', 'r', 'a', 'c', 't', 'e', 'd', '\n',
        's', 'u', 'b', 't', 'r', 'a', 'c', 't', 'i', 'n', 'g', '\n',
        's', 'u', 'b', 't', 'r', 'a', 'c', 't', 'i', 'o', 'n', '\n',
        's', 'u', 'b', 't', 'r', 'a', 'c', 't', 'i', 'o', 'n', 's', '\n',
        's', 'u', 'b', 't', 'r', 'a', 'c', 't', 'i', 'v', 'e', '\n',
        's', 'u', 'b', 't', 'r', 'a', 'c', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        's', 'u', 'b', 't', 'r', 'a', 'c', 't', 's', '\n',
        's', 'u', 'b', 't', 'r', 'o', 'p', 'i', 'c', 'a', 'l', '\n',
        's', 'u', 'b', 't', 'r', 'o', 'p', 'i', 'c', 's', '\n',
        's', 'u', 'b', 't', 'y', 'p', 'e', '\n',
        's', 'u', 'b', 't', 'y', 'p', 'e', 's', '\n',
        's', 'u', 'b', 'u', 'n', 'i', 't', '\n',
        's', 'u', 'b', 'u', 'n', 'i', 't', 's', '\n',
        's', 'u', 'b', 'u', 'r', 'b', '\n',
        's', 'u', 'b', 'u', 'r', 'b', 'a', 'n', '\n',
        's', 'u', 'b', 'u', 'r', 'b', 'a', 'n', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'u', 'b', 'u', 'r', 'b', 'a', 'n', 'i', 't', 'e', 's', '\n',
        's', 'u', 'b', 'u', 'r', 'b', 'i', 'a', '\n',
        's', 'u', 'b', 'u', 'r', 'b', 's', '\n',
        's', 'u', 'b', 'v', 'e', 'n', 't', 'i', 'o', 'n', '\n',
        's', 'u', 'b', 'v', 'e', 'n', 't', 'i', 'o', 'n', 's', '\n',
        's', 'u', 'b', 'v', 'e', 'r', 's', 'i', 'o', 'n', '\n',
        's', 'u', 'b', 'v', 'e', 'r', 's', 'i', 'v', 'e', '\n',
        's', 'u', 'b', 'v', 'e', 'r', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        's', 'u', 'b', 'v', 'e', 'r', 's', 'i', 'v', 'e', 's', '\n',
        's', 'u', 'b', 'v', 'e', 'r', 't', '\n',
        's', 'u', 'b', 'v', 'e', 'r', 't', 'e', 'd', '\n',
        's', 'u', 'b', 'v', 'e', 'r', 't', 'i', 'n', 'g', '\n',
        's', 'u', 'b', 'v', 'e', 'r', 't', 's', '\n',
        's', 'u', 'b', 'w', 'a', 'y', '\n',
        's', 'u', 'b', 'w', 'a', 'y', 's', '\n',
        's', 'u', 'b', 'z', 'e', 'r', 'o', '\n',
        's', 'u', 'c', 'c', 'e', 'e', 'd', '\n',
        's', 'u', 'c', 'c', 'e', 'e', 'd', 'e', 'd', '\n',
        's', 'u', 'c', 'c', 'e', 'e', 'd', 'i', 'n', 'g', '\n',
        's', 'u', 'c', 'c', 'e', 'e', 'd', 's', '\n',
        's', 'u', 'c', 'c', 'e', 's', 's', '\n',
        's', 'u', 'c', 'c', 'e', 's', 's', 'e', 's', '\n',
        's', 'u', 'c', 'c', 'e', 's', 's', 'f', 'u', 'l', '\n',
        's', 'u', 'c', 'c', 'e', 's', 's', 'f', 'u', 'l', 'l', 'y', '\n',
        's', 'u', 'c', 'c', 'e', 's', 's', 'i', 'o', 'n', '\n',
        's', 'u', 'c', 'c', 'e', 's', 's', 'i', 'o', 'n', 's', '\n',
        's', 'u', 'c', 'c', 'e', 's', 's', 'i', 'v', 'e', '\n',
        's', 'u', 'c', 'c', 'e', 's', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        's', 'u', 'c', 'c', 'e', 's', 's', 'o', 'r', '\n',
        's', 'u', 'c', 'c', 'e', 's', 's', 'o', 'r', 's', '\n',
        's', 'u', 'c', 'c', 'i', 'n', 'c', 't', '\n',
        's', 'u', 'c', 'c', 'i', 'n', 'c', 't', 'l', 'y', '\n',
        's', 'u', 'c', 'c', 'i', 'n', 'c', 't', 'n', 'e', 's', 's', '\n',
        's', 'u', 'c', 'c', 'o', 'u', 'r', '\n',
        's', 'u', 'c', 'c', 'u', 'l', 'e', 'n', 'c', 'e', '\n',
        's', 'u', 'c', 'c', 'u', 'l', 'e', 'n', 't', '\n',
        's', 'u', 'c', 'c', 'u', 'm', 'b', '\n',
        's', 'u', 'c', 'c', 'u', 'm', 'b', 'e', 'd', '\n',
        's', 'u', 'c', 'c', 'u', 'm', 'b', 'i', 'n', 'g', '\n',
        's', 'u', 'c', 'c', 'u', 'm', 'b', 's', '\n',
        's', 'u', 'c', 'h', '\n',
        's', 'u', 'c', 'h', 'a', 'n', 'd', 's', 'u', 'c', 'h', '\n',
        's', 'u', 'c', 'h', 'l', 'i', 'k', 'e', '\n',
        's', 'u', 'c', 'k', '\n',
        's', 'u', 'c', 'k', 'a', 'b', 'l', 'e', '\n',
        's', 'u', 'c', 'k', 'e', 'd', '\n',
        's', 'u', 'c', 'k', 'e', 'r', '\n',
        's', 'u', 'c', 'k', 'e', 'r', 's', '\n',
        's', 'u', 'c', 'k', 'i', 'n', 'g', '\n',
        's', 'u', 'c', 'k', 'l', 'e', '\n',
        's', 'u', 'c', 'k', 'l', 'e', 'd', '\n',
        's', 'u', 'c', 'k', 'l', 'e', 's', '\n',
        's', 'u', 'c', 'k', 'l', 'i', 'n', 'g', '\n',
        's', 'u', 'c', 'k', 'l', 'i', 'n', 'g', 's', '\n',
        's', 'u', 'c', 'k', 's', '\n',
        's', 'u', 'c', 'r', 'o', 's', 'e', '\n',
        's', 'u', 'c', 't', 'i', 'o', 'n', '\n',
        's', 'u', 'd', '\n',
        's', 'u', 'd', 'a', 'n', '\n',
        's', 'u', 'd', 'd', 'e', 'n', '\n',
        's', 'u', 'd', 'd', 'e', 'n', 'l', 'y', '\n',
        's', 'u', 'd', 'd', 'e', 'n', 'n', 'e', 's', 's', '\n',
        's', 'u', 'd', 's', '\n',
        's', 'u', 'e', '\n',
        's', 'u', 'e', 'd', '\n',
        's', 'u', 'e', 'd', 'e', '\n',
        's', 'u', 'e', 's', '\n',
        's', 'u', 'e', 't', '\n',
        's', 'u', 'f', 'f', 'e', 'r', '\n',
        's', 'u', 'f', 'f', 'e', 'r', 'a', 'n', 'c', 'e', '\n',
        's', 'u', 'f', 'f', 'e', 'r', 'e', 'd', '\n',
        's', 'u', 'f', 'f', 'e', 'r', 'e', 'r', '\n',
        's', 'u', 'f', 'f', 'e', 'r', 'e', 'r', 's', '\n',
        's', 'u', 'f', 'f', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'u', 'f', 'f', 'e', 'r', 'i', 'n', 'g', 's', '\n',
        's', 'u', 'f', 'f', 'e', 'r', 's', '\n',
        's', 'u', 'f', 'f', 'i', 'c', 'e', '\n',
        's', 'u', 'f', 'f', 'i', 'c', 'e', 'd', '\n',
        's', 'u', 'f', 'f', 'i', 'c', 'e', 's', '\n',
        's', 'u', 'f', 'f', 'i', 'c', 'i', 'e', 'n', 'c', 'y', '\n',
        's', 'u', 'f', 'f', 'i', 'c', 'i', 'e', 'n', 't', '\n',
        's', 'u', 'f', 'f', 'i', 'c', 'i', 'e', 'n', 't', 'l', 'y', '\n',
        's', 'u', 'f', 'f', 'i', 'c', 'i', 'n', 'g', '\n',
        's', 'u', 'f', 'f', 'i', 'x', '\n',
        's', 'u', 'f', 'f', 'i', 'x', 'e', 'd', '\n',
        's', 'u', 'f', 'f', 'i', 'x', 'e', 's', '\n',
        's', 'u', 'f', 'f', 'o', 'c', 'a', 't', 'e', '\n',
        's', 'u', 'f', 'f', 'o', 'c', 'a', 't', 'e', 'd', '\n',
        's', 'u', 'f', 'f', 'o', 'c', 'a', 't', 'e', 's', '\n',
        's', 'u', 'f', 'f', 'o', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        's', 'u', 'f', 'f', 'o', 'c', 'a', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        's', 'u', 'f', 'f', 'o', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'u', 'f', 'f', 'r', 'a', 'g', 'e', '\n',
        's', 'u', 'f', 'f', 'r', 'a', 'g', 'e', 't', 't', 'e', '\n',
        's', 'u', 'f', 'f', 'r', 'a', 'g', 'e', 't', 't', 'e', 's', '\n',
        's', 'u', 'f', 'f', 'r', 'a', 'g', 'i', 's', 't', '\n',
        's', 'u', 'f', 'f', 'u', 's', 'e', '\n',
        's', 'u', 'f', 'f', 'u', 's', 'e', 'd', '\n',
        's', 'u', 'f', 'f', 'u', 's', 'e', 's', '\n',
        's', 'u', 'f', 'f', 'u', 's', 'i', 'n', 'g', '\n',
        's', 'u', 'f', 'f', 'u', 's', 'i', 'o', 'n', '\n',
        's', 'u', 'g', 'a', 'r', '\n',
        's', 'u', 'g', 'a', 'r', 'c', 'o', 'a', 't', 'e', 'd', '\n',
        's', 'u', 'g', 'a', 'r', 'e', 'd', '\n',
        's', 'u', 'g', 'a', 'r', 'i', 'n', 'g', '\n',
        's', 'u', 'g', 'a', 'r', 'p', 'l', 'u', 'm', 's', '\n',
        's', 'u', 'g', 'a', 'r', 's', '\n',
        's', 'u', 'g', 'a', 'r', 'y', '\n',
        's', 'u', 'g', 'g', 'e', 's', 't', '\n',
        's', 'u', 'g', 'g', 'e', 's', 't', 'e', 'd', '\n',
        's', 'u', 'g', 'g', 'e', 's', 't', 'e', 'r', '\n',
        's', 'u', 'g', 'g', 'e', 's', 't', 'e', 'r', 's', '\n',
        's', 'u', 'g', 'g', 'e', 's', 't', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        's', 'u', 'g', 'g', 'e', 's', 't', 'i', 'b', 'l', 'e', '\n',
        's', 'u', 'g', 'g', 'e', 's', 't', 'i', 'n', 'g', '\n',
        's', 'u', 'g', 'g', 'e', 's', 't', 'i', 'o', 'n', '\n',
        's', 'u', 'g', 'g', 'e', 's', 't', 'i', 'o', 'n', 's', '\n',
        's', 'u', 'g', 'g', 'e', 's', 't', 'i', 'v', 'e', '\n',
        's', 'u', 'g', 'g', 'e', 's', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        's', 'u', 'g', 'g', 'e', 's', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        's', 'u', 'g', 'g', 'e', 's', 't', 's', '\n',
        's', 'u', 'g', 'i', 'l', 'l', 'a', 't', 'e', '\n',
        's', 'u', 'i', 'c', 'i', 'd', 'a', 'l', '\n',
        's', 'u', 'i', 'c', 'i', 'd', 'a', 'l', 'l', 'y', '\n',
        's', 'u', 'i', 'c', 'i', 'd', 'e', '\n',
        's', 'u', 'i', 'c', 'i', 'd', 'e', 's', '\n',
        's', 'u', 'i', 'n', 'g', '\n',
        's', 'u', 'i', 't', '\n',
        's', 'u', 'i', 't', 'a', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', '\n',
        's', 'u', 'i', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        's', 'u', 'i', 't', 'a', 'b', 'l', 'e', '\n',
        's', 'u', 'i', 't', 'a', 'b', 'l', 'e', 'n', 'e', 's', 's', '\n',
        's', 'u', 'i', 't', 'a', 'b', 'l', 'y', '\n',
        's', 'u', 'i', 't', 'c', 'a', 's', 'e', '\n',
        's', 'u', 'i', 't', 'c', 'a', 's', 'e', 's', '\n',
        's', 'u', 'i', 't', 'e', '\n',
        's', 'u', 'i', 't', 'e', 'd', '\n',
        's', 'u', 'i', 't', 'e', 's', '\n',
        's', 'u', 'i', 't', 'i', 'n', 'g', '\n',
        's', 'u', 'i', 't', 'o', 'r', '\n',
        's', 'u', 'i', 't', 'o', 'r', 's', '\n',
        's', 'u', 'i', 't', 's', '\n',
        's', 'u', 'l', 'k', '\n',
        's', 'u', 'l', 'k', 'e', 'd', '\n',
        's', 'u', 'l', 'k', 'i', 'e', 'r', '\n',
        's', 'u', 'l', 'k', 'i', 'e', 's', 't', '\n',
        's', 'u', 'l', 'k', 'i', 'l', 'y', '\n',
        's', 'u', 'l', 'k', 'i', 'n', 'e', 's', 's', '\n',
        's', 'u', 'l', 'k', 'i', 'n', 'g', '\n',
        's', 'u', 'l', 'k', 's', '\n',
        's', 'u', 'l', 'k', 'y', '\n',
        's', 'u', 'l', 'l', 'e', 'n', '\n',
        's', 'u', 'l', 'l', 'e', 'n', 'l', 'y', '\n',
        's', 'u', 'l', 'l', 'e', 'n', 'n', 'e', 's', 's', '\n',
        's', 'u', 'l', 'l', 'i', 'e', 'd', '\n',
        's', 'u', 'l', 'l', 'y', '\n',
        's', 'u', 'l', 'l', 'y', 'i', 'n', 'g', '\n',
        's', 'u', 'l', 'p', 'h', 'a', 't', 'e', '\n',
        's', 'u', 'l', 'p', 'h', 'a', 't', 'e', 's', '\n',
        's', 'u', 'l', 'p', 'h', 'i', 'd', 'e', '\n',
        's', 'u', 'l', 'p', 'h', 'i', 'd', 'e', 's', '\n',
        's', 'u', 'l', 'p', 'h', 'o', 'n', 'a', 'm', 'i', 'd', 'e', 's', '\n',
        's', 'u', 'l', 'p', 'h', 'u', 'r', '\n',
        's', 'u', 'l', 'p', 'h', 'u', 'r', 'i', 'c', '\n',
        's', 'u', 'l', 'p', 'h', 'u', 'r', 'o', 'u', 's', '\n',
        's', 'u', 'l', 't', 'a', 'n', '\n',
        's', 'u', 'l', 't', 'a', 'n', 'a', '\n',
        's', 'u', 'l', 't', 'a', 'n', 'a', 's', '\n',
        's', 'u', 'l', 't', 'a', 'n', 's', '\n',
        's', 'u', 'l', 't', 'r', 'y', '\n',
        's', 'u', 'm', '\n',
        's', 'u', 'm', 'a', 't', 'r', 'a', '\n',
        's', 'u', 'm', 'm', 'a', '\n',
        's', 'u', 'm', 'm', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        's', 'u', 'm', 'm', 'a', 'b', 'l', 'e', '\n',
        's', 'u', 'm', 'm', 'a', 'r', 'i', 'e', 's', '\n',
        's', 'u', 'm', 'm', 'a', 'r', 'i', 'l', 'y', '\n',
        's', 'u', 'm', 'm', 'a', 'r', 'i', 's', 'e', '\n',
        's', 'u', 'm', 'm', 'a', 'r', 'i', 's', 'e', 'd', '\n',
        's', 'u', 'm', 'm', 'a', 'r', 'i', 's', 'e', 'r', '\n',
        's', 'u', 'm', 'm', 'a', 'r', 'i', 's', 'e', 'r', 's', '\n',
        's', 'u', 'm', 'm', 'a', 'r', 'i', 's', 'e', 's', '\n',
        's', 'u', 'm', 'm', 'a', 'r', 'i', 's', 'i', 'n', 'g', '\n',
        's', 'u', 'm', 'm', 'a', 'r', 'y', '\n',
        's', 'u', 'm', 'm', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'u', 'm', 'm', 'a', 't', 'i', 'o', 'n', 's', '\n',
        's', 'u', 'm', 'm', 'e', 'd', '\n',
        's', 'u', 'm', 'm', 'e', 'r', '\n',
        's', 'u', 'm', 'm', 'e', 'r', 's', '\n',
        's', 'u', 'm', 'm', 'e', 'r', 't', 'i', 'm', 'e', '\n',
        's', 'u', 'm', 'm', 'e', 'r', 'y', '\n',
        's', 'u', 'm', 'm', 'i', 'n', 'g', '\n',
        's', 'u', 'm', 'm', 'i', 't', '\n',
        's', 'u', 'm', 'm', 'i', 't', 's', '\n',
        's', 'u', 'm', 'm', 'o', 'n', '\n',
        's', 'u', 'm', 'm', 'o', 'n', 'e', 'd', '\n',
        's', 'u', 'm', 'm', 'o', 'n', 'e', 'r', '\n',
        's', 'u', 'm', 'm', 'o', 'n', 'i', 'n', 'g', '\n',
        's', 'u', 'm', 'm', 'o', 'n', 'i', 'n', 'g', 's', '\n',
        's', 'u', 'm', 'm', 'o', 'n', 's', '\n',
        's', 'u', 'm', 'm', 'o', 'n', 's', 'e', 'd', '\n',
        's', 'u', 'm', 'm', 'o', 'n', 's', 'e', 's', '\n',
        's', 'u', 'm', 'm', 'o', 'n', 's', 'i', 'n', 'g', '\n',
        's', 'u', 'm', 'o', '\n',
        's', 'u', 'm', 'p', '\n',
        's', 'u', 'm', 'p', 's', '\n',
        's', 'u', 'm', 'p', 't', 'u', 'o', 'u', 's', '\n',
        's', 'u', 'm', 'p', 't', 'u', 'o', 'u', 's', 'l', 'y', '\n',
        's', 'u', 'm', 'p', 't', 'u', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        's', 'u', 'm', 's', '\n',
        's', 'u', 'n', '\n',
        's', 'u', 'n', 'b', 'a', 't', 'h', '\n',
        's', 'u', 'n', 'b', 'a', 't', 'h', 'e', '\n',
        's', 'u', 'n', 'b', 'a', 't', 'h', 'e', 'd', '\n',
        's', 'u', 'n', 'b', 'a', 't', 'h', 'e', 'r', 's', '\n',
        's', 'u', 'n', 'b', 'a', 't', 'h', 'i', 'n', 'g', '\n',
        's', 'u', 'n', 'b', 'e', 'a', 'm', '\n',
        's', 'u', 'n', 'b', 'e', 'a', 'm', 's', '\n',
        's', 'u', 'n', 'b', 'e', 'd', '\n',
        's', 'u', 'n', 'b', 'e', 'd', 's', '\n',
        's', 'u', 'n', 'b', 'l', 'o', 'c', 'k', '\n',
        's', 'u', 'n', 'b', 'u', 'r', 'n', '\n',
        's', 'u', 'n', 'b', 'u', 'r', 'n', 'e', 'd', '\n',
        's', 'u', 'n', 'b', 'u', 'r', 'n', 's', '\n',
        's', 'u', 'n', 'b', 'u', 'r', 'n', 't', '\n',
        's', 'u', 'n', 'b', 'u', 'r', 's', 't', '\n',
        's', 'u', 'n', 'c', 'r', 'e', 'a', 'm', '\n',
        's', 'u', 'n', 'd', 'a', 'e', 's', '\n',
        's', 'u', 'n', 'd', 'a', 'y', '\n',
        's', 'u', 'n', 'd', 'a', 'y', 's', '\n',
        's', 'u', 'n', 'd', 'i', 'a', 'l', '\n',
        's', 'u', 'n', 'd', 'i', 'a', 'l', 's', '\n',
        's', 'u', 'n', 'd', 'o', 'w', 'n', '\n',
        's', 'u', 'n', 'd', 'r', 'i', 'e', 'd', '\n',
        's', 'u', 'n', 'd', 'r', 'i', 'e', 's', '\n',
        's', 'u', 'n', 'd', 'r', 'y', '\n',
        's', 'u', 'n', 'f', 'l', 'o', 'w', 'e', 'r', '\n',
        's', 'u', 'n', 'f', 'l', 'o', 'w', 'e', 'r', 's', '\n',
        's', 'u', 'n', 'g', '\n',
        's', 'u', 'n', 'g', 'l', 'a', 's', 's', 'e', 's', '\n',
        's', 'u', 'n', 'k', '\n',
        's', 'u', 'n', 'k', 'e', 'n', '\n',
        's', 'u', 'n', 'k', 'i', 'n', 'g', '\n',
        's', 'u', 'n', 'l', 'e', 's', 's', '\n',
        's', 'u', 'n', 'l', 'i', 'g', 'h', 't', '\n',
        's', 'u', 'n', 'l', 'i', 't', '\n',
        's', 'u', 'n', 'l', 'o', 'u', 'n', 'g', 'e', 'r', '\n',
        's', 'u', 'n', 'n', 'e', 'd', '\n',
        's', 'u', 'n', 'n', 'i', 'e', 'r', '\n',
        's', 'u', 'n', 'n', 'i', 'e', 's', 't', '\n',
        's', 'u', 'n', 'n', 'i', 'n', 'g', '\n',
        's', 'u', 'n', 'n', 'y', '\n',
        's', 'u', 'n', 'r', 'i', 's', 'e', '\n',
        's', 'u', 'n', 'r', 'i', 's', 'e', 's', '\n',
        's', 'u', 'n', 'r', 'o', 'o', 'f', '\n',
        's', 'u', 'n', 's', '\n',
        's', 'u', 'n', 's', 'c', 'r', 'e', 'e', 'n', '\n',
        's', 'u', 'n', 's', 'c', 'r', 'e', 'e', 'n', 's', '\n',
        's', 'u', 'n', 's', 'e', 't', '\n',
        's', 'u', 'n', 's', 'e', 't', 's', '\n',
        's', 'u', 'n', 's', 'h', 'a', 'd', 'e', '\n',
        's', 'u', 'n', 's', 'h', 'i', 'n', 'e', '\n',
        's', 'u', 'n', 's', 'p', 'o', 't', '\n',
        's', 'u', 'n', 's', 'p', 'o', 't', 's', '\n',
        's', 'u', 'n', 's', 't', 'r', 'o', 'k', 'e', '\n',
        's', 'u', 'n', 't', 'a', 'n', '\n',
        's', 'u', 'n', 't', 'a', 'n', 'n', 'e', 'd', '\n',
        's', 'u', 'p', '\n',
        's', 'u', 'p', 'e', 'r', '\n',
        's', 'u', 'p', 'e', 'r', 'a', 'b', 'u', 'n', 'd', 'a', 'n', 'c', 'e', '\n',
        's', 'u', 'p', 'e', 'r', 'a', 'b', 'u', 'n', 'd', 'a', 'n', 't', '\n',
        's', 'u', 'p', 'e', 'r', 'a', 'n', 'n', 'u', 'a', 't', 'e', '\n',
        's', 'u', 'p', 'e', 'r', 'a', 'n', 'n', 'u', 'a', 't', 'e', 'd', '\n',
        's', 'u', 'p', 'e', 'r', 'a', 'n', 'n', 'u', 'a', 't', 'i', 'n', 'g', '\n',
        's', 'u', 'p', 'e', 'r', 'a', 'n', 'n', 'u', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'u', 'p', 'e', 'r', 'b', '\n',
        's', 'u', 'p', 'e', 'r', 'b', 'l', 'y', '\n',
        's', 'u', 'p', 'e', 'r', 'c', 'h', 'a', 'r', 'g', 'e', 'd', '\n',
        's', 'u', 'p', 'e', 'r', 'c', 'h', 'a', 'r', 'g', 'e', 'r', '\n',
        's', 'u', 'p', 'e', 'r', 'c', 'i', 'l', 'i', 'o', 'u', 's', '\n',
        's', 'u', 'p', 'e', 'r', 'c', 'i', 'l', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        's', 'u', 'p', 'e', 'r', 'c', 'i', 'l', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        's', 'u', 'p', 'e', 'r', 'c', 'o', 'm', 'p', 'u', 't', 'e', 'r', '\n',
        's', 'u', 'p', 'e', 'r', 'c', 'o', 'm', 'p', 'u', 't', 'e', 'r', 's', '\n',
        's', 'u', 'p', 'e', 'r', 'c', 'o', 'm', 'p', 'u', 't', 'i', 'n', 'g', '\n',
        's', 'u', 'p', 'e', 'r', 'c', 'o', 'n', 'd', 'u', 'c', 't', 'i', 'n', 'g', '\n',
        's', 'u', 'p', 'e', 'r', 'c', 'o', 'n', 'd', 'u', 'c', 't', 'i', 'v', 'i', 't', 'y', '\n',
        's', 'u', 'p', 'e', 'r', 'c', 'o', 'n', 'd', 'u', 'c', 't', 'o', 'r', '\n',
        's', 'u', 'p', 'e', 'r', 'c', 'o', 'n', 'd', 'u', 'c', 't', 'o', 'r', 's', '\n',
        's', 'u', 'p', 'e', 'r', 'c', 'o', 'o', 'l', 'e', 'd', '\n',
        's', 'u', 'p', 'e', 'r', 'c', 'o', 'o', 'l', 'i', 'n', 'g', '\n',
        's', 'u', 'p', 'e', 'r', 'c', 'r', 'i', 't', 'i', 'c', 'a', 'l', '\n',
        's', 'u', 'p', 'e', 'r', 'd', 'e', 'n', 's', 'e', '\n',
        's', 'u', 'p', 'e', 'r', 'f', 'a', 'm', 'i', 'l', 'y', '\n',
        's', 'u', 'p', 'e', 'r', 'f', 'i', 'c', 'i', 'a', 'l', '\n',
        's', 'u', 'p', 'e', 'r', 'f', 'i', 'c', 'i', 'a', 'l', 'i', 't', 'y', '\n',
        's', 'u', 'p', 'e', 'r', 'f', 'i', 'c', 'i', 'a', 'l', 'l', 'y', '\n',
        's', 'u', 'p', 'e', 'r', 'f', 'i', 'x', '\n',
        's', 'u', 'p', 'e', 'r', 'f', 'l', 'u', 'i', 't', 'i', 'e', 's', '\n',
        's', 'u', 'p', 'e', 'r', 'f', 'l', 'u', 'i', 't', 'y', '\n',
        's', 'u', 'p', 'e', 'r', 'f', 'l', 'u', 'o', 'u', 's', '\n',
        's', 'u', 'p', 'e', 'r', 'f', 'l', 'u', 'o', 'u', 's', 'l', 'y', '\n',
        's', 'u', 'p', 'e', 'r', 'g', 'l', 'u', 'e', '\n',
        's', 'u', 'p', 'e', 'r', 'h', 'e', 'a', 't', '\n',
        's', 'u', 'p', 'e', 'r', 'h', 'e', 'a', 't', 'e', 'd', '\n',
        's', 'u', 'p', 'e', 'r', 'h', 'e', 'r', 'o', '\n',
        's', 'u', 'p', 'e', 'r', 'h', 'u', 'm', 'a', 'n', '\n',
        's', 'u', 'p', 'e', 'r', 'i', 'm', 'p', 'o', 's', 'e', '\n',
        's', 'u', 'p', 'e', 'r', 'i', 'm', 'p', 'o', 's', 'e', 'd', '\n',
        's', 'u', 'p', 'e', 'r', 'i', 'm', 'p', 'o', 's', 'e', 's', '\n',
        's', 'u', 'p', 'e', 'r', 'i', 'm', 'p', 'o', 's', 'i', 'n', 'g', '\n',
        's', 'u', 'p', 'e', 'r', 'i', 'm', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', '\n',
        's', 'u', 'p', 'e', 'r', 'i', 'n', 't', 'e', 'n', 'd', '\n',
        's', 'u', 'p', 'e', 'r', 'i', 'n', 't', 'e', 'n', 'd', 'e', 'n', 'c', 'e', '\n',
        's', 'u', 'p', 'e', 'r', 'i', 'n', 't', 'e', 'n', 'd', 'e', 'n', 't', '\n',
        's', 'u', 'p', 'e', 'r', 'i', 'n', 't', 'e', 'n', 'd', 'e', 'n', 't', 's', '\n',
        's', 'u', 'p', 'e', 'r', 'i', 'o', 'r', '\n',
        's', 'u', 'p', 'e', 'r', 'i', 'o', 'r', 'i', 't', 'y', '\n',
        's', 'u', 'p', 'e', 'r', 'i', 'o', 'r', 's', '\n',
        's', 'u', 'p', 'e', 'r', 'l', 'a', 't', 'i', 'v', 'e', '\n',
        's', 'u', 'p', 'e', 'r', 'l', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        's', 'u', 'p', 'e', 'r', 'l', 'a', 't', 'i', 'v', 'e', 's', '\n',
        's', 'u', 'p', 'e', 'r', 'm', 'a', 'n', '\n',
        's', 'u', 'p', 'e', 'r', 'm', 'a', 'r', 'k', 'e', 't', '\n',
        's', 'u', 'p', 'e', 'r', 'm', 'a', 'r', 'k', 'e', 't', 's', '\n',
        's', 'u', 'p', 'e', 'r', 'm', 'e', 'n', '\n',
        's', 'u', 'p', 'e', 'r', 'm', 'o', 'd', 'e', 'l', '\n',
        's', 'u', 'p', 'e', 'r', 'm', 'o', 'd', 'e', 'l', 's', '\n',
        's', 'u', 'p', 'e', 'r', 'n', 'a', 't', 'a', 'n', 't', '\n',
        's', 'u', 'p', 'e', 'r', 'n', 'a', 't', 'u', 'r', 'a', 'l', '\n',
        's', 'u', 'p', 'e', 'r', 'n', 'a', 't', 'u', 'r', 'a', 'l', 'l', 'y', '\n',
        's', 'u', 'p', 'e', 'r', 'n', 'o', 'v', 'a', '\n',
        's', 'u', 'p', 'e', 'r', 'n', 'o', 'v', 'a', 'e', '\n',
        's', 'u', 'p', 'e', 'r', 'n', 'u', 'm', 'e', 'r', 'a', 'r', 'y', '\n',
        's', 'u', 'p', 'e', 'r', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'e', '\n',
        's', 'u', 'p', 'e', 'r', 'p', 'o', 's', 'e', '\n',
        's', 'u', 'p', 'e', 'r', 'p', 'o', 's', 'e', 'd', '\n',
        's', 'u', 'p', 'e', 'r', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', '\n',
        's', 'u', 'p', 'e', 'r', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', '\n',
        's', 'u', 'p', 'e', 'r', 'p', 'o', 'w', 'e', 'r', '\n',
        's', 'u', 'p', 'e', 'r', 'p', 'o', 'w', 'e', 'r', 's', '\n',
        's', 'u', 'p', 'e', 'r', 's', 'a', 't', 'u', 'r', 'a', 't', 'e', 'd', '\n',
        's', 'u', 'p', 'e', 'r', 's', 'a', 't', 'u', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'u', 'p', 'e', 'r', 's', 'c', 'r', 'i', 'p', 't', '\n',
        's', 'u', 'p', 'e', 'r', 's', 'c', 'r', 'i', 'p', 't', 's', '\n',
        's', 'u', 'p', 'e', 'r', 's', 'e', 'd', 'e', '\n',
        's', 'u', 'p', 'e', 'r', 's', 'e', 'd', 'e', 'd', '\n',
        's', 'u', 'p', 'e', 'r', 's', 'e', 'd', 'e', 's', '\n',
        's', 'u', 'p', 'e', 'r', 's', 'e', 'd', 'i', 'n', 'g', '\n',
        's', 'u', 'p', 'e', 'r', 's', 'o', 'n', 'i', 'c', '\n',
        's', 'u', 'p', 'e', 'r', 's', 'o', 'n', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 'u', 'p', 'e', 'r', 's', 't', 'a', 'r', '\n',
        's', 'u', 'p', 'e', 'r', 's', 't', 'a', 'r', 's', '\n',
        's', 'u', 'p', 'e', 'r', 's', 't', 'a', 't', 'e', '\n',
        's', 'u', 'p', 'e', 'r', 's', 't', 'a', 't', 'e', 's', '\n',
        's', 'u', 'p', 'e', 'r', 's', 't', 'i', 't', 'i', 'o', 'n', '\n',
        's', 'u', 'p', 'e', 'r', 's', 't', 'i', 't', 'i', 'o', 'n', 's', '\n',
        's', 'u', 'p', 'e', 'r', 's', 't', 'i', 't', 'i', 'o', 'u', 's', '\n',
        's', 'u', 'p', 'e', 'r', 's', 't', 'i', 't', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        's', 'u', 'p', 'e', 'r', 's', 't', 'o', 'r', 'e', '\n',
        's', 'u', 'p', 'e', 'r', 's', 't', 'o', 'r', 'e', 's', '\n',
        's', 'u', 'p', 'e', 'r', 's', 't', 'r', 'u', 'c', 't', 'u', 'r', 'e', '\n',
        's', 'u', 'p', 'e', 'r', 's', 't', 'r', 'u', 'c', 't', 'u', 'r', 'e', 's', '\n',
        's', 'u', 'p', 'e', 'r', 't', 'a', 'n', 'k', 'e', 'r', '\n',
        's', 'u', 'p', 'e', 'r', 't', 'a', 'n', 'k', 'e', 'r', 's', '\n',
        's', 'u', 'p', 'e', 'r', 'v', 'e', 'n', 'e', '\n',
        's', 'u', 'p', 'e', 'r', 'v', 'i', 's', 'e', '\n',
        's', 'u', 'p', 'e', 'r', 'v', 'i', 's', 'e', 'd', '\n',
        's', 'u', 'p', 'e', 'r', 'v', 'i', 's', 'e', 's', '\n',
        's', 'u', 'p', 'e', 'r', 'v', 'i', 's', 'i', 'n', 'g', '\n',
        's', 'u', 'p', 'e', 'r', 'v', 'i', 's', 'i', 'o', 'n', '\n',
        's', 'u', 'p', 'e', 'r', 'v', 'i', 's', 'i', 'o', 'n', 's', '\n',
        's', 'u', 'p', 'e', 'r', 'v', 'i', 's', 'o', 'r', '\n',
        's', 'u', 'p', 'e', 'r', 'v', 'i', 's', 'o', 'r', 's', '\n',
        's', 'u', 'p', 'e', 'r', 'v', 'i', 's', 'o', 'r', 'y', '\n',
        's', 'u', 'p', 'i', 'n', 'e', '\n',
        's', 'u', 'p', 'p', 'e', 'd', '\n',
        's', 'u', 'p', 'p', 'e', 'r', '\n',
        's', 'u', 'p', 'p', 'e', 'r', 's', '\n',
        's', 'u', 'p', 'p', 'i', 'n', 'g', '\n',
        's', 'u', 'p', 'p', 'l', 'a', 'n', 't', '\n',
        's', 'u', 'p', 'p', 'l', 'a', 'n', 't', 'e', 'd', '\n',
        's', 'u', 'p', 'p', 'l', 'a', 'n', 't', 'i', 'n', 'g', '\n',
        's', 'u', 'p', 'p', 'l', 'e', '\n',
        's', 'u', 'p', 'p', 'l', 'e', 'm', 'e', 'n', 't', '\n',
        's', 'u', 'p', 'p', 'l', 'e', 'm', 'e', 'n', 't', 'a', 'l', '\n',
        's', 'u', 'p', 'p', 'l', 'e', 'm', 'e', 'n', 't', 'a', 'r', 'y', '\n',
        's', 'u', 'p', 'p', 'l', 'e', 'm', 'e', 'n', 't', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'u', 'p', 'p', 'l', 'e', 'm', 'e', 'n', 't', 'e', 'd', '\n',
        's', 'u', 'p', 'p', 'l', 'e', 'm', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        's', 'u', 'p', 'p', 'l', 'e', 'm', 'e', 'n', 't', 's', '\n',
        's', 'u', 'p', 'p', 'l', 'e', 'n', 'e', 's', 's', '\n',
        's', 'u', 'p', 'p', 'l', 'i', 'a', 'n', 't', '\n',
        's', 'u', 'p', 'p', 'l', 'i', 'a', 'n', 't', 's', '\n',
        's', 'u', 'p', 'p', 'l', 'i', 'c', 'a', 'n', 't', '\n',
        's', 'u', 'p', 'p', 'l', 'i', 'c', 'a', 'n', 't', 's', '\n',
        's', 'u', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'e', '\n',
        's', 'u', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        's', 'u', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'u', 'p', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        's', 'u', 'p', 'p', 'l', 'i', 'e', 'd', '\n',
        's', 'u', 'p', 'p', 'l', 'i', 'e', 'r', '\n',
        's', 'u', 'p', 'p', 'l', 'i', 'e', 'r', 's', '\n',
        's', 'u', 'p', 'p', 'l', 'i', 'e', 's', '\n',
        's', 'u', 'p', 'p', 'l', 'y', '\n',
        's', 'u', 'p', 'p', 'l', 'y', 'i', 'n', 'g', '\n',
        's', 'u', 'p', 'p', 'o', 'r', 't', '\n',
        's', 'u', 'p', 'p', 'o', 'r', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        's', 'u', 'p', 'p', 'o', 'r', 't', 'a', 'b', 'l', 'e', '\n',
        's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', '\n',
        's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'r', '\n',
        's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'r', 's', '\n',
        's', 'u', 'p', 'p', 'o', 'r', 't', 'i', 'n', 'g', '\n',
        's', 'u', 'p', 'p', 'o', 'r', 't', 'i', 'v', 'e', '\n',
        's', 'u', 'p', 'p', 'o', 'r', 't', 's', '\n',
        's', 'u', 'p', 'p', 'o', 's', 'e', '\n',
        's', 'u', 'p', 'p', 'o', 's', 'e', 'd', '\n',
        's', 'u', 'p', 'p', 'o', 's', 'e', 'd', 'l', 'y', '\n',
        's', 'u', 'p', 'p', 'o', 's', 'e', 's', '\n',
        's', 'u', 'p', 'p', 'o', 's', 'i', 'n', 'g', '\n',
        's', 'u', 'p', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', '\n',
        's', 'u', 'p', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', '\n',
        's', 'u', 'p', 'p', 'o', 's', 'i', 't', 'o', 'r', 'i', 'e', 's', '\n',
        's', 'u', 'p', 'p', 'r', 'e', 's', 's', '\n',
        's', 'u', 'p', 'p', 'r', 'e', 's', 's', 'e', 'd', '\n',
        's', 'u', 'p', 'p', 'r', 'e', 's', 's', 'e', 's', '\n',
        's', 'u', 'p', 'p', 'r', 'e', 's', 's', 'i', 'b', 'l', 'e', '\n',
        's', 'u', 'p', 'p', 'r', 'e', 's', 's', 'i', 'n', 'g', '\n',
        's', 'u', 'p', 'p', 'r', 'e', 's', 's', 'i', 'o', 'n', '\n',
        's', 'u', 'p', 'p', 'r', 'e', 's', 's', 'i', 'v', 'e', '\n',
        's', 'u', 'p', 'p', 'r', 'e', 's', 's', 'o', 'r', '\n',
        's', 'u', 'p', 'p', 'r', 'e', 's', 's', 'o', 'r', 's', '\n',
        's', 'u', 'p', 'p', 'u', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        's', 'u', 'p', 'r', 'a', 'n', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        's', 'u', 'p', 'r', 'a', 'n', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 'm', '\n',
        's', 'u', 'p', 'r', 'e', 'm', 'a', 'c', 'i', 's', 't', '\n',
        's', 'u', 'p', 'r', 'e', 'm', 'a', 'c', 'y', '\n',
        's', 'u', 'p', 'r', 'e', 'm', 'a', 'l', '\n',
        's', 'u', 'p', 'r', 'e', 'm', 'e', '\n',
        's', 'u', 'p', 'r', 'e', 'm', 'e', 'l', 'y', '\n',
        's', 'u', 'p', 'r', 'e', 'm', 'o', '\n',
        's', 'u', 'p', 's', '\n',
        's', 'u', 'r', 'c', 'h', 'a', 'r', 'g', 'e', '\n',
        's', 'u', 'r', 'c', 'h', 'a', 'r', 'g', 'e', 'd', '\n',
        's', 'u', 'r', 'c', 'h', 'a', 'r', 'g', 'e', 's', '\n',
        's', 'u', 'r', 'd', '\n',
        's', 'u', 'r', 'e', '\n',
        's', 'u', 'r', 'e', 'f', 'o', 'o', 't', 'e', 'd', '\n',
        's', 'u', 'r', 'e', 'l', 'y', '\n',
        's', 'u', 'r', 'e', 'n', 'e', 's', 's', '\n',
        's', 'u', 'r', 'e', 'r', '\n',
        's', 'u', 'r', 'e', 's', 't', '\n',
        's', 'u', 'r', 'e', 't', 'i', 'e', 's', '\n',
        's', 'u', 'r', 'e', 't', 'y', '\n',
        's', 'u', 'r', 'f', '\n',
        's', 'u', 'r', 'f', 'a', 'c', 'e', '\n',
        's', 'u', 'r', 'f', 'a', 'c', 'e', 'd', '\n',
        's', 'u', 'r', 'f', 'a', 'c', 'e', 'r', '\n',
        's', 'u', 'r', 'f', 'a', 'c', 'e', 's', '\n',
        's', 'u', 'r', 'f', 'a', 'c', 'i', 'n', 'g', '\n',
        's', 'u', 'r', 'f', 'a', 'c', 't', 'a', 'n', 't', '\n',
        's', 'u', 'r', 'f', 'a', 'c', 't', 'a', 'n', 't', 's', '\n',
        's', 'u', 'r', 'f', 'b', 'o', 'a', 'r', 'd', '\n',
        's', 'u', 'r', 'f', 'e', 'd', '\n',
        's', 'u', 'r', 'f', 'e', 'i', 't', '\n',
        's', 'u', 'r', 'f', 'e', 'r', '\n',
        's', 'u', 'r', 'f', 'e', 'r', 's', '\n',
        's', 'u', 'r', 'f', 'i', 'n', 'g', '\n',
        's', 'u', 'r', 'f', 'i', 'n', 'g', 's', '\n',
        's', 'u', 'r', 'f', 's', '\n',
        's', 'u', 'r', 'g', 'e', '\n',
        's', 'u', 'r', 'g', 'e', 'd', '\n',
        's', 'u', 'r', 'g', 'e', 'o', 'n', '\n',
        's', 'u', 'r', 'g', 'e', 'o', 'n', 's', '\n',
        's', 'u', 'r', 'g', 'e', 'r', 'i', 'e', 's', '\n',
        's', 'u', 'r', 'g', 'e', 'r', 'y', '\n',
        's', 'u', 'r', 'g', 'e', 's', '\n',
        's', 'u', 'r', 'g', 'i', 'c', 'a', 'l', '\n',
        's', 'u', 'r', 'g', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 'u', 'r', 'g', 'i', 'n', 'g', '\n',
        's', 'u', 'r', 'l', 'i', 'e', 's', 't', '\n',
        's', 'u', 'r', 'l', 'i', 'l', 'y', '\n',
        's', 'u', 'r', 'l', 'i', 'n', 'e', 's', 's', '\n',
        's', 'u', 'r', 'l', 'y', '\n',
        's', 'u', 'r', 'm', 'i', 's', 'e', '\n',
        's', 'u', 'r', 'm', 'i', 's', 'e', 'd', '\n',
        's', 'u', 'r', 'm', 'i', 's', 'e', 's', '\n',
        's', 'u', 'r', 'm', 'i', 's', 'i', 'n', 'g', '\n',
        's', 'u', 'r', 'm', 'o', 'u', 'n', 't', '\n',
        's', 'u', 'r', 'm', 'o', 'u', 'n', 't', 'a', 'b', 'l', 'e', '\n',
        's', 'u', 'r', 'm', 'o', 'u', 'n', 't', 'e', 'd', '\n',
        's', 'u', 'r', 'm', 'o', 'u', 'n', 't', 'i', 'n', 'g', '\n',
        's', 'u', 'r', 'n', 'a', 'm', 'e', '\n',
        's', 'u', 'r', 'n', 'a', 'm', 'e', 's', '\n',
        's', 'u', 'r', 'p', 'a', 's', 's', '\n',
        's', 'u', 'r', 'p', 'a', 's', 's', 'e', 'd', '\n',
        's', 'u', 'r', 'p', 'a', 's', 's', 'e', 's', '\n',
        's', 'u', 'r', 'p', 'a', 's', 's', 'i', 'n', 'g', '\n',
        's', 'u', 'r', 'p', 'l', 'i', 'c', 'e', '\n',
        's', 'u', 'r', 'p', 'l', 'u', 's', '\n',
        's', 'u', 'r', 'p', 'l', 'u', 's', 'e', 's', '\n',
        's', 'u', 'r', 'p', 'r', 'i', 's', 'e', '\n',
        's', 'u', 'r', 'p', 'r', 'i', 's', 'e', 'd', '\n',
        's', 'u', 'r', 'p', 'r', 'i', 's', 'e', 's', '\n',
        's', 'u', 'r', 'p', 'r', 'i', 's', 'i', 'n', 'g', '\n',
        's', 'u', 'r', 'p', 'r', 'i', 's', 'i', 'n', 'g', 'l', 'y', '\n',
        's', 'u', 'r', 'r', 'e', 'a', 'l', '\n',
        's', 'u', 'r', 'r', 'e', 'a', 'l', 'i', 's', 'm', '\n',
        's', 'u', 'r', 'r', 'e', 'a', 'l', 'i', 's', 't', '\n',
        's', 'u', 'r', 'r', 'e', 'a', 'l', 'i', 's', 't', 'i', 'c', '\n',
        's', 'u', 'r', 'r', 'e', 'a', 'l', 'i', 's', 't', 's', '\n',
        's', 'u', 'r', 'r', 'e', 'a', 'l', 'i', 't', 'y', '\n',
        's', 'u', 'r', 'r', 'e', 'n', 'd', 'e', 'r', '\n',
        's', 'u', 'r', 'r', 'e', 'n', 'd', 'e', 'r', 'e', 'd', '\n',
        's', 'u', 'r', 'r', 'e', 'n', 'd', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'u', 'r', 'r', 'e', 'n', 'd', 'e', 'r', 's', '\n',
        's', 'u', 'r', 'r', 'e', 'p', 't', 'i', 't', 'i', 'o', 'u', 's', '\n',
        's', 'u', 'r', 'r', 'e', 'p', 't', 'i', 't', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        's', 'u', 'r', 'r', 'e', 'y', '\n',
        's', 'u', 'r', 'r', 'e', 'y', 's', '\n',
        's', 'u', 'r', 'r', 'o', 'g', 'a', 'c', 'y', '\n',
        's', 'u', 'r', 'r', 'o', 'g', 'a', 't', 'e', '\n',
        's', 'u', 'r', 'r', 'o', 'g', 'a', 't', 'e', 's', '\n',
        's', 'u', 'r', 'r', 'o', 'u', 'n', 'd', '\n',
        's', 'u', 'r', 'r', 'o', 'u', 'n', 'd', 'e', 'd', '\n',
        's', 'u', 'r', 'r', 'o', 'u', 'n', 'd', 'i', 'n', 'g', '\n',
        's', 'u', 'r', 'r', 'o', 'u', 'n', 'd', 'i', 'n', 'g', 's', '\n',
        's', 'u', 'r', 'r', 'o', 'u', 'n', 'd', 's', '\n',
        's', 'u', 'r', 't', 'a', 'x', '\n',
        's', 'u', 'r', 't', 'i', 't', 'l', 'e', 's', '\n',
        's', 'u', 'r', 'v', 'e', 'i', 'l', 'l', 'a', 'n', 'c', 'e', '\n',
        's', 'u', 'r', 'v', 'e', 'y', '\n',
        's', 'u', 'r', 'v', 'e', 'y', 'e', 'd', '\n',
        's', 'u', 'r', 'v', 'e', 'y', 'i', 'n', 'g', '\n',
        's', 'u', 'r', 'v', 'e', 'y', 'o', 'r', '\n',
        's', 'u', 'r', 'v', 'e', 'y', 'o', 'r', 's', '\n',
        's', 'u', 'r', 'v', 'e', 'y', 's', '\n',
        's', 'u', 'r', 'v', 'i', 'v', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        's', 'u', 'r', 'v', 'i', 'v', 'a', 'b', 'l', 'e', '\n',
        's', 'u', 'r', 'v', 'i', 'v', 'a', 'l', '\n',
        's', 'u', 'r', 'v', 'i', 'v', 'a', 'l', 's', '\n',
        's', 'u', 'r', 'v', 'i', 'v', 'e', '\n',
        's', 'u', 'r', 'v', 'i', 'v', 'e', 'd', '\n',
        's', 'u', 'r', 'v', 'i', 'v', 'e', 's', '\n',
        's', 'u', 'r', 'v', 'i', 'v', 'i', 'n', 'g', '\n',
        's', 'u', 'r', 'v', 'i', 'v', 'o', 'r', '\n',
        's', 'u', 'r', 'v', 'i', 'v', 'o', 'r', 's', '\n',
        's', 'u', 's', 'c', 'e', 'p', 't', 'i', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', '\n',
        's', 'u', 's', 'c', 'e', 'p', 't', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        's', 'u', 's', 'c', 'e', 'p', 't', 'i', 'b', 'l', 'e', '\n',
        's', 'u', 's', 'h', 'i', '\n',
        's', 'u', 's', 'h', 'i', 's', '\n',
        's', 'u', 's', 'p', 'e', 'c', 't', '\n',
        's', 'u', 's', 'p', 'e', 'c', 't', 'e', 'd', '\n',
        's', 'u', 's', 'p', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        's', 'u', 's', 'p', 'e', 'c', 't', 's', '\n',
        's', 'u', 's', 'p', 'e', 'n', 'd', '\n',
        's', 'u', 's', 'p', 'e', 'n', 'd', 'e', 'd', '\n',
        's', 'u', 's', 'p', 'e', 'n', 'd', 'e', 'r', '\n',
        's', 'u', 's', 'p', 'e', 'n', 'd', 'e', 'r', 's', '\n',
        's', 'u', 's', 'p', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        's', 'u', 's', 'p', 'e', 'n', 'd', 's', '\n',
        's', 'u', 's', 'p', 'e', 'n', 's', 'e', '\n',
        's', 'u', 's', 'p', 'e', 'n', 's', 'i', 'o', 'n', '\n',
        's', 'u', 's', 'p', 'e', 'n', 's', 'i', 'o', 'n', 's', '\n',
        's', 'u', 's', 'p', 'i', 'c', 'i', 'o', 'n', '\n',
        's', 'u', 's', 'p', 'i', 'c', 'i', 'o', 'n', 's', '\n',
        's', 'u', 's', 'p', 'i', 'c', 'i', 'o', 'u', 's', '\n',
        's', 'u', 's', 'p', 'i', 'c', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        's', 'u', 's', 't', 'a', 'i', 'n', '\n',
        's', 'u', 's', 't', 'a', 'i', 'n', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        's', 'u', 's', 't', 'a', 'i', 'n', 'a', 'b', 'l', 'e', '\n',
        's', 'u', 's', 't', 'a', 'i', 'n', 'a', 'b', 'l', 'y', '\n',
        's', 'u', 's', 't', 'a', 'i', 'n', 'e', 'd', '\n',
        's', 'u', 's', 't', 'a', 'i', 'n', 'i', 'n', 'g', '\n',
        's', 'u', 's', 't', 'a', 'i', 'n', 's', '\n',
        's', 'u', 's', 't', 'e', 'n', 'a', 'n', 'c', 'e', '\n',
        's', 'u', 't', 'u', 'r', 'e', '\n',
        's', 'u', 't', 'u', 'r', 'e', 's', '\n',
        's', 'u', 'z', 'e', 'r', 'a', 'i', 'n', 't', 'y', '\n',
        's', 'w', 'a', 'b', '\n',
        's', 'w', 'a', 'b', 'b', 'e', 'd', '\n',
        's', 'w', 'a', 'b', 'b', 'i', 'n', 'g', '\n',
        's', 'w', 'a', 'b', 's', '\n',
        's', 'w', 'a', 'd', '\n',
        's', 'w', 'a', 'd', 'd', 'l', 'e', 'd', '\n',
        's', 'w', 'a', 'd', 'd', 'l', 'i', 'n', 'g', '\n',
        's', 'w', 'a', 'd', 's', '\n',
        's', 'w', 'a', 'g', '\n',
        's', 'w', 'a', 'g', 'g', 'e', 'r', '\n',
        's', 'w', 'a', 'g', 'g', 'e', 'r', 'e', 'd', '\n',
        's', 'w', 'a', 'g', 'g', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'w', 'a', 'g', 's', '\n',
        's', 'w', 'a', 'h', 'i', 'l', 'i', '\n',
        's', 'w', 'a', 'i', 'n', 's', '\n',
        's', 'w', 'a', 'l', 'l', 'o', 'w', '\n',
        's', 'w', 'a', 'l', 'l', 'o', 'w', 'e', 'd', '\n',
        's', 'w', 'a', 'l', 'l', 'o', 'w', 'e', 'r', '\n',
        's', 'w', 'a', 'l', 'l', 'o', 'w', 'i', 'n', 'g', '\n',
        's', 'w', 'a', 'l', 'l', 'o', 'w', 's', '\n',
        's', 'w', 'a', 'l', 'l', 'o', 'w', 't', 'a', 'i', 'l', '\n',
        's', 'w', 'a', 'm', '\n',
        's', 'w', 'a', 'm', 'p', '\n',
        's', 'w', 'a', 'm', 'p', 'e', 'd', '\n',
        's', 'w', 'a', 'm', 'p', 'i', 'e', 'r', '\n',
        's', 'w', 'a', 'm', 'p', 'i', 'e', 's', 't', '\n',
        's', 'w', 'a', 'm', 'p', 'i', 'n', 'g', '\n',
        's', 'w', 'a', 'm', 'p', 'l', 'a', 'n', 'd', '\n',
        's', 'w', 'a', 'm', 'p', 'l', 'a', 'n', 'd', 's', '\n',
        's', 'w', 'a', 'm', 'p', 's', '\n',
        's', 'w', 'a', 'm', 'p', 'y', '\n',
        's', 'w', 'a', 'n', '\n',
        's', 'w', 'a', 'n', 's', '\n',
        's', 'w', 'a', 'n', 's', 'o', 'n', 'g', '\n',
        's', 'w', 'a', 'p', '\n',
        's', 'w', 'a', 'p', 'p', 'a', 'b', 'l', 'e', '\n',
        's', 'w', 'a', 'p', 'p', 'e', 'd', '\n',
        's', 'w', 'a', 'p', 'p', 'e', 'r', '\n',
        's', 'w', 'a', 'p', 'p', 'e', 'r', 's', '\n',
        's', 'w', 'a', 'p', 'p', 'i', 'n', 'g', '\n',
        's', 'w', 'a', 'p', 's', '\n',
        's', 'w', 'a', 'r', 'd', '\n',
        's', 'w', 'a', 'r', 'm', '\n',
        's', 'w', 'a', 'r', 'm', 'e', 'd', '\n',
        's', 'w', 'a', 'r', 'm', 'i', 'n', 'g', '\n',
        's', 'w', 'a', 'r', 'm', 's', '\n',
        's', 'w', 'a', 'r', 't', 'h', 'i', 'e', 'r', '\n',
        's', 'w', 'a', 'r', 't', 'h', 'i', 'e', 's', 't', '\n',
        's', 'w', 'a', 'r', 't', 'h', 'y', '\n',
        's', 'w', 'a', 's', 'h', 'b', 'u', 'c', 'k', 'l', 'i', 'n', 'g', '\n',
        's', 'w', 'a', 's', 't', 'i', 'k', 'a', '\n',
        's', 'w', 'a', 's', 't', 'i', 'k', 'a', 's', '\n',
        's', 'w', 'a', 't', '\n',
        's', 'w', 'a', 't', 'h', 'e', '\n',
        's', 'w', 'a', 't', 'h', 'e', 'd', '\n',
        's', 'w', 'a', 't', 'h', 'e', 's', '\n',
        's', 'w', 'a', 't', 's', '\n',
        's', 'w', 'a', 't', 't', 'e', 'd', '\n',
        's', 'w', 'a', 't', 't', 'i', 'n', 'g', '\n',
        's', 'w', 'a', 'y', '\n',
        's', 'w', 'a', 'y', 'e', 'd', '\n',
        's', 'w', 'a', 'y', 'i', 'n', 'g', '\n',
        's', 'w', 'a', 'y', 's', '\n',
        's', 'w', 'a', 'z', 'i', '\n',
        's', 'w', 'a', 'z', 'i', 's', '\n',
        's', 'w', 'e', 'a', 'r', '\n',
        's', 'w', 'e', 'a', 'r', 'e', 'r', '\n',
        's', 'w', 'e', 'a', 'r', 'e', 'r', 's', '\n',
        's', 'w', 'e', 'a', 'r', 'i', 'n', 'g', '\n',
        's', 'w', 'e', 'a', 'r', 's', '\n',
        's', 'w', 'e', 'a', 'r', 'w', 'o', 'r', 'd', '\n',
        's', 'w', 'e', 'a', 'r', 'w', 'o', 'r', 'd', 's', '\n',
        's', 'w', 'e', 'a', 't', '\n',
        's', 'w', 'e', 'a', 't', 'b', 'a', 'n', 'd', '\n',
        's', 'w', 'e', 'a', 't', 'e', 'd', '\n',
        's', 'w', 'e', 'a', 't', 'e', 'r', '\n',
        's', 'w', 'e', 'a', 't', 'e', 'r', 's', '\n',
        's', 'w', 'e', 'a', 't', 'i', 'e', 'r', '\n',
        's', 'w', 'e', 'a', 't', 'i', 'e', 's', 't', '\n',
        's', 'w', 'e', 'a', 't', 'i', 'l', 'y', '\n',
        's', 'w', 'e', 'a', 't', 'i', 'n', 'g', '\n',
        's', 'w', 'e', 'a', 't', 's', '\n',
        's', 'w', 'e', 'a', 't', 's', 'h', 'i', 'r', 't', '\n',
        's', 'w', 'e', 'a', 't', 's', 'h', 'i', 'r', 't', 's', '\n',
        's', 'w', 'e', 'a', 't', 's', 'h', 'o', 'p', '\n',
        's', 'w', 'e', 'a', 't', 's', 'h', 'o', 'p', 's', '\n',
        's', 'w', 'e', 'a', 't', 'y', '\n',
        's', 'w', 'e', 'd', 'e', '\n',
        's', 'w', 'e', 'd', 'e', 'n', '\n',
        's', 'w', 'e', 'd', 'i', 's', 'h', '\n',
        's', 'w', 'e', 'e', 'p', '\n',
        's', 'w', 'e', 'e', 'p', 'a', 'b', 'l', 'e', '\n',
        's', 'w', 'e', 'e', 'p', 'e', 'r', '\n',
        's', 'w', 'e', 'e', 'p', 'e', 'r', 's', '\n',
        's', 'w', 'e', 'e', 'p', 'i', 'n', 'g', '\n',
        's', 'w', 'e', 'e', 'p', 'i', 'n', 'g', 'l', 'y', '\n',
        's', 'w', 'e', 'e', 'p', 'i', 'n', 'g', 's', '\n',
        's', 'w', 'e', 'e', 'p', 's', '\n',
        's', 'w', 'e', 'e', 'p', 's', 't', 'a', 'k', 'e', '\n',
        's', 'w', 'e', 'e', 't', '\n',
        's', 'w', 'e', 'e', 't', 'b', 'r', 'e', 'a', 'd', '\n',
        's', 'w', 'e', 'e', 't', 'c', 'o', 'r', 'n', '\n',
        's', 'w', 'e', 'e', 't', 'e', 'n', '\n',
        's', 'w', 'e', 'e', 't', 'e', 'n', 'e', 'd', '\n',
        's', 'w', 'e', 'e', 't', 'e', 'n', 'e', 'r', '\n',
        's', 'w', 'e', 'e', 't', 'e', 'n', 'e', 'r', 's', '\n',
        's', 'w', 'e', 'e', 't', 'e', 'n', 'i', 'n', 'g', '\n',
        's', 'w', 'e', 'e', 't', 'e', 'n', 's', '\n',
        's', 'w', 'e', 'e', 't', 'e', 'r', '\n',
        's', 'w', 'e', 'e', 't', 'e', 's', 't', '\n',
        's', 'w', 'e', 'e', 't', 'h', 'e', 'a', 'r', 't', '\n',
        's', 'w', 'e', 'e', 't', 'h', 'e', 'a', 'r', 't', 's', '\n',
        's', 'w', 'e', 'e', 't', 'i', 'e', '\n',
        's', 'w', 'e', 'e', 't', 'i', 's', 'h', '\n',
        's', 'w', 'e', 'e', 't', 'l', 'y', '\n',
        's', 'w', 'e', 'e', 't', 'm', 'e', 'a', 't', '\n',
        's', 'w', 'e', 'e', 't', 'm', 'e', 'a', 't', 's', '\n',
        's', 'w', 'e', 'e', 't', 'n', 'e', 's', 's', '\n',
        's', 'w', 'e', 'e', 't', 'p', 'e', 'a', '\n',
        's', 'w', 'e', 'e', 't', 's', '\n',
        's', 'w', 'e', 'e', 't', 's', 'h', 'o', 'p', '\n',
        's', 'w', 'e', 'l', 'l', '\n',
        's', 'w', 'e', 'l', 'l', 'e', 'd', '\n',
        's', 'w', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        's', 'w', 'e', 'l', 'l', 'i', 'n', 'g', 's', '\n',
        's', 'w', 'e', 'l', 'l', 's', '\n',
        's', 'w', 'e', 'l', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        's', 'w', 'e', 'l', 't', 'r', 'y', '\n',
        's', 'w', 'e', 'p', 't', '\n',
        's', 'w', 'e', 'r', 'v', 'e', '\n',
        's', 'w', 'e', 'r', 'v', 'e', 'd', '\n',
        's', 'w', 'e', 'r', 'v', 'e', 's', '\n',
        's', 'w', 'e', 'r', 'v', 'i', 'n', 'g', '\n',
        's', 'w', 'i', 'f', 't', '\n',
        's', 'w', 'i', 'f', 't', 'e', 'r', '\n',
        's', 'w', 'i', 'f', 't', 'e', 's', 't', '\n',
        's', 'w', 'i', 'f', 't', 'l', 'e', 't', '\n',
        's', 'w', 'i', 'f', 't', 'l', 'y', '\n',
        's', 'w', 'i', 'f', 't', 'n', 'e', 's', 's', '\n',
        's', 'w', 'i', 'f', 't', 's', '\n',
        's', 'w', 'i', 'l', 'l', '\n',
        's', 'w', 'i', 'l', 'l', 'e', 'd', '\n',
        's', 'w', 'i', 'l', 'l', 'i', 'n', 'g', '\n',
        's', 'w', 'i', 'm', '\n',
        's', 'w', 'i', 'm', 'm', 'e', 'r', '\n',
        's', 'w', 'i', 'm', 'm', 'e', 'r', 's', '\n',
        's', 'w', 'i', 'm', 'm', 'i', 'n', 'g', '\n',
        's', 'w', 'i', 'm', 'm', 'i', 'n', 'g', 'l', 'y', '\n',
        's', 'w', 'i', 'm', 's', '\n',
        's', 'w', 'i', 'm', 's', 'u', 'i', 't', '\n',
        's', 'w', 'i', 'm', 's', 'u', 'i', 't', 's', '\n',
        's', 'w', 'i', 'm', 'w', 'e', 'a', 'r', '\n',
        's', 'w', 'i', 'n', 'd', 'l', 'e', '\n',
        's', 'w', 'i', 'n', 'd', 'l', 'e', 'd', '\n',
        's', 'w', 'i', 'n', 'd', 'l', 'e', 'r', '\n',
        's', 'w', 'i', 'n', 'd', 'l', 'e', 'r', 's', '\n',
        's', 'w', 'i', 'n', 'd', 'l', 'e', 's', '\n',
        's', 'w', 'i', 'n', 'd', 'l', 'i', 'n', 'g', '\n',
        's', 'w', 'i', 'n', 'e', '\n',
        's', 'w', 'i', 'n', 'e', 's', '\n',
        's', 'w', 'i', 'n', 'g', '\n',
        's', 'w', 'i', 'n', 'g', 'e', 'i', 'n', 'g', '\n',
        's', 'w', 'i', 'n', 'g', 'e', 'r', '\n',
        's', 'w', 'i', 'n', 'g', 'e', 'r', 's', '\n',
        's', 'w', 'i', 'n', 'g', 'i', 'n', 'g', '\n',
        's', 'w', 'i', 'n', 'g', 's', '\n',
        's', 'w', 'i', 'n', 'g', 'y', '\n',
        's', 'w', 'i', 'p', 'e', '\n',
        's', 'w', 'i', 'p', 'e', 'd', '\n',
        's', 'w', 'i', 'p', 'e', 's', '\n',
        's', 'w', 'i', 'r', 'l', '\n',
        's', 'w', 'i', 'r', 'l', 'e', 'd', '\n',
        's', 'w', 'i', 'r', 'l', 'i', 'n', 'g', '\n',
        's', 'w', 'i', 'r', 'l', 's', '\n',
        's', 'w', 'i', 's', 'h', '\n',
        's', 'w', 'i', 's', 'h', 'e', 'd', '\n',
        's', 'w', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        's', 'w', 'i', 's', 'h', 'y', '\n',
        's', 'w', 'i', 's', 's', '\n',
        's', 'w', 'i', 't', 'c', 'h', '\n',
        's', 'w', 'i', 't', 'c', 'h', 'a', 'b', 'l', 'e', '\n',
        's', 'w', 'i', 't', 'c', 'h', 'b', 'a', 'c', 'k', '\n',
        's', 'w', 'i', 't', 'c', 'h', 'b', 'o', 'a', 'r', 'd', '\n',
        's', 'w', 'i', 't', 'c', 'h', 'b', 'o', 'a', 'r', 'd', 's', '\n',
        's', 'w', 'i', 't', 'c', 'h', 'e', 'd', '\n',
        's', 'w', 'i', 't', 'c', 'h', 'e', 'r', '\n',
        's', 'w', 'i', 't', 'c', 'h', 'e', 's', '\n',
        's', 'w', 'i', 't', 'c', 'h', 'g', 'e', 'a', 'r', '\n',
        's', 'w', 'i', 't', 'c', 'h', 'i', 'n', 'g', '\n',
        's', 'w', 'i', 'v', 'e', 'l', '\n',
        's', 'w', 'i', 'v', 'e', 'l', 'l', 'e', 'd', '\n',
        's', 'w', 'i', 'v', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        's', 'w', 'i', 'v', 'e', 'l', 's', '\n',
        's', 'w', 'o', 'l', 'l', 'e', 'n', '\n',
        's', 'w', 'o', 'o', 'n', '\n',
        's', 'w', 'o', 'o', 'n', 'e', 'd', '\n',
        's', 'w', 'o', 'o', 'n', 'i', 'n', 'g', '\n',
        's', 'w', 'o', 'o', 'n', 's', '\n',
        's', 'w', 'o', 'o', 'p', '\n',
        's', 'w', 'o', 'o', 'p', 'e', 'd', '\n',
        's', 'w', 'o', 'o', 'p', 'i', 'n', 'g', '\n',
        's', 'w', 'o', 'o', 'p', 's', '\n',
        's', 'w', 'o', 'p', '\n',
        's', 'w', 'o', 'p', 'p', 'e', 'd', '\n',
        's', 'w', 'o', 'p', 'p', 'i', 'n', 'g', '\n',
        's', 'w', 'o', 'p', 's', '\n',
        's', 'w', 'o', 'r', 'd', '\n',
        's', 'w', 'o', 'r', 'd', 'f', 'i', 's', 'h', '\n',
        's', 'w', 'o', 'r', 'd', 's', '\n',
        's', 'w', 'o', 'r', 'd', 's', 'm', 'a', 'n', '\n',
        's', 'w', 'o', 'r', 'd', 's', 'm', 'e', 'n', '\n',
        's', 'w', 'o', 'r', 'e', '\n',
        's', 'w', 'o', 'r', 'n', '\n',
        's', 'w', 'o', 't', '\n',
        's', 'w', 'o', 't', 's', '\n',
        's', 'w', 'o', 't', 't', 'e', 'd', '\n',
        's', 'w', 'o', 't', 't', 'i', 'n', 'g', '\n',
        's', 'w', 'u', 'm', '\n',
        's', 'w', 'u', 'n', 'g', '\n',
        's', 'y', 'c', 'a', 'm', 'o', 'r', 'e', '\n',
        's', 'y', 'c', 'a', 'm', 'o', 'r', 'e', 's', '\n',
        's', 'y', 'c', 'o', 'p', 'h', 'a', 'n', 'c', 'y', '\n',
        's', 'y', 'c', 'o', 'p', 'h', 'a', 'n', 't', '\n',
        's', 'y', 'c', 'o', 'p', 'h', 'a', 'n', 't', 'i', 'c', '\n',
        's', 'y', 'c', 'o', 'p', 'h', 'a', 'n', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 'y', 'c', 'o', 'p', 'h', 'a', 'n', 't', 's', '\n',
        's', 'y', 'd', 'n', 'e', 'y', '\n',
        's', 'y', 'l', 'l', 'a', 'b', 'a', 'r', 'y', '\n',
        's', 'y', 'l', 'l', 'a', 'b', 'i', '\n',
        's', 'y', 'l', 'l', 'a', 'b', 'i', 'c', '\n',
        's', 'y', 'l', 'l', 'a', 'b', 'l', 'e', '\n',
        's', 'y', 'l', 'l', 'a', 'b', 'l', 'e', 's', '\n',
        's', 'y', 'l', 'l', 'a', 'b', 'u', 'b', '\n',
        's', 'y', 'l', 'l', 'a', 'b', 'u', 's', '\n',
        's', 'y', 'l', 'l', 'a', 'b', 'u', 's', 'e', 's', '\n',
        's', 'y', 'l', 'l', 'o', 'g', 'i', 's', 'm', '\n',
        's', 'y', 'l', 'l', 'o', 'g', 'i', 's', 'm', 's', '\n',
        's', 'y', 'l', 'l', 'o', 'g', 'i', 's', 't', 'i', 'c', '\n',
        's', 'y', 'l', 'p', 'h', '\n',
        's', 'y', 'l', 'p', 'h', 's', '\n',
        's', 'y', 'm', 'b', 'i', 'o', 'n', 't', '\n',
        's', 'y', 'm', 'b', 'i', 'o', 's', 'i', 's', '\n',
        's', 'y', 'm', 'b', 'i', 'o', 't', 'i', 'c', '\n',
        's', 'y', 'm', 'b', 'i', 'o', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 'y', 'm', 'b', 'o', 'l', '\n',
        's', 'y', 'm', 'b', 'o', 'l', 'i', 'c', '\n',
        's', 'y', 'm', 'b', 'o', 'l', 'i', 'c', 'a', 'l', '\n',
        's', 'y', 'm', 'b', 'o', 'l', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 'y', 'm', 'b', 'o', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'y', 'm', 'b', 'o', 'l', 'i', 's', 'e', '\n',
        's', 'y', 'm', 'b', 'o', 'l', 'i', 's', 'e', 'd', '\n',
        's', 'y', 'm', 'b', 'o', 'l', 'i', 's', 'e', 's', '\n',
        's', 'y', 'm', 'b', 'o', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        's', 'y', 'm', 'b', 'o', 'l', 'i', 's', 'm', '\n',
        's', 'y', 'm', 'b', 'o', 'l', 'i', 's', 't', '\n',
        's', 'y', 'm', 'b', 'o', 'l', 'i', 's', 't', 's', '\n',
        's', 'y', 'm', 'b', 'o', 'l', 's', '\n',
        's', 'y', 'm', 'm', 'e', 't', 'r', 'i', 'c', '\n',
        's', 'y', 'm', 'm', 'e', 't', 'r', 'i', 'c', 'a', 'l', '\n',
        's', 'y', 'm', 'm', 'e', 't', 'r', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 'y', 'm', 'm', 'e', 't', 'r', 'i', 'e', 's', '\n',
        's', 'y', 'm', 'm', 'e', 't', 'r', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'y', 'm', 'm', 'e', 't', 'r', 'i', 's', 'i', 'n', 'g', '\n',
        's', 'y', 'm', 'm', 'e', 't', 'r', 'y', '\n',
        's', 'y', 'm', 'p', 'a', 't', 'h', 'e', 't', 'i', 'c', '\n',
        's', 'y', 'm', 'p', 'a', 't', 'h', 'e', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 'y', 'm', 'p', 'a', 't', 'h', 'i', 'e', 's', '\n',
        's', 'y', 'm', 'p', 'a', 't', 'h', 'i', 's', 'e', '\n',
        's', 'y', 'm', 'p', 'a', 't', 'h', 'i', 's', 'e', 'd', '\n',
        's', 'y', 'm', 'p', 'a', 't', 'h', 'i', 's', 'e', 'r', '\n',
        's', 'y', 'm', 'p', 'a', 't', 'h', 'i', 's', 'e', 'r', 's', '\n',
        's', 'y', 'm', 'p', 'a', 't', 'h', 'i', 's', 'e', 's', '\n',
        's', 'y', 'm', 'p', 'a', 't', 'h', 'i', 's', 'i', 'n', 'g', '\n',
        's', 'y', 'm', 'p', 'a', 't', 'h', 'y', '\n',
        's', 'y', 'm', 'p', 'h', 'o', 'n', 'i', 'c', '\n',
        's', 'y', 'm', 'p', 'h', 'o', 'n', 'i', 'e', 's', '\n',
        's', 'y', 'm', 'p', 'h', 'o', 'n', 'i', 's', 't', 's', '\n',
        's', 'y', 'm', 'p', 'h', 'o', 'n', 'y', '\n',
        's', 'y', 'm', 'p', 'o', 's', 'i', 'a', '\n',
        's', 'y', 'm', 'p', 'o', 's', 'i', 'u', 'm', '\n',
        's', 'y', 'm', 'p', 't', 'o', 'm', '\n',
        's', 'y', 'm', 'p', 't', 'o', 'm', 'a', 't', 'i', 'c', '\n',
        's', 'y', 'm', 'p', 't', 'o', 'm', 'a', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 'y', 'm', 'p', 't', 'o', 'm', 'l', 'e', 's', 's', '\n',
        's', 'y', 'm', 'p', 't', 'o', 'm', 's', '\n',
        's', 'y', 'n', 'a', 'g', 'o', 'g', 'u', 'e', '\n',
        's', 'y', 'n', 'a', 'g', 'o', 'g', 'u', 'e', 's', '\n',
        's', 'y', 'n', 'a', 'p', 's', 'e', '\n',
        's', 'y', 'n', 'a', 'p', 's', 'e', 's', '\n',
        's', 'y', 'n', 'a', 'p', 't', 'i', 'c', '\n',
        's', 'y', 'n', 'c', '\n',
        's', 'y', 'n', 'c', 'h', 'r', 'o', 'n', 'i', 'c', '\n',
        's', 'y', 'n', 'c', 'h', 'r', 'o', 'n', 'i', 'c', 'i', 't', 'y', '\n',
        's', 'y', 'n', 'c', 'h', 'r', 'o', 'n', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'y', 'n', 'c', 'h', 'r', 'o', 'n', 'i', 's', 'e', '\n',
        's', 'y', 'n', 'c', 'h', 'r', 'o', 'n', 'i', 's', 'e', 'd', '\n',
        's', 'y', 'n', 'c', 'h', 'r', 'o', 'n', 'i', 's', 'e', 's', '\n',
        's', 'y', 'n', 'c', 'h', 'r', 'o', 'n', 'i', 's', 'i', 'n', 'g', '\n',
        's', 'y', 'n', 'c', 'h', 'r', 'o', 'n', 'o', 'u', 's', '\n',
        's', 'y', 'n', 'c', 'h', 'r', 'o', 'n', 'o', 'u', 's', 'l', 'y', '\n',
        's', 'y', 'n', 'c', 'h', 'r', 'o', 'n', 'y', '\n',
        's', 'y', 'n', 'c', 'h', 'r', 'o', 't', 'r', 'o', 'n', '\n',
        's', 'y', 'n', 'c', 'o', 'p', 'a', 't', 'e', 'd', '\n',
        's', 'y', 'n', 'c', 'o', 'p', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'y', 'n', 'c', 'r', 'e', 't', 'i', 'c', '\n',
        's', 'y', 'n', 'd', 'i', 'c', 'a', 'l', 'i', 's', 'm', '\n',
        's', 'y', 'n', 'd', 'i', 'c', 'a', 'l', 'i', 's', 't', '\n',
        's', 'y', 'n', 'd', 'i', 'c', 'a', 't', 'e', '\n',
        's', 'y', 'n', 'd', 'i', 'c', 'a', 't', 'e', 'd', '\n',
        's', 'y', 'n', 'd', 'i', 'c', 'a', 't', 'e', 's', '\n',
        's', 'y', 'n', 'd', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'y', 'n', 'd', 'r', 'o', 'm', 'e', '\n',
        's', 'y', 'n', 'd', 'r', 'o', 'm', 'e', 's', '\n',
        's', 'y', 'n', 'e', 'r', 'g', 'i', 's', 'm', '\n',
        's', 'y', 'n', 'e', 'r', 'g', 'i', 's', 't', 'i', 'c', '\n',
        's', 'y', 'n', 'e', 'r', 'g', 'y', '\n',
        's', 'y', 'n', 'o', 'd', '\n',
        's', 'y', 'n', 'o', 'd', 'i', 'c', '\n',
        's', 'y', 'n', 'o', 'd', 's', '\n',
        's', 'y', 'n', 'o', 'n', 'y', 'm', '\n',
        's', 'y', 'n', 'o', 'n', 'y', 'm', 'i', 'c', '\n',
        's', 'y', 'n', 'o', 'n', 'y', 'm', 'o', 'u', 's', '\n',
        's', 'y', 'n', 'o', 'n', 'y', 'm', 'o', 'u', 's', 'l', 'y', '\n',
        's', 'y', 'n', 'o', 'n', 'y', 'm', 's', '\n',
        's', 'y', 'n', 'o', 'n', 'y', 'm', 'y', '\n',
        's', 'y', 'n', 'o', 'p', 's', 'e', 's', '\n',
        's', 'y', 'n', 'o', 'p', 's', 'i', 's', '\n',
        's', 'y', 'n', 'o', 'p', 't', 'i', 'c', '\n',
        's', 'y', 'n', 'o', 'v', 'i', 'a', 'l', '\n',
        's', 'y', 'n', 't', 'a', 'c', 't', 'i', 'c', '\n',
        's', 'y', 'n', 't', 'a', 'c', 't', 'i', 'c', 'a', 'l', '\n',
        's', 'y', 'n', 't', 'a', 'c', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 'y', 'n', 't', 'a', 'g', 'm', 'a', 't', 'i', 'c', '\n',
        's', 'y', 'n', 't', 'a', 'x', '\n',
        's', 'y', 'n', 't', 'h', 'e', 's', 'e', 's', '\n',
        's', 'y', 'n', 't', 'h', 'e', 's', 'i', 's', '\n',
        's', 'y', 'n', 't', 'h', 'e', 's', 'i', 's', 'e', '\n',
        's', 'y', 'n', 't', 'h', 'e', 's', 'i', 's', 'e', 'd', '\n',
        's', 'y', 'n', 't', 'h', 'e', 's', 'i', 's', 'e', 'r', '\n',
        's', 'y', 'n', 't', 'h', 'e', 's', 'i', 's', 'e', 'r', 's', '\n',
        's', 'y', 'n', 't', 'h', 'e', 's', 'i', 's', 'e', 's', '\n',
        's', 'y', 'n', 't', 'h', 'e', 's', 'i', 's', 'i', 'n', 'g', '\n',
        's', 'y', 'n', 't', 'h', 'e', 't', 'i', 'c', '\n',
        's', 'y', 'n', 't', 'h', 'e', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 'y', 'n', 't', 'h', 'e', 't', 'i', 'c', 's', '\n',
        's', 'y', 'p', 'h', 'i', 'l', 'i', 's', '\n',
        's', 'y', 'p', 'h', 'i', 'l', 'i', 't', 'i', 'c', '\n',
        's', 'y', 'p', 'h', 'o', 'n', '\n',
        's', 'y', 'p', 'h', 'o', 'n', 'e', 'd', '\n',
        's', 'y', 'p', 'h', 'o', 'n', 'i', 'n', 'g', '\n',
        's', 'y', 'p', 'h', 'o', 'n', 's', '\n',
        's', 'y', 'r', 'i', 'a', '\n',
        's', 'y', 'r', 'i', 'a', 'n', '\n',
        's', 'y', 'r', 'i', 'n', 'g', 'e', '\n',
        's', 'y', 'r', 'i', 'n', 'g', 'e', 's', '\n',
        's', 'y', 'r', 'u', 'p', '\n',
        's', 'y', 'r', 'u', 'p', 's', '\n',
        's', 'y', 'r', 'u', 'p', 'y', '\n',
        's', 'y', 's', 't', 'e', 'm', '\n',
        's', 'y', 's', 't', 'e', 'm', 'a', 't', 'i', 'c', '\n',
        's', 'y', 's', 't', 'e', 'm', 'a', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 'y', 's', 't', 'e', 'm', 'a', 't', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        's', 'y', 's', 't', 'e', 'm', 'a', 't', 'i', 's', 'e', '\n',
        's', 'y', 's', 't', 'e', 'm', 'i', 'c', '\n',
        's', 'y', 's', 't', 'e', 'm', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        's', 'y', 's', 't', 'e', 'm', 's', '\n',
        's', 'y', 's', 't', 'o', 'l', 'e', 's', '\n',
        's', 'y', 's', 't', 'o', 'l', 'i', 'c', '\n',
        't', 'a', 'a', 'l', '\n',
        't', 'a', 'b', '\n',
        't', 'a', 'b', 'a', 's', 'c', 'o', '\n',
        't', 'a', 'b', 'b', 'e', 'd', '\n',
        't', 'a', 'b', 'b', 'i', 'n', 'g', '\n',
        't', 'a', 'b', 'b', 'y', '\n',
        't', 'a', 'b', 'e', 'r', 'n', 'a', 'c', 'l', 'e', '\n',
        't', 'a', 'b', 'e', 'r', 'n', 'a', 'c', 'l', 'e', 's', '\n',
        't', 'a', 'b', 'l', 'e', '\n',
        't', 'a', 'b', 'l', 'e', 'a', 'u', '\n',
        't', 'a', 'b', 'l', 'e', 'a', 'u', 'x', '\n',
        't', 'a', 'b', 'l', 'e', 'b', 'a', 'y', '\n',
        't', 'a', 'b', 'l', 'e', 'c', 'l', 'o', 't', 'h', '\n',
        't', 'a', 'b', 'l', 'e', 'c', 'l', 'o', 't', 'h', 's', '\n',
        't', 'a', 'b', 'l', 'e', 'd', '\n',
        't', 'a', 'b', 'l', 'e', 'l', 'a', 'n', 'd', '\n',
        't', 'a', 'b', 'l', 'e', 's', '\n',
        't', 'a', 'b', 'l', 'e', 's', 'p', 'o', 'o', 'n', '\n',
        't', 'a', 'b', 'l', 'e', 's', 'p', 'o', 'o', 'n', 'f', 'u', 'l', 's', '\n',
        't', 'a', 'b', 'l', 'e', 's', 'p', 'o', 'o', 'n', 's', '\n',
        't', 'a', 'b', 'l', 'e', 't', '\n',
        't', 'a', 'b', 'l', 'e', 't', 's', '\n',
        't', 'a', 'b', 'l', 'e', 'w', 'a', 'r', 'e', '\n',
        't', 'a', 'b', 'l', 'i', 'n', 'g', '\n',
        't', 'a', 'b', 'l', 'o', 'i', 'd', '\n',
        't', 'a', 'b', 'l', 'o', 'i', 'd', 's', '\n',
        't', 'a', 'b', 'o', 'o', '\n',
        't', 'a', 'b', 'o', 'o', 's', '\n',
        't', 'a', 'b', 's', '\n',
        't', 'a', 'b', 'u', 'l', 'a', 'r', '\n',
        't', 'a', 'b', 'u', 'l', 'a', 't', 'e', '\n',
        't', 'a', 'b', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        't', 'a', 'b', 'u', 'l', 'a', 't', 'e', 's', '\n',
        't', 'a', 'b', 'u', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        't', 'a', 'b', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        't', 'a', 'b', 'u', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        't', 'a', 'b', 'u', 'l', 'a', 't', 'o', 'r', '\n',
        't', 'a', 'c', 'h', 'o', 'g', 'r', 'a', 'p', 'h', '\n',
        't', 'a', 'c', 'h', 'o', 'g', 'r', 'a', 'p', 'h', 's', '\n',
        't', 'a', 'c', 'h', 'y', 'c', 'a', 'r', 'd', 'i', 'a', '\n',
        't', 'a', 'c', 'h', 'y', 'o', 'n', '\n',
        't', 'a', 'c', 'h', 'y', 'o', 'n', 's', '\n',
        't', 'a', 'c', 'i', 't', '\n',
        't', 'a', 'c', 'i', 't', 'l', 'y', '\n',
        't', 'a', 'c', 'i', 't', 'u', 'r', 'n', '\n',
        't', 'a', 'c', 'k', '\n',
        't', 'a', 'c', 'k', 'e', 'd', '\n',
        't', 'a', 'c', 'k', 'i', 'e', 'r', '\n',
        't', 'a', 'c', 'k', 'i', 'e', 's', 't', '\n',
        't', 'a', 'c', 'k', 'i', 'n', 'e', 's', 's', '\n',
        't', 'a', 'c', 'k', 'i', 'n', 'g', '\n',
        't', 'a', 'c', 'k', 'l', 'e', '\n',
        't', 'a', 'c', 'k', 'l', 'e', 'd', '\n',
        't', 'a', 'c', 'k', 'l', 'e', 'r', '\n',
        't', 'a', 'c', 'k', 'l', 'e', 's', '\n',
        't', 'a', 'c', 'k', 'l', 'i', 'n', 'g', '\n',
        't', 'a', 'c', 'k', 's', '\n',
        't', 'a', 'c', 'k', 'y', '\n',
        't', 'a', 'c', 't', '\n',
        't', 'a', 'c', 't', 'f', 'u', 'l', '\n',
        't', 'a', 'c', 't', 'f', 'u', 'l', 'l', 'y', '\n',
        't', 'a', 'c', 't', 'i', 'c', '\n',
        't', 'a', 'c', 't', 'i', 'c', 'a', 'l', '\n',
        't', 'a', 'c', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        't', 'a', 'c', 't', 'i', 'c', 'i', 'a', 'n', '\n',
        't', 'a', 'c', 't', 'i', 'c', 's', '\n',
        't', 'a', 'c', 't', 'i', 'l', 'e', '\n',
        't', 'a', 'c', 't', 'l', 'e', 's', 's', '\n',
        't', 'a', 'c', 't', 'l', 'e', 's', 's', 'l', 'y', '\n',
        't', 'a', 'c', 't', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        't', 'a', 'c', 't', 'u', 'a', 'l', '\n',
        't', 'a', 'd', 'p', 'o', 'l', 'e', '\n',
        't', 'a', 'd', 'p', 'o', 'l', 'e', 's', '\n',
        't', 'a', 'f', 'f', 'e', 't', 'a', '\n',
        't', 'a', 'g', '\n',
        't', 'a', 'g', 'g', 'e', 'd', '\n',
        't', 'a', 'g', 'g', 'i', 'n', 'g', '\n',
        't', 'a', 'g', 's', '\n',
        't', 'a', 'h', 'i', 't', 'i', '\n',
        't', 'a', 'h', 'r', '\n',
        't', 'a', 'i', 'l', '\n',
        't', 'a', 'i', 'l', 'e', 'd', '\n',
        't', 'a', 'i', 'l', 'i', 'n', 'g', '\n',
        't', 'a', 'i', 'l', 'l', 'e', 's', 's', '\n',
        't', 'a', 'i', 'l', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        't', 'a', 'i', 'l', 'o', 'r', '\n',
        't', 'a', 'i', 'l', 'o', 'r', 'a', 'b', 'l', 'e', '\n',
        't', 'a', 'i', 'l', 'o', 'r', 'e', 'd', '\n',
        't', 'a', 'i', 'l', 'o', 'r', 'i', 'n', 'g', '\n',
        't', 'a', 'i', 'l', 'o', 'r', 'm', 'a', 'd', 'e', '\n',
        't', 'a', 'i', 'l', 'o', 'r', 's', '\n',
        't', 'a', 'i', 'l', 'p', 'i', 'e', 'c', 'e', '\n',
        't', 'a', 'i', 'l', 'p', 'l', 'a', 'n', 'e', '\n',
        't', 'a', 'i', 'l', 's', '\n',
        't', 'a', 'i', 'l', 's', 'p', 'i', 'n', '\n',
        't', 'a', 'i', 'l', 'w', 'i', 'n', 'd', '\n',
        't', 'a', 'i', 'n', 't', '\n',
        't', 'a', 'i', 'n', 't', 'e', 'd', '\n',
        't', 'a', 'i', 'n', 't', 'i', 'n', 'g', '\n',
        't', 'a', 'i', 'n', 't', 's', '\n',
        't', 'a', 'i', 'p', 'e', 'i', '\n',
        't', 'a', 'i', 'w', 'a', 'n', '\n',
        't', 'a', 'k', 'e', '\n',
        't', 'a', 'k', 'e', 'a', 'b', 'l', 'e', '\n',
        't', 'a', 'k', 'e', 'a', 'w', 'a', 'y', '\n',
        't', 'a', 'k', 'e', 'a', 'w', 'a', 'y', 's', '\n',
        't', 'a', 'k', 'e', 'n', '\n',
        't', 'a', 'k', 'e', 'o', 'v', 'e', 'r', '\n',
        't', 'a', 'k', 'e', 'o', 'v', 'e', 'r', 's', '\n',
        't', 'a', 'k', 'e', 'r', '\n',
        't', 'a', 'k', 'e', 'r', 's', '\n',
        't', 'a', 'k', 'e', 's', '\n',
        't', 'a', 'k', 'i', 'n', 'g', '\n',
        't', 'a', 'k', 'i', 'n', 'g', 's', '\n',
        't', 'a', 'l', 'c', '\n',
        't', 'a', 'l', 'c', 'u', 'm', '\n',
        't', 'a', 'l', 'e', '\n',
        't', 'a', 'l', 'e', 'n', 't', '\n',
        't', 'a', 'l', 'e', 'n', 't', 'e', 'd', '\n',
        't', 'a', 'l', 'e', 'n', 't', 'l', 'e', 's', 's', '\n',
        't', 'a', 'l', 'e', 'n', 't', 's', '\n',
        't', 'a', 'l', 'e', 's', '\n',
        't', 'a', 'l', 'i', 's', 'm', 'a', 'n', '\n',
        't', 'a', 'l', 'i', 's', 'm', 'a', 'n', 's', '\n',
        't', 'a', 'l', 'k', '\n',
        't', 'a', 'l', 'k', 'a', 't', 'i', 'v', 'e', '\n',
        't', 'a', 'l', 'k', 'a', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        't', 'a', 'l', 'k', 'b', 'a', 'c', 'k', '\n',
        't', 'a', 'l', 'k', 'e', 'd', '\n',
        't', 'a', 'l', 'k', 'e', 'r', '\n',
        't', 'a', 'l', 'k', 'e', 'r', 's', '\n',
        't', 'a', 'l', 'k', 'i', 'e', '\n',
        't', 'a', 'l', 'k', 'i', 'e', 's', '\n',
        't', 'a', 'l', 'k', 'i', 'n', 'g', '\n',
        't', 'a', 'l', 'k', 'i', 'n', 'g', 's', '\n',
        't', 'a', 'l', 'k', 's', '\n',
        't', 'a', 'l', 'l', '\n',
        't', 'a', 'l', 'l', 'b', 'o', 'y', '\n',
        't', 'a', 'l', 'l', 'e', 'r', '\n',
        't', 'a', 'l', 'l', 'e', 's', 't', '\n',
        't', 'a', 'l', 'l', 'i', 'e', 'd', '\n',
        't', 'a', 'l', 'l', 'i', 'e', 's', '\n',
        't', 'a', 'l', 'l', 'i', 's', 'h', '\n',
        't', 'a', 'l', 'l', 'n', 'e', 's', 's', '\n',
        't', 'a', 'l', 'l', 'o', 'w', '\n',
        't', 'a', 'l', 'l', 'y', '\n',
        't', 'a', 'l', 'l', 'y', 'h', 'o', '\n',
        't', 'a', 'l', 'l', 'y', 'i', 'n', 'g', '\n',
        't', 'a', 'l', 'm', 'u', 'd', '\n',
        't', 'a', 'l', 'o', 'n', '\n',
        't', 'a', 'l', 'o', 'n', 's', '\n',
        't', 'a', 'm', 'b', 'o', 'u', 'r', 'i', 'n', 'e', '\n',
        't', 'a', 'm', 'b', 'o', 'u', 'r', 'i', 'n', 'e', 's', '\n',
        't', 'a', 'm', 'e', '\n',
        't', 'a', 'm', 'e', 'd', '\n',
        't', 'a', 'm', 'e', 'l', 'y', '\n',
        't', 'a', 'm', 'e', 'n', 'e', 's', 's', '\n',
        't', 'a', 'm', 'e', 'r', '\n',
        't', 'a', 'm', 'e', 'r', 's', '\n',
        't', 'a', 'm', 'e', 's', '\n',
        't', 'a', 'm', 'e', 's', 't', '\n',
        't', 'a', 'm', 'i', 'n', 'g', '\n',
        't', 'a', 'm', 'p', '\n',
        't', 'a', 'm', 'p', 'e', 'd', '\n',
        't', 'a', 'm', 'p', 'e', 'r', '\n',
        't', 'a', 'm', 'p', 'e', 'r', 'e', 'd', '\n',
        't', 'a', 'm', 'p', 'e', 'r', 'i', 'n', 'g', '\n',
        't', 'a', 'm', 'p', 'e', 'r', 's', '\n',
        't', 'a', 'n', '\n',
        't', 'a', 'n', 'd', 'e', 'm', '\n',
        't', 'a', 'n', 'd', 'e', 'm', 's', '\n',
        't', 'a', 'n', 'g', '\n',
        't', 'a', 'n', 'g', 'e', 'l', 'o', '\n',
        't', 'a', 'n', 'g', 'e', 'n', 't', '\n',
        't', 'a', 'n', 'g', 'e', 'n', 't', 'i', 'a', 'l', '\n',
        't', 'a', 'n', 'g', 'e', 'n', 't', 'i', 'a', 'l', 'l', 'y', '\n',
        't', 'a', 'n', 'g', 'e', 'n', 't', 's', '\n',
        't', 'a', 'n', 'g', 'e', 'r', 'i', 'n', 'e', '\n',
        't', 'a', 'n', 'g', 'e', 'r', 'i', 'n', 'e', 's', '\n',
        't', 'a', 'n', 'g', 'i', 'b', 'l', 'e', '\n',
        't', 'a', 'n', 'g', 'i', 'b', 'l', 'y', '\n',
        't', 'a', 'n', 'g', 'l', 'e', '\n',
        't', 'a', 'n', 'g', 'l', 'e', 'd', '\n',
        't', 'a', 'n', 'g', 'l', 'e', 's', '\n',
        't', 'a', 'n', 'g', 'l', 'i', 'n', 'g', '\n',
        't', 'a', 'n', 'g', 'o', '\n',
        't', 'a', 'n', 'g', 'y', '\n',
        't', 'a', 'n', 'k', '\n',
        't', 'a', 'n', 'k', 'a', 'g', 'e', '\n',
        't', 'a', 'n', 'k', 'a', 'r', 'd', '\n',
        't', 'a', 'n', 'k', 'a', 'r', 'd', 's', '\n',
        't', 'a', 'n', 'k', 'e', 'd', '\n',
        't', 'a', 'n', 'k', 'e', 'r', '\n',
        't', 'a', 'n', 'k', 'e', 'r', 's', '\n',
        't', 'a', 'n', 'k', 'f', 'u', 'l', '\n',
        't', 'a', 'n', 'k', 'i', 'n', 'g', '\n',
        't', 'a', 'n', 'k', 's', '\n',
        't', 'a', 'n', 'n', 'e', 'd', '\n',
        't', 'a', 'n', 'n', 'e', 'r', '\n',
        't', 'a', 'n', 'n', 'e', 'r', 'i', 'e', 's', '\n',
        't', 'a', 'n', 'n', 'e', 'r', 's', '\n',
        't', 'a', 'n', 'n', 'e', 'r', 'y', '\n',
        't', 'a', 'n', 'n', 'i', 'c', '\n',
        't', 'a', 'n', 'n', 'i', 'n', '\n',
        't', 'a', 'n', 'n', 'i', 'n', 'g', '\n',
        't', 'a', 'n', 'n', 'i', 'n', 's', '\n',
        't', 'a', 'n', 'n', 'o', 'y', '\n',
        't', 'a', 'n', 's', '\n',
        't', 'a', 'n', 't', 'a', 'l', 'i', 's', 'e', '\n',
        't', 'a', 'n', 't', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        't', 'a', 'n', 't', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        't', 'a', 'n', 't', 'a', 'l', 'i', 's', 'i', 'n', 'g', 'l', 'y', '\n',
        't', 'a', 'n', 't', 'a', 'l', 'u', 'm', '\n',
        't', 'a', 'n', 't', 'a', 'm', 'o', 'u', 'n', 't', '\n',
        't', 'a', 'n', 't', 'r', 'u', 'm', '\n',
        't', 'a', 'n', 't', 'r', 'u', 'm', 's', '\n',
        't', 'a', 'n', 'z', 'a', 'n', 'i', 'a', '\n',
        't', 'a', 'p', '\n',
        't', 'a', 'p', 'a', 's', '\n',
        't', 'a', 'p', 'd', 'a', 'n', 'c', 'e', '\n',
        't', 'a', 'p', 'd', 'a', 'n', 'c', 'i', 'n', 'g', '\n',
        't', 'a', 'p', 'e', '\n',
        't', 'a', 'p', 'e', 'd', '\n',
        't', 'a', 'p', 'e', 'r', '\n',
        't', 'a', 'p', 'e', 'r', 'e', 'c', 'o', 'r', 'd', 'e', 'd', '\n',
        't', 'a', 'p', 'e', 'r', 'e', 'c', 'o', 'r', 'd', 'i', 'n', 'g', '\n',
        't', 'a', 'p', 'e', 'r', 'e', 'd', '\n',
        't', 'a', 'p', 'e', 'r', 'e', 'r', '\n',
        't', 'a', 'p', 'e', 'r', 'i', 'n', 'g', '\n',
        't', 'a', 'p', 'e', 'r', 's', '\n',
        't', 'a', 'p', 'e', 's', '\n',
        't', 'a', 'p', 'e', 's', 't', 'r', 'i', 'e', 's', '\n',
        't', 'a', 'p', 'e', 's', 't', 'r', 'y', '\n',
        't', 'a', 'p', 'e', 'w', 'o', 'r', 'm', '\n',
        't', 'a', 'p', 'e', 'w', 'o', 'r', 'm', 's', '\n',
        't', 'a', 'p', 'i', 'n', 'g', '\n',
        't', 'a', 'p', 'i', 'o', 'c', 'a', '\n',
        't', 'a', 'p', 'i', 'r', '\n',
        't', 'a', 'p', 'p', 'e', 'd', '\n',
        't', 'a', 'p', 'p', 'e', 'r', 's', '\n',
        't', 'a', 'p', 'p', 'i', 'n', 'g', '\n',
        't', 'a', 'p', 'p', 'i', 'n', 'g', 's', '\n',
        't', 'a', 'p', 'r', 'o', 'o', 'm', '\n',
        't', 'a', 'p', 's', '\n',
        't', 'a', 'r', '\n',
        't', 'a', 'r', 'a', 'm', 'a', 's', 'a', 'l', 'a', 't', 'a', '\n',
        't', 'a', 'r', 'a', 'n', 't', 'u', 'l', 'a', '\n',
        't', 'a', 'r', 'a', 'n', 't', 'u', 'l', 'a', 's', '\n',
        't', 'a', 'r', 'd', 'i', 'l', 'y', '\n',
        't', 'a', 'r', 'd', 'i', 'n', 'e', 's', 's', '\n',
        't', 'a', 'r', 'd', 'y', '\n',
        't', 'a', 'r', 'e', 's', '\n',
        't', 'a', 'r', 'g', 'e', 't', '\n',
        't', 'a', 'r', 'g', 'e', 't', 'e', 'd', '\n',
        't', 'a', 'r', 'g', 'e', 't', 'i', 'n', 'g', '\n',
        't', 'a', 'r', 'g', 'e', 't', 's', '\n',
        't', 'a', 'r', 'i', 'f', 'f', '\n',
        't', 'a', 'r', 'i', 'f', 'f', 's', '\n',
        't', 'a', 'r', 'm', 'a', 'c', '\n',
        't', 'a', 'r', 'm', 'a', 'c', 'a', 'd', 'a', 'm', '\n',
        't', 'a', 'r', 'n', '\n',
        't', 'a', 'r', 'n', 'i', 's', 'h', '\n',
        't', 'a', 'r', 'n', 'i', 's', 'h', 'e', 'd', '\n',
        't', 'a', 'r', 'n', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        't', 'a', 'r', 'n', 's', '\n',
        't', 'a', 'r', 'o', 't', '\n',
        't', 'a', 'r', 'p', 'a', 'u', 'l', 'i', 'n', '\n',
        't', 'a', 'r', 'p', 'a', 'u', 'l', 'i', 'n', 's', '\n',
        't', 'a', 'r', 'r', 'a', 'g', 'o', 'n', '\n',
        't', 'a', 'r', 'r', 'e', 'd', '\n',
        't', 'a', 'r', 'r', 'i', 'e', 'd', '\n',
        't', 'a', 'r', 'r', 'i', 'e', 'r', '\n',
        't', 'a', 'r', 'r', 'i', 'e', 's', 't', '\n',
        't', 'a', 'r', 'r', 'i', 'n', 'g', '\n',
        't', 'a', 'r', 'r', 'y', '\n',
        't', 'a', 'r', 'r', 'y', 'i', 'n', 'g', '\n',
        't', 'a', 'r', 's', '\n',
        't', 'a', 'r', 's', 'a', 'l', '\n',
        't', 'a', 'r', 's', 'u', 's', '\n',
        't', 'a', 'r', 't', '\n',
        't', 'a', 'r', 't', 'a', 'n', '\n',
        't', 'a', 'r', 't', 'a', 'n', 's', '\n',
        't', 'a', 'r', 't', 'a', 'r', '\n',
        't', 'a', 'r', 't', 'a', 'r', 'i', 'c', '\n',
        't', 'a', 'r', 't', 'l', 'y', '\n',
        't', 'a', 'r', 't', 'n', 'e', 's', 's', '\n',
        't', 'a', 'r', 't', 'r', 'a', 't', 'e', '\n',
        't', 'a', 'r', 't', 's', '\n',
        't', 'a', 'r', 't', 'y', '\n',
        't', 'a', 'r', 'z', 'a', 'n', '\n',
        't', 'a', 's', 'k', '\n',
        't', 'a', 's', 'k', 'e', 'd', '\n',
        't', 'a', 's', 'k', 'i', 'n', 'g', '\n',
        't', 'a', 's', 'k', 'm', 'a', 's', 't', 'e', 'r', '\n',
        't', 'a', 's', 'k', 's', '\n',
        't', 'a', 's', 'm', 'a', 'n', 'i', 'a', '\n',
        't', 'a', 's', 's', 'e', 'l', '\n',
        't', 'a', 's', 's', 'e', 'l', 'l', 'e', 'd', '\n',
        't', 'a', 's', 's', 'e', 'l', 's', '\n',
        't', 'a', 's', 't', 'e', '\n',
        't', 'a', 's', 't', 'e', 'd', '\n',
        't', 'a', 's', 't', 'e', 'f', 'u', 'l', '\n',
        't', 'a', 's', 't', 'e', 'f', 'u', 'l', 'l', 'y', '\n',
        't', 'a', 's', 't', 'e', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        't', 'a', 's', 't', 'e', 'l', 'e', 's', 's', '\n',
        't', 'a', 's', 't', 'e', 'l', 'e', 's', 's', 'l', 'y', '\n',
        't', 'a', 's', 't', 'e', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        't', 'a', 's', 't', 'e', 'r', '\n',
        't', 'a', 's', 't', 'e', 'r', 's', '\n',
        't', 'a', 's', 't', 'e', 's', '\n',
        't', 'a', 's', 't', 'i', 'e', 'r', '\n',
        't', 'a', 's', 't', 'i', 'e', 's', 't', '\n',
        't', 'a', 's', 't', 'i', 'n', 'g', '\n',
        't', 'a', 's', 't', 'i', 'n', 'g', 's', '\n',
        't', 'a', 's', 't', 'y', '\n',
        't', 'a', 't', '\n',
        't', 'a', 't', 't', 'e', 'r', 'e', 'd', '\n',
        't', 'a', 't', 't', 'e', 'r', 's', '\n',
        't', 'a', 't', 't', 'l', 'e', '\n',
        't', 'a', 't', 't', 'o', 'o', '\n',
        't', 'a', 't', 't', 'o', 'o', 'e', 'd', '\n',
        't', 'a', 't', 't', 'o', 'o', 'i', 'n', 'g', '\n',
        't', 'a', 't', 't', 'o', 'o', 's', '\n',
        't', 'a', 't', 't', 'y', '\n',
        't', 'a', 'u', '\n',
        't', 'a', 'u', 'g', 'h', 't', '\n',
        't', 'a', 'u', 'n', 't', '\n',
        't', 'a', 'u', 'n', 't', 'e', 'd', '\n',
        't', 'a', 'u', 'n', 't', 'e', 'r', '\n',
        't', 'a', 'u', 'n', 't', 'i', 'n', 'g', '\n',
        't', 'a', 'u', 'n', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        't', 'a', 'u', 'n', 't', 's', '\n',
        't', 'a', 'u', 't', '\n',
        't', 'a', 'u', 't', 'e', 'r', '\n',
        't', 'a', 'u', 't', 'e', 's', 't', '\n',
        't', 'a', 'u', 't', 'l', 'y', '\n',
        't', 'a', 'u', 't', 'n', 'e', 's', 's', '\n',
        't', 'a', 'u', 't', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        't', 'a', 'u', 't', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        't', 'a', 'u', 't', 'o', 'l', 'o', 'g', 'i', 'e', 's', '\n',
        't', 'a', 'u', 't', 'o', 'l', 'o', 'g', 'o', 'u', 's', '\n',
        't', 'a', 'u', 't', 'o', 'l', 'o', 'g', 'y', '\n',
        't', 'a', 'v', 'e', 'r', 'n', '\n',
        't', 'a', 'v', 'e', 'r', 'n', 'a', '\n',
        't', 'a', 'v', 'e', 'r', 'n', 'a', 's', '\n',
        't', 'a', 'v', 'e', 'r', 'n', 's', '\n',
        't', 'a', 'w', 'd', 'r', 'y', '\n',
        't', 'a', 'w', 'n', 'y', '\n',
        't', 'a', 'x', '\n',
        't', 'a', 'x', 'a', 'b', 'l', 'e', '\n',
        't', 'a', 'x', 'a', 't', 'i', 'o', 'n', '\n',
        't', 'a', 'x', 'd', 'e', 'd', 'u', 'c', 't', 'i', 'b', 'l', 'e', '\n',
        't', 'a', 'x', 'e', 'd', '\n',
        't', 'a', 'x', 'e', 's', '\n',
        't', 'a', 'x', 'f', 'r', 'e', 'e', '\n',
        't', 'a', 'x', 'i', '\n',
        't', 'a', 'x', 'i', 'c', 'a', 'b', '\n',
        't', 'a', 'x', 'i', 'd', 'e', 'r', 'm', 'i', 's', 't', '\n',
        't', 'a', 'x', 'i', 'd', 'e', 'r', 'm', 'i', 's', 't', 's', '\n',
        't', 'a', 'x', 'i', 'd', 'e', 'r', 'm', 'y', '\n',
        't', 'a', 'x', 'i', 'e', 'd', '\n',
        't', 'a', 'x', 'i', 'e', 's', '\n',
        't', 'a', 'x', 'i', 'i', 'n', 'g', '\n',
        't', 'a', 'x', 'i', 'n', 'g', '\n',
        't', 'a', 'x', 'i', 's', '\n',
        't', 'a', 'x', 'm', 'a', 'n', '\n',
        't', 'a', 'x', 'o', 'n', 'o', 'm', 'i', 'c', '\n',
        't', 'a', 'x', 'o', 'n', 'o', 'm', 'i', 'c', 'a', 'l', '\n',
        't', 'a', 'x', 'o', 'n', 'o', 'm', 'i', 'e', 's', '\n',
        't', 'a', 'x', 'o', 'n', 'o', 'm', 'i', 's', 't', '\n',
        't', 'a', 'x', 'o', 'n', 'o', 'm', 'i', 's', 't', 's', '\n',
        't', 'a', 'x', 'o', 'n', 'o', 'm', 'y', '\n',
        't', 'a', 'x', 'p', 'a', 'y', 'e', 'r', '\n',
        't', 'a', 'x', 'p', 'a', 'y', 'e', 'r', 's', '\n',
        't', 'a', 'x', 'p', 'a', 'y', 'i', 'n', 'g', '\n',
        't', 'a', 'y', 'l', 'o', 'r', '\n',
        't', 'e', 'a', '\n',
        't', 'e', 'a', 'b', 'a', 'g', '\n',
        't', 'e', 'a', 'b', 'a', 'g', 's', '\n',
        't', 'e', 'a', 'c', 'h', '\n',
        't', 'e', 'a', 'c', 'h', 'a', 'b', 'l', 'e', '\n',
        't', 'e', 'a', 'c', 'h', 'e', 'r', '\n',
        't', 'e', 'a', 'c', 'h', 'e', 'r', 's', '\n',
        't', 'e', 'a', 'c', 'h', 'e', 's', '\n',
        't', 'e', 'a', 'c', 'h', 'i', 'n', 'g', '\n',
        't', 'e', 'a', 'c', 'h', 'i', 'n', 'g', 's', '\n',
        't', 'e', 'a', 'c', 'l', 'o', 't', 'h', '\n',
        't', 'e', 'a', 'c', 'u', 'p', '\n',
        't', 'e', 'a', 'c', 'u', 'p', 's', '\n',
        't', 'e', 'a', 'k', '\n',
        't', 'e', 'a', 'l', '\n',
        't', 'e', 'a', 'm', '\n',
        't', 'e', 'a', 'm', 'e', 'd', '\n',
        't', 'e', 'a', 'm', 'i', 'n', 'g', '\n',
        't', 'e', 'a', 'm', 'm', 'a', 't', 'e', '\n',
        't', 'e', 'a', 'm', 'm', 'a', 't', 'e', 's', '\n',
        't', 'e', 'a', 'm', 's', '\n',
        't', 'e', 'a', 'm', 's', 't', 'e', 'r', '\n',
        't', 'e', 'a', 'm', 'w', 'o', 'r', 'k', '\n',
        't', 'e', 'a', 'p', 'a', 'r', 't', 'y', '\n',
        't', 'e', 'a', 'p', 'o', 't', '\n',
        't', 'e', 'a', 'p', 'o', 't', 's', '\n',
        't', 'e', 'a', 'r', '\n',
        't', 'e', 'a', 'r', 'a', 'w', 'a', 'y', '\n',
        't', 'e', 'a', 'r', 'd', 'r', 'o', 'p', '\n',
        't', 'e', 'a', 'r', 'd', 'r', 'o', 'p', 's', '\n',
        't', 'e', 'a', 'r', 'f', 'u', 'l', '\n',
        't', 'e', 'a', 'r', 'f', 'u', 'l', 'l', 'y', '\n',
        't', 'e', 'a', 'r', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        't', 'e', 'a', 'r', 'g', 'a', 's', '\n',
        't', 'e', 'a', 'r', 'i', 'n', 'g', '\n',
        't', 'e', 'a', 'r', 'l', 'e', 's', 's', '\n',
        't', 'e', 'a', 'r', 'o', 'o', 'm', '\n',
        't', 'e', 'a', 'r', 'o', 'o', 'm', 's', '\n',
        't', 'e', 'a', 'r', 's', '\n',
        't', 'e', 'a', 'r', 's', 't', 'a', 'i', 'n', 'e', 'd', '\n',
        't', 'e', 'a', 's', '\n',
        't', 'e', 'a', 's', 'e', '\n',
        't', 'e', 'a', 's', 'e', 'd', '\n',
        't', 'e', 'a', 's', 'e', 'r', '\n',
        't', 'e', 'a', 's', 'e', 'r', 's', '\n',
        't', 'e', 'a', 's', 'e', 's', '\n',
        't', 'e', 'a', 's', 'h', 'o', 'p', '\n',
        't', 'e', 'a', 's', 'h', 'o', 'p', 's', '\n',
        't', 'e', 'a', 's', 'i', 'n', 'g', '\n',
        't', 'e', 'a', 's', 'i', 'n', 'g', 'l', 'y', '\n',
        't', 'e', 'a', 's', 'p', 'o', 'o', 'n', '\n',
        't', 'e', 'a', 's', 'p', 'o', 'o', 'n', 'f', 'u', 'l', '\n',
        't', 'e', 'a', 's', 'p', 'o', 'o', 'n', 'f', 'u', 'l', 's', '\n',
        't', 'e', 'a', 's', 'p', 'o', 'o', 'n', 's', '\n',
        't', 'e', 'a', 't', '\n',
        't', 'e', 'a', 't', 'i', 'm', 'e', '\n',
        't', 'e', 'a', 't', 'i', 'm', 'e', 's', '\n',
        't', 'e', 'a', 't', 's', '\n',
        't', 'e', 'c', 'h', '\n',
        't', 'e', 'c', 'h', 'n', 'i', 'c', 'a', 'l', '\n',
        't', 'e', 'c', 'h', 'n', 'i', 'c', 'a', 'l', 'i', 't', 'i', 'e', 's', '\n',
        't', 'e', 'c', 'h', 'n', 'i', 'c', 'a', 'l', 'i', 't', 'y', '\n',
        't', 'e', 'c', 'h', 'n', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        't', 'e', 'c', 'h', 'n', 'i', 'c', 'i', 'a', 'n', '\n',
        't', 'e', 'c', 'h', 'n', 'i', 'c', 'i', 'a', 'n', 's', '\n',
        't', 'e', 'c', 'h', 'n', 'i', 'q', 'u', 'e', '\n',
        't', 'e', 'c', 'h', 'n', 'i', 'q', 'u', 'e', 's', '\n',
        't', 'e', 'c', 'h', 'n', 'o', 'c', 'r', 'a', 'c', 'i', 'e', 's', '\n',
        't', 'e', 'c', 'h', 'n', 'o', 'c', 'r', 'a', 'c', 'y', '\n',
        't', 'e', 'c', 'h', 'n', 'o', 'c', 'r', 'a', 't', '\n',
        't', 'e', 'c', 'h', 'n', 'o', 'c', 'r', 'a', 't', 'i', 'c', '\n',
        't', 'e', 'c', 'h', 'n', 'o', 'c', 'r', 'a', 't', 's', '\n',
        't', 'e', 'c', 'h', 'n', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        't', 'e', 'c', 'h', 'n', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        't', 'e', 'c', 'h', 'n', 'o', 'l', 'o', 'g', 'i', 'e', 's', '\n',
        't', 'e', 'c', 'h', 'n', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        't', 'e', 'c', 'h', 'n', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        't', 'e', 'c', 'h', 'n', 'o', 'l', 'o', 'g', 'y', '\n',
        't', 'e', 'c', 'h', 'n', 'o', 'p', 'h', 'i', 'l', 'e', 's', '\n',
        't', 'e', 'c', 'h', 'n', 'o', 'p', 'h', 'o', 'b', 'i', 'a', '\n',
        't', 'e', 'c', 'h', 'n', 'o', 'p', 'h', 'o', 'b', 'i', 'c', '\n',
        't', 'e', 'c', 't', 'o', 'n', 'i', 'c', '\n',
        't', 'e', 'c', 't', 'o', 'n', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        't', 'e', 'c', 't', 'o', 'n', 'i', 'c', 's', '\n',
        't', 'e', 'd', '\n',
        't', 'e', 'd', 'd', 'i', 'e', 's', '\n',
        't', 'e', 'd', 'd', 'y', '\n',
        't', 'e', 'd', 'i', 'o', 'u', 's', '\n',
        't', 'e', 'd', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        't', 'e', 'd', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        't', 'e', 'd', 'i', 'u', 'm', '\n',
        't', 'e', 'd', 'i', 'u', 'm', 's', '\n',
        't', 'e', 'd', 's', '\n',
        't', 'e', 'e', '\n',
        't', 'e', 'e', 'd', '\n',
        't', 'e', 'e', 'h', 'e', 'e', '\n',
        't', 'e', 'e', 'i', 'n', 'g', '\n',
        't', 'e', 'e', 'm', '\n',
        't', 'e', 'e', 'm', 'e', 'd', '\n',
        't', 'e', 'e', 'm', 'i', 'n', 'g', '\n',
        't', 'e', 'e', 'm', 's', '\n',
        't', 'e', 'e', 'n', '\n',
        't', 'e', 'e', 'n', 'a', 'g', 'e', '\n',
        't', 'e', 'e', 'n', 'a', 'g', 'e', 'd', '\n',
        't', 'e', 'e', 'n', 'a', 'g', 'e', 'r', '\n',
        't', 'e', 'e', 'n', 'a', 'g', 'e', 'r', 's', '\n',
        't', 'e', 'e', 'n', 'i', 'e', 's', 't', '\n',
        't', 'e', 'e', 'n', 's', '\n',
        't', 'e', 'e', 'n', 's', 'y', '\n',
        't', 'e', 'e', 'n', 'y', '\n',
        't', 'e', 'e', 'n', 'y', 'w', 'e', 'e', 'n', 'y', '\n',
        't', 'e', 'e', 'p', 'e', 'e', '\n',
        't', 'e', 'e', 'p', 'e', 'e', 's', '\n',
        't', 'e', 'e', 's', '\n',
        't', 'e', 'e', 't', 'e', 'r', '\n',
        't', 'e', 'e', 't', 'e', 'r', 'e', 'd', '\n',
        't', 'e', 'e', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        't', 'e', 'e', 't', 'h', '\n',
        't', 'e', 'e', 't', 'h', 'e', '\n',
        't', 'e', 'e', 't', 'h', 'e', 'd', '\n',
        't', 'e', 'e', 't', 'h', 'e', 's', '\n',
        't', 'e', 'e', 't', 'h', 'i', 'n', 'g', '\n',
        't', 'e', 'e', 't', 'h', 'm', 'a', 'r', 'k', 's', '\n',
        't', 'e', 'e', 't', 'o', 't', 'a', 'l', '\n',
        't', 'e', 'e', 't', 'o', 't', 'a', 'l', 'i', 's', 'm', '\n',
        't', 'e', 'e', 't', 'o', 't', 'a', 'l', 'l', 'e', 'r', '\n',
        't', 'e', 'e', 't', 'o', 't', 'a', 'l', 'l', 'e', 'r', 's', '\n',
        't', 'e', 'h', 'e', 'r', 'a', 'n', '\n',
        't', 'e', 'l', 'a', 'v', 'i', 'v', '\n',
        't', 'e', 'l', 'e', 'c', 'o', 'm', 'm', 'u', 'n', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        't', 'e', 'l', 'e', 'c', 'o', 'm', 'm', 'u', 'n', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        't', 'e', 'l', 'e', 'c', 'o', 'm', 'm', 'u', 't', 'i', 'n', 'g', '\n',
        't', 'e', 'l', 'e', 'c', 'o', 'm', 's', '\n',
        't', 'e', 'l', 'e', 'c', 'o', 'n', 'f', 'e', 'r', 'e', 'n', 'c', 'e', '\n',
        't', 'e', 'l', 'e', 'g', 'r', 'a', 'm', '\n',
        't', 'e', 'l', 'e', 'g', 'r', 'a', 'm', 's', '\n',
        't', 'e', 'l', 'e', 'g', 'r', 'a', 'p', 'h', '\n',
        't', 'e', 'l', 'e', 'g', 'r', 'a', 'p', 'h', 'e', 'd', '\n',
        't', 'e', 'l', 'e', 'g', 'r', 'a', 'p', 'h', 'i', 'c', '\n',
        't', 'e', 'l', 'e', 'g', 'r', 'a', 'p', 'h', 'i', 'n', 'g', '\n',
        't', 'e', 'l', 'e', 'g', 'r', 'a', 'p', 'h', 's', '\n',
        't', 'e', 'l', 'e', 'g', 'r', 'a', 'p', 'h', 'y', '\n',
        't', 'e', 'l', 'e', 'k', 'i', 'n', 'e', 's', 'i', 's', '\n',
        't', 'e', 'l', 'e', 'm', 'e', 't', 'r', 'y', '\n',
        't', 'e', 'l', 'e', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        't', 'e', 'l', 'e', 'o', 'l', 'o', 'g', 'y', '\n',
        't', 'e', 'l', 'e', 'p', 'a', 't', 'h', 'i', 'c', '\n',
        't', 'e', 'l', 'e', 'p', 'a', 't', 'h', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        't', 'e', 'l', 'e', 'p', 'a', 't', 'h', 'y', '\n',
        't', 'e', 'l', 'e', 'p', 'h', 'o', 'n', 'e', '\n',
        't', 'e', 'l', 'e', 'p', 'h', 'o', 'n', 'e', 'd', '\n',
        't', 'e', 'l', 'e', 'p', 'h', 'o', 'n', 'e', 's', '\n',
        't', 'e', 'l', 'e', 'p', 'h', 'o', 'n', 'i', 'c', '\n',
        't', 'e', 'l', 'e', 'p', 'h', 'o', 'n', 'i', 'n', 'g', '\n',
        't', 'e', 'l', 'e', 'p', 'h', 'o', 'n', 'i', 's', 't', '\n',
        't', 'e', 'l', 'e', 'p', 'h', 'o', 'n', 'i', 's', 't', 's', '\n',
        't', 'e', 'l', 'e', 'p', 'h', 'o', 'n', 'y', '\n',
        't', 'e', 'l', 'e', 'p', 'h', 'o', 't', 'o', '\n',
        't', 'e', 'l', 'e', 'p', 'r', 'i', 'n', 't', 'e', 'r', '\n',
        't', 'e', 'l', 'e', 'p', 'r', 'i', 'n', 't', 'e', 'r', 's', '\n',
        't', 'e', 'l', 'e', 's', 'a', 'l', 'e', 's', '\n',
        't', 'e', 'l', 'e', 's', 'c', 'o', 'p', 'e', '\n',
        't', 'e', 'l', 'e', 's', 'c', 'o', 'p', 'e', 'd', '\n',
        't', 'e', 'l', 'e', 's', 'c', 'o', 'p', 'e', 's', '\n',
        't', 'e', 'l', 'e', 's', 'c', 'o', 'p', 'i', 'c', '\n',
        't', 'e', 'l', 'e', 's', 'c', 'o', 'p', 'i', 'n', 'g', '\n',
        't', 'e', 'l', 'e', 't', 'e', 'x', 't', '\n',
        't', 'e', 'l', 'e', 't', 'h', 'o', 'n', '\n',
        't', 'e', 'l', 'e', 't', 'y', 'p', 'e', '\n',
        't', 'e', 'l', 'e', 't', 'y', 'p', 'e', 's', '\n',
        't', 'e', 'l', 'e', 'v', 'i', 's', 'e', '\n',
        't', 'e', 'l', 'e', 'v', 'i', 's', 'e', 'd', '\n',
        't', 'e', 'l', 'e', 'v', 'i', 's', 'i', 'n', 'g', '\n',
        't', 'e', 'l', 'e', 'v', 'i', 's', 'i', 'o', 'n', '\n',
        't', 'e', 'l', 'e', 'v', 'i', 's', 'i', 'o', 'n', 's', '\n',
        't', 'e', 'l', 'e', 'v', 'i', 's', 'u', 'a', 'l', '\n',
        't', 'e', 'l', 'e', 'w', 'o', 'r', 'k', 'i', 'n', 'g', '\n',
        't', 'e', 'l', 'e', 'x', '\n',
        't', 'e', 'l', 'e', 'x', 'e', 's', '\n',
        't', 'e', 'l', 'l', '\n',
        't', 'e', 'l', 'l', 'e', 'r', '\n',
        't', 'e', 'l', 'l', 'e', 'r', 's', '\n',
        't', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        't', 'e', 'l', 'l', 'i', 'n', 'g', 'l', 'y', '\n',
        't', 'e', 'l', 'l', 's', '\n',
        't', 'e', 'l', 'l', 't', 'a', 'l', 'e', '\n',
        't', 'e', 'l', 'l', 'y', '\n',
        't', 'e', 'm', 'e', 'r', 'i', 't', 'y', '\n',
        't', 'e', 'm', 'p', 'e', 'r', '\n',
        't', 'e', 'm', 'p', 'e', 'r', 'a', '\n',
        't', 'e', 'm', 'p', 'e', 'r', 'a', 'm', 'e', 'n', 't', '\n',
        't', 'e', 'm', 'p', 'e', 'r', 'a', 'm', 'e', 'n', 't', 'a', 'l', '\n',
        't', 'e', 'm', 'p', 'e', 'r', 'a', 'm', 'e', 'n', 't', 'a', 'l', 'l', 'y', '\n',
        't', 'e', 'm', 'p', 'e', 'r', 'a', 'm', 'e', 'n', 't', 's', '\n',
        't', 'e', 'm', 'p', 'e', 'r', 'a', 'n', 'c', 'e', '\n',
        't', 'e', 'm', 'p', 'e', 'r', 'a', 't', 'e', '\n',
        't', 'e', 'm', 'p', 'e', 'r', 'a', 't', 'e', 'l', 'y', '\n',
        't', 'e', 'm', 'p', 'e', 'r', 'a', 't', 'u', 'r', 'e', '\n',
        't', 'e', 'm', 'p', 'e', 'r', 'a', 't', 'u', 'r', 'e', 's', '\n',
        't', 'e', 'm', 'p', 'e', 'r', 'e', 'd', '\n',
        't', 'e', 'm', 'p', 'e', 'r', 'i', 'n', 'g', '\n',
        't', 'e', 'm', 'p', 'e', 'r', 's', '\n',
        't', 'e', 'm', 'p', 'e', 's', 't', '\n',
        't', 'e', 'm', 'p', 'e', 's', 't', 's', '\n',
        't', 'e', 'm', 'p', 'e', 's', 't', 'u', 'o', 'u', 's', '\n',
        't', 'e', 'm', 'p', 'i', '\n',
        't', 'e', 'm', 'p', 'l', 'a', 't', 'e', '\n',
        't', 'e', 'm', 'p', 'l', 'a', 't', 'e', 's', '\n',
        't', 'e', 'm', 'p', 'l', 'e', '\n',
        't', 'e', 'm', 'p', 'l', 'e', 's', '\n',
        't', 'e', 'm', 'p', 'o', '\n',
        't', 'e', 'm', 'p', 'o', 'r', 'a', 'l', '\n',
        't', 'e', 'm', 'p', 'o', 'r', 'a', 'l', 'i', 't', 'y', '\n',
        't', 'e', 'm', 'p', 'o', 'r', 'a', 'l', 'l', 'y', '\n',
        't', 'e', 'm', 'p', 'o', 'r', 'a', 'r', 'i', 'e', 's', '\n',
        't', 'e', 'm', 'p', 'o', 'r', 'a', 'r', 'i', 'l', 'y', '\n',
        't', 'e', 'm', 'p', 'o', 'r', 'a', 'r', 'y', '\n',
        't', 'e', 'm', 'p', 't', '\n',
        't', 'e', 'm', 'p', 't', 'a', 't', 'i', 'o', 'n', '\n',
        't', 'e', 'm', 'p', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        't', 'e', 'm', 'p', 't', 'e', 'd', '\n',
        't', 'e', 'm', 'p', 't', 'e', 'r', '\n',
        't', 'e', 'm', 'p', 't', 'e', 'r', 's', '\n',
        't', 'e', 'm', 'p', 't', 'i', 'n', 'g', '\n',
        't', 'e', 'm', 'p', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        't', 'e', 'm', 'p', 't', 'r', 'e', 's', 's', '\n',
        't', 'e', 'm', 'p', 't', 's', '\n',
        't', 'e', 'n', '\n',
        't', 'e', 'n', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        't', 'e', 'n', 'a', 'b', 'l', 'e', '\n',
        't', 'e', 'n', 'a', 'c', 'i', 'o', 'u', 's', '\n',
        't', 'e', 'n', 'a', 'c', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        't', 'e', 'n', 'a', 'c', 'i', 't', 'y', '\n',
        't', 'e', 'n', 'a', 'n', 'c', 'i', 'e', 's', '\n',
        't', 'e', 'n', 'a', 'n', 'c', 'y', '\n',
        't', 'e', 'n', 'a', 'n', 't', '\n',
        't', 'e', 'n', 'a', 'n', 't', 'e', 'd', '\n',
        't', 'e', 'n', 'a', 'n', 't', 'r', 'y', '\n',
        't', 'e', 'n', 'a', 'n', 't', 's', '\n',
        't', 'e', 'n', 'c', 'h', '\n',
        't', 'e', 'n', 'd', '\n',
        't', 'e', 'n', 'd', 'e', 'd', '\n',
        't', 'e', 'n', 'd', 'e', 'n', 'c', 'i', 'e', 's', '\n',
        't', 'e', 'n', 'd', 'e', 'n', 'c', 'y', '\n',
        't', 'e', 'n', 'd', 'e', 'n', 't', 'i', 'o', 'u', 's', '\n',
        't', 'e', 'n', 'd', 'e', 'n', 't', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        't', 'e', 'n', 'd', 'e', 'r', '\n',
        't', 'e', 'n', 'd', 'e', 'r', 'e', 'd', '\n',
        't', 'e', 'n', 'd', 'e', 'r', 'e', 'r', '\n',
        't', 'e', 'n', 'd', 'e', 'r', 'e', 's', 't', '\n',
        't', 'e', 'n', 'd', 'e', 'r', 'i', 'n', 'g', '\n',
        't', 'e', 'n', 'd', 'e', 'r', 'l', 'y', '\n',
        't', 'e', 'n', 'd', 'e', 'r', 'n', 'e', 's', 's', '\n',
        't', 'e', 'n', 'd', 'e', 'r', 's', '\n',
        't', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        't', 'e', 'n', 'd', 'o', 'n', '\n',
        't', 'e', 'n', 'd', 'o', 'n', 's', '\n',
        't', 'e', 'n', 'd', 'r', 'i', 'l', '\n',
        't', 'e', 'n', 'd', 'r', 'i', 'l', 's', '\n',
        't', 'e', 'n', 'd', 's', '\n',
        't', 'e', 'n', 'e', 'm', 'e', 'n', 't', '\n',
        't', 'e', 'n', 'e', 'm', 'e', 'n', 't', 's', '\n',
        't', 'e', 'n', 'e', 't', '\n',
        't', 'e', 'n', 'e', 't', 's', '\n',
        't', 'e', 'n', 'f', 'o', 'l', 'd', '\n',
        't', 'e', 'n', 'n', 'e', 'r', 's', '\n',
        't', 'e', 'n', 'n', 'i', 's', '\n',
        't', 'e', 'n', 'o', 'n', '\n',
        't', 'e', 'n', 'o', 'r', '\n',
        't', 'e', 'n', 'o', 'r', 's', '\n',
        't', 'e', 'n', 's', '\n',
        't', 'e', 'n', 's', 'e', '\n',
        't', 'e', 'n', 's', 'e', 'd', '\n',
        't', 'e', 'n', 's', 'e', 'l', 'y', '\n',
        't', 'e', 'n', 's', 'e', 'n', 'e', 's', 's', '\n',
        't', 'e', 'n', 's', 'e', 'r', '\n',
        't', 'e', 'n', 's', 'e', 's', '\n',
        't', 'e', 'n', 's', 'e', 's', 't', '\n',
        't', 'e', 'n', 's', 'i', 'l', 'e', '\n',
        't', 'e', 'n', 's', 'i', 'n', 'g', '\n',
        't', 'e', 'n', 's', 'i', 'o', 'n', '\n',
        't', 'e', 'n', 's', 'i', 'o', 'n', 'a', 'l', '\n',
        't', 'e', 'n', 's', 'i', 'o', 'n', 'e', 'd', '\n',
        't', 'e', 'n', 's', 'i', 'o', 'n', 's', '\n',
        't', 'e', 'n', 's', 'i', 't', 'y', '\n',
        't', 'e', 'n', 's', 'o', 'r', '\n',
        't', 'e', 'n', 's', 'o', 'r', 's', '\n',
        't', 'e', 'n', 't', '\n',
        't', 'e', 'n', 't', 'a', 'c', 'l', 'e', '\n',
        't', 'e', 'n', 't', 'a', 'c', 'l', 'e', 'd', '\n',
        't', 'e', 'n', 't', 'a', 'c', 'l', 'e', 's', '\n',
        't', 'e', 'n', 't', 'a', 't', 'i', 'v', 'e', '\n',
        't', 'e', 'n', 't', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        't', 'e', 'n', 't', 'e', 'd', '\n',
        't', 'e', 'n', 't', 'e', 'r', 'h', 'o', 'o', 'k', 's', '\n',
        't', 'e', 'n', 't', 'h', '\n',
        't', 'e', 'n', 't', 'h', 's', '\n',
        't', 'e', 'n', 't', 's', '\n',
        't', 'e', 'n', 'u', 'o', 'u', 's', '\n',
        't', 'e', 'n', 'u', 'o', 'u', 's', 'l', 'y', '\n',
        't', 'e', 'n', 'u', 'r', 'e', '\n',
        't', 'e', 'n', 'u', 'r', 'e', 'd', '\n',
        't', 'e', 'n', 'u', 'r', 'e', 's', '\n',
        't', 'e', 'n', 'u', 'r', 'i', 'a', 'l', '\n',
        't', 'e', 'p', 'e', 'e', '\n',
        't', 'e', 'p', 'i', 'd', '\n',
        't', 'e', 'q', 'u', 'i', 'l', 'a', '\n',
        't', 'e', 'r', 'c', 'e', 'n', 't', 'e', 'n', 'a', 'r', 'y', '\n',
        't', 'e', 'r', 'm', '\n',
        't', 'e', 'r', 'm', 'e', 'd', '\n',
        't', 'e', 'r', 'm', 'i', 'n', 'a', 'l', '\n',
        't', 'e', 'r', 'm', 'i', 'n', 'a', 'l', 'l', 'y', '\n',
        't', 'e', 'r', 'm', 'i', 'n', 'a', 'l', 's', '\n',
        't', 'e', 'r', 'm', 'i', 'n', 'a', 't', 'e', '\n',
        't', 'e', 'r', 'm', 'i', 'n', 'a', 't', 'e', 'd', '\n',
        't', 'e', 'r', 'm', 'i', 'n', 'a', 't', 'e', 's', '\n',
        't', 'e', 'r', 'm', 'i', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        't', 'e', 'r', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        't', 'e', 'r', 'm', 'i', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        't', 'e', 'r', 'm', 'i', 'n', 'a', 't', 'o', 'r', '\n',
        't', 'e', 'r', 'm', 'i', 'n', 'a', 't', 'o', 'r', 's', '\n',
        't', 'e', 'r', 'm', 'i', 'n', 'g', '\n',
        't', 'e', 'r', 'm', 'i', 'n', 'i', '\n',
        't', 'e', 'r', 'm', 'i', 'n', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        't', 'e', 'r', 'm', 'i', 'n', 'o', 'l', 'o', 'g', 'i', 'e', 's', '\n',
        't', 'e', 'r', 'm', 'i', 'n', 'o', 'l', 'o', 'g', 'y', '\n',
        't', 'e', 'r', 'm', 'i', 'n', 'u', 's', '\n',
        't', 'e', 'r', 'm', 'i', 't', 'e', '\n',
        't', 'e', 'r', 'm', 'i', 't', 'e', 's', '\n',
        't', 'e', 'r', 'm', 'l', 'y', '\n',
        't', 'e', 'r', 'm', 's', '\n',
        't', 'e', 'r', 'n', '\n',
        't', 'e', 'r', 'n', 'a', 'r', 'y', '\n',
        't', 'e', 'r', 'n', 's', '\n',
        't', 'e', 'r', 'r', 'a', 'c', 'e', '\n',
        't', 'e', 'r', 'r', 'a', 'c', 'e', 'd', '\n',
        't', 'e', 'r', 'r', 'a', 'c', 'e', 's', '\n',
        't', 'e', 'r', 'r', 'a', 'c', 'i', 'n', 'g', '\n',
        't', 'e', 'r', 'r', 'a', 'c', 'o', 't', 't', 'a', '\n',
        't', 'e', 'r', 'r', 'a', 'f', 'o', 'r', 'm', '\n',
        't', 'e', 'r', 'r', 'a', 'f', 'o', 'r', 'm', 'e', 'd', '\n',
        't', 'e', 'r', 'r', 'a', 'i', 'n', '\n',
        't', 'e', 'r', 'r', 'a', 'i', 'n', 's', '\n',
        't', 'e', 'r', 'r', 'a', 'p', 'i', 'n', '\n',
        't', 'e', 'r', 'r', 'a', 'p', 'i', 'n', 's', '\n',
        't', 'e', 'r', 'r', 'a', 'z', 'z', 'o', '\n',
        't', 'e', 'r', 'r', 'e', 's', 't', 'r', 'i', 'a', 'l', '\n',
        't', 'e', 'r', 'r', 'i', 'b', 'l', 'e', '\n',
        't', 'e', 'r', 'r', 'i', 'b', 'l', 'y', '\n',
        't', 'e', 'r', 'r', 'i', 'e', 'r', '\n',
        't', 'e', 'r', 'r', 'i', 'e', 'r', 's', '\n',
        't', 'e', 'r', 'r', 'i', 'f', 'i', 'c', '\n',
        't', 'e', 'r', 'r', 'i', 'f', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        't', 'e', 'r', 'r', 'i', 'f', 'i', 'e', 'd', '\n',
        't', 'e', 'r', 'r', 'i', 'f', 'i', 'e', 's', '\n',
        't', 'e', 'r', 'r', 'i', 'f', 'y', '\n',
        't', 'e', 'r', 'r', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        't', 'e', 'r', 'r', 'i', 'f', 'y', 'i', 'n', 'g', 'l', 'y', '\n',
        't', 'e', 'r', 'r', 'i', 'n', 'e', '\n',
        't', 'e', 'r', 'r', 'i', 't', 'o', 'r', 'i', 'a', 'l', '\n',
        't', 'e', 'r', 'r', 'i', 't', 'o', 'r', 'i', 'a', 'l', 'i', 't', 'y', '\n',
        't', 'e', 'r', 'r', 'i', 't', 'o', 'r', 'i', 'a', 'l', 'l', 'y', '\n',
        't', 'e', 'r', 'r', 'i', 't', 'o', 'r', 'i', 'e', 's', '\n',
        't', 'e', 'r', 'r', 'i', 't', 'o', 'r', 'y', '\n',
        't', 'e', 'r', 'r', 'o', 'r', '\n',
        't', 'e', 'r', 'r', 'o', 'r', 'i', 's', 'e', '\n',
        't', 'e', 'r', 'r', 'o', 'r', 'i', 's', 'e', 'd', '\n',
        't', 'e', 'r', 'r', 'o', 'r', 'i', 's', 'i', 'n', 'g', '\n',
        't', 'e', 'r', 'r', 'o', 'r', 'i', 's', 'm', '\n',
        't', 'e', 'r', 'r', 'o', 'r', 'i', 's', 't', '\n',
        't', 'e', 'r', 'r', 'o', 'r', 'i', 's', 't', 's', '\n',
        't', 'e', 'r', 'r', 'o', 'r', 's', '\n',
        't', 'e', 'r', 'r', 'o', 'r', 's', 't', 'r', 'i', 'c', 'k', 'e', 'n', '\n',
        't', 'e', 'r', 'r', 'y', '\n',
        't', 'e', 'r', 's', 'e', '\n',
        't', 'e', 'r', 's', 'e', 'l', 'y', '\n',
        't', 'e', 'r', 's', 'e', 'n', 'e', 's', 's', '\n',
        't', 'e', 'r', 's', 'e', 'r', '\n',
        't', 'e', 'r', 't', 'i', 'a', 'r', 'i', 'e', 's', '\n',
        't', 'e', 'r', 't', 'i', 'a', 'r', 'y', '\n',
        't', 'e', 's', 's', 'e', 'l', 'l', 'a', 't', 'e', 'd', '\n',
        't', 'e', 's', 's', 'e', 'l', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        't', 'e', 's', 's', 'e', 'l', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        't', 'e', 's', 's', 'e', 'r', 'a', 'l', '\n',
        't', 'e', 's', 't', '\n',
        't', 'e', 's', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        't', 'e', 's', 't', 'a', 'b', 'l', 'e', '\n',
        't', 'e', 's', 't', 'a', 'm', 'e', 'n', 't', '\n',
        't', 'e', 's', 't', 'a', 'm', 'e', 'n', 't', 'a', 'r', 'y', '\n',
        't', 'e', 's', 't', 'a', 'm', 'e', 'n', 't', 's', '\n',
        't', 'e', 's', 't', 'd', 'r', 'i', 'v', 'e', '\n',
        't', 'e', 's', 't', 'd', 'r', 'i', 'v', 'i', 'n', 'g', '\n',
        't', 'e', 's', 't', 'e', 'd', '\n',
        't', 'e', 's', 't', 'e', 'r', '\n',
        't', 'e', 's', 't', 'e', 'r', 's', '\n',
        't', 'e', 's', 't', 'e', 's', '\n',
        't', 'e', 's', 't', 'i', 'c', 'l', 'e', '\n',
        't', 'e', 's', 't', 'i', 'c', 'l', 'e', 's', '\n',
        't', 'e', 's', 't', 'i', 'c', 'u', 'l', 'a', 'r', '\n',
        't', 'e', 's', 't', 'i', 'e', 'r', '\n',
        't', 'e', 's', 't', 'i', 'e', 's', 't', '\n',
        't', 'e', 's', 't', 'i', 'f', 'i', 'e', 'd', '\n',
        't', 'e', 's', 't', 'i', 'f', 'i', 'e', 's', '\n',
        't', 'e', 's', 't', 'i', 'f', 'y', '\n',
        't', 'e', 's', 't', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        't', 'e', 's', 't', 'i', 'l', 'y', '\n',
        't', 'e', 's', 't', 'i', 'm', 'o', 'n', 'i', 'a', 'l', '\n',
        't', 'e', 's', 't', 'i', 'm', 'o', 'n', 'i', 'a', 'l', 's', '\n',
        't', 'e', 's', 't', 'i', 'm', 'o', 'n', 'i', 'e', 's', '\n',
        't', 'e', 's', 't', 'i', 'm', 'o', 'n', 'y', '\n',
        't', 'e', 's', 't', 'i', 'n', 'e', 's', 's', '\n',
        't', 'e', 's', 't', 'i', 'n', 'g', '\n',
        't', 'e', 's', 't', 'i', 'n', 'g', 's', '\n',
        't', 'e', 's', 't', 'i', 's', '\n',
        't', 'e', 's', 't', 'o', 's', 't', 'e', 'r', 'o', 'n', 'e', '\n',
        't', 'e', 's', 't', 's', '\n',
        't', 'e', 's', 't', 't', 'u', 'b', 'e', '\n',
        't', 'e', 's', 't', 'y', '\n',
        't', 'e', 't', 'a', 'n', 'u', 's', '\n',
        't', 'e', 't', 'c', 'h', 'i', 'l', 'y', '\n',
        't', 'e', 't', 'c', 'h', 'y', '\n',
        't', 'e', 't', 'h', 'e', 'r', '\n',
        't', 'e', 't', 'h', 'e', 'r', 'e', 'd', '\n',
        't', 'e', 't', 'h', 'e', 'r', 'i', 'n', 'g', '\n',
        't', 'e', 't', 'h', 'e', 'r', 's', '\n',
        't', 'e', 't', 'r', 'a', '\n',
        't', 'e', 't', 'r', 'a', 'c', 'h', 'l', 'o', 'r', 'i', 'd', 'e', '\n',
        't', 'e', 't', 'r', 'a', 'h', 'e', 'd', 'r', 'a', '\n',
        't', 'e', 't', 'r', 'a', 'h', 'e', 'd', 'r', 'a', 'l', '\n',
        't', 'e', 't', 'r', 'a', 'h', 'e', 'd', 'r', 'o', 'n', '\n',
        't', 'e', 't', 'r', 'a', 'h', 'e', 'd', 'r', 'o', 'n', 's', '\n',
        't', 'e', 't', 'r', 'a', 'm', 'e', 't', 'e', 'r', 's', '\n',
        't', 'e', 't', 'r', 'o', 'x', 'i', 'd', 'e', '\n',
        't', 'e', 'x', 'a', 'n', '\n',
        't', 'e', 'x', 'a', 'n', 's', '\n',
        't', 'e', 'x', 'a', 's', '\n',
        't', 'e', 'x', 't', '\n',
        't', 'e', 'x', 't', 'b', 'o', 'o', 'k', '\n',
        't', 'e', 'x', 't', 'b', 'o', 'o', 'k', 's', '\n',
        't', 'e', 'x', 't', 'i', 'l', 'e', '\n',
        't', 'e', 'x', 't', 'i', 'l', 'e', 's', '\n',
        't', 'e', 'x', 't', 's', '\n',
        't', 'e', 'x', 't', 'u', 'a', 'l', '\n',
        't', 'e', 'x', 't', 'u', 'a', 'l', 'i', 't', 'y', '\n',
        't', 'e', 'x', 't', 'u', 'a', 'l', 'l', 'y', '\n',
        't', 'e', 'x', 't', 'u', 'r', 'a', 'l', '\n',
        't', 'e', 'x', 't', 'u', 'r', 'a', 'l', 'l', 'y', '\n',
        't', 'e', 'x', 't', 'u', 'r', 'e', '\n',
        't', 'e', 'x', 't', 'u', 'r', 'e', 'd', '\n',
        't', 'e', 'x', 't', 'u', 'r', 'e', 's', '\n',
        't', 'h', 'a', 'i', '\n',
        't', 'h', 'a', 'l', 'a', 'm', 'u', 's', '\n',
        't', 'h', 'a', 'l', 'i', 'd', 'o', 'm', 'i', 'd', 'e', '\n',
        't', 'h', 'a', 'l', 'l', 'i', 'u', 'm', '\n',
        't', 'h', 'a', 'm', 'e', 's', '\n',
        't', 'h', 'a', 'n', '\n',
        't', 'h', 'a', 'n', 'e', '\n',
        't', 'h', 'a', 'n', 'k', '\n',
        't', 'h', 'a', 'n', 'k', 'e', 'd', '\n',
        't', 'h', 'a', 'n', 'k', 'f', 'u', 'l', '\n',
        't', 'h', 'a', 'n', 'k', 'f', 'u', 'l', 'l', 'y', '\n',
        't', 'h', 'a', 'n', 'k', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        't', 'h', 'a', 'n', 'k', 'i', 'n', 'g', '\n',
        't', 'h', 'a', 'n', 'k', 'l', 'e', 's', 's', '\n',
        't', 'h', 'a', 'n', 'k', 'l', 'e', 's', 's', 'l', 'y', '\n',
        't', 'h', 'a', 'n', 'k', 's', '\n',
        't', 'h', 'a', 'n', 'k', 's', 'g', 'i', 'v', 'i', 'n', 'g', '\n',
        't', 'h', 'a', 't', '\n',
        't', 'h', 'a', 't', 'c', 'h', '\n',
        't', 'h', 'a', 't', 'c', 'h', 'e', 'd', '\n',
        't', 'h', 'a', 't', 'c', 'h', 'e', 'r', '\n',
        't', 'h', 'a', 't', 'c', 'h', 'e', 'r', 's', '\n',
        't', 'h', 'a', 't', 'c', 'h', 'i', 'n', 'g', '\n',
        't', 'h', 'a', 'u', 'm', 'a', 't', 'u', 'r', 'g', 'e', '\n',
        't', 'h', 'a', 'w', '\n',
        't', 'h', 'a', 'w', 'e', 'd', '\n',
        't', 'h', 'a', 'w', 'i', 'n', 'g', '\n',
        't', 'h', 'a', 'w', 's', '\n',
        't', 'h', 'e', '\n',
        't', 'h', 'e', 'a', 't', 'r', 'e', '\n',
        't', 'h', 'e', 'a', 't', 'r', 'e', 's', '\n',
        't', 'h', 'e', 'a', 't', 'r', 'i', 'c', 'a', 'l', '\n',
        't', 'h', 'e', 'a', 't', 'r', 'i', 'c', 'a', 'l', 'i', 't', 'y', '\n',
        't', 'h', 'e', 'a', 't', 'r', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        't', 'h', 'e', 'a', 't', 'r', 'i', 'c', 'a', 'l', 's', '\n',
        't', 'h', 'e', 'b', 'e', 's', '\n',
        't', 'h', 'e', 'e', '\n',
        't', 'h', 'e', 'f', 't', '\n',
        't', 'h', 'e', 'f', 't', 's', '\n',
        't', 'h', 'e', 'i', 'r', '\n',
        't', 'h', 'e', 'i', 'r', 's', '\n',
        't', 'h', 'e', 'i', 's', 'm', '\n',
        't', 'h', 'e', 'i', 's', 't', '\n',
        't', 'h', 'e', 'i', 's', 't', 'i', 'c', '\n',
        't', 'h', 'e', 'i', 's', 't', 's', '\n',
        't', 'h', 'e', 'm', '\n',
        't', 'h', 'e', 'm', 'a', 's', '\n',
        't', 'h', 'e', 'm', 'a', 't', 'i', 'c', '\n',
        't', 'h', 'e', 'm', 'a', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        't', 'h', 'e', 'm', 'e', '\n',
        't', 'h', 'e', 'm', 'e', 'd', '\n',
        't', 'h', 'e', 'm', 'e', 's', '\n',
        't', 'h', 'e', 'm', 's', 'e', 'l', 'v', 'e', 's', '\n',
        't', 'h', 'e', 'n', '\n',
        't', 'h', 'e', 'n', 'c', 'e', '\n',
        't', 'h', 'e', 'n', 'c', 'e', 'f', 'o', 'r', 't', 'h', '\n',
        't', 'h', 'e', 'n', 'c', 'e', 'f', 'o', 'r', 'w', 'a', 'r', 'd', '\n',
        't', 'h', 'e', 'o', 'c', 'r', 'a', 'c', 'i', 'e', 's', '\n',
        't', 'h', 'e', 'o', 'c', 'r', 'a', 'c', 'y', '\n',
        't', 'h', 'e', 'o', 'd', 'o', 'l', 'i', 't', 'e', '\n',
        't', 'h', 'e', 'o', 'd', 'o', 'l', 'i', 't', 'e', 's', '\n',
        't', 'h', 'e', 'o', 'l', 'o', 'g', 'i', 'a', 'n', '\n',
        't', 'h', 'e', 'o', 'l', 'o', 'g', 'i', 'a', 'n', 's', '\n',
        't', 'h', 'e', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        't', 'h', 'e', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        't', 'h', 'e', 'o', 'l', 'o', 'g', 'i', 'e', 's', '\n',
        't', 'h', 'e', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        't', 'h', 'e', 'o', 'l', 'o', 'g', 'y', '\n',
        't', 'h', 'e', 'o', 'r', 'e', 'm', '\n',
        't', 'h', 'e', 'o', 'r', 'e', 'm', 's', '\n',
        't', 'h', 'e', 'o', 'r', 'e', 't', 'i', 'c', '\n',
        't', 'h', 'e', 'o', 'r', 'e', 't', 'i', 'c', 'a', 'l', '\n',
        't', 'h', 'e', 'o', 'r', 'e', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        't', 'h', 'e', 'o', 'r', 'e', 't', 'i', 'c', 'i', 'a', 'n', '\n',
        't', 'h', 'e', 'o', 'r', 'e', 't', 'i', 'c', 'i', 'a', 'n', 's', '\n',
        't', 'h', 'e', 'o', 'r', 'i', 'e', 's', '\n',
        't', 'h', 'e', 'o', 'r', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        't', 'h', 'e', 'o', 'r', 'i', 's', 'e', '\n',
        't', 'h', 'e', 'o', 'r', 'i', 's', 'e', 'd', '\n',
        't', 'h', 'e', 'o', 'r', 'i', 's', 'e', 's', '\n',
        't', 'h', 'e', 'o', 'r', 'i', 's', 'i', 'n', 'g', '\n',
        't', 'h', 'e', 'o', 'r', 'i', 's', 't', '\n',
        't', 'h', 'e', 'o', 'r', 'i', 's', 't', 's', '\n',
        't', 'h', 'e', 'o', 'r', 'y', '\n',
        't', 'h', 'e', 'o', 's', 'o', 'p', 'h', 'y', '\n',
        't', 'h', 'e', 'r', 'a', 'p', 'e', 'u', 't', 'i', 'c', '\n',
        't', 'h', 'e', 'r', 'a', 'p', 'e', 'u', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        't', 'h', 'e', 'r', 'a', 'p', 'i', 'e', 's', '\n',
        't', 'h', 'e', 'r', 'a', 'p', 'i', 's', 't', '\n',
        't', 'h', 'e', 'r', 'a', 'p', 'i', 's', 't', 's', '\n',
        't', 'h', 'e', 'r', 'a', 'p', 'y', '\n',
        't', 'h', 'e', 'r', 'e', '\n',
        't', 'h', 'e', 'r', 'e', 'a', 'b', 'o', 'u', 't', 's', '\n',
        't', 'h', 'e', 'r', 'e', 'a', 'f', 't', 'e', 'r', '\n',
        't', 'h', 'e', 'r', 'e', 'b', 'y', '\n',
        't', 'h', 'e', 'r', 'e', 'f', 'o', 'r', '\n',
        't', 'h', 'e', 'r', 'e', 'f', 'o', 'r', 'e', '\n',
        't', 'h', 'e', 'r', 'e', 'f', 'r', 'o', 'm', '\n',
        't', 'h', 'e', 'r', 'e', 'i', 'n', '\n',
        't', 'h', 'e', 'r', 'e', 'o', 'f', '\n',
        't', 'h', 'e', 'r', 'e', 'o', 'n', '\n',
        't', 'h', 'e', 'r', 'e', 't', 'o', '\n',
        't', 'h', 'e', 'r', 'e', 'u', 'n', 'd', 'e', 'r', '\n',
        't', 'h', 'e', 'r', 'e', 'u', 'p', 'o', 'n', '\n',
        't', 'h', 'e', 'r', 'e', 'w', 'i', 't', 'h', '\n',
        't', 'h', 'e', 'r', 'm', 'a', 'l', '\n',
        't', 'h', 'e', 'r', 'm', 'a', 'l', 'l', 'y', '\n',
        't', 'h', 'e', 'r', 'm', 'a', 'l', 's', '\n',
        't', 'h', 'e', 'r', 'm', 'o', 'c', 'h', 'e', 'm', 'i', 'c', 'a', 'l', '\n',
        't', 'h', 'e', 'r', 'm', 'o', 'd', 'y', 'n', 'a', 'm', 'i', 'c', '\n',
        't', 'h', 'e', 'r', 'm', 'o', 'd', 'y', 'n', 'a', 'm', 'i', 'c', 'a', 'l', '\n',
        't', 'h', 'e', 'r', 'm', 'o', 'd', 'y', 'n', 'a', 'm', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        't', 'h', 'e', 'r', 'm', 'o', 'd', 'y', 'n', 'a', 'm', 'i', 'c', 's', '\n',
        't', 'h', 'e', 'r', 'm', 'o', 'e', 'l', 'e', 'c', 't', 'r', 'i', 'c', '\n',
        't', 'h', 'e', 'r', 'm', 'o', 'm', 'e', 't', 'e', 'r', '\n',
        't', 'h', 'e', 'r', 'm', 'o', 'm', 'e', 't', 'e', 'r', 's', '\n',
        't', 'h', 'e', 'r', 'm', 'o', 'p', 'l', 'a', 's', 't', 'i', 'c', '\n',
        't', 'h', 'e', 'r', 'm', 'o', 's', 't', 'a', 't', '\n',
        't', 'h', 'e', 'r', 'm', 'o', 's', 't', 'a', 't', 'i', 'c', '\n',
        't', 'h', 'e', 'r', 'm', 'o', 's', 't', 'a', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        't', 'h', 'e', 'r', 'm', 'o', 's', 't', 'a', 't', 's', '\n',
        't', 'h', 'e', 'r', 'm', 's', '\n',
        't', 'h', 'e', 's', 'a', 'u', 'r', 'i', '\n',
        't', 'h', 'e', 's', 'a', 'u', 'r', 'u', 's', '\n',
        't', 'h', 'e', 's', 'e', '\n',
        't', 'h', 'e', 's', 'i', 's', '\n',
        't', 'h', 'e', 's', 'p', 'i', 'a', 'n', '\n',
        't', 'h', 'e', 's', 'p', 'i', 'a', 'n', 's', '\n',
        't', 'h', 'e', 't', 'a', '\n',
        't', 'h', 'e', 'y', '\n',
        't', 'h', 'i', 'c', 'k', '\n',
        't', 'h', 'i', 'c', 'k', 'e', 'n', '\n',
        't', 'h', 'i', 'c', 'k', 'e', 'n', 'e', 'd', '\n',
        't', 'h', 'i', 'c', 'k', 'e', 'n', 'i', 'n', 'g', '\n',
        't', 'h', 'i', 'c', 'k', 'e', 'n', 's', '\n',
        't', 'h', 'i', 'c', 'k', 'e', 'r', '\n',
        't', 'h', 'i', 'c', 'k', 'e', 's', 't', '\n',
        't', 'h', 'i', 'c', 'k', 'e', 't', '\n',
        't', 'h', 'i', 'c', 'k', 'e', 't', 's', '\n',
        't', 'h', 'i', 'c', 'k', 'i', 's', 'h', '\n',
        't', 'h', 'i', 'c', 'k', 'l', 'y', '\n',
        't', 'h', 'i', 'c', 'k', 'n', 'e', 's', 's', '\n',
        't', 'h', 'i', 'c', 'k', 'n', 'e', 's', 's', 'e', 's', '\n',
        't', 'h', 'i', 'c', 'k', 's', 'e', 't', '\n',
        't', 'h', 'i', 'c', 'k', 's', 'k', 'i', 'n', 'n', 'e', 'd', '\n',
        't', 'h', 'i', 'e', 'f', '\n',
        't', 'h', 'i', 'e', 'v', 'e', '\n',
        't', 'h', 'i', 'e', 'v', 'e', 'd', '\n',
        't', 'h', 'i', 'e', 'v', 'e', 'r', 'y', '\n',
        't', 'h', 'i', 'e', 'v', 'e', 's', '\n',
        't', 'h', 'i', 'e', 'v', 'i', 'n', 'g', '\n',
        't', 'h', 'i', 'e', 'v', 'i', 's', 'h', '\n',
        't', 'h', 'i', 'e', 'v', 'i', 's', 'h', 'n', 'e', 's', 's', '\n',
        't', 'h', 'i', 'g', 'h', '\n',
        't', 'h', 'i', 'g', 'h', 's', '\n',
        't', 'h', 'i', 'm', 'b', 'l', 'e', '\n',
        't', 'h', 'i', 'm', 'b', 'l', 'e', 'f', 'u', 'l', '\n',
        't', 'h', 'i', 'm', 'b', 'l', 'e', 'f', 'u', 'l', 's', '\n',
        't', 'h', 'i', 'm', 'b', 'l', 'e', 's', '\n',
        't', 'h', 'i', 'n', '\n',
        't', 'h', 'i', 'n', 'e', '\n',
        't', 'h', 'i', 'n', 'g', '\n',
        't', 'h', 'i', 'n', 'g', 's', '\n',
        't', 'h', 'i', 'n', 'k', '\n',
        't', 'h', 'i', 'n', 'k', 'a', 'b', 'l', 'e', '\n',
        't', 'h', 'i', 'n', 'k', 'e', 'r', '\n',
        't', 'h', 'i', 'n', 'k', 'e', 'r', 's', '\n',
        't', 'h', 'i', 'n', 'k', 'i', 'n', 'g', '\n',
        't', 'h', 'i', 'n', 'k', 's', '\n',
        't', 'h', 'i', 'n', 'k', 't', 'a', 'n', 'k', '\n',
        't', 'h', 'i', 'n', 'l', 'y', '\n',
        't', 'h', 'i', 'n', 'n', 'e', 'd', '\n',
        't', 'h', 'i', 'n', 'n', 'e', 'r', '\n',
        't', 'h', 'i', 'n', 'n', 'e', 'r', 's', '\n',
        't', 'h', 'i', 'n', 'n', 'e', 's', 's', '\n',
        't', 'h', 'i', 'n', 'n', 'e', 's', 't', '\n',
        't', 'h', 'i', 'n', 'n', 'i', 'n', 'g', '\n',
        't', 'h', 'i', 'n', 'n', 'i', 's', 'h', '\n',
        't', 'h', 'i', 'n', 's', '\n',
        't', 'h', 'i', 'r', 'd', '\n',
        't', 'h', 'i', 'r', 'd', 'l', 'y', '\n',
        't', 'h', 'i', 'r', 'd', 's', '\n',
        't', 'h', 'i', 'r', 's', 't', '\n',
        't', 'h', 'i', 'r', 's', 't', 'e', 'd', '\n',
        't', 'h', 'i', 'r', 's', 't', 'i', 'e', 'r', '\n',
        't', 'h', 'i', 'r', 's', 't', 'i', 'e', 's', 't', '\n',
        't', 'h', 'i', 'r', 's', 't', 'i', 'l', 'y', '\n',
        't', 'h', 'i', 'r', 's', 't', 'i', 'n', 'g', '\n',
        't', 'h', 'i', 'r', 's', 't', 's', '\n',
        't', 'h', 'i', 'r', 's', 't', 'y', '\n',
        't', 'h', 'i', 'r', 't', 'e', 'e', 'n', '\n',
        't', 'h', 'i', 'r', 't', 'e', 'e', 'n', 't', 'h', '\n',
        't', 'h', 'i', 'r', 't', 'i', 'e', 's', '\n',
        't', 'h', 'i', 'r', 't', 'i', 'e', 't', 'h', '\n',
        't', 'h', 'i', 'r', 't', 'y', '\n',
        't', 'h', 'i', 's', '\n',
        't', 'h', 'i', 's', 't', 'l', 'e', '\n',
        't', 'h', 'i', 's', 't', 'l', 'e', 's', '\n',
        't', 'h', 'i', 't', 'h', 'e', 'r', '\n',
        't', 'h', 'o', 'm', 'a', 's', '\n',
        't', 'h', 'o', 'n', 'g', '\n',
        't', 'h', 'o', 'n', 'g', 's', '\n',
        't', 'h', 'o', 'r', '\n',
        't', 'h', 'o', 'r', 'a', 'c', 'i', 'c', '\n',
        't', 'h', 'o', 'r', 'a', 'x', '\n',
        't', 'h', 'o', 'r', 'i', 'u', 'm', '\n',
        't', 'h', 'o', 'r', 'n', '\n',
        't', 'h', 'o', 'r', 'n', 'i', 'e', 'r', '\n',
        't', 'h', 'o', 'r', 'n', 'i', 'e', 's', 't', '\n',
        't', 'h', 'o', 'r', 'n', 's', '\n',
        't', 'h', 'o', 'r', 'n', 'y', '\n',
        't', 'h', 'o', 'r', 'o', 'u', 'g', 'h', '\n',
        't', 'h', 'o', 'r', 'o', 'u', 'g', 'h', 'b', 'r', 'e', 'd', '\n',
        't', 'h', 'o', 'r', 'o', 'u', 'g', 'h', 'b', 'r', 'e', 'd', 's', '\n',
        't', 'h', 'o', 'r', 'o', 'u', 'g', 'h', 'f', 'a', 'r', 'e', '\n',
        't', 'h', 'o', 'r', 'o', 'u', 'g', 'h', 'f', 'a', 'r', 'e', 's', '\n',
        't', 'h', 'o', 'r', 'o', 'u', 'g', 'h', 'g', 'o', 'i', 'n', 'g', '\n',
        't', 'h', 'o', 'r', 'o', 'u', 'g', 'h', 'l', 'y', '\n',
        't', 'h', 'o', 'r', 'o', 'u', 'g', 'h', 'n', 'e', 's', 's', '\n',
        't', 'h', 'o', 's', 'e', '\n',
        't', 'h', 'o', 'u', '\n',
        't', 'h', 'o', 'u', 'g', 'h', '\n',
        't', 'h', 'o', 'u', 'g', 'h', 't', '\n',
        't', 'h', 'o', 'u', 'g', 'h', 't', 'f', 'u', 'l', '\n',
        't', 'h', 'o', 'u', 'g', 'h', 't', 'f', 'u', 'l', 'l', 'y', '\n',
        't', 'h', 'o', 'u', 'g', 'h', 't', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        't', 'h', 'o', 'u', 'g', 'h', 't', 'l', 'e', 's', 's', '\n',
        't', 'h', 'o', 'u', 'g', 'h', 't', 'l', 'e', 's', 's', 'l', 'y', '\n',
        't', 'h', 'o', 'u', 'g', 'h', 't', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        't', 'h', 'o', 'u', 'g', 'h', 't', 'p', 'r', 'o', 'v', 'o', 'k', 'i', 'n', 'g', '\n',
        't', 'h', 'o', 'u', 'g', 'h', 't', 's', '\n',
        't', 'h', 'o', 'u', 's', 'a', 'n', 'd', '\n',
        't', 'h', 'o', 'u', 's', 'a', 'n', 'd', 'f', 'o', 'l', 'd', '\n',
        't', 'h', 'o', 'u', 's', 'a', 'n', 'd', 's', '\n',
        't', 'h', 'o', 'u', 's', 'a', 'n', 'd', 't', 'h', '\n',
        't', 'h', 'o', 'u', 's', 'a', 'n', 'd', 't', 'h', 's', '\n',
        't', 'h', 'r', 'a', 'l', 'l', '\n',
        't', 'h', 'r', 'a', 's', 'h', '\n',
        't', 'h', 'r', 'a', 's', 'h', 'e', 'd', '\n',
        't', 'h', 'r', 'a', 's', 'h', 'e', 'r', '\n',
        't', 'h', 'r', 'a', 's', 'h', 'e', 's', '\n',
        't', 'h', 'r', 'a', 's', 'h', 'i', 'n', 'g', '\n',
        't', 'h', 'r', 'a', 's', 'h', 'i', 'n', 'g', 's', '\n',
        't', 'h', 'r', 'e', 'a', 'd', '\n',
        't', 'h', 'r', 'e', 'a', 'd', 'b', 'a', 'r', 'e', '\n',
        't', 'h', 'r', 'e', 'a', 'd', 'e', 'd', '\n',
        't', 'h', 'r', 'e', 'a', 'd', 'i', 'n', 'g', '\n',
        't', 'h', 'r', 'e', 'a', 'd', 's', '\n',
        't', 'h', 'r', 'e', 'a', 't', '\n',
        't', 'h', 'r', 'e', 'a', 't', 'e', 'n', '\n',
        't', 'h', 'r', 'e', 'a', 't', 'e', 'n', 'e', 'd', '\n',
        't', 'h', 'r', 'e', 'a', 't', 'e', 'n', 'i', 'n', 'g', '\n',
        't', 'h', 'r', 'e', 'a', 't', 'e', 'n', 'i', 'n', 'g', 'l', 'y', '\n',
        't', 'h', 'r', 'e', 'a', 't', 'e', 'n', 's', '\n',
        't', 'h', 'r', 'e', 'a', 't', 's', '\n',
        't', 'h', 'r', 'e', 'e', '\n',
        't', 'h', 'r', 'e', 'e', 'd', 'i', 'm', 'e', 'n', 's', 'i', 'o', 'n', 'a', 'l', '\n',
        't', 'h', 'r', 'e', 'e', 'f', 'o', 'l', 'd', '\n',
        't', 'h', 'r', 'e', 'e', 'q', 'u', 'a', 'r', 't', 'e', 'r', 's', '\n',
        't', 'h', 'r', 'e', 'e', 's', '\n',
        't', 'h', 'r', 'e', 'e', 's', 'o', 'm', 'e', '\n',
        't', 'h', 'r', 'e', 'e', 's', 'o', 'm', 'e', 's', '\n',
        't', 'h', 'r', 'e', 's', 'h', '\n',
        't', 'h', 'r', 'e', 's', 'h', 'e', 'd', '\n',
        't', 'h', 'r', 'e', 's', 'h', 'e', 'r', '\n',
        't', 'h', 'r', 'e', 's', 'h', 'e', 'r', 's', '\n',
        't', 'h', 'r', 'e', 's', 'h', 'i', 'n', 'g', '\n',
        't', 'h', 'r', 'e', 's', 'h', 'o', 'l', 'd', '\n',
        't', 'h', 'r', 'e', 's', 'h', 'o', 'l', 'd', 's', '\n',
        't', 'h', 'r', 'e', 'w', '\n',
        't', 'h', 'r', 'i', 'c', 'e', '\n',
        't', 'h', 'r', 'i', 'f', 't', '\n',
        't', 'h', 'r', 'i', 'f', 't', 'i', 'e', 'r', '\n',
        't', 'h', 'r', 'i', 'f', 't', 'i', 'e', 's', 't', '\n',
        't', 'h', 'r', 'i', 'f', 't', 'l', 'e', 's', 's', '\n',
        't', 'h', 'r', 'i', 'f', 't', 's', '\n',
        't', 'h', 'r', 'i', 'f', 't', 'y', '\n',
        't', 'h', 'r', 'i', 'l', 'l', '\n',
        't', 'h', 'r', 'i', 'l', 'l', 'e', 'd', '\n',
        't', 'h', 'r', 'i', 'l', 'l', 'e', 'r', '\n',
        't', 'h', 'r', 'i', 'l', 'l', 'e', 'r', 's', '\n',
        't', 'h', 'r', 'i', 'l', 'l', 'i', 'n', 'g', '\n',
        't', 'h', 'r', 'i', 'l', 'l', 'i', 'n', 'g', 'l', 'y', '\n',
        't', 'h', 'r', 'i', 'l', 'l', 's', '\n',
        't', 'h', 'r', 'i', 'v', 'e', '\n',
        't', 'h', 'r', 'i', 'v', 'e', 'd', '\n',
        't', 'h', 'r', 'i', 'v', 'e', 's', '\n',
        't', 'h', 'r', 'i', 'v', 'i', 'n', 'g', '\n',
        't', 'h', 'r', 'o', 'a', 't', '\n',
        't', 'h', 'r', 'o', 'a', 't', 'i', 'e', 'r', '\n',
        't', 'h', 'r', 'o', 'a', 't', 'i', 'e', 's', 't', '\n',
        't', 'h', 'r', 'o', 'a', 't', 'i', 'l', 'y', '\n',
        't', 'h', 'r', 'o', 'a', 't', 's', '\n',
        't', 'h', 'r', 'o', 'a', 't', 'y', '\n',
        't', 'h', 'r', 'o', 'b', '\n',
        't', 'h', 'r', 'o', 'b', 'b', 'e', 'd', '\n',
        't', 'h', 'r', 'o', 'b', 'b', 'i', 'n', 'g', '\n',
        't', 'h', 'r', 'o', 'b', 's', '\n',
        't', 'h', 'r', 'o', 'm', 'b', 'o', 's', 'e', 's', '\n',
        't', 'h', 'r', 'o', 'm', 'b', 'o', 's', 'i', 's', '\n',
        't', 'h', 'r', 'o', 'm', 'b', 'u', 's', '\n',
        't', 'h', 'r', 'o', 'n', 'e', '\n',
        't', 'h', 'r', 'o', 'n', 'e', 'd', '\n',
        't', 'h', 'r', 'o', 'n', 'e', 's', '\n',
        't', 'h', 'r', 'o', 'n', 'g', '\n',
        't', 'h', 'r', 'o', 'n', 'g', 'e', 'd', '\n',
        't', 'h', 'r', 'o', 'n', 'g', 'i', 'n', 'g', '\n',
        't', 'h', 'r', 'o', 'n', 'g', 's', '\n',
        't', 'h', 'r', 'o', 'r', 'o', 'u', 'g', 'h', 'l', 'y', '\n',
        't', 'h', 'r', 'o', 't', 't', 'l', 'e', '\n',
        't', 'h', 'r', 'o', 't', 't', 'l', 'e', 'd', '\n',
        't', 'h', 'r', 'o', 't', 't', 'l', 'e', 's', '\n',
        't', 'h', 'r', 'o', 't', 't', 'l', 'i', 'n', 'g', '\n',
        't', 'h', 'r', 'o', 'u', 'g', 'h', '\n',
        't', 'h', 'r', 'o', 'u', 'g', 'h', 'o', 'u', 't', '\n',
        't', 'h', 'r', 'o', 'u', 'g', 'h', 'p', 'u', 't', '\n',
        't', 'h', 'r', 'o', 'w', '\n',
        't', 'h', 'r', 'o', 'w', 'a', 'w', 'a', 'y', '\n',
        't', 'h', 'r', 'o', 'w', 'b', 'a', 'c', 'k', '\n',
        't', 'h', 'r', 'o', 'w', 'e', 'r', '\n',
        't', 'h', 'r', 'o', 'w', 'e', 'r', 's', '\n',
        't', 'h', 'r', 'o', 'w', 'i', 'n', 'g', '\n',
        't', 'h', 'r', 'o', 'w', 'n', '\n',
        't', 'h', 'r', 'o', 'w', 's', '\n',
        't', 'h', 'r', 'u', 'm', '\n',
        't', 'h', 'r', 'u', 's', 'h', '\n',
        't', 'h', 'r', 'u', 's', 'h', 'e', 's', '\n',
        't', 'h', 'r', 'u', 's', 't', '\n',
        't', 'h', 'r', 'u', 's', 't', 'e', 'r', '\n',
        't', 'h', 'r', 'u', 's', 't', 'e', 'r', 's', '\n',
        't', 'h', 'r', 'u', 's', 't', 'i', 'n', 'g', '\n',
        't', 'h', 'r', 'u', 's', 't', 's', '\n',
        't', 'h', 'u', 'd', '\n',
        't', 'h', 'u', 'd', 'd', 'e', 'd', '\n',
        't', 'h', 'u', 'd', 'd', 'i', 'n', 'g', '\n',
        't', 'h', 'u', 'd', 's', '\n',
        't', 'h', 'u', 'g', '\n',
        't', 'h', 'u', 'g', 'g', 'e', 'r', 'y', '\n',
        't', 'h', 'u', 'g', 'g', 'i', 's', 'h', '\n',
        't', 'h', 'u', 'g', 's', '\n',
        't', 'h', 'u', 'm', 'b', '\n',
        't', 'h', 'u', 'm', 'b', 'e', 'd', '\n',
        't', 'h', 'u', 'm', 'b', 'i', 'n', 'g', '\n',
        't', 'h', 'u', 'm', 'b', 'n', 'a', 'i', 'l', '\n',
        't', 'h', 'u', 'm', 'b', 'p', 'r', 'i', 'n', 't', '\n',
        't', 'h', 'u', 'm', 'b', 's', '\n',
        't', 'h', 'u', 'm', 'b', 's', 'c', 'r', 'e', 'w', '\n',
        't', 'h', 'u', 'm', 'b', 's', 'c', 'r', 'e', 'w', 's', '\n',
        't', 'h', 'u', 'm', 'p', '\n',
        't', 'h', 'u', 'm', 'p', 'e', 'd', '\n',
        't', 'h', 'u', 'm', 'p', 'i', 'n', 'g', '\n',
        't', 'h', 'u', 'm', 'p', 's', '\n',
        't', 'h', 'u', 'n', 'd', 'e', 'r', '\n',
        't', 'h', 'u', 'n', 'd', 'e', 'r', 'b', 'o', 'l', 't', '\n',
        't', 'h', 'u', 'n', 'd', 'e', 'r', 'b', 'o', 'l', 't', 's', '\n',
        't', 'h', 'u', 'n', 'd', 'e', 'r', 'c', 'l', 'a', 'p', '\n',
        't', 'h', 'u', 'n', 'd', 'e', 'r', 'c', 'l', 'a', 'p', 's', '\n',
        't', 'h', 'u', 'n', 'd', 'e', 'r', 'c', 'l', 'o', 'u', 'd', '\n',
        't', 'h', 'u', 'n', 'd', 'e', 'r', 'e', 'd', '\n',
        't', 'h', 'u', 'n', 'd', 'e', 'r', 'f', 'l', 'a', 's', 'h', 'e', 's', '\n',
        't', 'h', 'u', 'n', 'd', 'e', 'r', 'i', 'n', 'g', '\n',
        't', 'h', 'u', 'n', 'd', 'e', 'r', 'o', 'u', 's', '\n',
        't', 'h', 'u', 'n', 'd', 'e', 'r', 'o', 'u', 's', 'l', 'y', '\n',
        't', 'h', 'u', 'n', 'd', 'e', 'r', 's', '\n',
        't', 'h', 'u', 'n', 'd', 'e', 'r', 's', 't', 'o', 'r', 'm', '\n',
        't', 'h', 'u', 'n', 'd', 'e', 'r', 's', 't', 'o', 'r', 'm', 's', '\n',
        't', 'h', 'u', 'n', 'd', 'e', 'r', 's', 't', 'r', 'u', 'c', 'k', '\n',
        't', 'h', 'u', 'n', 'd', 'e', 'r', 'y', '\n',
        't', 'h', 'u', 'r', 's', 'd', 'a', 'y', '\n',
        't', 'h', 'u', 's', '\n',
        't', 'h', 'w', 'a', 'c', 'k', '\n',
        't', 'h', 'w', 'a', 'r', 't', '\n',
        't', 'h', 'w', 'a', 'r', 't', 'e', 'd', '\n',
        't', 'h', 'w', 'a', 'r', 't', 'i', 'n', 'g', '\n',
        't', 'h', 'w', 'a', 'r', 't', 's', '\n',
        't', 'h', 'y', '\n',
        't', 'h', 'y', 'm', 'e', '\n',
        't', 'h', 'y', 'm', 'u', 's', '\n',
        't', 'h', 'y', 'r', 'i', 's', 't', 'o', 'r', '\n',
        't', 'h', 'y', 'r', 'i', 's', 't', 'o', 'r', 's', '\n',
        't', 'h', 'y', 'r', 'o', 'i', 'd', '\n',
        't', 'h', 'y', 'r', 'o', 'i', 'd', 's', '\n',
        't', 'h', 'y', 's', 'e', 'l', 'f', '\n',
        't', 'i', 'a', 'r', 'a', '\n',
        't', 'i', 'a', 'r', 'a', 's', '\n',
        't', 'i', 'b', 'i', 'a', '\n',
        't', 'i', 'b', 'i', 'a', 'e', '\n',
        't', 'i', 'c', '\n',
        't', 'i', 'c', 'k', '\n',
        't', 'i', 'c', 'k', 'e', 'd', '\n',
        't', 'i', 'c', 'k', 'e', 'r', '\n',
        't', 'i', 'c', 'k', 'e', 'r', 's', '\n',
        't', 'i', 'c', 'k', 'e', 't', '\n',
        't', 'i', 'c', 'k', 'e', 't', 'e', 'd', '\n',
        't', 'i', 'c', 'k', 'e', 't', 's', '\n',
        't', 'i', 'c', 'k', 'i', 'n', 'g', '\n',
        't', 'i', 'c', 'k', 'l', 'e', '\n',
        't', 'i', 'c', 'k', 'l', 'e', 'd', '\n',
        't', 'i', 'c', 'k', 'l', 'e', 'r', '\n',
        't', 'i', 'c', 'k', 'l', 'e', 's', '\n',
        't', 'i', 'c', 'k', 'l', 'i', 'n', 'g', '\n',
        't', 'i', 'c', 'k', 'l', 'i', 's', 'h', '\n',
        't', 'i', 'c', 'k', 's', '\n',
        't', 'i', 'c', 's', '\n',
        't', 'i', 'd', 'a', 'l', '\n',
        't', 'i', 'd', 'b', 'i', 't', '\n',
        't', 'i', 'd', 'b', 'i', 't', 's', '\n',
        't', 'i', 'd', 'd', 'l', 'e', 'r', 's', '\n',
        't', 'i', 'd', 'd', 'l', 'y', 'w', 'i', 'n', 'k', 's', '\n',
        't', 'i', 'd', 'e', '\n',
        't', 'i', 'd', 'e', 'l', 'e', 's', 's', '\n',
        't', 'i', 'd', 'e', 's', '\n',
        't', 'i', 'd', 'e', 'w', 'a', 'y', '\n',
        't', 'i', 'd', 'i', 'e', 'd', '\n',
        't', 'i', 'd', 'i', 'e', 'r', '\n',
        't', 'i', 'd', 'i', 'e', 's', '\n',
        't', 'i', 'd', 'i', 'e', 's', 't', '\n',
        't', 'i', 'd', 'i', 'l', 'y', '\n',
        't', 'i', 'd', 'i', 'n', 'e', 's', 's', '\n',
        't', 'i', 'd', 'i', 'n', 'g', '\n',
        't', 'i', 'd', 'i', 'n', 'g', 's', '\n',
        't', 'i', 'd', 'y', '\n',
        't', 'i', 'd', 'y', 'i', 'n', 'g', '\n',
        't', 'i', 'e', '\n',
        't', 'i', 'e', 'b', 'r', 'e', 'a', 'k', '\n',
        't', 'i', 'e', 'd', '\n',
        't', 'i', 'e', 'r', '\n',
        't', 'i', 'e', 'r', 'e', 'd', '\n',
        't', 'i', 'e', 'r', 's', '\n',
        't', 'i', 'e', 's', '\n',
        't', 'i', 'g', 'e', 'r', '\n',
        't', 'i', 'g', 'e', 'r', 'i', 's', 'h', '\n',
        't', 'i', 'g', 'e', 'r', 's', '\n',
        't', 'i', 'g', 'h', 't', '\n',
        't', 'i', 'g', 'h', 't', 'e', 'n', '\n',
        't', 'i', 'g', 'h', 't', 'e', 'n', 'e', 'd', '\n',
        't', 'i', 'g', 'h', 't', 'e', 'n', 'i', 'n', 'g', '\n',
        't', 'i', 'g', 'h', 't', 'e', 'n', 's', '\n',
        't', 'i', 'g', 'h', 't', 'e', 'r', '\n',
        't', 'i', 'g', 'h', 't', 'e', 's', 't', '\n',
        't', 'i', 'g', 'h', 't', 'f', 'i', 's', 't', 'e', 'd', '\n',
        't', 'i', 'g', 'h', 't', 'l', 'i', 'p', 'p', 'e', 'd', '\n',
        't', 'i', 'g', 'h', 't', 'l', 'y', '\n',
        't', 'i', 'g', 'h', 't', 'n', 'e', 's', 's', '\n',
        't', 'i', 'g', 'h', 't', 'r', 'o', 'p', 'e', '\n',
        't', 'i', 'g', 'h', 't', 's', '\n',
        't', 'i', 'g', 'h', 't', 'w', 'a', 'd', '\n',
        't', 'i', 'g', 'r', 'e', 's', 's', '\n',
        't', 'i', 'g', 'r', 'i', 's', '\n',
        't', 'i', 'k', 'k', 'a', '\n',
        't', 'i', 'l', 'd', 'e', '\n',
        't', 'i', 'l', 'd', 'e', 's', '\n',
        't', 'i', 'l', 'e', '\n',
        't', 'i', 'l', 'e', 'd', '\n',
        't', 'i', 'l', 'e', 'r', '\n',
        't', 'i', 'l', 'e', 's', '\n',
        't', 'i', 'l', 'i', 'n', 'g', '\n',
        't', 'i', 'l', 'i', 'n', 'g', 's', '\n',
        't', 'i', 'l', 'l', '\n',
        't', 'i', 'l', 'l', 'a', 'g', 'e', '\n',
        't', 'i', 'l', 'l', 'e', 'd', '\n',
        't', 'i', 'l', 'l', 'e', 'r', '\n',
        't', 'i', 'l', 'l', 'e', 'r', 's', '\n',
        't', 'i', 'l', 'l', 'i', 'n', 'g', '\n',
        't', 'i', 'l', 'l', 's', '\n',
        't', 'i', 'l', 't', '\n',
        't', 'i', 'l', 't', 'e', 'd', '\n',
        't', 'i', 'l', 't', 'i', 'n', 'g', '\n',
        't', 'i', 'l', 't', 's', '\n',
        't', 'i', 'm', 'b', 'e', 'r', '\n',
        't', 'i', 'm', 'b', 'e', 'r', 'e', 'd', '\n',
        't', 'i', 'm', 'b', 'r', 'e', '\n',
        't', 'i', 'm', 'e', '\n',
        't', 'i', 'm', 'e', 'b', 'a', 's', 'e', '\n',
        't', 'i', 'm', 'e', 'c', 'o', 'n', 's', 'u', 'm', 'i', 'n', 'g', '\n',
        't', 'i', 'm', 'e', 'd', '\n',
        't', 'i', 'm', 'e', 'f', 'r', 'a', 'm', 'e', '\n',
        't', 'i', 'm', 'e', 'h', 'o', 'n', 'o', 'u', 'r', 'e', 'd', '\n',
        't', 'i', 'm', 'e', 'k', 'e', 'e', 'p', 'e', 'r', '\n',
        't', 'i', 'm', 'e', 'k', 'e', 'e', 'p', 'e', 'r', 's', '\n',
        't', 'i', 'm', 'e', 'k', 'e', 'e', 'p', 'i', 'n', 'g', '\n',
        't', 'i', 'm', 'e', 'l', 'a', 'p', 's', 'e', '\n',
        't', 'i', 'm', 'e', 'l', 'e', 's', 's', '\n',
        't', 'i', 'm', 'e', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        't', 'i', 'm', 'e', 'l', 'i', 'n', 'e', 's', 's', '\n',
        't', 'i', 'm', 'e', 'l', 'y', '\n',
        't', 'i', 'm', 'e', 'o', 'u', 't', '\n',
        't', 'i', 'm', 'e', 'p', 'i', 'e', 'c', 'e', '\n',
        't', 'i', 'm', 'e', 'r', '\n',
        't', 'i', 'm', 'e', 'r', 's', '\n',
        't', 'i', 'm', 'e', 's', '\n',
        't', 'i', 'm', 'e', 's', 'c', 'a', 'l', 'e', '\n',
        't', 'i', 'm', 'e', 's', 'c', 'a', 'l', 'e', 's', '\n',
        't', 'i', 'm', 'e', 's', 'h', 'a', 'r', 'e', '\n',
        't', 'i', 'm', 'e', 't', 'a', 'b', 'l', 'e', '\n',
        't', 'i', 'm', 'e', 't', 'a', 'b', 'l', 'e', 'd', '\n',
        't', 'i', 'm', 'e', 't', 'a', 'b', 'l', 'e', 's', '\n',
        't', 'i', 'm', 'e', 't', 'a', 'b', 'l', 'i', 'n', 'g', '\n',
        't', 'i', 'm', 'i', 'd', '\n',
        't', 'i', 'm', 'i', 'd', 'i', 't', 'y', '\n',
        't', 'i', 'm', 'i', 'd', 'l', 'y', '\n',
        't', 'i', 'm', 'i', 'n', 'g', '\n',
        't', 'i', 'm', 'i', 'n', 'g', 's', '\n',
        't', 'i', 'n', '\n',
        't', 'i', 'n', 'c', 'a', 'n', '\n',
        't', 'i', 'n', 'c', 't', 'u', 'r', 'e', '\n',
        't', 'i', 'n', 'c', 't', 'u', 'r', 'e', 'd', '\n',
        't', 'i', 'n', 'd', 'e', 'r', '\n',
        't', 'i', 'n', 'd', 'e', 'r', 'b', 'o', 'x', '\n',
        't', 'i', 'n', 'f', 'o', 'i', 'l', '\n',
        't', 'i', 'n', 'g', 'e', '\n',
        't', 'i', 'n', 'g', 'e', 'd', '\n',
        't', 'i', 'n', 'g', 'e', 's', '\n',
        't', 'i', 'n', 'g', 'l', 'e', '\n',
        't', 'i', 'n', 'g', 'l', 'e', 'd', '\n',
        't', 'i', 'n', 'g', 'l', 'e', 's', '\n',
        't', 'i', 'n', 'g', 'l', 'i', 'e', 'r', '\n',
        't', 'i', 'n', 'g', 'l', 'i', 'e', 's', 't', '\n',
        't', 'i', 'n', 'g', 'l', 'i', 'n', 'g', '\n',
        't', 'i', 'n', 'g', 'l', 'y', '\n',
        't', 'i', 'n', 'i', 'e', 'r', '\n',
        't', 'i', 'n', 'i', 'e', 's', 't', '\n',
        't', 'i', 'n', 'k', 'e', 'r', '\n',
        't', 'i', 'n', 'k', 'e', 'r', 'e', 'd', '\n',
        't', 'i', 'n', 'k', 'e', 'r', 'i', 'n', 'g', '\n',
        't', 'i', 'n', 'k', 'e', 'r', 's', '\n',
        't', 'i', 'n', 'k', 'l', 'e', '\n',
        't', 'i', 'n', 'k', 'l', 'e', 'd', '\n',
        't', 'i', 'n', 'k', 'l', 'i', 'n', 'g', '\n',
        't', 'i', 'n', 'k', 'l', 'y', '\n',
        't', 'i', 'n', 'n', 'e', 'd', '\n',
        't', 'i', 'n', 'n', 'e', 'r', '\n',
        't', 'i', 'n', 'n', 'i', 'e', 'r', '\n',
        't', 'i', 'n', 'n', 'i', 'e', 's', 't', '\n',
        't', 'i', 'n', 'n', 'i', 'l', 'y', '\n',
        't', 'i', 'n', 'n', 'i', 't', 'u', 's', '\n',
        't', 'i', 'n', 'n', 'y', '\n',
        't', 'i', 'n', 'o', 'p', 'e', 'n', 'e', 'r', '\n',
        't', 'i', 'n', 'p', 'o', 't', '\n',
        't', 'i', 'n', 's', '\n',
        't', 'i', 'n', 's', 'e', 'l', '\n',
        't', 'i', 'n', 's', 'e', 'l', 's', '\n',
        't', 'i', 'n', 't', '\n',
        't', 'i', 'n', 't', 'e', 'd', '\n',
        't', 'i', 'n', 't', 'i', 'n', 'g', '\n',
        't', 'i', 'n', 't', 'i', 'n', 'g', 's', '\n',
        't', 'i', 'n', 't', 's', '\n',
        't', 'i', 'n', 'w', 'a', 'r', 'e', '\n',
        't', 'i', 'n', 'y', '\n',
        't', 'i', 'p', '\n',
        't', 'i', 'p', 'o', 'f', 'f', '\n',
        't', 'i', 'p', 'o', 'f', 'f', 's', '\n',
        't', 'i', 'p', 'p', 'e', 'd', '\n',
        't', 'i', 'p', 'p', 'e', 'r', '\n',
        't', 'i', 'p', 'p', 'i', 'n', 'g', '\n',
        't', 'i', 'p', 'p', 'l', 'e', '\n',
        't', 'i', 'p', 'p', 'l', 'i', 'n', 'g', '\n',
        't', 'i', 'p', 's', '\n',
        't', 'i', 'p', 's', 't', 'e', 'r', '\n',
        't', 'i', 'p', 's', 't', 'e', 'r', 's', '\n',
        't', 'i', 'p', 's', 'y', '\n',
        't', 'i', 'p', 't', 'o', 'e', '\n',
        't', 'i', 'p', 't', 'o', 'e', 'd', '\n',
        't', 'i', 'p', 't', 'o', 'e', 'i', 'n', 'g', '\n',
        't', 'i', 'p', 't', 'o', 'e', 's', '\n',
        't', 'i', 'p', 't', 'o', 'p', '\n',
        't', 'i', 'r', 'a', 'd', 'e', '\n',
        't', 'i', 'r', 'a', 'd', 'e', 's', '\n',
        't', 'i', 'r', 'e', '\n',
        't', 'i', 'r', 'e', 'd', '\n',
        't', 'i', 'r', 'e', 'd', 'l', 'y', '\n',
        't', 'i', 'r', 'e', 'd', 'n', 'e', 's', 's', '\n',
        't', 'i', 'r', 'e', 'l', 'e', 's', 's', '\n',
        't', 'i', 'r', 'e', 'l', 'e', 's', 's', 'l', 'y', '\n',
        't', 'i', 'r', 'e', 's', '\n',
        't', 'i', 'r', 'e', 's', 'o', 'm', 'e', '\n',
        't', 'i', 'r', 'e', 's', 'o', 'm', 'e', 'l', 'y', '\n',
        't', 'i', 'r', 'i', 'n', 'g', '\n',
        't', 'i', 'r', 'o', '\n',
        't', 'i', 's', 's', 'u', 'e', '\n',
        't', 'i', 's', 's', 'u', 'e', 's', '\n',
        't', 'i', 't', '\n',
        't', 'i', 't', 'a', 'n', '\n',
        't', 'i', 't', 'a', 'n', 'i', 'c', '\n',
        't', 'i', 't', 'a', 'n', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        't', 'i', 't', 'a', 'n', 'i', 'u', 'm', '\n',
        't', 'i', 't', 'a', 'n', 's', '\n',
        't', 'i', 't', 'b', 'i', 't', '\n',
        't', 'i', 't', 'b', 'i', 't', 's', '\n',
        't', 'i', 't', 'f', 'o', 'r', 't', 'a', 't', '\n',
        't', 'i', 't', 'h', 'e', '\n',
        't', 'i', 't', 'h', 'e', 's', '\n',
        't', 'i', 't', 'h', 'i', 'n', 'g', '\n',
        't', 'i', 't', 'i', 'l', 'l', 'a', 't', 'e', '\n',
        't', 'i', 't', 'i', 'l', 'l', 'a', 't', 'e', 'd', '\n',
        't', 'i', 't', 'i', 'l', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        't', 'i', 't', 'i', 'l', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        't', 'i', 't', 'l', 'e', '\n',
        't', 'i', 't', 'l', 'e', 'd', '\n',
        't', 'i', 't', 'l', 'e', 's', '\n',
        't', 'i', 't', 'l', 'i', 'n', 'g', '\n',
        't', 'i', 't', 'r', 'a', 't', 'e', 'd', '\n',
        't', 'i', 't', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        't', 'i', 't', 'r', 'e', '\n',
        't', 'i', 't', 'r', 'e', 's', '\n',
        't', 'i', 't', 's', '\n',
        't', 'i', 't', 't', 'e', 'r', '\n',
        't', 'i', 't', 't', 'e', 'r', 'e', 'd', '\n',
        't', 'i', 't', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        't', 'i', 't', 't', 'e', 'r', 's', '\n',
        't', 'i', 't', 'u', 'l', 'a', 'r', '\n',
        't', 'o', '\n',
        't', 'o', 'a', 'd', '\n',
        't', 'o', 'a', 'd', 'i', 'e', 's', '\n',
        't', 'o', 'a', 'd', 's', '\n',
        't', 'o', 'a', 'd', 's', 't', 'o', 'o', 'l', '\n',
        't', 'o', 'a', 'd', 's', 't', 'o', 'o', 'l', 's', '\n',
        't', 'o', 'a', 'd', 'y', '\n',
        't', 'o', 'a', 's', 't', '\n',
        't', 'o', 'a', 's', 't', 'e', 'd', '\n',
        't', 'o', 'a', 's', 't', 'e', 'r', '\n',
        't', 'o', 'a', 's', 't', 'e', 'r', 's', '\n',
        't', 'o', 'a', 's', 't', 'i', 'n', 'g', '\n',
        't', 'o', 'a', 's', 't', 's', '\n',
        't', 'o', 'a', 's', 't', 'y', '\n',
        't', 'o', 'b', 'a', 'c', 'c', 'o', '\n',
        't', 'o', 'b', 'a', 'c', 'c', 'o', 'n', 'i', 's', 't', '\n',
        't', 'o', 'b', 'a', 'c', 'c', 'o', 'n', 'i', 's', 't', 's', '\n',
        't', 'o', 'b', 'a', 'g', 'o', '\n',
        't', 'o', 'b', 'o', 'g', 'g', 'a', 'n', '\n',
        't', 'o', 'b', 'o', 'g', 'g', 'a', 'n', 'i', 'n', 'g', '\n',
        't', 'o', 'b', 'y', '\n',
        't', 'o', 'c', 'c', 'a', 't', 'a', '\n',
        't', 'o', 'c', 's', 'i', 'n', '\n',
        't', 'o', 'd', 'a', 'y', '\n',
        't', 'o', 'd', 'd', 'l', 'e', '\n',
        't', 'o', 'd', 'd', 'l', 'e', 'd', '\n',
        't', 'o', 'd', 'd', 'l', 'e', 'r', '\n',
        't', 'o', 'd', 'd', 'l', 'e', 'r', 's', '\n',
        't', 'o', 'd', 'd', 'l', 'i', 'n', 'g', '\n',
        't', 'o', 'd', 'd', 'y', '\n',
        't', 'o', 'd', 'i', 'e', 's', '\n',
        't', 'o', 'e', '\n',
        't', 'o', 'e', 'd', '\n',
        't', 'o', 'e', 'h', 'o', 'l', 'd', '\n',
        't', 'o', 'e', 'i', 'n', 'g', '\n',
        't', 'o', 'e', 'l', 'e', 's', 's', '\n',
        't', 'o', 'e', 'n', 'a', 'i', 'l', '\n',
        't', 'o', 'e', 'n', 'a', 'i', 'l', 's', '\n',
        't', 'o', 'e', 's', '\n',
        't', 'o', 'f', 'f', 'e', 'e', '\n',
        't', 'o', 'f', 'f', 'e', 'e', 's', '\n',
        't', 'o', 'f', 'f', 'y', '\n',
        't', 'o', 'f', 'u', '\n',
        't', 'o', 'g', '\n',
        't', 'o', 'g', 'a', '\n',
        't', 'o', 'g', 'a', 's', '\n',
        't', 'o', 'g', 'e', 't', 'h', 'e', 'r', '\n',
        't', 'o', 'g', 'e', 't', 'h', 'e', 'r', 'n', 'e', 's', 's', '\n',
        't', 'o', 'g', 'g', 'l', 'e', '\n',
        't', 'o', 'g', 'g', 'l', 'e', 'd', '\n',
        't', 'o', 'g', 'g', 'l', 'e', 's', '\n',
        't', 'o', 'g', 'g', 'l', 'i', 'n', 'g', '\n',
        't', 'o', 'g', 'o', '\n',
        't', 'o', 'g', 's', '\n',
        't', 'o', 'i', 'l', '\n',
        't', 'o', 'i', 'l', 'e', 'd', '\n',
        't', 'o', 'i', 'l', 'e', 'r', '\n',
        't', 'o', 'i', 'l', 'e', 't', '\n',
        't', 'o', 'i', 'l', 'e', 't', 'i', 'n', 'g', '\n',
        't', 'o', 'i', 'l', 'e', 't', 'r', 'i', 'e', 's', '\n',
        't', 'o', 'i', 'l', 'e', 't', 'r', 'y', '\n',
        't', 'o', 'i', 'l', 'e', 't', 's', '\n',
        't', 'o', 'i', 'l', 'e', 't', 't', 'e', '\n',
        't', 'o', 'i', 'l', 'i', 'n', 'g', '\n',
        't', 'o', 'i', 'l', 's', '\n',
        't', 'o', 'i', 't', 'o', 'i', '\n',
        't', 'o', 'k', 'a', 'm', 'a', 'k', '\n',
        't', 'o', 'k', 'e', 'n', '\n',
        't', 'o', 'k', 'e', 'n', 'i', 's', 'm', '\n',
        't', 'o', 'k', 'e', 'n', 'i', 's', 't', 'i', 'c', '\n',
        't', 'o', 'k', 'e', 'n', 's', '\n',
        't', 'o', 'k', 'y', 'o', '\n',
        't', 'o', 'l', 'b', 'o', 'o', 't', 'h', '\n',
        't', 'o', 'l', 'd', '\n',
        't', 'o', 'l', 'e', 'd', 'o', '\n',
        't', 'o', 'l', 'e', 'r', 'a', 'b', 'l', 'e', '\n',
        't', 'o', 'l', 'e', 'r', 'a', 'b', 'l', 'y', '\n',
        't', 'o', 'l', 'e', 'r', 'a', 'n', 'c', 'e', '\n',
        't', 'o', 'l', 'e', 'r', 'a', 'n', 'c', 'e', 's', '\n',
        't', 'o', 'l', 'e', 'r', 'a', 'n', 't', '\n',
        't', 'o', 'l', 'e', 'r', 'a', 'n', 't', 'l', 'y', '\n',
        't', 'o', 'l', 'e', 'r', 'a', 't', 'e', '\n',
        't', 'o', 'l', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        't', 'o', 'l', 'e', 'r', 'a', 't', 'e', 's', '\n',
        't', 'o', 'l', 'e', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        't', 'o', 'l', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        't', 'o', 'l', 'l', '\n',
        't', 'o', 'l', 'l', 'e', 'd', '\n',
        't', 'o', 'l', 'l', 'g', 'a', 't', 'e', '\n',
        't', 'o', 'l', 'l', 'i', 'n', 'g', '\n',
        't', 'o', 'l', 'l', 's', '\n',
        't', 'o', 'l', 'u', 'e', 'n', 'e', '\n',
        't', 'o', 'm', 'a', 'h', 'a', 'w', 'k', '\n',
        't', 'o', 'm', 'a', 'h', 'a', 'w', 'k', 's', '\n',
        't', 'o', 'm', 'a', 't', 'o', '\n',
        't', 'o', 'm', 'b', '\n',
        't', 'o', 'm', 'b', 'o', 'l', 'a', '\n',
        't', 'o', 'm', 'b', 'o', 'y', '\n',
        't', 'o', 'm', 'b', 'o', 'y', 's', '\n',
        't', 'o', 'm', 'b', 's', '\n',
        't', 'o', 'm', 'b', 's', 't', 'o', 'n', 'e', '\n',
        't', 'o', 'm', 'b', 's', 't', 'o', 'n', 'e', 's', '\n',
        't', 'o', 'm', 'c', 'a', 't', '\n',
        't', 'o', 'm', 'e', '\n',
        't', 'o', 'm', 'e', 's', '\n',
        't', 'o', 'm', 'f', 'o', 'o', 'l', 'e', 'r', 'y', '\n',
        't', 'o', 'm', 'o', 'g', 'r', 'a', 'p', 'h', 'y', '\n',
        't', 'o', 'm', 'o', 'r', 'r', 'o', 'w', '\n',
        't', 'o', 'm', 'o', 'r', 'r', 'o', 'w', 's', '\n',
        't', 'o', 'm', 't', 'o', 'm', '\n',
        't', 'o', 'n', '\n',
        't', 'o', 'n', 'a', 'l', '\n',
        't', 'o', 'n', 'a', 'l', 'i', 't', 'i', 'e', 's', '\n',
        't', 'o', 'n', 'a', 'l', 'i', 't', 'y', '\n',
        't', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        't', 'o', 'n', 'e', '\n',
        't', 'o', 'n', 'e', 'd', '\n',
        't', 'o', 'n', 'e', 'd', 'e', 'a', 'f', '\n',
        't', 'o', 'n', 'e', 'l', 'e', 's', 's', '\n',
        't', 'o', 'n', 'e', 'l', 'e', 's', 's', 'l', 'y', '\n',
        't', 'o', 'n', 'e', 'r', '\n',
        't', 'o', 'n', 'e', 'r', 's', '\n',
        't', 'o', 'n', 'e', 's', '\n',
        't', 'o', 'n', 'g', 'a', '\n',
        't', 'o', 'n', 'g', 's', '\n',
        't', 'o', 'n', 'g', 'u', 'e', '\n',
        't', 'o', 'n', 'g', 'u', 'e', 'i', 'n', 'c', 'h', 'e', 'e', 'k', '\n',
        't', 'o', 'n', 'g', 'u', 'e', 's', '\n',
        't', 'o', 'n', 'g', 'u', 'e', 't', 'i', 'e', 'd', '\n',
        't', 'o', 'n', 'g', 'u', 'e', 't', 'w', 'i', 's', 't', 'e', 'r', '\n',
        't', 'o', 'n', 'g', 'u', 'e', 't', 'w', 'i', 's', 't', 'e', 'r', 's', '\n',
        't', 'o', 'n', 'i', 'c', '\n',
        't', 'o', 'n', 'i', 'c', 's', '\n',
        't', 'o', 'n', 'i', 'g', 'h', 't', '\n',
        't', 'o', 'n', 'i', 'n', 'g', '\n',
        't', 'o', 'n', 'n', 'a', 'g', 'e', '\n',
        't', 'o', 'n', 'n', 'a', 'g', 'e', 's', '\n',
        't', 'o', 'n', 'n', 'e', '\n',
        't', 'o', 'n', 'n', 'e', 's', '\n',
        't', 'o', 'n', 's', '\n',
        't', 'o', 'n', 's', 'i', 'l', '\n',
        't', 'o', 'n', 's', 'i', 'l', 'l', 'e', 'c', 't', 'o', 'm', 'y', '\n',
        't', 'o', 'n', 's', 'i', 'l', 'l', 'i', 't', 'i', 's', '\n',
        't', 'o', 'n', 's', 'i', 'l', 's', '\n',
        't', 'o', 'n', 's', 'u', 'r', 'e', '\n',
        't', 'o', 'n', 'y', '\n',
        't', 'o', 'o', '\n',
        't', 'o', 'o', 'k', '\n',
        't', 'o', 'o', 'l', '\n',
        't', 'o', 'o', 'l', 'b', 'o', 'x', '\n',
        't', 'o', 'o', 'l', 'b', 'o', 'x', 'e', 's', '\n',
        't', 'o', 'o', 'l', 'e', 'd', '\n',
        't', 'o', 'o', 'l', 'i', 'n', 'g', '\n',
        't', 'o', 'o', 'l', 'm', 'a', 'k', 'e', 'r', '\n',
        't', 'o', 'o', 'l', 'm', 'a', 'k', 'i', 'n', 'g', '\n',
        't', 'o', 'o', 'l', 's', '\n',
        't', 'o', 'o', 't', '\n',
        't', 'o', 'o', 't', 'e', 'd', '\n',
        't', 'o', 'o', 't', 'h', '\n',
        't', 'o', 'o', 't', 'h', 'a', 'c', 'h', 'e', '\n',
        't', 'o', 'o', 't', 'h', 'b', 'r', 'u', 's', 'h', '\n',
        't', 'o', 'o', 't', 'h', 'b', 'r', 'u', 's', 'h', 'e', 's', '\n',
        't', 'o', 'o', 't', 'h', 'e', 'd', '\n',
        't', 'o', 'o', 't', 'h', 'i', 'e', 'r', '\n',
        't', 'o', 'o', 't', 'h', 'i', 'e', 's', 't', '\n',
        't', 'o', 'o', 't', 'h', 'l', 'e', 's', 's', '\n',
        't', 'o', 'o', 't', 'h', 'm', 'a', 'r', 'k', 's', '\n',
        't', 'o', 'o', 't', 'h', 'p', 'a', 's', 't', 'e', '\n',
        't', 'o', 'o', 't', 'h', 'p', 'i', 'c', 'k', '\n',
        't', 'o', 'o', 't', 'h', 'p', 'i', 'c', 'k', 's', '\n',
        't', 'o', 'o', 't', 'h', 's', 'o', 'm', 'e', '\n',
        't', 'o', 'o', 't', 'h', 'y', '\n',
        't', 'o', 'o', 't', 'i', 'n', 'g', '\n',
        't', 'o', 'o', 't', 'l', 'e', '\n',
        't', 'o', 'p', '\n',
        't', 'o', 'p', 'a', 'z', '\n',
        't', 'o', 'p', 'a', 'z', 'e', 's', '\n',
        't', 'o', 'p', 'c', 'o', 'a', 't', '\n',
        't', 'o', 'p', 'h', 'e', 'a', 'v', 'y', '\n',
        't', 'o', 'p', 'i', 'a', 'r', 'y', '\n',
        't', 'o', 'p', 'i', 'c', '\n',
        't', 'o', 'p', 'i', 'c', 'a', 'l', '\n',
        't', 'o', 'p', 'i', 'c', 'a', 'l', 'i', 't', 'y', '\n',
        't', 'o', 'p', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        't', 'o', 'p', 'i', 'c', 's', '\n',
        't', 'o', 'p', 'l', 'e', 's', 's', '\n',
        't', 'o', 'p', 'l', 'e', 'v', 'e', 'l', '\n',
        't', 'o', 'p', 'm', 'o', 's', 't', '\n',
        't', 'o', 'p', 'n', 'o', 't', 'c', 'h', '\n',
        't', 'o', 'p', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', '\n',
        't', 'o', 'p', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', 'a', 'l', '\n',
        't', 'o', 'p', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        't', 'o', 'p', 'o', 'g', 'r', 'a', 'p', 'h', 'y', '\n',
        't', 'o', 'p', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        't', 'o', 'p', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        't', 'o', 'p', 'o', 'l', 'o', 'g', 'i', 'e', 's', '\n',
        't', 'o', 'p', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        't', 'o', 'p', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        't', 'o', 'p', 'o', 'l', 'o', 'g', 'y', '\n',
        't', 'o', 'p', 'p', 'e', 'd', '\n',
        't', 'o', 'p', 'p', 'e', 'r', '\n',
        't', 'o', 'p', 'p', 'i', 'n', 'g', '\n',
        't', 'o', 'p', 'p', 'i', 'n', 'g', 's', '\n',
        't', 'o', 'p', 'p', 'l', 'e', '\n',
        't', 'o', 'p', 'p', 'l', 'e', 'd', '\n',
        't', 'o', 'p', 'p', 'l', 'e', 's', '\n',
        't', 'o', 'p', 'p', 'l', 'i', 'n', 'g', '\n',
        't', 'o', 'p', 's', '\n',
        't', 'o', 'p', 's', 'o', 'i', 'l', '\n',
        't', 'o', 'p', 's', 'p', 'i', 'n', '\n',
        't', 'o', 'p', 's', 'y', 't', 'u', 'r', 'v', 'y', '\n',
        't', 'o', 'r', 'a', 'h', '\n',
        't', 'o', 'r', 'c', 'h', '\n',
        't', 'o', 'r', 'c', 'h', 'b', 'e', 'a', 'r', 'e', 'r', '\n',
        't', 'o', 'r', 'c', 'h', 'b', 'e', 'a', 'r', 'e', 'r', 's', '\n',
        't', 'o', 'r', 'c', 'h', 'e', 'd', '\n',
        't', 'o', 'r', 'c', 'h', 'e', 's', '\n',
        't', 'o', 'r', 'c', 'h', 'l', 'i', 'g', 'h', 't', '\n',
        't', 'o', 'r', 'c', 'h', 'l', 'i', 't', '\n',
        't', 'o', 'r', 'e', '\n',
        't', 'o', 'r', 'i', '\n',
        't', 'o', 'r', 'i', 'e', 's', '\n',
        't', 'o', 'r', 'm', 'e', 'n', 't', '\n',
        't', 'o', 'r', 'm', 'e', 'n', 't', 'e', 'd', '\n',
        't', 'o', 'r', 'm', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        't', 'o', 'r', 'm', 'e', 'n', 't', 'o', 'r', '\n',
        't', 'o', 'r', 'm', 'e', 'n', 't', 'o', 'r', 's', '\n',
        't', 'o', 'r', 'm', 'e', 'n', 't', 's', '\n',
        't', 'o', 'r', 'n', '\n',
        't', 'o', 'r', 'n', 'a', 'd', 'o', '\n',
        't', 'o', 'r', 'o', 'n', 't', 'o', '\n',
        't', 'o', 'r', 'p', 'e', 'd', 'o', '\n',
        't', 'o', 'r', 'p', 'e', 'd', 'o', 'e', 'd', '\n',
        't', 'o', 'r', 'p', 'i', 'd', '\n',
        't', 'o', 'r', 'p', 'o', 'r', '\n',
        't', 'o', 'r', 'q', 'u', 'e', '\n',
        't', 'o', 'r', 'q', 'u', 'e', 's', '\n',
        't', 'o', 'r', 'r', 'e', 'n', 't', '\n',
        't', 'o', 'r', 'r', 'e', 'n', 't', 'i', 'a', 'l', '\n',
        't', 'o', 'r', 'r', 'e', 'n', 't', 's', '\n',
        't', 'o', 'r', 'r', 'i', 'd', '\n',
        't', 'o', 'r', 's', 'i', 'o', 'n', '\n',
        't', 'o', 'r', 's', 'i', 'o', 'n', 'a', 'l', '\n',
        't', 'o', 'r', 's', 'i', 'o', 'n', 's', '\n',
        't', 'o', 'r', 's', 'o', '\n',
        't', 'o', 'r', 't', 'o', 'i', 's', 'e', '\n',
        't', 'o', 'r', 't', 'o', 'i', 's', 'e', 's', '\n',
        't', 'o', 'r', 't', 'o', 'i', 's', 'e', 's', 'h', 'e', 'l', 'l', '\n',
        't', 'o', 'r', 't', 's', '\n',
        't', 'o', 'r', 't', 'u', 'o', 'u', 's', '\n',
        't', 'o', 'r', 't', 'u', 'o', 'u', 's', 'l', 'y', '\n',
        't', 'o', 'r', 't', 'u', 'r', 'e', '\n',
        't', 'o', 'r', 't', 'u', 'r', 'e', 'd', '\n',
        't', 'o', 'r', 't', 'u', 'r', 'e', 'r', '\n',
        't', 'o', 'r', 't', 'u', 'r', 'e', 'r', 's', '\n',
        't', 'o', 'r', 't', 'u', 'r', 'e', 's', '\n',
        't', 'o', 'r', 't', 'u', 'r', 'i', 'n', 'g', '\n',
        't', 'o', 'r', 't', 'u', 'r', 'o', 'u', 's', '\n',
        't', 'o', 'r', 'u', 's', '\n',
        't', 'o', 'r', 'y', '\n',
        't', 'o', 's', 's', '\n',
        't', 'o', 's', 's', 'e', 'd', '\n',
        't', 'o', 's', 's', 'e', 'r', 's', '\n',
        't', 'o', 's', 's', 'e', 's', '\n',
        't', 'o', 's', 's', 'i', 'n', 'g', '\n',
        't', 'o', 's', 's', 'u', 'p', '\n',
        't', 'o', 's', 's', 'u', 'p', 's', '\n',
        't', 'o', 't', '\n',
        't', 'o', 't', 'a', 'l', '\n',
        't', 'o', 't', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        't', 'o', 't', 'a', 'l', 'i', 't', 'a', 'r', 'i', 'a', 'n', '\n',
        't', 'o', 't', 'a', 'l', 'i', 't', 'a', 'r', 'i', 'a', 'n', 'i', 's', 'm', '\n',
        't', 'o', 't', 'a', 'l', 'i', 't', 'y', '\n',
        't', 'o', 't', 'a', 'l', 'l', 'e', 'd', '\n',
        't', 'o', 't', 'a', 'l', 'l', 'i', 'n', 'g', '\n',
        't', 'o', 't', 'a', 'l', 'l', 'y', '\n',
        't', 'o', 't', 'a', 'l', 's', '\n',
        't', 'o', 't', 'e', 'm', '\n',
        't', 'o', 't', 'e', 'm', 'i', 'c', '\n',
        't', 'o', 't', 'e', 'm', 's', '\n',
        't', 'o', 't', 's', '\n',
        't', 'o', 't', 't', 'e', 'd', '\n',
        't', 'o', 't', 't', 'e', 'r', '\n',
        't', 'o', 't', 't', 'e', 'r', 'e', 'd', '\n',
        't', 'o', 't', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        't', 'o', 't', 't', 'e', 'r', 's', '\n',
        't', 'o', 't', 't', 'i', 'n', 'g', '\n',
        't', 'o', 'u', 'c', 'a', 'n', 's', '\n',
        't', 'o', 'u', 'c', 'h', '\n',
        't', 'o', 'u', 'c', 'h', 'a', 'n', 'd', 'g', 'o', '\n',
        't', 'o', 'u', 'c', 'h', 'd', 'o', 'w', 'n', '\n',
        't', 'o', 'u', 'c', 'h', 'd', 'o', 'w', 'n', 's', '\n',
        't', 'o', 'u', 'c', 'h', 'e', '\n',
        't', 'o', 'u', 'c', 'h', 'e', 'd', '\n',
        't', 'o', 'u', 'c', 'h', 'e', 'r', '\n',
        't', 'o', 'u', 'c', 'h', 'e', 's', '\n',
        't', 'o', 'u', 'c', 'h', 'i', 'e', 'r', '\n',
        't', 'o', 'u', 'c', 'h', 'i', 'e', 's', 't', '\n',
        't', 'o', 'u', 'c', 'h', 'i', 'n', 'e', 's', 's', '\n',
        't', 'o', 'u', 'c', 'h', 'i', 'n', 'g', '\n',
        't', 'o', 'u', 'c', 'h', 'i', 'n', 'g', 'l', 'y', '\n',
        't', 'o', 'u', 'c', 'h', 'y', '\n',
        't', 'o', 'u', 'g', 'h', '\n',
        't', 'o', 'u', 'g', 'h', 'e', 'n', '\n',
        't', 'o', 'u', 'g', 'h', 'e', 'n', 'e', 'd', '\n',
        't', 'o', 'u', 'g', 'h', 'e', 'n', 's', '\n',
        't', 'o', 'u', 'g', 'h', 'e', 'r', '\n',
        't', 'o', 'u', 'g', 'h', 'e', 's', 't', '\n',
        't', 'o', 'u', 'g', 'h', 'i', 'e', '\n',
        't', 'o', 'u', 'g', 'h', 'i', 'e', 's', '\n',
        't', 'o', 'u', 'g', 'h', 'l', 'y', '\n',
        't', 'o', 'u', 'g', 'h', 'n', 'e', 's', 's', '\n',
        't', 'o', 'u', 'g', 'h', 's', '\n',
        't', 'o', 'u', 'p', 'e', 'e', '\n',
        't', 'o', 'u', 'r', '\n',
        't', 'o', 'u', 'r', 'e', 'd', '\n',
        't', 'o', 'u', 'r', 'e', 'r', '\n',
        't', 'o', 'u', 'r', 'e', 'r', 's', '\n',
        't', 'o', 'u', 'r', 'i', 'n', 'g', '\n',
        't', 'o', 'u', 'r', 'i', 's', 'm', '\n',
        't', 'o', 'u', 'r', 'i', 's', 't', '\n',
        't', 'o', 'u', 'r', 'i', 's', 't', 'i', 'c', '\n',
        't', 'o', 'u', 'r', 'i', 's', 't', 's', '\n',
        't', 'o', 'u', 'r', 'i', 's', 't', 'y', '\n',
        't', 'o', 'u', 'r', 'n', 'a', 'm', 'e', 'n', 't', '\n',
        't', 'o', 'u', 'r', 'n', 'a', 'm', 'e', 'n', 't', 's', '\n',
        't', 'o', 'u', 'r', 'n', 'e', 'y', '\n',
        't', 'o', 'u', 'r', 'n', 'i', 'q', 'u', 'e', 't', '\n',
        't', 'o', 'u', 'r', 's', '\n',
        't', 'o', 'u', 's', 'l', 'e', 'd', '\n',
        't', 'o', 'u', 's', 'l', 'e', 's', '\n',
        't', 'o', 'u', 't', '\n',
        't', 'o', 'u', 't', 'e', 'd', '\n',
        't', 'o', 'u', 't', 'i', 'n', 'g', '\n',
        't', 'o', 'u', 't', 's', '\n',
        't', 'o', 'w', '\n',
        't', 'o', 'w', 'a', 'r', 'd', '\n',
        't', 'o', 'w', 'a', 'r', 'd', 's', '\n',
        't', 'o', 'w', 'e', 'd', '\n',
        't', 'o', 'w', 'e', 'l', '\n',
        't', 'o', 'w', 'e', 'l', 'l', 'e', 'd', '\n',
        't', 'o', 'w', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        't', 'o', 'w', 'e', 'l', 's', '\n',
        't', 'o', 'w', 'e', 'r', '\n',
        't', 'o', 'w', 'e', 'r', 'e', 'd', '\n',
        't', 'o', 'w', 'e', 'r', 'i', 'n', 'g', '\n',
        't', 'o', 'w', 'e', 'r', 's', '\n',
        't', 'o', 'w', 'i', 'n', 'g', '\n',
        't', 'o', 'w', 'n', '\n',
        't', 'o', 'w', 'n', 's', '\n',
        't', 'o', 'w', 'n', 's', 'c', 'a', 'p', 'e', '\n',
        't', 'o', 'w', 'n', 's', 'c', 'a', 'p', 'e', 's', '\n',
        't', 'o', 'w', 'n', 's', 'f', 'o', 'l', 'k', '\n',
        't', 'o', 'w', 'n', 's', 'h', 'i', 'p', '\n',
        't', 'o', 'w', 'n', 's', 'h', 'i', 'p', 's', '\n',
        't', 'o', 'w', 'n', 's', 'm', 'a', 'n', '\n',
        't', 'o', 'w', 'n', 's', 'm', 'e', 'n', '\n',
        't', 'o', 'w', 'n', 's', 'p', 'e', 'o', 'p', 'l', 'e', '\n',
        't', 'o', 'w', 'p', 'a', 't', 'h', '\n',
        't', 'o', 'w', 'p', 'a', 't', 'h', 's', '\n',
        't', 'o', 'w', 's', '\n',
        't', 'o', 'x', 'a', 'e', 'm', 'i', 'a', '\n',
        't', 'o', 'x', 'i', 'c', '\n',
        't', 'o', 'x', 'i', 'c', 'i', 't', 'y', '\n',
        't', 'o', 'x', 'i', 'c', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        't', 'o', 'x', 'i', 'c', 'o', 'l', 'o', 'g', 'y', '\n',
        't', 'o', 'x', 'i', 'n', '\n',
        't', 'o', 'x', 'i', 'n', 's', '\n',
        't', 'o', 'y', '\n',
        't', 'o', 'y', 'e', 'd', '\n',
        't', 'o', 'y', 'i', 'n', 'g', '\n',
        't', 'o', 'y', 'm', 'a', 'k', 'e', 'r', '\n',
        't', 'o', 'y', 's', '\n',
        't', 'o', 'y', 's', 'h', 'o', 'p', '\n',
        't', 'r', 'a', 'c', 'e', '\n',
        't', 'r', 'a', 'c', 'e', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        't', 'r', 'a', 'c', 'e', 'a', 'b', 'l', 'e', '\n',
        't', 'r', 'a', 'c', 'e', 'd', '\n',
        't', 'r', 'a', 'c', 'e', 'l', 'e', 's', 's', '\n',
        't', 'r', 'a', 'c', 'e', 'r', '\n',
        't', 'r', 'a', 'c', 'e', 'r', 's', '\n',
        't', 'r', 'a', 'c', 'e', 'r', 'y', '\n',
        't', 'r', 'a', 'c', 'e', 's', '\n',
        't', 'r', 'a', 'c', 'h', 'e', 'a', '\n',
        't', 'r', 'a', 'c', 'h', 'e', 'a', 'l', '\n',
        't', 'r', 'a', 'c', 'h', 'e', 'o', 's', 't', 'o', 'm', 'y', '\n',
        't', 'r', 'a', 'c', 'h', 'e', 'o', 't', 'o', 'm', 'y', '\n',
        't', 'r', 'a', 'c', 'i', 'n', 'g', '\n',
        't', 'r', 'a', 'c', 'i', 'n', 'g', 's', '\n',
        't', 'r', 'a', 'c', 'k', '\n',
        't', 'r', 'a', 'c', 'k', 'b', 'e', 'd', '\n',
        't', 'r', 'a', 'c', 'k', 'e', 'd', '\n',
        't', 'r', 'a', 'c', 'k', 'e', 'r', '\n',
        't', 'r', 'a', 'c', 'k', 'e', 'r', 's', '\n',
        't', 'r', 'a', 'c', 'k', 'i', 'n', 'g', '\n',
        't', 'r', 'a', 'c', 'k', 'l', 'e', 's', 's', '\n',
        't', 'r', 'a', 'c', 'k', 's', '\n',
        't', 'r', 'a', 'c', 'k', 's', 'u', 'i', 't', '\n',
        't', 'r', 'a', 'c', 'k', 's', 'u', 'i', 't', 's', '\n',
        't', 'r', 'a', 'c', 'k', 'w', 'a', 'y', '\n',
        't', 'r', 'a', 'c', 'k', 'w', 'a', 'y', 's', '\n',
        't', 'r', 'a', 'c', 't', '\n',
        't', 'r', 'a', 'c', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        't', 'r', 'a', 'c', 't', 'a', 'b', 'l', 'e', '\n',
        't', 'r', 'a', 'c', 't', 'i', 'o', 'n', '\n',
        't', 'r', 'a', 'c', 't', 'o', 'r', '\n',
        't', 'r', 'a', 'c', 't', 'o', 'r', 's', '\n',
        't', 'r', 'a', 'c', 't', 's', '\n',
        't', 'r', 'a', 'd', '\n',
        't', 'r', 'a', 'd', 'e', '\n',
        't', 'r', 'a', 'd', 'e', 'a', 'b', 'l', 'e', '\n',
        't', 'r', 'a', 'd', 'e', 'd', '\n',
        't', 'r', 'a', 'd', 'e', 'i', 'n', '\n',
        't', 'r', 'a', 'd', 'e', 'i', 'n', 's', '\n',
        't', 'r', 'a', 'd', 'e', 'm', 'a', 'r', 'k', '\n',
        't', 'r', 'a', 'd', 'e', 'm', 'a', 'r', 'k', 'e', 'd', '\n',
        't', 'r', 'a', 'd', 'e', 'm', 'a', 'r', 'k', 's', '\n',
        't', 'r', 'a', 'd', 'e', 'r', '\n',
        't', 'r', 'a', 'd', 'e', 'r', 's', '\n',
        't', 'r', 'a', 'd', 'e', 's', '\n',
        't', 'r', 'a', 'd', 'e', 's', 'm', 'a', 'n', '\n',
        't', 'r', 'a', 'd', 'e', 's', 'm', 'e', 'n', '\n',
        't', 'r', 'a', 'd', 'e', 's', 'p', 'e', 'o', 'p', 'l', 'e', '\n',
        't', 'r', 'a', 'd', 'i', 'n', 'g', '\n',
        't', 'r', 'a', 'd', 'i', 'n', 'g', 's', '\n',
        't', 'r', 'a', 'd', 'i', 't', 'i', 'o', 'n', '\n',
        't', 'r', 'a', 'd', 'i', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        't', 'r', 'a', 'd', 'i', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 'm', '\n',
        't', 'r', 'a', 'd', 'i', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 't', '\n',
        't', 'r', 'a', 'd', 'i', 't', 'i', 'o', 'n', 'a', 'l', 'i', 's', 't', 's', '\n',
        't', 'r', 'a', 'd', 'i', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        't', 'r', 'a', 'd', 'i', 't', 'i', 'o', 'n', 's', '\n',
        't', 'r', 'a', 'd', 'u', 'c', 'e', 'd', '\n',
        't', 'r', 'a', 'd', 'u', 'c', 'e', 'r', '\n',
        't', 'r', 'a', 'f', 'f', 'i', 'c', '\n',
        't', 'r', 'a', 'f', 'f', 'i', 'c', 'k', 'e', 'd', '\n',
        't', 'r', 'a', 'f', 'f', 'i', 'c', 'k', 'e', 'r', '\n',
        't', 'r', 'a', 'f', 'f', 'i', 'c', 'k', 'e', 'r', 's', '\n',
        't', 'r', 'a', 'f', 'f', 'i', 'c', 'k', 'i', 'n', 'g', '\n',
        't', 'r', 'a', 'g', 'e', 'd', 'i', 'a', 'n', '\n',
        't', 'r', 'a', 'g', 'e', 'd', 'i', 'a', 'n', 's', '\n',
        't', 'r', 'a', 'g', 'e', 'd', 'i', 'e', 's', '\n',
        't', 'r', 'a', 'g', 'e', 'd', 'y', '\n',
        't', 'r', 'a', 'g', 'i', 'c', '\n',
        't', 'r', 'a', 'g', 'i', 'c', 'a', 'l', '\n',
        't', 'r', 'a', 'g', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        't', 'r', 'a', 'i', 'l', '\n',
        't', 'r', 'a', 'i', 'l', 'e', 'd', '\n',
        't', 'r', 'a', 'i', 'l', 'e', 'r', '\n',
        't', 'r', 'a', 'i', 'l', 'e', 'r', 's', '\n',
        't', 'r', 'a', 'i', 'l', 'i', 'n', 'g', '\n',
        't', 'r', 'a', 'i', 'l', 's', '\n',
        't', 'r', 'a', 'i', 'n', '\n',
        't', 'r', 'a', 'i', 'n', 'e', 'd', '\n',
        't', 'r', 'a', 'i', 'n', 'e', 'e', '\n',
        't', 'r', 'a', 'i', 'n', 'e', 'e', 's', '\n',
        't', 'r', 'a', 'i', 'n', 'e', 'r', '\n',
        't', 'r', 'a', 'i', 'n', 'e', 'r', 's', '\n',
        't', 'r', 'a', 'i', 'n', 'i', 'n', 'g', '\n',
        't', 'r', 'a', 'i', 'n', 'i', 'n', 'g', 's', '\n',
        't', 'r', 'a', 'i', 'n', 'l', 'o', 'a', 'd', '\n',
        't', 'r', 'a', 'i', 'n', 's', '\n',
        't', 'r', 'a', 'i', 't', '\n',
        't', 'r', 'a', 'i', 't', 'o', 'r', '\n',
        't', 'r', 'a', 'i', 't', 'o', 'r', 'o', 'u', 's', '\n',
        't', 'r', 'a', 'i', 't', 'o', 'r', 'o', 'u', 's', 'l', 'y', '\n',
        't', 'r', 'a', 'i', 't', 'o', 'r', 's', '\n',
        't', 'r', 'a', 'i', 't', 's', '\n',
        't', 'r', 'a', 'j', 'e', 'c', 't', 'o', 'r', 'i', 'e', 's', '\n',
        't', 'r', 'a', 'j', 'e', 'c', 't', 'o', 'r', 'y', '\n',
        't', 'r', 'a', 'm', '\n',
        't', 'r', 'a', 'm', 'c', 'a', 'r', '\n',
        't', 'r', 'a', 'm', 'c', 'a', 'r', 's', '\n',
        't', 'r', 'a', 'm', 'l', 'i', 'n', 'e', 's', '\n',
        't', 'r', 'a', 'm', 'm', 'e', 'l', '\n',
        't', 'r', 'a', 'm', 'p', '\n',
        't', 'r', 'a', 'm', 'p', 'e', 'd', '\n',
        't', 'r', 'a', 'm', 'p', 'i', 'n', 'g', '\n',
        't', 'r', 'a', 'm', 'p', 'l', 'e', '\n',
        't', 'r', 'a', 'm', 'p', 'l', 'e', 'd', '\n',
        't', 'r', 'a', 'm', 'p', 'l', 'e', 's', '\n',
        't', 'r', 'a', 'm', 'p', 'l', 'i', 'n', 'g', '\n',
        't', 'r', 'a', 'm', 'p', 'o', 'l', 'i', 'n', 'e', '\n',
        't', 'r', 'a', 'm', 'p', 'o', 'l', 'i', 'n', 'e', 's', '\n',
        't', 'r', 'a', 'm', 'p', 'o', 'l', 'i', 'n', 'i', 'n', 'g', '\n',
        't', 'r', 'a', 'm', 'p', 'o', 'l', 'i', 'n', 'i', 's', 't', '\n',
        't', 'r', 'a', 'm', 'p', 's', '\n',
        't', 'r', 'a', 'm', 's', '\n',
        't', 'r', 'a', 'm', 'w', 'a', 'y', '\n',
        't', 'r', 'a', 'm', 'w', 'a', 'y', 's', '\n',
        't', 'r', 'a', 'n', 'c', 'e', '\n',
        't', 'r', 'a', 'n', 'c', 'e', 's', '\n',
        't', 'r', 'a', 'n', 'c', 'h', 'e', '\n',
        't', 'r', 'a', 'n', 'c', 'h', 'e', 's', '\n',
        't', 'r', 'a', 'n', 'n', 'y', '\n',
        't', 'r', 'a', 'n', 'q', 'u', 'i', 'l', '\n',
        't', 'r', 'a', 'n', 'q', 'u', 'i', 'l', 'l', 'i', 's', 'e', '\n',
        't', 'r', 'a', 'n', 'q', 'u', 'i', 'l', 'l', 'i', 's', 'e', 'd', '\n',
        't', 'r', 'a', 'n', 'q', 'u', 'i', 'l', 'l', 'i', 's', 'e', 'r', '\n',
        't', 'r', 'a', 'n', 'q', 'u', 'i', 'l', 'l', 'i', 's', 'e', 'r', 's', '\n',
        't', 'r', 'a', 'n', 'q', 'u', 'i', 'l', 'l', 'i', 't', 'y', '\n',
        't', 'r', 'a', 'n', 'q', 'u', 'i', 'l', 'l', 'y', '\n',
        't', 'r', 'a', 'n', 's', 'a', 'c', 't', '\n',
        't', 'r', 'a', 'n', 's', 'a', 'c', 't', 'e', 'd', '\n',
        't', 'r', 'a', 'n', 's', 'a', 'c', 't', 'i', 'n', 'g', '\n',
        't', 'r', 'a', 'n', 's', 'a', 'c', 't', 'i', 'o', 'n', '\n',
        't', 'r', 'a', 'n', 's', 'a', 'c', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        't', 'r', 'a', 'n', 's', 'a', 'c', 't', 'i', 'o', 'n', 's', '\n',
        't', 'r', 'a', 'n', 's', 'a', 'c', 't', 'o', 'r', '\n',
        't', 'r', 'a', 'n', 's', 'a', 't', 'l', 'a', 'n', 't', 'i', 'c', '\n',
        't', 'r', 'a', 'n', 's', 'c', 'e', 'i', 'v', 'e', 'r', '\n',
        't', 'r', 'a', 'n', 's', 'c', 'e', 'i', 'v', 'e', 'r', 's', '\n',
        't', 'r', 'a', 'n', 's', 'c', 'e', 'n', 'd', '\n',
        't', 'r', 'a', 'n', 's', 'c', 'e', 'n', 'd', 'e', 'd', '\n',
        't', 'r', 'a', 'n', 's', 'c', 'e', 'n', 'd', 'e', 'n', 'c', 'e', '\n',
        't', 'r', 'a', 'n', 's', 'c', 'e', 'n', 'd', 'e', 'n', 't', '\n',
        't', 'r', 'a', 'n', 's', 'c', 'e', 'n', 'd', 'e', 'n', 't', 'a', 'l', '\n',
        't', 'r', 'a', 'n', 's', 'c', 'e', 'n', 'd', 'e', 'n', 't', 'a', 'l', 'l', 'y', '\n',
        't', 'r', 'a', 'n', 's', 'c', 'e', 'n', 'd', 'e', 'n', 't', 'a', 'l', 's', '\n',
        't', 'r', 'a', 'n', 's', 'c', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        't', 'r', 'a', 'n', 's', 'c', 'e', 'n', 'd', 's', '\n',
        't', 'r', 'a', 'n', 's', 'c', 'o', 'n', 't', 'i', 'n', 'e', 'n', 't', 'a', 'l', '\n',
        't', 'r', 'a', 'n', 's', 'c', 'r', 'i', 'b', 'e', '\n',
        't', 'r', 'a', 'n', 's', 'c', 'r', 'i', 'b', 'e', 'd', '\n',
        't', 'r', 'a', 'n', 's', 'c', 'r', 'i', 'b', 'e', 'r', '\n',
        't', 'r', 'a', 'n', 's', 'c', 'r', 'i', 'b', 'e', 'r', 's', '\n',
        't', 'r', 'a', 'n', 's', 'c', 'r', 'i', 'b', 'e', 's', '\n',
        't', 'r', 'a', 'n', 's', 'c', 'r', 'i', 'b', 'i', 'n', 'g', '\n',
        't', 'r', 'a', 'n', 's', 'c', 'r', 'i', 'p', 't', '\n',
        't', 'r', 'a', 'n', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', '\n',
        't', 'r', 'a', 'n', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        't', 'r', 'a', 'n', 's', 'c', 'r', 'i', 'p', 't', 'i', 'o', 'n', 's', '\n',
        't', 'r', 'a', 'n', 's', 'c', 'r', 'i', 'p', 't', 's', '\n',
        't', 'r', 'a', 'n', 's', 'd', 'u', 'c', 'e', 'r', '\n',
        't', 'r', 'a', 'n', 's', 'd', 'u', 'c', 'e', 'r', 's', '\n',
        't', 'r', 'a', 'n', 's', 'd', 'u', 'c', 't', 'i', 'o', 'n', '\n',
        't', 'r', 'a', 'n', 's', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        't', 'r', 'a', 'n', 's', 'e', 'p', 't', '\n',
        't', 'r', 'a', 'n', 's', 'e', 'p', 't', 's', '\n',
        't', 'r', 'a', 'n', 's', 'f', 'e', 'r', '\n',
        't', 'r', 'a', 'n', 's', 'f', 'e', 'r', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        't', 'r', 'a', 'n', 's', 'f', 'e', 'r', 'a', 'b', 'l', 'e', '\n',
        't', 'r', 'a', 'n', 's', 'f', 'e', 'r', 'e', 'e', '\n',
        't', 'r', 'a', 'n', 's', 'f', 'e', 'r', 'e', 'e', 's', '\n',
        't', 'r', 'a', 'n', 's', 'f', 'e', 'r', 'e', 'n', 'c', 'e', '\n',
        't', 'r', 'a', 'n', 's', 'f', 'e', 'r', 'r', 'a', 'l', '\n',
        't', 'r', 'a', 'n', 's', 'f', 'e', 'r', 'r', 'e', 'd', '\n',
        't', 'r', 'a', 'n', 's', 'f', 'e', 'r', 'r', 'i', 'n', 'g', '\n',
        't', 'r', 'a', 'n', 's', 'f', 'e', 'r', 's', '\n',
        't', 'r', 'a', 'n', 's', 'f', 'i', 'g', 'u', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        't', 'r', 'a', 'n', 's', 'f', 'i', 'g', 'u', 'r', 'e', 'd', '\n',
        't', 'r', 'a', 'n', 's', 'f', 'i', 'n', 'i', 't', 'e', '\n',
        't', 'r', 'a', 'n', 's', 'f', 'i', 'n', 'i', 't', 'e', 'l', 'y', '\n',
        't', 'r', 'a', 'n', 's', 'f', 'i', 'x', 'e', 'd', '\n',
        't', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', '\n',
        't', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', '\n',
        't', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        't', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'o', 'n', 's', '\n',
        't', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'v', 'e', '\n',
        't', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'e', 'd', '\n',
        't', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'e', 'r', '\n',
        't', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'e', 'r', 's', '\n',
        't', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'i', 'n', 'g', '\n',
        't', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 's', '\n',
        't', 'r', 'a', 'n', 's', 'f', 'u', 's', 'e', 'd', '\n',
        't', 'r', 'a', 'n', 's', 'f', 'u', 's', 'i', 'n', 'g', '\n',
        't', 'r', 'a', 'n', 's', 'f', 'u', 's', 'i', 'o', 'n', '\n',
        't', 'r', 'a', 'n', 's', 'f', 'u', 's', 'i', 'o', 'n', 's', '\n',
        't', 'r', 'a', 'n', 's', 'g', 'r', 'e', 's', 's', '\n',
        't', 'r', 'a', 'n', 's', 'g', 'r', 'e', 's', 's', 'e', 'd', '\n',
        't', 'r', 'a', 'n', 's', 'g', 'r', 'e', 's', 's', 'e', 's', '\n',
        't', 'r', 'a', 'n', 's', 'g', 'r', 'e', 's', 's', 'i', 'n', 'g', '\n',
        't', 'r', 'a', 'n', 's', 'g', 'r', 'e', 's', 's', 'i', 'o', 'n', '\n',
        't', 'r', 'a', 'n', 's', 'g', 'r', 'e', 's', 's', 'i', 'o', 'n', 's', '\n',
        't', 'r', 'a', 'n', 's', 'g', 'r', 'e', 's', 's', 'i', 'v', 'e', '\n',
        't', 'r', 'a', 'n', 's', 'g', 'r', 'e', 's', 's', 'o', 'r', '\n',
        't', 'r', 'a', 'n', 's', 'g', 'r', 'e', 's', 's', 'o', 'r', 's', '\n',
        't', 'r', 'a', 'n', 's', 'h', 'i', 'p', 'm', 'e', 'n', 't', '\n',
        't', 'r', 'a', 'n', 's', 'i', 'e', 'n', 'c', 'e', '\n',
        't', 'r', 'a', 'n', 's', 'i', 'e', 'n', 't', '\n',
        't', 'r', 'a', 'n', 's', 'i', 'e', 'n', 't', 'l', 'y', '\n',
        't', 'r', 'a', 'n', 's', 'i', 'e', 'n', 't', 's', '\n',
        't', 'r', 'a', 'n', 's', 'i', 's', 't', 'o', 'r', '\n',
        't', 'r', 'a', 'n', 's', 'i', 's', 't', 'o', 'r', 'i', 's', 'e', 'd', '\n',
        't', 'r', 'a', 'n', 's', 'i', 's', 't', 'o', 'r', 's', '\n',
        't', 'r', 'a', 'n', 's', 'i', 't', '\n',
        't', 'r', 'a', 'n', 's', 'i', 't', 'i', 'o', 'n', '\n',
        't', 'r', 'a', 'n', 's', 'i', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        't', 'r', 'a', 'n', 's', 'i', 't', 'i', 'o', 'n', 's', '\n',
        't', 'r', 'a', 'n', 's', 'i', 't', 'i', 'v', 'e', '\n',
        't', 'r', 'a', 'n', 's', 'i', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        't', 'r', 'a', 'n', 's', 'i', 't', 'i', 'v', 'i', 't', 'y', '\n',
        't', 'r', 'a', 'n', 's', 'i', 't', 'o', 'r', 'i', 'n', 'e', 's', 's', '\n',
        't', 'r', 'a', 'n', 's', 'i', 't', 'o', 'r', 'y', '\n',
        't', 'r', 'a', 'n', 's', 'i', 't', 's', '\n',
        't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'a', 'b', 'l', 'e', '\n',
        't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'e', '\n',
        't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'e', 'd', '\n',
        't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'e', 's', '\n',
        't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'o', 'r', '\n',
        't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'o', 'r', 's', '\n',
        't', 'r', 'a', 'n', 's', 'l', 'i', 't', 'e', 'r', 'a', 't', 'e', '\n',
        't', 'r', 'a', 'n', 's', 'l', 'i', 't', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        't', 'r', 'a', 'n', 's', 'l', 'i', 't', 'e', 'r', 'a', 't', 'e', 's', '\n',
        't', 'r', 'a', 'n', 's', 'l', 'i', 't', 'e', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        't', 'r', 'a', 'n', 's', 'l', 'i', 't', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        't', 'r', 'a', 'n', 's', 'l', 'i', 't', 'e', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        't', 'r', 'a', 'n', 's', 'l', 'u', 'c', 'e', 'n', 'c', 'e', '\n',
        't', 'r', 'a', 'n', 's', 'l', 'u', 'c', 'e', 'n', 'c', 'y', '\n',
        't', 'r', 'a', 'n', 's', 'l', 'u', 'c', 'e', 'n', 't', '\n',
        't', 'r', 'a', 'n', 's', 'm', 'i', 'g', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        't', 'r', 'a', 'n', 's', 'm', 'i', 's', 's', 'i', 'b', 'l', 'e', '\n',
        't', 'r', 'a', 'n', 's', 'm', 'i', 's', 's', 'i', 'o', 'n', '\n',
        't', 'r', 'a', 'n', 's', 'm', 'i', 's', 's', 'i', 'o', 'n', 's', '\n',
        't', 'r', 'a', 'n', 's', 'm', 'i', 's', 's', 'i', 'v', 'e', '\n',
        't', 'r', 'a', 'n', 's', 'm', 'i', 't', '\n',
        't', 'r', 'a', 'n', 's', 'm', 'i', 't', 's', '\n',
        't', 'r', 'a', 'n', 's', 'm', 'i', 't', 't', 'a', 'b', 'l', 'e', '\n',
        't', 'r', 'a', 'n', 's', 'm', 'i', 't', 't', 'a', 'n', 'c', 'e', '\n',
        't', 'r', 'a', 'n', 's', 'm', 'i', 't', 't', 'e', 'd', '\n',
        't', 'r', 'a', 'n', 's', 'm', 'i', 't', 't', 'e', 'r', '\n',
        't', 'r', 'a', 'n', 's', 'm', 'i', 't', 't', 'e', 'r', 's', '\n',
        't', 'r', 'a', 'n', 's', 'm', 'i', 't', 't', 'i', 'n', 'g', '\n',
        't', 'r', 'a', 'n', 's', 'm', 'o', 'g', 'r', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        't', 'r', 'a', 'n', 's', 'm', 'o', 'g', 'r', 'i', 'f', 'i', 'e', 's', '\n',
        't', 'r', 'a', 'n', 's', 'm', 'o', 'g', 'r', 'i', 'f', 'y', '\n',
        't', 'r', 'a', 'n', 's', 'm', 'u', 't', 'a', 't', 'i', 'o', 'n', '\n',
        't', 'r', 'a', 'n', 's', 'm', 'u', 't', 'e', '\n',
        't', 'r', 'a', 'n', 's', 'm', 'u', 't', 'e', 'd', '\n',
        't', 'r', 'a', 'n', 's', 'm', 'u', 't', 'i', 'n', 'g', '\n',
        't', 'r', 'a', 'n', 's', 'n', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        't', 'r', 'a', 'n', 's', 'o', 'm', '\n',
        't', 'r', 'a', 'n', 's', 'o', 'n', 'i', 'c', '\n',
        't', 'r', 'a', 'n', 's', 'p', 'a', 'r', 'e', 'n', 'c', 'i', 'e', 's', '\n',
        't', 'r', 'a', 'n', 's', 'p', 'a', 'r', 'e', 'n', 'c', 'y', '\n',
        't', 'r', 'a', 'n', 's', 'p', 'a', 'r', 'e', 'n', 't', '\n',
        't', 'r', 'a', 'n', 's', 'p', 'a', 'r', 'e', 'n', 't', 'l', 'y', '\n',
        't', 'r', 'a', 'n', 's', 'p', 'i', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        't', 'r', 'a', 'n', 's', 'p', 'i', 'r', 'e', '\n',
        't', 'r', 'a', 'n', 's', 'p', 'i', 'r', 'e', 'd', '\n',
        't', 'r', 'a', 'n', 's', 'p', 'i', 'r', 'e', 's', '\n',
        't', 'r', 'a', 'n', 's', 'p', 'l', 'a', 'n', 't', '\n',
        't', 'r', 'a', 'n', 's', 'p', 'l', 'a', 'n', 't', 'a', 't', 'i', 'o', 'n', '\n',
        't', 'r', 'a', 'n', 's', 'p', 'l', 'a', 'n', 't', 'e', 'd', '\n',
        't', 'r', 'a', 'n', 's', 'p', 'l', 'a', 'n', 't', 'i', 'n', 'g', '\n',
        't', 'r', 'a', 'n', 's', 'p', 'l', 'a', 'n', 't', 's', '\n',
        't', 'r', 'a', 'n', 's', 'p', 'o', 'n', 'd', 'e', 'r', '\n',
        't', 'r', 'a', 'n', 's', 'p', 'o', 'n', 'd', 'e', 'r', 's', '\n',
        't', 'r', 'a', 'n', 's', 'p', 'o', 'r', 't', '\n',
        't', 'r', 'a', 'n', 's', 'p', 'o', 'r', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        't', 'r', 'a', 'n', 's', 'p', 'o', 'r', 't', 'a', 'b', 'l', 'e', '\n',
        't', 'r', 'a', 'n', 's', 'p', 'o', 'r', 't', 'a', 't', 'i', 'o', 'n', '\n',
        't', 'r', 'a', 'n', 's', 'p', 'o', 'r', 't', 'e', 'd', '\n',
        't', 'r', 'a', 'n', 's', 'p', 'o', 'r', 't', 'e', 'r', '\n',
        't', 'r', 'a', 'n', 's', 'p', 'o', 'r', 't', 'e', 'r', 's', '\n',
        't', 'r', 'a', 'n', 's', 'p', 'o', 'r', 't', 'i', 'n', 'g', '\n',
        't', 'r', 'a', 'n', 's', 'p', 'o', 'r', 't', 's', '\n',
        't', 'r', 'a', 'n', 's', 'p', 'o', 's', 'e', '\n',
        't', 'r', 'a', 'n', 's', 'p', 'o', 's', 'e', 'd', '\n',
        't', 'r', 'a', 'n', 's', 'p', 'o', 's', 'e', 's', '\n',
        't', 'r', 'a', 'n', 's', 'p', 'o', 's', 'i', 'n', 'g', '\n',
        't', 'r', 'a', 'n', 's', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', '\n',
        't', 'r', 'a', 'n', 's', 'p', 'o', 's', 'i', 't', 'i', 'o', 'n', 's', '\n',
        't', 'r', 'a', 'n', 's', 'v', 'e', 'r', 's', 'e', '\n',
        't', 'r', 'a', 'n', 's', 'v', 'e', 'r', 's', 'e', 'l', 'y', '\n',
        't', 'r', 'a', 'n', 's', 'v', 'e', 's', 't', 'i', 's', 'm', '\n',
        't', 'r', 'a', 'n', 's', 'v', 'e', 's', 't', 'i', 't', 'e', '\n',
        't', 'r', 'a', 'n', 's', 'v', 'e', 's', 't', 'i', 't', 'e', 's', '\n',
        't', 'r', 'a', 'p', '\n',
        't', 'r', 'a', 'p', 'd', 'o', 'o', 'r', '\n',
        't', 'r', 'a', 'p', 'd', 'o', 'o', 'r', 's', '\n',
        't', 'r', 'a', 'p', 'e', 'z', 'e', '\n',
        't', 'r', 'a', 'p', 'p', 'a', 'b', 'l', 'e', '\n',
        't', 'r', 'a', 'p', 'p', 'e', 'd', '\n',
        't', 'r', 'a', 'p', 'p', 'e', 'r', '\n',
        't', 'r', 'a', 'p', 'p', 'e', 'r', 's', '\n',
        't', 'r', 'a', 'p', 'p', 'i', 'n', 'g', '\n',
        't', 'r', 'a', 'p', 'p', 'i', 'n', 'g', 's', '\n',
        't', 'r', 'a', 'p', 's', '\n',
        't', 'r', 'a', 's', 'h', '\n',
        't', 'r', 'a', 's', 'h', 'e', 'd', '\n',
        't', 'r', 'a', 's', 'h', 'y', '\n',
        't', 'r', 'a', 'u', 'm', 'a', '\n',
        't', 'r', 'a', 'u', 'm', 'a', 's', '\n',
        't', 'r', 'a', 'u', 'm', 'a', 't', 'a', '\n',
        't', 'r', 'a', 'u', 'm', 'a', 't', 'i', 'c', '\n',
        't', 'r', 'a', 'u', 'm', 'a', 't', 'i', 's', 'e', '\n',
        't', 'r', 'a', 'u', 'm', 'a', 't', 'i', 's', 'e', 'd', '\n',
        't', 'r', 'a', 'v', 'a', 'i', 'l', '\n',
        't', 'r', 'a', 'v', 'a', 'i', 'l', 's', '\n',
        't', 'r', 'a', 'v', 'e', 'l', '\n',
        't', 'r', 'a', 'v', 'e', 'l', 'l', 'e', 'd', '\n',
        't', 'r', 'a', 'v', 'e', 'l', 'l', 'e', 'r', '\n',
        't', 'r', 'a', 'v', 'e', 'l', 'l', 'e', 'r', 's', '\n',
        't', 'r', 'a', 'v', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        't', 'r', 'a', 'v', 'e', 'l', 'o', 'g', 'u', 'e', '\n',
        't', 'r', 'a', 'v', 'e', 'l', 'o', 'g', 'u', 'e', 's', '\n',
        't', 'r', 'a', 'v', 'e', 'l', 's', '\n',
        't', 'r', 'a', 'v', 'e', 'r', 's', 'a', 'l', '\n',
        't', 'r', 'a', 'v', 'e', 'r', 's', 'a', 'l', 's', '\n',
        't', 'r', 'a', 'v', 'e', 'r', 's', 'e', '\n',
        't', 'r', 'a', 'v', 'e', 'r', 's', 'e', 'd', '\n',
        't', 'r', 'a', 'v', 'e', 'r', 's', 'e', 's', '\n',
        't', 'r', 'a', 'v', 'e', 'r', 's', 'i', 'n', 'g', '\n',
        't', 'r', 'a', 'v', 'e', 's', 't', 'i', 'e', 's', '\n',
        't', 'r', 'a', 'v', 'e', 's', 't', 'y', '\n',
        't', 'r', 'a', 'w', 'l', '\n',
        't', 'r', 'a', 'w', 'l', 'e', 'd', '\n',
        't', 'r', 'a', 'w', 'l', 'e', 'r', '\n',
        't', 'r', 'a', 'w', 'l', 'e', 'r', 's', '\n',
        't', 'r', 'a', 'w', 'l', 'i', 'n', 'g', '\n',
        't', 'r', 'a', 'w', 'l', 'n', 'e', 't', '\n',
        't', 'r', 'a', 'w', 'l', 's', '\n',
        't', 'r', 'a', 'y', '\n',
        't', 'r', 'a', 'y', 's', '\n',
        't', 'r', 'e', 'a', 'c', 'h', 'e', 'r', 'o', 'u', 's', '\n',
        't', 'r', 'e', 'a', 'c', 'h', 'e', 'r', 'o', 'u', 's', 'l', 'y', '\n',
        't', 'r', 'e', 'a', 'c', 'h', 'e', 'r', 'y', '\n',
        't', 'r', 'e', 'a', 'c', 'l', 'e', '\n',
        't', 'r', 'e', 'a', 'd', '\n',
        't', 'r', 'e', 'a', 'd', 'e', 'r', '\n',
        't', 'r', 'e', 'a', 'd', 'i', 'n', 'g', '\n',
        't', 'r', 'e', 'a', 'd', 'l', 'e', '\n',
        't', 'r', 'e', 'a', 'd', 'm', 'i', 'l', 'l', '\n',
        't', 'r', 'e', 'a', 'd', 'm', 'i', 'l', 'l', 's', '\n',
        't', 'r', 'e', 'a', 'd', 's', '\n',
        't', 'r', 'e', 'a', 's', 'o', 'n', '\n',
        't', 'r', 'e', 'a', 's', 'o', 'n', 'a', 'b', 'l', 'e', '\n',
        't', 'r', 'e', 'a', 's', 'o', 'n', 'o', 'u', 's', '\n',
        't', 'r', 'e', 'a', 's', 'o', 'n', 's', '\n',
        't', 'r', 'e', 'a', 's', 'u', 'r', 'e', '\n',
        't', 'r', 'e', 'a', 's', 'u', 'r', 'e', 'd', '\n',
        't', 'r', 'e', 'a', 's', 'u', 'r', 'e', 'r', '\n',
        't', 'r', 'e', 'a', 's', 'u', 'r', 'e', 'r', 's', '\n',
        't', 'r', 'e', 'a', 's', 'u', 'r', 'e', 'r', 's', 'h', 'i', 'p', '\n',
        't', 'r', 'e', 'a', 's', 'u', 'r', 'e', 's', '\n',
        't', 'r', 'e', 'a', 's', 'u', 'r', 'i', 'e', 's', '\n',
        't', 'r', 'e', 'a', 's', 'u', 'r', 'i', 'n', 'g', '\n',
        't', 'r', 'e', 'a', 's', 'u', 'r', 'y', '\n',
        't', 'r', 'e', 'a', 't', '\n',
        't', 'r', 'e', 'a', 't', 'a', 'b', 'l', 'e', '\n',
        't', 'r', 'e', 'a', 't', 'e', 'd', '\n',
        't', 'r', 'e', 'a', 't', 'i', 'e', 's', '\n',
        't', 'r', 'e', 'a', 't', 'i', 'n', 'g', '\n',
        't', 'r', 'e', 'a', 't', 'i', 's', 'e', '\n',
        't', 'r', 'e', 'a', 't', 'i', 's', 'e', 's', '\n',
        't', 'r', 'e', 'a', 't', 'm', 'e', 'n', 't', '\n',
        't', 'r', 'e', 'a', 't', 'm', 'e', 'n', 't', 's', '\n',
        't', 'r', 'e', 'a', 't', 's', '\n',
        't', 'r', 'e', 'a', 't', 'y', '\n',
        't', 'r', 'e', 'b', 'l', 'e', '\n',
        't', 'r', 'e', 'b', 'l', 'e', 'd', '\n',
        't', 'r', 'e', 'b', 'l', 'e', 's', '\n',
        't', 'r', 'e', 'b', 'l', 'i', 'n', 'g', '\n',
        't', 'r', 'e', 'e', '\n',
        't', 'r', 'e', 'e', 'l', 'e', 's', 's', '\n',
        't', 'r', 'e', 'e', 's', '\n',
        't', 'r', 'e', 'e', 't', 'o', 'p', '\n',
        't', 'r', 'e', 'e', 't', 'o', 'p', 's', '\n',
        't', 'r', 'e', 'f', 'o', 'i', 'l', '\n',
        't', 'r', 'e', 'f', 'o', 'i', 'l', 's', '\n',
        't', 'r', 'e', 'k', '\n',
        't', 'r', 'e', 'k', 'k', 'e', 'd', '\n',
        't', 'r', 'e', 'k', 'k', 'e', 'r', '\n',
        't', 'r', 'e', 'k', 'k', 'e', 'r', 's', '\n',
        't', 'r', 'e', 'k', 'k', 'i', 'n', 'g', '\n',
        't', 'r', 'e', 'k', 's', '\n',
        't', 'r', 'e', 'l', 'l', 'i', 's', '\n',
        't', 'r', 'e', 'l', 'l', 'i', 's', 'e', 'd', '\n',
        't', 'r', 'e', 'l', 'l', 'i', 's', 'e', 's', '\n',
        't', 'r', 'e', 'm', 'b', 'l', 'e', '\n',
        't', 'r', 'e', 'm', 'b', 'l', 'e', 'd', '\n',
        't', 'r', 'e', 'm', 'b', 'l', 'e', 'r', '\n',
        't', 'r', 'e', 'm', 'b', 'l', 'e', 's', '\n',
        't', 'r', 'e', 'm', 'b', 'l', 'i', 'n', 'g', '\n',
        't', 'r', 'e', 'm', 'b', 'l', 'i', 'n', 'g', 'l', 'y', '\n',
        't', 'r', 'e', 'm', 'b', 'l', 'i', 'n', 'g', 's', '\n',
        't', 'r', 'e', 'm', 'e', 'n', 'd', 'o', 'u', 's', '\n',
        't', 'r', 'e', 'm', 'e', 'n', 'd', 'o', 'u', 's', 'l', 'y', '\n',
        't', 'r', 'e', 'm', 'o', 'l', 'o', '\n',
        't', 'r', 'e', 'm', 'o', 'r', '\n',
        't', 'r', 'e', 'm', 'o', 'r', 's', '\n',
        't', 'r', 'e', 'm', 'u', 'l', 'o', 'u', 's', '\n',
        't', 'r', 'e', 'm', 'u', 'l', 'o', 'u', 's', 'l', 'y', '\n',
        't', 'r', 'e', 'm', 'u', 'l', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        't', 'r', 'e', 'n', 'c', 'h', '\n',
        't', 'r', 'e', 'n', 'c', 'h', 'a', 'n', 't', '\n',
        't', 'r', 'e', 'n', 'c', 'h', 'a', 'n', 't', 'l', 'y', '\n',
        't', 'r', 'e', 'n', 'c', 'h', 'e', 'd', '\n',
        't', 'r', 'e', 'n', 'c', 'h', 'e', 'r', '\n',
        't', 'r', 'e', 'n', 'c', 'h', 'e', 's', '\n',
        't', 'r', 'e', 'n', 'c', 'h', 'i', 'n', 'g', '\n',
        't', 'r', 'e', 'n', 'd', '\n',
        't', 'r', 'e', 'n', 'd', 'i', 'e', 'r', '\n',
        't', 'r', 'e', 'n', 'd', 'i', 'e', 's', 't', '\n',
        't', 'r', 'e', 'n', 'd', 'i', 'n', 'e', 's', 's', '\n',
        't', 'r', 'e', 'n', 'd', 's', '\n',
        't', 'r', 'e', 'n', 'd', 'y', '\n',
        't', 'r', 'e', 'p', 'a', 'n', 'n', 'e', 'd', '\n',
        't', 'r', 'e', 'p', 'i', 'd', 'a', 't', 'i', 'o', 'n', '\n',
        't', 'r', 'e', 'p', 'i', 'd', 'a', 't', 'i', 'o', 'n', 's', '\n',
        't', 'r', 'e', 's', 'p', 'a', 's', 's', '\n',
        't', 'r', 'e', 's', 'p', 'a', 's', 's', 'e', 'd', '\n',
        't', 'r', 'e', 's', 'p', 'a', 's', 's', 'e', 'r', '\n',
        't', 'r', 'e', 's', 'p', 'a', 's', 's', 'e', 'r', 's', '\n',
        't', 'r', 'e', 's', 'p', 'a', 's', 's', 'e', 's', '\n',
        't', 'r', 'e', 's', 'p', 'a', 's', 's', 'i', 'n', 'g', '\n',
        't', 'r', 'e', 's', 's', '\n',
        't', 'r', 'e', 's', 's', 'e', 's', '\n',
        't', 'r', 'e', 's', 't', 'l', 'e', '\n',
        't', 'r', 'e', 's', 't', 'l', 'e', 's', '\n',
        't', 'r', 'e', 'w', 's', '\n',
        't', 'r', 'i', 'a', 'd', '\n',
        't', 'r', 'i', 'a', 'd', 'i', 'c', '\n',
        't', 'r', 'i', 'a', 'd', 's', '\n',
        't', 'r', 'i', 'a', 'g', 'e', '\n',
        't', 'r', 'i', 'a', 'l', '\n',
        't', 'r', 'i', 'a', 'l', 's', '\n',
        't', 'r', 'i', 'a', 'n', 'g', 'l', 'e', '\n',
        't', 'r', 'i', 'a', 'n', 'g', 'l', 'e', 's', '\n',
        't', 'r', 'i', 'a', 'n', 'g', 'u', 'l', 'a', 'r', '\n',
        't', 'r', 'i', 'a', 'n', 'g', 'u', 'l', 'a', 't', 'e', '\n',
        't', 'r', 'i', 'a', 'n', 'g', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        't', 'r', 'i', 'a', 'n', 'g', 'u', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        't', 'r', 'i', 'a', 'n', 'g', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        't', 'r', 'i', 'a', 'n', 'g', 'u', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        't', 'r', 'i', 'a', 't', 'h', 'l', 'o', 'n', '\n',
        't', 'r', 'i', 'a', 't', 'o', 'm', 'i', 'c', '\n',
        't', 'r', 'i', 'b', 'a', 'l', '\n',
        't', 'r', 'i', 'b', 'a', 'l', 'i', 's', 'm', '\n',
        't', 'r', 'i', 'b', 'a', 'l', 'l', 'y', '\n',
        't', 'r', 'i', 'b', 'e', '\n',
        't', 'r', 'i', 'b', 'e', 's', '\n',
        't', 'r', 'i', 'b', 'e', 's', 'm', 'a', 'n', '\n',
        't', 'r', 'i', 'b', 'e', 's', 'm', 'e', 'n', '\n',
        't', 'r', 'i', 'b', 'e', 's', 'p', 'e', 'o', 'p', 'l', 'e', '\n',
        't', 'r', 'i', 'b', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        't', 'r', 'i', 'b', 'u', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        't', 'r', 'i', 'b', 'u', 'n', 'a', 'l', '\n',
        't', 'r', 'i', 'b', 'u', 'n', 'a', 'l', 's', '\n',
        't', 'r', 'i', 'b', 'u', 'n', 'e', '\n',
        't', 'r', 'i', 'b', 'u', 'n', 'e', 's', '\n',
        't', 'r', 'i', 'b', 'u', 't', 'a', 'r', 'i', 'e', 's', '\n',
        't', 'r', 'i', 'b', 'u', 't', 'a', 'r', 'y', '\n',
        't', 'r', 'i', 'b', 'u', 't', 'e', '\n',
        't', 'r', 'i', 'b', 'u', 't', 'e', 's', '\n',
        't', 'r', 'i', 'c', 'e', '\n',
        't', 'r', 'i', 'c', 'k', '\n',
        't', 'r', 'i', 'c', 'k', 'e', 'd', '\n',
        't', 'r', 'i', 'c', 'k', 'e', 'r', 'y', '\n',
        't', 'r', 'i', 'c', 'k', 'i', 'e', 'r', '\n',
        't', 'r', 'i', 'c', 'k', 'i', 'e', 's', 't', '\n',
        't', 'r', 'i', 'c', 'k', 'i', 'l', 'y', '\n',
        't', 'r', 'i', 'c', 'k', 'i', 'n', 'g', '\n',
        't', 'r', 'i', 'c', 'k', 'l', 'e', '\n',
        't', 'r', 'i', 'c', 'k', 'l', 'e', 'd', '\n',
        't', 'r', 'i', 'c', 'k', 'l', 'e', 's', '\n',
        't', 'r', 'i', 'c', 'k', 'l', 'i', 'n', 'g', '\n',
        't', 'r', 'i', 'c', 'k', 's', '\n',
        't', 'r', 'i', 'c', 'k', 's', 't', 'e', 'r', '\n',
        't', 'r', 'i', 'c', 'k', 's', 't', 'e', 'r', 's', '\n',
        't', 'r', 'i', 'c', 'k', 'y', '\n',
        't', 'r', 'i', 'c', 'o', 'l', 'o', 'u', 'r', '\n',
        't', 'r', 'i', 'c', 'o', 'l', 'o', 'u', 'r', 's', '\n',
        't', 'r', 'i', 'c', 'y', 'c', 'l', 'e', '\n',
        't', 'r', 'i', 'c', 'y', 'c', 'l', 'e', 's', '\n',
        't', 'r', 'i', 'd', 'e', 'n', 't', '\n',
        't', 'r', 'i', 'd', 'e', 'n', 't', 's', '\n',
        't', 'r', 'i', 'e', 'd', '\n',
        't', 'r', 'i', 'e', 'n', 'n', 'i', 'a', 'l', '\n',
        't', 'r', 'i', 'e', 'r', '\n',
        't', 'r', 'i', 'e', 's', '\n',
        't', 'r', 'i', 'f', 'f', 'i', 'd', '\n',
        't', 'r', 'i', 'f', 'f', 'i', 'd', 's', '\n',
        't', 'r', 'i', 'f', 'l', 'e', '\n',
        't', 'r', 'i', 'f', 'l', 'e', 'd', '\n',
        't', 'r', 'i', 'f', 'l', 'e', 'r', '\n',
        't', 'r', 'i', 'f', 'l', 'e', 's', '\n',
        't', 'r', 'i', 'f', 'l', 'i', 'n', 'g', '\n',
        't', 'r', 'i', 'g', 'g', 'e', 'r', '\n',
        't', 'r', 'i', 'g', 'g', 'e', 'r', 'e', 'd', '\n',
        't', 'r', 'i', 'g', 'g', 'e', 'r', 'h', 'a', 'p', 'p', 'y', '\n',
        't', 'r', 'i', 'g', 'g', 'e', 'r', 'i', 'n', 'g', '\n',
        't', 'r', 'i', 'g', 'g', 'e', 'r', 's', '\n',
        't', 'r', 'i', 'g', 'l', 'y', 'c', 'e', 'r', 'i', 'd', 'e', '\n',
        't', 'r', 'i', 'g', 'o', 'n', 'o', 'm', 'e', 't', 'r', 'i', 'c', '\n',
        't', 'r', 'i', 'g', 'o', 'n', 'o', 'm', 'e', 't', 'r', 'i', 'c', 'a', 'l', '\n',
        't', 'r', 'i', 'g', 'o', 'n', 'o', 'm', 'e', 't', 'r', 'y', '\n',
        't', 'r', 'i', 'g', 'r', 'a', 'm', '\n',
        't', 'r', 'i', 'g', 'r', 'a', 'm', 's', '\n',
        't', 'r', 'i', 'g', 's', '\n',
        't', 'r', 'i', 'k', 'e', 's', '\n',
        't', 'r', 'i', 'l', 'a', 't', 'e', 'r', 'a', 'l', '\n',
        't', 'r', 'i', 'l', 'b', 'y', '\n',
        't', 'r', 'i', 'l', 'i', 'n', 'g', 'u', 'a', 'l', '\n',
        't', 'r', 'i', 'l', 'l', '\n',
        't', 'r', 'i', 'l', 'l', 'e', 'd', '\n',
        't', 'r', 'i', 'l', 'l', 'i', 'n', 'g', '\n',
        't', 'r', 'i', 'l', 'l', 'i', 'o', 'n', '\n',
        't', 'r', 'i', 'l', 'l', 'i', 'o', 'n', 's', '\n',
        't', 'r', 'i', 'l', 'l', 's', '\n',
        't', 'r', 'i', 'l', 'o', 'b', 'i', 't', 'e', '\n',
        't', 'r', 'i', 'l', 'o', 'b', 'i', 't', 'e', 's', '\n',
        't', 'r', 'i', 'l', 'o', 'g', 'i', 'e', 's', '\n',
        't', 'r', 'i', 'l', 'o', 'g', 'y', '\n',
        't', 'r', 'i', 'm', '\n',
        't', 'r', 'i', 'm', 'a', 'r', 'a', 'n', '\n',
        't', 'r', 'i', 'm', 'm', 'e', 'd', '\n',
        't', 'r', 'i', 'm', 'm', 'e', 'r', '\n',
        't', 'r', 'i', 'm', 'm', 'e', 'r', 's', '\n',
        't', 'r', 'i', 'm', 'm', 'i', 'n', 'g', '\n',
        't', 'r', 'i', 'm', 'm', 'i', 'n', 'g', 's', '\n',
        't', 'r', 'i', 'm', 'o', 'd', 'a', 'l', '\n',
        't', 'r', 'i', 'm', 's', '\n',
        't', 'r', 'i', 'n', 'i', 'd', 'a', 'd', '\n',
        't', 'r', 'i', 'n', 'i', 't', 'y', '\n',
        't', 'r', 'i', 'n', 'k', 'e', 't', '\n',
        't', 'r', 'i', 'n', 'k', 'e', 't', 's', '\n',
        't', 'r', 'i', 'o', '\n',
        't', 'r', 'i', 'p', '\n',
        't', 'r', 'i', 'p', 'a', 'r', 't', 'i', 't', 'e', '\n',
        't', 'r', 'i', 'p', 'e', '\n',
        't', 'r', 'i', 'p', 'l', 'a', 'n', 'e', '\n',
        't', 'r', 'i', 'p', 'l', 'e', '\n',
        't', 'r', 'i', 'p', 'l', 'e', 'd', '\n',
        't', 'r', 'i', 'p', 'l', 'e', 's', '\n',
        't', 'r', 'i', 'p', 'l', 'e', 't', '\n',
        't', 'r', 'i', 'p', 'l', 'e', 't', 's', '\n',
        't', 'r', 'i', 'p', 'l', 'e', 'x', '\n',
        't', 'r', 'i', 'p', 'l', 'i', 'c', 'a', 't', 'e', '\n',
        't', 'r', 'i', 'p', 'l', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        't', 'r', 'i', 'p', 'l', 'i', 'n', 'g', '\n',
        't', 'r', 'i', 'p', 'l', 'y', '\n',
        't', 'r', 'i', 'p', 'o', 'd', '\n',
        't', 'r', 'i', 'p', 'o', 'd', 's', '\n',
        't', 'r', 'i', 'p', 'o', 'l', 'i', '\n',
        't', 'r', 'i', 'p', 'p', 'e', 'd', '\n',
        't', 'r', 'i', 'p', 'p', 'e', 'r', 's', '\n',
        't', 'r', 'i', 'p', 'p', 'i', 'n', 'g', '\n',
        't', 'r', 'i', 'p', 's', '\n',
        't', 'r', 'i', 'p', 't', 'y', 'c', 'h', '\n',
        't', 'r', 'i', 'p', 'w', 'i', 'r', 'e', '\n',
        't', 'r', 'i', 'p', 'w', 'i', 'r', 'e', 's', '\n',
        't', 'r', 'i', 'r', 'e', 'm', 'e', '\n',
        't', 'r', 'i', 's', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        't', 'r', 'i', 's', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        't', 'r', 'i', 's', 'e', 'c', 't', 'o', 'r', '\n',
        't', 'r', 'i', 's', 't', 'a', 'n', '\n',
        't', 'r', 'i', 't', 'e', '\n',
        't', 'r', 'i', 't', 'e', 'n', 'e', 's', 's', '\n',
        't', 'r', 'i', 't', 'i', 'u', 'm', '\n',
        't', 'r', 'i', 'u', 'm', 'p', 'h', '\n',
        't', 'r', 'i', 'u', 'm', 'p', 'h', 'a', 'l', '\n',
        't', 'r', 'i', 'u', 'm', 'p', 'h', 'a', 'l', 'i', 's', 'm', '\n',
        't', 'r', 'i', 'u', 'm', 'p', 'h', 'a', 'l', 'i', 's', 't', '\n',
        't', 'r', 'i', 'u', 'm', 'p', 'h', 'a', 'n', 't', '\n',
        't', 'r', 'i', 'u', 'm', 'p', 'h', 'a', 'n', 't', 'l', 'y', '\n',
        't', 'r', 'i', 'u', 'm', 'p', 'h', 'e', 'd', '\n',
        't', 'r', 'i', 'u', 'm', 'p', 'h', 'i', 'n', 'g', '\n',
        't', 'r', 'i', 'u', 'm', 'p', 'h', 's', '\n',
        't', 'r', 'i', 'u', 'm', 'v', 'i', 'r', 'a', 't', 'e', '\n',
        't', 'r', 'i', 'v', 'i', 'a', '\n',
        't', 'r', 'i', 'v', 'i', 'a', 'l', '\n',
        't', 'r', 'i', 'v', 'i', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        't', 'r', 'i', 'v', 'i', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        't', 'r', 'i', 'v', 'i', 'a', 'l', 'i', 's', 'e', '\n',
        't', 'r', 'i', 'v', 'i', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        't', 'r', 'i', 'v', 'i', 'a', 'l', 'i', 's', 'e', 's', '\n',
        't', 'r', 'i', 'v', 'i', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        't', 'r', 'i', 'v', 'i', 'a', 'l', 'i', 't', 'i', 'e', 's', '\n',
        't', 'r', 'i', 'v', 'i', 'a', 'l', 'i', 't', 'y', '\n',
        't', 'r', 'i', 'v', 'i', 'a', 'l', 'l', 'y', '\n',
        't', 'r', 'o', 'd', '\n',
        't', 'r', 'o', 'd', 'd', 'e', 'n', '\n',
        't', 'r', 'o', 'g', 'l', 'o', 'd', 'y', 't', 'e', '\n',
        't', 'r', 'o', 'g', 'l', 'o', 'd', 'y', 't', 'e', 's', '\n',
        't', 'r', 'o', 'i', 'k', 'a', '\n',
        't', 'r', 'o', 'i', 'k', 'a', 's', '\n',
        't', 'r', 'o', 'l', 'l', '\n',
        't', 'r', 'o', 'l', 'l', 'e', 'y', '\n',
        't', 'r', 'o', 'l', 'l', 'e', 'y', 's', '\n',
        't', 'r', 'o', 'l', 'l', 'i', 'n', 'g', '\n',
        't', 'r', 'o', 'l', 'l', 'i', 's', 'h', '\n',
        't', 'r', 'o', 'l', 'l', 's', '\n',
        't', 'r', 'o', 'm', 'b', 'o', 'n', 'e', '\n',
        't', 'r', 'o', 'm', 'b', 'o', 'n', 'e', 's', '\n',
        't', 'r', 'o', 'm', 'b', 'o', 'n', 'i', 's', 't', '\n',
        't', 'r', 'o', 'm', 'b', 'o', 'n', 'i', 's', 't', 's', '\n',
        't', 'r', 'o', 'o', 'p', '\n',
        't', 'r', 'o', 'o', 'p', 'e', 'd', '\n',
        't', 'r', 'o', 'o', 'p', 'e', 'r', '\n',
        't', 'r', 'o', 'o', 'p', 'e', 'r', 's', '\n',
        't', 'r', 'o', 'o', 'p', 'i', 'n', 'g', '\n',
        't', 'r', 'o', 'o', 'p', 's', '\n',
        't', 'r', 'o', 'o', 'p', 's', 'h', 'i', 'p', '\n',
        't', 'r', 'o', 'p', 'e', '\n',
        't', 'r', 'o', 'p', 'e', 's', '\n',
        't', 'r', 'o', 'p', 'h', 'i', 'e', 's', '\n',
        't', 'r', 'o', 'p', 'h', 'y', '\n',
        't', 'r', 'o', 'p', 'i', 'c', '\n',
        't', 'r', 'o', 'p', 'i', 'c', 'a', 'l', '\n',
        't', 'r', 'o', 'p', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        't', 'r', 'o', 'p', 'i', 'c', 's', '\n',
        't', 'r', 'o', 'p', 'o', 'p', 'a', 'u', 's', 'e', '\n',
        't', 'r', 'o', 'p', 'o', 's', 'p', 'h', 'e', 'r', 'e', '\n',
        't', 'r', 'o', 'p', 'o', 's', 'p', 'h', 'e', 'r', 'i', 'c', '\n',
        't', 'r', 'o', 't', '\n',
        't', 'r', 'o', 't', 's', '\n',
        't', 'r', 'o', 't', 't', 'e', 'd', '\n',
        't', 'r', 'o', 't', 't', 'e', 'r', '\n',
        't', 'r', 'o', 't', 't', 'e', 'r', 's', '\n',
        't', 'r', 'o', 't', 't', 'i', 'n', 'g', '\n',
        't', 'r', 'o', 'u', 'b', 'a', 'd', 'o', 'u', 'r', '\n',
        't', 'r', 'o', 'u', 'b', 'a', 'd', 'o', 'u', 'r', 's', '\n',
        't', 'r', 'o', 'u', 'b', 'l', 'e', '\n',
        't', 'r', 'o', 'u', 'b', 'l', 'e', 'd', '\n',
        't', 'r', 'o', 'u', 'b', 'l', 'e', 'm', 'a', 'k', 'e', 'r', '\n',
        't', 'r', 'o', 'u', 'b', 'l', 'e', 'm', 'a', 'k', 'e', 'r', 's', '\n',
        't', 'r', 'o', 'u', 'b', 'l', 'e', 's', '\n',
        't', 'r', 'o', 'u', 'b', 'l', 'e', 's', 'h', 'o', 'o', 't', 'e', 'r', '\n',
        't', 'r', 'o', 'u', 'b', 'l', 'e', 's', 'h', 'o', 'o', 't', 'e', 'r', 's', '\n',
        't', 'r', 'o', 'u', 'b', 'l', 'e', 's', 'h', 'o', 'o', 't', 'i', 'n', 'g', '\n',
        't', 'r', 'o', 'u', 'b', 'l', 'e', 's', 'o', 'm', 'e', '\n',
        't', 'r', 'o', 'u', 'b', 'l', 'e', 's', 'o', 'm', 'e', 'n', 'e', 's', 's', '\n',
        't', 'r', 'o', 'u', 'b', 'l', 'i', 'n', 'g', '\n',
        't', 'r', 'o', 'u', 'g', 'h', '\n',
        't', 'r', 'o', 'u', 'g', 'h', 's', '\n',
        't', 'r', 'o', 'u', 'n', 'c', 'e', '\n',
        't', 'r', 'o', 'u', 'n', 'c', 'e', 'd', '\n',
        't', 'r', 'o', 'u', 'n', 'c', 'e', 's', '\n',
        't', 'r', 'o', 'u', 'n', 'c', 'i', 'n', 'g', '\n',
        't', 'r', 'o', 'u', 'p', 'e', '\n',
        't', 'r', 'o', 'u', 'p', 'e', 'r', '\n',
        't', 'r', 'o', 'u', 'p', 'e', 'r', 's', '\n',
        't', 'r', 'o', 'u', 'p', 'e', 's', '\n',
        't', 'r', 'o', 'u', 's', 'e', 'r', '\n',
        't', 'r', 'o', 'u', 's', 'e', 'r', 's', '\n',
        't', 'r', 'o', 'u', 't', '\n',
        't', 'r', 'o', 'u', 't', 's', '\n',
        't', 'r', 'o', 'v', 'e', '\n',
        't', 'r', 'o', 'w', 'e', 'l', '\n',
        't', 'r', 'o', 'w', 'e', 'l', 's', '\n',
        't', 'r', 'o', 'y', '\n',
        't', 'r', 'u', 'a', 'n', 'c', 'y', '\n',
        't', 'r', 'u', 'a', 'n', 't', '\n',
        't', 'r', 'u', 'a', 'n', 't', 'i', 'n', 'g', '\n',
        't', 'r', 'u', 'a', 'n', 't', 's', '\n',
        't', 'r', 'u', 'c', 'e', '\n',
        't', 'r', 'u', 'c', 'e', 's', '\n',
        't', 'r', 'u', 'c', 'k', '\n',
        't', 'r', 'u', 'c', 'k', 's', '\n',
        't', 'r', 'u', 'c', 'u', 'l', 'e', 'n', 'c', 'e', '\n',
        't', 'r', 'u', 'c', 'u', 'l', 'e', 'n', 't', '\n',
        't', 'r', 'u', 'c', 'u', 'l', 'e', 'n', 't', 'l', 'y', '\n',
        't', 'r', 'u', 'd', 'g', 'e', '\n',
        't', 'r', 'u', 'd', 'g', 'e', 'd', '\n',
        't', 'r', 'u', 'd', 'g', 'e', 's', '\n',
        't', 'r', 'u', 'd', 'g', 'i', 'n', 'g', '\n',
        't', 'r', 'u', 'e', '\n',
        't', 'r', 'u', 'e', 'b', 'l', 'u', 'e', '\n',
        't', 'r', 'u', 'e', 'r', '\n',
        't', 'r', 'u', 'e', 's', 't', '\n',
        't', 'r', 'u', 'f', 'f', 'l', 'e', '\n',
        't', 'r', 'u', 'f', 'f', 'l', 'e', 's', '\n',
        't', 'r', 'u', 'i', 's', 'm', '\n',
        't', 'r', 'u', 'i', 's', 'm', 's', '\n',
        't', 'r', 'u', 'l', 'y', '\n',
        't', 'r', 'u', 'm', 'p', '\n',
        't', 'r', 'u', 'm', 'p', 'e', 'd', '\n',
        't', 'r', 'u', 'm', 'p', 'e', 'r', 'y', '\n',
        't', 'r', 'u', 'm', 'p', 'e', 't', '\n',
        't', 'r', 'u', 'm', 'p', 'e', 't', 'e', 'd', '\n',
        't', 'r', 'u', 'm', 'p', 'e', 't', 'e', 'r', '\n',
        't', 'r', 'u', 'm', 'p', 'e', 't', 'e', 'r', 's', '\n',
        't', 'r', 'u', 'm', 'p', 'e', 't', 'i', 'n', 'g', '\n',
        't', 'r', 'u', 'm', 'p', 'e', 't', 's', '\n',
        't', 'r', 'u', 'm', 'p', 's', '\n',
        't', 'r', 'u', 'n', 'c', 'a', 't', 'e', '\n',
        't', 'r', 'u', 'n', 'c', 'a', 't', 'e', 'd', '\n',
        't', 'r', 'u', 'n', 'c', 'a', 't', 'e', 's', '\n',
        't', 'r', 'u', 'n', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        't', 'r', 'u', 'n', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        't', 'r', 'u', 'n', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        't', 'r', 'u', 'n', 'c', 'h', 'e', 'o', 'n', '\n',
        't', 'r', 'u', 'n', 'c', 'h', 'e', 'o', 'n', 's', '\n',
        't', 'r', 'u', 'n', 'd', 'l', 'e', '\n',
        't', 'r', 'u', 'n', 'd', 'l', 'e', 'd', '\n',
        't', 'r', 'u', 'n', 'd', 'l', 'e', 's', '\n',
        't', 'r', 'u', 'n', 'd', 'l', 'i', 'n', 'g', '\n',
        't', 'r', 'u', 'n', 'k', '\n',
        't', 'r', 'u', 'n', 'k', 'i', 'n', 'g', '\n',
        't', 'r', 'u', 'n', 'k', 's', '\n',
        't', 'r', 'u', 'n', 'n', 'i', 'o', 'n', '\n',
        't', 'r', 'u', 'n', 'n', 'i', 'o', 'n', 's', '\n',
        't', 'r', 'u', 's', 's', '\n',
        't', 'r', 'u', 's', 's', 'e', 'd', '\n',
        't', 'r', 'u', 's', 's', 'e', 's', '\n',
        't', 'r', 'u', 's', 's', 'i', 'n', 'g', '\n',
        't', 'r', 'u', 's', 't', '\n',
        't', 'r', 'u', 's', 't', 'e', 'd', '\n',
        't', 'r', 'u', 's', 't', 'e', 'e', '\n',
        't', 'r', 'u', 's', 't', 'e', 'e', 's', '\n',
        't', 'r', 'u', 's', 't', 'e', 'e', 's', 'h', 'i', 'p', '\n',
        't', 'r', 'u', 's', 't', 'f', 'u', 'l', '\n',
        't', 'r', 'u', 's', 't', 'f', 'u', 'l', 'l', 'y', '\n',
        't', 'r', 'u', 's', 't', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        't', 'r', 'u', 's', 't', 'i', 'e', 's', '\n',
        't', 'r', 'u', 's', 't', 'i', 'n', 'g', '\n',
        't', 'r', 'u', 's', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        't', 'r', 'u', 's', 't', 's', '\n',
        't', 'r', 'u', 's', 't', 'w', 'o', 'r', 't', 'h', 'i', 'n', 'e', 's', 's', '\n',
        't', 'r', 'u', 's', 't', 'w', 'o', 'r', 't', 'h', 'y', '\n',
        't', 'r', 'u', 's', 't', 'y', '\n',
        't', 'r', 'u', 't', 'h', '\n',
        't', 'r', 'u', 't', 'h', 'f', 'u', 'l', '\n',
        't', 'r', 'u', 't', 'h', 'f', 'u', 'l', 'l', 'y', '\n',
        't', 'r', 'u', 't', 'h', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        't', 'r', 'u', 't', 'h', 's', '\n',
        't', 'r', 'y', '\n',
        't', 'r', 'y', 'i', 'n', 'g', '\n',
        't', 's', 'e', 't', 's', 'e', '\n',
        't', 's', 'h', 'i', 'r', 't', '\n',
        't', 's', 'u', 'n', 'a', 'm', 'i', '\n',
        't', 's', 'w', 'a', 'n', 'a', '\n',
        't', 's', 'w', 'a', 'n', 'a', 's', '\n',
        't', 'u', 'a', 'r', 'e', 'g', '\n',
        't', 'u', 'a', 'r', 'e', 'g', 's', '\n',
        't', 'u', 'a', 't', 'a', 'r', 'a', '\n',
        't', 'u', 'b', '\n',
        't', 'u', 'b', 'a', '\n',
        't', 'u', 'b', 'a', 's', '\n',
        't', 'u', 'b', 'b', 'y', '\n',
        't', 'u', 'b', 'e', '\n',
        't', 'u', 'b', 'e', 'd', '\n',
        't', 'u', 'b', 'e', 'l', 'e', 's', 's', '\n',
        't', 'u', 'b', 'e', 'r', '\n',
        't', 'u', 'b', 'e', 'r', 'c', 'u', 'l', 'a', 'r', '\n',
        't', 'u', 'b', 'e', 'r', 'c', 'u', 'l', 'o', 's', 'i', 's', '\n',
        't', 'u', 'b', 'e', 'r', 's', '\n',
        't', 'u', 'b', 'e', 's', '\n',
        't', 'u', 'b', 'i', 'n', 'g', '\n',
        't', 'u', 'b', 's', '\n',
        't', 'u', 'b', 'u', 'l', 'a', 'r', '\n',
        't', 'u', 'b', 'u', 'l', 'e', 's', '\n',
        't', 'u', 'c', 'k', '\n',
        't', 'u', 'c', 'k', 'e', 'd', '\n',
        't', 'u', 'c', 'k', 'e', 'r', '\n',
        't', 'u', 'c', 'k', 'e', 'r', 's', '\n',
        't', 'u', 'c', 'k', 'i', 'n', 'g', '\n',
        't', 'u', 'c', 'k', 's', '\n',
        't', 'u', 'e', 's', '\n',
        't', 'u', 'e', 's', 'd', 'a', 'y', '\n',
        't', 'u', 'e', 's', 'd', 'a', 'y', 's', '\n',
        't', 'u', 'f', 't', '\n',
        't', 'u', 'f', 't', 'e', 'd', '\n',
        't', 'u', 'f', 't', 'i', 'n', 'g', '\n',
        't', 'u', 'f', 't', 's', '\n',
        't', 'u', 'g', '\n',
        't', 'u', 'g', 'e', 'l', 'a', '\n',
        't', 'u', 'g', 'g', 'e', 'd', '\n',
        't', 'u', 'g', 'g', 'i', 'n', 'g', '\n',
        't', 'u', 'g', 's', '\n',
        't', 'u', 'i', 't', 'i', 'o', 'n', '\n',
        't', 'u', 'l', 'i', 'p', '\n',
        't', 'u', 'l', 'i', 'p', 's', '\n',
        't', 'u', 'm', 'b', 'l', 'e', '\n',
        't', 'u', 'm', 'b', 'l', 'e', 'd', '\n',
        't', 'u', 'm', 'b', 'l', 'e', 'd', 'o', 'w', 'n', '\n',
        't', 'u', 'm', 'b', 'l', 'e', 'r', '\n',
        't', 'u', 'm', 'b', 'l', 'e', 'r', 's', '\n',
        't', 'u', 'm', 'b', 'l', 'e', 's', '\n',
        't', 'u', 'm', 'b', 'l', 'i', 'n', 'g', '\n',
        't', 'u', 'm', 'b', 'r', 'i', 'l', 's', '\n',
        't', 'u', 'm', 'e', 's', 'c', 'e', 'n', 't', '\n',
        't', 'u', 'm', 'm', 'i', 'e', 's', '\n',
        't', 'u', 'm', 'm', 'y', '\n',
        't', 'u', 'm', 'o', 'u', 'r', '\n',
        't', 'u', 'm', 'o', 'u', 'r', 's', '\n',
        't', 'u', 'm', 'u', 'l', 't', '\n',
        't', 'u', 'm', 'u', 'l', 't', 's', '\n',
        't', 'u', 'm', 'u', 'l', 't', 'u', 'o', 'u', 's', '\n',
        't', 'u', 'm', 'u', 'l', 't', 'u', 'o', 'u', 's', 'l', 'y', '\n',
        't', 'u', 'm', 'u', 'l', 'u', 's', '\n',
        't', 'u', 'n', '\n',
        't', 'u', 'n', 'a', '\n',
        't', 'u', 'n', 'a', 'b', 'l', 'e', '\n',
        't', 'u', 'n', 'a', 's', '\n',
        't', 'u', 'n', 'd', 'r', 'a', '\n',
        't', 'u', 'n', 'd', 'r', 'a', 's', '\n',
        't', 'u', 'n', 'e', '\n',
        't', 'u', 'n', 'e', 'd', '\n',
        't', 'u', 'n', 'e', 'f', 'u', 'l', '\n',
        't', 'u', 'n', 'e', 'f', 'u', 'l', 'l', 'y', '\n',
        't', 'u', 'n', 'e', 'l', 'e', 's', 's', '\n',
        't', 'u', 'n', 'e', 'l', 'e', 's', 's', 'l', 'y', '\n',
        't', 'u', 'n', 'e', 'r', '\n',
        't', 'u', 'n', 'e', 'r', 's', '\n',
        't', 'u', 'n', 'e', 's', '\n',
        't', 'u', 'n', 'g', 's', 't', 'e', 'n', '\n',
        't', 'u', 'n', 'i', 'c', '\n',
        't', 'u', 'n', 'i', 'c', 's', '\n',
        't', 'u', 'n', 'i', 'n', 'g', '\n',
        't', 'u', 'n', 'i', 'n', 'g', 's', '\n',
        't', 'u', 'n', 'i', 's', 'i', 'a', '\n',
        't', 'u', 'n', 'i', 's', 'i', 'a', 'n', '\n',
        't', 'u', 'n', 'n', 'e', 'l', '\n',
        't', 'u', 'n', 'n', 'e', 'l', 'l', 'e', 'd', '\n',
        't', 'u', 'n', 'n', 'e', 'l', 'l', 'e', 'r', 's', '\n',
        't', 'u', 'n', 'n', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        't', 'u', 'n', 'n', 'e', 'l', 's', '\n',
        't', 'u', 'n', 'n', 'y', '\n',
        't', 'u', 'n', 's', '\n',
        't', 'u', 'p', 'p', 'e', 'n', 'c', 'e', '\n',
        't', 'u', 'p', 'p', 'e', 'n', 'c', 'e', 's', '\n',
        't', 'u', 'r', 'b', 'a', 'n', '\n',
        't', 'u', 'r', 'b', 'a', 'n', 's', '\n',
        't', 'u', 'r', 'b', 'i', 'd', '\n',
        't', 'u', 'r', 'b', 'i', 'd', 'i', 't', 'y', '\n',
        't', 'u', 'r', 'b', 'i', 'n', 'e', '\n',
        't', 'u', 'r', 'b', 'i', 'n', 'e', 's', '\n',
        't', 'u', 'r', 'b', 'o', '\n',
        't', 'u', 'r', 'b', 'o', 'c', 'h', 'a', 'r', 'g', 'e', 'd', '\n',
        't', 'u', 'r', 'b', 'o', 'c', 'h', 'a', 'r', 'g', 'e', 'r', '\n',
        't', 'u', 'r', 'b', 'o', 'p', 'r', 'o', 'p', '\n',
        't', 'u', 'r', 'b', 'o', 't', '\n',
        't', 'u', 'r', 'b', 'u', 'l', 'e', 'n', 'c', 'e', '\n',
        't', 'u', 'r', 'b', 'u', 'l', 'e', 'n', 't', '\n',
        't', 'u', 'r', 'e', 'e', 'n', '\n',
        't', 'u', 'r', 'e', 'e', 'n', 's', '\n',
        't', 'u', 'r', 'f', '\n',
        't', 'u', 'r', 'f', 'e', 'd', '\n',
        't', 'u', 'r', 'f', 's', '\n',
        't', 'u', 'r', 'f', 'y', '\n',
        't', 'u', 'r', 'g', 'i', 'd', '\n',
        't', 'u', 'r', 'g', 'i', 'd', 'i', 't', 'y', '\n',
        't', 'u', 'r', 'g', 'i', 'd', 'l', 'y', '\n',
        't', 'u', 'r', 'i', 'n', '\n',
        't', 'u', 'r', 'k', '\n',
        't', 'u', 'r', 'k', 'e', 'y', '\n',
        't', 'u', 'r', 'k', 'e', 'y', 's', '\n',
        't', 'u', 'r', 'k', 'i', 's', 'h', '\n',
        't', 'u', 'r', 'k', 's', '\n',
        't', 'u', 'r', 'm', 'e', 'r', 'i', 'c', '\n',
        't', 'u', 'r', 'm', 'o', 'i', 'l', '\n',
        't', 'u', 'r', 'm', 'o', 'i', 'l', 's', '\n',
        't', 'u', 'r', 'n', '\n',
        't', 'u', 'r', 'n', 'a', 'b', 'o', 'u', 't', '\n',
        't', 'u', 'r', 'n', 'a', 'r', 'o', 'u', 'n', 'd', '\n',
        't', 'u', 'r', 'n', 'c', 'o', 'a', 't', '\n',
        't', 'u', 'r', 'n', 'c', 'o', 'a', 't', 's', '\n',
        't', 'u', 'r', 'n', 'e', 'd', '\n',
        't', 'u', 'r', 'n', 'e', 'r', '\n',
        't', 'u', 'r', 'n', 'e', 'r', 's', '\n',
        't', 'u', 'r', 'n', 'i', 'n', 'g', '\n',
        't', 'u', 'r', 'n', 'i', 'n', 'g', 's', '\n',
        't', 'u', 'r', 'n', 'i', 'p', '\n',
        't', 'u', 'r', 'n', 'i', 'p', 's', '\n',
        't', 'u', 'r', 'n', 'k', 'e', 'y', '\n',
        't', 'u', 'r', 'n', 'o', 'u', 't', '\n',
        't', 'u', 'r', 'n', 'o', 'u', 't', 's', '\n',
        't', 'u', 'r', 'n', 'o', 'v', 'e', 'r', '\n',
        't', 'u', 'r', 'n', 'o', 'v', 'e', 'r', 's', '\n',
        't', 'u', 'r', 'n', 'p', 'i', 'k', 'e', '\n',
        't', 'u', 'r', 'n', 'r', 'o', 'u', 'n', 'd', '\n',
        't', 'u', 'r', 'n', 's', '\n',
        't', 'u', 'r', 'n', 's', 't', 'i', 'l', 'e', '\n',
        't', 'u', 'r', 'n', 's', 't', 'i', 'l', 'e', 's', '\n',
        't', 'u', 'r', 'n', 't', 'a', 'b', 'l', 'e', '\n',
        't', 'u', 'r', 'n', 't', 'a', 'b', 'l', 'e', 's', '\n',
        't', 'u', 'r', 'p', 'e', 'n', 't', 'i', 'n', 'e', '\n',
        't', 'u', 'r', 'p', 'i', 't', 'u', 'd', 'e', '\n',
        't', 'u', 'r', 'q', 'u', 'o', 'i', 's', 'e', '\n',
        't', 'u', 'r', 'r', 'e', 't', '\n',
        't', 'u', 'r', 'r', 'e', 't', 'e', 'd', '\n',
        't', 'u', 'r', 'r', 'e', 't', 's', '\n',
        't', 'u', 'r', 't', 'l', 'e', '\n',
        't', 'u', 'r', 't', 'l', 'e', 'n', 'e', 'c', 'k', '\n',
        't', 'u', 'r', 't', 'l', 'e', 's', '\n',
        't', 'u', 's', 'c', 'a', 'n', 'y', '\n',
        't', 'u', 's', 'k', '\n',
        't', 'u', 's', 'k', 'e', 'd', '\n',
        't', 'u', 's', 'k', 'e', 'r', '\n',
        't', 'u', 's', 'k', 's', '\n',
        't', 'u', 's', 's', 'l', 'e', '\n',
        't', 'u', 's', 's', 'l', 'e', 's', '\n',
        't', 'u', 's', 's', 'l', 'i', 'n', 'g', '\n',
        't', 'u', 's', 's', 'o', 'c', 'k', '\n',
        't', 'u', 's', 's', 'o', 'c', 'k', 's', '\n',
        't', 'u', 's', 's', 'o', 'c', 'k', 'y', '\n',
        't', 'u', 't', 'e', 'l', 'a', 'g', 'e', '\n',
        't', 'u', 't', 'e', 'l', 'a', 'r', 'y', '\n',
        't', 'u', 't', 'o', 'r', '\n',
        't', 'u', 't', 'o', 'r', 'e', 'd', '\n',
        't', 'u', 't', 'o', 'r', 'i', 'a', 'l', '\n',
        't', 'u', 't', 'o', 'r', 'i', 'a', 'l', 's', '\n',
        't', 'u', 't', 'o', 'r', 'i', 'n', 'g', '\n',
        't', 'u', 't', 'o', 'r', 's', '\n',
        't', 'u', 't', 'u', '\n',
        't', 'u', 'x', 'e', 'd', 'o', '\n',
        't', 'w', 'a', 'i', 'n', '\n',
        't', 'w', 'a', 'n', 'g', '\n',
        't', 'w', 'a', 'n', 'g', 'e', 'd', '\n',
        't', 'w', 'a', 'n', 'g', 'i', 'n', 'g', '\n',
        't', 'w', 'a', 'n', 'g', 's', '\n',
        't', 'w', 'e', 'a', 'k', '\n',
        't', 'w', 'e', 'a', 'k', 'e', 'd', '\n',
        't', 'w', 'e', 'a', 'k', 'i', 'n', 'g', '\n',
        't', 'w', 'e', 'a', 'k', 's', '\n',
        't', 'w', 'e', 'e', '\n',
        't', 'w', 'e', 'e', 'd', '\n',
        't', 'w', 'e', 'e', 'd', 's', '\n',
        't', 'w', 'e', 'e', 'd', 'y', '\n',
        't', 'w', 'e', 'e', 'n', 'e', 's', 's', '\n',
        't', 'w', 'e', 'e', 't', '\n',
        't', 'w', 'e', 'e', 't', 'e', 'r', '\n',
        't', 'w', 'e', 'e', 't', 'e', 'r', 's', '\n',
        't', 'w', 'e', 'e', 't', 's', '\n',
        't', 'w', 'e', 'e', 'z', 'e', 'r', 's', '\n',
        't', 'w', 'e', 'l', 'f', 't', 'h', '\n',
        't', 'w', 'e', 'l', 'f', 't', 'h', 's', '\n',
        't', 'w', 'e', 'l', 'v', 'e', '\n',
        't', 'w', 'e', 'l', 'v', 'e', 's', '\n',
        't', 'w', 'e', 'n', 't', 'i', 'e', 's', '\n',
        't', 'w', 'e', 'n', 't', 'i', 'e', 't', 'h', '\n',
        't', 'w', 'e', 'n', 't', 'y', '\n',
        't', 'w', 'i', 'c', 'e', '\n',
        't', 'w', 'i', 'd', 'd', 'l', 'e', '\n',
        't', 'w', 'i', 'd', 'd', 'l', 'e', 'd', '\n',
        't', 'w', 'i', 'd', 'd', 'l', 'e', 'r', '\n',
        't', 'w', 'i', 'd', 'd', 'l', 'e', 's', '\n',
        't', 'w', 'i', 'd', 'd', 'l', 'i', 'n', 'g', '\n',
        't', 'w', 'i', 'd', 'd', 'l', 'y', '\n',
        't', 'w', 'i', 'g', '\n',
        't', 'w', 'i', 'g', 'g', 'e', 'd', '\n',
        't', 'w', 'i', 'g', 'g', 'y', '\n',
        't', 'w', 'i', 'g', 's', '\n',
        't', 'w', 'i', 'l', 'i', 'g', 'h', 't', '\n',
        't', 'w', 'i', 'l', 'i', 't', '\n',
        't', 'w', 'i', 'l', 'l', '\n',
        't', 'w', 'i', 'n', '\n',
        't', 'w', 'i', 'n', 'e', '\n',
        't', 'w', 'i', 'n', 'e', 'd', '\n',
        't', 'w', 'i', 'n', 'e', 's', '\n',
        't', 'w', 'i', 'n', 'g', 'e', '\n',
        't', 'w', 'i', 'n', 'g', 'e', 's', '\n',
        't', 'w', 'i', 'n', 'i', 'n', 'g', '\n',
        't', 'w', 'i', 'n', 'k', 'l', 'e', '\n',
        't', 'w', 'i', 'n', 'k', 'l', 'e', 'd', '\n',
        't', 'w', 'i', 'n', 'k', 'l', 'e', 's', '\n',
        't', 'w', 'i', 'n', 'k', 'l', 'i', 'n', 'g', '\n',
        't', 'w', 'i', 'n', 'n', 'e', 'd', '\n',
        't', 'w', 'i', 'n', 'n', 'i', 'n', 'g', '\n',
        't', 'w', 'i', 'n', 's', '\n',
        't', 'w', 'i', 'r', 'l', '\n',
        't', 'w', 'i', 'r', 'l', 'e', 'd', '\n',
        't', 'w', 'i', 'r', 'l', 'i', 'n', 'g', '\n',
        't', 'w', 'i', 'r', 'l', 's', '\n',
        't', 'w', 'i', 's', 't', '\n',
        't', 'w', 'i', 's', 't', 'e', 'd', '\n',
        't', 'w', 'i', 's', 't', 'e', 'r', '\n',
        't', 'w', 'i', 's', 't', 'e', 'r', 's', '\n',
        't', 'w', 'i', 's', 't', 'i', 'n', 'g', '\n',
        't', 'w', 'i', 's', 't', 's', '\n',
        't', 'w', 'i', 's', 't', 'y', '\n',
        't', 'w', 'i', 't', '\n',
        't', 'w', 'i', 't', 'c', 'h', '\n',
        't', 'w', 'i', 't', 'c', 'h', 'e', 'd', '\n',
        't', 'w', 'i', 't', 'c', 'h', 'e', 's', '\n',
        't', 'w', 'i', 't', 'c', 'h', 'i', 'n', 'g', '\n',
        't', 'w', 'i', 't', 'c', 'h', 'y', '\n',
        't', 'w', 'i', 't', 't', 'e', 'r', '\n',
        't', 'w', 'i', 't', 't', 'e', 'r', 'e', 'd', '\n',
        't', 'w', 'i', 't', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        't', 'w', 'o', '\n',
        't', 'w', 'o', 'd', 'i', 'm', 'e', 'n', 's', 'i', 'o', 'n', 'a', 'l', '\n',
        't', 'w', 'o', 'f', 'a', 'c', 'e', 'd', '\n',
        't', 'w', 'o', 'f', 'o', 'l', 'd', '\n',
        't', 'w', 'o', 's', 'o', 'm', 'e', '\n',
        't', 'y', 'c', 'o', 'o', 'n', '\n',
        't', 'y', 'c', 'o', 'o', 'n', 's', '\n',
        't', 'y', 'i', 'n', 'g', '\n',
        't', 'y', 'k', 'e', '\n',
        't', 'y', 'k', 'e', 's', '\n',
        't', 'y', 'p', 'e', '\n',
        't', 'y', 'p', 'e', 'c', 'a', 's', 't', '\n',
        't', 'y', 'p', 'e', 'c', 'a', 's', 't', 'i', 'n', 'g', '\n',
        't', 'y', 'p', 'e', 'd', '\n',
        't', 'y', 'p', 'e', 'f', 'a', 'c', 'e', '\n',
        't', 'y', 'p', 'e', 'f', 'a', 'c', 'e', 's', '\n',
        't', 'y', 'p', 'e', 'l', 'e', 's', 's', '\n',
        't', 'y', 'p', 'e', 's', '\n',
        't', 'y', 'p', 'e', 's', 'c', 'r', 'i', 'p', 't', '\n',
        't', 'y', 'p', 'e', 's', 'c', 'r', 'i', 'p', 't', 's', '\n',
        't', 'y', 'p', 'e', 's', 'e', 't', '\n',
        't', 'y', 'p', 'e', 's', 'e', 't', 's', '\n',
        't', 'y', 'p', 'e', 's', 'e', 't', 't', 'e', 'r', '\n',
        't', 'y', 'p', 'e', 's', 'e', 't', 't', 'e', 'r', 's', '\n',
        't', 'y', 'p', 'e', 's', 'e', 't', 't', 'i', 'n', 'g', '\n',
        't', 'y', 'p', 'e', 'w', 'r', 'i', 't', 'e', 'r', '\n',
        't', 'y', 'p', 'e', 'w', 'r', 'i', 't', 'e', 'r', 's', '\n',
        't', 'y', 'p', 'e', 'w', 'r', 'i', 't', 'i', 'n', 'g', '\n',
        't', 'y', 'p', 'e', 'w', 'r', 'i', 't', 't', 'e', 'n', '\n',
        't', 'y', 'p', 'h', 'o', 'i', 'd', '\n',
        't', 'y', 'p', 'h', 'o', 'o', 'n', '\n',
        't', 'y', 'p', 'h', 'o', 'o', 'n', 's', '\n',
        't', 'y', 'p', 'h', 'u', 's', '\n',
        't', 'y', 'p', 'i', 'c', 'a', 'l', '\n',
        't', 'y', 'p', 'i', 'c', 'a', 'l', 'i', 't', 'y', '\n',
        't', 'y', 'p', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        't', 'y', 'p', 'i', 'f', 'i', 'e', 'd', '\n',
        't', 'y', 'p', 'i', 'f', 'i', 'e', 's', '\n',
        't', 'y', 'p', 'i', 'f', 'y', '\n',
        't', 'y', 'p', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        't', 'y', 'p', 'i', 'n', 'g', '\n',
        't', 'y', 'p', 'i', 'n', 'g', 's', '\n',
        't', 'y', 'p', 'i', 's', 't', '\n',
        't', 'y', 'p', 'i', 's', 't', 's', '\n',
        't', 'y', 'p', 'o', 'g', 'r', 'a', 'p', 'h', 'e', 'r', '\n',
        't', 'y', 'p', 'o', 'g', 'r', 'a', 'p', 'h', 'e', 'r', 's', '\n',
        't', 'y', 'p', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', '\n',
        't', 'y', 'p', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', 'a', 'l', '\n',
        't', 'y', 'p', 'o', 'g', 'r', 'a', 'p', 'h', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        't', 'y', 'p', 'o', 'g', 'r', 'a', 'p', 'h', 'y', '\n',
        't', 'y', 'p', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        't', 'y', 'p', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        't', 'y', 'p', 'o', 'l', 'o', 'g', 'i', 'e', 's', '\n',
        't', 'y', 'p', 'o', 'l', 'o', 'g', 'y', '\n',
        't', 'y', 'r', 'a', 'n', 'n', 'i', 'c', '\n',
        't', 'y', 'r', 'a', 'n', 'n', 'i', 'c', 'a', 'l', '\n',
        't', 'y', 'r', 'a', 'n', 'n', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        't', 'y', 'r', 'a', 'n', 'n', 'i', 'c', 'i', 'd', 'e', '\n',
        't', 'y', 'r', 'a', 'n', 'n', 'i', 'e', 's', '\n',
        't', 'y', 'r', 'a', 'n', 'n', 'i', 's', 'e', '\n',
        't', 'y', 'r', 'a', 'n', 'n', 'i', 's', 'e', 'd', '\n',
        't', 'y', 'r', 'a', 'n', 'n', 'o', 'u', 's', '\n',
        't', 'y', 'r', 'a', 'n', 'n', 'y', '\n',
        't', 'y', 'r', 'a', 'n', 't', '\n',
        't', 'y', 'r', 'a', 'n', 't', 's', '\n',
        't', 'y', 'r', 'e', '\n',
        't', 'y', 'r', 'e', 's', '\n',
        'u', 'b', 'o', 'a', 't', 's', '\n',
        'u', 'd', 'd', 'e', 'r', '\n',
        'u', 'd', 'd', 'e', 'r', 's', '\n',
        'u', 'f', 'o', '\n',
        'u', 'g', 'a', 'n', 'd', 'a', '\n',
        'u', 'g', 'a', 'n', 'd', 'a', 'n', '\n',
        'u', 'g', 'l', 'i', 'e', 'r', '\n',
        'u', 'g', 'l', 'i', 'e', 's', 't', '\n',
        'u', 'g', 'l', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'u', 'g', 'l', 'i', 'n', 'e', 's', 's', '\n',
        'u', 'g', 'l', 'y', '\n',
        'u', 'h', 'u', 'h', '\n',
        'u', 'k', 'e', '\n',
        'u', 'k', 'r', 'a', 'i', 'n', 'e', '\n',
        'u', 'k', 'u', 'l', 'e', 'l', 'e', '\n',
        'u', 'k', 'u', 'l', 'e', 'l', 'e', 's', '\n',
        'u', 'l', 'c', 'e', 'r', '\n',
        'u', 'l', 'c', 'e', 'r', 'a', 't', 'e', '\n',
        'u', 'l', 'c', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'u', 'l', 'c', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'u', 'l', 'c', 'e', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'u', 'l', 'c', 'e', 'r', 'o', 'u', 's', '\n',
        'u', 'l', 'c', 'e', 'r', 's', '\n',
        'u', 'l', 's', 't', 'e', 'r', '\n',
        'u', 'l', 's', 't', 'e', 'r', 's', '\n',
        'u', 'l', 't', 'e', 'r', 'i', 'o', 'r', '\n',
        'u', 'l', 't', 'i', 'm', 'a', 'c', 'y', '\n',
        'u', 'l', 't', 'i', 'm', 'a', 't', 'e', '\n',
        'u', 'l', 't', 'i', 'm', 'a', 't', 'e', 'l', 'y', '\n',
        'u', 'l', 't', 'i', 'm', 'a', 't', 'u', 'm', '\n',
        'u', 'l', 't', 'i', 'm', 'a', 't', 'u', 'm', 's', '\n',
        'u', 'l', 't', 'i', 'm', 'o', '\n',
        'u', 'l', 't', 'r', 'a', '\n',
        'u', 'l', 't', 'r', 'a', 'm', 'a', 'r', 'i', 'n', 'e', '\n',
        'u', 'l', 't', 'r', 'a', 'm', 'o', 'n', 't', 'a', 'n', 'e', '\n',
        'u', 'l', 't', 'r', 'a', 's', 'o', 'n', 'i', 'c', '\n',
        'u', 'l', 't', 'r', 'a', 's', 'o', 'n', 'i', 'c', 's', '\n',
        'u', 'l', 't', 'r', 'a', 's', 'o', 'u', 'n', 'd', '\n',
        'u', 'l', 't', 'r', 'a', 'v', 'i', 'o', 'l', 'e', 't', '\n',
        'u', 'm', 'b', 'i', 'l', 'i', 'c', 'a', 'l', '\n',
        'u', 'm', 'b', 'i', 'l', 'i', 'c', 'u', 's', '\n',
        'u', 'm', 'b', 'r', 'a', '\n',
        'u', 'm', 'b', 'r', 'a', 'e', '\n',
        'u', 'm', 'b', 'r', 'a', 'g', 'e', '\n',
        'u', 'm', 'b', 'r', 'a', 'g', 'e', 'o', 'u', 's', '\n',
        'u', 'm', 'b', 'r', 'a', 's', '\n',
        'u', 'm', 'b', 'r', 'e', 'l', 'l', 'a', '\n',
        'u', 'm', 'b', 'r', 'e', 'l', 'l', 'a', 's', '\n',
        'u', 'm', 'l', 'a', 'u', 't', '\n',
        'u', 'm', 'l', 'a', 'u', 't', 's', '\n',
        'u', 'm', 'p', 'i', 'r', 'e', '\n',
        'u', 'm', 'p', 'i', 'r', 'e', 'd', '\n',
        'u', 'm', 'p', 'i', 'r', 'e', 's', '\n',
        'u', 'm', 'p', 'i', 'r', 'i', 'n', 'g', '\n',
        'u', 'm', 'p', 't', 'e', 'e', 'n', '\n',
        'u', 'm', 'p', 't', 'e', 'e', 'n', 't', 'h', '\n',
        'u', 'n', 'a', 'b', 'a', 's', 'h', 'e', 'd', '\n',
        'u', 'n', 'a', 'b', 'a', 's', 'h', 'e', 'd', 'l', 'y', '\n',
        'u', 'n', 'a', 'b', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'a', 'b', 'r', 'i', 'd', 'g', 'e', 'd', '\n',
        'u', 'n', 'a', 'b', 's', 'o', 'r', 'b', 'e', 'd', '\n',
        'u', 'n', 'a', 'c', 'c', 'e', 'p', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'u', 'n', 'a', 'c', 'c', 'e', 'p', 't', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'a', 'c', 'c', 'e', 'p', 't', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 'a', 'c', 'c', 'e', 'p', 't', 'e', 'd', '\n',
        'u', 'n', 'a', 'c', 'c', 'o', 'm', 'm', 'o', 'd', 'a', 't', 'i', 'n', 'g', '\n',
        'u', 'n', 'a', 'c', 'c', 'o', 'm', 'p', 'a', 'n', 'i', 'e', 'd', '\n',
        'u', 'n', 'a', 'c', 'c', 'o', 'u', 'n', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'u', 'n', 'a', 'c', 'c', 'o', 'u', 'n', 't', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'a', 'c', 'c', 'o', 'u', 'n', 't', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 'a', 'c', 'c', 'o', 'u', 'n', 't', 'e', 'd', '\n',
        'u', 'n', 'a', 'c', 'c', 'u', 's', 't', 'o', 'm', 'e', 'd', '\n',
        'u', 'n', 'a', 'c', 'h', 'i', 'e', 'v', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'a', 'c', 'k', 'n', 'o', 'w', 'l', 'e', 'd', 'g', 'e', 'd', '\n',
        'u', 'n', 'a', 'c', 'q', 'u', 'a', 'i', 'n', 't', 'e', 'd', '\n',
        'u', 'n', 'a', 'c', 't', 'i', 'v', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'a', 'd', 'a', 'p', 't', 'e', 'd', '\n',
        'u', 'n', 'a', 'd', 'a', 'p', 't', 'i', 'v', 'e', '\n',
        'u', 'n', 'a', 'd', 'd', 'r', 'e', 's', 's', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'a', 'd', 'd', 'r', 'e', 's', 's', 'e', 'd', '\n',
        'u', 'n', 'a', 'd', 'j', 'u', 's', 't', 'e', 'd', '\n',
        'u', 'n', 'a', 'd', 'o', 'r', 'n', 'e', 'd', '\n',
        'u', 'n', 'a', 'd', 'u', 'l', 't', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'a', 'd', 'v', 'e', 'n', 't', 'u', 'r', 'o', 'u', 's', '\n',
        'u', 'n', 'a', 'd', 'v', 'e', 'r', 't', 'i', 's', 'e', 'd', '\n',
        'u', 'n', 'a', 'e', 's', 't', 'h', 'e', 't', 'i', 'c', '\n',
        'u', 'n', 'a', 'f', 'f', 'e', 'c', 't', 'e', 'd', '\n',
        'u', 'n', 'a', 'f', 'f', 'e', 'c', 't', 'e', 'd', 'l', 'y', '\n',
        'u', 'n', 'a', 'f', 'f', 'i', 'l', 'i', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'a', 'f', 'f', 'o', 'r', 'd', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'a', 'f', 'r', 'a', 'i', 'd', '\n',
        'u', 'n', 'a', 'i', 'd', 'e', 'd', '\n',
        'u', 'n', 'a', 'l', 'i', 'g', 'n', 'e', 'd', '\n',
        'u', 'n', 'a', 'l', 'i', 'k', 'e', '\n',
        'u', 'n', 'a', 'l', 'l', 'o', 'c', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'a', 'l', 'l', 'o', 'y', 'e', 'd', '\n',
        'u', 'n', 'a', 'l', 't', 'e', 'r', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'a', 'l', 't', 'e', 'r', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 'a', 'l', 't', 'e', 'r', 'e', 'd', '\n',
        'u', 'n', 'a', 'm', 'b', 'i', 'g', 'u', 'i', 't', 'y', '\n',
        'u', 'n', 'a', 'm', 'b', 'i', 'g', 'u', 'o', 'u', 's', '\n',
        'u', 'n', 'a', 'm', 'b', 'i', 'g', 'u', 'o', 'u', 's', 'l', 'y', '\n',
        'u', 'n', 'a', 'm', 'b', 'i', 't', 'i', 'o', 'u', 's', '\n',
        'u', 'n', 'a', 'm', 'e', 'n', 'd', 'e', 'd', '\n',
        'u', 'n', 'a', 'm', 'u', 's', 'e', 'd', '\n',
        'u', 'n', 'a', 'n', 'i', 'm', 'i', 't', 'y', '\n',
        'u', 'n', 'a', 'n', 'i', 'm', 'o', 'u', 's', '\n',
        'u', 'n', 'a', 'n', 'i', 'm', 'o', 'u', 's', 'l', 'y', '\n',
        'u', 'n', 'a', 'n', 'n', 'o', 't', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'a', 'n', 'n', 'o', 'u', 'n', 'c', 'e', 'd', '\n',
        'u', 'n', 'a', 'n', 's', 'w', 'e', 'r', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'a', 'n', 's', 'w', 'e', 'r', 'e', 'd', '\n',
        'u', 'n', 'a', 'n', 't', 'i', 'c', 'i', 'p', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'a', 'p', 'o', 'l', 'o', 'g', 'e', 't', 'i', 'c', '\n',
        'u', 'n', 'a', 'p', 'p', 'e', 'a', 'l', 'i', 'n', 'g', '\n',
        'u', 'n', 'a', 'p', 'p', 'e', 'a', 's', 'e', 'd', '\n',
        'u', 'n', 'a', 'p', 'p', 'e', 't', 'i', 's', 'i', 'n', 'g', '\n',
        'u', 'n', 'a', 'p', 'p', 'r', 'e', 'c', 'i', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'a', 'p', 'p', 'r', 'e', 'c', 'i', 'a', 't', 'i', 'v', 'e', '\n',
        'u', 'n', 'a', 'p', 'p', 'r', 'o', 'a', 'c', 'h', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'a', 'p', 'p', 'r', 'o', 'v', 'e', 'd', '\n',
        'u', 'n', 'a', 'p', 't', '\n',
        'u', 'n', 'a', 'r', 'c', 'h', 'i', 'v', 'e', 'd', '\n',
        'u', 'n', 'a', 'r', 'g', 'u', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'a', 'r', 'g', 'u', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 'a', 'r', 'm', '\n',
        'u', 'n', 'a', 'r', 'm', 'e', 'd', '\n',
        'u', 'n', 'a', 'r', 'm', 's', '\n',
        'u', 'n', 'a', 'r', 'o', 'u', 's', 'e', 'd', '\n',
        'u', 'n', 'a', 'r', 't', 'i', 'c', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'a', 'r', 'y', '\n',
        'u', 'n', 'a', 's', 'h', 'a', 'm', 'e', 'd', '\n',
        'u', 'n', 'a', 's', 'h', 'a', 'm', 'e', 'd', 'l', 'y', '\n',
        'u', 'n', 'a', 's', 'k', 'e', 'd', '\n',
        'u', 'n', 'a', 's', 's', 'a', 'i', 'l', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'a', 's', 's', 'a', 'i', 'l', 'e', 'd', '\n',
        'u', 'n', 'a', 's', 's', 'e', 'r', 't', 'i', 'v', 'e', '\n',
        'u', 'n', 'a', 's', 's', 'i', 'g', 'n', 'e', 'd', '\n',
        'u', 'n', 'a', 's', 's', 'i', 's', 't', 'e', 'd', '\n',
        'u', 'n', 'a', 's', 's', 'o', 'c', 'i', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'a', 's', 's', 'u', 'a', 'g', 'e', 'd', '\n',
        'u', 'n', 'a', 's', 's', 'u', 'm', 'i', 'n', 'g', '\n',
        'u', 'n', 'a', 't', 't', 'a', 'c', 'h', 'e', 'd', '\n',
        'u', 'n', 'a', 't', 't', 'a', 'i', 'n', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'a', 't', 't', 'a', 'i', 'n', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 'a', 't', 't', 'a', 'i', 'n', 'e', 'd', '\n',
        'u', 'n', 'a', 't', 't', 'e', 'n', 'd', 'e', 'd', '\n',
        'u', 'n', 'a', 't', 't', 'e', 'n', 'u', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'a', 't', 't', 'r', 'a', 'c', 't', 'i', 'v', 'e', '\n',
        'u', 'n', 'a', 't', 't', 'r', 'a', 'c', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'u', 'n', 'a', 't', 't', 'r', 'i', 'b', 'u', 't', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'a', 't', 't', 'r', 'i', 'b', 'u', 't', 'e', 'd', '\n',
        'u', 'n', 'a', 'u', 'd', 'i', 't', 'e', 'd', '\n',
        'u', 'n', 'a', 'u', 't', 'h', 'e', 'n', 't', 'i', 'c', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'a', 'u', 't', 'h', 'o', 'r', 'i', 's', 'e', 'd', '\n',
        'u', 'n', 'a', 'v', 'a', 'i', 'l', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'u', 'n', 'a', 'v', 'a', 'i', 'l', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'a', 'v', 'a', 'i', 'l', 'i', 'n', 'g', '\n',
        'u', 'n', 'a', 'v', 'a', 'i', 'l', 'i', 'n', 'g', 'l', 'y', '\n',
        'u', 'n', 'a', 'v', 'e', 'n', 'g', 'e', 'd', '\n',
        'u', 'n', 'a', 'v', 'o', 'i', 'd', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'a', 'v', 'o', 'i', 'd', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 'a', 'w', 'a', 'k', 'e', 'n', 'e', 'd', '\n',
        'u', 'n', 'a', 'w', 'a', 'r', 'e', '\n',
        'u', 'n', 'a', 'w', 'a', 'r', 'e', 'n', 'e', 's', 's', '\n',
        'u', 'n', 'a', 'w', 'a', 'r', 'e', 's', '\n',
        'u', 'n', 'a', 'w', 'e', 'd', '\n',
        'u', 'n', 'b', 'a', 'l', 'a', 'n', 'c', 'e', '\n',
        'u', 'n', 'b', 'a', 'l', 'a', 'n', 'c', 'e', 'd', '\n',
        'u', 'n', 'b', 'a', 'l', 'a', 'n', 'c', 'e', 's', '\n',
        'u', 'n', 'b', 'a', 'l', 'a', 'n', 'c', 'i', 'n', 'g', '\n',
        'u', 'n', 'b', 'a', 'n', 'n', 'e', 'd', '\n',
        'u', 'n', 'b', 'a', 'n', 'n', 'i', 'n', 'g', '\n',
        'u', 'n', 'b', 'a', 'p', 't', 'i', 's', 'e', 'd', '\n',
        'u', 'n', 'b', 'a', 'r', '\n',
        'u', 'n', 'b', 'a', 'r', 'r', 'e', 'd', '\n',
        'u', 'n', 'b', 'a', 'r', 's', '\n',
        'u', 'n', 'b', 'e', 'a', 'r', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'b', 'e', 'a', 'r', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 'b', 'e', 'a', 't', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'b', 'e', 'a', 't', 'e', 'n', '\n',
        'u', 'n', 'b', 'e', 'c', 'o', 'm', 'i', 'n', 'g', '\n',
        'u', 'n', 'b', 'e', 'k', 'n', 'o', 'w', 'n', '\n',
        'u', 'n', 'b', 'e', 'k', 'n', 'o', 'w', 'n', 's', 't', '\n',
        'u', 'n', 'b', 'e', 'l', 'i', 'e', 'v', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'u', 'n', 'b', 'e', 'l', 'i', 'e', 'v', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'b', 'e', 'l', 'i', 'e', 'v', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 'b', 'e', 'l', 'i', 'e', 'v', 'e', 'd', '\n',
        'u', 'n', 'b', 'e', 'l', 'i', 'e', 'v', 'e', 'r', '\n',
        'u', 'n', 'b', 'e', 'l', 'i', 'e', 'v', 'e', 'r', 's', '\n',
        'u', 'n', 'b', 'e', 'l', 'i', 'e', 'v', 'i', 'n', 'g', '\n',
        'u', 'n', 'b', 'e', 'n', 'd', '\n',
        'u', 'n', 'b', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'u', 'n', 'b', 'e', 'n', 't', '\n',
        'u', 'n', 'b', 'i', 'a', 's', 'e', 'd', '\n',
        'u', 'n', 'b', 'i', 'a', 's', 'e', 'd', 'l', 'y', '\n',
        'u', 'n', 'b', 'i', 'a', 's', 's', 'e', 'd', '\n',
        'u', 'n', 'b', 'i', 'a', 's', 's', 'e', 'd', 'l', 'y', '\n',
        'u', 'n', 'b', 'i', 'd', 'd', 'e', 'n', '\n',
        'u', 'n', 'b', 'i', 'n', 'd', '\n',
        'u', 'n', 'b', 'l', 'e', 'a', 'c', 'h', 'e', 'd', '\n',
        'u', 'n', 'b', 'l', 'e', 'm', 'i', 's', 'h', 'e', 'd', '\n',
        'u', 'n', 'b', 'l', 'i', 'n', 'k', 'i', 'n', 'g', '\n',
        'u', 'n', 'b', 'l', 'i', 'n', 'k', 'i', 'n', 'g', 'l', 'y', '\n',
        'u', 'n', 'b', 'l', 'o', 'c', 'k', '\n',
        'u', 'n', 'b', 'l', 'o', 'c', 'k', 'e', 'd', '\n',
        'u', 'n', 'b', 'l', 'o', 'c', 'k', 'i', 'n', 'g', '\n',
        'u', 'n', 'b', 'l', 'o', 'o', 'd', 'i', 'e', 'd', '\n',
        'u', 'n', 'b', 'o', 'i', 'l', 'e', 'd', '\n',
        'u', 'n', 'b', 'o', 'l', 't', '\n',
        'u', 'n', 'b', 'o', 'l', 't', 'e', 'd', '\n',
        'u', 'n', 'b', 'o', 'o', 'k', 'e', 'd', '\n',
        'u', 'n', 'b', 'o', 'r', 'n', '\n',
        'u', 'n', 'b', 'o', 's', 'o', 'm', '\n',
        'u', 'n', 'b', 'o', 't', 'h', 'e', 'r', 'e', 'd', '\n',
        'u', 'n', 'b', 'o', 'u', 'n', 'd', '\n',
        'u', 'n', 'b', 'o', 'u', 'n', 'd', 'e', 'd', '\n',
        'u', 'n', 'b', 'o', 'w', 'e', 'd', '\n',
        'u', 'n', 'b', 'r', 'a', 'c', 'e', 'd', '\n',
        'u', 'n', 'b', 'r', 'a', 'c', 'k', 'e', 't', 'e', 'd', '\n',
        'u', 'n', 'b', 'r', 'a', 'n', 'd', 'e', 'd', '\n',
        'u', 'n', 'b', 'r', 'e', 'a', 'k', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'u', 'n', 'b', 'r', 'e', 'a', 'k', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'b', 'r', 'i', 'd', 'g', 'e', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'b', 'r', 'i', 'd', 'g', 'e', 'd', '\n',
        'u', 'n', 'b', 'r', 'i', 'd', 'l', 'e', 'd', '\n',
        'u', 'n', 'b', 'r', 'o', 'k', 'e', 'n', '\n',
        'u', 'n', 'b', 'r', 'u', 'i', 's', 'e', 'd', '\n',
        'u', 'n', 'b', 'u', 'c', 'k', 'l', 'e', '\n',
        'u', 'n', 'b', 'u', 'c', 'k', 'l', 'e', 'd', '\n',
        'u', 'n', 'b', 'u', 'c', 'k', 'l', 'i', 'n', 'g', '\n',
        'u', 'n', 'b', 'u', 'n', 'd', 'l', 'e', 'd', '\n',
        'u', 'n', 'b', 'u', 'r', 'd', 'e', 'n', '\n',
        'u', 'n', 'b', 'u', 'r', 'd', 'e', 'n', 'e', 'd', '\n',
        'u', 'n', 'b', 'u', 'r', 'd', 'e', 'n', 'i', 'n', 'g', '\n',
        'u', 'n', 'b', 'u', 'r', 'i', 'e', 'd', '\n',
        'u', 'n', 'b', 'u', 'r', 'n', 'e', 'd', '\n',
        'u', 'n', 'b', 'u', 'r', 'n', 't', '\n',
        'u', 'n', 'b', 'u', 't', 't', 'o', 'n', '\n',
        'u', 'n', 'b', 'u', 't', 't', 'o', 'n', 'e', 'd', '\n',
        'u', 'n', 'b', 'u', 't', 't', 'o', 'n', 'i', 'n', 'g', '\n',
        'u', 'n', 'c', 'a', 'l', 'i', 'b', 'r', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'c', 'a', 'l', 'l', 'e', 'd', '\n',
        'u', 'n', 'c', 'a', 'n', 'c', 'e', 'l', 'l', 'e', 'd', '\n',
        'u', 'n', 'c', 'a', 'n', 'n', 'i', 'l', 'y', '\n',
        'u', 'n', 'c', 'a', 'n', 'n', 'y', '\n',
        'u', 'n', 'c', 'a', 'p', 'p', 'e', 'd', '\n',
        'u', 'n', 'c', 'a', 'r', 'e', 'd', '\n',
        'u', 'n', 'c', 'a', 'r', 'i', 'n', 'g', '\n',
        'u', 'n', 'c', 'a', 's', 'e', 'd', '\n',
        'u', 'n', 'c', 'a', 't', 'a', 'l', 'o', 'g', 'u', 'e', 'd', '\n',
        'u', 'n', 'c', 'a', 'u', 'g', 'h', 't', '\n',
        'u', 'n', 'c', 'e', 'a', 's', 'i', 'n', 'g', '\n',
        'u', 'n', 'c', 'e', 'a', 's', 'i', 'n', 'g', 'l', 'y', '\n',
        'u', 'n', 'c', 'e', 'l', 'e', 'b', 'r', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'c', 'e', 'n', 's', 'o', 'r', 'e', 'd', '\n',
        'u', 'n', 'c', 'e', 'r', 'e', 'm', 'o', 'n', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'u', 'n', 'c', 'e', 'r', 't', 'a', 'i', 'n', '\n',
        'u', 'n', 'c', 'e', 'r', 't', 'a', 'i', 'n', 'l', 'y', '\n',
        'u', 'n', 'c', 'e', 'r', 't', 'a', 'i', 'n', 't', 'i', 'e', 's', '\n',
        'u', 'n', 'c', 'e', 'r', 't', 'a', 'i', 'n', 't', 'y', '\n',
        'u', 'n', 'c', 'h', 'a', 'i', 'n', '\n',
        'u', 'n', 'c', 'h', 'a', 'i', 'n', 'e', 'd', '\n',
        'u', 'n', 'c', 'h', 'a', 'i', 'n', 'i', 'n', 'g', '\n',
        'u', 'n', 'c', 'h', 'a', 'l', 'l', 'e', 'n', 'g', 'e', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'c', 'h', 'a', 'l', 'l', 'e', 'n', 'g', 'e', 'd', '\n',
        'u', 'n', 'c', 'h', 'a', 'n', 'g', 'e', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'c', 'h', 'a', 'n', 'g', 'e', 'd', '\n',
        'u', 'n', 'c', 'h', 'a', 'n', 'g', 'i', 'n', 'g', '\n',
        'u', 'n', 'c', 'h', 'a', 'p', 'e', 'r', 'o', 'n', 'e', 'd', '\n',
        'u', 'n', 'c', 'h', 'a', 'r', 'a', 'c', 't', 'e', 'r', 'i', 's', 't', 'i', 'c', '\n',
        'u', 'n', 'c', 'h', 'a', 'r', 'a', 'c', 't', 'e', 'r', 'i', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'u', 'n', 'c', 'h', 'a', 'r', 'g', 'e', 'd', '\n',
        'u', 'n', 'c', 'h', 'a', 'r', 'i', 's', 'm', 'a', 't', 'i', 'c', '\n',
        'u', 'n', 'c', 'h', 'a', 'r', 'i', 't', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'c', 'h', 'a', 'r', 'i', 't', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 'c', 'h', 'a', 'r', 't', 'e', 'd', '\n',
        'u', 'n', 'c', 'h', 'a', 'r', 't', 'e', 'r', 'e', 'd', '\n',
        'u', 'n', 'c', 'h', 'e', 'c', 'k', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'c', 'h', 'e', 'c', 'k', 'e', 'd', '\n',
        'u', 'n', 'c', 'h', 'r', 'i', 's', 't', 'e', 'n', 'e', 'd', '\n',
        'u', 'n', 'c', 'h', 'r', 'i', 's', 't', 'i', 'a', 'n', '\n',
        'u', 'n', 'c', 'h', 'r', 'o', 'n', 'i', 'c', 'l', 'e', 'd', '\n',
        'u', 'n', 'c', 'i', 'r', 'c', 'u', 'm', 'c', 'i', 's', 'e', 'd', '\n',
        'u', 'n', 'c', 'i', 'v', 'i', 'l', '\n',
        'u', 'n', 'c', 'i', 'v', 'i', 'l', 'i', 's', 'e', 'd', '\n',
        'u', 'n', 'c', 'l', 'a', 'd', '\n',
        'u', 'n', 'c', 'l', 'a', 'i', 'm', 'e', 'd', '\n',
        'u', 'n', 'c', 'l', 'a', 's', 'p', 'e', 'd', '\n',
        'u', 'n', 'c', 'l', 'a', 's', 'p', 'i', 'n', 'g', '\n',
        'u', 'n', 'c', 'l', 'a', 's', 's', 'i', 'f', 'i', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'c', 'l', 'a', 's', 's', 'i', 'f', 'i', 'e', 'd', '\n',
        'u', 'n', 'c', 'l', 'e', '\n',
        'u', 'n', 'c', 'l', 'e', 'a', 'n', '\n',
        'u', 'n', 'c', 'l', 'e', 'a', 'n', 'l', 'i', 'n', 'e', 's', 's', '\n',
        'u', 'n', 'c', 'l', 'e', 'a', 'n', 'l', 'y', '\n',
        'u', 'n', 'c', 'l', 'e', 'a', 'r', '\n',
        'u', 'n', 'c', 'l', 'e', 'a', 'r', 'e', 'd', '\n',
        'u', 'n', 'c', 'l', 'e', 'n', 'c', 'h', '\n',
        'u', 'n', 'c', 'l', 'e', 'n', 'c', 'h', 'e', 'd', '\n',
        'u', 'n', 'c', 'l', 'e', 'n', 'c', 'h', 'i', 'n', 'g', '\n',
        'u', 'n', 'c', 'l', 'e', 's', '\n',
        'u', 'n', 'c', 'l', 'e', 's', 'a', 'm', '\n',
        'u', 'n', 'c', 'l', 'i', 'm', 'b', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'c', 'l', 'i', 'm', 'b', 'e', 'd', '\n',
        'u', 'n', 'c', 'l', 'o', 'g', '\n',
        'u', 'n', 'c', 'l', 'o', 's', 'e', 'd', '\n',
        'u', 'n', 'c', 'l', 'o', 't', 'h', 'e', 'd', '\n',
        'u', 'n', 'c', 'l', 'o', 'u', 'd', 'e', 'd', '\n',
        'u', 'n', 'c', 'l', 'u', 't', 't', 'e', 'r', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'i', 'l', '\n',
        'u', 'n', 'c', 'o', 'i', 'l', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'i', 'l', 'i', 'n', 'g', '\n',
        'u', 'n', 'c', 'o', 'i', 'l', 's', '\n',
        'u', 'n', 'c', 'o', 'l', 'l', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'l', 'l', 'e', 'c', 't', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'l', 'l', 'i', 'm', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'm', 'b', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'm', 'e', 'l', 'y', '\n',
        'u', 'n', 'c', 'o', 'm', 'f', 'o', 'r', 't', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'c', 'o', 'm', 'f', 'o', 'r', 't', 'a', 'b', 'l', 'e', 'n', 'e', 's', 's', '\n',
        'u', 'n', 'c', 'o', 'm', 'f', 'o', 'r', 't', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 'c', 'o', 'm', 'm', 'i', 't', 't', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'm', 'm', 'o', 'n', '\n',
        'u', 'n', 'c', 'o', 'm', 'm', 'o', 'n', 'l', 'y', '\n',
        'u', 'n', 'c', 'o', 'm', 'm', 'u', 'n', 'i', 'c', 'a', 't', 'i', 'v', 'e', '\n',
        'u', 'n', 'c', 'o', 'm', 'p', 'e', 't', 'i', 't', 'i', 'v', 'e', '\n',
        'u', 'n', 'c', 'o', 'm', 'p', 'e', 't', 'i', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'u', 'n', 'c', 'o', 'm', 'p', 'i', 'l', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'c', 'o', 'm', 'p', 'l', 'a', 'i', 'n', 'i', 'n', 'g', '\n',
        'u', 'n', 'c', 'o', 'm', 'p', 'l', 'a', 'i', 'n', 'i', 'n', 'g', 'l', 'y', '\n',
        'u', 'n', 'c', 'o', 'm', 'p', 'l', 'e', 't', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'm', 'p', 'l', 'i', 'c', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'm', 'p', 'l', 'i', 'm', 'e', 'n', 't', 'a', 'r', 'y', '\n',
        'u', 'n', 'c', 'o', 'm', 'p', 'r', 'e', 'h', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'u', 'n', 'c', 'o', 'm', 'p', 'r', 'e', 'h', 'e', 'n', 'd', 'i', 'n', 'g', 'l', 'y', '\n',
        'u', 'n', 'c', 'o', 'm', 'p', 'r', 'e', 's', 's', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'm', 'p', 'r', 'o', 'm', 'i', 's', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'c', 'o', 'm', 'p', 'r', 'o', 'm', 'i', 's', 'i', 'n', 'g', '\n',
        'u', 'n', 'c', 'o', 'm', 'p', 'r', 'o', 'm', 'i', 's', 'i', 'n', 'g', 'l', 'y', '\n',
        'u', 'n', 'c', 'o', 'n', 'c', 'e', 'r', 'n', '\n',
        'u', 'n', 'c', 'o', 'n', 'c', 'e', 'r', 'n', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'n', 'c', 'e', 'r', 'n', 'e', 'd', 'l', 'y', '\n',
        'u', 'n', 'c', 'o', 'n', 'd', 'i', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'u', 'n', 'c', 'o', 'n', 'd', 'i', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'u', 'n', 'c', 'o', 'n', 'd', 'i', 't', 'i', 'o', 'n', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'n', 'f', 'i', 'n', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'n', 'f', 'i', 'r', 'm', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'n', 'f', 'u', 's', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'n', 'g', 'e', 'n', 'i', 'a', 'l', '\n',
        'u', 'n', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'n', 'q', 'u', 'e', 'r', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'c', 'o', 'n', 'q', 'u', 'e', 'r', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'n', 's', 'c', 'i', 'o', 'n', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'c', 'o', 'n', 's', 'c', 'i', 'o', 'n', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 'c', 'o', 'n', 's', 'c', 'i', 'o', 'u', 's', '\n',
        'u', 'n', 'c', 'o', 'n', 's', 'c', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'u', 'n', 'c', 'o', 'n', 's', 'c', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'u', 'n', 'c', 'o', 'n', 's', 'e', 'c', 'r', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'n', 's', 'i', 'd', 'e', 'r', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'n', 's', 'o', 'l', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'n', 's', 't', 'i', 't', 'u', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'u', 'n', 'c', 'o', 'n', 's', 't', 'i', 't', 'u', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'u', 'n', 'c', 'o', 'n', 's', 't', 'r', 'a', 'i', 'n', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'n', 's', 'u', 'm', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'n', 't', 'a', 'i', 'n', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'c', 'o', 'n', 't', 'a', 'm', 'i', 'n', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'n', 't', 'e', 'n', 't', 'i', 'o', 'u', 's', '\n',
        'u', 'n', 'c', 'o', 'n', 't', 'e', 's', 't', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'n', 't', 'r', 'o', 'l', 'l', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'c', 'o', 'n', 't', 'r', 'o', 'l', 'l', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 'c', 'o', 'n', 't', 'r', 'o', 'l', 'l', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'n', 't', 'r', 'o', 'v', 'e', 'r', 's', 'i', 'a', 'l', '\n',
        'u', 'n', 'c', 'o', 'n', 't', 'r', 'o', 'v', 'e', 'r', 's', 'i', 'a', 'l', 'l', 'y', '\n',
        'u', 'n', 'c', 'o', 'n', 'v', 'e', 'n', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'u', 'n', 'c', 'o', 'n', 'v', 'e', 'n', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'u', 'n', 'c', 'o', 'n', 'v', 'e', 'r', 't', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'n', 'v', 'i', 'n', 'c', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'n', 'v', 'i', 'n', 'c', 'i', 'n', 'g', '\n',
        'u', 'n', 'c', 'o', 'n', 'v', 'i', 'n', 'c', 'i', 'n', 'g', 'l', 'y', '\n',
        'u', 'n', 'c', 'o', 'o', 'k', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'o', 'p', 'e', 'r', 'a', 't', 'i', 'v', 'e', '\n',
        'u', 'n', 'c', 'o', 'o', 'r', 'd', 'i', 'n', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'r', 'k', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'r', 'r', 'e', 'c', 't', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'c', 'o', 'r', 'r', 'e', 'c', 't', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'r', 'r', 'e', 'l', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'r', 'r', 'o', 'b', 'o', 'r', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'r', 'r', 'u', 'p', 't', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'u', 'n', 't', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'c', 'o', 'u', 'n', 't', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 'c', 'o', 'u', 'n', 't', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'u', 'p', 'l', 'e', '\n',
        'u', 'n', 'c', 'o', 'u', 'p', 'l', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'u', 't', 'h', '\n',
        'u', 'n', 'c', 'o', 'u', 't', 'h', 'n', 'e', 's', 's', '\n',
        'u', 'n', 'c', 'o', 'v', 'e', 'r', '\n',
        'u', 'n', 'c', 'o', 'v', 'e', 'r', 'e', 'd', '\n',
        'u', 'n', 'c', 'o', 'v', 'e', 'r', 'i', 'n', 'g', '\n',
        'u', 'n', 'c', 'o', 'v', 'e', 'r', 's', '\n',
        'u', 'n', 'c', 'r', 'a', 'c', 'k', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'c', 'r', 'e', 'a', 's', 'e', 'd', '\n',
        'u', 'n', 'c', 'r', 'e', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'c', 'r', 'e', 'a', 't', 'i', 'v', 'e', '\n',
        'u', 'n', 'c', 'r', 'e', 'd', 'i', 't', 'e', 'd', '\n',
        'u', 'n', 'c', 'r', 'i', 't', 'i', 'c', 'a', 'l', '\n',
        'u', 'n', 'c', 'r', 'i', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'u', 'n', 'c', 'r', 'o', 's', 's', '\n',
        'u', 'n', 'c', 'r', 'o', 's', 's', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'c', 'r', 'o', 's', 's', 'e', 'd', '\n',
        'u', 'n', 'c', 'r', 'o', 'w', 'd', 'e', 'd', '\n',
        'u', 'n', 'c', 'r', 'o', 'w', 'n', 'e', 'd', '\n',
        'u', 'n', 'c', 'r', 'u', 's', 'h', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'c', 't', 'i', 'o', 'n', '\n',
        'u', 'n', 'c', 't', 'u', 'o', 'u', 's', '\n',
        'u', 'n', 'c', 't', 'u', 'o', 'u', 's', 'l', 'y', '\n',
        'u', 'n', 'c', 'u', 'l', 't', 'i', 'v', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'c', 'u', 'l', 't', 'u', 'r', 'e', 'd', '\n',
        'u', 'n', 'c', 'u', 'r', 'e', 'd', '\n',
        'u', 'n', 'c', 'u', 'r', 'l', 'e', 'd', '\n',
        'u', 'n', 'c', 'u', 't', '\n',
        'u', 'n', 'd', 'a', 'm', 'a', 'g', 'e', 'd', '\n',
        'u', 'n', 'd', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'd', 'a', 'u', 'n', 't', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'a', 'd', '\n',
        'u', 'n', 'd', 'e', 'c', 'e', 'i', 'v', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'c', 'i', 'd', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'u', 'n', 'd', 'e', 'c', 'i', 'd', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'd', 'e', 'c', 'i', 'd', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'c', 'l', 'a', 'r', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'c', 'o', 'r', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'f', 'e', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'f', 'e', 'n', 'd', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'f', 'i', 'l', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'f', 'i', 'n', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'd', 'e', 'f', 'i', 'n', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'l', 'i', 'v', 'e', 'r', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'd', 'e', 'l', 'i', 'v', 'e', 'r', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'm', 'a', 'n', 'd', 'i', 'n', 'g', '\n',
        'u', 'n', 'd', 'e', 'm', 'o', 'c', 'r', 'a', 't', 'i', 'c', '\n',
        'u', 'n', 'd', 'e', 'm', 'o', 'c', 'r', 'a', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'u', 'n', 'd', 'e', 'm', 'o', 'n', 's', 't', 'r', 'a', 't', 'i', 'v', 'e', '\n',
        'u', 'n', 'd', 'e', 'n', 'i', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'd', 'e', 'n', 'i', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 'd', 'e', 'r', '\n',
        'u', 'n', 'd', 'e', 'r', 'a', 'c', 'h', 'i', 'e', 'v', 'e', 'm', 'e', 'n', 't', '\n',
        'u', 'n', 'd', 'e', 'r', 'a', 'c', 'h', 'i', 'e', 'v', 'i', 'n', 'g', '\n',
        'u', 'n', 'd', 'e', 'r', 'a', 'r', 'm', '\n',
        'u', 'n', 'd', 'e', 'r', 'b', 'e', 'l', 'l', 'y', '\n',
        'u', 'n', 'd', 'e', 'r', 'b', 'o', 'd', 'y', '\n',
        'u', 'n', 'd', 'e', 'r', 'c', 'a', 'r', 'r', 'i', 'a', 'g', 'e', '\n',
        'u', 'n', 'd', 'e', 'r', 'c', 'l', 'a', 's', 's', '\n',
        'u', 'n', 'd', 'e', 'r', 'c', 'l', 'o', 't', 'h', 'e', 's', '\n',
        'u', 'n', 'd', 'e', 'r', 'c', 'l', 'o', 't', 'h', 'i', 'n', 'g', '\n',
        'u', 'n', 'd', 'e', 'r', 'c', 'o', 'a', 't', '\n',
        'u', 'n', 'd', 'e', 'r', 'c', 'o', 'a', 't', 'i', 'n', 'g', '\n',
        'u', 'n', 'd', 'e', 'r', 'c', 'o', 'o', 'k', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'r', 'c', 'o', 'v', 'e', 'r', '\n',
        'u', 'n', 'd', 'e', 'r', 'c', 'r', 'o', 'f', 't', '\n',
        'u', 'n', 'd', 'e', 'r', 'c', 'u', 'r', 'r', 'e', 'n', 't', '\n',
        'u', 'n', 'd', 'e', 'r', 'c', 'u', 'r', 'r', 'e', 'n', 't', 's', '\n',
        'u', 'n', 'd', 'e', 'r', 'c', 'u', 't', '\n',
        'u', 'n', 'd', 'e', 'r', 'c', 'u', 't', 's', '\n',
        'u', 'n', 'd', 'e', 'r', 'c', 'u', 't', 't', 'i', 'n', 'g', '\n',
        'u', 'n', 'd', 'e', 'r', 'd', 'e', 'v', 'e', 'l', 'o', 'p', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'r', 'd', 'e', 'v', 'e', 'l', 'o', 'p', 'm', 'e', 'n', 't', '\n',
        'u', 'n', 'd', 'e', 'r', 'd', 'o', 'g', '\n',
        'u', 'n', 'd', 'e', 'r', 'd', 'o', 'g', 's', '\n',
        'u', 'n', 'd', 'e', 'r', 'd', 'o', 'n', 'e', '\n',
        'u', 'n', 'd', 'e', 'r', 'e', 'd', 'u', 'c', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'r', 'e', 'm', 'p', 'h', 'a', 's', 'i', 's', '\n',
        'u', 'n', 'd', 'e', 'r', 'e', 'm', 'p', 'l', 'o', 'y', 'm', 'e', 'n', 't', '\n',
        'u', 'n', 'd', 'e', 'r', 'e', 's', 't', 'i', 'm', 'a', 't', 'e', '\n',
        'u', 'n', 'd', 'e', 'r', 'e', 's', 't', 'i', 'm', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'r', 'e', 's', 't', 'i', 'm', 'a', 't', 'e', 's', '\n',
        'u', 'n', 'd', 'e', 'r', 'e', 's', 't', 'i', 'm', 'a', 't', 'i', 'n', 'g', '\n',
        'u', 'n', 'd', 'e', 'r', 'e', 's', 't', 'i', 'm', 'a', 't', 'i', 'o', 'n', '\n',
        'u', 'n', 'd', 'e', 'r', 'e', 'x', 'p', 'l', 'o', 'i', 't', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'r', 'f', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'r', 'f', 'l', 'o', 'o', 'r', '\n',
        'u', 'n', 'd', 'e', 'r', 'f', 'l', 'o', 'w', '\n',
        'u', 'n', 'd', 'e', 'r', 'f', 'o', 'o', 't', '\n',
        'u', 'n', 'd', 'e', 'r', 'f', 'r', 'a', 'm', 'e', '\n',
        'u', 'n', 'd', 'e', 'r', 'f', 'u', 'n', 'd', '\n',
        'u', 'n', 'd', 'e', 'r', 'f', 'u', 'n', 'd', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'r', 'f', 'u', 'n', 'd', 'i', 'n', 'g', '\n',
        'u', 'n', 'd', 'e', 'r', 'g', 'a', 'r', 'm', 'e', 'n', 't', '\n',
        'u', 'n', 'd', 'e', 'r', 'g', 'a', 'r', 'm', 'e', 'n', 't', 's', '\n',
        'u', 'n', 'd', 'e', 'r', 'g', 'o', '\n',
        'u', 'n', 'd', 'e', 'r', 'g', 'o', 'e', 's', '\n',
        'u', 'n', 'd', 'e', 'r', 'g', 'o', 'i', 'n', 'g', '\n',
        'u', 'n', 'd', 'e', 'r', 'g', 'o', 'n', 'e', '\n',
        'u', 'n', 'd', 'e', 'r', 'g', 'r', 'a', 'd', 'u', 'a', 't', 'e', '\n',
        'u', 'n', 'd', 'e', 'r', 'g', 'r', 'a', 'd', 'u', 'a', 't', 'e', 's', '\n',
        'u', 'n', 'd', 'e', 'r', 'g', 'r', 'o', 'u', 'n', 'd', '\n',
        'u', 'n', 'd', 'e', 'r', 'g', 'r', 'o', 'u', 'n', 'd', 's', '\n',
        'u', 'n', 'd', 'e', 'r', 'g', 'r', 'o', 'w', 't', 'h', '\n',
        'u', 'n', 'd', 'e', 'r', 'h', 'a', 'n', 'd', '\n',
        'u', 'n', 'd', 'e', 'r', 'i', 'n', 'v', 'e', 's', 't', 'm', 'e', 'n', 't', '\n',
        'u', 'n', 'd', 'e', 'r', 'l', 'a', 'i', 'n', '\n',
        'u', 'n', 'd', 'e', 'r', 'l', 'a', 'y', '\n',
        'u', 'n', 'd', 'e', 'r', 'l', 'i', 'e', '\n',
        'u', 'n', 'd', 'e', 'r', 'l', 'i', 'e', 's', '\n',
        'u', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', '\n',
        'u', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'e', 's', '\n',
        'u', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'g', '\n',
        'u', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'g', 's', '\n',
        'u', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'i', 'n', 'g', '\n',
        'u', 'n', 'd', 'e', 'r', 'l', 'i', 'n', 'i', 'n', 'g', 's', '\n',
        'u', 'n', 'd', 'e', 'r', 'l', 'o', 'a', 'd', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'r', 'l', 'y', 'i', 'n', 'g', '\n',
        'u', 'n', 'd', 'e', 'r', 'm', 'a', 'n', 'n', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'r', 'm', 'i', 'n', 'e', '\n',
        'u', 'n', 'd', 'e', 'r', 'm', 'i', 'n', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'r', 'm', 'i', 'n', 'e', 's', '\n',
        'u', 'n', 'd', 'e', 'r', 'm', 'i', 'n', 'i', 'n', 'g', '\n',
        'u', 'n', 'd', 'e', 'r', 'n', 'e', 'a', 't', 'h', '\n',
        'u', 'n', 'd', 'e', 'r', 'n', 'o', 'u', 'r', 'i', 's', 'h', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'r', 'n', 'o', 'u', 'r', 'i', 's', 'h', 'm', 'e', 'n', 't', '\n',
        'u', 'n', 'd', 'e', 'r', 'p', 'a', 'i', 'd', '\n',
        'u', 'n', 'd', 'e', 'r', 'p', 'a', 'n', 't', 's', '\n',
        'u', 'n', 'd', 'e', 'r', 'p', 'a', 'r', 't', 's', '\n',
        'u', 'n', 'd', 'e', 'r', 'p', 'a', 's', 's', '\n',
        'u', 'n', 'd', 'e', 'r', 'p', 'a', 'y', '\n',
        'u', 'n', 'd', 'e', 'r', 'p', 'a', 'y', 'i', 'n', 'g', '\n',
        'u', 'n', 'd', 'e', 'r', 'p', 'e', 'r', 'f', 'o', 'r', 'm', 'a', 'n', 'c', 'e', '\n',
        'u', 'n', 'd', 'e', 'r', 'p', 'e', 'r', 'f', 'o', 'r', 'm', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'r', 'p', 'i', 'n', '\n',
        'u', 'n', 'd', 'e', 'r', 'p', 'i', 'n', 'n', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'r', 'p', 'i', 'n', 'n', 'i', 'n', 'g', '\n',
        'u', 'n', 'd', 'e', 'r', 'p', 'i', 'n', 'n', 'i', 'n', 'g', 's', '\n',
        'u', 'n', 'd', 'e', 'r', 'p', 'i', 'n', 's', '\n',
        'u', 'n', 'd', 'e', 'r', 'p', 'l', 'a', 'y', '\n',
        'u', 'n', 'd', 'e', 'r', 'p', 'l', 'a', 'y', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'r', 'p', 'l', 'a', 'y', 's', '\n',
        'u', 'n', 'd', 'e', 'r', 'p', 'o', 'p', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'r', 'p', 'o', 'p', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'u', 'n', 'd', 'e', 'r', 'p', 'o', 'w', 'e', 'r', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'r', 'p', 'r', 'i', 'c', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'r', 'p', 'r', 'i', 'c', 'i', 'n', 'g', '\n',
        'u', 'n', 'd', 'e', 'r', 'p', 'r', 'i', 'v', 'i', 'l', 'e', 'g', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'r', 'r', 'a', 't', 'e', '\n',
        'u', 'n', 'd', 'e', 'r', 'r', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'r', 's', 'c', 'o', 'r', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'r', 's', 'e', 'a', '\n',
        'u', 'n', 'd', 'e', 'r', 's', 'i', 'd', 'e', '\n',
        'u', 'n', 'd', 'e', 'r', 's', 'i', 'd', 'e', 's', '\n',
        'u', 'n', 'd', 'e', 'r', 's', 'i', 'g', 'n', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'r', 's', 'i', 'z', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'r', 's', 'k', 'i', 'r', 't', '\n',
        'u', 'n', 'd', 'e', 'r', 's', 't', 'a', 'f', 'f', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'r', 's', 't', 'a', 'n', 'd', '\n',
        'u', 'n', 'd', 'e', 'r', 's', 't', 'a', 'n', 'd', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'u', 'n', 'd', 'e', 'r', 's', 't', 'a', 'n', 'd', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'd', 'e', 'r', 's', 't', 'a', 'n', 'd', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 'd', 'e', 'r', 's', 't', 'a', 'n', 'd', 'e', 'r', '\n',
        'u', 'n', 'd', 'e', 'r', 's', 't', 'a', 'n', 'd', 'i', 'n', 'g', '\n',
        'u', 'n', 'd', 'e', 'r', 's', 't', 'a', 'n', 'd', 'i', 'n', 'g', 'l', 'y', '\n',
        'u', 'n', 'd', 'e', 'r', 's', 't', 'a', 'n', 'd', 'i', 'n', 'g', 's', '\n',
        'u', 'n', 'd', 'e', 'r', 's', 't', 'a', 'n', 'd', 's', '\n',
        'u', 'n', 'd', 'e', 'r', 's', 't', 'a', 't', 'e', '\n',
        'u', 'n', 'd', 'e', 'r', 's', 't', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'r', 's', 't', 'a', 't', 'e', 'm', 'e', 'n', 't', '\n',
        'u', 'n', 'd', 'e', 'r', 's', 't', 'a', 't', 'e', 's', '\n',
        'u', 'n', 'd', 'e', 'r', 's', 't', 'a', 't', 'i', 'n', 'g', '\n',
        'u', 'n', 'd', 'e', 'r', 's', 't', 'o', 'c', 'k', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'r', 's', 't', 'o', 'o', 'd', '\n',
        'u', 'n', 'd', 'e', 'r', 's', 't', 'o', 'r', 'e', 'y', '\n',
        'u', 'n', 'd', 'e', 'r', 's', 't', 'u', 'd', 'y', '\n',
        'u', 'n', 'd', 'e', 'r', 't', 'a', 'k', 'e', '\n',
        'u', 'n', 'd', 'e', 'r', 't', 'a', 'k', 'e', 'n', '\n',
        'u', 'n', 'd', 'e', 'r', 't', 'a', 'k', 'e', 'r', '\n',
        'u', 'n', 'd', 'e', 'r', 't', 'a', 'k', 'e', 'r', 's', '\n',
        'u', 'n', 'd', 'e', 'r', 't', 'a', 'k', 'e', 's', '\n',
        'u', 'n', 'd', 'e', 'r', 't', 'a', 'k', 'i', 'n', 'g', '\n',
        'u', 'n', 'd', 'e', 'r', 't', 'a', 'k', 'i', 'n', 'g', 's', '\n',
        'u', 'n', 'd', 'e', 'r', 't', 'o', 'n', 'e', '\n',
        'u', 'n', 'd', 'e', 'r', 't', 'o', 'n', 'e', 's', '\n',
        'u', 'n', 'd', 'e', 'r', 't', 'o', 'o', 'k', '\n',
        'u', 'n', 'd', 'e', 'r', 'u', 't', 'i', 'l', 'i', 's', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'r', 'v', 'a', 'l', 'u', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'r', 'v', 'a', 'l', 'u', 'e', 's', '\n',
        'u', 'n', 'd', 'e', 'r', 'v', 'a', 'l', 'u', 'i', 'n', 'g', '\n',
        'u', 'n', 'd', 'e', 'r', 'w', 'a', 't', 'e', 'r', '\n',
        'u', 'n', 'd', 'e', 'r', 'w', 'e', 'a', 'r', '\n',
        'u', 'n', 'd', 'e', 'r', 'w', 'e', 'i', 'g', 'h', 't', '\n',
        'u', 'n', 'd', 'e', 'r', 'w', 'e', 'n', 't', '\n',
        'u', 'n', 'd', 'e', 'r', 'w', 'o', 'o', 'd', '\n',
        'u', 'n', 'd', 'e', 'r', 'w', 'o', 'r', 'l', 'd', '\n',
        'u', 'n', 'd', 'e', 'r', 'w', 'r', 'i', 't', 'e', '\n',
        'u', 'n', 'd', 'e', 'r', 'w', 'r', 'i', 't', 'e', 'r', '\n',
        'u', 'n', 'd', 'e', 'r', 'w', 'r', 'i', 't', 'e', 'r', 's', '\n',
        'u', 'n', 'd', 'e', 'r', 'w', 'r', 'i', 't', 'e', 's', '\n',
        'u', 'n', 'd', 'e', 'r', 'w', 'r', 'i', 't', 'i', 'n', 'g', '\n',
        'u', 'n', 'd', 'e', 'r', 'w', 'r', 'i', 't', 't', 'e', 'n', '\n',
        'u', 'n', 'd', 'e', 'r', 'w', 'r', 'o', 't', 'e', '\n',
        'u', 'n', 'd', 'e', 's', 'e', 'r', 'v', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 's', 'e', 'r', 'v', 'e', 'd', 'l', 'y', '\n',
        'u', 'n', 'd', 'e', 's', 'e', 'r', 'v', 'i', 'n', 'g', '\n',
        'u', 'n', 'd', 'e', 's', 'i', 'r', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'u', 'n', 'd', 'e', 's', 'i', 'r', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'd', 'e', 's', 'i', 'r', 'a', 'b', 'l', 'e', 's', '\n',
        'u', 'n', 'd', 'e', 's', 'i', 'r', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 'd', 'e', 's', 'i', 'r', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 't', 'e', 'c', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'u', 'n', 'd', 'e', 't', 'e', 'c', 't', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'd', 'e', 't', 'e', 'c', 't', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 'd', 'e', 't', 'e', 'c', 't', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 't', 'e', 'r', 'm', 'i', 'n', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 't', 'e', 'r', 'r', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 't', 'o', 'n', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'd', 'e', 'v', 'e', 'l', 'o', 'p', 'e', 'd', '\n',
        'u', 'n', 'd', 'i', 'a', 'g', 'n', 'o', 's', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'd', 'i', 'a', 'g', 'n', 'o', 's', 'e', 'd', '\n',
        'u', 'n', 'd', 'i', 'd', '\n',
        'u', 'n', 'd', 'i', 'f', 'f', 'e', 'r', 'e', 'n', 't', 'i', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'd', 'i', 'g', 'e', 's', 't', 'e', 'd', '\n',
        'u', 'n', 'd', 'i', 'g', 'n', 'i', 'f', 'i', 'e', 'd', '\n',
        'u', 'n', 'd', 'i', 'l', 'u', 't', 'e', 'd', '\n',
        'u', 'n', 'd', 'i', 'm', 'i', 'n', 'i', 's', 'h', 'e', 'd', '\n',
        'u', 'n', 'd', 'i', 'p', 'l', 'o', 'm', 'a', 't', 'i', 'c', '\n',
        'u', 'n', 'd', 'i', 'r', 'e', 'c', 't', 'e', 'd', '\n',
        'u', 'n', 'd', 'i', 's', 'c', 'e', 'r', 'n', 'i', 'n', 'g', '\n',
        'u', 'n', 'd', 'i', 's', 'c', 'i', 'p', 'l', 'i', 'n', 'e', 'd', '\n',
        'u', 'n', 'd', 'i', 's', 'c', 'l', 'o', 's', 'e', 'd', '\n',
        'u', 'n', 'd', 'i', 's', 'c', 'o', 'v', 'e', 'r', 'e', 'd', '\n',
        'u', 'n', 'd', 'i', 's', 'c', 'r', 'i', 'm', 'i', 'n', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'd', 'i', 's', 'c', 'r', 'i', 'm', 'i', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'u', 'n', 'd', 'i', 's', 'g', 'u', 'i', 's', 'e', 'd', '\n',
        'u', 'n', 'd', 'i', 's', 'g', 'u', 'i', 's', 'e', 'd', 'l', 'y', '\n',
        'u', 'n', 'd', 'i', 's', 'm', 'a', 'y', 'e', 'd', '\n',
        'u', 'n', 'd', 'i', 's', 'p', 'l', 'a', 'y', 'e', 'd', '\n',
        'u', 'n', 'd', 'i', 's', 'p', 'u', 't', 'e', 'd', '\n',
        'u', 'n', 'd', 'i', 's', 's', 'i', 'p', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'd', 'i', 's', 't', 'i', 'n', 'g', 'u', 'i', 's', 'h', 'e', 'd', '\n',
        'u', 'n', 'd', 'i', 's', 't', 'o', 'r', 't', 'e', 'd', '\n',
        'u', 'n', 'd', 'i', 's', 't', 'r', 'i', 'b', 'u', 't', 'e', 'd', '\n',
        'u', 'n', 'd', 'i', 's', 't', 'u', 'r', 'b', 'e', 'd', '\n',
        'u', 'n', 'd', 'i', 'v', 'i', 'd', 'e', 'd', '\n',
        'u', 'n', 'd', 'o', '\n',
        'u', 'n', 'd', 'o', 'c', 'u', 'm', 'e', 'n', 't', 'e', 'd', '\n',
        'u', 'n', 'd', 'o', 'i', 'n', 'g', '\n',
        'u', 'n', 'd', 'o', 'i', 'n', 'g', 's', '\n',
        'u', 'n', 'd', 'o', 'm', 'e', 's', 't', 'i', 'c', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'd', 'o', 'n', 'e', '\n',
        'u', 'n', 'd', 'o', 'u', 'b', 't', 'e', 'd', '\n',
        'u', 'n', 'd', 'o', 'u', 'b', 't', 'e', 'd', 'l', 'y', '\n',
        'u', 'n', 'd', 'r', 'e', 's', 's', '\n',
        'u', 'n', 'd', 'r', 'e', 's', 's', 'e', 'd', '\n',
        'u', 'n', 'd', 'r', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'u', 'n', 'd', 'r', 'i', 'n', 'k', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'u', 'n', 'd', 'r', 'i', 'n', 'k', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'd', 'r', 'o', 'p', 'p', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'd', 'u', 'e', '\n',
        'u', 'n', 'd', 'u', 'l', 'a', 't', 'e', '\n',
        'u', 'n', 'd', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'd', 'u', 'l', 'a', 't', 'e', 's', '\n',
        'u', 'n', 'd', 'u', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'u', 'n', 'd', 'u', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'u', 'n', 'd', 'u', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'u', 'n', 'd', 'u', 'l', 'y', '\n',
        'u', 'n', 'd', 'y', 'i', 'n', 'g', '\n',
        'u', 'n', 'e', 'a', 'r', 'n', 'e', 'd', '\n',
        'u', 'n', 'e', 'a', 'r', 't', 'h', '\n',
        'u', 'n', 'e', 'a', 'r', 't', 'h', 'e', 'd', '\n',
        'u', 'n', 'e', 'a', 'r', 't', 'h', 'i', 'n', 'g', '\n',
        'u', 'n', 'e', 'a', 'r', 't', 'h', 'l', 'y', '\n',
        'u', 'n', 'e', 'a', 'r', 't', 'h', 's', '\n',
        'u', 'n', 'e', 'a', 's', 'e', '\n',
        'u', 'n', 'e', 'a', 's', 'i', 'e', 'r', '\n',
        'u', 'n', 'e', 'a', 's', 'i', 'e', 's', 't', '\n',
        'u', 'n', 'e', 'a', 's', 'i', 'l', 'y', '\n',
        'u', 'n', 'e', 'a', 's', 'i', 'n', 'e', 's', 's', '\n',
        'u', 'n', 'e', 'a', 's', 'y', '\n',
        'u', 'n', 'e', 'a', 't', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'e', 'a', 't', 'e', 'n', '\n',
        'u', 'n', 'e', 'c', 'o', 'n', 'o', 'm', 'i', 'c', '\n',
        'u', 'n', 'e', 'c', 'o', 'n', 'o', 'm', 'i', 'c', 'a', 'l', '\n',
        'u', 'n', 'e', 'd', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'u', 'n', 'e', 'd', 'i', 't', 'e', 'd', '\n',
        'u', 'n', 'e', 'd', 'u', 'c', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'e', 'l', 'e', 'c', 't', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'e', 'l', 'e', 'c', 't', 'e', 'd', '\n',
        'u', 'n', 'e', 'm', 'o', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'u', 'n', 'e', 'm', 'o', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'u', 'n', 'e', 'm', 'p', 'l', 'o', 'y', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'e', 'm', 'p', 'l', 'o', 'y', 'e', 'd', '\n',
        'u', 'n', 'e', 'm', 'p', 'l', 'o', 'y', 'm', 'e', 'n', 't', '\n',
        'u', 'n', 'e', 'n', 'c', 'r', 'y', 'p', 't', 'e', 'd', '\n',
        'u', 'n', 'e', 'n', 'c', 'u', 'm', 'b', 'e', 'r', 'e', 'd', '\n',
        'u', 'n', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'u', 'n', 'e', 'n', 'd', 'i', 'n', 'g', 'l', 'y', '\n',
        'u', 'n', 'e', 'n', 'd', 'u', 'r', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'e', 'n', 'f', 'o', 'r', 'c', 'e', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'e', 'n', 'g', 'a', 'g', 'e', 'd', '\n',
        'u', 'n', 'e', 'n', 'l', 'i', 'g', 'h', 't', 'e', 'n', 'e', 'd', '\n',
        'u', 'n', 'e', 'n', 'l', 'i', 'g', 'h', 't', 'e', 'n', 'i', 'n', 'g', '\n',
        'u', 'n', 'e', 'n', 't', 'e', 'r', 'e', 'd', '\n',
        'u', 'n', 'e', 'n', 't', 'h', 'u', 's', 'i', 'a', 's', 't', 'i', 'c', '\n',
        'u', 'n', 'e', 'n', 't', 'h', 'u', 's', 'i', 'a', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'u', 'n', 'e', 'n', 'v', 'i', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'e', 'q', 'u', 'a', 'l', '\n',
        'u', 'n', 'e', 'q', 'u', 'a', 'l', 'l', 'e', 'd', '\n',
        'u', 'n', 'e', 'q', 'u', 'a', 'l', 'l', 'y', '\n',
        'u', 'n', 'e', 'q', 'u', 'i', 'v', 'o', 'c', 'a', 'l', '\n',
        'u', 'n', 'e', 'q', 'u', 'i', 'v', 'o', 'c', 'a', 'l', 'l', 'y', '\n',
        'u', 'n', 'e', 'r', 'g', 'o', 'n', 'o', 'm', 'i', 'c', '\n',
        'u', 'n', 'e', 'r', 'r', 'i', 'n', 'g', '\n',
        'u', 'n', 'e', 'r', 'r', 'i', 'n', 'g', 'l', 'y', '\n',
        'u', 'n', 'e', 's', 'c', 'o', 'r', 't', 'e', 'd', '\n',
        'u', 'n', 'e', 's', 't', 'a', 'b', 'l', 'i', 's', 'h', 'e', 'd', '\n',
        'u', 'n', 'e', 't', 'h', 'i', 'c', 'a', 'l', '\n',
        'u', 'n', 'e', 't', 'h', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'u', 'n', 'e', 'v', 'a', 'l', 'u', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'e', 'v', 'e', 'n', '\n',
        'u', 'n', 'e', 'v', 'e', 'n', 'l', 'y', '\n',
        'u', 'n', 'e', 'v', 'e', 'n', 'n', 'e', 's', 's', '\n',
        'u', 'n', 'e', 'v', 'e', 'n', 't', 'f', 'u', 'l', '\n',
        'u', 'n', 'e', 'v', 'e', 'n', 't', 'f', 'u', 'l', 'l', 'y', '\n',
        'u', 'n', 'e', 'x', 'a', 'c', 't', 'i', 'n', 'g', '\n',
        'u', 'n', 'e', 'x', 'a', 'm', 'i', 'n', 'e', 'd', '\n',
        'u', 'n', 'e', 'x', 'c', 'e', 'p', 't', 'i', 'o', 'n', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'e', 'x', 'c', 'e', 'p', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'u', 'n', 'e', 'x', 'c', 'i', 't', 'e', 'd', '\n',
        'u', 'n', 'e', 'x', 'c', 'i', 't', 'i', 'n', 'g', '\n',
        'u', 'n', 'e', 'x', 'p', 'a', 'n', 'd', 'e', 'd', '\n',
        'u', 'n', 'e', 'x', 'p', 'e', 'c', 't', 'e', 'd', '\n',
        'u', 'n', 'e', 'x', 'p', 'e', 'c', 't', 'e', 'd', 'l', 'y', '\n',
        'u', 'n', 'e', 'x', 'p', 'e', 'c', 't', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'u', 'n', 'e', 'x', 'p', 'i', 'r', 'e', 'd', '\n',
        'u', 'n', 'e', 'x', 'p', 'l', 'a', 'i', 'n', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'e', 'x', 'p', 'l', 'a', 'i', 'n', 'e', 'd', '\n',
        'u', 'n', 'e', 'x', 'p', 'l', 'o', 'd', 'e', 'd', '\n',
        'u', 'n', 'e', 'x', 'p', 'l', 'o', 'i', 't', 'e', 'd', '\n',
        'u', 'n', 'e', 'x', 'p', 'l', 'o', 'r', 'e', 'd', '\n',
        'u', 'n', 'e', 'x', 'p', 'r', 'e', 's', 's', 'e', 'd', '\n',
        'u', 'n', 'e', 'x', 'p', 'u', 'r', 'g', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'f', 'a', 'i', 'l', 'i', 'n', 'g', '\n',
        'u', 'n', 'f', 'a', 'i', 'l', 'i', 'n', 'g', 'l', 'y', '\n',
        'u', 'n', 'f', 'a', 'i', 'r', '\n',
        'u', 'n', 'f', 'a', 'i', 'r', 'l', 'y', '\n',
        'u', 'n', 'f', 'a', 'i', 'r', 'n', 'e', 's', 's', '\n',
        'u', 'n', 'f', 'a', 'i', 't', 'h', 'f', 'u', 'l', '\n',
        'u', 'n', 'f', 'a', 'i', 't', 'h', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'u', 'n', 'f', 'a', 'l', 's', 'i', 'f', 'i', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'f', 'a', 'm', 'i', 'l', 'i', 'a', 'r', '\n',
        'u', 'n', 'f', 'a', 'm', 'i', 'l', 'i', 'a', 'r', 'i', 't', 'y', '\n',
        'u', 'n', 'f', 'a', 'n', 'c', 'i', 'e', 'd', '\n',
        'u', 'n', 'f', 'a', 's', 'h', 'i', 'o', 'n', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'f', 'a', 's', 'h', 'i', 'o', 'n', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 'f', 'a', 's', 't', 'e', 'n', '\n',
        'u', 'n', 'f', 'a', 's', 't', 'e', 'n', 'e', 'd', '\n',
        'u', 'n', 'f', 'a', 's', 't', 'e', 'n', 'i', 'n', 'g', '\n',
        'u', 'n', 'f', 'a', 't', 'h', 'o', 'm', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'f', 'a', 't', 'h', 'o', 'm', 'e', 'd', '\n',
        'u', 'n', 'f', 'a', 't', 'i', 'g', 'u', 'e', 'd', '\n',
        'u', 'n', 'f', 'a', 'v', 'o', 'u', 'r', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'f', 'a', 'v', 'o', 'u', 'r', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 'f', 'a', 'v', 'o', 'u', 'r', 'e', 'd', '\n',
        'u', 'n', 'f', 'e', 'a', 's', 'i', 'b', 'l', 'e', '\n',
        'u', 'n', 'f', 'e', 'a', 's', 'i', 'b', 'l', 'y', '\n',
        'u', 'n', 'f', 'e', 'd', '\n',
        'u', 'n', 'f', 'e', 'e', 'l', 'i', 'n', 'g', '\n',
        'u', 'n', 'f', 'e', 'e', 'l', 'i', 'n', 'g', 'l', 'y', '\n',
        'u', 'n', 'f', 'e', 'i', 'g', 'n', 'e', 'd', '\n',
        'u', 'n', 'f', 'e', 'l', 't', '\n',
        'u', 'n', 'f', 'e', 'm', 'i', 'n', 'i', 'n', 'e', '\n',
        'u', 'n', 'f', 'e', 'n', 'c', 'e', 'd', '\n',
        'u', 'n', 'f', 'e', 'r', 't', 'i', 'l', 'i', 's', 'e', 'd', '\n',
        'u', 'n', 'f', 'e', 't', 'c', 'h', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'f', 'e', 't', 't', 'e', 'r', 'e', 'd', '\n',
        'u', 'n', 'f', 'i', 'l', 'l', 'e', 'd', '\n',
        'u', 'n', 'f', 'i', 'n', 'i', 's', 'h', 'e', 'd', '\n',
        'u', 'n', 'f', 'i', 'r', 'e', 'd', '\n',
        'u', 'n', 'f', 'i', 'r', 'm', '\n',
        'u', 'n', 'f', 'i', 't', '\n',
        'u', 'n', 'f', 'i', 't', 'n', 'e', 's', 's', '\n',
        'u', 'n', 'f', 'i', 't', 's', '\n',
        'u', 'n', 'f', 'i', 't', 't', 'i', 'n', 'g', '\n',
        'u', 'n', 'f', 'i', 'x', '\n',
        'u', 'n', 'f', 'i', 'x', 'e', 'd', '\n',
        'u', 'n', 'f', 'l', 'a', 'g', 'g', 'i', 'n', 'g', '\n',
        'u', 'n', 'f', 'l', 'a', 't', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'u', 'n', 'f', 'l', 'a', 'w', 'e', 'd', '\n',
        'u', 'n', 'f', 'l', 'e', 'd', 'g', 'e', 'd', '\n',
        'u', 'n', 'f', 'l', 'i', 'n', 'c', 'h', 'i', 'n', 'g', '\n',
        'u', 'n', 'f', 'l', 'i', 'n', 'c', 'h', 'i', 'n', 'g', 'l', 'y', '\n',
        'u', 'n', 'f', 'o', 'c', 'u', 's', 'e', 'd', '\n',
        'u', 'n', 'f', 'o', 'c', 'u', 's', 's', 'e', 'd', '\n',
        'u', 'n', 'f', 'o', 'l', 'd', '\n',
        'u', 'n', 'f', 'o', 'l', 'd', 'e', 'd', '\n',
        'u', 'n', 'f', 'o', 'l', 'd', 'i', 'n', 'g', '\n',
        'u', 'n', 'f', 'o', 'l', 'd', 's', '\n',
        'u', 'n', 'f', 'o', 'r', 'c', 'e', 'd', '\n',
        'u', 'n', 'f', 'o', 'r', 'd', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'f', 'o', 'r', 'e', 's', 'e', 'e', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'f', 'o', 'r', 'e', 's', 'e', 'e', 'n', '\n',
        'u', 'n', 'f', 'o', 'r', 'g', 'e', 't', 't', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'f', 'o', 'r', 'g', 'i', 'v', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'f', 'o', 'r', 'g', 'i', 'v', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 'f', 'o', 'r', 'g', 'i', 'v', 'e', 'n', '\n',
        'u', 'n', 'f', 'o', 'r', 'g', 'i', 'v', 'i', 'n', 'g', '\n',
        'u', 'n', 'f', 'o', 'r', 'm', 'e', 'd', '\n',
        'u', 'n', 'f', 'o', 'r', 't', 'h', 'c', 'o', 'm', 'i', 'n', 'g', '\n',
        'u', 'n', 'f', 'o', 'r', 't', 'u', 'n', 'a', 't', 'e', '\n',
        'u', 'n', 'f', 'o', 'r', 't', 'u', 'n', 'a', 't', 'e', 'l', 'y', '\n',
        'u', 'n', 'f', 'o', 'r', 't', 'u', 'n', 'a', 't', 'e', 's', '\n',
        'u', 'n', 'f', 'o', 'u', 'n', 'd', 'e', 'd', '\n',
        'u', 'n', 'f', 'r', 'e', 'e', 'z', 'e', '\n',
        'u', 'n', 'f', 'r', 'e', 'e', 'z', 'i', 'n', 'g', '\n',
        'u', 'n', 'f', 'r', 'e', 'q', 'u', 'e', 'n', 't', 'e', 'd', '\n',
        'u', 'n', 'f', 'r', 'i', 'e', 'n', 'd', 'l', 'i', 'e', 'r', '\n',
        'u', 'n', 'f', 'r', 'i', 'e', 'n', 'd', 'l', 'i', 'e', 's', 't', '\n',
        'u', 'n', 'f', 'r', 'i', 'e', 'n', 'd', 'l', 'i', 'n', 'e', 's', 's', '\n',
        'u', 'n', 'f', 'r', 'i', 'e', 'n', 'd', 'l', 'y', '\n',
        'u', 'n', 'f', 'r', 'o', 'z', 'e', 'n', '\n',
        'u', 'n', 'f', 'r', 'u', 'i', 't', 'f', 'u', 'l', '\n',
        'u', 'n', 'f', 'u', 'l', 'f', 'i', 'l', 'l', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'f', 'u', 'l', 'f', 'i', 'l', 'l', 'e', 'd', '\n',
        'u', 'n', 'f', 'u', 'n', 'd', 'e', 'd', '\n',
        'u', 'n', 'f', 'u', 'n', 'n', 'y', '\n',
        'u', 'n', 'f', 'u', 'r', 'l', '\n',
        'u', 'n', 'f', 'u', 'r', 'l', 'e', 'd', '\n',
        'u', 'n', 'f', 'u', 'r', 'l', 'i', 'n', 'g', '\n',
        'u', 'n', 'f', 'u', 'r', 'l', 's', '\n',
        'u', 'n', 'f', 'u', 'r', 'n', 'i', 's', 'h', 'e', 'd', '\n',
        'u', 'n', 'f', 'u', 's', 's', 'y', '\n',
        'u', 'n', 'g', 'a', 'i', 'n', 'l', 'y', '\n',
        'u', 'n', 'g', 'e', 'n', 'e', 'r', 'o', 'u', 's', '\n',
        'u', 'n', 'g', 'e', 'n', 'e', 'r', 'o', 'u', 's', 'l', 'y', '\n',
        'u', 'n', 'g', 'e', 'n', 't', 'l', 'e', 'm', 'a', 'n', 'l', 'y', '\n',
        'u', 'n', 'g', 'e', 'r', 'm', 'i', 'n', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'g', 'l', 'a', 'm', 'o', 'r', 'o', 'u', 's', '\n',
        'u', 'n', 'g', 'l', 'a', 'z', 'e', 'd', '\n',
        'u', 'n', 'g', 'o', 'd', 'l', 'y', '\n',
        'u', 'n', 'g', 'o', 'v', 'e', 'r', 'n', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'g', 'o', 'v', 'e', 'r', 'n', 'e', 'd', '\n',
        'u', 'n', 'g', 'r', 'a', 'c', 'e', 'f', 'u', 'l', '\n',
        'u', 'n', 'g', 'r', 'a', 'c', 'i', 'o', 'u', 's', '\n',
        'u', 'n', 'g', 'r', 'a', 'c', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'u', 'n', 'g', 'r', 'a', 'm', 'm', 'a', 't', 'i', 'c', 'a', 'l', '\n',
        'u', 'n', 'g', 'r', 'a', 't', 'e', 'f', 'u', 'l', '\n',
        'u', 'n', 'g', 'r', 'a', 't', 'e', 'f', 'u', 'l', 'l', 'y', '\n',
        'u', 'n', 'g', 'r', 'o', 'u', 'n', 'd', 'e', 'd', '\n',
        'u', 'n', 'g', 'u', 'a', 'r', 'd', 'e', 'd', '\n',
        'u', 'n', 'g', 'u', 'e', 's', 's', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'g', 'u', 'i', 'd', 'e', 'd', '\n',
        'u', 'n', 'g', 'u', 'l', 'a', 't', 'e', 's', '\n',
        'u', 'n', 'h', 'a', 'm', 'p', 'e', 'r', 'e', 'd', '\n',
        'u', 'n', 'h', 'a', 'n', 'd', '\n',
        'u', 'n', 'h', 'a', 'n', 'd', 'y', '\n',
        'u', 'n', 'h', 'a', 'p', 'p', 'i', 'e', 'r', '\n',
        'u', 'n', 'h', 'a', 'p', 'p', 'i', 'e', 's', 't', '\n',
        'u', 'n', 'h', 'a', 'p', 'p', 'i', 'l', 'y', '\n',
        'u', 'n', 'h', 'a', 'p', 'p', 'i', 'n', 'e', 's', 's', '\n',
        'u', 'n', 'h', 'a', 'p', 'p', 'y', '\n',
        'u', 'n', 'h', 'a', 'r', 'm', 'e', 'd', '\n',
        'u', 'n', 'h', 'e', 'a', 'l', 't', 'h', 'i', 'e', 'r', '\n',
        'u', 'n', 'h', 'e', 'a', 'l', 't', 'h', 'i', 'e', 's', 't', '\n',
        'u', 'n', 'h', 'e', 'a', 'l', 't', 'h', 'i', 'l', 'y', '\n',
        'u', 'n', 'h', 'e', 'a', 'l', 't', 'h', 'y', '\n',
        'u', 'n', 'h', 'e', 'a', 'r', 'd', '\n',
        'u', 'n', 'h', 'e', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'h', 'e', 'e', 'd', 'e', 'd', '\n',
        'u', 'n', 'h', 'e', 'l', 'p', 'f', 'u', 'l', '\n',
        'u', 'n', 'h', 'e', 'l', 'p', 'f', 'u', 'l', 'l', 'y', '\n',
        'u', 'n', 'h', 'e', 'r', 'a', 'l', 'd', 'e', 'd', '\n',
        'u', 'n', 'h', 'e', 'r', 'o', 'i', 'c', '\n',
        'u', 'n', 'h', 'e', 's', 'i', 't', 'a', 't', 'i', 'n', 'g', '\n',
        'u', 'n', 'h', 'e', 's', 'i', 't', 'a', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'u', 'n', 'h', 'i', 'd', 'd', 'e', 'n', '\n',
        'u', 'n', 'h', 'i', 'n', 'd', 'e', 'r', 'e', 'd', '\n',
        'u', 'n', 'h', 'i', 'n', 'g', 'e', '\n',
        'u', 'n', 'h', 'i', 'n', 'g', 'e', 'd', '\n',
        'u', 'n', 'h', 'o', 'l', 'y', '\n',
        'u', 'n', 'h', 'o', 'n', 'o', 'u', 'r', 'e', 'd', '\n',
        'u', 'n', 'h', 'o', 'o', 'k', '\n',
        'u', 'n', 'h', 'o', 'o', 'k', 'e', 'd', '\n',
        'u', 'n', 'h', 'o', 'o', 'k', 's', '\n',
        'u', 'n', 'h', 'o', 'p', 'e', 'd', '\n',
        'u', 'n', 'h', 'u', 'm', 'a', 'n', '\n',
        'u', 'n', 'h', 'u', 'r', 'r', 'i', 'e', 'd', '\n',
        'u', 'n', 'h', 'u', 'r', 'r', 'i', 'e', 'd', 'l', 'y', '\n',
        'u', 'n', 'h', 'u', 'r', 't', '\n',
        'u', 'n', 'h', 'y', 'g', 'i', 'e', 'n', 'i', 'c', '\n',
        'u', 'n', 'h', 'y', 'p', 'h', 'e', 'n', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'i', 'c', 'a', 'm', 'e', 'r', 'a', 'l', '\n',
        'u', 'n', 'i', 'c', 'e', 'l', 'l', 'u', 'l', 'a', 'r', '\n',
        'u', 'n', 'i', 'c', 'o', 'r', 'n', '\n',
        'u', 'n', 'i', 'c', 'o', 'r', 'n', 's', '\n',
        'u', 'n', 'i', 'c', 'y', 'c', 'l', 'e', '\n',
        'u', 'n', 'i', 'c', 'y', 'c', 'l', 'e', 's', '\n',
        'u', 'n', 'i', 'c', 'y', 'c', 'l', 'i', 's', 't', '\n',
        'u', 'n', 'i', 'c', 'y', 'c', 'l', 'i', 's', 't', 's', '\n',
        'u', 'n', 'i', 'd', 'e', 'a', 'l', '\n',
        'u', 'n', 'i', 'd', 'e', 'n', 't', 'i', 'f', 'i', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'i', 'd', 'e', 'n', 't', 'i', 'f', 'i', 'e', 'd', '\n',
        'u', 'n', 'i', 'd', 'i', 'r', 'e', 'c', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'u', 'n', 'i', 'f', 'i', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'u', 'n', 'i', 'f', 'i', 'e', 'd', '\n',
        'u', 'n', 'i', 'f', 'i', 'e', 'r', '\n',
        'u', 'n', 'i', 'f', 'i', 'e', 's', '\n',
        'u', 'n', 'i', 'f', 'o', 'r', 'm', '\n',
        'u', 'n', 'i', 'f', 'o', 'r', 'm', 'e', 'd', '\n',
        'u', 'n', 'i', 'f', 'o', 'r', 'm', 'i', 't', 'y', '\n',
        'u', 'n', 'i', 'f', 'o', 'r', 'm', 'l', 'y', '\n',
        'u', 'n', 'i', 'f', 'o', 'r', 'm', 's', '\n',
        'u', 'n', 'i', 'f', 'y', '\n',
        'u', 'n', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'u', 'n', 'i', 'l', 'a', 't', 'e', 'r', 'a', 'l', '\n',
        'u', 'n', 'i', 'l', 'a', 't', 'e', 'r', 'a', 'l', 'i', 's', 'm', '\n',
        'u', 'n', 'i', 'l', 'a', 't', 'e', 'r', 'a', 'l', 'i', 's', 't', '\n',
        'u', 'n', 'i', 'l', 'a', 't', 'e', 'r', 'a', 'l', 'l', 'y', '\n',
        'u', 'n', 'i', 'l', 'l', 'u', 's', 't', 'r', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'i', 'm', 'a', 'g', 'i', 'n', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'i', 'm', 'a', 'g', 'i', 'n', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 'i', 'm', 'a', 'g', 'i', 'n', 'a', 't', 'i', 'v', 'e', '\n',
        'u', 'n', 'i', 'm', 'a', 'g', 'i', 'n', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'u', 'n', 'i', 'm', 'a', 'g', 'i', 'n', 'e', 'd', '\n',
        'u', 'n', 'i', 'm', 'p', 'a', 'i', 'r', 'e', 'd', '\n',
        'u', 'n', 'i', 'm', 'p', 'e', 'a', 'c', 'h', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'i', 'm', 'p', 'e', 'd', 'e', 'd', '\n',
        'u', 'n', 'i', 'm', 'p', 'l', 'e', 'm', 'e', 'n', 't', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'i', 'm', 'p', 'l', 'e', 'm', 'e', 'n', 't', 'e', 'd', '\n',
        'u', 'n', 'i', 'm', 'p', 'o', 'r', 't', 'a', 'n', 'c', 'e', '\n',
        'u', 'n', 'i', 'm', 'p', 'o', 'r', 't', 'a', 'n', 't', '\n',
        'u', 'n', 'i', 'm', 'p', 'r', 'e', 's', 's', 'e', 'd', '\n',
        'u', 'n', 'i', 'm', 'p', 'r', 'e', 's', 's', 'i', 'v', 'e', '\n',
        'u', 'n', 'i', 'm', 'p', 'r', 'o', 'v', 'e', 'd', '\n',
        'u', 'n', 'i', 'n', 'c', 'o', 'r', 'p', 'o', 'r', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'i', 'n', 'f', 'e', 'c', 't', 'e', 'd', '\n',
        'u', 'n', 'i', 'n', 'f', 'l', 'u', 'e', 'n', 'c', 'e', 'd', '\n',
        'u', 'n', 'i', 'n', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'v', 'e', '\n',
        'u', 'n', 'i', 'n', 'f', 'o', 'r', 'm', 'a', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'u', 'n', 'i', 'n', 'f', 'o', 'r', 'm', 'e', 'd', '\n',
        'u', 'n', 'i', 'n', 'h', 'a', 'b', 'i', 't', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'i', 'n', 'h', 'a', 'b', 'i', 't', 'e', 'd', '\n',
        'u', 'n', 'i', 'n', 'h', 'i', 'b', 'i', 't', 'e', 'd', '\n',
        'u', 'n', 'i', 'n', 'h', 'i', 'b', 'i', 't', 'e', 'd', 'l', 'y', '\n',
        'u', 'n', 'i', 'n', 'i', 't', 'i', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'u', 'n', 'i', 'n', 'i', 't', 'i', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'i', 'n', 'j', 'u', 'r', 'e', 'd', '\n',
        'u', 'n', 'i', 'n', 's', 'p', 'i', 'r', 'e', 'd', '\n',
        'u', 'n', 'i', 'n', 's', 'p', 'i', 'r', 'i', 'n', 'g', '\n',
        'u', 'n', 'i', 'n', 's', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'i', 'n', 's', 'u', 'r', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'i', 'n', 's', 'u', 'r', 'e', 'd', '\n',
        'u', 'n', 'i', 'n', 't', 'e', 'l', 'l', 'e', 'c', 't', 'u', 'a', 'l', '\n',
        'u', 'n', 'i', 'n', 't', 'e', 'l', 'l', 'i', 'g', 'e', 'n', 't', '\n',
        'u', 'n', 'i', 'n', 't', 'e', 'l', 'l', 'i', 'g', 'i', 'b', 'l', 'e', '\n',
        'u', 'n', 'i', 'n', 't', 'e', 'n', 'd', 'e', 'd', '\n',
        'u', 'n', 'i', 'n', 't', 'e', 'n', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'u', 'n', 'i', 'n', 't', 'e', 'n', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'u', 'n', 'i', 'n', 't', 'e', 'r', 'e', 's', 't', 'e', 'd', '\n',
        'u', 'n', 'i', 'n', 't', 'e', 'r', 'e', 's', 't', 'e', 'd', 'l', 'y', '\n',
        'u', 'n', 'i', 'n', 't', 'e', 'r', 'e', 's', 't', 'i', 'n', 'g', '\n',
        'u', 'n', 'i', 'n', 't', 'e', 'r', 'p', 'r', 'e', 't', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'i', 'n', 't', 'e', 'r', 'p', 'r', 'e', 't', 'e', 'd', '\n',
        'u', 'n', 'i', 'n', 't', 'e', 'r', 'r', 'u', 'p', 't', 'e', 'd', '\n',
        'u', 'n', 'i', 'n', 't', 'e', 'r', 'r', 'u', 'p', 't', 'e', 'd', 'l', 'y', '\n',
        'u', 'n', 'i', 'n', 't', 'u', 'i', 't', 'i', 'v', 'e', '\n',
        'u', 'n', 'i', 'n', 'v', 'e', 'n', 't', 'e', 'd', '\n',
        'u', 'n', 'i', 'n', 'v', 'i', 't', 'e', 'd', '\n',
        'u', 'n', 'i', 'n', 'v', 'i', 't', 'i', 'n', 'g', '\n',
        'u', 'n', 'i', 'n', 'v', 'o', 'l', 'v', 'e', 'd', '\n',
        'u', 'n', 'i', 'o', 'n', '\n',
        'u', 'n', 'i', 'o', 'n', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'u', 'n', 'i', 'o', 'n', 'i', 's', 'e', 'd', '\n',
        'u', 'n', 'i', 'o', 'n', 'i', 's', 'm', '\n',
        'u', 'n', 'i', 'o', 'n', 'i', 's', 't', '\n',
        'u', 'n', 'i', 'o', 'n', 'i', 's', 't', 's', '\n',
        'u', 'n', 'i', 'o', 'n', 's', '\n',
        'u', 'n', 'i', 'p', 'o', 'l', 'a', 'r', '\n',
        'u', 'n', 'i', 'q', 'u', 'e', '\n',
        'u', 'n', 'i', 'q', 'u', 'e', 'l', 'y', '\n',
        'u', 'n', 'i', 'q', 'u', 'e', 'n', 'e', 's', 's', '\n',
        'u', 'n', 'i', 's', 'e', 'x', '\n',
        'u', 'n', 'i', 's', 'o', 'n', '\n',
        'u', 'n', 'i', 's', 'o', 'n', 's', '\n',
        'u', 'n', 'i', 's', 's', 'u', 'e', 'd', '\n',
        'u', 'n', 'i', 't', '\n',
        'u', 'n', 'i', 't', 'a', 'r', 'y', '\n',
        'u', 'n', 'i', 't', 'e', '\n',
        'u', 'n', 'i', 't', 'e', 'd', '\n',
        'u', 'n', 'i', 't', 'e', 's', '\n',
        'u', 'n', 'i', 't', 'i', 'e', 's', '\n',
        'u', 'n', 'i', 't', 'i', 'n', 'g', '\n',
        'u', 'n', 'i', 't', 's', '\n',
        'u', 'n', 'i', 't', 'y', '\n',
        'u', 'n', 'i', 'v', 'e', 'r', 's', 'a', 'l', '\n',
        'u', 'n', 'i', 'v', 'e', 'r', 's', 'a', 'l', 'i', 's', 'm', '\n',
        'u', 'n', 'i', 'v', 'e', 'r', 's', 'a', 'l', 'i', 's', 't', '\n',
        'u', 'n', 'i', 'v', 'e', 'r', 's', 'a', 'l', 'i', 't', 'y', '\n',
        'u', 'n', 'i', 'v', 'e', 'r', 's', 'a', 'l', 'l', 'y', '\n',
        'u', 'n', 'i', 'v', 'e', 'r', 's', 'a', 'l', 's', '\n',
        'u', 'n', 'i', 'v', 'e', 'r', 's', 'e', '\n',
        'u', 'n', 'i', 'v', 'e', 'r', 's', 'e', 's', '\n',
        'u', 'n', 'i', 'v', 'e', 'r', 's', 'i', 't', 'i', 'e', 's', '\n',
        'u', 'n', 'i', 'v', 'e', 'r', 's', 'i', 't', 'y', '\n',
        'u', 'n', 'j', 'a', 'm', '\n',
        'u', 'n', 'j', 'a', 'm', 'm', 'e', 'd', '\n',
        'u', 'n', 'j', 'a', 'm', 'm', 'i', 'n', 'g', '\n',
        'u', 'n', 'j', 'a', 'u', 'n', 'd', 'i', 'c', 'e', 'd', '\n',
        'u', 'n', 'j', 'u', 's', 't', '\n',
        'u', 'n', 'j', 'u', 's', 't', 'i', 'f', 'i', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'j', 'u', 's', 't', 'i', 'f', 'i', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 'j', 'u', 's', 't', 'i', 'f', 'i', 'e', 'd', '\n',
        'u', 'n', 'j', 'u', 's', 't', 'l', 'y', '\n',
        'u', 'n', 'j', 'u', 's', 't', 'n', 'e', 's', 's', '\n',
        'u', 'n', 'k', 'e', 'm', 'p', 't', '\n',
        'u', 'n', 'k', 'e', 'p', 't', '\n',
        'u', 'n', 'k', 'i', 'n', 'd', '\n',
        'u', 'n', 'k', 'i', 'n', 'd', 'e', 's', 't', '\n',
        'u', 'n', 'k', 'i', 'n', 'd', 'l', 'y', '\n',
        'u', 'n', 'k', 'i', 'n', 'd', 'n', 'e', 's', 's', '\n',
        'u', 'n', 'k', 'n', 'i', 'g', 'h', 't', 'l', 'y', '\n',
        'u', 'n', 'k', 'n', 'o', 'w', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'k', 'n', 'o', 'w', 'i', 'n', 'g', '\n',
        'u', 'n', 'k', 'n', 'o', 'w', 'i', 'n', 'g', 'l', 'y', '\n',
        'u', 'n', 'k', 'n', 'o', 'w', 'n', '\n',
        'u', 'n', 'k', 'n', 'o', 'w', 'n', 's', '\n',
        'u', 'n', 'l', 'a', 'b', 'e', 'l', 'l', 'e', 'd', '\n',
        'u', 'n', 'l', 'a', 'c', 'e', '\n',
        'u', 'n', 'l', 'a', 'c', 'e', 'd', '\n',
        'u', 'n', 'l', 'a', 'c', 'i', 'n', 'g', '\n',
        'u', 'n', 'l', 'a', 'd', 'e', 'n', '\n',
        'u', 'n', 'l', 'a', 'd', 'y', 'l', 'i', 'k', 'e', '\n',
        'u', 'n', 'l', 'a', 'm', 'e', 'n', 't', 'e', 'd', '\n',
        'u', 'n', 'l', 'a', 't', 'c', 'h', 'i', 'n', 'g', '\n',
        'u', 'n', 'l', 'a', 'w', 'f', 'u', 'l', '\n',
        'u', 'n', 'l', 'a', 'w', 'f', 'u', 'l', 'l', 'y', '\n',
        'u', 'n', 'l', 'a', 'w', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'u', 'n', 'l', 'e', 'a', 'd', 'e', 'd', '\n',
        'u', 'n', 'l', 'e', 'a', 'r', 'n', '\n',
        'u', 'n', 'l', 'e', 'a', 'r', 'n', 'e', 'd', '\n',
        'u', 'n', 'l', 'e', 'a', 's', 'h', '\n',
        'u', 'n', 'l', 'e', 'a', 's', 'h', 'e', 'd', '\n',
        'u', 'n', 'l', 'e', 'a', 's', 'h', 'e', 's', '\n',
        'u', 'n', 'l', 'e', 'a', 's', 'h', 'i', 'n', 'g', '\n',
        'u', 'n', 'l', 'e', 'a', 'v', 'e', 'n', 'e', 'd', '\n',
        'u', 'n', 'l', 'e', 's', 's', '\n',
        'u', 'n', 'l', 'i', 'c', 'e', 'n', 's', 'e', 'd', '\n',
        'u', 'n', 'l', 'i', 'k', 'e', '\n',
        'u', 'n', 'l', 'i', 'k', 'e', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'l', 'i', 'k', 'e', 'l', 'i', 'e', 's', 't', '\n',
        'u', 'n', 'l', 'i', 'k', 'e', 'l', 'i', 'h', 'o', 'o', 'd', '\n',
        'u', 'n', 'l', 'i', 'k', 'e', 'l', 'i', 'n', 'e', 's', 's', '\n',
        'u', 'n', 'l', 'i', 'k', 'e', 'l', 'y', '\n',
        'u', 'n', 'l', 'i', 'm', 'i', 't', 'e', 'd', '\n',
        'u', 'n', 'l', 'i', 'n', 'e', 'd', '\n',
        'u', 'n', 'l', 'i', 'n', 'k', '\n',
        'u', 'n', 'l', 'i', 'n', 'k', 'e', 'd', '\n',
        'u', 'n', 'l', 'i', 's', 't', 'e', 'd', '\n',
        'u', 'n', 'l', 'i', 't', '\n',
        'u', 'n', 'l', 'o', 'a', 'd', '\n',
        'u', 'n', 'l', 'o', 'a', 'd', 'e', 'd', '\n',
        'u', 'n', 'l', 'o', 'a', 'd', 'i', 'n', 'g', '\n',
        'u', 'n', 'l', 'o', 'a', 'd', 's', '\n',
        'u', 'n', 'l', 'o', 'c', 'k', '\n',
        'u', 'n', 'l', 'o', 'c', 'k', 'e', 'd', '\n',
        'u', 'n', 'l', 'o', 'c', 'k', 'i', 'n', 'g', '\n',
        'u', 'n', 'l', 'o', 'c', 'k', 's', '\n',
        'u', 'n', 'l', 'o', 'o', 's', 'e', '\n',
        'u', 'n', 'l', 'o', 'v', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'l', 'o', 'v', 'e', 'd', '\n',
        'u', 'n', 'l', 'o', 'v', 'e', 'l', 'y', '\n',
        'u', 'n', 'l', 'o', 'v', 'i', 'n', 'g', '\n',
        'u', 'n', 'l', 'u', 'c', 'k', 'i', 'e', 'r', '\n',
        'u', 'n', 'l', 'u', 'c', 'k', 'i', 'e', 's', 't', '\n',
        'u', 'n', 'l', 'u', 'c', 'k', 'i', 'l', 'y', '\n',
        'u', 'n', 'l', 'u', 'c', 'k', 'y', '\n',
        'u', 'n', 'm', 'a', 'd', 'e', '\n',
        'u', 'n', 'm', 'a', 'g', 'n', 'i', 'f', 'i', 'e', 'd', '\n',
        'u', 'n', 'm', 'a', 'i', 'n', 't', 'a', 'i', 'n', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'm', 'a', 'i', 'n', 't', 'a', 'i', 'n', 'e', 'd', '\n',
        'u', 'n', 'm', 'a', 'k', 'i', 'n', 'g', '\n',
        'u', 'n', 'm', 'a', 'n', 'a', 'g', 'e', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'm', 'a', 'n', 'a', 'g', 'e', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 'm', 'a', 'n', 'l', 'y', '\n',
        'u', 'n', 'm', 'a', 'n', 'n', 'e', 'd', '\n',
        'u', 'n', 'm', 'a', 'n', 'n', 'e', 'r', 'l', 'y', '\n',
        'u', 'n', 'm', 'a', 'p', 'p', 'e', 'd', '\n',
        'u', 'n', 'm', 'a', 'r', 'k', 'e', 'd', '\n',
        'u', 'n', 'm', 'a', 'r', 'r', 'i', 'e', 'd', '\n',
        'u', 'n', 'm', 'a', 's', 'k', '\n',
        'u', 'n', 'm', 'a', 's', 'k', 'e', 'd', '\n',
        'u', 'n', 'm', 'a', 's', 'k', 's', '\n',
        'u', 'n', 'm', 'a', 't', 'c', 'h', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'm', 'a', 't', 'c', 'h', 'e', 'd', '\n',
        'u', 'n', 'm', 'e', 'a', 's', 'u', 'r', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'm', 'e', 'c', 'h', 'a', 'n', 'i', 's', 'e', 'd', '\n',
        'u', 'n', 'm', 'e', 'e', 't', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'm', 'e', 'l', 'o', 'd', 'i', 'o', 'u', 's', '\n',
        'u', 'n', 'm', 'e', 'm', 'o', 'r', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'm', 'e', 'm', 'o', 'r', 'i', 's', 'e', 'd', '\n',
        'u', 'n', 'm', 'e', 'n', 't', 'i', 'o', 'n', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'm', 'e', 'n', 't', 'i', 'o', 'n', 'a', 'b', 'l', 'e', 's', '\n',
        'u', 'n', 'm', 'e', 'n', 't', 'i', 'o', 'n', 'e', 'd', '\n',
        'u', 'n', 'm', 'e', 'r', 'c', 'i', 'f', 'u', 'l', 'l', 'y', '\n',
        'u', 'n', 'm', 'e', 'r', 'i', 't', 'e', 'd', '\n',
        'u', 'n', 'm', 'e', 't', '\n',
        'u', 'n', 'm', 'i', 's', 's', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'm', 'i', 's', 't', 'a', 'k', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'm', 'i', 's', 't', 'a', 'k', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 'm', 'i', 's', 't', 'a', 'k', 'e', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'm', 'i', 's', 't', 'a', 'k', 'e', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 'm', 'i', 't', 'i', 'g', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'm', 'i', 'x', 'e', 'd', '\n',
        'u', 'n', 'm', 'n', 'e', 'm', 'o', 'n', 'i', 'c', '\n',
        'u', 'n', 'm', 'o', 'd', 'i', 'f', 'i', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'm', 'o', 'd', 'i', 'f', 'i', 'e', 'd', '\n',
        'u', 'n', 'm', 'o', 'l', 'e', 's', 't', 'e', 'd', '\n',
        'u', 'n', 'm', 'o', 'n', 'i', 't', 'o', 'r', 'e', 'd', '\n',
        'u', 'n', 'm', 'o', 't', 'i', 'v', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'm', 'o', 'u', 'n', 't', 'e', 'd', '\n',
        'u', 'n', 'm', 'o', 'v', 'e', 'd', '\n',
        'u', 'n', 'm', 'o', 'v', 'i', 'n', 'g', '\n',
        'u', 'n', 'm', 'u', 's', 'i', 'c', 'a', 'l', '\n',
        'u', 'n', 'm', 'u', 's', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'u', 'n', 'm', 'u', 't', 'i', 'l', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'm', 'u', 'z', 'z', 'l', 'e', 'd', '\n',
        'u', 'n', 'n', 'a', 'm', 'e', 'd', '\n',
        'u', 'n', 'n', 'a', 't', 'u', 'r', 'a', 'l', '\n',
        'u', 'n', 'n', 'a', 't', 'u', 'r', 'a', 'l', 'l', 'y', '\n',
        'u', 'n', 'n', 'a', 'v', 'i', 'g', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'n', 'e', 'c', 'e', 's', 's', 'a', 'r', 'i', 'l', 'y', '\n',
        'u', 'n', 'n', 'e', 'c', 'e', 's', 's', 'a', 'r', 'y', '\n',
        'u', 'n', 'n', 'e', 'e', 'd', 'e', 'd', '\n',
        'u', 'n', 'n', 'e', 'r', 'v', 'e', '\n',
        'u', 'n', 'n', 'e', 'r', 'v', 'e', 'd', '\n',
        'u', 'n', 'n', 'e', 'r', 'v', 'i', 'n', 'g', '\n',
        'u', 'n', 'n', 'e', 'r', 'v', 'i', 'n', 'g', 'l', 'y', '\n',
        'u', 'n', 'n', 'o', 't', 'e', 'd', '\n',
        'u', 'n', 'n', 'o', 't', 'i', 'c', 'e', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'n', 'o', 't', 'i', 'c', 'e', 'd', '\n',
        'u', 'n', 'n', 'u', 'm', 'b', 'e', 'r', 'e', 'd', '\n',
        'u', 'n', 'o', 'b', 'j', 'e', 'c', 't', 'i', 'o', 'n', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'o', 'b', 'l', 'i', 'g', 'i', 'n', 'g', '\n',
        'u', 'n', 'o', 'b', 's', 'e', 'r', 'v', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'o', 'b', 's', 'e', 'r', 'v', 'a', 'n', 't', '\n',
        'u', 'n', 'o', 'b', 's', 'e', 'r', 'v', 'e', 'd', '\n',
        'u', 'n', 'o', 'b', 's', 't', 'r', 'u', 'c', 't', 'e', 'd', '\n',
        'u', 'n', 'o', 'b', 't', 'a', 'i', 'n', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'o', 'b', 't', 'r', 'u', 's', 'i', 'v', 'e', '\n',
        'u', 'n', 'o', 'b', 't', 'r', 'u', 's', 'i', 'v', 'e', 'l', 'y', '\n',
        'u', 'n', 'o', 'c', 'c', 'u', 'p', 'i', 'e', 'd', '\n',
        'u', 'n', 'o', 'f', 'f', 'i', 'c', 'i', 'a', 'l', '\n',
        'u', 'n', 'o', 'f', 'f', 'i', 'c', 'i', 'a', 'l', 'l', 'y', '\n',
        'u', 'n', 'o', 'p', 'e', 'n', 'e', 'd', '\n',
        'u', 'n', 'o', 'p', 'p', 'o', 's', 'e', 'd', '\n',
        'u', 'n', 'o', 'p', 't', 'i', 'm', 'i', 's', 'e', 'd', '\n',
        'u', 'n', 'o', 'r', 'd', 'e', 'r', 'e', 'd', '\n',
        'u', 'n', 'o', 'r', 'g', 'a', 'n', 'i', 's', 'e', 'd', '\n',
        'u', 'n', 'o', 'r', 'i', 'g', 'i', 'n', 'a', 'l', '\n',
        'u', 'n', 'o', 'r', 'i', 'g', 'i', 'n', 'a', 'l', 'i', 't', 'y', '\n',
        'u', 'n', 'o', 'r', 't', 'h', 'o', 'd', 'o', 'x', '\n',
        'u', 'n', 'o', 'r', 't', 'h', 'o', 'd', 'o', 'x', 'y', '\n',
        'u', 'n', 'o', 'w', 'n', 'e', 'd', '\n',
        'u', 'n', 'p', 'a', 'c', 'k', '\n',
        'u', 'n', 'p', 'a', 'c', 'k', 'e', 'd', '\n',
        'u', 'n', 'p', 'a', 'c', 'k', 'e', 'r', 's', '\n',
        'u', 'n', 'p', 'a', 'c', 'k', 'i', 'n', 'g', '\n',
        'u', 'n', 'p', 'a', 'c', 'k', 's', '\n',
        'u', 'n', 'p', 'a', 'i', 'd', '\n',
        'u', 'n', 'p', 'a', 'i', 'n', 't', 'e', 'd', '\n',
        'u', 'n', 'p', 'a', 'i', 'r', 'e', 'd', '\n',
        'u', 'n', 'p', 'a', 'l', 'a', 't', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'p', 'a', 'r', 'a', 'l', 'l', 'e', 'l', 'e', 'd', '\n',
        'u', 'n', 'p', 'a', 'r', 'd', 'o', 'n', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'p', 'a', 'r', 'o', 'd', 'i', 'e', 'd', '\n',
        'u', 'n', 'p', 'a', 's', 't', 'e', 'd', '\n',
        'u', 'n', 'p', 'a', 's', 't', 'e', 'u', 'r', 'i', 's', 'e', 'd', '\n',
        'u', 'n', 'p', 'a', 't', 'r', 'i', 'o', 't', 'i', 'c', '\n',
        'u', 'n', 'p', 'a', 'v', 'e', 'd', '\n',
        'u', 'n', 'p', 'e', 'e', 'l', 'e', 'd', '\n',
        'u', 'n', 'p', 'e', 'r', 'c', 'e', 'i', 'v', 'e', 'd', '\n',
        'u', 'n', 'p', 'e', 'r', 's', 'o', 'n', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'u', 'n', 'p', 'e', 'r', 's', 'u', 'a', 'd', 'e', 'd', '\n',
        'u', 'n', 'p', 'e', 'r', 's', 'u', 'a', 's', 'i', 'v', 'e', '\n',
        'u', 'n', 'p', 'e', 'r', 't', 'u', 'r', 'b', 'e', 'd', '\n',
        'u', 'n', 'p', 'h', 'y', 's', 'i', 'c', 'a', 'l', '\n',
        'u', 'n', 'p', 'i', 'c', 'k', '\n',
        'u', 'n', 'p', 'i', 'c', 'k', 'e', 'd', '\n',
        'u', 'n', 'p', 'i', 'c', 'k', 'i', 'n', 'g', '\n',
        'u', 'n', 'p', 'l', 'a', 'c', 'e', 'd', '\n',
        'u', 'n', 'p', 'l', 'a', 'n', 'n', 'e', 'd', '\n',
        'u', 'n', 'p', 'l', 'a', 'y', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'u', 'n', 'p', 'l', 'a', 'y', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'p', 'l', 'e', 'a', 's', 'a', 'n', 't', '\n',
        'u', 'n', 'p', 'l', 'e', 'a', 's', 'a', 'n', 't', 'l', 'y', '\n',
        'u', 'n', 'p', 'l', 'e', 'a', 's', 'a', 'n', 't', 'n', 'e', 's', 's', '\n',
        'u', 'n', 'p', 'l', 'e', 'a', 's', 'i', 'n', 'g', '\n',
        'u', 'n', 'p', 'l', 'o', 'u', 'g', 'h', 'e', 'd', '\n',
        'u', 'n', 'p', 'l', 'u', 'g', '\n',
        'u', 'n', 'p', 'l', 'u', 'g', 'g', 'e', 'd', '\n',
        'u', 'n', 'p', 'l', 'u', 'g', 'g', 'i', 'n', 'g', '\n',
        'u', 'n', 'p', 'o', 'e', 't', 'i', 'c', 'a', 'l', '\n',
        'u', 'n', 'p', 'o', 'l', 'i', 's', 'h', 'e', 'd', '\n',
        'u', 'n', 'p', 'o', 'l', 'l', 'u', 't', 'e', 'd', '\n',
        'u', 'n', 'p', 'o', 'p', 'u', 'l', 'a', 'r', '\n',
        'u', 'n', 'p', 'o', 'p', 'u', 'l', 'a', 'r', 'i', 't', 'y', '\n',
        'u', 'n', 'p', 'o', 'p', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'p', 'o', 'r', 't', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'p', 'r', 'a', 'c', 't', 'i', 'c', 'a', 'l', '\n',
        'u', 'n', 'p', 'r', 'a', 'c', 't', 'i', 's', 'e', 'd', '\n',
        'u', 'n', 'p', 'r', 'e', 'c', 'e', 'd', 'e', 'n', 't', 'e', 'd', '\n',
        'u', 'n', 'p', 'r', 'e', 'c', 'e', 'd', 'e', 'n', 't', 'e', 'd', 'l', 'y', '\n',
        'u', 'n', 'p', 'r', 'e', 'd', 'i', 'c', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'u', 'n', 'p', 'r', 'e', 'd', 'i', 'c', 't', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'p', 'r', 'e', 'd', 'i', 'c', 't', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 'p', 'r', 'e', 'd', 'i', 'c', 't', 'e', 'd', '\n',
        'u', 'n', 'p', 'r', 'e', 'j', 'u', 'd', 'i', 'c', 'e', 'd', '\n',
        'u', 'n', 'p', 'r', 'e', 'm', 'e', 'd', 'i', 't', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'p', 'r', 'e', 'p', 'a', 'r', 'e', 'd', '\n',
        'u', 'n', 'p', 'r', 'e', 'p', 'a', 'r', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'u', 'n', 'p', 'r', 'e', 'p', 'o', 's', 's', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'u', 'n', 'p', 'r', 'e', 's', 's', 'u', 'r', 'i', 's', 'e', 'd', '\n',
        'u', 'n', 'p', 'r', 'e', 't', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'u', 'n', 'p', 'r', 'e', 't', 'e', 'n', 't', 'i', 'o', 'u', 's', '\n',
        'u', 'n', 'p', 'r', 'i', 'n', 'c', 'i', 'p', 'l', 'e', 'd', '\n',
        'u', 'n', 'p', 'r', 'i', 'n', 't', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'p', 'r', 'i', 'n', 't', 'e', 'd', '\n',
        'u', 'n', 'p', 'r', 'i', 'v', 'i', 'l', 'e', 'g', 'e', 'd', '\n',
        'u', 'n', 'p', 'r', 'o', 'b', 'l', 'e', 'm', 'a', 't', 'i', 'c', '\n',
        'u', 'n', 'p', 'r', 'o', 'c', 'e', 's', 's', 'e', 'd', '\n',
        'u', 'n', 'p', 'r', 'o', 'd', 'u', 'c', 't', 'i', 'v', 'e', '\n',
        'u', 'n', 'p', 'r', 'o', 'f', 'e', 's', 's', 'i', 'o', 'n', 'a', 'l', '\n',
        'u', 'n', 'p', 'r', 'o', 'f', 'i', 't', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'p', 'r', 'o', 'f', 'i', 't', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 'p', 'r', 'o', 'm', 'i', 's', 'i', 'n', 'g', '\n',
        'u', 'n', 'p', 'r', 'o', 'm', 'p', 't', 'e', 'd', '\n',
        'u', 'n', 'p', 'r', 'o', 'n', 'o', 'u', 'n', 'c', 'e', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'p', 'r', 'o', 'n', 'o', 'u', 'n', 'c', 'e', 'd', '\n',
        'u', 'n', 'p', 'r', 'o', 't', 'e', 'c', 't', 'e', 'd', '\n',
        'u', 'n', 'p', 'r', 'o', 'v', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'p', 'r', 'o', 'v', 'e', 'd', '\n',
        'u', 'n', 'p', 'r', 'o', 'v', 'e', 'n', '\n',
        'u', 'n', 'p', 'r', 'o', 'v', 'o', 'k', 'e', 'd', '\n',
        'u', 'n', 'p', 'u', 'b', 'l', 'i', 'c', 'i', 's', 'e', 'd', '\n',
        'u', 'n', 'p', 'u', 'b', 'l', 'i', 's', 'h', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'p', 'u', 'b', 'l', 'i', 's', 'h', 'e', 'd', '\n',
        'u', 'n', 'p', 'u', 'n', 'c', 't', 'u', 'a', 'l', '\n',
        'u', 'n', 'p', 'u', 'n', 'c', 't', 'u', 'a', 'l', 'i', 't', 'y', '\n',
        'u', 'n', 'p', 'u', 'n', 'i', 's', 'h', 'e', 'd', '\n',
        'u', 'n', 'q', 'u', 'a', 'l', 'i', 'f', 'i', 'e', 'd', '\n',
        'u', 'n', 'q', 'u', 'a', 'n', 't', 'i', 'f', 'i', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'q', 'u', 'a', 'n', 't', 'i', 'f', 'i', 'e', 'd', '\n',
        'u', 'n', 'q', 'u', 'e', 'n', 'c', 'h', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'q', 'u', 'e', 's', 't', 'i', 'o', 'n', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'q', 'u', 'e', 's', 't', 'i', 'o', 'n', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 'q', 'u', 'e', 's', 't', 'i', 'o', 'n', 'e', 'd', '\n',
        'u', 'n', 'q', 'u', 'e', 's', 't', 'i', 'o', 'n', 'i', 'n', 'g', '\n',
        'u', 'n', 'q', 'u', 'e', 's', 't', 'i', 'o', 'n', 'i', 'n', 'g', 'l', 'y', '\n',
        'u', 'n', 'q', 'u', 'i', 'e', 't', '\n',
        'u', 'n', 'q', 'u', 'o', 't', 'e', '\n',
        'u', 'n', 'q', 'u', 'o', 't', 'e', 'd', '\n',
        'u', 'n', 'r', 'a', 'i', 's', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'r', 'a', 'v', 'e', 'l', '\n',
        'u', 'n', 'r', 'a', 'v', 'e', 'l', 'l', 'e', 'd', '\n',
        'u', 'n', 'r', 'a', 'v', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'u', 'n', 'r', 'a', 'v', 'e', 'l', 's', '\n',
        'u', 'n', 'r', 'e', 'a', 'c', 'h', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'r', 'e', 'a', 'c', 'h', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 'a', 'd', '\n',
        'u', 'n', 'r', 'e', 'a', 'd', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'u', 'n', 'r', 'e', 'a', 'd', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'r', 'e', 'a', 'd', 'y', '\n',
        'u', 'n', 'r', 'e', 'a', 'l', '\n',
        'u', 'n', 'r', 'e', 'a', 'l', 'i', 's', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'r', 'e', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 'a', 'l', 'i', 's', 't', 'i', 'c', '\n',
        'u', 'n', 'r', 'e', 'a', 'l', 'i', 's', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'u', 'n', 'r', 'e', 'a', 'l', 'i', 't', 'y', '\n',
        'u', 'n', 'r', 'e', 'a', 's', 'o', 'n', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'r', 'e', 'a', 's', 'o', 'n', 'a', 'b', 'l', 'e', 'n', 'e', 's', 's', '\n',
        'u', 'n', 'r', 'e', 'a', 's', 'o', 'n', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 'r', 'e', 'a', 's', 'o', 'n', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 'a', 's', 'o', 'n', 'i', 'n', 'g', '\n',
        'u', 'n', 'r', 'e', 'c', 'e', 'i', 'v', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 'c', 'e', 'p', 't', 'i', 'v', 'e', '\n',
        'u', 'n', 'r', 'e', 'c', 'o', 'g', 'n', 'i', 's', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'r', 'e', 'c', 'o', 'g', 'n', 'i', 's', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 'r', 'e', 'c', 'o', 'g', 'n', 'i', 's', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 'c', 'o', 'm', 'm', 'e', 'n', 'd', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 'c', 'o', 'n', 'c', 'i', 'l', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 'c', 'o', 'n', 's', 't', 'r', 'u', 'c', 't', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 'c', 'o', 'r', 'd', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 'c', 'o', 'v', 'e', 'r', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'r', 'e', 'd', 'e', 'e', 'm', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 'd', 'u', 'c', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 'f', 'e', 'r', 'e', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 'f', 'e', 'r', 'e', 'n', 'c', 'i', 'n', 'g', '\n',
        'u', 'n', 'r', 'e', 'f', 'i', 'n', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 'f', 'l', 'e', 'c', 't', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 'f', 'o', 'r', 'm', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 'f', 'r', 'e', 's', 'h', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 'f', 'r', 'i', 'g', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 'g', 'a', 'r', 'd', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 'g', 'e', 'n', 'e', 'r', 'a', 't', 'e', '\n',
        'u', 'n', 'r', 'e', 'g', 'i', 's', 't', 'e', 'r', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 'g', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 'h', 'e', 'a', 'r', 's', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 'l', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 'l', 'e', 'a', 's', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'r', 'e', 'l', 'e', 'a', 's', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 'l', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'u', 'n', 'r', 'e', 'l', 'e', 'n', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'u', 'n', 'r', 'e', 'l', 'i', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'u', 'n', 'r', 'e', 'l', 'i', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'r', 'e', 'l', 'i', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 'r', 'e', 'l', 'i', 'e', 'v', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 'm', 'a', 'r', 'k', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'r', 'e', 'm', 'a', 'r', 'k', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 'm', 'e', 'm', 'b', 'e', 'r', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 'm', 'i', 't', 't', 'i', 'n', 'g', '\n',
        'u', 'n', 'r', 'e', 'm', 'i', 't', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'u', 'n', 'r', 'e', 'p', 'a', 'i', 'r', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'r', 'e', 'p', 'e', 'a', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'u', 'n', 'r', 'e', 'p', 'e', 'a', 't', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'r', 'e', 'p', 'e', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 'p', 'e', 'n', 't', 'a', 'n', 't', '\n',
        'u', 'n', 'r', 'e', 'p', 'e', 'n', 't', 'a', 'n', 't', 'l', 'y', '\n',
        'u', 'n', 'r', 'e', 'p', 'o', 'r', 't', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 'p', 'r', 'e', 's', 'e', 'n', 't', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'r', 'e', 'p', 'r', 'e', 's', 'e', 'n', 't', 'a', 't', 'i', 'v', 'e', '\n',
        'u', 'n', 'r', 'e', 'p', 'r', 'e', 's', 'e', 'n', 't', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 'p', 'r', 'o', 'd', 'u', 'c', 'i', 'b', 'l', 'e', '\n',
        'u', 'n', 'r', 'e', 'q', 'u', 'e', 's', 't', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 'q', 'u', 'i', 't', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 's', 'e', 'r', 'v', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 's', 'e', 'r', 'v', 'e', 'd', 'l', 'y', '\n',
        'u', 'n', 'r', 'e', 's', 'i', 's', 't', 'i', 'n', 'g', '\n',
        'u', 'n', 'r', 'e', 's', 'i', 's', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'u', 'n', 'r', 'e', 's', 'o', 'l', 'v', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'r', 'e', 's', 'o', 'l', 'v', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 's', 'p', 'o', 'n', 's', 'i', 'v', 'e', '\n',
        'u', 'n', 'r', 'e', 's', 'p', 'o', 'n', 's', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'u', 'n', 'r', 'e', 's', 't', '\n',
        'u', 'n', 'r', 'e', 's', 't', 'r', 'a', 'i', 'n', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 's', 't', 'r', 'i', 'c', 't', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 's', 't', 's', '\n',
        'u', 'n', 'r', 'e', 'v', 'e', 'a', 'l', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 'v', 'e', 'a', 'l', 'i', 'n', 'g', '\n',
        'u', 'n', 'r', 'e', 'v', 'i', 's', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 'w', 'a', 'r', 'd', 'e', 'd', '\n',
        'u', 'n', 'r', 'e', 'w', 'a', 'r', 'd', 'i', 'n', 'g', '\n',
        'u', 'n', 'r', 'i', 'd', 'd', 'l', 'e', '\n',
        'u', 'n', 'r', 'i', 'p', 'e', '\n',
        'u', 'n', 'r', 'i', 'v', 'a', 'l', 'l', 'e', 'd', '\n',
        'u', 'n', 'r', 'o', 'l', 'l', '\n',
        'u', 'n', 'r', 'o', 'l', 'l', 'e', 'd', '\n',
        'u', 'n', 'r', 'o', 'l', 'l', 'i', 'n', 'g', '\n',
        'u', 'n', 'r', 'o', 'm', 'a', 'n', 't', 'i', 'c', '\n',
        'u', 'n', 'r', 'u', 'f', 'f', 'l', 'e', 'd', '\n',
        'u', 'n', 'r', 'u', 'l', 'i', 'n', 'e', 's', 's', '\n',
        'u', 'n', 'r', 'u', 'l', 'y', '\n',
        'u', 'n', 's', 'a', 'd', 'd', 'l', 'e', 'd', '\n',
        'u', 'n', 's', 'a', 'f', 'e', '\n',
        'u', 'n', 's', 'a', 'f', 'e', 'l', 'y', '\n',
        'u', 'n', 's', 'a', 'f', 'e', 'n', 'e', 's', 's', '\n',
        'u', 'n', 's', 'a', 'i', 'd', '\n',
        'u', 'n', 's', 'a', 'l', 'e', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 's', 'a', 'l', 't', 'e', 'd', '\n',
        'u', 'n', 's', 'a', 'n', 'i', 't', 'a', 'r', 'y', '\n',
        'u', 'n', 's', 'a', 't', 'i', 's', 'f', 'a', 'c', 't', 'o', 'r', 'i', 'l', 'y', '\n',
        'u', 'n', 's', 'a', 't', 'i', 's', 'f', 'a', 'c', 't', 'o', 'r', 'i', 'n', 'e', 's', 's', '\n',
        'u', 'n', 's', 'a', 't', 'i', 's', 'f', 'a', 'c', 't', 'o', 'r', 'y', '\n',
        'u', 'n', 's', 'a', 't', 'i', 's', 'f', 'i', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 's', 'a', 't', 'i', 's', 'f', 'i', 'e', 'd', '\n',
        'u', 'n', 's', 'a', 't', 'i', 's', 'f', 'y', 'i', 'n', 'g', '\n',
        'u', 'n', 's', 'a', 't', 'u', 'r', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 's', 'a', 'v', 'e', 'd', '\n',
        'u', 'n', 's', 'a', 'v', 'o', 'r', 'y', '\n',
        'u', 'n', 's', 'a', 'v', 'o', 'u', 'r', 'y', '\n',
        'u', 'n', 's', 'c', 'a', 'l', 'e', 'd', '\n',
        'u', 'n', 's', 'c', 'a', 't', 'h', 'e', 'd', '\n',
        'u', 'n', 's', 'c', 'h', 'e', 'd', 'u', 'l', 'e', 'd', '\n',
        'u', 'n', 's', 'c', 'i', 'e', 'n', 't', 'i', 'f', 'i', 'c', '\n',
        'u', 'n', 's', 'c', 'r', 'a', 'm', 'b', 'l', 'e', '\n',
        'u', 'n', 's', 'c', 'r', 'a', 'm', 'b', 'l', 'e', 'd', '\n',
        'u', 'n', 's', 'c', 'r', 'a', 'm', 'b', 'l', 'e', 's', '\n',
        'u', 'n', 's', 'c', 'r', 'a', 'm', 'b', 'l', 'i', 'n', 'g', '\n',
        'u', 'n', 's', 'c', 'r', 'a', 't', 'c', 'h', 'e', 'd', '\n',
        'u', 'n', 's', 'c', 'r', 'e', 'w', '\n',
        'u', 'n', 's', 'c', 'r', 'e', 'w', 'e', 'd', '\n',
        'u', 'n', 's', 'c', 'r', 'e', 'w', 'i', 'n', 'g', '\n',
        'u', 'n', 's', 'c', 'r', 'i', 'p', 't', 'e', 'd', '\n',
        'u', 'n', 's', 'c', 'r', 'u', 'p', 'u', 'l', 'o', 'u', 's', '\n',
        'u', 'n', 's', 'e', 'a', 'l', '\n',
        'u', 'n', 's', 'e', 'a', 'l', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 's', 'e', 'a', 'l', 'e', 'd', '\n',
        'u', 'n', 's', 'e', 'a', 'l', 'i', 'n', 'g', '\n',
        'u', 'n', 's', 'e', 'a', 's', 'o', 'n', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 's', 'e', 'a', 's', 'o', 'n', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 's', 'e', 'a', 's', 'o', 'n', 'a', 'l', '\n',
        'u', 'n', 's', 'e', 'a', 't', '\n',
        'u', 'n', 's', 'e', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 's', 'e', 'a', 'w', 'o', 'r', 't', 'h', 'i', 'n', 'e', 's', 's', '\n',
        'u', 'n', 's', 'e', 'c', 'u', 'r', 'e', 'd', '\n',
        'u', 'n', 's', 'e', 'e', 'd', 'e', 'd', '\n',
        'u', 'n', 's', 'e', 'e', 'i', 'n', 'g', '\n',
        'u', 'n', 's', 'e', 'e', 'i', 'n', 'g', 'l', 'y', '\n',
        'u', 'n', 's', 'e', 'e', 'm', 'l', 'y', '\n',
        'u', 'n', 's', 'e', 'e', 'n', '\n',
        'u', 'n', 's', 'e', 'l', 'e', 'c', 't', 'e', 'd', '\n',
        'u', 'n', 's', 'e', 'l', 'f', 'c', 'o', 'n', 's', 'c', 'i', 'o', 'u', 's', '\n',
        'u', 'n', 's', 'e', 'l', 'f', 'c', 'o', 'n', 's', 'c', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'u', 'n', 's', 'e', 'l', 'f', 'i', 's', 'h', '\n',
        'u', 'n', 's', 'e', 'l', 'f', 'i', 's', 'h', 'l', 'y', '\n',
        'u', 'n', 's', 'e', 'l', 'f', 'i', 's', 'h', 'n', 'e', 's', 's', '\n',
        'u', 'n', 's', 'e', 'l', 'l', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 's', 'e', 'n', 's', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'u', 'n', 's', 'e', 'n', 't', '\n',
        'u', 'n', 's', 'e', 'n', 't', 'i', 'm', 'e', 'n', 't', 'a', 'l', '\n',
        'u', 'n', 's', 'e', 'r', 'v', 'i', 'c', 'e', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 's', 'e', 'r', 'v', 'i', 'c', 'e', 'd', '\n',
        'u', 'n', 's', 'e', 't', '\n',
        'u', 'n', 's', 'e', 't', 't', 'l', 'e', '\n',
        'u', 'n', 's', 'e', 't', 't', 'l', 'e', 'd', '\n',
        'u', 'n', 's', 'e', 't', 't', 'l', 'i', 'n', 'g', '\n',
        'u', 'n', 's', 'h', 'a', 'c', 'k', 'l', 'e', 'd', '\n',
        'u', 'n', 's', 'h', 'a', 'd', 'e', 'd', '\n',
        'u', 'n', 's', 'h', 'a', 'k', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 's', 'h', 'a', 'k', 'e', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 's', 'h', 'a', 'k', 'e', 'n', '\n',
        'u', 'n', 's', 'h', 'a', 'p', 'e', 'd', '\n',
        'u', 'n', 's', 'h', 'a', 'p', 'e', 'n', '\n',
        'u', 'n', 's', 'h', 'a', 'r', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 's', 'h', 'a', 'r', 'e', 'd', '\n',
        'u', 'n', 's', 'h', 'a', 'v', 'e', 'd', '\n',
        'u', 'n', 's', 'h', 'a', 'v', 'e', 'n', '\n',
        'u', 'n', 's', 'h', 'e', 'a', 't', 'h', 'e', 'd', '\n',
        'u', 'n', 's', 'h', 'i', 'e', 'l', 'd', 'e', 'd', '\n',
        'u', 'n', 's', 'h', 'o', 'c', 'k', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 's', 'h', 'o', 'd', '\n',
        'u', 'n', 's', 'h', 'o', 'r', 'n', '\n',
        'u', 'n', 's', 'h', 'r', 'i', 'n', 'k', 'i', 'n', 'g', '\n',
        'u', 'n', 's', 'i', 'g', 'h', 't', 'e', 'd', '\n',
        'u', 'n', 's', 'i', 'g', 'h', 't', 'l', 'y', '\n',
        'u', 'n', 's', 'i', 'g', 'n', 'e', 'd', '\n',
        'u', 'n', 's', 'i', 'm', 'p', 'l', 'i', 'f', 'i', 'e', 'd', '\n',
        'u', 'n', 's', 'i', 'n', 'k', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 's', 'k', 'i', 'l', 'f', 'u', 'l', '\n',
        'u', 'n', 's', 'k', 'i', 'l', 'l', 'e', 'd', '\n',
        'u', 'n', 's', 'l', 'i', 'c', 'e', 'd', '\n',
        'u', 'n', 's', 'm', 'i', 'l', 'i', 'n', 'g', '\n',
        'u', 'n', 's', 'm', 'i', 'l', 'i', 'n', 'g', 'l', 'y', '\n',
        'u', 'n', 's', 'm', 'o', 'o', 't', 'h', '\n',
        'u', 'n', 's', 'o', 'c', 'i', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 's', 'o', 'c', 'i', 'a', 'l', '\n',
        'u', 'n', 's', 'o', 'i', 'l', 'e', 'd', '\n',
        'u', 'n', 's', 'o', 'l', 'd', '\n',
        'u', 'n', 's', 'o', 'l', 'd', 'e', 'r', '\n',
        'u', 'n', 's', 'o', 'l', 'i', 'c', 'i', 't', 'e', 'd', '\n',
        'u', 'n', 's', 'o', 'l', 'v', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 's', 'o', 'l', 'v', 'e', 'd', '\n',
        'u', 'n', 's', 'o', 'p', 'h', 'i', 's', 't', 'i', 'c', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 's', 'o', 'p', 'h', 'i', 's', 't', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'u', 'n', 's', 'o', 'r', 't', 'e', 'd', '\n',
        'u', 'n', 's', 'o', 'u', 'g', 'h', 't', '\n',
        'u', 'n', 's', 'o', 'u', 'n', 'd', '\n',
        'u', 'n', 's', 'o', 'u', 'n', 'd', 'n', 'e', 's', 's', '\n',
        'u', 'n', 's', 'p', 'a', 'n', 'n', 'e', 'd', '\n',
        'u', 'n', 's', 'p', 'e', 'a', 'k', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 's', 'p', 'e', 'a', 'k', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 's', 'p', 'e', 'c', 'i', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'u', 'n', 's', 'p', 'e', 'c', 'i', 'f', 'i', 'c', '\n',
        'u', 'n', 's', 'p', 'e', 'c', 'i', 'f', 'i', 'e', 'd', '\n',
        'u', 'n', 's', 'p', 'e', 'c', 't', 'a', 'c', 'u', 'l', 'a', 'r', '\n',
        'u', 'n', 's', 'p', 'e', 'n', 't', '\n',
        'u', 'n', 's', 'p', 'o', 'i', 'l', 'e', 'd', '\n',
        'u', 'n', 's', 'p', 'o', 'i', 'l', 't', '\n',
        'u', 'n', 's', 'p', 'o', 'k', 'e', 'n', '\n',
        'u', 'n', 's', 'p', 'o', 'r', 't', 'i', 'n', 'g', '\n',
        'u', 'n', 's', 't', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 's', 't', 'a', 'c', 'k', '\n',
        'u', 'n', 's', 't', 'a', 'c', 'k', 'e', 'd', '\n',
        'u', 'n', 's', 't', 'a', 'c', 'k', 'i', 'n', 'g', '\n',
        'u', 'n', 's', 't', 'a', 'i', 'n', 'e', 'd', '\n',
        'u', 'n', 's', 't', 'a', 'm', 'p', 'e', 'd', '\n',
        'u', 'n', 's', 't', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 's', 't', 'e', 'a', 'd', 'i', 'l', 'y', '\n',
        'u', 'n', 's', 't', 'e', 'a', 'd', 'i', 'n', 'e', 's', 's', '\n',
        'u', 'n', 's', 't', 'e', 'a', 'd', 'y', '\n',
        'u', 'n', 's', 't', 'e', 'r', 'i', 'l', 'i', 's', 'e', 'd', '\n',
        'u', 'n', 's', 't', 'i', 'c', 'k', 'i', 'n', 'g', '\n',
        'u', 'n', 's', 't', 'i', 'm', 'u', 'l', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 's', 't', 'i', 'n', 't', 'i', 'n', 'g', '\n',
        'u', 'n', 's', 't', 'i', 'n', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'u', 'n', 's', 't', 'i', 'r', 'r', 'e', 'd', '\n',
        'u', 'n', 's', 't', 'o', 'p', 'p', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 's', 't', 'o', 'p', 'p', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 's', 't', 'o', 'p', 'p', 'e', 'd', '\n',
        'u', 'n', 's', 't', 'r', 'a', 'p', 'p', 'e', 'd', '\n',
        'u', 'n', 's', 't', 'r', 'e', 's', 's', 'e', 'd', '\n',
        'u', 'n', 's', 't', 'r', 'e', 't', 'c', 'h', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 's', 't', 'r', 'u', 'c', 't', 'u', 'r', 'e', 'd', '\n',
        'u', 'n', 's', 't', 'u', 'c', 'k', '\n',
        'u', 'n', 's', 'u', 'b', 'd', 'u', 'e', 'd', '\n',
        'u', 'n', 's', 'u', 'b', 's', 'i', 'd', 'i', 's', 'e', 'd', '\n',
        'u', 'n', 's', 'u', 'b', 's', 't', 'a', 'n', 't', 'i', 'a', 'l', '\n',
        'u', 'n', 's', 'u', 'b', 's', 't', 'a', 'n', 't', 'i', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 's', 'u', 'b', 's', 't', 'i', 't', 'u', 't', 'e', 'd', '\n',
        'u', 'n', 's', 'u', 'b', 't', 'l', 'e', '\n',
        'u', 'n', 's', 'u', 'b', 't', 'l', 'y', '\n',
        'u', 'n', 's', 'u', 'c', 'c', 'e', 's', 's', 'f', 'u', 'l', '\n',
        'u', 'n', 's', 'u', 'c', 'c', 'e', 's', 's', 'f', 'u', 'l', 'l', 'y', '\n',
        'u', 'n', 's', 'u', 'i', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'u', 'n', 's', 'u', 'i', 't', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 's', 'u', 'i', 't', 'a', 'b', 'l', 'e', 'n', 'e', 's', 's', '\n',
        'u', 'n', 's', 'u', 'i', 't', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 's', 'u', 'i', 't', 'e', 'd', '\n',
        'u', 'n', 's', 'u', 'l', 'l', 'i', 'e', 'd', '\n',
        'u', 'n', 's', 'u', 'n', 'g', '\n',
        'u', 'n', 's', 'u', 'p', 'e', 'r', 'v', 'i', 's', 'e', 'd', '\n',
        'u', 'n', 's', 'u', 'p', 'p', 'o', 'r', 't', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', '\n',
        'u', 'n', 's', 'u', 'p', 'p', 'r', 'e', 's', 's', 'e', 'd', '\n',
        'u', 'n', 's', 'u', 'r', 'e', '\n',
        'u', 'n', 's', 'u', 'r', 'e', 'n', 'e', 's', 's', '\n',
        'u', 'n', 's', 'u', 'r', 'f', 'a', 'c', 'e', 'd', '\n',
        'u', 'n', 's', 'u', 'r', 'p', 'a', 's', 's', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 's', 'u', 'r', 'p', 'a', 's', 's', 'e', 'd', '\n',
        'u', 'n', 's', 'u', 'r', 'p', 'r', 'i', 's', 'e', 'd', '\n',
        'u', 'n', 's', 'u', 'r', 'p', 'r', 'i', 's', 'i', 'n', 'g', '\n',
        'u', 'n', 's', 'u', 'r', 'p', 'r', 'i', 's', 'i', 'n', 'g', 'l', 'y', '\n',
        'u', 'n', 's', 'u', 'r', 'v', 'i', 'v', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 's', 'u', 's', 'p', 'e', 'c', 't', 'e', 'd', '\n',
        'u', 'n', 's', 'u', 's', 'p', 'e', 'c', 't', 'i', 'n', 'g', '\n',
        'u', 'n', 's', 'u', 's', 't', 'a', 'i', 'n', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 's', 'w', 'a', 'p', 'p', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 's', 'w', 'e', 'e', 't', 'e', 'n', 'e', 'd', '\n',
        'u', 'n', 's', 'w', 'e', 'r', 'v', 'i', 'n', 'g', '\n',
        'u', 'n', 's', 'w', 'e', 'r', 'v', 'i', 'n', 'g', 'l', 'y', '\n',
        'u', 'n', 's', 'y', 'm', 'p', 'a', 't', 'h', 'e', 't', 'i', 'c', '\n',
        'u', 'n', 's', 'y', 'm', 'p', 'a', 't', 'h', 'e', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'u', 'n', 's', 'y', 's', 't', 'e', 'm', 'a', 't', 'i', 'c', '\n',
        'u', 'n', 't', 'a', 'c', 't', 'f', 'u', 'l', '\n',
        'u', 'n', 't', 'a', 'g', 'g', 'e', 'd', '\n',
        'u', 'n', 't', 'a', 'i', 'n', 't', 'e', 'd', '\n',
        'u', 'n', 't', 'a', 'l', 'e', 'n', 't', 'e', 'd', '\n',
        'u', 'n', 't', 'a', 'm', 'e', 'd', '\n',
        'u', 'n', 't', 'a', 'n', 'g', 'l', 'e', '\n',
        'u', 'n', 't', 'a', 'n', 'g', 'l', 'e', 'd', '\n',
        'u', 'n', 't', 'a', 'n', 'g', 'l', 'i', 'n', 'g', '\n',
        'u', 'n', 't', 'a', 'p', 'p', 'e', 'd', '\n',
        'u', 'n', 't', 'a', 'r', 'n', 'i', 's', 'h', 'e', 'd', '\n',
        'u', 'n', 't', 'a', 's', 't', 'e', 'd', '\n',
        'u', 'n', 't', 'a', 'u', 'g', 'h', 't', '\n',
        'u', 'n', 't', 'a', 'x', 'e', 'd', '\n',
        'u', 'n', 't', 'a', 'x', 'i', 'n', 'g', '\n',
        'u', 'n', 't', 'e', 'm', 'p', 'e', 'r', 'e', 'd', '\n',
        'u', 'n', 't', 'e', 'n', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'u', 'n', 't', 'e', 'n', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 't', 'e', 'n', 'd', 'e', 'd', '\n',
        'u', 'n', 't', 'e', 'r', 'm', 'i', 'n', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 't', 'e', 's', 't', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 't', 'e', 's', 't', 'e', 'd', '\n',
        'u', 'n', 't', 'e', 't', 'h', 'e', 'r', 'e', 'd', '\n',
        'u', 'n', 't', 'e', 'x', 't', 'u', 'r', 'e', 'd', '\n',
        'u', 'n', 't', 'h', 'i', 'n', 'k', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 't', 'h', 'i', 'n', 'k', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 't', 'h', 'i', 'n', 'k', 'i', 'n', 'g', '\n',
        'u', 'n', 't', 'h', 'i', 'n', 'k', 'i', 'n', 'g', 'l', 'y', '\n',
        'u', 'n', 't', 'h', 'o', 'u', 'g', 'h', 't', 'f', 'u', 'l', '\n',
        'u', 'n', 't', 'i', 'd', 'i', 'e', 'r', '\n',
        'u', 'n', 't', 'i', 'd', 'i', 'e', 's', 't', '\n',
        'u', 'n', 't', 'i', 'd', 'i', 'l', 'y', '\n',
        'u', 'n', 't', 'i', 'd', 'i', 'n', 'e', 's', 's', '\n',
        'u', 'n', 't', 'i', 'd', 'y', '\n',
        'u', 'n', 't', 'i', 'e', '\n',
        'u', 'n', 't', 'i', 'e', 'd', '\n',
        'u', 'n', 't', 'i', 'e', 's', '\n',
        'u', 'n', 't', 'i', 'l', '\n',
        'u', 'n', 't', 'i', 'm', 'e', 'l', 'y', '\n',
        'u', 'n', 't', 'i', 'r', 'i', 'n', 'g', '\n',
        'u', 'n', 't', 'i', 't', 'l', 'e', 'd', '\n',
        'u', 'n', 't', 'o', '\n',
        'u', 'n', 't', 'o', 'l', 'd', '\n',
        'u', 'n', 't', 'o', 'u', 'c', 'h', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 't', 'o', 'u', 'c', 'h', 'a', 'b', 'l', 'e', 's', '\n',
        'u', 'n', 't', 'o', 'u', 'c', 'h', 'e', 'd', '\n',
        'u', 'n', 't', 'o', 'w', 'a', 'r', 'd', '\n',
        'u', 'n', 't', 'r', 'a', 'c', 'e', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 't', 'r', 'a', 'c', 'e', 'd', '\n',
        'u', 'n', 't', 'r', 'a', 'i', 'n', 'e', 'd', '\n',
        'u', 'n', 't', 'r', 'a', 'm', 'm', 'e', 'l', 'l', 'e', 'd', '\n',
        'u', 'n', 't', 'r', 'a', 'n', 's', 'f', 'o', 'r', 'm', 'e', 'd', '\n',
        'u', 'n', 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 't', 'r', 'a', 'n', 's', 'l', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 't', 'r', 'a', 'n', 's', 'p', 'o', 'r', 't', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 't', 'r', 'a', 'p', 'p', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 't', 'r', 'e', 'a', 't', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 't', 'r', 'e', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 't', 'r', 'i', 'e', 'd', '\n',
        'u', 'n', 't', 'r', 'o', 'd', 'd', 'e', 'n', '\n',
        'u', 'n', 't', 'r', 'o', 'u', 'b', 'l', 'e', 'd', '\n',
        'u', 'n', 't', 'r', 'u', 'e', '\n',
        'u', 'n', 't', 'r', 'u', 's', 't', 'e', 'd', '\n',
        'u', 'n', 't', 'r', 'u', 's', 't', 'w', 'o', 'r', 't', 'h', 'y', '\n',
        'u', 'n', 't', 'r', 'u', 's', 't', 'y', '\n',
        'u', 'n', 't', 'r', 'u', 't', 'h', '\n',
        'u', 'n', 't', 'r', 'u', 't', 'h', 'f', 'u', 'l', '\n',
        'u', 'n', 't', 'r', 'u', 't', 'h', 'f', 'u', 'l', 'l', 'y', '\n',
        'u', 'n', 't', 'r', 'u', 't', 'h', 's', '\n',
        'u', 'n', 't', 'u', 'r', 'n', 'e', 'd', '\n',
        'u', 'n', 't', 'u', 't', 'o', 'r', 'e', 'd', '\n',
        'u', 'n', 't', 'w', 'i', 's', 't', '\n',
        'u', 'n', 't', 'w', 'i', 's', 't', 'e', 'd', '\n',
        'u', 'n', 't', 'y', 'i', 'n', 'g', '\n',
        'u', 'n', 't', 'y', 'p', 'e', 'd', '\n',
        'u', 'n', 't', 'y', 'p', 'i', 'c', 'a', 'l', '\n',
        'u', 'n', 't', 'y', 'p', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'u', 'n', 'u', 's', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'u', 's', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 'u', 's', 'e', 'd', '\n',
        'u', 'n', 'u', 's', 'u', 'a', 'l', '\n',
        'u', 'n', 'u', 's', 'u', 'a', 'l', 'l', 'y', '\n',
        'u', 'n', 'u', 't', 't', 'e', 'r', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'u', 't', 't', 'e', 'r', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 'v', 'a', 'l', 'i', 'd', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'v', 'a', 'l', 'u', 'e', 'd', '\n',
        'u', 'n', 'v', 'a', 'n', 'q', 'u', 'i', 's', 'h', 'e', 'd', '\n',
        'u', 'n', 'v', 'a', 'r', 'n', 'i', 's', 'h', 'e', 'd', '\n',
        'u', 'n', 'v', 'a', 'r', 'y', 'i', 'n', 'g', '\n',
        'u', 'n', 'v', 'a', 'r', 'y', 'i', 'n', 'g', 'l', 'y', '\n',
        'u', 'n', 'v', 'e', 'i', 'l', '\n',
        'u', 'n', 'v', 'e', 'i', 'l', 'e', 'd', '\n',
        'u', 'n', 'v', 'e', 'i', 'l', 'i', 'n', 'g', '\n',
        'u', 'n', 'v', 'e', 'i', 'l', 's', '\n',
        'u', 'n', 'v', 'e', 'n', 't', 'i', 'l', 'a', 't', 'e', 'd', '\n',
        'u', 'n', 'v', 'e', 'r', 'i', 'f', 'i', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'v', 'e', 'r', 'i', 'f', 'i', 'e', 'd', '\n',
        'u', 'n', 'v', 'e', 'r', 's', 'e', 'd', '\n',
        'u', 'n', 'v', 'i', 's', 'i', 't', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'v', 'i', 's', 'i', 't', 'e', 'd', '\n',
        'u', 'n', 'v', 'o', 'i', 'c', 'e', 'd', '\n',
        'u', 'n', 'w', 'a', 'n', 't', 'e', 'd', '\n',
        'u', 'n', 'w', 'a', 'r', 'i', 'l', 'y', '\n',
        'u', 'n', 'w', 'a', 'r', 'm', 'e', 'd', '\n',
        'u', 'n', 'w', 'a', 'r', 'n', 'e', 'd', '\n',
        'u', 'n', 'w', 'a', 'r', 'r', 'a', 'n', 't', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'w', 'a', 'r', 'r', 'a', 'n', 't', 'a', 'b', 'l', 'y', '\n',
        'u', 'n', 'w', 'a', 'r', 'r', 'a', 'n', 't', 'e', 'd', '\n',
        'u', 'n', 'w', 'a', 'r', 'y', '\n',
        'u', 'n', 'w', 'a', 's', 'h', 'e', 'd', '\n',
        'u', 'n', 'w', 'a', 't', 'c', 'h', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'w', 'a', 't', 'c', 'h', 'e', 'd', '\n',
        'u', 'n', 'w', 'a', 'v', 'e', 'r', 'i', 'n', 'g', '\n',
        'u', 'n', 'w', 'a', 'v', 'e', 'r', 'i', 'n', 'g', 'l', 'y', '\n',
        'u', 'n', 'w', 'e', 'a', 'n', 'e', 'd', '\n',
        'u', 'n', 'w', 'e', 'a', 'r', 'i', 'e', 'd', '\n',
        'u', 'n', 'w', 'e', 'a', 'r', 'y', '\n',
        'u', 'n', 'w', 'e', 'd', '\n',
        'u', 'n', 'w', 'e', 'd', 'd', 'e', 'd', '\n',
        'u', 'n', 'w', 'e', 'd', 'g', 'e', '\n',
        'u', 'n', 'w', 'e', 'i', 'g', 'h', 't', 'e', 'd', '\n',
        'u', 'n', 'w', 'e', 'l', 'c', 'o', 'm', 'e', '\n',
        'u', 'n', 'w', 'e', 'l', 'c', 'o', 'm', 'i', 'n', 'g', '\n',
        'u', 'n', 'w', 'e', 'l', 'l', '\n',
        'u', 'n', 'w', 'h', 'o', 'l', 'e', 's', 'o', 'm', 'e', '\n',
        'u', 'n', 'w', 'i', 'e', 'l', 'd', 'y', '\n',
        'u', 'n', 'w', 'i', 'l', 'l', 'i', 'n', 'g', '\n',
        'u', 'n', 'w', 'i', 'l', 'l', 'i', 'n', 'g', 'l', 'y', '\n',
        'u', 'n', 'w', 'i', 'l', 'l', 'i', 'n', 'g', 'n', 'e', 's', 's', '\n',
        'u', 'n', 'w', 'i', 'n', 'd', '\n',
        'u', 'n', 'w', 'i', 'n', 'd', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'w', 'i', 'n', 'd', 'i', 'n', 'g', '\n',
        'u', 'n', 'w', 'i', 'n', 'd', 's', '\n',
        'u', 'n', 'w', 'i', 's', 'd', 'o', 'm', '\n',
        'u', 'n', 'w', 'i', 's', 'e', '\n',
        'u', 'n', 'w', 'i', 's', 'e', 'l', 'y', '\n',
        'u', 'n', 'w', 'i', 's', 'e', 's', 't', '\n',
        'u', 'n', 'w', 'i', 't', 't', 'i', 'n', 'g', '\n',
        'u', 'n', 'w', 'i', 't', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'u', 'n', 'w', 'o', 'n', 't', 'e', 'd', 'l', 'y', '\n',
        'u', 'n', 'w', 'o', 'r', 'k', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'u', 'n', 'w', 'o', 'r', 'k', 'a', 'b', 'l', 'e', '\n',
        'u', 'n', 'w', 'o', 'r', 'l', 'd', 'l', 'y', '\n',
        'u', 'n', 'w', 'o', 'r', 'n', '\n',
        'u', 'n', 'w', 'o', 'r', 'r', 'i', 'e', 'd', '\n',
        'u', 'n', 'w', 'o', 'r', 't', 'h', 'i', 'l', 'y', '\n',
        'u', 'n', 'w', 'o', 'r', 't', 'h', 'i', 'n', 'e', 's', 's', '\n',
        'u', 'n', 'w', 'o', 'r', 't', 'h', 'y', '\n',
        'u', 'n', 'w', 'o', 'u', 'n', 'd', '\n',
        'u', 'n', 'w', 'o', 'u', 'n', 'd', 'e', 'd', '\n',
        'u', 'n', 'w', 'r', 'a', 'p', '\n',
        'u', 'n', 'w', 'r', 'a', 'p', 'p', 'e', 'd', '\n',
        'u', 'n', 'w', 'r', 'a', 'p', 'p', 'i', 'n', 'g', '\n',
        'u', 'n', 'w', 'r', 'a', 'p', 's', '\n',
        'u', 'n', 'w', 'r', 'i', 't', 't', 'e', 'n', '\n',
        'u', 'n', 'y', 'i', 'e', 'l', 'd', 'i', 'n', 'g', '\n',
        'u', 'n', 'z', 'i', 'p', '\n',
        'u', 'n', 'z', 'i', 'p', 'p', 'e', 'd', '\n',
        'u', 'n', 'z', 'i', 'p', 'p', 'i', 'n', 'g', '\n',
        'u', 'n', 'z', 'i', 'p', 's', '\n',
        'u', 'p', '\n',
        'u', 'p', 'b', 'e', 'a', 't', '\n',
        'u', 'p', 'b', 'r', 'a', 'i', 'd', '\n',
        'u', 'p', 'b', 'r', 'a', 'i', 'd', 'e', 'd', '\n',
        'u', 'p', 'b', 'r', 'a', 'i', 'd', 'i', 'n', 'g', '\n',
        'u', 'p', 'b', 'r', 'a', 'i', 'd', 's', '\n',
        'u', 'p', 'b', 'r', 'i', 'n', 'g', 'i', 'n', 'g', '\n',
        'u', 'p', 'b', 'r', 'i', 'n', 'g', 'i', 'n', 'g', 's', '\n',
        'u', 'p', 'c', 'a', 's', 't', '\n',
        'u', 'p', 'c', 'o', 'm', 'i', 'n', 'g', '\n',
        'u', 'p', 'd', 'a', 't', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'u', 'p', 'd', 'a', 't', 'e', '\n',
        'u', 'p', 'd', 'a', 't', 'e', 'd', '\n',
        'u', 'p', 'd', 'a', 't', 'e', 'r', '\n',
        'u', 'p', 'd', 'a', 't', 'e', 's', '\n',
        'u', 'p', 'd', 'a', 't', 'i', 'n', 'g', '\n',
        'u', 'p', 'e', 'n', 'd', 'e', 'd', '\n',
        'u', 'p', 'f', 'i', 'e', 'l', 'd', '\n',
        'u', 'p', 'f', 'r', 'o', 'n', 't', '\n',
        'u', 'p', 'g', 'r', 'a', 'd', 'a', 'b', 'l', 'e', '\n',
        'u', 'p', 'g', 'r', 'a', 'd', 'e', '\n',
        'u', 'p', 'g', 'r', 'a', 'd', 'e', 'a', 'b', 'l', 'e', '\n',
        'u', 'p', 'g', 'r', 'a', 'd', 'e', 'd', '\n',
        'u', 'p', 'g', 'r', 'a', 'd', 'e', 's', '\n',
        'u', 'p', 'g', 'r', 'a', 'd', 'i', 'n', 'g', '\n',
        'u', 'p', 'g', 'r', 'a', 'd', 'i', 'n', 'g', 's', '\n',
        'u', 'p', 'h', 'e', 'a', 'v', 'a', 'l', '\n',
        'u', 'p', 'h', 'e', 'a', 'v', 'a', 'l', 's', '\n',
        'u', 'p', 'h', 'e', 'l', 'd', '\n',
        'u', 'p', 'h', 'i', 'l', 'l', '\n',
        'u', 'p', 'h', 'o', 'l', 'd', '\n',
        'u', 'p', 'h', 'o', 'l', 'd', 'e', 'r', '\n',
        'u', 'p', 'h', 'o', 'l', 'd', 'e', 'r', 's', '\n',
        'u', 'p', 'h', 'o', 'l', 'd', 'i', 'n', 'g', '\n',
        'u', 'p', 'h', 'o', 'l', 'd', 's', '\n',
        'u', 'p', 'h', 'o', 'l', 's', 't', 'e', 'r', '\n',
        'u', 'p', 'h', 'o', 'l', 's', 't', 'e', 'r', 'e', 'd', '\n',
        'u', 'p', 'h', 'o', 'l', 's', 't', 'e', 'r', 'e', 'r', '\n',
        'u', 'p', 'h', 'o', 'l', 's', 't', 'e', 'r', 'e', 'r', 's', '\n',
        'u', 'p', 'h', 'o', 'l', 's', 't', 'e', 'r', 'y', '\n',
        'u', 'p', 'k', 'e', 'e', 'p', '\n',
        'u', 'p', 'l', 'a', 'n', 'd', '\n',
        'u', 'p', 'l', 'a', 'n', 'd', 's', '\n',
        'u', 'p', 'l', 'i', 'f', 't', '\n',
        'u', 'p', 'l', 'i', 'f', 't', 'e', 'd', '\n',
        'u', 'p', 'l', 'i', 'f', 't', 'i', 'n', 'g', '\n',
        'u', 'p', 'l', 'i', 'f', 't', 's', '\n',
        'u', 'p', 'l', 'i', 'n', 'k', '\n',
        'u', 'p', 'l', 'i', 'n', 'k', 's', '\n',
        'u', 'p', 'l', 'o', 'a', 'd', '\n',
        'u', 'p', 'l', 'o', 'a', 'd', 'e', 'd', '\n',
        'u', 'p', 'l', 'o', 'a', 'd', 's', '\n',
        'u', 'p', 'm', 'a', 'r', 'k', 'e', 't', '\n',
        'u', 'p', 'm', 'o', 's', 't', '\n',
        'u', 'p', 'o', 'n', '\n',
        'u', 'p', 'p', 'e', 'd', '\n',
        'u', 'p', 'p', 'e', 'r', '\n',
        'u', 'p', 'p', 'e', 'r', 'c', 'a', 's', 'e', '\n',
        'u', 'p', 'p', 'e', 'r', 'c', 'l', 'a', 's', 's', '\n',
        'u', 'p', 'p', 'e', 'r', 'c', 'u', 't', '\n',
        'u', 'p', 'p', 'e', 'r', 'm', 'o', 's', 't', '\n',
        'u', 'p', 'p', 'e', 'r', 's', '\n',
        'u', 'p', 'r', 'a', 'i', 's', 'e', 'd', '\n',
        'u', 'p', 'r', 'a', 't', 'e', '\n',
        'u', 'p', 'r', 'a', 't', 'e', 'd', '\n',
        'u', 'p', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'u', 'p', 'r', 'i', 'g', 'h', 't', '\n',
        'u', 'p', 'r', 'i', 'g', 'h', 't', 'l', 'y', '\n',
        'u', 'p', 'r', 'i', 'g', 'h', 't', 'n', 'e', 's', 's', '\n',
        'u', 'p', 'r', 'i', 'g', 'h', 't', 's', '\n',
        'u', 'p', 'r', 'i', 's', 'e', '\n',
        'u', 'p', 'r', 'i', 's', 'i', 'n', 'g', '\n',
        'u', 'p', 'r', 'i', 's', 'i', 'n', 'g', 's', '\n',
        'u', 'p', 'r', 'i', 'v', 'e', 'r', '\n',
        'u', 'p', 'r', 'o', 'a', 'r', '\n',
        'u', 'p', 'r', 'o', 'a', 'r', 'i', 'o', 'u', 's', '\n',
        'u', 'p', 'r', 'o', 'a', 'r', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'u', 'p', 'r', 'o', 'a', 'r', 's', '\n',
        'u', 'p', 'r', 'o', 'o', '\n',
        'u', 'p', 'r', 'o', 'o', 't', '\n',
        'u', 'p', 'r', 'o', 'o', 't', 'e', 'd', '\n',
        'u', 'p', 'r', 'o', 'o', 't', 'i', 'n', 'g', '\n',
        'u', 'p', 'r', 'o', 'o', 't', 's', '\n',
        'u', 'p', 's', '\n',
        'u', 'p', 's', 'e', 't', '\n',
        'u', 'p', 's', 'e', 't', 's', '\n',
        'u', 'p', 's', 'e', 't', 't', 'i', 'n', 'g', '\n',
        'u', 'p', 's', 'h', 'o', 't', '\n',
        'u', 'p', 's', 'i', 'd', 'e', '\n',
        'u', 'p', 's', 'i', 'd', 'e', 'd', 'o', 'w', 'n', '\n',
        'u', 'p', 's', 'i', 'l', 'o', 'n', '\n',
        'u', 'p', 's', 't', 'a', 'g', 'e', '\n',
        'u', 'p', 's', 't', 'a', 'g', 'e', 'd', '\n',
        'u', 'p', 's', 't', 'a', 'g', 'e', 's', '\n',
        'u', 'p', 's', 't', 'a', 'g', 'i', 'n', 'g', '\n',
        'u', 'p', 's', 't', 'a', 'i', 'r', 's', '\n',
        'u', 'p', 's', 't', 'a', 'n', 'd', 'i', 'n', 'g', '\n',
        'u', 'p', 's', 't', 'a', 'r', 't', '\n',
        'u', 'p', 's', 't', 'a', 'r', 't', 's', '\n',
        'u', 'p', 's', 't', 'r', 'e', 'a', 'm', '\n',
        'u', 'p', 's', 'u', 'r', 'g', 'e', '\n',
        'u', 'p', 's', 'u', 'r', 'g', 'e', 's', '\n',
        'u', 'p', 's', 'w', 'i', 'n', 'g', '\n',
        'u', 'p', 't', 'a', 'k', 'e', '\n',
        'u', 'p', 't', 'h', 'r', 'u', 's', 't', '\n',
        'u', 'p', 't', 'o', 't', 'h', 'e', 'm', 'i', 'n', 'u', 't', 'e', '\n',
        'u', 'p', 't', 'o', 'w', 'n', '\n',
        'u', 'p', 't', 'u', 'r', 'n', '\n',
        'u', 'p', 't', 'u', 'r', 'n', 'e', 'd', '\n',
        'u', 'p', 'w', 'a', 'r', 'd', '\n',
        'u', 'p', 'w', 'a', 'r', 'd', 'l', 'y', '\n',
        'u', 'p', 'w', 'a', 'r', 'd', 's', '\n',
        'u', 'p', 'w', 'i', 'n', 'd', '\n',
        'u', 'r', 'a', 'n', 'i', 'u', 'm', '\n',
        'u', 'r', 'a', 'n', 'u', 's', '\n',
        'u', 'r', 'b', 'a', 'n', '\n',
        'u', 'r', 'b', 'a', 'n', 'e', '\n',
        'u', 'r', 'b', 'a', 'n', 'e', 'l', 'y', '\n',
        'u', 'r', 'b', 'a', 'n', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'u', 'r', 'b', 'a', 'n', 'i', 's', 'e', '\n',
        'u', 'r', 'b', 'a', 'n', 'i', 's', 'e', 'd', '\n',
        'u', 'r', 'b', 'a', 'n', 'i', 's', 'i', 'n', 'g', '\n',
        'u', 'r', 'b', 'a', 'n', 'i', 't', 'e', 's', '\n',
        'u', 'r', 'b', 'a', 'n', 'i', 't', 'y', '\n',
        'u', 'r', 'c', 'h', 'i', 'n', '\n',
        'u', 'r', 'c', 'h', 'i', 'n', 's', '\n',
        'u', 'r', 'e', 'a', '\n',
        'u', 'r', 'e', 't', 'e', 'r', '\n',
        'u', 'r', 'e', 't', 'e', 'r', 's', '\n',
        'u', 'r', 'e', 't', 'h', 'a', 'n', 'e', '\n',
        'u', 'r', 'e', 't', 'h', 'r', 'a', '\n',
        'u', 'r', 'e', 't', 'h', 'r', 'a', 'e', '\n',
        'u', 'r', 'e', 't', 'h', 'r', 'a', 'l', '\n',
        'u', 'r', 'e', 't', 'h', 'r', 'a', 's', '\n',
        'u', 'r', 'e', 't', 'h', 'r', 'i', 't', 'i', 's', '\n',
        'u', 'r', 'g', 'e', '\n',
        'u', 'r', 'g', 'e', 'd', '\n',
        'u', 'r', 'g', 'e', 'n', 'c', 'y', '\n',
        'u', 'r', 'g', 'e', 'n', 't', '\n',
        'u', 'r', 'g', 'e', 'n', 't', 'l', 'y', '\n',
        'u', 'r', 'g', 'e', 's', '\n',
        'u', 'r', 'g', 'i', 'n', 'g', '\n',
        'u', 'r', 'g', 'i', 'n', 'g', 's', '\n',
        'u', 'r', 'i', 'n', 'a', 'r', 'y', '\n',
        'u', 'r', 'i', 'n', 'e', '\n',
        'u', 'r', 'n', '\n',
        'u', 'r', 'n', 's', '\n',
        'u', 'r', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'u', 'r', 's', 'i', 'n', 'e', '\n',
        'u', 'r', 't', 'i', 'c', 'a', 'r', 'i', 'a', '\n',
        'u', 'r', 'u', 'g', 'u', 'a', 'y', '\n',
        'u', 's', '\n',
        'u', 's', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'u', 's', 'a', 'b', 'l', 'e', '\n',
        'u', 's', 'a', 'g', 'e', '\n',
        'u', 's', 'a', 'g', 'e', 's', '\n',
        'u', 's', 'a', 'n', 'c', 'e', 's', '\n',
        'u', 's', 'e', '\n',
        'u', 's', 'e', 'a', 'b', 'l', 'e', '\n',
        'u', 's', 'e', 'd', '\n',
        'u', 's', 'e', 'f', 'u', 'l', '\n',
        'u', 's', 'e', 'f', 'u', 'l', 'l', 'y', '\n',
        'u', 's', 'e', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'u', 's', 'e', 'l', 'e', 's', 's', '\n',
        'u', 's', 'e', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'u', 's', 'e', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'u', 's', 'e', 'r', '\n',
        'u', 's', 'e', 'r', 'f', 'r', 'i', 'e', 'n', 'd', 'l', 'i', 'n', 'e', 's', 's', '\n',
        'u', 's', 'e', 'r', 'f', 'r', 'i', 'e', 'n', 'd', 'l', 'y', '\n',
        'u', 's', 'e', 'r', 's', '\n',
        'u', 's', 'e', 's', '\n',
        'u', 's', 'h', 'e', 'r', '\n',
        'u', 's', 'h', 'e', 'r', 'e', 'd', '\n',
        'u', 's', 'h', 'e', 'r', 'e', 't', 't', 'e', '\n',
        'u', 's', 'h', 'e', 'r', 'i', 'n', 'g', '\n',
        'u', 's', 'h', 'e', 'r', 's', '\n',
        'u', 's', 'i', 'n', 'g', '\n',
        'u', 's', 'u', 'a', 'l', '\n',
        'u', 's', 'u', 'a', 'l', 'l', 'y', '\n',
        'u', 's', 'u', 'r', 'e', 'r', '\n',
        'u', 's', 'u', 'r', 'e', 'r', 's', '\n',
        'u', 's', 'u', 'r', 'i', 'o', 'u', 's', '\n',
        'u', 's', 'u', 'r', 'p', '\n',
        'u', 's', 'u', 'r', 'p', 'a', 't', 'i', 'o', 'n', '\n',
        'u', 's', 'u', 'r', 'p', 'e', 'd', '\n',
        'u', 's', 'u', 'r', 'p', 'e', 'r', '\n',
        'u', 's', 'u', 'r', 'p', 'i', 'n', 'g', '\n',
        'u', 's', 'u', 'r', 'y', '\n',
        'u', 't', 'a', 'h', '\n',
        'u', 't', 'e', 'n', 's', 'i', 'l', '\n',
        'u', 't', 'e', 'n', 's', 'i', 'l', 's', '\n',
        'u', 't', 'e', 'r', 'i', '\n',
        'u', 't', 'e', 'r', 'i', 'n', 'e', '\n',
        'u', 't', 'e', 'r', 'u', 's', '\n',
        'u', 't', 'i', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'u', 't', 'i', 'l', 'i', 's', 'e', '\n',
        'u', 't', 'i', 'l', 'i', 's', 'e', 'd', '\n',
        'u', 't', 'i', 'l', 'i', 's', 'e', 's', '\n',
        'u', 't', 'i', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'u', 't', 'i', 'l', 'i', 't', 'a', 'r', 'i', 'a', 'n', '\n',
        'u', 't', 'i', 'l', 'i', 't', 'a', 'r', 'i', 'a', 'n', 'i', 's', 'm', '\n',
        'u', 't', 'i', 'l', 'i', 't', 'a', 'r', 'i', 'a', 'n', 's', '\n',
        'u', 't', 'i', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'u', 't', 'i', 'l', 'i', 't', 'y', '\n',
        'u', 't', 'm', 'o', 's', 't', '\n',
        'u', 't', 'o', 'p', 'i', 'a', '\n',
        'u', 't', 'o', 'p', 'i', 'a', 'n', '\n',
        'u', 't', 'o', 'p', 'i', 'a', 'n', 's', '\n',
        'u', 't', 'o', 'p', 'i', 'a', 's', '\n',
        'u', 't', 't', 'e', 'r', '\n',
        'u', 't', 't', 'e', 'r', 'a', 'n', 'c', 'e', '\n',
        'u', 't', 't', 'e', 'r', 'a', 'n', 'c', 'e', 's', '\n',
        'u', 't', 't', 'e', 'r', 'e', 'd', '\n',
        'u', 't', 't', 'e', 'r', 'e', 'r', '\n',
        'u', 't', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'u', 't', 't', 'e', 'r', 'l', 'y', '\n',
        'u', 't', 't', 'e', 'r', 'm', 'o', 's', 't', '\n',
        'u', 't', 't', 'e', 'r', 's', '\n',
        'u', 't', 'u', 'r', 'n', 's', '\n',
        'u', 'v', 'u', 'l', 'a', '\n',
        'u', 'v', 'u', 'l', 'a', 'r', '\n',
        'v', 'a', 'c', 'a', 'n', 'c', 'i', 'e', 's', '\n',
        'v', 'a', 'c', 'a', 'n', 'c', 'y', '\n',
        'v', 'a', 'c', 'a', 'n', 't', '\n',
        'v', 'a', 'c', 'a', 'n', 't', 'l', 'y', '\n',
        'v', 'a', 'c', 'a', 't', 'e', '\n',
        'v', 'a', 'c', 'a', 't', 'e', 'd', '\n',
        'v', 'a', 'c', 'a', 't', 'e', 's', '\n',
        'v', 'a', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'v', 'a', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'v', 'a', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'v', 'a', 'c', 'c', 'i', 'n', 'a', 't', 'e', '\n',
        'v', 'a', 'c', 'c', 'i', 'n', 'a', 't', 'e', 'd', '\n',
        'v', 'a', 'c', 'c', 'i', 'n', 'a', 't', 'i', 'n', 'g', '\n',
        'v', 'a', 'c', 'c', 'i', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'v', 'a', 'c', 'c', 'i', 'n', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'v', 'a', 'c', 'c', 'i', 'n', 'e', '\n',
        'v', 'a', 'c', 'c', 'i', 'n', 'e', 's', '\n',
        'v', 'a', 'c', 'i', 'l', 'l', 'a', 't', 'e', '\n',
        'v', 'a', 'c', 'i', 'l', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'v', 'a', 'c', 'i', 'l', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'v', 'a', 'c', 'i', 'l', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'v', 'a', 'c', 'u', 'a', '\n',
        'v', 'a', 'c', 'u', 'i', 't', 'y', '\n',
        'v', 'a', 'c', 'u', 'o', 'l', 'e', '\n',
        'v', 'a', 'c', 'u', 'o', 'l', 'e', 's', '\n',
        'v', 'a', 'c', 'u', 'o', 'u', 's', '\n',
        'v', 'a', 'c', 'u', 'o', 'u', 's', 'l', 'y', '\n',
        'v', 'a', 'c', 'u', 'u', 'm', '\n',
        'v', 'a', 'c', 'u', 'u', 'm', 's', '\n',
        'v', 'a', 'd', 'u', 'z', '\n',
        'v', 'a', 'g', 'a', 'b', 'o', 'n', 'd', '\n',
        'v', 'a', 'g', 'a', 'b', 'o', 'n', 'd', 's', '\n',
        'v', 'a', 'g', 'r', 'a', 'n', 'c', 'y', '\n',
        'v', 'a', 'g', 'r', 'a', 'n', 't', '\n',
        'v', 'a', 'g', 'r', 'a', 'n', 't', 's', '\n',
        'v', 'a', 'g', 'u', 'e', '\n',
        'v', 'a', 'g', 'u', 'e', 'l', 'y', '\n',
        'v', 'a', 'g', 'u', 'e', 'n', 'e', 's', 's', '\n',
        'v', 'a', 'g', 'u', 'e', 'r', '\n',
        'v', 'a', 'g', 'u', 'e', 's', 't', '\n',
        'v', 'a', 'i', 'n', '\n',
        'v', 'a', 'i', 'n', 'e', 'r', '\n',
        'v', 'a', 'i', 'n', 'e', 's', 't', '\n',
        'v', 'a', 'i', 'n', 'g', 'l', 'o', 'r', 'i', 'o', 'u', 's', '\n',
        'v', 'a', 'i', 'n', 'g', 'l', 'o', 'r', 'y', '\n',
        'v', 'a', 'i', 'n', 'l', 'y', '\n',
        'v', 'a', 'l', 'a', 'n', 'c', 'e', '\n',
        'v', 'a', 'l', 'e', '\n',
        'v', 'a', 'l', 'e', 'd', 'i', 'c', 't', 'i', 'o', 'n', '\n',
        'v', 'a', 'l', 'e', 'd', 'i', 'c', 't', 'o', 'r', 'y', '\n',
        'v', 'a', 'l', 'e', 'n', 'c', 'e', '\n',
        'v', 'a', 'l', 'e', 'n', 'c', 'i', 'e', 's', '\n',
        'v', 'a', 'l', 'e', 'n', 'c', 'y', '\n',
        'v', 'a', 'l', 'e', 'n', 't', 'i', 'n', 'e', '\n',
        'v', 'a', 'l', 'e', 's', '\n',
        'v', 'a', 'l', 'e', 't', '\n',
        'v', 'a', 'l', 'e', 't', 's', '\n',
        'v', 'a', 'l', 'h', 'a', 'l', 'l', 'a', '\n',
        'v', 'a', 'l', 'i', 'a', 'n', 't', '\n',
        'v', 'a', 'l', 'i', 'a', 'n', 't', 'l', 'y', '\n',
        'v', 'a', 'l', 'i', 'd', '\n',
        'v', 'a', 'l', 'i', 'd', 'a', 't', 'e', '\n',
        'v', 'a', 'l', 'i', 'd', 'a', 't', 'e', 'd', '\n',
        'v', 'a', 'l', 'i', 'd', 'a', 't', 'e', 's', '\n',
        'v', 'a', 'l', 'i', 'd', 'a', 't', 'i', 'n', 'g', '\n',
        'v', 'a', 'l', 'i', 'd', 'a', 't', 'i', 'o', 'n', '\n',
        'v', 'a', 'l', 'i', 'd', 'i', 't', 'y', '\n',
        'v', 'a', 'l', 'i', 'd', 'l', 'y', '\n',
        'v', 'a', 'l', 'i', 's', 'e', '\n',
        'v', 'a', 'l', 'l', 'e', 'y', '\n',
        'v', 'a', 'l', 'l', 'e', 'y', 's', '\n',
        'v', 'a', 'l', 'o', 'u', 'r', '\n',
        'v', 'a', 'l', 'u', 'a', 'b', 'l', 'e', '\n',
        'v', 'a', 'l', 'u', 'a', 'b', 'l', 'e', 's', '\n',
        'v', 'a', 'l', 'u', 'a', 't', 'i', 'o', 'n', '\n',
        'v', 'a', 'l', 'u', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'v', 'a', 'l', 'u', 'e', '\n',
        'v', 'a', 'l', 'u', 'e', 'a', 'd', 'd', 'e', 'd', '\n',
        'v', 'a', 'l', 'u', 'e', 'd', '\n',
        'v', 'a', 'l', 'u', 'e', 'f', 'o', 'r', 'm', 'o', 'n', 'e', 'y', '\n',
        'v', 'a', 'l', 'u', 'e', 'l', 'e', 's', 's', '\n',
        'v', 'a', 'l', 'u', 'e', 'r', '\n',
        'v', 'a', 'l', 'u', 'e', 'r', 's', '\n',
        'v', 'a', 'l', 'u', 'e', 's', '\n',
        'v', 'a', 'l', 'u', 'i', 'n', 'g', '\n',
        'v', 'a', 'l', 'u', 't', 'a', '\n',
        'v', 'a', 'l', 'v', 'e', '\n',
        'v', 'a', 'l', 'v', 'e', 's', '\n',
        'v', 'a', 'm', 'p', '\n',
        'v', 'a', 'm', 'p', 'e', 'd', '\n',
        'v', 'a', 'm', 'p', 'e', 'r', '\n',
        'v', 'a', 'm', 'p', 'i', 'n', 'g', '\n',
        'v', 'a', 'm', 'p', 'i', 'r', 'e', '\n',
        'v', 'a', 'm', 'p', 'i', 'r', 'e', 's', '\n',
        'v', 'a', 'm', 'p', 's', '\n',
        'v', 'a', 'n', '\n',
        'v', 'a', 'n', 'a', 'd', 'i', 'u', 'm', '\n',
        'v', 'a', 'n', 'd', 'a', 'l', '\n',
        'v', 'a', 'n', 'd', 'a', 'l', 'i', 's', 'e', '\n',
        'v', 'a', 'n', 'd', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'v', 'a', 'n', 'd', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'v', 'a', 'n', 'd', 'a', 'l', 'i', 's', 'm', '\n',
        'v', 'a', 'n', 'd', 'a', 'l', 's', '\n',
        'v', 'a', 'n', 'e', '\n',
        'v', 'a', 'n', 'e', 'd', '\n',
        'v', 'a', 'n', 'e', 's', '\n',
        'v', 'a', 'n', 'g', 'o', 'g', 'h', '\n',
        'v', 'a', 'n', 'g', 'u', 'a', 'r', 'd', '\n',
        'v', 'a', 'n', 'i', 'l', 'l', 'a', '\n',
        'v', 'a', 'n', 'i', 's', 'h', '\n',
        'v', 'a', 'n', 'i', 's', 'h', 'e', 'd', '\n',
        'v', 'a', 'n', 'i', 's', 'h', 'e', 's', '\n',
        'v', 'a', 'n', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'v', 'a', 'n', 'i', 's', 'h', 'i', 'n', 'g', 'l', 'y', '\n',
        'v', 'a', 'n', 'i', 't', 'i', 'e', 's', '\n',
        'v', 'a', 'n', 'i', 't', 'y', '\n',
        'v', 'a', 'n', 'q', 'u', 'i', 's', 'h', '\n',
        'v', 'a', 'n', 'q', 'u', 'i', 's', 'h', 'e', 'd', '\n',
        'v', 'a', 'n', 'q', 'u', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'v', 'a', 'n', 's', '\n',
        'v', 'a', 'n', 't', 'a', 'g', 'e', '\n',
        'v', 'a', 'p', 'i', 'd', '\n',
        'v', 'a', 'p', 'o', 'r', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'v', 'a', 'p', 'o', 'r', 'i', 's', 'e', '\n',
        'v', 'a', 'p', 'o', 'r', 'i', 's', 'e', 'd', '\n',
        'v', 'a', 'p', 'o', 'r', 'i', 's', 'i', 'n', 'g', '\n',
        'v', 'a', 'p', 'o', 'r', 'o', 'u', 's', '\n',
        'v', 'a', 'p', 'o', 'u', 'r', '\n',
        'v', 'a', 'p', 'o', 'u', 'r', 's', '\n',
        'v', 'a', 'r', 'i', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'v', 'a', 'r', 'i', 'a', 'b', 'l', 'e', '\n',
        'v', 'a', 'r', 'i', 'a', 'b', 'l', 'e', 's', '\n',
        'v', 'a', 'r', 'i', 'a', 'b', 'l', 'y', '\n',
        'v', 'a', 'r', 'i', 'a', 'n', 'c', 'e', '\n',
        'v', 'a', 'r', 'i', 'a', 'n', 'c', 'e', 's', '\n',
        'v', 'a', 'r', 'i', 'a', 'n', 't', '\n',
        'v', 'a', 'r', 'i', 'a', 'n', 't', 's', '\n',
        'v', 'a', 'r', 'i', 'a', 't', 'e', '\n',
        'v', 'a', 'r', 'i', 'a', 't', 'e', 's', '\n',
        'v', 'a', 'r', 'i', 'a', 't', 'i', 'o', 'n', '\n',
        'v', 'a', 'r', 'i', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'v', 'a', 'r', 'i', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'v', 'a', 'r', 'i', 'c', 'o', 's', 'e', '\n',
        'v', 'a', 'r', 'i', 'e', 'd', '\n',
        'v', 'a', 'r', 'i', 'e', 'g', 'a', 't', 'e', 'd', '\n',
        'v', 'a', 'r', 'i', 'e', 's', '\n',
        'v', 'a', 'r', 'i', 'e', 't', 'a', 'l', '\n',
        'v', 'a', 'r', 'i', 'e', 't', 'i', 'e', 's', '\n',
        'v', 'a', 'r', 'i', 'e', 't', 'y', '\n',
        'v', 'a', 'r', 'i', 'o', 'u', 's', '\n',
        'v', 'a', 'r', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'v', 'a', 'r', 'n', 'i', 's', 'h', '\n',
        'v', 'a', 'r', 'n', 'i', 's', 'h', 'e', 'd', '\n',
        'v', 'a', 'r', 'n', 'i', 's', 'h', 'e', 's', '\n',
        'v', 'a', 'r', 'n', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'v', 'a', 'r', 's', 'i', 't', 'y', '\n',
        'v', 'a', 'r', 'y', '\n',
        'v', 'a', 'r', 'y', 'i', 'n', 'g', '\n',
        'v', 'a', 's', 'c', 'u', 'l', 'a', 'r', '\n',
        'v', 'a', 's', 'e', '\n',
        'v', 'a', 's', 'e', 'c', 't', 'o', 'm', 'i', 'e', 's', '\n',
        'v', 'a', 's', 'e', 'c', 't', 'o', 'm', 'y', '\n',
        'v', 'a', 's', 'e', 'l', 'i', 'n', 'e', '\n',
        'v', 'a', 's', 'e', 's', '\n',
        'v', 'a', 's', 's', 'a', 'l', '\n',
        'v', 'a', 's', 's', 'a', 'l', 'a', 'g', 'e', '\n',
        'v', 'a', 's', 's', 'a', 'l', 's', '\n',
        'v', 'a', 's', 't', '\n',
        'v', 'a', 's', 't', 'e', 'r', '\n',
        'v', 'a', 's', 't', 'l', 'y', '\n',
        'v', 'a', 's', 't', 'n', 'e', 's', 's', '\n',
        'v', 'a', 't', '\n',
        'v', 'a', 't', 'i', 'c', 'a', 'n', '\n',
        'v', 'a', 't', 's', '\n',
        'v', 'a', 'u', 'l', 't', '\n',
        'v', 'a', 'u', 'l', 't', 'e', 'd', '\n',
        'v', 'a', 'u', 'l', 't', 'i', 'n', 'g', '\n',
        'v', 'a', 'u', 'l', 't', 's', '\n',
        'v', 'a', 'u', 'n', 't', 'e', 'd', '\n',
        'v', 'a', 'u', 'n', 't', 'i', 'n', 'g', '\n',
        'v', 'e', 'a', 'l', '\n',
        'v', 'e', 'c', 't', 'o', 'r', '\n',
        'v', 'e', 'c', 't', 'o', 'r', 'e', 'd', '\n',
        'v', 'e', 'c', 't', 'o', 'r', 'i', 'n', 'g', '\n',
        'v', 'e', 'c', 't', 'o', 'r', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'v', 'e', 'c', 't', 'o', 'r', 'i', 's', 'e', 'd', '\n',
        'v', 'e', 'c', 't', 'o', 'r', 's', '\n',
        'v', 'e', 'e', 'r', '\n',
        'v', 'e', 'e', 'r', 'e', 'd', '\n',
        'v', 'e', 'e', 'r', 'i', 'n', 'g', '\n',
        'v', 'e', 'e', 'r', 's', '\n',
        'v', 'e', 'g', '\n',
        'v', 'e', 'g', 'a', 'n', '\n',
        'v', 'e', 'g', 'a', 'n', 's', '\n',
        'v', 'e', 'g', 'e', 't', 'a', 'b', 'l', 'e', '\n',
        'v', 'e', 'g', 'e', 't', 'a', 'b', 'l', 'e', 's', '\n',
        'v', 'e', 'g', 'e', 't', 'a', 'r', 'i', 'a', 'n', '\n',
        'v', 'e', 'g', 'e', 't', 'a', 'r', 'i', 'a', 'n', 'i', 's', 'm', '\n',
        'v', 'e', 'g', 'e', 't', 'a', 'r', 'i', 'a', 'n', 's', '\n',
        'v', 'e', 'g', 'e', 't', 'a', 't', 'e', '\n',
        'v', 'e', 'g', 'e', 't', 'a', 't', 'e', 'd', '\n',
        'v', 'e', 'g', 'e', 't', 'a', 't', 'i', 'n', 'g', '\n',
        'v', 'e', 'g', 'e', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'v', 'e', 'g', 'e', 't', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'v', 'e', 'g', 'e', 't', 'a', 't', 'i', 'v', 'e', '\n',
        'v', 'e', 'g', 'e', 't', 'i', 'v', 'e', '\n',
        'v', 'e', 'g', 'g', 'i', 'e', 's', '\n',
        'v', 'e', 'h', 'e', 'm', 'e', 'n', 'c', 'e', '\n',
        'v', 'e', 'h', 'e', 'm', 'e', 'n', 't', '\n',
        'v', 'e', 'h', 'e', 'm', 'e', 'n', 't', 'l', 'y', '\n',
        'v', 'e', 'h', 'i', 'c', 'l', 'e', '\n',
        'v', 'e', 'h', 'i', 'c', 'l', 'e', 's', '\n',
        'v', 'e', 'h', 'i', 'c', 'u', 'l', 'a', 'r', '\n',
        'v', 'e', 'i', 'l', '\n',
        'v', 'e', 'i', 'l', 'e', 'd', '\n',
        'v', 'e', 'i', 'l', 'i', 'n', 'g', '\n',
        'v', 'e', 'i', 'l', 's', '\n',
        'v', 'e', 'i', 'n', '\n',
        'v', 'e', 'i', 'n', 'e', 'd', '\n',
        'v', 'e', 'i', 'n', 's', '\n',
        'v', 'e', 'l', 'a', 'r', '\n',
        'v', 'e', 'l', 'd', '\n',
        'v', 'e', 'l', 'd', 't', '\n',
        'v', 'e', 'l', 'l', 'u', 'm', '\n',
        'v', 'e', 'l', 'o', 'c', 'i', 'p', 'e', 'd', 'e', '\n',
        'v', 'e', 'l', 'o', 'c', 'i', 't', 'i', 'e', 's', '\n',
        'v', 'e', 'l', 'o', 'c', 'i', 't', 'y', '\n',
        'v', 'e', 'l', 'o', 'd', 'r', 'o', 'm', 'e', '\n',
        'v', 'e', 'l', 'o', 'u', 'r', '\n',
        'v', 'e', 'l', 'u', 'm', '\n',
        'v', 'e', 'l', 'v', 'e', 't', '\n',
        'v', 'e', 'l', 'v', 'e', 't', 'e', 'e', 'n', '\n',
        'v', 'e', 'l', 'v', 'e', 't', 'e', 'e', 'n', 's', '\n',
        'v', 'e', 'l', 'v', 'e', 't', 's', '\n',
        'v', 'e', 'l', 'v', 'e', 't', 'y', '\n',
        'v', 'e', 'n', 'a', 'l', '\n',
        'v', 'e', 'n', 'a', 'l', 'i', 't', 'y', '\n',
        'v', 'e', 'n', 'd', '\n',
        'v', 'e', 'n', 'd', 'e', 'r', 's', '\n',
        'v', 'e', 'n', 'd', 'e', 't', 't', 'a', '\n',
        'v', 'e', 'n', 'd', 'e', 't', 't', 'a', 's', '\n',
        'v', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'v', 'e', 'n', 'd', 'o', 'r', '\n',
        'v', 'e', 'n', 'd', 'o', 'r', 's', '\n',
        'v', 'e', 'n', 'd', 's', '\n',
        'v', 'e', 'n', 'e', 'e', 'r', '\n',
        'v', 'e', 'n', 'e', 'e', 'r', 'e', 'd', '\n',
        'v', 'e', 'n', 'e', 'e', 'r', 's', '\n',
        'v', 'e', 'n', 'e', 'r', 'a', 'b', 'l', 'e', '\n',
        'v', 'e', 'n', 'e', 'r', 'a', 't', 'e', '\n',
        'v', 'e', 'n', 'e', 'r', 'a', 't', 'e', 'd', '\n',
        'v', 'e', 'n', 'e', 'r', 'a', 't', 'e', 's', '\n',
        'v', 'e', 'n', 'e', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'v', 'e', 'n', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'v', 'e', 'n', 'e', 'r', 'e', 'a', 'l', '\n',
        'v', 'e', 'n', 'e', 't', 'i', 'a', 'n', '\n',
        'v', 'e', 'n', 'g', 'e', 'a', 'n', 'c', 'e', '\n',
        'v', 'e', 'n', 'g', 'e', 'f', 'u', 'l', '\n',
        'v', 'e', 'n', 'g', 'e', 'f', 'u', 'l', 'l', 'y', '\n',
        'v', 'e', 'n', 'i', 'a', 'l', '\n',
        'v', 'e', 'n', 'i', 'c', 'e', '\n',
        'v', 'e', 'n', 'i', 's', 'o', 'n', '\n',
        'v', 'e', 'n', 'o', 'm', '\n',
        'v', 'e', 'n', 'o', 'm', 'o', 'u', 's', '\n',
        'v', 'e', 'n', 'o', 'm', 'o', 'u', 's', 'l', 'y', '\n',
        'v', 'e', 'n', 'o', 'm', 's', '\n',
        'v', 'e', 'n', 'o', 's', 'e', '\n',
        'v', 'e', 'n', 'o', 'u', 's', '\n',
        'v', 'e', 'n', 't', '\n',
        'v', 'e', 'n', 't', 'e', 'd', '\n',
        'v', 'e', 'n', 't', 'i', 'l', 'a', 't', 'e', '\n',
        'v', 'e', 'n', 't', 'i', 'l', 'a', 't', 'e', 'd', '\n',
        'v', 'e', 'n', 't', 'i', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'v', 'e', 'n', 't', 'i', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'v', 'e', 'n', 't', 'i', 'l', 'a', 't', 'o', 'r', '\n',
        'v', 'e', 'n', 't', 'i', 'l', 'a', 't', 'o', 'r', 's', '\n',
        'v', 'e', 'n', 't', 'i', 'n', 'g', '\n',
        'v', 'e', 'n', 't', 'i', 'n', 'g', 's', '\n',
        'v', 'e', 'n', 't', 'r', 'a', 'l', '\n',
        'v', 'e', 'n', 't', 'r', 'a', 'l', 'l', 'y', '\n',
        'v', 'e', 'n', 't', 'r', 'i', 'c', 'l', 'e', '\n',
        'v', 'e', 'n', 't', 'r', 'i', 'c', 'l', 'e', 's', '\n',
        'v', 'e', 'n', 't', 'r', 'i', 'c', 'u', 'l', 'a', 'r', '\n',
        'v', 'e', 'n', 't', 'r', 'i', 'l', 'o', 'q', 'u', 'i', 's', 'm', '\n',
        'v', 'e', 'n', 't', 'r', 'i', 'l', 'o', 'q', 'u', 'i', 's', 't', '\n',
        'v', 'e', 'n', 't', 'r', 'i', 'l', 'o', 'q', 'u', 'i', 's', 't', 's', '\n',
        'v', 'e', 'n', 't', 'r', 'i', 'l', 'o', 'q', 'u', 'y', '\n',
        'v', 'e', 'n', 't', 's', '\n',
        'v', 'e', 'n', 't', 'u', 'r', 'e', '\n',
        'v', 'e', 'n', 't', 'u', 'r', 'e', 'd', '\n',
        'v', 'e', 'n', 't', 'u', 'r', 'e', 'r', '\n',
        'v', 'e', 'n', 't', 'u', 'r', 'e', 's', '\n',
        'v', 'e', 'n', 't', 'u', 'r', 'e', 's', 'o', 'm', 'e', '\n',
        'v', 'e', 'n', 't', 'u', 'r', 'i', 'n', 'g', '\n',
        'v', 'e', 'n', 'u', 'e', '\n',
        'v', 'e', 'n', 'u', 'e', 's', '\n',
        'v', 'e', 'n', 'u', 's', '\n',
        'v', 'e', 'r', 'a', 'c', 'i', 't', 'y', '\n',
        'v', 'e', 'r', 'a', 'n', 'd', 'a', '\n',
        'v', 'e', 'r', 'a', 'n', 'd', 'a', 'h', '\n',
        'v', 'e', 'r', 'a', 'n', 'd', 'a', 'h', 's', '\n',
        'v', 'e', 'r', 'a', 'n', 'd', 'a', 's', '\n',
        'v', 'e', 'r', 'b', '\n',
        'v', 'e', 'r', 'b', 'a', 'l', '\n',
        'v', 'e', 'r', 'b', 'a', 'l', 'i', 's', 'e', '\n',
        'v', 'e', 'r', 'b', 'a', 'l', 'l', 'y', '\n',
        'v', 'e', 'r', 'b', 'a', 'l', 's', '\n',
        'v', 'e', 'r', 'b', 'a', 't', 'i', 'm', '\n',
        'v', 'e', 'r', 'b', 'i', 'a', 'g', 'e', '\n',
        'v', 'e', 'r', 'b', 'o', 's', 'e', '\n',
        'v', 'e', 'r', 'b', 'o', 's', 'e', 'l', 'y', '\n',
        'v', 'e', 'r', 'b', 'o', 's', 'e', 'n', 'e', 's', 's', '\n',
        'v', 'e', 'r', 'b', 'o', 's', 'i', 't', 'y', '\n',
        'v', 'e', 'r', 'b', 's', '\n',
        'v', 'e', 'r', 'd', 'a', 'n', 't', '\n',
        'v', 'e', 'r', 'd', 'i', 'c', 't', '\n',
        'v', 'e', 'r', 'd', 'i', 'c', 't', 's', '\n',
        'v', 'e', 'r', 'd', 'i', 'g', 'r', 'i', 's', '\n',
        'v', 'e', 'r', 'd', 'u', 'r', 'e', '\n',
        'v', 'e', 'r', 'g', 'e', '\n',
        'v', 'e', 'r', 'g', 'e', 'd', '\n',
        'v', 'e', 'r', 'g', 'e', 'r', '\n',
        'v', 'e', 'r', 'g', 'e', 's', '\n',
        'v', 'e', 'r', 'g', 'i', 'n', 'g', '\n',
        'v', 'e', 'r', 'i', 'f', 'i', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'v', 'e', 'r', 'i', 'f', 'i', 'a', 'b', 'l', 'e', '\n',
        'v', 'e', 'r', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'v', 'e', 'r', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'v', 'e', 'r', 'i', 'f', 'i', 'e', 'd', '\n',
        'v', 'e', 'r', 'i', 'f', 'i', 'e', 'r', '\n',
        'v', 'e', 'r', 'i', 'f', 'i', 'e', 'r', 's', '\n',
        'v', 'e', 'r', 'i', 'f', 'i', 'e', 's', '\n',
        'v', 'e', 'r', 'i', 'f', 'y', '\n',
        'v', 'e', 'r', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'v', 'e', 'r', 'i', 'l', 'y', '\n',
        'v', 'e', 'r', 'i', 's', 'i', 'm', 'i', 'l', 'i', 't', 'u', 'd', 'e', '\n',
        'v', 'e', 'r', 'i', 't', 'a', 'b', 'l', 'e', '\n',
        'v', 'e', 'r', 'i', 't', 'a', 'b', 'l', 'y', '\n',
        'v', 'e', 'r', 'i', 't', 'i', 'e', 's', '\n',
        'v', 'e', 'r', 'i', 't', 'y', '\n',
        'v', 'e', 'r', 'm', 'i', 'l', 'i', 'o', 'n', '\n',
        'v', 'e', 'r', 'm', 'i', 'n', '\n',
        'v', 'e', 'r', 'm', 'i', 'n', 'o', 'u', 's', '\n',
        'v', 'e', 'r', 'n', 'a', 'c', 'u', 'l', 'a', 'r', '\n',
        'v', 'e', 'r', 'n', 'a', 'l', '\n',
        'v', 'e', 'r', 'n', 'i', 'e', 'r', '\n',
        'v', 'e', 'r', 'o', 'n', 'a', '\n',
        'v', 'e', 'r', 's', 'a', 't', 'i', 'l', 'e', '\n',
        'v', 'e', 'r', 's', 'a', 't', 'i', 'l', 'i', 't', 'y', '\n',
        'v', 'e', 'r', 's', 'e', '\n',
        'v', 'e', 'r', 's', 'e', 'd', '\n',
        'v', 'e', 'r', 's', 'e', 's', '\n',
        'v', 'e', 'r', 's', 'i', 'c', 'l', 'e', '\n',
        'v', 'e', 'r', 's', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'v', 'e', 'r', 's', 'i', 'f', 'i', 'e', 'r', '\n',
        'v', 'e', 'r', 's', 'i', 'o', 'n', '\n',
        'v', 'e', 'r', 's', 'i', 'o', 'n', 's', '\n',
        'v', 'e', 'r', 's', 'u', 's', '\n',
        'v', 'e', 'r', 't', 'e', 'b', 'r', 'a', '\n',
        'v', 'e', 'r', 't', 'e', 'b', 'r', 'a', 'e', '\n',
        'v', 'e', 'r', 't', 'e', 'b', 'r', 'a', 'l', '\n',
        'v', 'e', 'r', 't', 'e', 'b', 'r', 'a', 't', 'e', '\n',
        'v', 'e', 'r', 't', 'e', 'b', 'r', 'a', 't', 'e', 's', '\n',
        'v', 'e', 'r', 't', 'e', 'x', '\n',
        'v', 'e', 'r', 't', 'i', 'c', 'a', 'l', '\n',
        'v', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'i', 't', 'y', '\n',
        'v', 'e', 'r', 't', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'v', 'e', 'r', 't', 'i', 'c', 'a', 'l', 's', '\n',
        'v', 'e', 'r', 't', 'i', 'c', 'e', 's', '\n',
        'v', 'e', 'r', 't', 'i', 'g', 'i', 'n', 'o', 'u', 's', '\n',
        'v', 'e', 'r', 't', 'i', 'g', 'o', '\n',
        'v', 'e', 'r', 'v', 'e', '\n',
        'v', 'e', 'r', 'y', '\n',
        'v', 'e', 's', 'i', 'c', 'l', 'e', '\n',
        'v', 'e', 's', 'i', 'c', 'l', 'e', 's', '\n',
        'v', 'e', 's', 'i', 'c', 'u', 'l', 'a', 'r', '\n',
        'v', 'e', 's', 'p', 'e', 'r', 's', '\n',
        'v', 'e', 's', 's', 'e', 'l', '\n',
        'v', 'e', 's', 's', 'e', 'l', 's', '\n',
        'v', 'e', 's', 't', '\n',
        'v', 'e', 's', 't', 'a', 'l', '\n',
        'v', 'e', 's', 't', 'e', 'd', '\n',
        'v', 'e', 's', 't', 'i', 'b', 'u', 'l', 'a', 'r', '\n',
        'v', 'e', 's', 't', 'i', 'b', 'u', 'l', 'e', '\n',
        'v', 'e', 's', 't', 'i', 'b', 'u', 'l', 'e', 's', '\n',
        'v', 'e', 's', 't', 'i', 'g', 'e', '\n',
        'v', 'e', 's', 't', 'i', 'g', 'e', 's', '\n',
        'v', 'e', 's', 't', 'i', 'g', 'i', 'a', 'l', '\n',
        'v', 'e', 's', 't', 'i', 'n', 'g', '\n',
        'v', 'e', 's', 't', 'm', 'e', 'n', 't', '\n',
        'v', 'e', 's', 't', 'm', 'e', 'n', 't', 's', '\n',
        'v', 'e', 's', 't', 'r', 'y', '\n',
        'v', 'e', 's', 't', 's', '\n',
        'v', 'e', 's', 'u', 'v', 'i', 'u', 's', '\n',
        'v', 'e', 't', '\n',
        'v', 'e', 't', 'e', 'r', 'a', 'n', '\n',
        'v', 'e', 't', 'e', 'r', 'a', 'n', 's', '\n',
        'v', 'e', 't', 'e', 'r', 'i', 'n', 'a', 'r', 'y', '\n',
        'v', 'e', 't', 'o', '\n',
        'v', 'e', 't', 'o', 'e', 'd', '\n',
        'v', 'e', 't', 'o', 'i', 'n', 'g', '\n',
        'v', 'e', 't', 's', '\n',
        'v', 'e', 't', 't', 'e', 'd', '\n',
        'v', 'e', 't', 't', 'i', 'n', 'g', '\n',
        'v', 'e', 'x', '\n',
        'v', 'e', 'x', 'a', 't', 'i', 'o', 'n', '\n',
        'v', 'e', 'x', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'v', 'e', 'x', 'a', 't', 'i', 'o', 'u', 's', '\n',
        'v', 'e', 'x', 'e', 'd', '\n',
        'v', 'e', 'x', 'e', 's', '\n',
        'v', 'e', 'x', 'i', 'n', 'g', '\n',
        'v', 'i', 'a', '\n',
        'v', 'i', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'v', 'i', 'a', 'b', 'l', 'e', '\n',
        'v', 'i', 'a', 'b', 'l', 'y', '\n',
        'v', 'i', 'a', 'd', 'u', 'c', 't', '\n',
        'v', 'i', 'a', 'd', 'u', 'c', 't', 's', '\n',
        'v', 'i', 'a', 'l', '\n',
        'v', 'i', 'a', 'l', 's', '\n',
        'v', 'i', 'b', 'e', 's', '\n',
        'v', 'i', 'b', 'r', 'a', 'n', 'c', 'y', '\n',
        'v', 'i', 'b', 'r', 'a', 'n', 't', '\n',
        'v', 'i', 'b', 'r', 'a', 'n', 't', 'l', 'y', '\n',
        'v', 'i', 'b', 'r', 'a', 't', 'e', '\n',
        'v', 'i', 'b', 'r', 'a', 't', 'e', 'd', '\n',
        'v', 'i', 'b', 'r', 'a', 't', 'e', 's', '\n',
        'v', 'i', 'b', 'r', 'a', 't', 'i', 'n', 'g', '\n',
        'v', 'i', 'b', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'v', 'i', 'b', 'r', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'v', 'i', 'b', 'r', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'v', 'i', 'b', 'r', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'v', 'i', 'b', 'r', 'a', 't', 'o', '\n',
        'v', 'i', 'b', 'r', 'a', 't', 'o', 'r', '\n',
        'v', 'i', 'b', 'r', 'a', 't', 'o', 'r', 's', '\n',
        'v', 'i', 'b', 'r', 'a', 't', 'o', 'r', 'y', '\n',
        'v', 'i', 'c', 'a', 'r', '\n',
        'v', 'i', 'c', 'a', 'r', 'a', 'g', 'e', '\n',
        'v', 'i', 'c', 'a', 'r', 'a', 'g', 'e', 's', '\n',
        'v', 'i', 'c', 'a', 'r', 'i', 'o', 'u', 's', '\n',
        'v', 'i', 'c', 'a', 'r', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'v', 'i', 'c', 'a', 'r', 's', '\n',
        'v', 'i', 'c', 'e', '\n',
        'v', 'i', 'c', 'e', 'c', 'h', 'a', 'n', 'c', 'e', 'l', 'l', 'o', 'r', '\n',
        'v', 'i', 'c', 'e', 'c', 'h', 'a', 'n', 'c', 'e', 'l', 'l', 'o', 'r', 's', '\n',
        'v', 'i', 'c', 'e', 'p', 'r', 'e', 's', 'i', 'd', 'e', 'n', 'c', 'y', '\n',
        'v', 'i', 'c', 'e', 'p', 'r', 'e', 's', 'i', 'd', 'e', 'n', 't', '\n',
        'v', 'i', 'c', 'e', 'p', 'r', 'e', 's', 'i', 'd', 'e', 'n', 't', 'i', 'a', 'l', '\n',
        'v', 'i', 'c', 'e', 'p', 'r', 'e', 's', 'i', 'd', 'e', 'n', 't', 's', '\n',
        'v', 'i', 'c', 'e', 'r', 'o', 'y', '\n',
        'v', 'i', 'c', 'e', 'r', 'o', 'y', 's', '\n',
        'v', 'i', 'c', 'e', 's', '\n',
        'v', 'i', 'c', 'i', 'n', 'i', 't', 'i', 'e', 's', '\n',
        'v', 'i', 'c', 'i', 'n', 'i', 't', 'y', '\n',
        'v', 'i', 'c', 'i', 'o', 'u', 's', '\n',
        'v', 'i', 'c', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'v', 'i', 'c', 'i', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'v', 'i', 'c', 'i', 's', 's', 'i', 't', 'u', 'd', 'e', '\n',
        'v', 'i', 'c', 'i', 's', 's', 'i', 't', 'u', 'd', 'e', 's', '\n',
        'v', 'i', 'c', 't', 'i', 'm', '\n',
        'v', 'i', 'c', 't', 'i', 'm', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'v', 'i', 'c', 't', 'i', 'm', 'i', 's', 'e', '\n',
        'v', 'i', 'c', 't', 'i', 'm', 'i', 's', 'e', 'd', '\n',
        'v', 'i', 'c', 't', 'i', 'm', 'i', 's', 'e', 's', '\n',
        'v', 'i', 'c', 't', 'i', 'm', 'i', 's', 'i', 'n', 'g', '\n',
        'v', 'i', 'c', 't', 'i', 'm', 'l', 'e', 's', 's', '\n',
        'v', 'i', 'c', 't', 'i', 'm', 's', '\n',
        'v', 'i', 'c', 't', 'o', 'r', '\n',
        'v', 'i', 'c', 't', 'o', 'r', 'i', 'a', '\n',
        'v', 'i', 'c', 't', 'o', 'r', 'i', 'e', 's', '\n',
        'v', 'i', 'c', 't', 'o', 'r', 'i', 'o', 'u', 's', '\n',
        'v', 'i', 'c', 't', 'o', 'r', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'v', 'i', 'c', 't', 'o', 'r', 's', '\n',
        'v', 'i', 'c', 't', 'o', 'r', 'y', '\n',
        'v', 'i', 'c', 't', 'u', 'a', 'l', 'l', 'i', 'n', 'g', '\n',
        'v', 'i', 'c', 't', 'u', 'a', 'l', 's', '\n',
        'v', 'i', 'd', 'e', 'o', '\n',
        'v', 'i', 'd', 'e', 'o', 'c', 'o', 'n', 'f', 'e', 'r', 'e', 'n', 'c', 'i', 'n', 'g', '\n',
        'v', 'i', 'd', 'e', 'o', 'd', 'i', 's', 'c', '\n',
        'v', 'i', 'd', 'e', 'o', 'e', 'd', '\n',
        'v', 'i', 'd', 'e', 'o', 'i', 'n', 'g', '\n',
        'v', 'i', 'd', 'e', 'o', 'p', 'h', 'o', 'n', 'e', '\n',
        'v', 'i', 'd', 'e', 'o', 's', '\n',
        'v', 'i', 'd', 'e', 'o', 't', 'a', 'p', 'e', '\n',
        'v', 'i', 'd', 'e', 'o', 't', 'a', 'p', 'e', 'd', '\n',
        'v', 'i', 'd', 'e', 'o', 't', 'a', 'p', 'e', 's', '\n',
        'v', 'i', 'd', 'e', 'o', 't', 'a', 'p', 'i', 'n', 'g', '\n',
        'v', 'i', 'e', '\n',
        'v', 'i', 'e', 'd', '\n',
        'v', 'i', 'e', 'n', 'n', 'a', '\n',
        'v', 'i', 'e', 'r', '\n',
        'v', 'i', 'e', 's', '\n',
        'v', 'i', 'e', 'w', '\n',
        'v', 'i', 'e', 'w', 'a', 'b', 'l', 'e', '\n',
        'v', 'i', 'e', 'w', 'e', 'd', '\n',
        'v', 'i', 'e', 'w', 'e', 'r', '\n',
        'v', 'i', 'e', 'w', 'e', 'r', 's', '\n',
        'v', 'i', 'e', 'w', 'f', 'i', 'n', 'd', 'e', 'r', '\n',
        'v', 'i', 'e', 'w', 'f', 'i', 'n', 'd', 'e', 'r', 's', '\n',
        'v', 'i', 'e', 'w', 'i', 'n', 'g', '\n',
        'v', 'i', 'e', 'w', 'i', 'n', 'g', 's', '\n',
        'v', 'i', 'e', 'w', 'p', 'o', 'i', 'n', 't', '\n',
        'v', 'i', 'e', 'w', 'p', 'o', 'i', 'n', 't', 's', '\n',
        'v', 'i', 'e', 'w', 's', '\n',
        'v', 'i', 'g', 'i', 'l', '\n',
        'v', 'i', 'g', 'i', 'l', 'a', 'n', 'c', 'e', '\n',
        'v', 'i', 'g', 'i', 'l', 'a', 'n', 't', '\n',
        'v', 'i', 'g', 'i', 'l', 'a', 'n', 't', 'e', '\n',
        'v', 'i', 'g', 'i', 'l', 'a', 'n', 't', 'e', 's', '\n',
        'v', 'i', 'g', 'i', 'l', 'a', 'n', 't', 'l', 'y', '\n',
        'v', 'i', 'g', 'i', 'l', 's', '\n',
        'v', 'i', 'g', 'n', 'e', 't', 't', 'e', '\n',
        'v', 'i', 'g', 'n', 'e', 't', 't', 'e', 's', '\n',
        'v', 'i', 'g', 'o', 'r', 'o', 'u', 's', '\n',
        'v', 'i', 'g', 'o', 'r', 'o', 'u', 's', 'l', 'y', '\n',
        'v', 'i', 'g', 'o', 'u', 'r', '\n',
        'v', 'i', 'k', 'i', 'n', 'g', '\n',
        'v', 'i', 'k', 'i', 'n', 'g', 's', '\n',
        'v', 'i', 'l', 'e', '\n',
        'v', 'i', 'l', 'e', 'l', 'y', '\n',
        'v', 'i', 'l', 'e', 'n', 'e', 's', 's', '\n',
        'v', 'i', 'l', 'e', 'r', '\n',
        'v', 'i', 'l', 'e', 's', 't', '\n',
        'v', 'i', 'l', 'i', 'f', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'v', 'i', 'l', 'i', 'f', 'i', 'e', 'd', '\n',
        'v', 'i', 'l', 'i', 'f', 'y', '\n',
        'v', 'i', 'l', 'i', 'f', 'y', 'i', 'n', 'g', '\n',
        'v', 'i', 'l', 'l', 'a', '\n',
        'v', 'i', 'l', 'l', 'a', 'g', 'e', '\n',
        'v', 'i', 'l', 'l', 'a', 'g', 'e', 'r', '\n',
        'v', 'i', 'l', 'l', 'a', 'g', 'e', 'r', 's', '\n',
        'v', 'i', 'l', 'l', 'a', 'g', 'e', 's', '\n',
        'v', 'i', 'l', 'l', 'a', 'i', 'n', '\n',
        'v', 'i', 'l', 'l', 'a', 'i', 'n', 'o', 'u', 's', '\n',
        'v', 'i', 'l', 'l', 'a', 'i', 'n', 's', '\n',
        'v', 'i', 'l', 'l', 'a', 'i', 'n', 'y', '\n',
        'v', 'i', 'l', 'l', 'a', 's', '\n',
        'v', 'i', 'm', '\n',
        'v', 'i', 'm', 's', '\n',
        'v', 'i', 'n', 'd', 'i', 'c', 'a', 't', 'e', '\n',
        'v', 'i', 'n', 'd', 'i', 'c', 'a', 't', 'e', 'd', '\n',
        'v', 'i', 'n', 'd', 'i', 'c', 'a', 't', 'e', 's', '\n',
        'v', 'i', 'n', 'd', 'i', 'c', 'a', 't', 'i', 'n', 'g', '\n',
        'v', 'i', 'n', 'd', 'i', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'v', 'i', 'n', 'd', 'i', 'c', 't', 'i', 'v', 'e', '\n',
        'v', 'i', 'n', 'd', 'i', 'c', 't', 'i', 'v', 'e', 'l', 'y', '\n',
        'v', 'i', 'n', 'd', 'i', 'c', 't', 'i', 'v', 'e', 'n', 'e', 's', 's', '\n',
        'v', 'i', 'n', 'e', '\n',
        'v', 'i', 'n', 'e', 'g', 'a', 'r', '\n',
        'v', 'i', 'n', 'e', 'g', 'a', 'r', 's', '\n',
        'v', 'i', 'n', 'e', 's', '\n',
        'v', 'i', 'n', 'e', 'y', 'a', 'r', 'd', '\n',
        'v', 'i', 'n', 'e', 'y', 'a', 'r', 'd', 's', '\n',
        'v', 'i', 'n', 'o', '\n',
        'v', 'i', 'n', 't', 'a', 'g', 'e', '\n',
        'v', 'i', 'n', 't', 'a', 'g', 'e', 's', '\n',
        'v', 'i', 'n', 't', 'n', 'e', 'r', '\n',
        'v', 'i', 'n', 'y', 'l', '\n',
        'v', 'i', 'n', 'y', 'l', 's', '\n',
        'v', 'i', 'o', 'l', '\n',
        'v', 'i', 'o', 'l', 'a', '\n',
        'v', 'i', 'o', 'l', 'a', 's', '\n',
        'v', 'i', 'o', 'l', 'a', 't', 'e', '\n',
        'v', 'i', 'o', 'l', 'a', 't', 'e', 'd', '\n',
        'v', 'i', 'o', 'l', 'a', 't', 'e', 's', '\n',
        'v', 'i', 'o', 'l', 'a', 't', 'i', 'n', 'g', '\n',
        'v', 'i', 'o', 'l', 'a', 't', 'i', 'o', 'n', '\n',
        'v', 'i', 'o', 'l', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'v', 'i', 'o', 'l', 'a', 't', 'o', 'r', '\n',
        'v', 'i', 'o', 'l', 'a', 't', 'o', 'r', 's', '\n',
        'v', 'i', 'o', 'l', 'e', 'n', 'c', 'e', '\n',
        'v', 'i', 'o', 'l', 'e', 'n', 't', '\n',
        'v', 'i', 'o', 'l', 'e', 'n', 't', 'l', 'y', '\n',
        'v', 'i', 'o', 'l', 'e', 't', '\n',
        'v', 'i', 'o', 'l', 'e', 't', 's', '\n',
        'v', 'i', 'o', 'l', 'i', 'n', '\n',
        'v', 'i', 'o', 'l', 'i', 'n', 'i', 's', 't', '\n',
        'v', 'i', 'o', 'l', 'i', 'n', 'i', 's', 't', 's', '\n',
        'v', 'i', 'o', 'l', 'i', 'n', 's', '\n',
        'v', 'i', 'o', 'l', 'i', 's', 't', '\n',
        'v', 'i', 'p', 'e', 'r', '\n',
        'v', 'i', 'p', 'e', 'r', 's', '\n',
        'v', 'i', 'r', 'a', 'g', 'o', '\n',
        'v', 'i', 'r', 'a', 'l', '\n',
        'v', 'i', 'r', 'g', 'i', 'l', '\n',
        'v', 'i', 'r', 'g', 'i', 'n', '\n',
        'v', 'i', 'r', 'g', 'i', 'n', 'a', 'l', '\n',
        'v', 'i', 'r', 'g', 'i', 'n', 'i', 'a', '\n',
        'v', 'i', 'r', 'g', 'i', 'n', 'i', 't', 'y', '\n',
        'v', 'i', 'r', 'g', 'i', 'n', 's', '\n',
        'v', 'i', 'r', 'i', 'l', 'e', '\n',
        'v', 'i', 'r', 'i', 'l', 'i', 't', 'y', '\n',
        'v', 'i', 'r', 'o', 'l', 'o', 'g', 'y', '\n',
        'v', 'i', 'r', 't', 'u', 'a', 'l', '\n',
        'v', 'i', 'r', 't', 'u', 'a', 'l', 'l', 'y', '\n',
        'v', 'i', 'r', 't', 'u', 'e', '\n',
        'v', 'i', 'r', 't', 'u', 'e', 's', '\n',
        'v', 'i', 'r', 't', 'u', 'o', 's', 'i', '\n',
        'v', 'i', 'r', 't', 'u', 'o', 's', 'i', 'c', '\n',
        'v', 'i', 'r', 't', 'u', 'o', 's', 'i', 't', 'y', '\n',
        'v', 'i', 'r', 't', 'u', 'o', 's', 'o', '\n',
        'v', 'i', 'r', 't', 'u', 'o', 'u', 's', '\n',
        'v', 'i', 'r', 't', 'u', 'o', 'u', 's', 'l', 'y', '\n',
        'v', 'i', 'r', 'u', 'l', 'e', 'n', 'c', 'e', '\n',
        'v', 'i', 'r', 'u', 'l', 'e', 'n', 't', '\n',
        'v', 'i', 'r', 'u', 'l', 'e', 'n', 't', 'l', 'y', '\n',
        'v', 'i', 'r', 'u', 's', '\n',
        'v', 'i', 'r', 'u', 's', 'e', 's', '\n',
        'v', 'i', 's', 'a', '\n',
        'v', 'i', 's', 'a', 'g', 'e', '\n',
        'v', 'i', 's', 'a', 's', '\n',
        'v', 'i', 's', 'c', 'o', 's', 'e', '\n',
        'v', 'i', 's', 'c', 'o', 's', 'i', 't', 'y', '\n',
        'v', 'i', 's', 'c', 'o', 'u', 'n', 't', '\n',
        'v', 'i', 's', 'c', 'o', 'u', 'n', 't', 's', '\n',
        'v', 'i', 's', 'c', 'o', 'u', 's', '\n',
        'v', 'i', 's', 'e', '\n',
        'v', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'v', 'i', 's', 'i', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'v', 'i', 's', 'i', 'b', 'l', 'e', '\n',
        'v', 'i', 's', 'i', 'b', 'l', 'y', '\n',
        'v', 'i', 's', 'i', 'o', 'n', '\n',
        'v', 'i', 's', 'i', 'o', 'n', 'a', 'r', 'i', 'e', 's', '\n',
        'v', 'i', 's', 'i', 'o', 'n', 'a', 'r', 'y', '\n',
        'v', 'i', 's', 'i', 'o', 'n', 's', '\n',
        'v', 'i', 's', 'i', 't', '\n',
        'v', 'i', 's', 'i', 't', 'a', 'b', 'l', 'e', '\n',
        'v', 'i', 's', 'i', 't', 'a', 'n', 't', '\n',
        'v', 'i', 's', 'i', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'v', 'i', 's', 'i', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'v', 'i', 's', 'i', 't', 'e', 'd', '\n',
        'v', 'i', 's', 'i', 't', 'i', 'n', 'g', '\n',
        'v', 'i', 's', 'i', 't', 'o', 'r', '\n',
        'v', 'i', 's', 'i', 't', 'o', 'r', 's', '\n',
        'v', 'i', 's', 'i', 't', 's', '\n',
        'v', 'i', 's', 'o', 'r', '\n',
        'v', 'i', 's', 'o', 'r', 's', '\n',
        'v', 'i', 's', 't', 'a', '\n',
        'v', 'i', 's', 't', 'a', 's', '\n',
        'v', 'i', 's', 'u', 'a', 'l', '\n',
        'v', 'i', 's', 'u', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'v', 'i', 's', 'u', 'a', 'l', 'i', 's', 'e', '\n',
        'v', 'i', 's', 'u', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'v', 'i', 's', 'u', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'v', 'i', 's', 'u', 'a', 'l', 'l', 'y', '\n',
        'v', 'i', 's', 'u', 'a', 'l', 's', '\n',
        'v', 'i', 't', 'a', 'l', '\n',
        'v', 'i', 't', 'a', 'l', 'i', 's', 'e', '\n',
        'v', 'i', 't', 'a', 'l', 'i', 't', 'y', '\n',
        'v', 'i', 't', 'a', 'l', 'l', 'y', '\n',
        'v', 'i', 't', 'a', 'l', 's', '\n',
        'v', 'i', 't', 'a', 'm', 'i', 'n', '\n',
        'v', 'i', 't', 'a', 'm', 'i', 'n', 's', '\n',
        'v', 'i', 't', 'i', 'a', 't', 'e', '\n',
        'v', 'i', 't', 'i', 'a', 't', 'e', 'd', '\n',
        'v', 'i', 't', 'i', 'a', 't', 'e', 's', '\n',
        'v', 'i', 't', 'i', 'a', 't', 'i', 'n', 'g', '\n',
        'v', 'i', 't', 'r', 'e', 'o', 'u', 's', '\n',
        'v', 'i', 't', 'r', 'i', 'f', 'i', 'e', 'd', '\n',
        'v', 'i', 't', 'r', 'i', 'o', 'l', '\n',
        'v', 'i', 't', 'r', 'i', 'o', 'l', 'i', 'c', '\n',
        'v', 'i', 't', 'u', 'p', 'e', 'r', 'a', 't', 'e', '\n',
        'v', 'i', 't', 'u', 'p', 'e', 'r', 'a', 't', 'i', 'o', 'n', '\n',
        'v', 'i', 't', 'u', 'p', 'e', 'r', 'a', 't', 'i', 'v', 'e', '\n',
        'v', 'i', 'v', 'a', '\n',
        'v', 'i', 'v', 'a', 'c', 'i', 'o', 'u', 's', '\n',
        'v', 'i', 'v', 'a', 'c', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'v', 'i', 'v', 'a', 'c', 'i', 't', 'y', '\n',
        'v', 'i', 'v', 'i', 'd', '\n',
        'v', 'i', 'v', 'i', 'd', 'l', 'y', '\n',
        'v', 'i', 'v', 'i', 'd', 'n', 'e', 's', 's', '\n',
        'v', 'i', 'v', 'i', 'f', 'i', 'e', 'd', '\n',
        'v', 'i', 'v', 'i', 's', 'e', 'c', 't', 'e', 'd', '\n',
        'v', 'i', 'v', 'i', 's', 'e', 'c', 't', 'i', 'o', 'n', '\n',
        'v', 'i', 'v', 'i', 's', 'e', 'c', 't', 'i', 'o', 'n', 'i', 's', 't', '\n',
        'v', 'i', 'v', 'i', 's', 'e', 'c', 't', 'i', 'o', 'n', 'i', 's', 't', 's', '\n',
        'v', 'i', 'x', 'e', 'n', '\n',
        'v', 'i', 'x', 'e', 'n', 's', '\n',
        'v', 'i', 'z', 'i', 'e', 'r', '\n',
        'v', 'o', 'c', 'a', 'b', 'u', 'l', 'a', 'r', 'i', 'e', 's', '\n',
        'v', 'o', 'c', 'a', 'b', 'u', 'l', 'a', 'r', 'y', '\n',
        'v', 'o', 'c', 'a', 'l', '\n',
        'v', 'o', 'c', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'v', 'o', 'c', 'a', 'l', 'i', 's', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'v', 'o', 'c', 'a', 'l', 'i', 's', 'e', '\n',
        'v', 'o', 'c', 'a', 'l', 'i', 's', 'e', 'd', '\n',
        'v', 'o', 'c', 'a', 'l', 'i', 's', 'i', 'n', 'g', '\n',
        'v', 'o', 'c', 'a', 'l', 'i', 's', 't', '\n',
        'v', 'o', 'c', 'a', 'l', 'i', 's', 't', 's', '\n',
        'v', 'o', 'c', 'a', 'l', 'l', 'y', '\n',
        'v', 'o', 'c', 'a', 'l', 's', '\n',
        'v', 'o', 'c', 'a', 't', 'i', 'o', 'n', '\n',
        'v', 'o', 'c', 'a', 't', 'i', 'o', 'n', 'a', 'l', '\n',
        'v', 'o', 'c', 'a', 't', 'i', 'o', 'n', 'a', 'l', 'l', 'y', '\n',
        'v', 'o', 'c', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'v', 'o', 'c', 'a', 't', 'i', 'v', 'e', '\n',
        'v', 'o', 'c', 'i', 'f', 'e', 'r', 'o', 'u', 's', '\n',
        'v', 'o', 'c', 'i', 'f', 'e', 'r', 'o', 'u', 's', 'l', 'y', '\n',
        'v', 'o', 'd', 'k', 'a', '\n',
        'v', 'o', 'g', 'u', 'e', '\n',
        'v', 'o', 'i', 'c', 'e', '\n',
        'v', 'o', 'i', 'c', 'e', 'd', '\n',
        'v', 'o', 'i', 'c', 'e', 'l', 'e', 's', 's', '\n',
        'v', 'o', 'i', 'c', 'e', 's', '\n',
        'v', 'o', 'i', 'c', 'i', 'n', 'g', '\n',
        'v', 'o', 'i', 'c', 'i', 'n', 'g', 's', '\n',
        'v', 'o', 'i', 'd', '\n',
        'v', 'o', 'i', 'd', 'a', 'b', 'l', 'e', '\n',
        'v', 'o', 'i', 'd', 'e', 'd', '\n',
        'v', 'o', 'i', 'd', 'i', 'n', 'g', '\n',
        'v', 'o', 'i', 'd', 's', '\n',
        'v', 'o', 'i', 'l', 'e', '\n',
        'v', 'o', 'l', 'a', 't', 'i', 'l', 'e', '\n',
        'v', 'o', 'l', 'a', 't', 'i', 'l', 'e', 's', '\n',
        'v', 'o', 'l', 'a', 't', 'i', 'l', 'i', 't', 'y', '\n',
        'v', 'o', 'l', 'c', 'a', 'n', 'i', 'c', '\n',
        'v', 'o', 'l', 'c', 'a', 'n', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'v', 'o', 'l', 'c', 'a', 'n', 'i', 's', 'm', '\n',
        'v', 'o', 'l', 'c', 'a', 'n', 'o', '\n',
        'v', 'o', 'l', 'e', '\n',
        'v', 'o', 'l', 'e', 's', '\n',
        'v', 'o', 'l', 'g', 'a', '\n',
        'v', 'o', 'l', 'i', 't', 'i', 'o', 'n', '\n',
        'v', 'o', 'l', 'l', 'e', 'y', '\n',
        'v', 'o', 'l', 'l', 'e', 'y', 'b', 'a', 'l', 'l', '\n',
        'v', 'o', 'l', 'l', 'e', 'y', 'e', 'd', '\n',
        'v', 'o', 'l', 'l', 'e', 'y', 'i', 'n', 'g', '\n',
        'v', 'o', 'l', 'l', 'e', 'y', 's', '\n',
        'v', 'o', 'l', 't', '\n',
        'v', 'o', 'l', 't', 'a', 'g', 'e', '\n',
        'v', 'o', 'l', 't', 'a', 'g', 'e', 's', '\n',
        'v', 'o', 'l', 't', 'm', 'e', 't', 'e', 'r', '\n',
        'v', 'o', 'l', 't', 's', '\n',
        'v', 'o', 'l', 'u', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'v', 'o', 'l', 'u', 'b', 'l', 'e', '\n',
        'v', 'o', 'l', 'u', 'b', 'l', 'y', '\n',
        'v', 'o', 'l', 'u', 'm', 'e', '\n',
        'v', 'o', 'l', 'u', 'm', 'e', 's', '\n',
        'v', 'o', 'l', 'u', 'm', 'e', 't', 'r', 'i', 'c', '\n',
        'v', 'o', 'l', 'u', 'm', 'i', 'n', 'o', 'u', 's', '\n',
        'v', 'o', 'l', 'u', 'n', 't', 'a', 'r', 'i', 'l', 'y', '\n',
        'v', 'o', 'l', 'u', 'n', 't', 'a', 'r', 'y', '\n',
        'v', 'o', 'l', 'u', 'n', 't', 'e', 'e', 'r', '\n',
        'v', 'o', 'l', 'u', 'n', 't', 'e', 'e', 'r', 'e', 'd', '\n',
        'v', 'o', 'l', 'u', 'n', 't', 'e', 'e', 'r', 'i', 'n', 'g', '\n',
        'v', 'o', 'l', 'u', 'n', 't', 'e', 'e', 'r', 's', '\n',
        'v', 'o', 'l', 'u', 'p', 't', 'u', 'o', 'u', 's', '\n',
        'v', 'o', 'l', 'u', 'p', 't', 'u', 'o', 'u', 's', 'l', 'y', '\n',
        'v', 'o', 'l', 'u', 'p', 't', 'u', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'v', 'o', 'l', 'u', 't', 'e', '\n',
        'v', 'o', 'm', 'i', 't', '\n',
        'v', 'o', 'm', 'i', 't', 'e', 'd', '\n',
        'v', 'o', 'm', 'i', 't', 'i', 'n', 'g', '\n',
        'v', 'o', 'm', 'i', 't', 's', '\n',
        'v', 'o', 'o', 'd', 'o', 'o', '\n',
        'v', 'o', 'r', 'a', 'c', 'i', 'o', 'u', 's', '\n',
        'v', 'o', 'r', 'a', 'c', 'i', 'o', 'u', 's', 'l', 'y', '\n',
        'v', 'o', 'r', 'a', 'c', 'i', 't', 'y', '\n',
        'v', 'o', 'r', 't', 'e', 'x', '\n',
        'v', 'o', 'r', 't', 'e', 'x', 'e', 's', '\n',
        'v', 'o', 'r', 't', 'i', 'c', 'e', 's', '\n',
        'v', 'o', 'r', 't', 'i', 'c', 'i', 't', 'y', '\n',
        'v', 'o', 't', 'e', '\n',
        'v', 'o', 't', 'e', 'd', '\n',
        'v', 'o', 't', 'e', 'l', 'e', 's', 's', '\n',
        'v', 'o', 't', 'e', 'r', '\n',
        'v', 'o', 't', 'e', 'r', 's', '\n',
        'v', 'o', 't', 'e', 's', '\n',
        'v', 'o', 't', 'i', 'n', 'g', '\n',
        'v', 'o', 't', 'i', 'v', 'e', '\n',
        'v', 'o', 'u', 'c', 'h', '\n',
        'v', 'o', 'u', 'c', 'h', 'e', 'd', '\n',
        'v', 'o', 'u', 'c', 'h', 'e', 'r', '\n',
        'v', 'o', 'u', 'c', 'h', 'e', 'r', 's', '\n',
        'v', 'o', 'u', 'c', 'h', 'e', 's', '\n',
        'v', 'o', 'u', 'c', 'h', 's', 'a', 'f', 'e', '\n',
        'v', 'o', 'u', 'c', 'h', 's', 'a', 'f', 'e', 'd', '\n',
        'v', 'o', 'u', 'c', 'h', 's', 'a', 'f', 'i', 'n', 'g', '\n',
        'v', 'o', 'w', '\n',
        'v', 'o', 'w', 'e', 'd', '\n',
        'v', 'o', 'w', 'e', 'l', '\n',
        'v', 'o', 'w', 'e', 'l', 's', '\n',
        'v', 'o', 'w', 'i', 'n', 'g', '\n',
        'v', 'o', 'w', 's', '\n',
        'v', 'o', 'y', 'a', 'g', 'e', '\n',
        'v', 'o', 'y', 'a', 'g', 'e', 'd', '\n',
        'v', 'o', 'y', 'a', 'g', 'e', 'r', '\n',
        'v', 'o', 'y', 'a', 'g', 'e', 'r', 's', '\n',
        'v', 'o', 'y', 'a', 'g', 'e', 's', '\n',
        'v', 'o', 'y', 'a', 'g', 'i', 'n', 'g', '\n',
        'v', 'o', 'y', 'e', 'u', 'r', '\n',
        'v', 'o', 'y', 'e', 'u', 'r', 'i', 's', 'm', '\n',
        'v', 'o', 'y', 'e', 'u', 'r', 'i', 's', 't', 'i', 'c', '\n',
        'v', 'o', 'y', 'e', 'u', 'r', 's', '\n',
        'v', 'u', 'l', 'c', 'a', 'n', '\n',
        'v', 'u', 'l', 'c', 'a', 'n', 'i', 's', 'e', '\n',
        'v', 'u', 'l', 'c', 'a', 'n', 'i', 's', 'e', 'd', '\n',
        'v', 'u', 'l', 'c', 'a', 'n', 'i', 's', 'm', '\n',
        'v', 'u', 'l', 'c', 'a', 'n', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'v', 'u', 'l', 'g', 'a', 'r', '\n',
        'v', 'u', 'l', 'g', 'a', 'r', 'i', 't', 'i', 'e', 's', '\n',
        'v', 'u', 'l', 'g', 'a', 'r', 'i', 't', 'y', '\n',
        'v', 'u', 'l', 'g', 'a', 'r', 'l', 'y', '\n',
        'v', 'u', 'l', 'g', 'a', 't', 'e', '\n',
        'v', 'u', 'l', 'n', 'e', 'r', 'a', 'b', 'i', 'l', 'i', 't', 'i', 'e', 's', '\n',
        'v', 'u', 'l', 'n', 'e', 'r', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'v', 'u', 'l', 'n', 'e', 'r', 'a', 'b', 'l', 'e', '\n',
        'v', 'u', 'l', 'p', 'i', 'n', 'e', '\n',
        'v', 'u', 'l', 't', 'u', 'r', 'e', '\n',
        'v', 'u', 'l', 't', 'u', 'r', 'e', 's', '\n',
        'v', 'u', 'l', 'v', 'a', '\n',
        'v', 'y', 'i', 'n', 'g', '\n',
        'w', 'a', 'c', 'k', 'i', 'e', 'r', '\n',
        'w', 'a', 'c', 'k', 'y', '\n',
        'w', 'a', 'd', '\n',
        'w', 'a', 'd', 'd', 'i', 'n', 'g', '\n',
        'w', 'a', 'd', 'd', 'l', 'e', '\n',
        'w', 'a', 'd', 'd', 'l', 'e', 'd', '\n',
        'w', 'a', 'd', 'd', 'l', 'e', 's', '\n',
        'w', 'a', 'd', 'd', 'l', 'i', 'n', 'g', '\n',
        'w', 'a', 'd', 'e', '\n',
        'w', 'a', 'd', 'e', 'd', '\n',
        'w', 'a', 'd', 'e', 'r', '\n',
        'w', 'a', 'd', 'e', 'r', 's', '\n',
        'w', 'a', 'd', 'e', 's', '\n',
        'w', 'a', 'd', 'i', '\n',
        'w', 'a', 'd', 'i', 'n', 'g', '\n',
        'w', 'a', 'd', 'i', 'n', 'g', 's', '\n',
        'w', 'a', 'd', 'i', 's', '\n',
        'w', 'a', 'd', 's', '\n',
        'w', 'a', 'f', 'e', 'r', '\n',
        'w', 'a', 'f', 'e', 'r', 's', '\n',
        'w', 'a', 'f', 'f', 'l', 'e', '\n',
        'w', 'a', 'f', 'f', 'l', 'e', 'd', '\n',
        'w', 'a', 'f', 'f', 'l', 'e', 's', '\n',
        'w', 'a', 'f', 't', '\n',
        'w', 'a', 'f', 't', 'e', 'd', '\n',
        'w', 'a', 'f', 't', 'i', 'n', 'g', '\n',
        'w', 'a', 'f', 't', 's', '\n',
        'w', 'a', 'f', 't', 'u', 'r', 'e', '\n',
        'w', 'a', 'g', '\n',
        'w', 'a', 'g', 'e', '\n',
        'w', 'a', 'g', 'e', 'd', '\n',
        'w', 'a', 'g', 'e', 'r', '\n',
        'w', 'a', 'g', 'e', 'r', 'e', 'd', '\n',
        'w', 'a', 'g', 'e', 'r', 'e', 'r', '\n',
        'w', 'a', 'g', 'e', 'r', 's', '\n',
        'w', 'a', 'g', 'e', 's', '\n',
        'w', 'a', 'g', 'g', 'e', 'd', '\n',
        'w', 'a', 'g', 'g', 'e', 'r', 'y', '\n',
        'w', 'a', 'g', 'g', 'i', 'n', 'g', '\n',
        'w', 'a', 'g', 'g', 'i', 's', 'h', '\n',
        'w', 'a', 'g', 'g', 'i', 's', 'h', 'l', 'y', '\n',
        'w', 'a', 'g', 'g', 'l', 'e', '\n',
        'w', 'a', 'g', 'g', 'l', 'e', 'd', '\n',
        'w', 'a', 'g', 'g', 'l', 'e', 's', '\n',
        'w', 'a', 'g', 'g', 'l', 'i', 'n', 'g', '\n',
        'w', 'a', 'g', 'g', 'l', 'y', '\n',
        'w', 'a', 'g', 'g', 'o', 'n', 'e', 'r', 's', '\n',
        'w', 'a', 'g', 'g', 'o', 'n', 's', '\n',
        'w', 'a', 'g', 'i', 'n', 'g', '\n',
        'w', 'a', 'g', 'o', 'n', '\n',
        'w', 'a', 'g', 'o', 'n', 's', '\n',
        'w', 'a', 'g', 's', '\n',
        'w', 'a', 'g', 't', 'a', 'i', 'l', '\n',
        'w', 'a', 'g', 't', 'a', 'i', 'l', 's', '\n',
        'w', 'a', 'i', 'f', '\n',
        'w', 'a', 'i', 'f', 's', '\n',
        'w', 'a', 'i', 'l', '\n',
        'w', 'a', 'i', 'l', 'e', 'd', '\n',
        'w', 'a', 'i', 'l', 'e', 'r', '\n',
        'w', 'a', 'i', 'l', 'i', 'n', 'g', '\n',
        'w', 'a', 'i', 'l', 's', '\n',
        'w', 'a', 'i', 'n', 's', 'c', 'o', 't', '\n',
        'w', 'a', 'i', 'n', 's', 'c', 'o', 't', 'i', 'n', 'g', '\n',
        'w', 'a', 'i', 's', 't', '\n',
        'w', 'a', 'i', 's', 't', 'b', 'a', 'n', 'd', '\n',
        'w', 'a', 'i', 's', 't', 'c', 'o', 'a', 't', '\n',
        'w', 'a', 'i', 's', 't', 'c', 'o', 'a', 't', 's', '\n',
        'w', 'a', 'i', 's', 't', 'l', 'i', 'n', 'e', '\n',
        'w', 'a', 'i', 's', 't', 's', '\n',
        'w', 'a', 'i', 't', '\n',
        'w', 'a', 'i', 't', 'e', 'd', '\n',
        'w', 'a', 'i', 't', 'e', 'r', '\n',
        'w', 'a', 'i', 't', 'e', 'r', 's', '\n',
        'w', 'a', 'i', 't', 'i', 'n', 'g', '\n',
        'w', 'a', 'i', 't', 'r', 'e', 's', 's', '\n',
        'w', 'a', 'i', 't', 'r', 'e', 's', 's', 'e', 's', '\n',
        'w', 'a', 'i', 't', 's', '\n',
        'w', 'a', 'i', 'v', 'e', '\n',
        'w', 'a', 'i', 'v', 'e', 'd', '\n',
        'w', 'a', 'i', 'v', 'e', 'r', '\n',
        'w', 'a', 'i', 'v', 'e', 'r', 's', '\n',
        'w', 'a', 'i', 'v', 'e', 's', '\n',
        'w', 'a', 'i', 'v', 'i', 'n', 'g', '\n',
        'w', 'a', 'k', 'e', '\n',
        'w', 'a', 'k', 'e', 'd', '\n',
        'w', 'a', 'k', 'e', 'f', 'u', 'l', '\n',
        'w', 'a', 'k', 'e', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'w', 'a', 'k', 'e', 'n', '\n',
        'w', 'a', 'k', 'e', 'n', 'e', 'd', '\n',
        'w', 'a', 'k', 'e', 'n', 'i', 'n', 'g', '\n',
        'w', 'a', 'k', 'e', 'n', 's', '\n',
        'w', 'a', 'k', 'e', 's', '\n',
        'w', 'a', 'k', 'i', 'n', 'g', '\n',
        'w', 'a', 'l', 'e', 's', '\n',
        'w', 'a', 'l', 'k', '\n',
        'w', 'a', 'l', 'k', 'a', 'b', 'l', 'e', '\n',
        'w', 'a', 'l', 'k', 'a', 'b', 'o', 'u', 't', '\n',
        'w', 'a', 'l', 'k', 'a', 'b', 'o', 'u', 't', 's', '\n',
        'w', 'a', 'l', 'k', 'e', 'd', '\n',
        'w', 'a', 'l', 'k', 'e', 'r', '\n',
        'w', 'a', 'l', 'k', 'e', 'r', 's', '\n',
        'w', 'a', 'l', 'k', 'i', 'e', 't', 'a', 'l', 'k', 'i', 'e', '\n',
        'w', 'a', 'l', 'k', 'i', 'e', 't', 'a', 'l', 'k', 'i', 'e', 's', '\n',
        'w', 'a', 'l', 'k', 'i', 'n', 'g', '\n',
        'w', 'a', 'l', 'k', 'o', 'u', 't', '\n',
        'w', 'a', 'l', 'k', 'o', 'v', 'e', 'r', '\n',
        'w', 'a', 'l', 'k', 's', '\n',
        'w', 'a', 'l', 'k', 'w', 'a', 'y', '\n',
        'w', 'a', 'l', 'k', 'w', 'a', 'y', 's', '\n',
        'w', 'a', 'l', 'l', '\n',
        'w', 'a', 'l', 'l', 'a', 'b', 'i', 'e', 's', '\n',
        'w', 'a', 'l', 'l', 'a', 'b', 'y', '\n',
        'w', 'a', 'l', 'l', 'c', 'h', 'a', 'r', 't', '\n',
        'w', 'a', 'l', 'l', 'e', 'd', '\n',
        'w', 'a', 'l', 'l', 'e', 't', '\n',
        'w', 'a', 'l', 'l', 'e', 't', 's', '\n',
        'w', 'a', 'l', 'l', 'f', 'l', 'o', 'w', 'e', 'r', '\n',
        'w', 'a', 'l', 'l', 'f', 'l', 'o', 'w', 'e', 'r', 's', '\n',
        'w', 'a', 'l', 'l', 'i', 'n', 'g', '\n',
        'w', 'a', 'l', 'l', 'o', 'p', '\n',
        'w', 'a', 'l', 'l', 'o', 'w', '\n',
        'w', 'a', 'l', 'l', 'o', 'w', 'e', 'd', '\n',
        'w', 'a', 'l', 'l', 'o', 'w', 'i', 'n', 'g', '\n',
        'w', 'a', 'l', 'l', 'o', 'w', 's', '\n',
        'w', 'a', 'l', 'l', 'p', 'a', 'p', 'e', 'r', '\n',
        'w', 'a', 'l', 'l', 'p', 'a', 'p', 'e', 'r', 'i', 'n', 'g', '\n',
        'w', 'a', 'l', 'l', 'p', 'a', 'p', 'e', 'r', 's', '\n',
        'w', 'a', 'l', 'l', 's', '\n',
        'w', 'a', 'l', 'l', 't', 'o', 'w', 'a', 'l', 'l', '\n',
        'w', 'a', 'l', 'n', 'u', 't', '\n',
        'w', 'a', 'l', 'n', 'u', 't', 's', '\n',
        'w', 'a', 'l', 'r', 'u', 's', '\n',
        'w', 'a', 'l', 'r', 'u', 's', 'e', 's', '\n',
        'w', 'a', 'l', 't', 'z', '\n',
        'w', 'a', 'l', 't', 'z', 'e', 'd', '\n',
        'w', 'a', 'l', 't', 'z', 'e', 's', '\n',
        'w', 'a', 'l', 't', 'z', 'i', 'n', 'g', '\n',
        'w', 'a', 'n', '\n',
        'w', 'a', 'n', 'd', '\n',
        'w', 'a', 'n', 'd', 'e', 'r', '\n',
        'w', 'a', 'n', 'd', 'e', 'r', 'e', 'd', '\n',
        'w', 'a', 'n', 'd', 'e', 'r', 'e', 'r', '\n',
        'w', 'a', 'n', 'd', 'e', 'r', 'e', 'r', 's', '\n',
        'w', 'a', 'n', 'd', 'e', 'r', 'i', 'n', 'g', '\n',
        'w', 'a', 'n', 'd', 'e', 'r', 'i', 'n', 'g', 's', '\n',
        'w', 'a', 'n', 'd', 'e', 'r', 'l', 'u', 's', 't', '\n',
        'w', 'a', 'n', 'd', 'e', 'r', 's', '\n',
        'w', 'a', 'n', 'd', 's', '\n',
        'w', 'a', 'n', 'e', '\n',
        'w', 'a', 'n', 'e', 'd', '\n',
        'w', 'a', 'n', 'e', 's', '\n',
        'w', 'a', 'n', 'i', 'n', 'g', '\n',
        'w', 'a', 'n', 'l', 'y', '\n',
        'w', 'a', 'n', 't', '\n',
        'w', 'a', 'n', 't', 'e', 'd', '\n',
        'w', 'a', 'n', 't', 'i', 'n', 'g', '\n',
        'w', 'a', 'n', 't', 'o', 'n', '\n',
        'w', 'a', 'n', 't', 'o', 'n', 'l', 'y', '\n',
        'w', 'a', 'n', 't', 'o', 'n', 'n', 'e', 's', 's', '\n',
        'w', 'a', 'n', 't', 's', '\n',
        'w', 'a', 'p', 'i', 't', 'i', '\n',
        'w', 'a', 'p', 'i', 't', 'i', 's', '\n',
        'w', 'a', 'r', '\n',
        'w', 'a', 'r', 'b', 'l', 'e', '\n',
        'w', 'a', 'r', 'b', 'l', 'e', 'd', '\n',
        'w', 'a', 'r', 'b', 'l', 'e', 'r', '\n',
        'w', 'a', 'r', 'b', 'l', 'e', 'r', 's', '\n',
        'w', 'a', 'r', 'b', 'l', 'e', 's', '\n',
        'w', 'a', 'r', 'b', 'l', 'i', 'n', 'g', '\n',
        'w', 'a', 'r', 'd', '\n',
        'w', 'a', 'r', 'd', 'e', 'd', '\n',
        'w', 'a', 'r', 'd', 'e', 'n', '\n',
        'w', 'a', 'r', 'd', 'e', 'n', 's', '\n',
        'w', 'a', 'r', 'd', 'e', 'r', '\n',
        'w', 'a', 'r', 'd', 'e', 'r', 's', '\n',
        'w', 'a', 'r', 'd', 'i', 'n', 'g', '\n',
        'w', 'a', 'r', 'd', 'r', 'o', 'b', 'e', '\n',
        'w', 'a', 'r', 'd', 'r', 'o', 'b', 'e', 's', '\n',
        'w', 'a', 'r', 'd', 's', '\n',
        'w', 'a', 'r', 'd', 's', 'h', 'i', 'p', '\n',
        'w', 'a', 'r', 'e', '\n',
        'w', 'a', 'r', 'e', 'h', 'o', 'u', 's', 'e', '\n',
        'w', 'a', 'r', 'e', 'h', 'o', 'u', 's', 'e', 'd', '\n',
        'w', 'a', 'r', 'e', 'h', 'o', 'u', 's', 'e', 'm', 'a', 'n', '\n',
        'w', 'a', 'r', 'e', 'h', 'o', 'u', 's', 'e', 'm', 'e', 'n', '\n',
        'w', 'a', 'r', 'e', 'h', 'o', 'u', 's', 'e', 's', '\n',
        'w', 'a', 'r', 'e', 'h', 'o', 'u', 's', 'i', 'n', 'g', '\n',
        'w', 'a', 'r', 'e', 's', '\n',
        'w', 'a', 'r', 'f', 'a', 'r', 'e', '\n',
        'w', 'a', 'r', 'h', 'e', 'a', 'd', '\n',
        'w', 'a', 'r', 'h', 'e', 'a', 'd', 's', '\n',
        'w', 'a', 'r', 'h', 'o', 'r', 's', 'e', '\n',
        'w', 'a', 'r', 'h', 'o', 'r', 's', 'e', 's', '\n',
        'w', 'a', 'r', 'i', 'e', 's', 't', '\n',
        'w', 'a', 'r', 'i', 'l', 'y', '\n',
        'w', 'a', 'r', 'i', 'n', 'e', 's', 's', '\n',
        'w', 'a', 'r', 'i', 'n', 'g', '\n',
        'w', 'a', 'r', 'l', 'i', 'k', 'e', '\n',
        'w', 'a', 'r', 'l', 'o', 'c', 'k', '\n',
        'w', 'a', 'r', 'l', 'o', 'c', 'k', 's', '\n',
        'w', 'a', 'r', 'l', 'o', 'r', 'd', '\n',
        'w', 'a', 'r', 'l', 'o', 'r', 'd', 's', '\n',
        'w', 'a', 'r', 'm', '\n',
        'w', 'a', 'r', 'm', 'b', 'l', 'o', 'o', 'd', 'e', 'd', '\n',
        'w', 'a', 'r', 'm', 'e', 'd', '\n',
        'w', 'a', 'r', 'm', 'e', 'r', '\n',
        'w', 'a', 'r', 'm', 'e', 'r', 's', '\n',
        'w', 'a', 'r', 'm', 'e', 's', 't', '\n',
        'w', 'a', 'r', 'm', 'h', 'e', 'a', 'r', 't', 'e', 'd', '\n',
        'w', 'a', 'r', 'm', 'h', 'e', 'a', 'r', 't', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'w', 'a', 'r', 'm', 'i', 'n', 'g', '\n',
        'w', 'a', 'r', 'm', 'i', 's', 'h', '\n',
        'w', 'a', 'r', 'm', 'l', 'y', '\n',
        'w', 'a', 'r', 'm', 'n', 'e', 's', 's', '\n',
        'w', 'a', 'r', 'm', 'o', 'n', 'g', 'e', 'r', '\n',
        'w', 'a', 'r', 'm', 's', '\n',
        'w', 'a', 'r', 'm', 't', 'h', '\n',
        'w', 'a', 'r', 'm', 'u', 'p', '\n',
        'w', 'a', 'r', 'n', '\n',
        'w', 'a', 'r', 'n', 'e', 'd', '\n',
        'w', 'a', 'r', 'n', 'e', 'r', 's', '\n',
        'w', 'a', 'r', 'n', 'i', 'n', 'g', '\n',
        'w', 'a', 'r', 'n', 'i', 'n', 'g', 'l', 'y', '\n',
        'w', 'a', 'r', 'n', 'i', 'n', 'g', 's', '\n',
        'w', 'a', 'r', 'n', 's', '\n',
        'w', 'a', 'r', 'p', '\n',
        'w', 'a', 'r', 'p', 'a', 'i', 'n', 't', '\n',
        'w', 'a', 'r', 'p', 'a', 't', 'h', '\n',
        'w', 'a', 'r', 'p', 'e', 'd', '\n',
        'w', 'a', 'r', 'p', 'i', 'n', 'g', '\n',
        'w', 'a', 'r', 'p', 'l', 'a', 'n', 'e', 's', '\n',
        'w', 'a', 'r', 'p', 's', '\n',
        'w', 'a', 'r', 'r', 'a', 'n', 't', '\n',
        'w', 'a', 'r', 'r', 'a', 'n', 't', 'e', 'd', '\n',
        'w', 'a', 'r', 'r', 'a', 'n', 't', 'i', 'e', 's', '\n',
        'w', 'a', 'r', 'r', 'a', 'n', 't', 'i', 'n', 'g', '\n',
        'w', 'a', 'r', 'r', 'a', 'n', 't', 's', '\n',
        'w', 'a', 'r', 'r', 'a', 'n', 't', 'y', '\n',
        'w', 'a', 'r', 'r', 'e', 'd', '\n',
        'w', 'a', 'r', 'r', 'e', 'n', '\n',
        'w', 'a', 'r', 'r', 'e', 'n', 's', '\n',
        'w', 'a', 'r', 'r', 'i', 'n', 'g', '\n',
        'w', 'a', 'r', 'r', 'i', 'o', 'r', '\n',
        'w', 'a', 'r', 'r', 'i', 'o', 'r', 's', '\n',
        'w', 'a', 'r', 's', '\n',
        'w', 'a', 'r', 's', 'a', 'w', '\n',
        'w', 'a', 'r', 's', 'h', 'i', 'p', '\n',
        'w', 'a', 'r', 's', 'h', 'i', 'p', 's', '\n',
        'w', 'a', 'r', 't', '\n',
        'w', 'a', 'r', 't', 'h', 'o', 'g', '\n',
        'w', 'a', 'r', 't', 'h', 'o', 'g', 's', '\n',
        'w', 'a', 'r', 't', 'i', 'm', 'e', '\n',
        'w', 'a', 'r', 't', 's', '\n',
        'w', 'a', 'r', 't', 'y', '\n',
        'w', 'a', 'r', 'y', '\n',
        'w', 'a', 's', '\n',
        'w', 'a', 's', 'h', '\n',
        'w', 'a', 's', 'h', 'a', 'b', 'l', 'e', '\n',
        'w', 'a', 's', 'h', 'b', 'a', 's', 'i', 'n', '\n',
        'w', 'a', 's', 'h', 'b', 'a', 's', 'i', 'n', 's', '\n',
        'w', 'a', 's', 'h', 'b', 'o', 'a', 'r', 'd', '\n',
        'w', 'a', 's', 'h', 'd', 'a', 'y', '\n',
        'w', 'a', 's', 'h', 'e', 'd', '\n',
        'w', 'a', 's', 'h', 'e', 'r', '\n',
        'w', 'a', 's', 'h', 'e', 'r', 's', '\n',
        'w', 'a', 's', 'h', 'e', 'r', 'w', 'o', 'm', 'a', 'n', '\n',
        'w', 'a', 's', 'h', 'e', 'r', 'w', 'o', 'm', 'e', 'n', '\n',
        'w', 'a', 's', 'h', 'e', 's', '\n',
        'w', 'a', 's', 'h', 'i', 'n', 'g', '\n',
        'w', 'a', 's', 'h', 'i', 'n', 'g', 's', '\n',
        'w', 'a', 's', 'h', 'i', 'n', 'g', 't', 'o', 'n', '\n',
        'w', 'a', 's', 'h', 'o', 'u', 't', '\n',
        'w', 'a', 's', 'h', 's', 't', 'a', 'n', 'd', '\n',
        'w', 'a', 's', 'h', 'y', '\n',
        'w', 'a', 's', 'p', '\n',
        'w', 'a', 's', 'p', 'i', 's', 'h', '\n',
        'w', 'a', 's', 'p', 'i', 's', 'h', 'l', 'y', '\n',
        'w', 'a', 's', 'p', 's', '\n',
        'w', 'a', 's', 'p', 'w', 'a', 'i', 's', 't', 'e', 'd', '\n',
        'w', 'a', 's', 't', '\n',
        'w', 'a', 's', 't', 'a', 'g', 'e', '\n',
        'w', 'a', 's', 't', 'a', 'g', 'e', 's', '\n',
        'w', 'a', 's', 't', 'e', '\n',
        'w', 'a', 's', 't', 'e', 'd', '\n',
        'w', 'a', 's', 't', 'e', 'f', 'u', 'l', '\n',
        'w', 'a', 's', 't', 'e', 'f', 'u', 'l', 'l', 'y', '\n',
        'w', 'a', 's', 't', 'e', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'w', 'a', 's', 't', 'e', 'l', 'a', 'n', 'd', '\n',
        'w', 'a', 's', 't', 'e', 'l', 'a', 'n', 'd', 's', '\n',
        'w', 'a', 's', 't', 'e', 'p', 'a', 'p', 'e', 'r', '\n',
        'w', 'a', 's', 't', 'e', 'r', '\n',
        'w', 'a', 's', 't', 'e', 'r', 's', '\n',
        'w', 'a', 's', 't', 'e', 's', '\n',
        'w', 'a', 's', 't', 'i', 'n', 'g', '\n',
        'w', 'a', 's', 't', 'i', 'n', 'g', 's', '\n',
        'w', 'a', 's', 't', 'r', 'e', 'l', '\n',
        'w', 'a', 't', 'c', 'h', '\n',
        'w', 'a', 't', 'c', 'h', 'a', 'b', 'l', 'e', '\n',
        'w', 'a', 't', 'c', 'h', 'd', 'o', 'g', '\n',
        'w', 'a', 't', 'c', 'h', 'd', 'o', 'g', 's', '\n',
        'w', 'a', 't', 'c', 'h', 'e', 'd', '\n',
        'w', 'a', 't', 'c', 'h', 'e', 'r', '\n',
        'w', 'a', 't', 'c', 'h', 'e', 'r', 's', '\n',
        'w', 'a', 't', 'c', 'h', 'e', 's', '\n',
        'w', 'a', 't', 'c', 'h', 'f', 'u', 'l', '\n',
        'w', 'a', 't', 'c', 'h', 'f', 'u', 'l', 'l', 'y', '\n',
        'w', 'a', 't', 'c', 'h', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'w', 'a', 't', 'c', 'h', 'i', 'n', 'g', '\n',
        'w', 'a', 't', 'c', 'h', 'm', 'a', 'k', 'e', 'r', '\n',
        'w', 'a', 't', 'c', 'h', 'm', 'a', 'k', 'e', 'r', 's', '\n',
        'w', 'a', 't', 'c', 'h', 'm', 'a', 'n', '\n',
        'w', 'a', 't', 'c', 'h', 'm', 'e', 'n', '\n',
        'w', 'a', 't', 'c', 'h', 't', 'o', 'w', 'e', 'r', '\n',
        'w', 'a', 't', 'c', 'h', 't', 'o', 'w', 'e', 'r', 's', '\n',
        'w', 'a', 't', 'c', 'h', 'w', 'o', 'r', 'd', '\n',
        'w', 'a', 't', 'c', 'h', 'w', 'o', 'r', 'd', 's', '\n',
        'w', 'a', 't', 'e', 'r', '\n',
        'w', 'a', 't', 'e', 'r', 'b', 'e', 'd', '\n',
        'w', 'a', 't', 'e', 'r', 'b', 'e', 'd', 's', '\n',
        'w', 'a', 't', 'e', 'r', 'c', 'o', 'l', 'o', 'u', 'r', '\n',
        'w', 'a', 't', 'e', 'r', 'c', 'o', 'l', 'o', 'u', 'r', 'i', 's', 't', 's', '\n',
        'w', 'a', 't', 'e', 'r', 'c', 'o', 'l', 'o', 'u', 'r', 's', '\n',
        'w', 'a', 't', 'e', 'r', 'c', 'o', 'o', 'l', 'e', 'd', '\n',
        'w', 'a', 't', 'e', 'r', 'c', 'o', 'u', 'r', 's', 'e', '\n',
        'w', 'a', 't', 'e', 'r', 'c', 'o', 'u', 'r', 's', 'e', 's', '\n',
        'w', 'a', 't', 'e', 'r', 'c', 'r', 'e', 's', 's', '\n',
        'w', 'a', 't', 'e', 'r', 'e', 'd', '\n',
        'w', 'a', 't', 'e', 'r', 'f', 'a', 'l', 'l', '\n',
        'w', 'a', 't', 'e', 'r', 'f', 'a', 'l', 'l', 's', '\n',
        'w', 'a', 't', 'e', 'r', 'f', 'o', 'w', 'l', '\n',
        'w', 'a', 't', 'e', 'r', 'f', 'r', 'o', 'n', 't', '\n',
        'w', 'a', 't', 'e', 'r', 'g', 'l', 'a', 's', 's', '\n',
        'w', 'a', 't', 'e', 'r', 'h', 'o', 'l', 'e', '\n',
        'w', 'a', 't', 'e', 'r', 'h', 'o', 'l', 'e', 's', '\n',
        'w', 'a', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'w', 'a', 't', 'e', 'r', 'l', 'e', 's', 's', '\n',
        'w', 'a', 't', 'e', 'r', 'l', 'i', 'n', 'e', '\n',
        'w', 'a', 't', 'e', 'r', 'l', 'o', 'g', 'g', 'e', 'd', '\n',
        'w', 'a', 't', 'e', 'r', 'l', 'o', 'o', '\n',
        'w', 'a', 't', 'e', 'r', 'm', 'a', 'n', '\n',
        'w', 'a', 't', 'e', 'r', 'm', 'a', 'r', 'k', '\n',
        'w', 'a', 't', 'e', 'r', 'm', 'a', 'r', 'k', 's', '\n',
        'w', 'a', 't', 'e', 'r', 'm', 'e', 'l', 'o', 'n', '\n',
        'w', 'a', 't', 'e', 'r', 'm', 'e', 'l', 'o', 'n', 's', '\n',
        'w', 'a', 't', 'e', 'r', 'm', 'e', 'n', '\n',
        'w', 'a', 't', 'e', 'r', 'm', 'i', 'l', 'l', '\n',
        'w', 'a', 't', 'e', 'r', 'm', 'i', 'l', 'l', 's', '\n',
        'w', 'a', 't', 'e', 'r', 'p', 'r', 'o', 'o', 'f', '\n',
        'w', 'a', 't', 'e', 'r', 'p', 'r', 'o', 'o', 'f', 'e', 'd', '\n',
        'w', 'a', 't', 'e', 'r', 'p', 'r', 'o', 'o', 'f', 'i', 'n', 'g', '\n',
        'w', 'a', 't', 'e', 'r', 'p', 'r', 'o', 'o', 'f', 's', '\n',
        'w', 'a', 't', 'e', 'r', 'r', 'e', 's', 'i', 's', 't', 'a', 'n', 't', '\n',
        'w', 'a', 't', 'e', 'r', 's', '\n',
        'w', 'a', 't', 'e', 'r', 's', 'h', 'e', 'd', '\n',
        'w', 'a', 't', 'e', 'r', 's', 'h', 'e', 'd', 's', '\n',
        'w', 'a', 't', 'e', 'r', 's', 'i', 'd', 'e', '\n',
        'w', 'a', 't', 'e', 'r', 's', 'k', 'i', 'i', 'n', 'g', '\n',
        'w', 'a', 't', 'e', 'r', 's', 'o', 'l', 'u', 'b', 'l', 'e', '\n',
        'w', 'a', 't', 'e', 'r', 's', 'p', 'o', 'u', 't', 's', '\n',
        'w', 'a', 't', 'e', 'r', 't', 'a', 'b', 'l', 'e', '\n',
        'w', 'a', 't', 'e', 'r', 't', 'i', 'g', 'h', 't', '\n',
        'w', 'a', 't', 'e', 'r', 'w', 'a', 'y', '\n',
        'w', 'a', 't', 'e', 'r', 'w', 'a', 'y', 's', '\n',
        'w', 'a', 't', 'e', 'r', 'w', 'h', 'e', 'e', 'l', '\n',
        'w', 'a', 't', 'e', 'r', 'w', 'h', 'e', 'e', 'l', 's', '\n',
        'w', 'a', 't', 'e', 'r', 'w', 'o', 'r', 'k', 's', '\n',
        'w', 'a', 't', 'e', 'r', 'y', '\n',
        'w', 'a', 't', 't', '\n',
        'w', 'a', 't', 't', 'a', 'g', 'e', '\n',
        'w', 'a', 't', 't', 'l', 'e', '\n',
        'w', 'a', 't', 't', 's', '\n',
        'w', 'a', 'v', 'e', '\n',
        'w', 'a', 'v', 'e', 'b', 'a', 'n', 'd', '\n',
        'w', 'a', 'v', 'e', 'b', 'a', 'n', 'd', 's', '\n',
        'w', 'a', 'v', 'e', 'd', '\n',
        'w', 'a', 'v', 'e', 'f', 'o', 'r', 'm', '\n',
        'w', 'a', 'v', 'e', 'f', 'o', 'r', 'm', 's', '\n',
        'w', 'a', 'v', 'e', 'f', 'r', 'o', 'n', 't', '\n',
        'w', 'a', 'v', 'e', 'g', 'u', 'i', 'd', 'e', '\n',
        'w', 'a', 'v', 'e', 'g', 'u', 'i', 'd', 'e', 's', '\n',
        'w', 'a', 'v', 'e', 'l', 'e', 'n', 'g', 't', 'h', '\n',
        'w', 'a', 'v', 'e', 'l', 'e', 'n', 'g', 't', 'h', 's', '\n',
        'w', 'a', 'v', 'e', 'l', 'e', 't', '\n',
        'w', 'a', 'v', 'e', 'l', 'e', 't', 's', '\n',
        'w', 'a', 'v', 'e', 'l', 'i', 'k', 'e', '\n',
        'w', 'a', 'v', 'e', 'r', '\n',
        'w', 'a', 'v', 'e', 'r', 'e', 'd', '\n',
        'w', 'a', 'v', 'e', 'r', 'e', 'r', 's', '\n',
        'w', 'a', 'v', 'e', 'r', 'i', 'n', 'g', '\n',
        'w', 'a', 'v', 'e', 'r', 's', '\n',
        'w', 'a', 'v', 'e', 's', '\n',
        'w', 'a', 'v', 'i', 'e', 'r', '\n',
        'w', 'a', 'v', 'i', 'e', 's', 't', '\n',
        'w', 'a', 'v', 'i', 'l', 'y', '\n',
        'w', 'a', 'v', 'i', 'n', 'g', '\n',
        'w', 'a', 'v', 'i', 'n', 'g', 's', '\n',
        'w', 'a', 'v', 'y', '\n',
        'w', 'a', 'x', '\n',
        'w', 'a', 'x', 'e', 'd', '\n',
        'w', 'a', 'x', 'e', 'n', '\n',
        'w', 'a', 'x', 'e', 's', '\n',
        'w', 'a', 'x', 'i', 'n', 'g', '\n',
        'w', 'a', 'x', 'p', 'a', 'p', 'e', 'r', '\n',
        'w', 'a', 'x', 'w', 'o', 'r', 'k', '\n',
        'w', 'a', 'x', 'w', 'o', 'r', 'k', 's', '\n',
        'w', 'a', 'x', 'y', '\n',
        'w', 'a', 'y', '\n',
        'w', 'a', 'y', 'o', 'u', 't', '\n',
        'w', 'a', 'y', 's', '\n',
        'w', 'a', 'y', 's', 'i', 'd', 'e', '\n',
        'w', 'a', 'y', 'w', 'a', 'r', 'd', '\n',
        'w', 'a', 'y', 'w', 'a', 'r', 'd', 'l', 'y', '\n',
        'w', 'a', 'y', 'w', 'a', 'r', 'd', 'n', 'e', 's', 's', '\n',
        'w', 'e', '\n',
        'w', 'e', 'a', 'k', '\n',
        'w', 'e', 'a', 'k', 'e', 'n', '\n',
        'w', 'e', 'a', 'k', 'e', 'n', 'e', 'd', '\n',
        'w', 'e', 'a', 'k', 'e', 'n', 'i', 'n', 'g', '\n',
        'w', 'e', 'a', 'k', 'e', 'n', 's', '\n',
        'w', 'e', 'a', 'k', 'e', 'r', '\n',
        'w', 'e', 'a', 'k', 'e', 's', 't', '\n',
        'w', 'e', 'a', 'k', 'i', 's', 'h', '\n',
        'w', 'e', 'a', 'k', 'k', 'n', 'e', 'e', 'd', '\n',
        'w', 'e', 'a', 'k', 'l', 'i', 'n', 'g', '\n',
        'w', 'e', 'a', 'k', 'l', 'i', 'n', 'g', 's', '\n',
        'w', 'e', 'a', 'k', 'l', 'y', '\n',
        'w', 'e', 'a', 'k', 'm', 'i', 'n', 'd', 'e', 'd', '\n',
        'w', 'e', 'a', 'k', 'n', 'e', 's', 's', '\n',
        'w', 'e', 'a', 'k', 'n', 'e', 's', 's', 'e', 's', '\n',
        'w', 'e', 'a', 'l', '\n',
        'w', 'e', 'a', 'l', 't', 'h', '\n',
        'w', 'e', 'a', 'l', 't', 'h', 'i', 'e', 'r', '\n',
        'w', 'e', 'a', 'l', 't', 'h', 'i', 'e', 's', 't', '\n',
        'w', 'e', 'a', 'l', 't', 'h', 'y', '\n',
        'w', 'e', 'a', 'n', '\n',
        'w', 'e', 'a', 'n', 'e', 'd', '\n',
        'w', 'e', 'a', 'n', 'i', 'n', 'g', '\n',
        'w', 'e', 'a', 'n', 'l', 'i', 'n', 'g', '\n',
        'w', 'e', 'a', 'n', 's', '\n',
        'w', 'e', 'a', 'p', 'o', 'n', '\n',
        'w', 'e', 'a', 'p', 'o', 'n', 'r', 'y', '\n',
        'w', 'e', 'a', 'p', 'o', 'n', 's', '\n',
        'w', 'e', 'a', 'r', '\n',
        'w', 'e', 'a', 'r', 'a', 'b', 'l', 'e', '\n',
        'w', 'e', 'a', 'r', 'e', 'r', '\n',
        'w', 'e', 'a', 'r', 'e', 'r', 's', '\n',
        'w', 'e', 'a', 'r', 'i', 'e', 'd', '\n',
        'w', 'e', 'a', 'r', 'i', 'e', 'r', '\n',
        'w', 'e', 'a', 'r', 'i', 'e', 's', '\n',
        'w', 'e', 'a', 'r', 'i', 'e', 's', 't', '\n',
        'w', 'e', 'a', 'r', 'i', 'l', 'y', '\n',
        'w', 'e', 'a', 'r', 'i', 'n', 'e', 's', 's', '\n',
        'w', 'e', 'a', 'r', 'i', 'n', 'g', '\n',
        'w', 'e', 'a', 'r', 'i', 's', 'o', 'm', 'e', '\n',
        'w', 'e', 'a', 'r', 's', '\n',
        'w', 'e', 'a', 'r', 'y', '\n',
        'w', 'e', 'a', 'r', 'y', 'i', 'n', 'g', '\n',
        'w', 'e', 'a', 'r', 'y', 'i', 'n', 'g', 'l', 'y', '\n',
        'w', 'e', 'a', 's', 'e', 'l', '\n',
        'w', 'e', 'a', 's', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'w', 'e', 'a', 's', 'e', 'l', 'l', 'y', '\n',
        'w', 'e', 'a', 's', 'e', 'l', 's', '\n',
        'w', 'e', 'a', 't', 'h', 'e', 'r', '\n',
        'w', 'e', 'a', 't', 'h', 'e', 'r', 'b', 'e', 'a', 't', 'e', 'n', '\n',
        'w', 'e', 'a', 't', 'h', 'e', 'r', 'b', 'o', 'u', 'n', 'd', '\n',
        'w', 'e', 'a', 't', 'h', 'e', 'r', 'c', 'o', 'c', 'k', '\n',
        'w', 'e', 'a', 't', 'h', 'e', 'r', 'c', 'o', 'c', 'k', 's', '\n',
        'w', 'e', 'a', 't', 'h', 'e', 'r', 'e', 'd', '\n',
        'w', 'e', 'a', 't', 'h', 'e', 'r', 'i', 'n', 'g', '\n',
        'w', 'e', 'a', 't', 'h', 'e', 'r', 'm', 'a', 'n', '\n',
        'w', 'e', 'a', 't', 'h', 'e', 'r', 'm', 'e', 'n', '\n',
        'w', 'e', 'a', 't', 'h', 'e', 'r', 'p', 'r', 'o', 'o', 'f', '\n',
        'w', 'e', 'a', 't', 'h', 'e', 'r', 's', '\n',
        'w', 'e', 'a', 't', 'h', 'e', 'r', 'v', 'a', 'n', 'e', '\n',
        'w', 'e', 'a', 't', 'h', 'e', 'r', 'w', 'o', 'r', 'n', '\n',
        'w', 'e', 'a', 'v', 'e', '\n',
        'w', 'e', 'a', 'v', 'e', 'd', '\n',
        'w', 'e', 'a', 'v', 'e', 'r', '\n',
        'w', 'e', 'a', 'v', 'e', 'r', 's', '\n',
        'w', 'e', 'a', 'v', 'e', 's', '\n',
        'w', 'e', 'a', 'v', 'i', 'n', 'g', '\n',
        'w', 'e', 'a', 'v', 'i', 'n', 'g', 's', '\n',
        'w', 'e', 'b', '\n',
        'w', 'e', 'b', 'b', 'e', 'd', '\n',
        'w', 'e', 'b', 'b', 'i', 'n', 'g', '\n',
        'w', 'e', 'b', 'b', 'y', '\n',
        'w', 'e', 'b', 'f', 'o', 'o', 't', '\n',
        'w', 'e', 'b', 's', '\n',
        'w', 'e', 'b', 's', 'i', 't', 'e', '\n',
        'w', 'e', 'd', '\n',
        'w', 'e', 'd', 'd', 'e', 'd', '\n',
        'w', 'e', 'd', 'd', 'i', 'n', 'g', '\n',
        'w', 'e', 'd', 'd', 'i', 'n', 'g', 's', '\n',
        'w', 'e', 'd', 'g', 'e', '\n',
        'w', 'e', 'd', 'g', 'e', 'd', '\n',
        'w', 'e', 'd', 'g', 'e', 's', '\n',
        'w', 'e', 'd', 'g', 'i', 'n', 'g', '\n',
        'w', 'e', 'd', 'l', 'o', 'c', 'k', '\n',
        'w', 'e', 'd', 's', '\n',
        'w', 'e', 'e', '\n',
        'w', 'e', 'e', 'd', '\n',
        'w', 'e', 'e', 'd', 'e', 'd', '\n',
        'w', 'e', 'e', 'd', 'i', 'e', 'r', '\n',
        'w', 'e', 'e', 'd', 'i', 'e', 's', 't', '\n',
        'w', 'e', 'e', 'd', 'i', 'n', 'g', '\n',
        'w', 'e', 'e', 'd', 'k', 'i', 'l', 'l', 'e', 'r', '\n',
        'w', 'e', 'e', 'd', 'k', 'i', 'l', 'l', 'e', 'r', 's', '\n',
        'w', 'e', 'e', 'd', 's', '\n',
        'w', 'e', 'e', 'd', 'y', '\n',
        'w', 'e', 'e', 'k', '\n',
        'w', 'e', 'e', 'k', 'd', 'a', 'y', '\n',
        'w', 'e', 'e', 'k', 'd', 'a', 'y', 's', '\n',
        'w', 'e', 'e', 'k', 'e', 'n', 'd', '\n',
        'w', 'e', 'e', 'k', 'e', 'n', 'd', 'e', 'r', 's', '\n',
        'w', 'e', 'e', 'k', 'e', 'n', 'd', 's', '\n',
        'w', 'e', 'e', 'k', 'l', 'i', 'e', 's', '\n',
        'w', 'e', 'e', 'k', 'l', 'y', '\n',
        'w', 'e', 'e', 'k', 's', '\n',
        'w', 'e', 'e', 'n', '\n',
        'w', 'e', 'e', 'n', 'y', '\n',
        'w', 'e', 'e', 'p', '\n',
        'w', 'e', 'e', 'p', 'e', 'r', '\n',
        'w', 'e', 'e', 'p', 'i', 'n', 'g', '\n',
        'w', 'e', 'e', 'p', 'i', 'n', 'g', 's', '\n',
        'w', 'e', 'e', 'p', 's', '\n',
        'w', 'e', 'e', 'p', 'y', '\n',
        'w', 'e', 'e', 'v', 'i', 'l', '\n',
        'w', 'e', 'e', 'v', 'i', 'l', 's', '\n',
        'w', 'e', 'i', 'g', 'h', '\n',
        'w', 'e', 'i', 'g', 'h', 'b', 'r', 'i', 'd', 'g', 'e', '\n',
        'w', 'e', 'i', 'g', 'h', 'e', 'd', '\n',
        'w', 'e', 'i', 'g', 'h', 'i', 'n', 'g', '\n',
        'w', 'e', 'i', 'g', 'h', 's', '\n',
        'w', 'e', 'i', 'g', 'h', 't', '\n',
        'w', 'e', 'i', 'g', 'h', 't', 'e', 'd', '\n',
        'w', 'e', 'i', 'g', 'h', 't', 'i', 'e', 'r', '\n',
        'w', 'e', 'i', 'g', 'h', 't', 'i', 'e', 's', 't', '\n',
        'w', 'e', 'i', 'g', 'h', 't', 'i', 'l', 'y', '\n',
        'w', 'e', 'i', 'g', 'h', 't', 'i', 'n', 'g', '\n',
        'w', 'e', 'i', 'g', 'h', 't', 'i', 'n', 'g', 's', '\n',
        'w', 'e', 'i', 'g', 'h', 't', 'l', 'e', 's', 's', '\n',
        'w', 'e', 'i', 'g', 'h', 't', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'w', 'e', 'i', 'g', 'h', 't', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'w', 'e', 'i', 'g', 'h', 't', 'l', 'i', 'f', 't', 'e', 'r', '\n',
        'w', 'e', 'i', 'g', 'h', 't', 'l', 'i', 'f', 't', 'e', 'r', 's', '\n',
        'w', 'e', 'i', 'g', 'h', 't', 'l', 'i', 'f', 't', 'i', 'n', 'g', '\n',
        'w', 'e', 'i', 'g', 'h', 't', 's', '\n',
        'w', 'e', 'i', 'g', 'h', 't', 'y', '\n',
        'w', 'e', 'i', 'r', '\n',
        'w', 'e', 'i', 'r', 'd', '\n',
        'w', 'e', 'i', 'r', 'd', 'e', 'r', '\n',
        'w', 'e', 'i', 'r', 'd', 'e', 's', 't', '\n',
        'w', 'e', 'i', 'r', 'd', 'l', 'y', '\n',
        'w', 'e', 'i', 'r', 'd', 'n', 'e', 's', 's', '\n',
        'w', 'e', 'i', 'r', 'd', 'o', '\n',
        'w', 'e', 'i', 'r', 's', '\n',
        'w', 'e', 'l', 'c', 'o', 'm', 'e', '\n',
        'w', 'e', 'l', 'c', 'o', 'm', 'e', 'd', '\n',
        'w', 'e', 'l', 'c', 'o', 'm', 'e', 'r', '\n',
        'w', 'e', 'l', 'c', 'o', 'm', 'e', 's', '\n',
        'w', 'e', 'l', 'c', 'o', 'm', 'i', 'n', 'g', '\n',
        'w', 'e', 'l', 'd', '\n',
        'w', 'e', 'l', 'd', 'e', 'd', '\n',
        'w', 'e', 'l', 'd', 'e', 'r', '\n',
        'w', 'e', 'l', 'd', 'e', 'r', 's', '\n',
        'w', 'e', 'l', 'd', 'i', 'n', 'g', '\n',
        'w', 'e', 'l', 'd', 's', '\n',
        'w', 'e', 'l', 'f', 'a', 'r', 'e', '\n',
        'w', 'e', 'l', 'l', '\n',
        'w', 'e', 'l', 'l', 'a', 'd', 'j', 'u', 's', 't', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'b', 'a', 'l', 'a', 'n', 'c', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'b', 'e', 'h', 'a', 'v', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'b', 'e', 'i', 'n', 'g', '\n',
        'w', 'e', 'l', 'l', 'b', 'e', 'l', 'o', 'v', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'b', 'o', 'r', 'n', '\n',
        'w', 'e', 'l', 'l', 'b', 'r', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'b', 'u', 'i', 'l', 't', '\n',
        'w', 'e', 'l', 'l', 'c', 'h', 'o', 's', 'e', 'n', '\n',
        'w', 'e', 'l', 'l', 'c', 'o', 'n', 'n', 'e', 'c', 't', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'd', 'e', 'f', 'i', 'n', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'd', 'e', 's', 'e', 'r', 'v', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'd', 'e', 's', 'i', 'g', 'n', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'd', 'e', 'v', 'e', 'l', 'o', 'p', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'd', 'i', 's', 'p', 'o', 's', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'd', 'r', 'e', 's', 's', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'e', 'a', 'r', 'n', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'e', 'd', 'u', 'c', 'a', 't', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'e', 'n', 'd', 'o', 'w', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'e', 'q', 'u', 'i', 'p', 'p', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'e', 's', 't', 'a', 'b', 'l', 'i', 's', 'h', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'f', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'f', 'o', 'r', 'm', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'f', 'o', 'u', 'n', 'd', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'g', 'r', 'o', 'u', 'n', 'd', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'h', 'e', 'a', 'd', '\n',
        'w', 'e', 'l', 'l', 'i', 'n', 'f', 'o', 'r', 'm', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'w', 'e', 'l', 'l', 'i', 'n', 'g', 't', 'o', 'n', '\n',
        'w', 'e', 'l', 'l', 'i', 'n', 'g', 't', 'o', 'n', 's', '\n',
        'w', 'e', 'l', 'l', 'i', 'n', 't', 'e', 'n', 't', 'i', 'o', 'n', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'k', 'e', 'p', 't', '\n',
        'w', 'e', 'l', 'l', 'k', 'n', 'o', 'w', 'n', '\n',
        'w', 'e', 'l', 'l', 'l', 'i', 'k', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'l', 'o', 'v', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'm', 'a', 'd', 'e', '\n',
        'w', 'e', 'l', 'l', 'm', 'a', 'n', 'n', 'e', 'r', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'm', 'a', 'r', 'k', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'm', 'a', 't', 'c', 'h', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'm', 'e', 'a', 'n', 'i', 'n', 'g', '\n',
        'w', 'e', 'l', 'l', 'm', 'e', 'a', 'n', 't', '\n',
        'w', 'e', 'l', 'l', 'o', 'f', 'f', '\n',
        'w', 'e', 'l', 'l', 'o', 'r', 'd', 'e', 'r', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'o', 'r', 'g', 'a', 'n', 'i', 's', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'p', 'a', 'i', 'd', '\n',
        'w', 'e', 'l', 'l', 'p', 'l', 'a', 'c', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'p', 'r', 'e', 'p', 'a', 'r', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'p', 'r', 'e', 's', 'e', 'r', 'v', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'r', 'e', 'a', 'd', '\n',
        'w', 'e', 'l', 'l', 'r', 'e', 'c', 'e', 'i', 'v', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'r', 'o', 'u', 'n', 'd', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 's', '\n',
        'w', 'e', 'l', 'l', 's', 'p', 'o', 'k', 'e', 'n', '\n',
        'w', 'e', 'l', 'l', 's', 't', 'r', 'u', 'c', 't', 'u', 'r', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 's', 'u', 'p', 'p', 'o', 'r', 't', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 't', 'a', 'k', 'e', 'n', '\n',
        'w', 'e', 'l', 'l', 't', 'h', 'o', 'u', 'g', 'h', 't', 'o', 'u', 't', '\n',
        'w', 'e', 'l', 'l', 't', 'i', 'm', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 't', 'o', 'd', 'o', '\n',
        'w', 'e', 'l', 'l', 't', 'r', 'i', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'u', 's', 'e', 'd', '\n',
        'w', 'e', 'l', 'l', 'w', 'i', 's', 'h', 'e', 'r', '\n',
        'w', 'e', 'l', 'l', 'w', 'i', 's', 'h', 'e', 'r', 's', '\n',
        'w', 'e', 'l', 'l', 'w', 'o', 'r', 'n', '\n',
        'w', 'e', 'l', 'l', 'y', '\n',
        'w', 'e', 'l', 's', 'h', '\n',
        'w', 'e', 'l', 's', 'h', 'm', 'a', 'n', '\n',
        'w', 'e', 'l', 't', '\n',
        'w', 'e', 'l', 't', 'e', 'r', '\n',
        'w', 'e', 'l', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'w', 'e', 'l', 't', 'e', 'r', 's', '\n',
        'w', 'e', 'l', 't', 'e', 'r', 'w', 'e', 'i', 'g', 'h', 't', '\n',
        'w', 'e', 'l', 't', 's', '\n',
        'w', 'e', 'n', 'c', 'h', '\n',
        'w', 'e', 'n', 'c', 'h', 'e', 's', '\n',
        'w', 'e', 'n', 'd', '\n',
        'w', 'e', 'n', 'd', 'e', 'd', '\n',
        'w', 'e', 'n', 'd', 'i', 'n', 'g', '\n',
        'w', 'e', 'n', 'd', 's', '\n',
        'w', 'e', 'n', 't', '\n',
        'w', 'e', 'p', 't', '\n',
        'w', 'e', 'r', 'e', '\n',
        'w', 'e', 'r', 'e', 'w', 'o', 'l', 'f', '\n',
        'w', 'e', 'r', 'e', 'w', 'o', 'l', 'v', 'e', 's', '\n',
        'w', 'e', 's', 't', '\n',
        'w', 'e', 's', 't', 'b', 'o', 'u', 'n', 'd', '\n',
        'w', 'e', 's', 't', 'e', 'r', 'l', 'y', '\n',
        'w', 'e', 's', 't', 'e', 'r', 'n', '\n',
        'w', 'e', 's', 't', 'e', 'r', 'n', 'e', 'r', '\n',
        'w', 'e', 's', 't', 'e', 'r', 'n', 'e', 'r', 's', '\n',
        'w', 'e', 's', 't', 'e', 'r', 'n', 'i', 's', 'a', 't', 'i', 'o', 'n', '\n',
        'w', 'e', 's', 't', 'e', 'r', 'n', 'i', 's', 'e', 'd', '\n',
        'w', 'e', 's', 't', 'e', 'r', 'n', 'm', 'o', 's', 't', '\n',
        'w', 'e', 's', 't', 'e', 'r', 'n', 's', '\n',
        'w', 'e', 's', 't', 'w', 'a', 'r', 'd', '\n',
        'w', 'e', 's', 't', 'w', 'a', 'r', 'd', 's', '\n',
        'w', 'e', 't', '\n',
        'w', 'e', 't', 'h', 'e', 'r', '\n',
        'w', 'e', 't', 'l', 'a', 'n', 'd', '\n',
        'w', 'e', 't', 'l', 'a', 'n', 'd', 's', '\n',
        'w', 'e', 't', 'l', 'y', '\n',
        'w', 'e', 't', 'n', 'e', 's', 's', '\n',
        'w', 'e', 't', 's', '\n',
        'w', 'e', 't', 's', 'u', 'i', 't', '\n',
        'w', 'e', 't', 's', 'u', 'i', 't', 's', '\n',
        'w', 'e', 't', 't', 'a', 'b', 'l', 'e', '\n',
        'w', 'e', 't', 't', 'e', 'd', '\n',
        'w', 'e', 't', 't', 'e', 'r', '\n',
        'w', 'e', 't', 't', 'e', 's', 't', '\n',
        'w', 'e', 't', 't', 'i', 'n', 'g', '\n',
        'w', 'h', 'a', 'c', 'k', '\n',
        'w', 'h', 'a', 'c', 'k', 'e', 'd', '\n',
        'w', 'h', 'a', 'c', 'k', 'e', 'r', '\n',
        'w', 'h', 'a', 'c', 'k', 'o', '\n',
        'w', 'h', 'a', 'c', 'k', 's', '\n',
        'w', 'h', 'a', 'l', 'e', '\n',
        'w', 'h', 'a', 'l', 'e', 'b', 'o', 'n', 'e', '\n',
        'w', 'h', 'a', 'l', 'e', 'r', '\n',
        'w', 'h', 'a', 'l', 'e', 'r', 's', '\n',
        'w', 'h', 'a', 'l', 'e', 's', '\n',
        'w', 'h', 'a', 'l', 'i', 'n', 'g', '\n',
        'w', 'h', 'a', 'm', '\n',
        'w', 'h', 'a', 'p', '\n',
        'w', 'h', 'a', 'r', 'f', '\n',
        'w', 'h', 'a', 'r', 'f', 's', '\n',
        'w', 'h', 'a', 'r', 'v', 'e', 's', '\n',
        'w', 'h', 'a', 't', '\n',
        'w', 'h', 'a', 't', 'e', 'v', 'e', 'r', '\n',
        'w', 'h', 'a', 't', 'n', 'o', 't', '\n',
        'w', 'h', 'a', 't', 's', 'o', 'e', 'v', 'e', 'r', '\n',
        'w', 'h', 'e', 'a', 'l', 's', '\n',
        'w', 'h', 'e', 'a', 't', '\n',
        'w', 'h', 'e', 'a', 't', 'e', 'a', 'r', 's', '\n',
        'w', 'h', 'e', 'a', 't', 'e', 'n', '\n',
        'w', 'h', 'e', 'a', 't', 'g', 'e', 'r', 'm', '\n',
        'w', 'h', 'e', 'a', 't', 's', '\n',
        'w', 'h', 'e', 'e', '\n',
        'w', 'h', 'e', 'e', 'd', 'l', 'e', '\n',
        'w', 'h', 'e', 'e', 'd', 'l', 'e', 'd', '\n',
        'w', 'h', 'e', 'e', 'd', 'l', 'i', 'n', 'g', '\n',
        'w', 'h', 'e', 'e', 'l', '\n',
        'w', 'h', 'e', 'e', 'l', 'b', 'a', 'r', 'r', 'o', 'w', '\n',
        'w', 'h', 'e', 'e', 'l', 'b', 'a', 'r', 'r', 'o', 'w', 's', '\n',
        'w', 'h', 'e', 'e', 'l', 'b', 'a', 's', 'e', '\n',
        'w', 'h', 'e', 'e', 'l', 'c', 'h', 'a', 'i', 'r', '\n',
        'w', 'h', 'e', 'e', 'l', 'c', 'h', 'a', 'i', 'r', 's', '\n',
        'w', 'h', 'e', 'e', 'l', 'e', 'd', '\n',
        'w', 'h', 'e', 'e', 'l', 'e', 'r', '\n',
        'w', 'h', 'e', 'e', 'l', 'e', 'r', 's', '\n',
        'w', 'h', 'e', 'e', 'l', 'h', 'o', 'u', 's', 'e', '\n',
        'w', 'h', 'e', 'e', 'l', 'i', 'e', '\n',
        'w', 'h', 'e', 'e', 'l', 'i', 'n', 'g', '\n',
        'w', 'h', 'e', 'e', 'l', 's', '\n',
        'w', 'h', 'e', 'e', 'l', 'w', 'r', 'i', 'g', 'h', 't', '\n',
        'w', 'h', 'e', 'e', 'l', 'w', 'r', 'i', 'g', 'h', 't', 's', '\n',
        'w', 'h', 'e', 'e', 'z', 'e', '\n',
        'w', 'h', 'e', 'e', 'z', 'e', 'd', '\n',
        'w', 'h', 'e', 'e', 'z', 'e', 's', '\n',
        'w', 'h', 'e', 'e', 'z', 'i', 'n', 'g', '\n',
        'w', 'h', 'e', 'e', 'z', 'y', '\n',
        'w', 'h', 'e', 'l', 'k', '\n',
        'w', 'h', 'e', 'l', 'k', 'e', 'd', '\n',
        'w', 'h', 'e', 'l', 'k', 's', '\n',
        'w', 'h', 'e', 'l', 'p', '\n',
        'w', 'h', 'e', 'n', '\n',
        'w', 'h', 'e', 'n', 'c', 'e', '\n',
        'w', 'h', 'e', 'n', 'e', 'v', 'e', 'r', '\n',
        'w', 'h', 'e', 'r', 'e', '\n',
        'w', 'h', 'e', 'r', 'e', 'a', 'b', 'o', 'u', 't', 's', '\n',
        'w', 'h', 'e', 'r', 'e', 'a', 's', '\n',
        'w', 'h', 'e', 'r', 'e', 'b', 'y', '\n',
        'w', 'h', 'e', 'r', 'e', 'f', 'o', 'r', 'e', '\n',
        'w', 'h', 'e', 'r', 'e', 'f', 'o', 'r', 'e', 's', '\n',
        'w', 'h', 'e', 'r', 'e', 'i', 'n', '\n',
        'w', 'h', 'e', 'r', 'e', 'o', 'f', '\n',
        'w', 'h', 'e', 'r', 'e', 'o', 'n', '\n',
        'w', 'h', 'e', 'r', 'e', 's', 'o', 'e', 'v', 'e', 'r', '\n',
        'w', 'h', 'e', 'r', 'e', 't', 'o', '\n',
        'w', 'h', 'e', 'r', 'e', 'u', 'p', 'o', 'n', '\n',
        'w', 'h', 'e', 'r', 'e', 'v', 'e', 'r', '\n',
        'w', 'h', 'e', 'r', 'e', 'w', 'i', 't', 'h', '\n',
        'w', 'h', 'e', 'r', 'e', 'w', 'i', 't', 'h', 'a', 'l', '\n',
        'w', 'h', 'e', 'r', 'r', 'y', '\n',
        'w', 'h', 'e', 't', '\n',
        'w', 'h', 'e', 't', 'h', 'e', 'r', '\n',
        'w', 'h', 'e', 't', 's', 't', 'o', 'n', 'e', '\n',
        'w', 'h', 'e', 't', 's', 't', 'o', 'n', 'e', 's', '\n',
        'w', 'h', 'e', 't', 't', 'e', 'd', '\n',
        'w', 'h', 'e', 't', 't', 'i', 'n', 'g', '\n',
        'w', 'h', 'e', 'y', '\n',
        'w', 'h', 'i', 'c', 'h', '\n',
        'w', 'h', 'i', 'c', 'h', 'e', 'v', 'e', 'r', '\n',
        'w', 'h', 'i', 'f', 'f', '\n',
        'w', 'h', 'i', 'f', 'f', 's', '\n',
        'w', 'h', 'i', 'l', 'e', '\n',
        'w', 'h', 'i', 'l', 'e', 'd', '\n',
        'w', 'h', 'i', 'l', 'e', 's', '\n',
        'w', 'h', 'i', 'l', 'i', 'n', 'g', '\n',
        'w', 'h', 'i', 'l', 's', 't', '\n',
        'w', 'h', 'i', 'm', '\n',
        'w', 'h', 'i', 'm', 'p', 'e', 'r', '\n',
        'w', 'h', 'i', 'm', 'p', 'e', 'r', 'e', 'd', '\n',
        'w', 'h', 'i', 'm', 'p', 'e', 'r', 'i', 'n', 'g', '\n',
        'w', 'h', 'i', 'm', 'p', 'e', 'r', 's', '\n',
        'w', 'h', 'i', 'm', 's', '\n',
        'w', 'h', 'i', 'm', 's', 'i', 'c', 'a', 'l', '\n',
        'w', 'h', 'i', 'm', 's', 'i', 'c', 'a', 'l', 'l', 'y', '\n',
        'w', 'h', 'i', 'm', 's', 'y', '\n',
        'w', 'h', 'i', 'n', 'e', '\n',
        'w', 'h', 'i', 'n', 'e', 'd', '\n',
        'w', 'h', 'i', 'n', 'e', 's', '\n',
        'w', 'h', 'i', 'n', 'i', 'n', 'g', '\n',
        'w', 'h', 'i', 'n', 'n', 'i', 'e', 'd', '\n',
        'w', 'h', 'i', 'n', 'n', 'y', '\n',
        'w', 'h', 'i', 'n', 'n', 'y', 'i', 'n', 'g', '\n',
        'w', 'h', 'i', 'p', '\n',
        'w', 'h', 'i', 'p', 'c', 'o', 'r', 'd', '\n',
        'w', 'h', 'i', 'p', 'l', 'a', 's', 'h', '\n',
        'w', 'h', 'i', 'p', 'p', 'e', 'd', '\n',
        'w', 'h', 'i', 'p', 'p', 'e', 'r', '\n',
        'w', 'h', 'i', 'p', 'p', 'e', 't', '\n',
        'w', 'h', 'i', 'p', 'p', 'e', 't', 's', '\n',
        'w', 'h', 'i', 'p', 'p', 'i', 'n', 'g', '\n',
        'w', 'h', 'i', 'p', 'p', 'y', '\n',
        'w', 'h', 'i', 'p', 's', '\n',
        'w', 'h', 'i', 'r', '\n',
        'w', 'h', 'i', 'r', 'l', '\n',
        'w', 'h', 'i', 'r', 'l', 'e', 'd', '\n',
        'w', 'h', 'i', 'r', 'l', 'i', 'g', 'i', 'g', '\n',
        'w', 'h', 'i', 'r', 'l', 'i', 'n', 'g', '\n',
        'w', 'h', 'i', 'r', 'l', 'p', 'o', 'o', 'l', '\n',
        'w', 'h', 'i', 'r', 'l', 'p', 'o', 'o', 'l', 's', '\n',
        'w', 'h', 'i', 'r', 'l', 's', '\n',
        'w', 'h', 'i', 'r', 'l', 'w', 'i', 'n', 'd', '\n',
        'w', 'h', 'i', 'r', 'l', 'w', 'i', 'n', 'd', 's', '\n',
        'w', 'h', 'i', 'r', 'r', '\n',
        'w', 'h', 'i', 'r', 'r', 'e', 'd', '\n',
        'w', 'h', 'i', 'r', 'r', 'i', 'n', 'g', '\n',
        'w', 'h', 'i', 's', 'k', '\n',
        'w', 'h', 'i', 's', 'k', 'e', 'd', '\n',
        'w', 'h', 'i', 's', 'k', 'e', 'r', '\n',
        'w', 'h', 'i', 's', 'k', 'e', 'r', 's', '\n',
        'w', 'h', 'i', 's', 'k', 'e', 'r', 'y', '\n',
        'w', 'h', 'i', 's', 'k', 'e', 'y', '\n',
        'w', 'h', 'i', 's', 'k', 'e', 'y', 's', '\n',
        'w', 'h', 'i', 's', 'k', 'i', 'e', 's', '\n',
        'w', 'h', 'i', 's', 'k', 'i', 'n', 'g', '\n',
        'w', 'h', 'i', 's', 'k', 's', '\n',
        'w', 'h', 'i', 's', 'k', 'y', '\n',
        'w', 'h', 'i', 's', 'p', 'e', 'r', '\n',
        'w', 'h', 'i', 's', 'p', 'e', 'r', 'e', 'd', '\n',
        'w', 'h', 'i', 's', 'p', 'e', 'r', 'e', 'r', 's', '\n',
        'w', 'h', 'i', 's', 'p', 'e', 'r', 'i', 'n', 'g', '\n',
        'w', 'h', 'i', 's', 'p', 'e', 'r', 'i', 'n', 'g', 's', '\n',
        'w', 'h', 'i', 's', 'p', 'e', 'r', 's', '\n',
        'w', 'h', 'i', 's', 't', '\n',
        'w', 'h', 'i', 's', 't', 'l', 'e', '\n',
        'w', 'h', 'i', 's', 't', 'l', 'e', 'd', '\n',
        'w', 'h', 'i', 's', 't', 'l', 'e', 'r', '\n',
        'w', 'h', 'i', 's', 't', 'l', 'e', 's', '\n',
        'w', 'h', 'i', 's', 't', 'l', 'i', 'n', 'g', '\n',
        'w', 'h', 'i', 's', 't', 's', '\n',
        'w', 'h', 'i', 't', 'e', '\n',
        'w', 'h', 'i', 't', 'e', 'b', 'a', 'i', 't', '\n',
        'w', 'h', 'i', 't', 'e', 'b', 'o', 'a', 'r', 'd', 's', '\n',
        'w', 'h', 'i', 't', 'e', 'c', 'o', 'l', 'l', 'a', 'r', '\n',
        'w', 'h', 'i', 't', 'e', 'l', 'y', '\n',
        'w', 'h', 'i', 't', 'e', 'n', '\n',
        'w', 'h', 'i', 't', 'e', 'n', 'e', 'd', '\n',
        'w', 'h', 'i', 't', 'e', 'n', 'e', 'r', '\n',
        'w', 'h', 'i', 't', 'e', 'n', 'e', 's', 's', '\n',
        'w', 'h', 'i', 't', 'e', 'n', 'i', 'n', 'g', '\n',
        'w', 'h', 'i', 't', 'e', 'n', 's', '\n',
        'w', 'h', 'i', 't', 'e', 'r', '\n',
        'w', 'h', 'i', 't', 'e', 's', '\n',
        'w', 'h', 'i', 't', 'e', 's', 't', '\n',
        'w', 'h', 'i', 't', 'e', 'w', 'a', 's', 'h', '\n',
        'w', 'h', 'i', 't', 'e', 'w', 'a', 's', 'h', 'e', 'd', '\n',
        'w', 'h', 'i', 't', 'e', 'w', 'a', 's', 'h', 'i', 'n', 'g', '\n',
        'w', 'h', 'i', 't', 'h', 'e', 'r', '\n',
        'w', 'h', 'i', 't', 'i', 'n', 'g', '\n',
        'w', 'h', 'i', 't', 'i', 's', 'h', '\n',
        'w', 'h', 'i', 't', 't', 'l', 'e', '\n',
        'w', 'h', 'i', 't', 't', 'l', 'e', 'd', '\n',
        'w', 'h', 'i', 't', 't', 'l', 'i', 'n', 'g', '\n',
        'w', 'h', 'i', 'z', 'k', 'i', 'd', 's', '\n',
        'w', 'h', 'i', 'z', 'z', '\n',
        'w', 'h', 'i', 'z', 'z', 'k', 'i', 'd', '\n',
        'w', 'h', 'o', '\n',
        'w', 'h', 'o', 'a', '\n',
        'w', 'h', 'o', 'd', 'u', 'n', 'i', 't', '\n',
        'w', 'h', 'o', 'd', 'u', 'n', 'n', 'i', 't', '\n',
        'w', 'h', 'o', 'e', 'v', 'e', 'r', '\n',
        'w', 'h', 'o', 'l', 'e', '\n',
        'w', 'h', 'o', 'l', 'e', 'f', 'o', 'o', 'd', '\n',
        'w', 'h', 'o', 'l', 'e', 'g', 'r', 'a', 'i', 'n', '\n',
        'w', 'h', 'o', 'l', 'e', 'h', 'e', 'a', 'r', 't', 'e', 'd', '\n',
        'w', 'h', 'o', 'l', 'e', 'h', 'e', 'a', 'r', 't', 'e', 'd', 'l', 'y', '\n',
        'w', 'h', 'o', 'l', 'e', 'm', 'e', 'a', 'l', '\n',
        'w', 'h', 'o', 'l', 'e', 'n', 'e', 's', 's', '\n',
        'w', 'h', 'o', 'l', 'e', 's', '\n',
        'w', 'h', 'o', 'l', 'e', 's', 'a', 'l', 'e', '\n',
        'w', 'h', 'o', 'l', 'e', 's', 'a', 'l', 'e', 'r', '\n',
        'w', 'h', 'o', 'l', 'e', 's', 'a', 'l', 'e', 'r', 's', '\n',
        'w', 'h', 'o', 'l', 'e', 's', 'a', 'l', 'i', 'n', 'g', '\n',
        'w', 'h', 'o', 'l', 'e', 's', 'o', 'm', 'e', '\n',
        'w', 'h', 'o', 'l', 'e', 's', 'o', 'm', 'e', 'l', 'y', '\n',
        'w', 'h', 'o', 'l', 'e', 's', 'o', 'm', 'e', 'n', 'e', 's', 's', '\n',
        'w', 'h', 'o', 'l', 'e', 'w', 'h', 'e', 'a', 't', '\n',
        'w', 'h', 'o', 'l', 'l', 'y', '\n',
        'w', 'h', 'o', 'm', '\n',
        'w', 'h', 'o', 'm', 'e', 'v', 'e', 'r', '\n',
        'w', 'h', 'o', 'm', 's', 'o', 'e', 'v', 'e', 'r', '\n',
        'w', 'h', 'o', 'o', 'p', '\n',
        'w', 'h', 'o', 'o', 'p', 'e', 'd', '\n',
        'w', 'h', 'o', 'o', 'p', 'i', 'n', 'g', '\n',
        'w', 'h', 'o', 'o', 'p', 's', '\n',
        'w', 'h', 'o', 'o', 's', 'h', '\n',
        'w', 'h', 'o', 'p', '\n',
        'w', 'h', 'o', 'r', 'e', '\n',
        'w', 'h', 'o', 'r', 'e', 'h', 'o', 'u', 's', 'e', '\n',
        'w', 'h', 'o', 'r', 'e', 's', '\n',
        'w', 'h', 'o', 'r', 'i', 'n', 'g', '\n',
        'w', 'h', 'o', 'r', 'l', 'e', 'd', '\n',
        'w', 'h', 'o', 'r', 'l', 's', '\n',
        'w', 'h', 'o', 's', 'e', '\n',
        'w', 'h', 'o', 's', 'o', 'e', 'v', 'e', 'r', '\n',
        'w', 'h', 'y', '\n',
        'w', 'h', 'y', 's', '\n',
        'w', 'i', 'c', 'k', '\n',
        'w', 'i', 'c', 'k', 'e', 'd', '\n',
        'w', 'i', 'c', 'k', 'e', 'd', 'e', 's', 't', '\n',
        'w', 'i', 'c', 'k', 'e', 'd', 'l', 'y', '\n',
        'w', 'i', 'c', 'k', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'w', 'i', 'c', 'k', 'e', 'r', '\n',
        'w', 'i', 'c', 'k', 'e', 'r', 'w', 'o', 'r', 'k', '\n',
        'w', 'i', 'c', 'k', 'e', 't', '\n',
        'w', 'i', 'c', 'k', 'e', 't', 'k', 'e', 'e', 'p', 'e', 'r', '\n',
        'w', 'i', 'c', 'k', 'e', 't', 'k', 'e', 'e', 'p', 'e', 'r', 's', '\n',
        'w', 'i', 'c', 'k', 'e', 't', 'k', 'e', 'e', 'p', 'i', 'n', 'g', '\n',
        'w', 'i', 'c', 'k', 'e', 't', 's', '\n',
        'w', 'i', 'c', 'k', 's', '\n',
        'w', 'i', 'd', 'e', '\n',
        'w', 'i', 'd', 'e', 'e', 'y', 'e', 'd', '\n',
        'w', 'i', 'd', 'e', 'l', 'y', '\n',
        'w', 'i', 'd', 'e', 'n', '\n',
        'w', 'i', 'd', 'e', 'n', 'e', 'd', '\n',
        'w', 'i', 'd', 'e', 'n', 'e', 's', 's', '\n',
        'w', 'i', 'd', 'e', 'n', 'i', 'n', 'g', '\n',
        'w', 'i', 'd', 'e', 'n', 's', '\n',
        'w', 'i', 'd', 'e', 'o', 'p', 'e', 'n', '\n',
        'w', 'i', 'd', 'e', 'r', '\n',
        'w', 'i', 'd', 'e', 'r', 'a', 'n', 'g', 'i', 'n', 'g', '\n',
        'w', 'i', 'd', 'e', 's', '\n',
        'w', 'i', 'd', 'e', 's', 'c', 'r', 'e', 'e', 'n', '\n',
        'w', 'i', 'd', 'e', 's', 'p', 'r', 'e', 'a', 'd', '\n',
        'w', 'i', 'd', 'e', 's', 't', '\n',
        'w', 'i', 'd', 'g', 'e', 'o', 'n', '\n',
        'w', 'i', 'd', 'g', 'e', 't', '\n',
        'w', 'i', 'd', 'o', 'w', '\n',
        'w', 'i', 'd', 'o', 'w', 'e', 'd', '\n',
        'w', 'i', 'd', 'o', 'w', 'e', 'r', '\n',
        'w', 'i', 'd', 'o', 'w', 'e', 'r', 's', '\n',
        'w', 'i', 'd', 'o', 'w', 'h', 'o', 'o', 'd', '\n',
        'w', 'i', 'd', 'o', 'w', 's', '\n',
        'w', 'i', 'd', 't', 'h', '\n',
        'w', 'i', 'd', 't', 'h', 's', '\n',
        'w', 'i', 'e', 'l', 'd', '\n',
        'w', 'i', 'e', 'l', 'd', 'e', 'd', '\n',
        'w', 'i', 'e', 'l', 'd', 'e', 'r', '\n',
        'w', 'i', 'e', 'l', 'd', 'i', 'n', 'g', '\n',
        'w', 'i', 'e', 'l', 'd', 's', '\n',
        'w', 'i', 'f', 'e', '\n',
        'w', 'i', 'f', 'e', 'l', 'e', 's', 's', '\n',
        'w', 'i', 'f', 'e', 'l', 'y', '\n',
        'w', 'i', 'g', '\n',
        'w', 'i', 'g', 'e', 'o', 'n', '\n',
        'w', 'i', 'g', 'e', 'o', 'n', 's', '\n',
        'w', 'i', 'g', 'g', 'i', 'n', 'g', '\n',
        'w', 'i', 'g', 'g', 'l', 'e', '\n',
        'w', 'i', 'g', 'g', 'l', 'e', 'd', '\n',
        'w', 'i', 'g', 'g', 'l', 'e', 'r', '\n',
        'w', 'i', 'g', 'g', 'l', 'e', 's', '\n',
        'w', 'i', 'g', 'g', 'l', 'i', 'n', 'g', '\n',
        'w', 'i', 'g', 's', '\n',
        'w', 'i', 'g', 'w', 'a', 'm', '\n',
        'w', 'i', 'g', 'w', 'a', 'm', 's', '\n',
        'w', 'i', 'l', 'd', '\n',
        'w', 'i', 'l', 'd', 'c', 'a', 't', '\n',
        'w', 'i', 'l', 'd', 'c', 'a', 't', 's', '\n',
        'w', 'i', 'l', 'd', 'e', 'b', 'e', 'e', 's', 't', '\n',
        'w', 'i', 'l', 'd', 'e', 'r', '\n',
        'w', 'i', 'l', 'd', 'e', 'r', 'n', 'e', 's', 's', '\n',
        'w', 'i', 'l', 'd', 'e', 'r', 'n', 'e', 's', 's', 'e', 's', '\n',
        'w', 'i', 'l', 'd', 'e', 's', 't', '\n',
        'w', 'i', 'l', 'd', 'e', 'y', 'e', 'd', '\n',
        'w', 'i', 'l', 'd', 'f', 'i', 'r', 'e', '\n',
        'w', 'i', 'l', 'd', 'f', 'i', 'r', 'e', 's', '\n',
        'w', 'i', 'l', 'd', 'f', 'o', 'w', 'l', '\n',
        'w', 'i', 'l', 'd', 'l', 'i', 'f', 'e', '\n',
        'w', 'i', 'l', 'd', 'l', 'y', '\n',
        'w', 'i', 'l', 'd', 'n', 'e', 's', 's', '\n',
        'w', 'i', 'l', 'd', 'o', 'a', 't', 's', '\n',
        'w', 'i', 'l', 'd', 's', '\n',
        'w', 'i', 'l', 'e', '\n',
        'w', 'i', 'l', 'e', 's', '\n',
        'w', 'i', 'l', 'f', 'u', 'l', '\n',
        'w', 'i', 'l', 'f', 'u', 'l', 'l', 'y', '\n',
        'w', 'i', 'l', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'w', 'i', 'l', 'i', 'e', 'r', '\n',
        'w', 'i', 'l', 'i', 'e', 's', 't', '\n',
        'w', 'i', 'l', 'i', 'n', 'g', '\n',
        'w', 'i', 'l', 'l', '\n',
        'w', 'i', 'l', 'l', 'e', 'd', '\n',
        'w', 'i', 'l', 'l', 'i', 'n', 'g', '\n',
        'w', 'i', 'l', 'l', 'i', 'n', 'g', 'l', 'y', '\n',
        'w', 'i', 'l', 'l', 'i', 'n', 'g', 'n', 'e', 's', 's', '\n',
        'w', 'i', 'l', 'l', 'o', 'w', '\n',
        'w', 'i', 'l', 'l', 'o', 'w', 's', '\n',
        'w', 'i', 'l', 'l', 'o', 'w', 'y', '\n',
        'w', 'i', 'l', 'l', 'p', 'o', 'w', 'e', 'r', '\n',
        'w', 'i', 'l', 'l', 's', '\n',
        'w', 'i', 'l', 'l', 'y', 'n', 'i', 'l', 'l', 'y', '\n',
        'w', 'i', 'l', 't', '\n',
        'w', 'i', 'l', 't', 'e', 'd', '\n',
        'w', 'i', 'l', 't', 'i', 'n', 'g', '\n',
        'w', 'i', 'l', 't', 's', '\n',
        'w', 'i', 'l', 'y', '\n',
        'w', 'i', 'm', 'p', '\n',
        'w', 'i', 'm', 'p', 'l', 'e', '\n',
        'w', 'i', 'm', 'p', 'y', '\n',
        'w', 'i', 'n', '\n',
        'w', 'i', 'n', 'c', 'e', '\n',
        'w', 'i', 'n', 'c', 'e', 'd', '\n',
        'w', 'i', 'n', 'c', 'e', 's', '\n',
        'w', 'i', 'n', 'c', 'h', '\n',
        'w', 'i', 'n', 'c', 'h', 'e', 'd', '\n',
        'w', 'i', 'n', 'c', 'h', 'e', 's', '\n',
        'w', 'i', 'n', 'c', 'h', 'i', 'n', 'g', '\n',
        'w', 'i', 'n', 'c', 'i', 'n', 'g', '\n',
        'w', 'i', 'n', 'd', '\n',
        'w', 'i', 'n', 'd', 'b', 'a', 'g', '\n',
        'w', 'i', 'n', 'd', 'b', 'a', 'g', 's', '\n',
        'w', 'i', 'n', 'd', 'b', 'r', 'e', 'a', 'k', '\n',
        'w', 'i', 'n', 'd', 'c', 'h', 'e', 'a', 't', 'e', 'r', '\n',
        'w', 'i', 'n', 'd', 'c', 'h', 'e', 'a', 't', 'e', 'r', 's', '\n',
        'w', 'i', 'n', 'd', 'e', 'd', '\n',
        'w', 'i', 'n', 'd', 'e', 'r', '\n',
        'w', 'i', 'n', 'd', 'e', 'r', 's', '\n',
        'w', 'i', 'n', 'd', 'f', 'a', 'l', 'l', '\n',
        'w', 'i', 'n', 'd', 'f', 'a', 'l', 'l', 's', '\n',
        'w', 'i', 'n', 'd', 'i', 'e', 'r', '\n',
        'w', 'i', 'n', 'd', 'i', 'e', 's', 't', '\n',
        'w', 'i', 'n', 'd', 'i', 'l', 'y', '\n',
        'w', 'i', 'n', 'd', 'i', 'n', 'g', '\n',
        'w', 'i', 'n', 'd', 'i', 'n', 'g', 's', '\n',
        'w', 'i', 'n', 'd', 'l', 'a', 's', 's', '\n',
        'w', 'i', 'n', 'd', 'l', 'e', 's', 's', '\n',
        'w', 'i', 'n', 'd', 'm', 'i', 'l', 'l', '\n',
        'w', 'i', 'n', 'd', 'm', 'i', 'l', 'l', 's', '\n',
        'w', 'i', 'n', 'd', 'o', 'w', '\n',
        'w', 'i', 'n', 'd', 'o', 'w', 'e', 'd', '\n',
        'w', 'i', 'n', 'd', 'o', 'w', 'i', 'n', 'g', '\n',
        'w', 'i', 'n', 'd', 'o', 'w', 'l', 'e', 's', 's', '\n',
        'w', 'i', 'n', 'd', 'o', 'w', 's', '\n',
        'w', 'i', 'n', 'd', 'o', 'w', 's', 'h', 'o', 'p', '\n',
        'w', 'i', 'n', 'd', 'o', 'w', 's', 'h', 'o', 'p', 'p', 'i', 'n', 'g', '\n',
        'w', 'i', 'n', 'd', 'p', 'i', 'p', 'e', '\n',
        'w', 'i', 'n', 'd', 's', '\n',
        'w', 'i', 'n', 'd', 's', 'c', 'r', 'e', 'e', 'n', '\n',
        'w', 'i', 'n', 'd', 's', 'c', 'r', 'e', 'e', 'n', 's', '\n',
        'w', 'i', 'n', 'd', 's', 'o', 'c', 'k', '\n',
        'w', 'i', 'n', 'd', 's', 'o', 'r', '\n',
        'w', 'i', 'n', 'd', 's', 'u', 'r', 'f', '\n',
        'w', 'i', 'n', 'd', 's', 'u', 'r', 'f', 'e', 'r', '\n',
        'w', 'i', 'n', 'd', 's', 'u', 'r', 'f', 'e', 'r', 's', '\n',
        'w', 'i', 'n', 'd', 's', 'u', 'r', 'f', 'i', 'n', 'g', '\n',
        'w', 'i', 'n', 'd', 's', 'w', 'e', 'p', 't', '\n',
        'w', 'i', 'n', 'd', 'w', 'a', 'r', 'd', '\n',
        'w', 'i', 'n', 'd', 'y', '\n',
        'w', 'i', 'n', 'e', '\n',
        'w', 'i', 'n', 'e', 'd', '\n',
        'w', 'i', 'n', 'e', 'g', 'l', 'a', 's', 's', '\n',
        'w', 'i', 'n', 'e', 'g', 'l', 'a', 's', 's', 'e', 's', '\n',
        'w', 'i', 'n', 'e', 'm', 'a', 'k', 'e', 'r', 's', '\n',
        'w', 'i', 'n', 'e', 'r', 'y', '\n',
        'w', 'i', 'n', 'e', 's', '\n',
        'w', 'i', 'n', 'e', 's', 'k', 'i', 'n', '\n',
        'w', 'i', 'n', 'g', '\n',
        'w', 'i', 'n', 'g', 'e', 'd', '\n',
        'w', 'i', 'n', 'g', 'e', 'r', '\n',
        'w', 'i', 'n', 'g', 'e', 'r', 's', '\n',
        'w', 'i', 'n', 'g', 'i', 'n', 'g', '\n',
        'w', 'i', 'n', 'g', 'l', 'e', 's', 's', '\n',
        'w', 'i', 'n', 'g', 's', '\n',
        'w', 'i', 'n', 'g', 's', 'p', 'a', 'n', '\n',
        'w', 'i', 'n', 'i', 'n', 'g', '\n',
        'w', 'i', 'n', 'k', '\n',
        'w', 'i', 'n', 'k', 'e', 'd', '\n',
        'w', 'i', 'n', 'k', 'e', 'r', '\n',
        'w', 'i', 'n', 'k', 'e', 'r', 's', '\n',
        'w', 'i', 'n', 'k', 'i', 'n', 'g', '\n',
        'w', 'i', 'n', 'k', 'l', 'e', '\n',
        'w', 'i', 'n', 'k', 'l', 'e', 'd', '\n',
        'w', 'i', 'n', 'k', 'l', 'e', 's', '\n',
        'w', 'i', 'n', 'k', 's', '\n',
        'w', 'i', 'n', 'n', 'a', 'b', 'l', 'e', '\n',
        'w', 'i', 'n', 'n', 'e', 'r', '\n',
        'w', 'i', 'n', 'n', 'e', 'r', 's', '\n',
        'w', 'i', 'n', 'n', 'i', 'n', 'g', '\n',
        'w', 'i', 'n', 'n', 'i', 'n', 'g', 'l', 'y', '\n',
        'w', 'i', 'n', 'n', 'i', 'n', 'g', 's', '\n',
        'w', 'i', 'n', 'n', 'o', 'w', '\n',
        'w', 'i', 'n', 'n', 'o', 'w', 'i', 'n', 'g', '\n',
        'w', 'i', 'n', 's', '\n',
        'w', 'i', 'n', 's', 'o', 'm', 'e', '\n',
        'w', 'i', 'n', 't', 'e', 'r', '\n',
        'w', 'i', 'n', 't', 'e', 'r', 'e', 'd', '\n',
        'w', 'i', 'n', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'w', 'i', 'n', 't', 'e', 'r', 's', '\n',
        'w', 'i', 'n', 't', 'e', 'r', 't', 'i', 'm', 'e', '\n',
        'w', 'i', 'n', 't', 'e', 'r', 'y', '\n',
        'w', 'i', 'n', 't', 'r', 'i', 'e', 'r', '\n',
        'w', 'i', 'n', 't', 'r', 'i', 'e', 's', 't', '\n',
        'w', 'i', 'n', 't', 'r', 'y', '\n',
        'w', 'i', 'p', 'e', '\n',
        'w', 'i', 'p', 'e', 'd', '\n',
        'w', 'i', 'p', 'e', 'r', '\n',
        'w', 'i', 'p', 'e', 'r', 's', '\n',
        'w', 'i', 'p', 'e', 's', '\n',
        'w', 'i', 'p', 'i', 'n', 'g', '\n',
        'w', 'i', 'r', 'e', '\n',
        'w', 'i', 'r', 'e', 'd', '\n',
        'w', 'i', 'r', 'e', 'l', 'e', 's', 's', '\n',
        'w', 'i', 'r', 'e', 'r', '\n',
        'w', 'i', 'r', 'e', 's', '\n',
        'w', 'i', 'r', 'i', 'e', 'r', '\n',
        'w', 'i', 'r', 'i', 'e', 's', 't', '\n',
        'w', 'i', 'r', 'i', 'n', 'g', '\n',
        'w', 'i', 'r', 'i', 'n', 'g', 's', '\n',
        'w', 'i', 'r', 'y', '\n',
        'w', 'i', 's', 'd', 'o', 'm', '\n',
        'w', 'i', 's', 'd', 'o', 'm', 's', '\n',
        'w', 'i', 's', 'e', '\n',
        'w', 'i', 's', 'e', 'c', 'r', 'a', 'c', 'k', 's', '\n',
        'w', 'i', 's', 'e', 'g', 'u', 'y', 's', '\n',
        'w', 'i', 's', 'e', 'l', 'y', '\n',
        'w', 'i', 's', 'e', 'r', '\n',
        'w', 'i', 's', 'e', 's', 't', '\n',
        'w', 'i', 's', 'h', '\n',
        'w', 'i', 's', 'h', 'b', 'o', 'n', 'e', '\n',
        'w', 'i', 's', 'h', 'e', 'd', '\n',
        'w', 'i', 's', 'h', 'e', 's', '\n',
        'w', 'i', 's', 'h', 'f', 'u', 'l', '\n',
        'w', 'i', 's', 'h', 'f', 'u', 'l', 'l', 'y', '\n',
        'w', 'i', 's', 'h', 'i', 'n', 'g', '\n',
        'w', 'i', 's', 'h', 'y', 'w', 'a', 's', 'h', 'y', '\n',
        'w', 'i', 's', 'p', '\n',
        'w', 'i', 's', 'p', 's', '\n',
        'w', 'i', 's', 'p', 'y', '\n',
        'w', 'i', 's', 't', 'f', 'u', 'l', '\n',
        'w', 'i', 's', 't', 'f', 'u', 'l', 'l', 'y', '\n',
        'w', 'i', 's', 't', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'w', 'i', 't', '\n',
        'w', 'i', 't', 'c', 'h', '\n',
        'w', 'i', 't', 'c', 'h', 'c', 'r', 'a', 'f', 't', '\n',
        'w', 'i', 't', 'c', 'h', 'd', 'o', 'c', 't', 'o', 'r', '\n',
        'w', 'i', 't', 'c', 'h', 'd', 'o', 'c', 't', 'o', 'r', 's', '\n',
        'w', 'i', 't', 'c', 'h', 'e', 'r', 'y', '\n',
        'w', 'i', 't', 'c', 'h', 'e', 's', '\n',
        'w', 'i', 't', 'c', 'h', 'h', 'u', 'n', 't', '\n',
        'w', 'i', 't', 'c', 'h', 'h', 'u', 'n', 't', 's', '\n',
        'w', 'i', 't', 'c', 'h', 'l', 'i', 'k', 'e', '\n',
        'w', 'i', 't', 'h', '\n',
        'w', 'i', 't', 'h', 'd', 'r', 'a', 'w', '\n',
        'w', 'i', 't', 'h', 'd', 'r', 'a', 'w', 'a', 'l', '\n',
        'w', 'i', 't', 'h', 'd', 'r', 'a', 'w', 'a', 'l', 's', '\n',
        'w', 'i', 't', 'h', 'd', 'r', 'a', 'w', 'i', 'n', 'g', '\n',
        'w', 'i', 't', 'h', 'd', 'r', 'a', 'w', 'n', '\n',
        'w', 'i', 't', 'h', 'd', 'r', 'a', 'w', 's', '\n',
        'w', 'i', 't', 'h', 'd', 'r', 'e', 'w', '\n',
        'w', 'i', 't', 'h', 'e', 'r', '\n',
        'w', 'i', 't', 'h', 'e', 'r', 'e', 'd', '\n',
        'w', 'i', 't', 'h', 'e', 'r', 'i', 'n', 'g', '\n',
        'w', 'i', 't', 'h', 'e', 'r', 'i', 'n', 'g', 'l', 'y', '\n',
        'w', 'i', 't', 'h', 'e', 'r', 's', '\n',
        'w', 'i', 't', 'h', 'h', 'e', 'l', 'd', '\n',
        'w', 'i', 't', 'h', 'h', 'o', 'l', 'd', '\n',
        'w', 'i', 't', 'h', 'h', 'o', 'l', 'd', 'i', 'n', 'g', '\n',
        'w', 'i', 't', 'h', 'h', 'o', 'l', 'd', 's', '\n',
        'w', 'i', 't', 'h', 'i', 'n', '\n',
        'w', 'i', 't', 'h', 'o', 'u', 't', '\n',
        'w', 'i', 't', 'h', 's', 't', 'a', 'n', 'd', '\n',
        'w', 'i', 't', 'h', 's', 't', 'a', 'n', 'd', 'i', 'n', 'g', '\n',
        'w', 'i', 't', 'h', 's', 't', 'a', 'n', 'd', 's', '\n',
        'w', 'i', 't', 'h', 's', 't', 'o', 'o', 'd', '\n',
        'w', 'i', 't', 'l', 'e', 's', 's', '\n',
        'w', 'i', 't', 'n', 'e', 's', 's', '\n',
        'w', 'i', 't', 'n', 'e', 's', 's', 'e', 'd', '\n',
        'w', 'i', 't', 'n', 'e', 's', 's', 'e', 's', '\n',
        'w', 'i', 't', 'n', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'w', 'i', 't', 's', '\n',
        'w', 'i', 't', 't', 'e', 'r', '\n',
        'w', 'i', 't', 't', 'e', 'r', 'i', 'n', 'g', '\n',
        'w', 'i', 't', 't', 'i', 'c', 'i', 's', 'm', '\n',
        'w', 'i', 't', 't', 'i', 'c', 'i', 's', 'm', 's', '\n',
        'w', 'i', 't', 't', 'i', 'e', 'r', '\n',
        'w', 'i', 't', 't', 'i', 'e', 's', 't', '\n',
        'w', 'i', 't', 't', 'i', 'l', 'y', '\n',
        'w', 'i', 't', 't', 'i', 'n', 'e', 's', 's', '\n',
        'w', 'i', 't', 't', 'i', 'n', 'g', '\n',
        'w', 'i', 't', 't', 'i', 'n', 'g', 'l', 'y', '\n',
        'w', 'i', 't', 't', 'y', '\n',
        'w', 'i', 'v', 'e', 's', '\n',
        'w', 'i', 'z', 'a', 'r', 'd', '\n',
        'w', 'i', 'z', 'a', 'r', 'd', 'r', 'y', '\n',
        'w', 'i', 'z', 'a', 'r', 'd', 's', '\n',
        'w', 'i', 'z', 'e', 'n', 'e', 'd', '\n',
        'w', 'o', 'a', 'd', '\n',
        'w', 'o', 'b', 'b', 'l', 'e', '\n',
        'w', 'o', 'b', 'b', 'l', 'e', 'd', '\n',
        'w', 'o', 'b', 'b', 'l', 'e', 'r', '\n',
        'w', 'o', 'b', 'b', 'l', 'e', 's', '\n',
        'w', 'o', 'b', 'b', 'l', 'i', 'e', 'r', '\n',
        'w', 'o', 'b', 'b', 'l', 'i', 'e', 's', 't', '\n',
        'w', 'o', 'b', 'b', 'l', 'i', 'n', 'g', '\n',
        'w', 'o', 'b', 'b', 'l', 'y', '\n',
        'w', 'o', 'd', 'a', 'n', '\n',
        'w', 'o', 'd', 'g', 'e', '\n',
        'w', 'o', 'e', '\n',
        'w', 'o', 'e', 'b', 'e', 'g', 'o', 'n', 'e', '\n',
        'w', 'o', 'e', 'f', 'u', 'l', '\n',
        'w', 'o', 'e', 'f', 'u', 'l', 'l', 'y', '\n',
        'w', 'o', 'e', 's', '\n',
        'w', 'o', 'k', '\n',
        'w', 'o', 'k', 'e', '\n',
        'w', 'o', 'k', 'e', 'n', '\n',
        'w', 'o', 'k', 's', '\n',
        'w', 'o', 'l', 'd', '\n',
        'w', 'o', 'l', 'd', 's', '\n',
        'w', 'o', 'l', 'f', '\n',
        'w', 'o', 'l', 'f', 'c', 'u', 'b', 's', '\n',
        'w', 'o', 'l', 'f', 'e', 'd', '\n',
        'w', 'o', 'l', 'f', 'h', 'o', 'u', 'n', 'd', '\n',
        'w', 'o', 'l', 'f', 'h', 'o', 'u', 'n', 'd', 's', '\n',
        'w', 'o', 'l', 'f', 'i', 's', 'h', '\n',
        'w', 'o', 'l', 'f', 'i', 's', 'h', 'l', 'y', '\n',
        'w', 'o', 'l', 'f', 'w', 'h', 'i', 's', 't', 'l', 'e', 's', '\n',
        'w', 'o', 'l', 'v', 'e', 's', '\n',
        'w', 'o', 'm', 'a', 'n', '\n',
        'w', 'o', 'm', 'a', 'n', 'h', 'o', 'o', 'd', '\n',
        'w', 'o', 'm', 'a', 'n', 'i', 's', 'e', '\n',
        'w', 'o', 'm', 'a', 'n', 'i', 's', 'e', 'r', '\n',
        'w', 'o', 'm', 'a', 'n', 'i', 's', 'h', '\n',
        'w', 'o', 'm', 'a', 'n', 'i', 's', 'i', 'n', 'g', '\n',
        'w', 'o', 'm', 'a', 'n', 'k', 'i', 'n', 'd', '\n',
        'w', 'o', 'm', 'a', 'n', 'l', 'i', 'n', 'e', 's', 's', '\n',
        'w', 'o', 'm', 'a', 'n', 'l', 'y', '\n',
        'w', 'o', 'm', 'a', 'n', 's', '\n',
        'w', 'o', 'm', 'b', '\n',
        'w', 'o', 'm', 'b', 'a', 't', '\n',
        'w', 'o', 'm', 'b', 'a', 't', 's', '\n',
        'w', 'o', 'm', 'b', 's', '\n',
        'w', 'o', 'm', 'e', 'n', '\n',
        'w', 'o', 'm', 'e', 'n', 'f', 'o', 'l', 'k', '\n',
        'w', 'o', 'n', '\n',
        'w', 'o', 'n', 'd', 'e', 'r', '\n',
        'w', 'o', 'n', 'd', 'e', 'r', 'e', 'd', '\n',
        'w', 'o', 'n', 'd', 'e', 'r', 'f', 'u', 'l', '\n',
        'w', 'o', 'n', 'd', 'e', 'r', 'f', 'u', 'l', 'l', 'y', '\n',
        'w', 'o', 'n', 'd', 'e', 'r', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'w', 'o', 'n', 'd', 'e', 'r', 'i', 'n', 'g', '\n',
        'w', 'o', 'n', 'd', 'e', 'r', 'i', 'n', 'g', 'l', 'y', '\n',
        'w', 'o', 'n', 'd', 'e', 'r', 'l', 'a', 'n', 'd', '\n',
        'w', 'o', 'n', 'd', 'e', 'r', 'm', 'e', 'n', 't', '\n',
        'w', 'o', 'n', 'd', 'e', 'r', 's', '\n',
        'w', 'o', 'n', 'd', 'r', 'o', 'u', 's', '\n',
        'w', 'o', 'n', 'd', 'r', 'o', 'u', 's', 'l', 'y', '\n',
        'w', 'o', 'n', 't', '\n',
        'w', 'o', 'o', '\n',
        'w', 'o', 'o', 'd', '\n',
        'w', 'o', 'o', 'd', 'b', 'i', 'n', 'e', '\n',
        'w', 'o', 'o', 'd', 'c', 'o', 'c', 'k', '\n',
        'w', 'o', 'o', 'd', 'c', 'o', 'c', 'k', 's', '\n',
        'w', 'o', 'o', 'd', 'c', 'u', 't', '\n',
        'w', 'o', 'o', 'd', 'c', 'u', 't', 's', '\n',
        'w', 'o', 'o', 'd', 'c', 'u', 't', 't', 'e', 'r', '\n',
        'w', 'o', 'o', 'd', 'c', 'u', 't', 't', 'e', 'r', 's', '\n',
        'w', 'o', 'o', 'd', 'e', 'd', '\n',
        'w', 'o', 'o', 'd', 'e', 'n', '\n',
        'w', 'o', 'o', 'd', 'e', 'n', 'l', 'y', '\n',
        'w', 'o', 'o', 'd', 'e', 'n', 'n', 'e', 's', 's', '\n',
        'w', 'o', 'o', 'd', 'l', 'a', 'n', 'd', '\n',
        'w', 'o', 'o', 'd', 'l', 'a', 'n', 'd', 's', '\n',
        'w', 'o', 'o', 'd', 'l', 'i', 'c', 'e', '\n',
        'w', 'o', 'o', 'd', 'l', 'o', 'u', 's', 'e', '\n',
        'w', 'o', 'o', 'd', 'm', 'a', 'n', '\n',
        'w', 'o', 'o', 'd', 'm', 'e', 'n', '\n',
        'w', 'o', 'o', 'd', 'p', 'e', 'c', 'k', 'e', 'r', '\n',
        'w', 'o', 'o', 'd', 'p', 'e', 'c', 'k', 'e', 'r', 's', '\n',
        'w', 'o', 'o', 'd', 'p', 'i', 'l', 'e', '\n',
        'w', 'o', 'o', 'd', 's', '\n',
        'w', 'o', 'o', 'd', 's', 'h', 'e', 'd', '\n',
        'w', 'o', 'o', 'd', 's', 'm', 'a', 'n', '\n',
        'w', 'o', 'o', 'd', 's', 'm', 'o', 'k', 'e', '\n',
        'w', 'o', 'o', 'd', 'w', 'i', 'n', 'd', '\n',
        'w', 'o', 'o', 'd', 'w', 'o', 'r', 'k', '\n',
        'w', 'o', 'o', 'd', 'w', 'o', 'r', 'k', 'e', 'r', '\n',
        'w', 'o', 'o', 'd', 'w', 'o', 'r', 'k', 'e', 'r', 's', '\n',
        'w', 'o', 'o', 'd', 'w', 'o', 'r', 'k', 'i', 'n', 'g', '\n',
        'w', 'o', 'o', 'd', 'w', 'o', 'r', 'm', '\n',
        'w', 'o', 'o', 'd', 'y', '\n',
        'w', 'o', 'o', 'e', 'd', '\n',
        'w', 'o', 'o', 'e', 'r', '\n',
        'w', 'o', 'o', 'f', '\n',
        'w', 'o', 'o', 'f', 'e', 'r', '\n',
        'w', 'o', 'o', 'f', 'e', 'r', 's', '\n',
        'w', 'o', 'o', 'i', 'n', 'g', '\n',
        'w', 'o', 'o', 'l', '\n',
        'w', 'o', 'o', 'l', 'l', 'e', 'n', '\n',
        'w', 'o', 'o', 'l', 'l', 'e', 'n', 's', '\n',
        'w', 'o', 'o', 'l', 'l', 'i', 'e', 'r', '\n',
        'w', 'o', 'o', 'l', 'l', 'i', 'e', 's', '\n',
        'w', 'o', 'o', 'l', 'l', 'i', 'k', 'e', '\n',
        'w', 'o', 'o', 'l', 'l', 'i', 'n', 'e', 's', 's', '\n',
        'w', 'o', 'o', 'l', 'l', 'y', '\n',
        'w', 'o', 'o', 'l', 's', '\n',
        'w', 'o', 'o', 'l', 'y', '\n',
        'w', 'o', 'o', 's', '\n',
        'w', 'o', 'r', 'd', '\n',
        'w', 'o', 'r', 'd', 'a', 'g', 'e', '\n',
        'w', 'o', 'r', 'd', 'e', 'd', '\n',
        'w', 'o', 'r', 'd', 'g', 'a', 'm', 'e', '\n',
        'w', 'o', 'r', 'd', 'i', 'e', 'r', '\n',
        'w', 'o', 'r', 'd', 'i', 'e', 's', 't', '\n',
        'w', 'o', 'r', 'd', 'i', 'n', 'e', 's', 's', '\n',
        'w', 'o', 'r', 'd', 'i', 'n', 'g', '\n',
        'w', 'o', 'r', 'd', 'i', 'n', 'g', 's', '\n',
        'w', 'o', 'r', 'd', 'l', 'e', 's', 's', '\n',
        'w', 'o', 'r', 'd', 'l', 'e', 's', 's', 'l', 'y', '\n',
        'w', 'o', 'r', 'd', 'p', 'l', 'a', 'y', '\n',
        'w', 'o', 'r', 'd', 'p', 'r', 'o', 'c', 'e', 's', 's', 'i', 'n', 'g', '\n',
        'w', 'o', 'r', 'd', 's', '\n',
        'w', 'o', 'r', 'd', 's', 'm', 'i', 't', 'h', '\n',
        'w', 'o', 'r', 'd', 'y', '\n',
        'w', 'o', 'r', 'e', '\n',
        'w', 'o', 'r', 'k', '\n',
        'w', 'o', 'r', 'k', 'a', 'b', 'i', 'l', 'i', 't', 'y', '\n',
        'w', 'o', 'r', 'k', 'a', 'b', 'l', 'e', '\n',
        'w', 'o', 'r', 'k', 'a', 'd', 'a', 'y', '\n',
        'w', 'o', 'r', 'k', 'b', 'e', 'n', 'c', 'h', '\n',
        'w', 'o', 'r', 'k', 'b', 'o', 'o', 'k', '\n',
        'w', 'o', 'r', 'k', 'b', 'o', 'o', 'k', 's', '\n',
        'w', 'o', 'r', 'k', 'd', 'a', 'y', '\n',
        'w', 'o', 'r', 'k', 'd', 'a', 'y', 's', '\n',
        'w', 'o', 'r', 'k', 'e', 'd', '\n',
        'w', 'o', 'r', 'k', 'e', 'r', '\n',
        'w', 'o', 'r', 'k', 'e', 'r', 's', '\n',
        'w', 'o', 'r', 'k', 'f', 'a', 'r', 'e', '\n',
        'w', 'o', 'r', 'k', 'f', 'o', 'r', 'c', 'e', '\n',
        'w', 'o', 'r', 'k', 'f', 'o', 'r', 'c', 'e', 's', '\n',
        'w', 'o', 'r', 'k', 'h', 'o', 'r', 's', 'e', '\n',
        'w', 'o', 'r', 'k', 'h', 'o', 'r', 's', 'e', 's', '\n',
        'w', 'o', 'r', 'k', 'h', 'o', 'u', 's', 'e', '\n',
        'w', 'o', 'r', 'k', 'h', 'o', 'u', 's', 'e', 's', '\n',
        'w', 'o', 'r', 'k', 'i', 'n', 'g', '\n',
        'w', 'o', 'r', 'k', 'i', 'n', 'g', 's', '\n',
        'w', 'o', 'r', 'k', 'l', 'e', 's', 's', '\n',
        'w', 'o', 'r', 'k', 'l', 'o', 'a', 'd', '\n',
        'w', 'o', 'r', 'k', 'l', 'o', 'a', 'd', 's', '\n',
        'w', 'o', 'r', 'k', 'm', 'a', 'n', '\n',
        'w', 'o', 'r', 'k', 'm', 'a', 'n', 'l', 'i', 'k', 'e', '\n',
        'w', 'o', 'r', 'k', 'm', 'a', 'n', 's', 'h', 'i', 'p', '\n',
        'w', 'o', 'r', 'k', 'm', 'a', 't', 'e', '\n',
        'w', 'o', 'r', 'k', 'm', 'a', 't', 'e', 's', '\n',
        'w', 'o', 'r', 'k', 'm', 'e', 'n', '\n',
        'w', 'o', 'r', 'k', 'o', 'u', 't', '\n',
        'w', 'o', 'r', 'k', 'o', 'u', 't', 's', '\n',
        'w', 'o', 'r', 'k', 'p', 'e', 'o', 'p', 'l', 'e', '\n',
        'w', 'o', 'r', 'k', 'p', 'i', 'e', 'c', 'e', '\n',
        'w', 'o', 'r', 'k', 'p', 'i', 'e', 'c', 'e', 's', '\n',
        'w', 'o', 'r', 'k', 'p', 'l', 'a', 'c', 'e', '\n',
        'w', 'o', 'r', 'k', 'p', 'l', 'a', 'c', 'e', 's', '\n',
        'w', 'o', 'r', 'k', 'r', 'o', 'o', 'm', '\n',
        'w', 'o', 'r', 'k', 'r', 'o', 'o', 'm', 's', '\n',
        'w', 'o', 'r', 'k', 's', '\n',
        'w', 'o', 'r', 'k', 's', 'h', 'e', 'e', 't', '\n',
        'w', 'o', 'r', 'k', 's', 'h', 'e', 'e', 't', 's', '\n',
        'w', 'o', 'r', 'k', 's', 'h', 'o', 'p', '\n',
        'w', 'o', 'r', 'k', 's', 'h', 'o', 'p', 's', '\n',
        'w', 'o', 'r', 'k', 's', 'h', 'y', '\n',
        'w', 'o', 'r', 'k', 's', 'p', 'a', 'c', 'e', '\n',
        'w', 'o', 'r', 'k', 's', 't', 'a', 't', 'i', 'o', 'n', '\n',
        'w', 'o', 'r', 'k', 's', 't', 'a', 't', 'i', 'o', 'n', 's', '\n',
        'w', 'o', 'r', 'k', 't', 'o', 'p', '\n',
        'w', 'o', 'r', 'k', 't', 'o', 'p', 's', '\n',
        'w', 'o', 'r', 'k', 'w', 'e', 'e', 'k', '\n',
        'w', 'o', 'r', 'l', 'd', '\n',
        'w', 'o', 'r', 'l', 'd', 'c', 'l', 'a', 's', 's', '\n',
        'w', 'o', 'r', 'l', 'd', 'f', 'a', 'm', 'o', 'u', 's', '\n',
        'w', 'o', 'r', 'l', 'd', 'l', 'i', 'n', 'e', 's', 's', '\n',
        'w', 'o', 'r', 'l', 'd', 'l', 'y', '\n',
        'w', 'o', 'r', 'l', 'd', 's', '\n',
        'w', 'o', 'r', 'l', 'd', 'w', 'a', 'r', '\n',
        'w', 'o', 'r', 'l', 'd', 'w', 'i', 'd', 'e', '\n',
        'w', 'o', 'r', 'm', '\n',
        'w', 'o', 'r', 'm', 'h', 'o', 'l', 'e', '\n',
        'w', 'o', 'r', 'm', 'h', 'o', 'l', 'e', 's', '\n',
        'w', 'o', 'r', 'm', 'i', 'n', 'g', '\n',
        'w', 'o', 'r', 'm', 'l', 'i', 'k', 'e', '\n',
        'w', 'o', 'r', 'm', 's', '\n',
        'w', 'o', 'r', 'm', 'y', '\n',
        'w', 'o', 'r', 'n', '\n',
        'w', 'o', 'r', 'r', 'i', 'e', 'd', '\n',
        'w', 'o', 'r', 'r', 'i', 'e', 'd', 'l', 'y', '\n',
        'w', 'o', 'r', 'r', 'i', 'e', 'r', '\n',
        'w', 'o', 'r', 'r', 'i', 'e', 'r', 's', '\n',
        'w', 'o', 'r', 'r', 'i', 'e', 's', '\n',
        'w', 'o', 'r', 'r', 'i', 's', 'o', 'm', 'e', '\n',
        'w', 'o', 'r', 'r', 'y', '\n',
        'w', 'o', 'r', 'r', 'y', 'i', 'n', 'g', '\n',
        'w', 'o', 'r', 'r', 'y', 'i', 'n', 'g', 'l', 'y', '\n',
        'w', 'o', 'r', 's', 'e', '\n',
        'w', 'o', 'r', 's', 'e', 'n', '\n',
        'w', 'o', 'r', 's', 'e', 'n', 'e', 'd', '\n',
        'w', 'o', 'r', 's', 'e', 'n', 'i', 'n', 'g', '\n',
        'w', 'o', 'r', 's', 'e', 'n', 's', '\n',
        'w', 'o', 'r', 's', 'e', 'r', '\n',
        'w', 'o', 'r', 's', 'h', 'i', 'p', '\n',
        'w', 'o', 'r', 's', 'h', 'i', 'p', 'f', 'u', 'l', '\n',
        'w', 'o', 'r', 's', 'h', 'i', 'p', 'p', 'e', 'd', '\n',
        'w', 'o', 'r', 's', 'h', 'i', 'p', 'p', 'e', 'r', '\n',
        'w', 'o', 'r', 's', 'h', 'i', 'p', 'p', 'e', 'r', 's', '\n',
        'w', 'o', 'r', 's', 'h', 'i', 'p', 'p', 'i', 'n', 'g', '\n',
        'w', 'o', 'r', 's', 'h', 'i', 'p', 's', '\n',
        'w', 'o', 'r', 's', 't', '\n',
        'w', 'o', 'r', 's', 't', 'e', 'd', '\n',
        'w', 'o', 'r', 't', 'h', '\n',
        'w', 'o', 'r', 't', 'h', 'i', 'e', 'r', '\n',
        'w', 'o', 'r', 't', 'h', 'i', 'e', 's', '\n',
        'w', 'o', 'r', 't', 'h', 'i', 'e', 's', 't', '\n',
        'w', 'o', 'r', 't', 'h', 'i', 'l', 'y', '\n',
        'w', 'o', 'r', 't', 'h', 'i', 'n', 'e', 's', 's', '\n',
        'w', 'o', 'r', 't', 'h', 'l', 'e', 's', 's', '\n',
        'w', 'o', 'r', 't', 'h', 'l', 'e', 's', 's', 'n', 'e', 's', 's', '\n',
        'w', 'o', 'r', 't', 'h', 'w', 'h', 'i', 'l', 'e', '\n',
        'w', 'o', 'r', 't', 'h', 'y', '\n',
        'w', 'o', 'u', 'l', 'd', '\n',
        'w', 'o', 'u', 'n', 'd', '\n',
        'w', 'o', 'u', 'n', 'd', 'e', 'd', '\n',
        'w', 'o', 'u', 'n', 'd', 'i', 'n', 'g', '\n',
        'w', 'o', 'u', 'n', 'd', 's', '\n',
        'w', 'o', 'v', 'e', '\n',
        'w', 'o', 'v', 'e', 'n', '\n',
        'w', 'o', 'w', '\n',
        'w', 'o', 'w', 'e', 'd', '\n',
        'w', 'o', 'w', 's', '\n',
        'w', 'r', 'a', 'c', 'k', '\n',
        'w', 'r', 'a', 'c', 'k', 'e', 'd', '\n',
        'w', 'r', 'a', 'i', 't', 'h', '\n',
        'w', 'r', 'a', 'i', 't', 'h', 's', '\n',
        'w', 'r', 'a', 'n', 'g', 'l', 'e', '\n',
        'w', 'r', 'a', 'n', 'g', 'l', 'e', 'd', '\n',
        'w', 'r', 'a', 'n', 'g', 'l', 'e', 'r', '\n',
        'w', 'r', 'a', 'n', 'g', 'l', 'e', 's', '\n',
        'w', 'r', 'a', 'n', 'g', 'l', 'i', 'n', 'g', '\n',
        'w', 'r', 'a', 'p', '\n',
        'w', 'r', 'a', 'p', 'a', 'r', 'o', 'u', 'n', 'd', '\n',
        'w', 'r', 'a', 'p', 'p', 'e', 'd', '\n',
        'w', 'r', 'a', 'p', 'p', 'e', 'r', '\n',
        'w', 'r', 'a', 'p', 'p', 'e', 'r', 's', '\n',
        'w', 'r', 'a', 'p', 'p', 'i', 'n', 'g', '\n',
        'w', 'r', 'a', 'p', 'p', 'i', 'n', 'g', 's', '\n',
        'w', 'r', 'a', 'p', 's', '\n',
        'w', 'r', 'a', 's', 's', 'e', '\n',
        'w', 'r', 'a', 't', 'h', '\n',
        'w', 'r', 'a', 't', 'h', 'f', 'u', 'l', '\n',
        'w', 'r', 'a', 't', 'h', 'f', 'u', 'l', 'l', 'y', '\n',
        'w', 'r', 'a', 't', 'h', 's', '\n',
        'w', 'r', 'e', 'a', 'k', '\n',
        'w', 'r', 'e', 'a', 'k', 'e', 'd', '\n',
        'w', 'r', 'e', 'a', 'k', 'i', 'n', 'g', '\n',
        'w', 'r', 'e', 'a', 'k', 's', '\n',
        'w', 'r', 'e', 'a', 't', 'h', '\n',
        'w', 'r', 'e', 'a', 't', 'h', 'e', '\n',
        'w', 'r', 'e', 'a', 't', 'h', 'e', 'd', '\n',
        'w', 'r', 'e', 'a', 't', 'h', 'e', 's', '\n',
        'w', 'r', 'e', 'a', 't', 'h', 'i', 'n', 'g', '\n',
        'w', 'r', 'e', 'a', 't', 'h', 's', '\n',
        'w', 'r', 'e', 'c', 'k', '\n',
        'w', 'r', 'e', 'c', 'k', 'a', 'g', 'e', '\n',
        'w', 'r', 'e', 'c', 'k', 'e', 'd', '\n',
        'w', 'r', 'e', 'c', 'k', 'e', 'r', '\n',
        'w', 'r', 'e', 'c', 'k', 'e', 'r', 's', '\n',
        'w', 'r', 'e', 'c', 'k', 'i', 'n', 'g', '\n',
        'w', 'r', 'e', 'c', 'k', 's', '\n',
        'w', 'r', 'e', 'n', '\n',
        'w', 'r', 'e', 'n', 'c', 'h', '\n',
        'w', 'r', 'e', 'n', 'c', 'h', 'e', 'd', '\n',
        'w', 'r', 'e', 'n', 'c', 'h', 'e', 's', '\n',
        'w', 'r', 'e', 'n', 'c', 'h', 'i', 'n', 'g', '\n',
        'w', 'r', 'e', 'n', 's', '\n',
        'w', 'r', 'e', 's', 't', '\n',
        'w', 'r', 'e', 's', 't', 'e', 'd', '\n',
        'w', 'r', 'e', 's', 't', 'i', 'n', 'g', '\n',
        'w', 'r', 'e', 's', 't', 'l', 'e', '\n',
        'w', 'r', 'e', 's', 't', 'l', 'e', 'd', '\n',
        'w', 'r', 'e', 's', 't', 'l', 'e', 'r', '\n',
        'w', 'r', 'e', 's', 't', 'l', 'e', 'r', 's', '\n',
        'w', 'r', 'e', 's', 't', 'l', 'e', 's', '\n',
        'w', 'r', 'e', 's', 't', 'l', 'i', 'n', 'g', '\n',
        'w', 'r', 'e', 't', 'c', 'h', '\n',
        'w', 'r', 'e', 't', 'c', 'h', 'e', 'd', '\n',
        'w', 'r', 'e', 't', 'c', 'h', 'e', 'd', 'l', 'y', '\n',
        'w', 'r', 'e', 't', 'c', 'h', 'e', 'd', 'n', 'e', 's', 's', '\n',
        'w', 'r', 'e', 't', 'c', 'h', 'e', 's', '\n',
        'w', 'r', 'i', 'g', 'g', 'l', 'e', '\n',
        'w', 'r', 'i', 'g', 'g', 'l', 'e', 'd', '\n',
        'w', 'r', 'i', 'g', 'g', 'l', 'e', 's', '\n',
        'w', 'r', 'i', 'g', 'g', 'l', 'i', 'n', 'g', '\n',
        'w', 'r', 'i', 'g', 'g', 'l', 'y', '\n',
        'w', 'r', 'i', 'g', 'h', 't', '\n',
        'w', 'r', 'i', 'n', 'g', '\n',
        'w', 'r', 'i', 'n', 'g', 'e', 'r', '\n',
        'w', 'r', 'i', 'n', 'g', 'i', 'n', 'g', '\n',
        'w', 'r', 'i', 'n', 'g', 's', '\n',
        'w', 'r', 'i', 'n', 'k', 'l', 'e', '\n',
        'w', 'r', 'i', 'n', 'k', 'l', 'e', 'd', '\n',
        'w', 'r', 'i', 'n', 'k', 'l', 'e', 's', '\n',
        'w', 'r', 'i', 'n', 'k', 'l', 'i', 'n', 'g', '\n',
        'w', 'r', 'i', 'n', 'k', 'l', 'y', '\n',
        'w', 'r', 'i', 's', 't', '\n',
        'w', 'r', 'i', 's', 't', 'b', 'a', 'n', 'd', '\n',
        'w', 'r', 'i', 's', 't', 'b', 'a', 'n', 'd', 's', '\n',
        'w', 'r', 'i', 's', 't', 's', '\n',
        'w', 'r', 'i', 's', 't', 'w', 'a', 't', 'c', 'h', '\n',
        'w', 'r', 'i', 't', '\n',
        'w', 'r', 'i', 't', 'a', 'b', 'l', 'e', '\n',
        'w', 'r', 'i', 't', 'e', '\n',
        'w', 'r', 'i', 't', 'e', 'r', '\n',
        'w', 'r', 'i', 't', 'e', 'r', 's', '\n',
        'w', 'r', 'i', 't', 'e', 's', '\n',
        'w', 'r', 'i', 't', 'h', 'e', '\n',
        'w', 'r', 'i', 't', 'h', 'e', 'd', '\n',
        'w', 'r', 'i', 't', 'h', 'e', 's', '\n',
        'w', 'r', 'i', 't', 'h', 'i', 'n', 'g', '\n',
        'w', 'r', 'i', 't', 'i', 'n', 'g', '\n',
        'w', 'r', 'i', 't', 'i', 'n', 'g', 's', '\n',
        'w', 'r', 'i', 't', 's', '\n',
        'w', 'r', 'i', 't', 't', 'e', 'n', '\n',
        'w', 'r', 'o', 'n', 'g', '\n',
        'w', 'r', 'o', 'n', 'g', 'd', 'o', 'e', 'r', '\n',
        'w', 'r', 'o', 'n', 'g', 'd', 'o', 'e', 'r', 's', '\n',
        'w', 'r', 'o', 'n', 'g', 'd', 'o', 'i', 'n', 'g', '\n',
        'w', 'r', 'o', 'n', 'g', 'd', 'o', 'i', 'n', 'g', 's', '\n',
        'w', 'r', 'o', 'n', 'g', 'e', 'd', '\n',
        'w', 'r', 'o', 'n', 'g', 'e', 'r', '\n',
        'w', 'r', 'o', 'n', 'g', 'e', 's', 't', '\n',
        'w', 'r', 'o', 'n', 'g', 'f', 'u', 'l', '\n',
        'w', 'r', 'o', 'n', 'g', 'f', 'u', 'l', 'l', 'y', '\n',
        'w', 'r', 'o', 'n', 'g', 'i', 'n', 'g', '\n',
        'w', 'r', 'o', 'n', 'g', 'l', 'y', '\n',
        'w', 'r', 'o', 'n', 'g', 'n', 'e', 's', 's', '\n',
        'w', 'r', 'o', 'n', 'g', 's', '\n',
        'w', 'r', 'o', 't', 'e', '\n',
        'w', 'r', 'o', 'u', 'g', 'h', 't', '\n',
        'w', 'r', 'o', 'u', 'g', 'h', 't', 'i', 'r', 'o', 'n', '\n',
        'w', 'r', 'u', 'n', 'g', '\n',
        'w', 'r', 'y', '\n',
        'w', 'r', 'y', 'l', 'y', '\n',
        'w', 'r', 'y', 'n', 'e', 's', 's', '\n',
        'w', 'u', 'n', 'd', 'e', 'r', 'k', 'i', 'n', 'd', '\n',
        'x', 'e', 'n', 'o', 'n', '\n',
        'x', 'e', 'n', 'o', 'p', 'h', 'o', 'b', 'e', '\n',
        'x', 'e', 'n', 'o', 'p', 'h', 'o', 'b', 'i', 'a', '\n',
        'x', 'e', 'n', 'o', 'p', 'h', 'o', 'b', 'i', 'c', '\n',
        'x', 'e', 'r', 'o', 'g', 'r', 'a', 'p', 'h', 'y', '\n',
        'x', 'h', 'o', 's', 'a', '\n',
        'x', 'h', 'o', 's', 'a', 's', '\n',
        'x', 'm', 'a', 's', '\n',
        'x', 'r', 'a', 'y', '\n',
        'x', 'r', 'a', 'y', 'e', 'd', '\n',
        'x', 'r', 'a', 'y', 'i', 'n', 'g', '\n',
        'x', 'r', 'a', 'y', 's', '\n',
        'x', 'y', 'l', 'o', 'p', 'h', 'o', 'n', 'e', '\n',
        'x', 'y', 'l', 'o', 'p', 'h', 'o', 'n', 'i', 's', 't', '\n',
        'y', 'a', 'c', 'h', 't', '\n',
        'y', 'a', 'c', 'h', 't', 'i', 'n', 'g', '\n',
        'y', 'a', 'c', 'h', 't', 's', '\n',
        'y', 'a', 'c', 'h', 't', 's', 'm', 'a', 'n', '\n',
        'y', 'a', 'c', 'h', 't', 's', 'm', 'e', 'n', '\n',
        'y', 'a', 'k', '\n',
        'y', 'a', 'k', 's', '\n',
        'y', 'a', 'l', 'e', '\n',
        'y', 'a', 'l', 'e', 'l', 'o', 'c', 'k', '\n',
        'y', 'a', 'm', '\n',
        'y', 'a', 'm', 's', '\n',
        'y', 'a', 'n', 'k', '\n',
        'y', 'a', 'n', 'k', 'e', 'e', '\n',
        'y', 'a', 'n', 'k', 'e', 'e', 's', '\n',
        'y', 'a', 'n', 'k', 's', '\n',
        'y', 'a', 'p', '\n',
        'y', 'a', 'p', 'p', 'i', 'n', 'g', '\n',
        'y', 'a', 'p', 's', '\n',
        'y', 'a', 'r', 'd', '\n',
        'y', 'a', 'r', 'd', 'a', 'g', 'e', '\n',
        'y', 'a', 'r', 'd', 's', '\n',
        'y', 'a', 'r', 'd', 's', 't', 'i', 'c', 'k', '\n',
        'y', 'a', 'r', 'd', 's', 't', 'i', 'c', 'k', 's', '\n',
        'y', 'a', 'r', 'n', '\n',
        'y', 'a', 'r', 'n', 's', '\n',
        'y', 'a', 'w', '\n',
        'y', 'a', 'w', 'e', 'd', '\n',
        'y', 'a', 'w', 'l', '\n',
        'y', 'a', 'w', 'l', 's', '\n',
        'y', 'a', 'w', 'n', '\n',
        'y', 'a', 'w', 'n', 'e', 'd', '\n',
        'y', 'a', 'w', 'n', 'i', 'n', 'g', '\n',
        'y', 'a', 'w', 'n', 'i', 'n', 'g', 'l', 'y', '\n',
        'y', 'a', 'w', 'n', 's', '\n',
        'y', 'a', 'w', 's', '\n',
        'y', 'e', '\n',
        'y', 'e', 'a', '\n',
        'y', 'e', 'a', 'h', '\n',
        'y', 'e', 'a', 'n', 'e', 'd', '\n',
        'y', 'e', 'a', 'r', '\n',
        'y', 'e', 'a', 'r', 'b', 'o', 'o', 'k', '\n',
        'y', 'e', 'a', 'r', 'b', 'o', 'o', 'k', 's', '\n',
        'y', 'e', 'a', 'r', 'l', 'i', 'n', 'g', '\n',
        'y', 'e', 'a', 'r', 'l', 'i', 'n', 'g', 's', '\n',
        'y', 'e', 'a', 'r', 'l', 'o', 'n', 'g', '\n',
        'y', 'e', 'a', 'r', 'l', 'y', '\n',
        'y', 'e', 'a', 'r', 'n', '\n',
        'y', 'e', 'a', 'r', 'n', 'e', 'd', '\n',
        'y', 'e', 'a', 'r', 'n', 'i', 'n', 'g', '\n',
        'y', 'e', 'a', 'r', 'n', 'i', 'n', 'g', 'l', 'y', '\n',
        'y', 'e', 'a', 'r', 'n', 'i', 'n', 'g', 's', '\n',
        'y', 'e', 'a', 'r', 'n', 's', '\n',
        'y', 'e', 'a', 'r', 's', '\n',
        'y', 'e', 'a', 's', '\n',
        'y', 'e', 'a', 's', 't', '\n',
        'y', 'e', 'a', 's', 't', 's', '\n',
        'y', 'e', 'a', 's', 't', 'y', '\n',
        'y', 'e', 'l', 'l', '\n',
        'y', 'e', 'l', 'l', 'e', 'd', '\n',
        'y', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'y', 'e', 'l', 'l', 'i', 'n', 'g', 's', '\n',
        'y', 'e', 'l', 'l', 'o', 'w', '\n',
        'y', 'e', 'l', 'l', 'o', 'w', 'e', 'd', '\n',
        'y', 'e', 'l', 'l', 'o', 'w', 'e', 'r', '\n',
        'y', 'e', 'l', 'l', 'o', 'w', 'i', 'n', 'g', '\n',
        'y', 'e', 'l', 'l', 'o', 'w', 'i', 's', 'h', '\n',
        'y', 'e', 'l', 'l', 'o', 'w', 's', '\n',
        'y', 'e', 'l', 'l', 'o', 'w', 'y', '\n',
        'y', 'e', 'l', 'l', 's', '\n',
        'y', 'e', 'l', 'p', '\n',
        'y', 'e', 'l', 'p', 'e', 'd', '\n',
        'y', 'e', 'l', 'p', 'i', 'n', 'g', '\n',
        'y', 'e', 'l', 'p', 'i', 'n', 'g', 's', '\n',
        'y', 'e', 'l', 'p', 's', '\n',
        'y', 'e', 'm', 'e', 'n', '\n',
        'y', 'e', 'n', '\n',
        'y', 'e', 'n', 's', '\n',
        'y', 'e', 'o', 'm', 'a', 'n', '\n',
        'y', 'e', 'o', 'm', 'a', 'n', 'r', 'y', '\n',
        'y', 'e', 'o', 'm', 'e', 'n', '\n',
        'y', 'e', 'p', '\n',
        'y', 'e', 's', '\n',
        'y', 'e', 's', 't', 'e', 'r', 'd', 'a', 'y', '\n',
        'y', 'e', 's', 't', 'e', 'r', 'd', 'a', 'y', 's', '\n',
        'y', 'e', 's', 't', 'e', 'r', 'y', 'e', 'a', 'r', '\n',
        'y', 'e', 't', '\n',
        'y', 'e', 't', 'i', '\n',
        'y', 'e', 't', 'i', 's', '\n',
        'y', 'e', 'w', '\n',
        'y', 'e', 'w', 's', '\n',
        'y', 'i', 'd', 'd', 'i', 's', 'h', '\n',
        'y', 'i', 'e', 'l', 'd', '\n',
        'y', 'i', 'e', 'l', 'd', 'e', 'd', '\n',
        'y', 'i', 'e', 'l', 'd', 'i', 'n', 'g', '\n',
        'y', 'i', 'e', 'l', 'd', 's', '\n',
        'y', 'i', 'p', '\n',
        'y', 'i', 'p', 'p', 'e', 'e', '\n',
        'y', 'o', 'd', 'e', 'l', '\n',
        'y', 'o', 'd', 'e', 'l', 'l', 'e', 'd', '\n',
        'y', 'o', 'd', 'e', 'l', 'l', 'e', 'r', '\n',
        'y', 'o', 'd', 'e', 'l', 'l', 'i', 'n', 'g', '\n',
        'y', 'o', 'd', 'e', 'l', 's', '\n',
        'y', 'o', 'g', 'a', '\n',
        'y', 'o', 'g', 'i', '\n',
        'y', 'o', 'k', 'e', '\n',
        'y', 'o', 'k', 'e', 'd', '\n',
        'y', 'o', 'k', 'e', 'l', '\n',
        'y', 'o', 'k', 'e', 'l', 's', '\n',
        'y', 'o', 'k', 'e', 's', '\n',
        'y', 'o', 'l', 'k', '\n',
        'y', 'o', 'l', 'k', 's', '\n',
        'y', 'o', 'n', '\n',
        'y', 'o', 'n', 'd', 'e', 'r', '\n',
        'y', 'o', 'r', 'e', '\n',
        'y', 'o', 'r', 'k', '\n',
        'y', 'o', 'r', 'k', 'e', 'r', '\n',
        'y', 'o', 'r', 'k', 'e', 'r', 's', '\n',
        'y', 'o', 'u', '\n',
        'y', 'o', 'u', 'n', 'g', '\n',
        'y', 'o', 'u', 'n', 'g', 'e', 'r', '\n',
        'y', 'o', 'u', 'n', 'g', 'e', 's', 't', '\n',
        'y', 'o', 'u', 'n', 'g', 'i', 's', 'h', '\n',
        'y', 'o', 'u', 'n', 'g', 's', 't', 'e', 'r', '\n',
        'y', 'o', 'u', 'n', 'g', 's', 't', 'e', 'r', 's', '\n',
        'y', 'o', 'u', 'r', '\n',
        'y', 'o', 'u', 'r', 's', '\n',
        'y', 'o', 'u', 'r', 's', 'e', 'l', 'f', '\n',
        'y', 'o', 'u', 'r', 's', 'e', 'l', 'v', 'e', 's', '\n',
        'y', 'o', 'u', 't', 'h', '\n',
        'y', 'o', 'u', 't', 'h', 'f', 'u', 'l', '\n',
        'y', 'o', 'u', 't', 'h', 'f', 'u', 'l', 'n', 'e', 's', 's', '\n',
        'y', 'o', 'u', 't', 'h', 's', '\n',
        'y', 'o', 'w', 'l', '\n',
        'y', 'o', 'y', 'o', '\n',
        'y', 'r', 's', '\n',
        'y', 't', 't', 'r', 'i', 'u', 'm', '\n',
        'y', 'u', 'c', 'k', '\n',
        'y', 'u', 'k', 'o', 'n', '\n',
        'y', 'u', 'l', 'e', '\n',
        'y', 'u', 'l', 'e', 't', 'i', 'd', 'e', '\n',
        'y', 'u', 'm', 'm', 'i', 'e', 's', 't', '\n',
        'y', 'u', 'm', 'm', 'y', '\n',
        'y', 'u', 'p', 'p', 'i', 'e', '\n',
        'y', 'u', 'p', 'p', 'i', 'e', 's', '\n',
        'z', 'a', 'g', '\n',
        'z', 'a', 'i', 'r', 'e', '\n',
        'z', 'a', 'm', 'b', 'e', 'z', 'i', '\n',
        'z', 'a', 'm', 'b', 'i', 'a', '\n',
        'z', 'a', 'm', 'b', 'i', 'a', 'n', '\n',
        'z', 'a', 'm', 'b', 'i', 'a', 'n', 's', '\n',
        'z', 'a', 'n', 'i', 'e', 's', 't', '\n',
        'z', 'a', 'n', 'y', '\n',
        'z', 'a', 'n', 'z', 'i', 'b', 'a', 'r', '\n',
        'z', 'a', 'p', '\n',
        'z', 'a', 'p', 'p', 'i', 'n', 'g', '\n',
        'z', 'a', 'p', 'p', 'y', '\n',
        'z', 'a', 'p', 's', '\n',
        'z', 'e', 'a', 'l', '\n',
        'z', 'e', 'a', 'l', 'o', 't', '\n',
        'z', 'e', 'a', 'l', 'o', 't', 'r', 'y', '\n',
        'z', 'e', 'a', 'l', 'o', 't', 's', '\n',
        'z', 'e', 'a', 'l', 'o', 'u', 's', '\n',
        'z', 'e', 'a', 'l', 'o', 'u', 's', 'l', 'y', '\n',
        'z', 'e', 'a', 'l', 'o', 'u', 's', 'n', 'e', 's', 's', '\n',
        'z', 'e', 'a', 'l', 's', '\n',
        'z', 'e', 'b', 'r', 'a', '\n',
        'z', 'e', 'b', 'r', 'a', 's', '\n',
        'z', 'e', 'b', 'u', '\n',
        'z', 'e', 'b', 'u', 's', '\n',
        'z', 'e', 'e', 's', '\n',
        'z', 'e', 'n', 'i', 't', 'h', '\n',
        'z', 'e', 'n', 'i', 't', 'h', 's', '\n',
        'z', 'e', 'o', 'l', 'i', 't', 'e', '\n',
        'z', 'e', 'o', 'l', 'i', 't', 'e', 's', '\n',
        'z', 'e', 'p', 'h', 'y', 'r', '\n',
        'z', 'e', 'p', 'h', 'y', 'r', 's', '\n',
        'z', 'e', 'p', 'p', 'e', 'l', 'i', 'n', '\n',
        'z', 'e', 'r', 'o', '\n',
        'z', 'e', 'r', 'o', 'e', 'd', '\n',
        'z', 'e', 'r', 'o', 'i', 'n', 'g', '\n',
        'z', 'e', 's', 't', '\n',
        'z', 'e', 's', 't', 'f', 'u', 'l', 'l', 'y', '\n',
        'z', 'e', 's', 't', 'y', '\n',
        'z', 'e', 't', 'a', '\n',
        'z', 'e', 'u', 's', '\n',
        'z', 'i', 'g', '\n',
        'z', 'i', 'g', 'z', 'a', 'g', '\n',
        'z', 'i', 'g', 'z', 'a', 'g', 'g', 'e', 'd', '\n',
        'z', 'i', 'g', 'z', 'a', 'g', 'g', 'i', 'n', 'g', '\n',
        'z', 'i', 'g', 'z', 'a', 'g', 's', '\n',
        'z', 'i', 'l', 'l', 'i', 'o', 'n', '\n',
        'z', 'i', 'l', 'l', 'i', 'o', 'n', 's', '\n',
        'z', 'i', 'm', 'b', 'a', 'b', 'w', 'e', '\n',
        'z', 'i', 'n', 'c', '\n',
        'z', 'i', 'o', 'n', '\n',
        'z', 'i', 'o', 'n', 'i', 's', 'm', '\n',
        'z', 'i', 'o', 'n', 'i', 's', 't', '\n',
        'z', 'i', 'o', 'n', 'i', 's', 't', 's', '\n',
        'z', 'i', 'p', '\n',
        'z', 'i', 'p', 'p', 'e', 'd', '\n',
        'z', 'i', 'p', 'p', 'e', 'r', '\n',
        'z', 'i', 'p', 'p', 'e', 'r', 's', '\n',
        'z', 'i', 'p', 'p', 'i', 'n', 'g', '\n',
        'z', 'i', 'p', 'p', 'y', '\n',
        'z', 'i', 'p', 's', '\n',
        'z', 'i', 't', 'h', 'e', 'r', '\n',
        'z', 'i', 't', 'h', 'e', 'r', 's', '\n',
        'z', 'o', 'm', 'b', 'i', '\n',
        'z', 'o', 'm', 'b', 'i', 'e', '\n',
        'z', 'o', 'm', 'b', 'i', 'e', 's', '\n',
        'z', 'o', 'n', 'a', 'l', '\n',
        'z', 'o', 'n', 'a', 't', 'i', 'o', 'n', '\n',
        'z', 'o', 'n', 'e', '\n',
        'z', 'o', 'n', 'e', 'd', '\n',
        'z', 'o', 'n', 'e', 's', '\n',
        'z', 'o', 'n', 'i', 'n', 'g', '\n',
        'z', 'o', 'o', '\n',
        'z', 'o', 'o', 'k', 'e', 'e', 'p', 'e', 'r', 's', '\n',
        'z', 'o', 'o', 'l', 'o', 'g', 'i', 'c', 'a', 'l', '\n',
        'z', 'o', 'o', 'l', 'o', 'g', 'i', 's', 't', '\n',
        'z', 'o', 'o', 'l', 'o', 'g', 'i', 's', 't', 's', '\n',
        'z', 'o', 'o', 'l', 'o', 'g', 'y', '\n',
        'z', 'o', 'o', 'm', '\n',
        'z', 'o', 'o', 'm', 'e', 'd', '\n',
        'z', 'o', 'o', 'm', 'i', 'n', 'g', '\n',
        'z', 'o', 'o', 'm', 's', '\n',
        'z', 'o', 'o', 'p', 'l', 'a', 'n', 'k', 't', 'o', 'n', '\n',
        'z', 'o', 'o', 's', '\n',
        'z', 'u', 'l', 'u', '\n',
        'z', 'u', 'l', 'u', 's', '\n',
        '\0'
    };

    // Two characters to ignore: '\n' at start and '\0' at end of the literal.
    constexpr auto english_words = string_view(
        english_words_literal + 1, sizeof( english_words_literal ) - 2
        );

    inline auto count_the_english_words()
        -> int
    {
        int count = 0;
        for( const char ch: english_words ) {
            count += (ch == '\n');
        }
        return count;
    }
    
    const struct
    {
        operator int() const        // Lazy evaluation to pay only for what's used.
        {
            static int n = count_the_english_words();
            return n;
        }
    } n_english_words;

}  // namespace data
